/*!
 * jQuery JavaScript Library v2.1.4
 * http://jquery.com/
 *
 * Includes Sizzle.js
 * http://sizzlejs.com/
 *
 * Copyright 2005, 2014 jQuery Foundation, Inc. and other contributors
 * Released under the MIT license
 * http://jquery.org/license
 *
 * Date: 2015-04-28T16:01Z
 */

(function( global, factory ) {

	if ( typeof module === "object" && typeof module.exports === "object" ) {
		// For CommonJS and CommonJS-like environments where a proper `window`
		// is present, execute the factory and get jQuery.
		// For environments that do not have a `window` with a `document`
		// (such as Node.js), expose a factory as module.exports.
		// This accentuates the need for the creation of a real `window`.
		// e.g. var jQuery = require("jquery")(window);
		// See ticket #14549 for more info.
		module.exports = global.document ?
			factory( global, true ) :
			function( w ) {
				if ( !w.document ) {
					throw new Error( "jQuery requires a window with a document" );
				}
				return factory( w );
			};
	} else {
		factory( global );
	}

// Pass this if window is not defined yet
}(typeof window !== "undefined" ? window : this, function( window, noGlobal ) {

// Support: Firefox 18+
// Can't be in strict mode, several libs including ASP.NET trace
// the stack via arguments.caller.callee and Firefox dies if
// you try to trace through "use strict" call chains. (#13335)
//

var arr = [];

var slice = arr.slice;

var concat = arr.concat;

var push = arr.push;

var indexOf = arr.indexOf;

var class2type = {};

var toString = class2type.toString;

var hasOwn = class2type.hasOwnProperty;

var support = {};



var
	// Use the correct document accordingly with window argument (sandbox)
	document = window.document,

	version = "2.1.4",

	// Define a local copy of jQuery
	jQuery = function( selector, context ) {
		// The jQuery object is actually just the init constructor 'enhanced'
		// Need init if jQuery is called (just allow error to be thrown if not included)
		return new jQuery.fn.init( selector, context );
	},

	// Support: Android<4.1
	// Make sure we trim BOM and NBSP
	rtrim = /^[\s\uFEFF\xA0]+|[\s\uFEFF\xA0]+$/g,

	// Matches dashed string for camelizing
	rmsPrefix = /^-ms-/,
	rdashAlpha = /-([\da-z])/gi,

	// Used by jQuery.camelCase as callback to replace()
	fcamelCase = function( all, letter ) {
		return letter.toUpperCase();
	};

jQuery.fn = jQuery.prototype = {
	// The current version of jQuery being used
	jquery: version,

	constructor: jQuery,

	// Start with an empty selector
	selector: "",

	// The default length of a jQuery object is 0
	length: 0,

	toArray: function() {
		return slice.call( this );
	},

	// Get the Nth element in the matched element set OR
	// Get the whole matched element set as a clean array
	get: function( num ) {
		return num != null ?

			// Return just the one element from the set
			( num < 0 ? this[ num + this.length ] : this[ num ] ) :

			// Return all the elements in a clean array
			slice.call( this );
	},

	// Take an array of elements and push it onto the stack
	// (returning the new matched element set)
	pushStack: function( elems ) {

		// Build a new jQuery matched element set
		var ret = jQuery.merge( this.constructor(), elems );

		// Add the old object onto the stack (as a reference)
		ret.prevObject = this;
		ret.context = this.context;

		// Return the newly-formed element set
		return ret;
	},

	// Execute a callback for every element in the matched set.
	// (You can seed the arguments with an array of args, but this is
	// only used internally.)
	each: function( callback, args ) {
		return jQuery.each( this, callback, args );
	},

	map: function( callback ) {
		return this.pushStack( jQuery.map(this, function( elem, i ) {
			return callback.call( elem, i, elem );
		}));
	},

	slice: function() {
		return this.pushStack( slice.apply( this, arguments ) );
	},

	first: function() {
		return this.eq( 0 );
	},

	last: function() {
		return this.eq( -1 );
	},

	eq: function( i ) {
		var len = this.length,
			j = +i + ( i < 0 ? len : 0 );
		return this.pushStack( j >= 0 && j < len ? [ this[j] ] : [] );
	},

	end: function() {
		return this.prevObject || this.constructor(null);
	},

	// For internal use only.
	// Behaves like an Array's method, not like a jQuery method.
	push: push,
	sort: arr.sort,
	splice: arr.splice
};

jQuery.extend = jQuery.fn.extend = function() {
	var options, name, src, copy, copyIsArray, clone,
		target = arguments[0] || {},
		i = 1,
		length = arguments.length,
		deep = false;

	// Handle a deep copy situation
	if ( typeof target === "boolean" ) {
		deep = target;

		// Skip the boolean and the target
		target = arguments[ i ] || {};
		i++;
	}

	// Handle case when target is a string or something (possible in deep copy)
	if ( typeof target !== "object" && !jQuery.isFunction(target) ) {
		target = {};
	}

	// Extend jQuery itself if only one argument is passed
	if ( i === length ) {
		target = this;
		i--;
	}

	for ( ; i < length; i++ ) {
		// Only deal with non-null/undefined values
		if ( (options = arguments[ i ]) != null ) {
			// Extend the base object
			for ( name in options ) {
				src = target[ name ];
				copy = options[ name ];

				// Prevent never-ending loop
				if ( target === copy ) {
					continue;
				}

				// Recurse if we're merging plain objects or arrays
				if ( deep && copy && ( jQuery.isPlainObject(copy) || (copyIsArray = jQuery.isArray(copy)) ) ) {
					if ( copyIsArray ) {
						copyIsArray = false;
						clone = src && jQuery.isArray(src) ? src : [];

					} else {
						clone = src && jQuery.isPlainObject(src) ? src : {};
					}

					// Never move original objects, clone them
					target[ name ] = jQuery.extend( deep, clone, copy );

				// Don't bring in undefined values
				} else if ( copy !== undefined ) {
					target[ name ] = copy;
				}
			}
		}
	}

	// Return the modified object
	return target;
};

jQuery.extend({
	// Unique for each copy of jQuery on the page
	expando: "jQuery" + ( version + Math.random() ).replace( /\D/g, "" ),

	// Assume jQuery is ready without the ready module
	isReady: true,

	error: function( msg ) {
		throw new Error( msg );
	},

	noop: function() {},

	isFunction: function( obj ) {
		return jQuery.type(obj) === "function";
	},

	isArray: Array.isArray,

	isWindow: function( obj ) {
		return obj != null && obj === obj.window;
	},

	isNumeric: function( obj ) {
		// parseFloat NaNs numeric-cast false positives (null|true|false|"")
		// ...but misinterprets leading-number strings, particularly hex literals ("0x...")
		// subtraction forces infinities to NaN
		// adding 1 corrects loss of precision from parseFloat (#15100)
		return !jQuery.isArray( obj ) && (obj - parseFloat( obj ) + 1) >= 0;
	},

	isPlainObject: function( obj ) {
		// Not plain objects:
		// - Any object or value whose internal [[Class]] property is not "[object Object]"
		// - DOM nodes
		// - window
		if ( jQuery.type( obj ) !== "object" || obj.nodeType || jQuery.isWindow( obj ) ) {
			return false;
		}

		if ( obj.constructor &&
				!hasOwn.call( obj.constructor.prototype, "isPrototypeOf" ) ) {
			return false;
		}

		// If the function hasn't returned already, we're confident that
		// |obj| is a plain object, created by {} or constructed with new Object
		return true;
	},

	isEmptyObject: function( obj ) {
		var name;
		for ( name in obj ) {
			return false;
		}
		return true;
	},

	type: function( obj ) {
		if ( obj == null ) {
			return obj + "";
		}
		// Support: Android<4.0, iOS<6 (functionish RegExp)
		return typeof obj === "object" || typeof obj === "function" ?
			class2type[ toString.call(obj) ] || "object" :
			typeof obj;
	},

	// Evaluates a script in a global context
	globalEval: function( code ) {
		var script,
			indirect = eval;

		code = jQuery.trim( code );

		if ( code ) {
			// If the code includes a valid, prologue position
			// strict mode pragma, execute code by injecting a
			// script tag into the document.
			if ( code.indexOf("use strict") === 1 ) {
				script = document.createElement("script");
				script.text = code;
				document.head.appendChild( script ).parentNode.removeChild( script );
			} else {
			// Otherwise, avoid the DOM node creation, insertion
			// and removal by using an indirect global eval
				indirect( code );
			}
		}
	},

	// Convert dashed to camelCase; used by the css and data modules
	// Support: IE9-11+
	// Microsoft forgot to hump their vendor prefix (#9572)
	camelCase: function( string ) {
		return string.replace( rmsPrefix, "ms-" ).replace( rdashAlpha, fcamelCase );
	},

	nodeName: function( elem, name ) {
		return elem.nodeName && elem.nodeName.toLowerCase() === name.toLowerCase();
	},

	// args is for internal usage only
	each: function( obj, callback, args ) {
		var value,
			i = 0,
			length = obj.length,
			isArray = isArraylike( obj );

		if ( args ) {
			if ( isArray ) {
				for ( ; i < length; i++ ) {
					value = callback.apply( obj[ i ], args );

					if ( value === false ) {
						break;
					}
				}
			} else {
				for ( i in obj ) {
					value = callback.apply( obj[ i ], args );

					if ( value === false ) {
						break;
					}
				}
			}

		// A special, fast, case for the most common use of each
		} else {
			if ( isArray ) {
				for ( ; i < length; i++ ) {
					value = callback.call( obj[ i ], i, obj[ i ] );

					if ( value === false ) {
						break;
					}
				}
			} else {
				for ( i in obj ) {
					value = callback.call( obj[ i ], i, obj[ i ] );

					if ( value === false ) {
						break;
					}
				}
			}
		}

		return obj;
	},

	// Support: Android<4.1
	trim: function( text ) {
		return text == null ?
			"" :
			( text + "" ).replace( rtrim, "" );
	},

	// results is for internal usage only
	makeArray: function( arr, results ) {
		var ret = results || [];

		if ( arr != null ) {
			if ( isArraylike( Object(arr) ) ) {
				jQuery.merge( ret,
					typeof arr === "string" ?
					[ arr ] : arr
				);
			} else {
				push.call( ret, arr );
			}
		}

		return ret;
	},

	inArray: function( elem, arr, i ) {
		return arr == null ? -1 : indexOf.call( arr, elem, i );
	},

	merge: function( first, second ) {
		var len = +second.length,
			j = 0,
			i = first.length;

		for ( ; j < len; j++ ) {
			first[ i++ ] = second[ j ];
		}

		first.length = i;

		return first;
	},

	grep: function( elems, callback, invert ) {
		var callbackInverse,
			matches = [],
			i = 0,
			length = elems.length,
			callbackExpect = !invert;

		// Go through the array, only saving the items
		// that pass the validator function
		for ( ; i < length; i++ ) {
			callbackInverse = !callback( elems[ i ], i );
			if ( callbackInverse !== callbackExpect ) {
				matches.push( elems[ i ] );
			}
		}

		return matches;
	},

	// arg is for internal usage only
	map: function( elems, callback, arg ) {
		var value,
			i = 0,
			length = elems.length,
			isArray = isArraylike( elems ),
			ret = [];

		// Go through the array, translating each of the items to their new values
		if ( isArray ) {
			for ( ; i < length; i++ ) {
				value = callback( elems[ i ], i, arg );

				if ( value != null ) {
					ret.push( value );
				}
			}

		// Go through every key on the object,
		} else {
			for ( i in elems ) {
				value = callback( elems[ i ], i, arg );

				if ( value != null ) {
					ret.push( value );
				}
			}
		}

		// Flatten any nested arrays
		return concat.apply( [], ret );
	},

	// A global GUID counter for objects
	guid: 1,

	// Bind a function to a context, optionally partially applying any
	// arguments.
	proxy: function( fn, context ) {
		var tmp, args, proxy;

		if ( typeof context === "string" ) {
			tmp = fn[ context ];
			context = fn;
			fn = tmp;
		}

		// Quick check to determine if target is callable, in the spec
		// this throws a TypeError, but we will just return undefined.
		if ( !jQuery.isFunction( fn ) ) {
			return undefined;
		}

		// Simulated bind
		args = slice.call( arguments, 2 );
		proxy = function() {
			return fn.apply( context || this, args.concat( slice.call( arguments ) ) );
		};

		// Set the guid of unique handler to the same of original handler, so it can be removed
		proxy.guid = fn.guid = fn.guid || jQuery.guid++;

		return proxy;
	},

	now: Date.now,

	// jQuery.support is not used in Core but other projects attach their
	// properties to it so it needs to exist.
	support: support
});

// Populate the class2type map
jQuery.each("Boolean Number String Function Array Date RegExp Object Error".split(" "), function(i, name) {
	class2type[ "[object " + name + "]" ] = name.toLowerCase();
});

function isArraylike( obj ) {

	// Support: iOS 8.2 (not reproducible in simulator)
	// `in` check used to prevent JIT error (gh-2145)
	// hasOwn isn't used here due to false negatives
	// regarding Nodelist length in IE
	var length = "length" in obj && obj.length,
		type = jQuery.type( obj );

	if ( type === "function" || jQuery.isWindow( obj ) ) {
		return false;
	}

	if ( obj.nodeType === 1 && length ) {
		return true;
	}

	return type === "array" || length === 0 ||
		typeof length === "number" && length > 0 && ( length - 1 ) in obj;
}
var Sizzle =
/*!
 * Sizzle CSS Selector Engine v2.2.0-pre
 * http://sizzlejs.com/
 *
 * Copyright 2008, 2014 jQuery Foundation, Inc. and other contributors
 * Released under the MIT license
 * http://jquery.org/license
 *
 * Date: 2014-12-16
 */
(function( window ) {

var i,
	support,
	Expr,
	getText,
	isXML,
	tokenize,
	compile,
	select,
	outermostContext,
	sortInput,
	hasDuplicate,

	// Local document vars
	setDocument,
	document,
	docElem,
	documentIsHTML,
	rbuggyQSA,
	rbuggyMatches,
	matches,
	contains,

	// Instance-specific data
	expando = "sizzle" + 1 * new Date(),
	preferredDoc = window.document,
	dirruns = 0,
	done = 0,
	classCache = createCache(),
	tokenCache = createCache(),
	compilerCache = createCache(),
	sortOrder = function( a, b ) {
		if ( a === b ) {
			hasDuplicate = true;
		}
		return 0;
	},

	// General-purpose constants
	MAX_NEGATIVE = 1 << 31,

	// Instance methods
	hasOwn = ({}).hasOwnProperty,
	arr = [],
	pop = arr.pop,
	push_native = arr.push,
	push = arr.push,
	slice = arr.slice,
	// Use a stripped-down indexOf as it's faster than native
	// http://jsperf.com/thor-indexof-vs-for/5
	indexOf = function( list, elem ) {
		var i = 0,
			len = list.length;
		for ( ; i < len; i++ ) {
			if ( list[i] === elem ) {
				return i;
			}
		}
		return -1;
	},

	booleans = "checked|selected|async|autofocus|autoplay|controls|defer|disabled|hidden|ismap|loop|multiple|open|readonly|required|scoped",

	// Regular expressions

	// Whitespace characters http://www.w3.org/TR/css3-selectors/#whitespace
	whitespace = "[\\x20\\t\\r\\n\\f]",
	// http://www.w3.org/TR/css3-syntax/#characters
	characterEncoding = "(?:\\\\.|[\\w-]|[^\\x00-\\xa0])+",

	// Loosely modeled on CSS identifier characters
	// An unquoted value should be a CSS identifier http://www.w3.org/TR/css3-selectors/#attribute-selectors
	// Proper syntax: http://www.w3.org/TR/CSS21/syndata.html#value-def-identifier
	identifier = characterEncoding.replace( "w", "w#" ),

	// Attribute selectors: http://www.w3.org/TR/selectors/#attribute-selectors
	attributes = "\\[" + whitespace + "*(" + characterEncoding + ")(?:" + whitespace +
		// Operator (capture 2)
		"*([*^$|!~]?=)" + whitespace +
		// "Attribute values must be CSS identifiers [capture 5] or strings [capture 3 or capture 4]"
		"*(?:'((?:\\\\.|[^\\\\'])*)'|\"((?:\\\\.|[^\\\\\"])*)\"|(" + identifier + "))|)" + whitespace +
		"*\\]",

	pseudos = ":(" + characterEncoding + ")(?:\\((" +
		// To reduce the number of selectors needing tokenize in the preFilter, prefer arguments:
		// 1. quoted (capture 3; capture 4 or capture 5)
		"('((?:\\\\.|[^\\\\'])*)'|\"((?:\\\\.|[^\\\\\"])*)\")|" +
		// 2. simple (capture 6)
		"((?:\\\\.|[^\\\\()[\\]]|" + attributes + ")*)|" +
		// 3. anything else (capture 2)
		".*" +
		")\\)|)",

	// Leading and non-escaped trailing whitespace, capturing some non-whitespace characters preceding the latter
	rwhitespace = new RegExp( whitespace + "+", "g" ),
	rtrim = new RegExp( "^" + whitespace + "+|((?:^|[^\\\\])(?:\\\\.)*)" + whitespace + "+$", "g" ),

	rcomma = new RegExp( "^" + whitespace + "*," + whitespace + "*" ),
	rcombinators = new RegExp( "^" + whitespace + "*([>+~]|" + whitespace + ")" + whitespace + "*" ),

	rattributeQuotes = new RegExp( "=" + whitespace + "*([^\\]'\"]*?)" + whitespace + "*\\]", "g" ),

	rpseudo = new RegExp( pseudos ),
	ridentifier = new RegExp( "^" + identifier + "$" ),

	matchExpr = {
		"ID": new RegExp( "^#(" + characterEncoding + ")" ),
		"CLASS": new RegExp( "^\\.(" + characterEncoding + ")" ),
		"TAG": new RegExp( "^(" + characterEncoding.replace( "w", "w*" ) + ")" ),
		"ATTR": new RegExp( "^" + attributes ),
		"PSEUDO": new RegExp( "^" + pseudos ),
		"CHILD": new RegExp( "^:(only|first|last|nth|nth-last)-(child|of-type)(?:\\(" + whitespace +
			"*(even|odd|(([+-]|)(\\d*)n|)" + whitespace + "*(?:([+-]|)" + whitespace +
			"*(\\d+)|))" + whitespace + "*\\)|)", "i" ),
		"bool": new RegExp( "^(?:" + booleans + ")$", "i" ),
		// For use in libraries implementing .is()
		// We use this for POS matching in `select`
		"needsContext": new RegExp( "^" + whitespace + "*[>+~]|:(even|odd|eq|gt|lt|nth|first|last)(?:\\(" +
			whitespace + "*((?:-\\d)?\\d*)" + whitespace + "*\\)|)(?=[^-]|$)", "i" )
	},

	rinputs = /^(?:input|select|textarea|button)$/i,
	rheader = /^h\d$/i,

	rnative = /^[^{]+\{\s*\[native \w/,

	// Easily-parseable/retrievable ID or TAG or CLASS selectors
	rquickExpr = /^(?:#([\w-]+)|(\w+)|\.([\w-]+))$/,

	rsibling = /[+~]/,
	rescape = /'|\\/g,

	// CSS escapes http://www.w3.org/TR/CSS21/syndata.html#escaped-characters
	runescape = new RegExp( "\\\\([\\da-f]{1,6}" + whitespace + "?|(" + whitespace + ")|.)", "ig" ),
	funescape = function( _, escaped, escapedWhitespace ) {
		var high = "0x" + escaped - 0x10000;
		// NaN means non-codepoint
		// Support: Firefox<24
		// Workaround erroneous numeric interpretation of +"0x"
		return high !== high || escapedWhitespace ?
			escaped :
			high < 0 ?
				// BMP codepoint
				String.fromCharCode( high + 0x10000 ) :
				// Supplemental Plane codepoint (surrogate pair)
				String.fromCharCode( high >> 10 | 0xD800, high & 0x3FF | 0xDC00 );
	},

	// Used for iframes
	// See setDocument()
	// Removing the function wrapper causes a "Permission Denied"
	// error in IE
	unloadHandler = function() {
		setDocument();
	};

// Optimize for push.apply( _, NodeList )
try {
	push.apply(
		(arr = slice.call( preferredDoc.childNodes )),
		preferredDoc.childNodes
	);
	// Support: Android<4.0
	// Detect silently failing push.apply
	arr[ preferredDoc.childNodes.length ].nodeType;
} catch ( e ) {
	push = { apply: arr.length ?

		// Leverage slice if possible
		function( target, els ) {
			push_native.apply( target, slice.call(els) );
		} :

		// Support: IE<9
		// Otherwise append directly
		function( target, els ) {
			var j = target.length,
				i = 0;
			// Can't trust NodeList.length
			while ( (target[j++] = els[i++]) ) {}
			target.length = j - 1;
		}
	};
}

function Sizzle( selector, context, results, seed ) {
	var match, elem, m, nodeType,
		// QSA vars
		i, groups, old, nid, newContext, newSelector;

	if ( ( context ? context.ownerDocument || context : preferredDoc ) !== document ) {
		setDocument( context );
	}

	context = context || document;
	results = results || [];
	nodeType = context.nodeType;

	if ( typeof selector !== "string" || !selector ||
		nodeType !== 1 && nodeType !== 9 && nodeType !== 11 ) {

		return results;
	}

	if ( !seed && documentIsHTML ) {

		// Try to shortcut find operations when possible (e.g., not under DocumentFragment)
		if ( nodeType !== 11 && (match = rquickExpr.exec( selector )) ) {
			// Speed-up: Sizzle("#ID")
			if ( (m = match[1]) ) {
				if ( nodeType === 9 ) {
					elem = context.getElementById( m );
					// Check parentNode to catch when Blackberry 4.6 returns
					// nodes that are no longer in the document (jQuery #6963)
					if ( elem && elem.parentNode ) {
						// Handle the case where IE, Opera, and Webkit return items
						// by name instead of ID
						if ( elem.id === m ) {
							results.push( elem );
							return results;
						}
					} else {
						return results;
					}
				} else {
					// Context is not a document
					if ( context.ownerDocument && (elem = context.ownerDocument.getElementById( m )) &&
						contains( context, elem ) && elem.id === m ) {
						results.push( elem );
						return results;
					}
				}

			// Speed-up: Sizzle("TAG")
			} else if ( match[2] ) {
				push.apply( results, context.getElementsByTagName( selector ) );
				return results;

			// Speed-up: Sizzle(".CLASS")
			} else if ( (m = match[3]) && support.getElementsByClassName ) {
				push.apply( results, context.getElementsByClassName( m ) );
				return results;
			}
		}

		// QSA path
		if ( support.qsa && (!rbuggyQSA || !rbuggyQSA.test( selector )) ) {
			nid = old = expando;
			newContext = context;
			newSelector = nodeType !== 1 && selector;

			// qSA works strangely on Element-rooted queries
			// We can work around this by specifying an extra ID on the root
			// and working up from there (Thanks to Andrew Dupont for the technique)
			// IE 8 doesn't work on object elements
			if ( nodeType === 1 && context.nodeName.toLowerCase() !== "object" ) {
				groups = tokenize( selector );

				if ( (old = context.getAttribute("id")) ) {
					nid = old.replace( rescape, "\\$&" );
				} else {
					context.setAttribute( "id", nid );
				}
				nid = "[id='" + nid + "'] ";

				i = groups.length;
				while ( i-- ) {
					groups[i] = nid + toSelector( groups[i] );
				}
				newContext = rsibling.test( selector ) && testContext( context.parentNode ) || context;
				newSelector = groups.join(",");
			}

			if ( newSelector ) {
				try {
					push.apply( results,
						newContext.querySelectorAll( newSelector )
					);
					return results;
				} catch(qsaError) {
				} finally {
					if ( !old ) {
						context.removeAttribute("id");
					}
				}
			}
		}
	}

	// All others
	return select( selector.replace( rtrim, "$1" ), context, results, seed );
}

/**
 * Create key-value caches of limited size
 * @returns {Function(string, Object)} Returns the Object data after storing it on itself with
 *	property name the (space-suffixed) string and (if the cache is larger than Expr.cacheLength)
 *	deleting the oldest entry
 */
function createCache() {
	var keys = [];

	function cache( key, value ) {
		// Use (key + " ") to avoid collision with native prototype properties (see Issue #157)
		if ( keys.push( key + " " ) > Expr.cacheLength ) {
			// Only keep the most recent entries
			delete cache[ keys.shift() ];
		}
		return (cache[ key + " " ] = value);
	}
	return cache;
}

/**
 * Mark a function for special use by Sizzle
 * @param {Function} fn The function to mark
 */
function markFunction( fn ) {
	fn[ expando ] = true;
	return fn;
}

/**
 * Support testing using an element
 * @param {Function} fn Passed the created div and expects a boolean result
 */
function assert( fn ) {
	var div = document.createElement("div");

	try {
		return !!fn( div );
	} catch (e) {
		return false;
	} finally {
		// Remove from its parent by default
		if ( div.parentNode ) {
			div.parentNode.removeChild( div );
		}
		// release memory in IE
		div = null;
	}
}

/**
 * Adds the same handler for all of the specified attrs
 * @param {String} attrs Pipe-separated list of attributes
 * @param {Function} handler The method that will be applied
 */
function addHandle( attrs, handler ) {
	var arr = attrs.split("|"),
		i = attrs.length;

	while ( i-- ) {
		Expr.attrHandle[ arr[i] ] = handler;
	}
}

/**
 * Checks document order of two siblings
 * @param {Element} a
 * @param {Element} b
 * @returns {Number} Returns less than 0 if a precedes b, greater than 0 if a follows b
 */
function siblingCheck( a, b ) {
	var cur = b && a,
		diff = cur && a.nodeType === 1 && b.nodeType === 1 &&
			( ~b.sourceIndex || MAX_NEGATIVE ) -
			( ~a.sourceIndex || MAX_NEGATIVE );

	// Use IE sourceIndex if available on both nodes
	if ( diff ) {
		return diff;
	}

	// Check if b follows a
	if ( cur ) {
		while ( (cur = cur.nextSibling) ) {
			if ( cur === b ) {
				return -1;
			}
		}
	}

	return a ? 1 : -1;
}

/**
 * Returns a function to use in pseudos for input types
 * @param {String} type
 */
function createInputPseudo( type ) {
	return function( elem ) {
		var name = elem.nodeName.toLowerCase();
		return name === "input" && elem.type === type;
	};
}

/**
 * Returns a function to use in pseudos for buttons
 * @param {String} type
 */
function createButtonPseudo( type ) {
	return function( elem ) {
		var name = elem.nodeName.toLowerCase();
		return (name === "input" || name === "button") && elem.type === type;
	};
}

/**
 * Returns a function to use in pseudos for positionals
 * @param {Function} fn
 */
function createPositionalPseudo( fn ) {
	return markFunction(function( argument ) {
		argument = +argument;
		return markFunction(function( seed, matches ) {
			var j,
				matchIndexes = fn( [], seed.length, argument ),
				i = matchIndexes.length;

			// Match elements found at the specified indexes
			while ( i-- ) {
				if ( seed[ (j = matchIndexes[i]) ] ) {
					seed[j] = !(matches[j] = seed[j]);
				}
			}
		});
	});
}

/**
 * Checks a node for validity as a Sizzle context
 * @param {Element|Object=} context
 * @returns {Element|Object|Boolean} The input node if acceptable, otherwise a falsy value
 */
function testContext( context ) {
	return context && typeof context.getElementsByTagName !== "undefined" && context;
}

// Expose support vars for convenience
support = Sizzle.support = {};

/**
 * Detects XML nodes
 * @param {Element|Object} elem An element or a document
 * @returns {Boolean} True iff elem is a non-HTML XML node
 */
isXML = Sizzle.isXML = function( elem ) {
	// documentElement is verified for cases where it doesn't yet exist
	// (such as loading iframes in IE - #4833)
	var documentElement = elem && (elem.ownerDocument || elem).documentElement;
	return documentElement ? documentElement.nodeName !== "HTML" : false;
};

/**
 * Sets document-related variables once based on the current document
 * @param {Element|Object} [doc] An element or document object to use to set the document
 * @returns {Object} Returns the current document
 */
setDocument = Sizzle.setDocument = function( node ) {
	var hasCompare, parent,
		doc = node ? node.ownerDocument || node : preferredDoc;

	// If no document and documentElement is available, return
	if ( doc === document || doc.nodeType !== 9 || !doc.documentElement ) {
		return document;
	}

	// Set our document
	document = doc;
	docElem = doc.documentElement;
	parent = doc.defaultView;

	// Support: IE>8
	// If iframe document is assigned to "document" variable and if iframe has been reloaded,
	// IE will throw "permission denied" error when accessing "document" variable, see jQuery #13936
	// IE6-8 do not support the defaultView property so parent will be undefined
	if ( parent && parent !== parent.top ) {
		// IE11 does not have attachEvent, so all must suffer
		if ( parent.addEventListener ) {
			parent.addEventListener( "unload", unloadHandler, false );
		} else if ( parent.attachEvent ) {
			parent.attachEvent( "onunload", unloadHandler );
		}
	}

	/* Support tests
	---------------------------------------------------------------------- */
	documentIsHTML = !isXML( doc );

	/* Attributes
	---------------------------------------------------------------------- */

	// Support: IE<8
	// Verify that getAttribute really returns attributes and not properties
	// (excepting IE8 booleans)
	support.attributes = assert(function( div ) {
		div.className = "i";
		return !div.getAttribute("className");
	});

	/* getElement(s)By*
	---------------------------------------------------------------------- */

	// Check if getElementsByTagName("*") returns only elements
	support.getElementsByTagName = assert(function( div ) {
		div.appendChild( doc.createComment("") );
		return !div.getElementsByTagName("*").length;
	});

	// Support: IE<9
	support.getElementsByClassName = rnative.test( doc.getElementsByClassName );

	// Support: IE<10
	// Check if getElementById returns elements by name
	// The broken getElementById methods don't pick up programatically-set names,
	// so use a roundabout getElementsByName test
	support.getById = assert(function( div ) {
		docElem.appendChild( div ).id = expando;
		return !doc.getElementsByName || !doc.getElementsByName( expando ).length;
	});

	// ID find and filter
	if ( support.getById ) {
		Expr.find["ID"] = function( id, context ) {
			if ( typeof context.getElementById !== "undefined" && documentIsHTML ) {
				var m = context.getElementById( id );
				// Check parentNode to catch when Blackberry 4.6 returns
				// nodes that are no longer in the document #6963
				return m && m.parentNode ? [ m ] : [];
			}
		};
		Expr.filter["ID"] = function( id ) {
			var attrId = id.replace( runescape, funescape );
			return function( elem ) {
				return elem.getAttribute("id") === attrId;
			};
		};
	} else {
		// Support: IE6/7
		// getElementById is not reliable as a find shortcut
		delete Expr.find["ID"];

		Expr.filter["ID"] =  function( id ) {
			var attrId = id.replace( runescape, funescape );
			return function( elem ) {
				var node = typeof elem.getAttributeNode !== "undefined" && elem.getAttributeNode("id");
				return node && node.value === attrId;
			};
		};
	}

	// Tag
	Expr.find["TAG"] = support.getElementsByTagName ?
		function( tag, context ) {
			if ( typeof context.getElementsByTagName !== "undefined" ) {
				return context.getElementsByTagName( tag );

			// DocumentFragment nodes don't have gEBTN
			} else if ( support.qsa ) {
				return context.querySelectorAll( tag );
			}
		} :

		function( tag, context ) {
			var elem,
				tmp = [],
				i = 0,
				// By happy coincidence, a (broken) gEBTN appears on DocumentFragment nodes too
				results = context.getElementsByTagName( tag );

			// Filter out possible comments
			if ( tag === "*" ) {
				while ( (elem = results[i++]) ) {
					if ( elem.nodeType === 1 ) {
						tmp.push( elem );
					}
				}

				return tmp;
			}
			return results;
		};

	// Class
	Expr.find["CLASS"] = support.getElementsByClassName && function( className, context ) {
		if ( documentIsHTML ) {
			return context.getElementsByClassName( className );
		}
	};

	/* QSA/matchesSelector
	---------------------------------------------------------------------- */

	// QSA and matchesSelector support

	// matchesSelector(:active) reports false when true (IE9/Opera 11.5)
	rbuggyMatches = [];

	// qSa(:focus) reports false when true (Chrome 21)
	// We allow this because of a bug in IE8/9 that throws an error
	// whenever `document.activeElement` is accessed on an iframe
	// So, we allow :focus to pass through QSA all the time to avoid the IE error
	// See http://bugs.jquery.com/ticket/13378
	rbuggyQSA = [];

	if ( (support.qsa = rnative.test( doc.querySelectorAll )) ) {
		// Build QSA regex
		// Regex strategy adopted from Diego Perini
		assert(function( div ) {
			// Select is set to empty string on purpose
			// This is to test IE's treatment of not explicitly
			// setting a boolean content attribute,
			// since its presence should be enough
			// http://bugs.jquery.com/ticket/12359
			docElem.appendChild( div ).innerHTML = "<a id='" + expando + "'></a>" +
				"<select id='" + expando + "-\f]' msallowcapture=''>" +
				"<option selected=''></option></select>";

			// Support: IE8, Opera 11-12.16
			// Nothing should be selected when empty strings follow ^= or $= or *=
			// The test attribute must be unknown in Opera but "safe" for WinRT
			// http://msdn.microsoft.com/en-us/library/ie/hh465388.aspx#attribute_section
			if ( div.querySelectorAll("[msallowcapture^='']").length ) {
				rbuggyQSA.push( "[*^$]=" + whitespace + "*(?:''|\"\")" );
			}

			// Support: IE8
			// Boolean attributes and "value" are not treated correctly
			if ( !div.querySelectorAll("[selected]").length ) {
				rbuggyQSA.push( "\\[" + whitespace + "*(?:value|" + booleans + ")" );
			}

			// Support: Chrome<29, Android<4.2+, Safari<7.0+, iOS<7.0+, PhantomJS<1.9.7+
			if ( !div.querySelectorAll( "[id~=" + expando + "-]" ).length ) {
				rbuggyQSA.push("~=");
			}

			// Webkit/Opera - :checked should return selected option elements
			// http://www.w3.org/TR/2011/REC-css3-selectors-20110929/#checked
			// IE8 throws error here and will not see later tests
			if ( !div.querySelectorAll(":checked").length ) {
				rbuggyQSA.push(":checked");
			}

			// Support: Safari 8+, iOS 8+
			// https://bugs.webkit.org/show_bug.cgi?id=136851
			// In-page `selector#id sibing-combinator selector` fails
			if ( !div.querySelectorAll( "a#" + expando + "+*" ).length ) {
				rbuggyQSA.push(".#.+[+~]");
			}
		});

		assert(function( div ) {
			// Support: Windows 8 Native Apps
			// The type and name attributes are restricted during .innerHTML assignment
			var input = doc.createElement("input");
			input.setAttribute( "type", "hidden" );
			div.appendChild( input ).setAttribute( "name", "D" );

			// Support: IE8
			// Enforce case-sensitivity of name attribute
			if ( div.querySelectorAll("[name=d]").length ) {
				rbuggyQSA.push( "name" + whitespace + "*[*^$|!~]?=" );
			}

			// FF 3.5 - :enabled/:disabled and hidden elements (hidden elements are still enabled)
			// IE8 throws error here and will not see later tests
			if ( !div.querySelectorAll(":enabled").length ) {
				rbuggyQSA.push( ":enabled", ":disabled" );
			}

			// Opera 10-11 does not throw on post-comma invalid pseudos
			div.querySelectorAll("*,:x");
			rbuggyQSA.push(",.*:");
		});
	}

	if ( (support.matchesSelector = rnative.test( (matches = docElem.matches ||
		docElem.webkitMatchesSelector ||
		docElem.mozMatchesSelector ||
		docElem.oMatchesSelector ||
		docElem.msMatchesSelector) )) ) {

		assert(function( div ) {
			// Check to see if it's possible to do matchesSelector
			// on a disconnected node (IE 9)
			support.disconnectedMatch = matches.call( div, "div" );

			// This should fail with an exception
			// Gecko does not error, returns false instead
			matches.call( div, "[s!='']:x" );
			rbuggyMatches.push( "!=", pseudos );
		});
	}

	rbuggyQSA = rbuggyQSA.length && new RegExp( rbuggyQSA.join("|") );
	rbuggyMatches = rbuggyMatches.length && new RegExp( rbuggyMatches.join("|") );

	/* Contains
	---------------------------------------------------------------------- */
	hasCompare = rnative.test( docElem.compareDocumentPosition );

	// Element contains another
	// Purposefully does not implement inclusive descendent
	// As in, an element does not contain itself
	contains = hasCompare || rnative.test( docElem.contains ) ?
		function( a, b ) {
			var adown = a.nodeType === 9 ? a.documentElement : a,
				bup = b && b.parentNode;
			return a === bup || !!( bup && bup.nodeType === 1 && (
				adown.contains ?
					adown.contains( bup ) :
					a.compareDocumentPosition && a.compareDocumentPosition( bup ) & 16
			));
		} :
		function( a, b ) {
			if ( b ) {
				while ( (b = b.parentNode) ) {
					if ( b === a ) {
						return true;
					}
				}
			}
			return false;
		};

	/* Sorting
	---------------------------------------------------------------------- */

	// Document order sorting
	sortOrder = hasCompare ?
	function( a, b ) {

		// Flag for duplicate removal
		if ( a === b ) {
			hasDuplicate = true;
			return 0;
		}

		// Sort on method existence if only one input has compareDocumentPosition
		var compare = !a.compareDocumentPosition - !b.compareDocumentPosition;
		if ( compare ) {
			return compare;
		}

		// Calculate position if both inputs belong to the same document
		compare = ( a.ownerDocument || a ) === ( b.ownerDocument || b ) ?
			a.compareDocumentPosition( b ) :

			// Otherwise we know they are disconnected
			1;

		// Disconnected nodes
		if ( compare & 1 ||
			(!support.sortDetached && b.compareDocumentPosition( a ) === compare) ) {

			// Choose the first element that is related to our preferred document
			if ( a === doc || a.ownerDocument === preferredDoc && contains(preferredDoc, a) ) {
				return -1;
			}
			if ( b === doc || b.ownerDocument === preferredDoc && contains(preferredDoc, b) ) {
				return 1;
			}

			// Maintain original order
			return sortInput ?
				( indexOf( sortInput, a ) - indexOf( sortInput, b ) ) :
				0;
		}

		return compare & 4 ? -1 : 1;
	} :
	function( a, b ) {
		// Exit early if the nodes are identical
		if ( a === b ) {
			hasDuplicate = true;
			return 0;
		}

		var cur,
			i = 0,
			aup = a.parentNode,
			bup = b.parentNode,
			ap = [ a ],
			bp = [ b ];

		// Parentless nodes are either documents or disconnected
		if ( !aup || !bup ) {
			return a === doc ? -1 :
				b === doc ? 1 :
				aup ? -1 :
				bup ? 1 :
				sortInput ?
				( indexOf( sortInput, a ) - indexOf( sortInput, b ) ) :
				0;

		// If the nodes are siblings, we can do a quick check
		} else if ( aup === bup ) {
			return siblingCheck( a, b );
		}

		// Otherwise we need full lists of their ancestors for comparison
		cur = a;
		while ( (cur = cur.parentNode) ) {
			ap.unshift( cur );
		}
		cur = b;
		while ( (cur = cur.parentNode) ) {
			bp.unshift( cur );
		}

		// Walk down the tree looking for a discrepancy
		while ( ap[i] === bp[i] ) {
			i++;
		}

		return i ?
			// Do a sibling check if the nodes have a common ancestor
			siblingCheck( ap[i], bp[i] ) :

			// Otherwise nodes in our document sort first
			ap[i] === preferredDoc ? -1 :
			bp[i] === preferredDoc ? 1 :
			0;
	};

	return doc;
};

Sizzle.matches = function( expr, elements ) {
	return Sizzle( expr, null, null, elements );
};

Sizzle.matchesSelector = function( elem, expr ) {
	// Set document vars if needed
	if ( ( elem.ownerDocument || elem ) !== document ) {
		setDocument( elem );
	}

	// Make sure that attribute selectors are quoted
	expr = expr.replace( rattributeQuotes, "='$1']" );

	if ( support.matchesSelector && documentIsHTML &&
		( !rbuggyMatches || !rbuggyMatches.test( expr ) ) &&
		( !rbuggyQSA     || !rbuggyQSA.test( expr ) ) ) {

		try {
			var ret = matches.call( elem, expr );

			// IE 9's matchesSelector returns false on disconnected nodes
			if ( ret || support.disconnectedMatch ||
					// As well, disconnected nodes are said to be in a document
					// fragment in IE 9
					elem.document && elem.document.nodeType !== 11 ) {
				return ret;
			}
		} catch (e) {}
	}

	return Sizzle( expr, document, null, [ elem ] ).length > 0;
};

Sizzle.contains = function( context, elem ) {
	// Set document vars if needed
	if ( ( context.ownerDocument || context ) !== document ) {
		setDocument( context );
	}
	return contains( context, elem );
};

Sizzle.attr = function( elem, name ) {
	// Set document vars if needed
	if ( ( elem.ownerDocument || elem ) !== document ) {
		setDocument( elem );
	}

	var fn = Expr.attrHandle[ name.toLowerCase() ],
		// Don't get fooled by Object.prototype properties (jQuery #13807)
		val = fn && hasOwn.call( Expr.attrHandle, name.toLowerCase() ) ?
			fn( elem, name, !documentIsHTML ) :
			undefined;

	return val !== undefined ?
		val :
		support.attributes || !documentIsHTML ?
			elem.getAttribute( name ) :
			(val = elem.getAttributeNode(name)) && val.specified ?
				val.value :
				null;
};

Sizzle.error = function( msg ) {
	throw new Error( "Syntax error, unrecognized expression: " + msg );
};

/**
 * Document sorting and removing duplicates
 * @param {ArrayLike} results
 */
Sizzle.uniqueSort = function( results ) {
	var elem,
		duplicates = [],
		j = 0,
		i = 0;

	// Unless we *know* we can detect duplicates, assume their presence
	hasDuplicate = !support.detectDuplicates;
	sortInput = !support.sortStable && results.slice( 0 );
	results.sort( sortOrder );

	if ( hasDuplicate ) {
		while ( (elem = results[i++]) ) {
			if ( elem === results[ i ] ) {
				j = duplicates.push( i );
			}
		}
		while ( j-- ) {
			results.splice( duplicates[ j ], 1 );
		}
	}

	// Clear input after sorting to release objects
	// See https://github.com/jquery/sizzle/pull/225
	sortInput = null;

	return results;
};

/**
 * Utility function for retrieving the text value of an array of DOM nodes
 * @param {Array|Element} elem
 */
getText = Sizzle.getText = function( elem ) {
	var node,
		ret = "",
		i = 0,
		nodeType = elem.nodeType;

	if ( !nodeType ) {
		// If no nodeType, this is expected to be an array
		while ( (node = elem[i++]) ) {
			// Do not traverse comment nodes
			ret += getText( node );
		}
	} else if ( nodeType === 1 || nodeType === 9 || nodeType === 11 ) {
		// Use textContent for elements
		// innerText usage removed for consistency of new lines (jQuery #11153)
		if ( typeof elem.textContent === "string" ) {
			return elem.textContent;
		} else {
			// Traverse its children
			for ( elem = elem.firstChild; elem; elem = elem.nextSibling ) {
				ret += getText( elem );
			}
		}
	} else if ( nodeType === 3 || nodeType === 4 ) {
		return elem.nodeValue;
	}
	// Do not include comment or processing instruction nodes

	return ret;
};

Expr = Sizzle.selectors = {

	// Can be adjusted by the user
	cacheLength: 50,

	createPseudo: markFunction,

	match: matchExpr,

	attrHandle: {},

	find: {},

	relative: {
		">": { dir: "parentNode", first: true },
		" ": { dir: "parentNode" },
		"+": { dir: "previousSibling", first: true },
		"~": { dir: "previousSibling" }
	},

	preFilter: {
		"ATTR": function( match ) {
			match[1] = match[1].replace( runescape, funescape );

			// Move the given value to match[3] whether quoted or unquoted
			match[3] = ( match[3] || match[4] || match[5] || "" ).replace( runescape, funescape );

			if ( match[2] === "~=" ) {
				match[3] = " " + match[3] + " ";
			}

			return match.slice( 0, 4 );
		},

		"CHILD": function( match ) {
			/* matches from matchExpr["CHILD"]
				1 type (only|nth|...)
				2 what (child|of-type)
				3 argument (even|odd|\d*|\d*n([+-]\d+)?|...)
				4 xn-component of xn+y argument ([+-]?\d*n|)
				5 sign of xn-component
				6 x of xn-component
				7 sign of y-component
				8 y of y-component
			*/
			match[1] = match[1].toLowerCase();

			if ( match[1].slice( 0, 3 ) === "nth" ) {
				// nth-* requires argument
				if ( !match[3] ) {
					Sizzle.error( match[0] );
				}

				// numeric x and y parameters for Expr.filter.CHILD
				// remember that false/true cast respectively to 0/1
				match[4] = +( match[4] ? match[5] + (match[6] || 1) : 2 * ( match[3] === "even" || match[3] === "odd" ) );
				match[5] = +( ( match[7] + match[8] ) || match[3] === "odd" );

			// other types prohibit arguments
			} else if ( match[3] ) {
				Sizzle.error( match[0] );
			}

			return match;
		},

		"PSEUDO": function( match ) {
			var excess,
				unquoted = !match[6] && match[2];

			if ( matchExpr["CHILD"].test( match[0] ) ) {
				return null;
			}

			// Accept quoted arguments as-is
			if ( match[3] ) {
				match[2] = match[4] || match[5] || "";

			// Strip excess characters from unquoted arguments
			} else if ( unquoted && rpseudo.test( unquoted ) &&
				// Get excess from tokenize (recursively)
				(excess = tokenize( unquoted, true )) &&
				// advance to the next closing parenthesis
				(excess = unquoted.indexOf( ")", unquoted.length - excess ) - unquoted.length) ) {

				// excess is a negative index
				match[0] = match[0].slice( 0, excess );
				match[2] = unquoted.slice( 0, excess );
			}

			// Return only captures needed by the pseudo filter method (type and argument)
			return match.slice( 0, 3 );
		}
	},

	filter: {

		"TAG": function( nodeNameSelector ) {
			var nodeName = nodeNameSelector.replace( runescape, funescape ).toLowerCase();
			return nodeNameSelector === "*" ?
				function() { return true; } :
				function( elem ) {
					return elem.nodeName && elem.nodeName.toLowerCase() === nodeName;
				};
		},

		"CLASS": function( className ) {
			var pattern = classCache[ className + " " ];

			return pattern ||
				(pattern = new RegExp( "(^|" + whitespace + ")" + className + "(" + whitespace + "|$)" )) &&
				classCache( className, function( elem ) {
					return pattern.test( typeof elem.className === "string" && elem.className || typeof elem.getAttribute !== "undefined" && elem.getAttribute("class") || "" );
				});
		},

		"ATTR": function( name, operator, check ) {
			return function( elem ) {
				var result = Sizzle.attr( elem, name );

				if ( result == null ) {
					return operator === "!=";
				}
				if ( !operator ) {
					return true;
				}

				result += "";

				return operator === "=" ? result === check :
					operator === "!=" ? result !== check :
					operator === "^=" ? check && result.indexOf( check ) === 0 :
					operator === "*=" ? check && result.indexOf( check ) > -1 :
					operator === "$=" ? check && result.slice( -check.length ) === check :
					operator === "~=" ? ( " " + result.replace( rwhitespace, " " ) + " " ).indexOf( check ) > -1 :
					operator === "|=" ? result === check || result.slice( 0, check.length + 1 ) === check + "-" :
					false;
			};
		},

		"CHILD": function( type, what, argument, first, last ) {
			var simple = type.slice( 0, 3 ) !== "nth",
				forward = type.slice( -4 ) !== "last",
				ofType = what === "of-type";

			return first === 1 && last === 0 ?

				// Shortcut for :nth-*(n)
				function( elem ) {
					return !!elem.parentNode;
				} :

				function( elem, context, xml ) {
					var cache, outerCache, node, diff, nodeIndex, start,
						dir = simple !== forward ? "nextSibling" : "previousSibling",
						parent = elem.parentNode,
						name = ofType && elem.nodeName.toLowerCase(),
						useCache = !xml && !ofType;

					if ( parent ) {

						// :(first|last|only)-(child|of-type)
						if ( simple ) {
							while ( dir ) {
								node = elem;
								while ( (node = node[ dir ]) ) {
									if ( ofType ? node.nodeName.toLowerCase() === name : node.nodeType === 1 ) {
										return false;
									}
								}
								// Reverse direction for :only-* (if we haven't yet done so)
								start = dir = type === "only" && !start && "nextSibling";
							}
							return true;
						}

						start = [ forward ? parent.firstChild : parent.lastChild ];

						// non-xml :nth-child(...) stores cache data on `parent`
						if ( forward && useCache ) {
							// Seek `elem` from a previously-cached index
							outerCache = parent[ expando ] || (parent[ expando ] = {});
							cache = outerCache[ type ] || [];
							nodeIndex = cache[0] === dirruns && cache[1];
							diff = cache[0] === dirruns && cache[2];
							node = nodeIndex && parent.childNodes[ nodeIndex ];

							while ( (node = ++nodeIndex && node && node[ dir ] ||

								// Fallback to seeking `elem` from the start
								(diff = nodeIndex = 0) || start.pop()) ) {

								// When found, cache indexes on `parent` and break
								if ( node.nodeType === 1 && ++diff && node === elem ) {
									outerCache[ type ] = [ dirruns, nodeIndex, diff ];
									break;
								}
							}

						// Use previously-cached element index if available
						} else if ( useCache && (cache = (elem[ expando ] || (elem[ expando ] = {}))[ type ]) && cache[0] === dirruns ) {
							diff = cache[1];

						// xml :nth-child(...) or :nth-last-child(...) or :nth(-last)?-of-type(...)
						} else {
							// Use the same loop as above to seek `elem` from the start
							while ( (node = ++nodeIndex && node && node[ dir ] ||
								(diff = nodeIndex = 0) || start.pop()) ) {

								if ( ( ofType ? node.nodeName.toLowerCase() === name : node.nodeType === 1 ) && ++diff ) {
									// Cache the index of each encountered element
									if ( useCache ) {
										(node[ expando ] || (node[ expando ] = {}))[ type ] = [ dirruns, diff ];
									}

									if ( node === elem ) {
										break;
									}
								}
							}
						}

						// Incorporate the offset, then check against cycle size
						diff -= last;
						return diff === first || ( diff % first === 0 && diff / first >= 0 );
					}
				};
		},

		"PSEUDO": function( pseudo, argument ) {
			// pseudo-class names are case-insensitive
			// http://www.w3.org/TR/selectors/#pseudo-classes
			// Prioritize by case sensitivity in case custom pseudos are added with uppercase letters
			// Remember that setFilters inherits from pseudos
			var args,
				fn = Expr.pseudos[ pseudo ] || Expr.setFilters[ pseudo.toLowerCase() ] ||
					Sizzle.error( "unsupported pseudo: " + pseudo );

			// The user may use createPseudo to indicate that
			// arguments are needed to create the filter function
			// just as Sizzle does
			if ( fn[ expando ] ) {
				return fn( argument );
			}

			// But maintain support for old signatures
			if ( fn.length > 1 ) {
				args = [ pseudo, pseudo, "", argument ];
				return Expr.setFilters.hasOwnProperty( pseudo.toLowerCase() ) ?
					markFunction(function( seed, matches ) {
						var idx,
							matched = fn( seed, argument ),
							i = matched.length;
						while ( i-- ) {
							idx = indexOf( seed, matched[i] );
							seed[ idx ] = !( matches[ idx ] = matched[i] );
						}
					}) :
					function( elem ) {
						return fn( elem, 0, args );
					};
			}

			return fn;
		}
	},

	pseudos: {
		// Potentially complex pseudos
		"not": markFunction(function( selector ) {
			// Trim the selector passed to compile
			// to avoid treating leading and trailing
			// spaces as combinators
			var input = [],
				results = [],
				matcher = compile( selector.replace( rtrim, "$1" ) );

			return matcher[ expando ] ?
				markFunction(function( seed, matches, context, xml ) {
					var elem,
						unmatched = matcher( seed, null, xml, [] ),
						i = seed.length;

					// Match elements unmatched by `matcher`
					while ( i-- ) {
						if ( (elem = unmatched[i]) ) {
							seed[i] = !(matches[i] = elem);
						}
					}
				}) :
				function( elem, context, xml ) {
					input[0] = elem;
					matcher( input, null, xml, results );
					// Don't keep the element (issue #299)
					input[0] = null;
					return !results.pop();
				};
		}),

		"has": markFunction(function( selector ) {
			return function( elem ) {
				return Sizzle( selector, elem ).length > 0;
			};
		}),

		"contains": markFunction(function( text ) {
			text = text.replace( runescape, funescape );
			return function( elem ) {
				return ( elem.textContent || elem.innerText || getText( elem ) ).indexOf( text ) > -1;
			};
		}),

		// "Whether an element is represented by a :lang() selector
		// is based solely on the element's language value
		// being equal to the identifier C,
		// or beginning with the identifier C immediately followed by "-".
		// The matching of C against the element's language value is performed case-insensitively.
		// The identifier C does not have to be a valid language name."
		// http://www.w3.org/TR/selectors/#lang-pseudo
		"lang": markFunction( function( lang ) {
			// lang value must be a valid identifier
			if ( !ridentifier.test(lang || "") ) {
				Sizzle.error( "unsupported lang: " + lang );
			}
			lang = lang.replace( runescape, funescape ).toLowerCase();
			return function( elem ) {
				var elemLang;
				do {
					if ( (elemLang = documentIsHTML ?
						elem.lang :
						elem.getAttribute("xml:lang") || elem.getAttribute("lang")) ) {

						elemLang = elemLang.toLowerCase();
						return elemLang === lang || elemLang.indexOf( lang + "-" ) === 0;
					}
				} while ( (elem = elem.parentNode) && elem.nodeType === 1 );
				return false;
			};
		}),

		// Miscellaneous
		"target": function( elem ) {
			var hash = window.location && window.location.hash;
			return hash && hash.slice( 1 ) === elem.id;
		},

		"root": function( elem ) {
			return elem === docElem;
		},

		"focus": function( elem ) {
			return elem === document.activeElement && (!document.hasFocus || document.hasFocus()) && !!(elem.type || elem.href || ~elem.tabIndex);
		},

		// Boolean properties
		"enabled": function( elem ) {
			return elem.disabled === false;
		},

		"disabled": function( elem ) {
			return elem.disabled === true;
		},

		"checked": function( elem ) {
			// In CSS3, :checked should return both checked and selected elements
			// http://www.w3.org/TR/2011/REC-css3-selectors-20110929/#checked
			var nodeName = elem.nodeName.toLowerCase();
			return (nodeName === "input" && !!elem.checked) || (nodeName === "option" && !!elem.selected);
		},

		"selected": function( elem ) {
			// Accessing this property makes selected-by-default
			// options in Safari work properly
			if ( elem.parentNode ) {
				elem.parentNode.selectedIndex;
			}

			return elem.selected === true;
		},

		// Contents
		"empty": function( elem ) {
			// http://www.w3.org/TR/selectors/#empty-pseudo
			// :empty is negated by element (1) or content nodes (text: 3; cdata: 4; entity ref: 5),
			//   but not by others (comment: 8; processing instruction: 7; etc.)
			// nodeType < 6 works because attributes (2) do not appear as children
			for ( elem = elem.firstChild; elem; elem = elem.nextSibling ) {
				if ( elem.nodeType < 6 ) {
					return false;
				}
			}
			return true;
		},

		"parent": function( elem ) {
			return !Expr.pseudos["empty"]( elem );
		},

		// Element/input types
		"header": function( elem ) {
			return rheader.test( elem.nodeName );
		},

		"input": function( elem ) {
			return rinputs.test( elem.nodeName );
		},

		"button": function( elem ) {
			var name = elem.nodeName.toLowerCase();
			return name === "input" && elem.type === "button" || name === "button";
		},

		"text": function( elem ) {
			var attr;
			return elem.nodeName.toLowerCase() === "input" &&
				elem.type === "text" &&

				// Support: IE<8
				// New HTML5 attribute values (e.g., "search") appear with elem.type === "text"
				( (attr = elem.getAttribute("type")) == null || attr.toLowerCase() === "text" );
		},

		// Position-in-collection
		"first": createPositionalPseudo(function() {
			return [ 0 ];
		}),

		"last": createPositionalPseudo(function( matchIndexes, length ) {
			return [ length - 1 ];
		}),

		"eq": createPositionalPseudo(function( matchIndexes, length, argument ) {
			return [ argument < 0 ? argument + length : argument ];
		}),

		"even": createPositionalPseudo(function( matchIndexes, length ) {
			var i = 0;
			for ( ; i < length; i += 2 ) {
				matchIndexes.push( i );
			}
			return matchIndexes;
		}),

		"odd": createPositionalPseudo(function( matchIndexes, length ) {
			var i = 1;
			for ( ; i < length; i += 2 ) {
				matchIndexes.push( i );
			}
			return matchIndexes;
		}),

		"lt": createPositionalPseudo(function( matchIndexes, length, argument ) {
			var i = argument < 0 ? argument + length : argument;
			for ( ; --i >= 0; ) {
				matchIndexes.push( i );
			}
			return matchIndexes;
		}),

		"gt": createPositionalPseudo(function( matchIndexes, length, argument ) {
			var i = argument < 0 ? argument + length : argument;
			for ( ; ++i < length; ) {
				matchIndexes.push( i );
			}
			return matchIndexes;
		})
	}
};

Expr.pseudos["nth"] = Expr.pseudos["eq"];

// Add button/input type pseudos
for ( i in { radio: true, checkbox: true, file: true, password: true, image: true } ) {
	Expr.pseudos[ i ] = createInputPseudo( i );
}
for ( i in { submit: true, reset: true } ) {
	Expr.pseudos[ i ] = createButtonPseudo( i );
}

// Easy API for creating new setFilters
function setFilters() {}
setFilters.prototype = Expr.filters = Expr.pseudos;
Expr.setFilters = new setFilters();

tokenize = Sizzle.tokenize = function( selector, parseOnly ) {
	var matched, match, tokens, type,
		soFar, groups, preFilters,
		cached = tokenCache[ selector + " " ];

	if ( cached ) {
		return parseOnly ? 0 : cached.slice( 0 );
	}

	soFar = selector;
	groups = [];
	preFilters = Expr.preFilter;

	while ( soFar ) {

		// Comma and first run
		if ( !matched || (match = rcomma.exec( soFar )) ) {
			if ( match ) {
				// Don't consume trailing commas as valid
				soFar = soFar.slice( match[0].length ) || soFar;
			}
			groups.push( (tokens = []) );
		}

		matched = false;

		// Combinators
		if ( (match = rcombinators.exec( soFar )) ) {
			matched = match.shift();
			tokens.push({
				value: matched,
				// Cast descendant combinators to space
				type: match[0].replace( rtrim, " " )
			});
			soFar = soFar.slice( matched.length );
		}

		// Filters
		for ( type in Expr.filter ) {
			if ( (match = matchExpr[ type ].exec( soFar )) && (!preFilters[ type ] ||
				(match = preFilters[ type ]( match ))) ) {
				matched = match.shift();
				tokens.push({
					value: matched,
					type: type,
					matches: match
				});
				soFar = soFar.slice( matched.length );
			}
		}

		if ( !matched ) {
			break;
		}
	}

	// Return the length of the invalid excess
	// if we're just parsing
	// Otherwise, throw an error or return tokens
	return parseOnly ?
		soFar.length :
		soFar ?
			Sizzle.error( selector ) :
			// Cache the tokens
			tokenCache( selector, groups ).slice( 0 );
};

function toSelector( tokens ) {
	var i = 0,
		len = tokens.length,
		selector = "";
	for ( ; i < len; i++ ) {
		selector += tokens[i].value;
	}
	return selector;
}

function addCombinator( matcher, combinator, base ) {
	var dir = combinator.dir,
		checkNonElements = base && dir === "parentNode",
		doneName = done++;

	return combinator.first ?
		// Check against closest ancestor/preceding element
		function( elem, context, xml ) {
			while ( (elem = elem[ dir ]) ) {
				if ( elem.nodeType === 1 || checkNonElements ) {
					return matcher( elem, context, xml );
				}
			}
		} :

		// Check against all ancestor/preceding elements
		function( elem, context, xml ) {
			var oldCache, outerCache,
				newCache = [ dirruns, doneName ];

			// We can't set arbitrary data on XML nodes, so they don't benefit from dir caching
			if ( xml ) {
				while ( (elem = elem[ dir ]) ) {
					if ( elem.nodeType === 1 || checkNonElements ) {
						if ( matcher( elem, context, xml ) ) {
							return true;
						}
					}
				}
			} else {
				while ( (elem = elem[ dir ]) ) {
					if ( elem.nodeType === 1 || checkNonElements ) {
						outerCache = elem[ expando ] || (elem[ expando ] = {});
						if ( (oldCache = outerCache[ dir ]) &&
							oldCache[ 0 ] === dirruns && oldCache[ 1 ] === doneName ) {

							// Assign to newCache so results back-propagate to previous elements
							return (newCache[ 2 ] = oldCache[ 2 ]);
						} else {
							// Reuse newcache so results back-propagate to previous elements
							outerCache[ dir ] = newCache;

							// A match means we're done; a fail means we have to keep checking
							if ( (newCache[ 2 ] = matcher( elem, context, xml )) ) {
								return true;
							}
						}
					}
				}
			}
		};
}

function elementMatcher( matchers ) {
	return matchers.length > 1 ?
		function( elem, context, xml ) {
			var i = matchers.length;
			while ( i-- ) {
				if ( !matchers[i]( elem, context, xml ) ) {
					return false;
				}
			}
			return true;
		} :
		matchers[0];
}

function multipleContexts( selector, contexts, results ) {
	var i = 0,
		len = contexts.length;
	for ( ; i < len; i++ ) {
		Sizzle( selector, contexts[i], results );
	}
	return results;
}

function condense( unmatched, map, filter, context, xml ) {
	var elem,
		newUnmatched = [],
		i = 0,
		len = unmatched.length,
		mapped = map != null;

	for ( ; i < len; i++ ) {
		if ( (elem = unmatched[i]) ) {
			if ( !filter || filter( elem, context, xml ) ) {
				newUnmatched.push( elem );
				if ( mapped ) {
					map.push( i );
				}
			}
		}
	}

	return newUnmatched;
}

function setMatcher( preFilter, selector, matcher, postFilter, postFinder, postSelector ) {
	if ( postFilter && !postFilter[ expando ] ) {
		postFilter = setMatcher( postFilter );
	}
	if ( postFinder && !postFinder[ expando ] ) {
		postFinder = setMatcher( postFinder, postSelector );
	}
	return markFunction(function( seed, results, context, xml ) {
		var temp, i, elem,
			preMap = [],
			postMap = [],
			preexisting = results.length,

			// Get initial elements from seed or context
			elems = seed || multipleContexts( selector || "*", context.nodeType ? [ context ] : context, [] ),

			// Prefilter to get matcher input, preserving a map for seed-results synchronization
			matcherIn = preFilter && ( seed || !selector ) ?
				condense( elems, preMap, preFilter, context, xml ) :
				elems,

			matcherOut = matcher ?
				// If we have a postFinder, or filtered seed, or non-seed postFilter or preexisting results,
				postFinder || ( seed ? preFilter : preexisting || postFilter ) ?

					// ...intermediate processing is necessary
					[] :

					// ...otherwise use results directly
					results :
				matcherIn;

		// Find primary matches
		if ( matcher ) {
			matcher( matcherIn, matcherOut, context, xml );
		}

		// Apply postFilter
		if ( postFilter ) {
			temp = condense( matcherOut, postMap );
			postFilter( temp, [], context, xml );

			// Un-match failing elements by moving them back to matcherIn
			i = temp.length;
			while ( i-- ) {
				if ( (elem = temp[i]) ) {
					matcherOut[ postMap[i] ] = !(matcherIn[ postMap[i] ] = elem);
				}
			}
		}

		if ( seed ) {
			if ( postFinder || preFilter ) {
				if ( postFinder ) {
					// Get the final matcherOut by condensing this intermediate into postFinder contexts
					temp = [];
					i = matcherOut.length;
					while ( i-- ) {
						if ( (elem = matcherOut[i]) ) {
							// Restore matcherIn since elem is not yet a final match
							temp.push( (matcherIn[i] = elem) );
						}
					}
					postFinder( null, (matcherOut = []), temp, xml );
				}

				// Move matched elements from seed to results to keep them synchronized
				i = matcherOut.length;
				while ( i-- ) {
					if ( (elem = matcherOut[i]) &&
						(temp = postFinder ? indexOf( seed, elem ) : preMap[i]) > -1 ) {

						seed[temp] = !(results[temp] = elem);
					}
				}
			}

		// Add elements to results, through postFinder if defined
		} else {
			matcherOut = condense(
				matcherOut === results ?
					matcherOut.splice( preexisting, matcherOut.length ) :
					matcherOut
			);
			if ( postFinder ) {
				postFinder( null, results, matcherOut, xml );
			} else {
				push.apply( results, matcherOut );
			}
		}
	});
}

function matcherFromTokens( tokens ) {
	var checkContext, matcher, j,
		len = tokens.length,
		leadingRelative = Expr.relative[ tokens[0].type ],
		implicitRelative = leadingRelative || Expr.relative[" "],
		i = leadingRelative ? 1 : 0,

		// The foundational matcher ensures that elements are reachable from top-level context(s)
		matchContext = addCombinator( function( elem ) {
			return elem === checkContext;
		}, implicitRelative, true ),
		matchAnyContext = addCombinator( function( elem ) {
			return indexOf( checkContext, elem ) > -1;
		}, implicitRelative, true ),
		matchers = [ function( elem, context, xml ) {
			var ret = ( !leadingRelative && ( xml || context !== outermostContext ) ) || (
				(checkContext = context).nodeType ?
					matchContext( elem, context, xml ) :
					matchAnyContext( elem, context, xml ) );
			// Avoid hanging onto element (issue #299)
			checkContext = null;
			return ret;
		} ];

	for ( ; i < len; i++ ) {
		if ( (matcher = Expr.relative[ tokens[i].type ]) ) {
			matchers = [ addCombinator(elementMatcher( matchers ), matcher) ];
		} else {
			matcher = Expr.filter[ tokens[i].type ].apply( null, tokens[i].matches );

			// Return special upon seeing a positional matcher
			if ( matcher[ expando ] ) {
				// Find the next relative operator (if any) for proper handling
				j = ++i;
				for ( ; j < len; j++ ) {
					if ( Expr.relative[ tokens[j].type ] ) {
						break;
					}
				}
				return setMatcher(
					i > 1 && elementMatcher( matchers ),
					i > 1 && toSelector(
						// If the preceding token was a descendant combinator, insert an implicit any-element `*`
						tokens.slice( 0, i - 1 ).concat({ value: tokens[ i - 2 ].type === " " ? "*" : "" })
					).replace( rtrim, "$1" ),
					matcher,
					i < j && matcherFromTokens( tokens.slice( i, j ) ),
					j < len && matcherFromTokens( (tokens = tokens.slice( j )) ),
					j < len && toSelector( tokens )
				);
			}
			matchers.push( matcher );
		}
	}

	return elementMatcher( matchers );
}

function matcherFromGroupMatchers( elementMatchers, setMatchers ) {
	var bySet = setMatchers.length > 0,
		byElement = elementMatchers.length > 0,
		superMatcher = function( seed, context, xml, results, outermost ) {
			var elem, j, matcher,
				matchedCount = 0,
				i = "0",
				unmatched = seed && [],
				setMatched = [],
				contextBackup = outermostContext,
				// We must always have either seed elements or outermost context
				elems = seed || byElement && Expr.find["TAG"]( "*", outermost ),
				// Use integer dirruns iff this is the outermost matcher
				dirrunsUnique = (dirruns += contextBackup == null ? 1 : Math.random() || 0.1),
				len = elems.length;

			if ( outermost ) {
				outermostContext = context !== document && context;
			}

			// Add elements passing elementMatchers directly to results
			// Keep `i` a string if there are no elements so `matchedCount` will be "00" below
			// Support: IE<9, Safari
			// Tolerate NodeList properties (IE: "length"; Safari: <number>) matching elements by id
			for ( ; i !== len && (elem = elems[i]) != null; i++ ) {
				if ( byElement && elem ) {
					j = 0;
					while ( (matcher = elementMatchers[j++]) ) {
						if ( matcher( elem, context, xml ) ) {
							results.push( elem );
							break;
						}
					}
					if ( outermost ) {
						dirruns = dirrunsUnique;
					}
				}

				// Track unmatched elements for set filters
				if ( bySet ) {
					// They will have gone through all possible matchers
					if ( (elem = !matcher && elem) ) {
						matchedCount--;
					}

					// Lengthen the array for every element, matched or not
					if ( seed ) {
						unmatched.push( elem );
					}
				}
			}

			// Apply set filters to unmatched elements
			matchedCount += i;
			if ( bySet && i !== matchedCount ) {
				j = 0;
				while ( (matcher = setMatchers[j++]) ) {
					matcher( unmatched, setMatched, context, xml );
				}

				if ( seed ) {
					// Reintegrate element matches to eliminate the need for sorting
					if ( matchedCount > 0 ) {
						while ( i-- ) {
							if ( !(unmatched[i] || setMatched[i]) ) {
								setMatched[i] = pop.call( results );
							}
						}
					}

					// Discard index placeholder values to get only actual matches
					setMatched = condense( setMatched );
				}

				// Add matches to results
				push.apply( results, setMatched );

				// Seedless set matches succeeding multiple successful matchers stipulate sorting
				if ( outermost && !seed && setMatched.length > 0 &&
					( matchedCount + setMatchers.length ) > 1 ) {

					Sizzle.uniqueSort( results );
				}
			}

			// Override manipulation of globals by nested matchers
			if ( outermost ) {
				dirruns = dirrunsUnique;
				outermostContext = contextBackup;
			}

			return unmatched;
		};

	return bySet ?
		markFunction( superMatcher ) :
		superMatcher;
}

compile = Sizzle.compile = function( selector, match /* Internal Use Only */ ) {
	var i,
		setMatchers = [],
		elementMatchers = [],
		cached = compilerCache[ selector + " " ];

	if ( !cached ) {
		// Generate a function of recursive functions that can be used to check each element
		if ( !match ) {
			match = tokenize( selector );
		}
		i = match.length;
		while ( i-- ) {
			cached = matcherFromTokens( match[i] );
			if ( cached[ expando ] ) {
				setMatchers.push( cached );
			} else {
				elementMatchers.push( cached );
			}
		}

		// Cache the compiled function
		cached = compilerCache( selector, matcherFromGroupMatchers( elementMatchers, setMatchers ) );

		// Save selector and tokenization
		cached.selector = selector;
	}
	return cached;
};

/**
 * A low-level selection function that works with Sizzle's compiled
 *  selector functions
 * @param {String|Function} selector A selector or a pre-compiled
 *  selector function built with Sizzle.compile
 * @param {Element} context
 * @param {Array} [results]
 * @param {Array} [seed] A set of elements to match against
 */
select = Sizzle.select = function( selector, context, results, seed ) {
	var i, tokens, token, type, find,
		compiled = typeof selector === "function" && selector,
		match = !seed && tokenize( (selector = compiled.selector || selector) );

	results = results || [];

	// Try to minimize operations if there is no seed and only one group
	if ( match.length === 1 ) {

		// Take a shortcut and set the context if the root selector is an ID
		tokens = match[0] = match[0].slice( 0 );
		if ( tokens.length > 2 && (token = tokens[0]).type === "ID" &&
				support.getById && context.nodeType === 9 && documentIsHTML &&
				Expr.relative[ tokens[1].type ] ) {

			context = ( Expr.find["ID"]( token.matches[0].replace(runescape, funescape), context ) || [] )[0];
			if ( !context ) {
				return results;

			// Precompiled matchers will still verify ancestry, so step up a level
			} else if ( compiled ) {
				context = context.parentNode;
			}

			selector = selector.slice( tokens.shift().value.length );
		}

		// Fetch a seed set for right-to-left matching
		i = matchExpr["needsContext"].test( selector ) ? 0 : tokens.length;
		while ( i-- ) {
			token = tokens[i];

			// Abort if we hit a combinator
			if ( Expr.relative[ (type = token.type) ] ) {
				break;
			}
			if ( (find = Expr.find[ type ]) ) {
				// Search, expanding context for leading sibling combinators
				if ( (seed = find(
					token.matches[0].replace( runescape, funescape ),
					rsibling.test( tokens[0].type ) && testContext( context.parentNode ) || context
				)) ) {

					// If seed is empty or no tokens remain, we can return early
					tokens.splice( i, 1 );
					selector = seed.length && toSelector( tokens );
					if ( !selector ) {
						push.apply( results, seed );
						return results;
					}

					break;
				}
			}
		}
	}

	// Compile and execute a filtering function if one is not provided
	// Provide `match` to avoid retokenization if we modified the selector above
	( compiled || compile( selector, match ) )(
		seed,
		context,
		!documentIsHTML,
		results,
		rsibling.test( selector ) && testContext( context.parentNode ) || context
	);
	return results;
};

// One-time assignments

// Sort stability
support.sortStable = expando.split("").sort( sortOrder ).join("") === expando;

// Support: Chrome 14-35+
// Always assume duplicates if they aren't passed to the comparison function
support.detectDuplicates = !!hasDuplicate;

// Initialize against the default document
setDocument();

// Support: Webkit<537.32 - Safari 6.0.3/Chrome 25 (fixed in Chrome 27)
// Detached nodes confoundingly follow *each other*
support.sortDetached = assert(function( div1 ) {
	// Should return 1, but returns 4 (following)
	return div1.compareDocumentPosition( document.createElement("div") ) & 1;
});

// Support: IE<8
// Prevent attribute/property "interpolation"
// http://msdn.microsoft.com/en-us/library/ms536429%28VS.85%29.aspx
if ( !assert(function( div ) {
	div.innerHTML = "<a href='#'></a>";
	return div.firstChild.getAttribute("href") === "#" ;
}) ) {
	addHandle( "type|href|height|width", function( elem, name, isXML ) {
		if ( !isXML ) {
			return elem.getAttribute( name, name.toLowerCase() === "type" ? 1 : 2 );
		}
	});
}

// Support: IE<9
// Use defaultValue in place of getAttribute("value")
if ( !support.attributes || !assert(function( div ) {
	div.innerHTML = "<input/>";
	div.firstChild.setAttribute( "value", "" );
	return div.firstChild.getAttribute( "value" ) === "";
}) ) {
	addHandle( "value", function( elem, name, isXML ) {
		if ( !isXML && elem.nodeName.toLowerCase() === "input" ) {
			return elem.defaultValue;
		}
	});
}

// Support: IE<9
// Use getAttributeNode to fetch booleans when getAttribute lies
if ( !assert(function( div ) {
	return div.getAttribute("disabled") == null;
}) ) {
	addHandle( booleans, function( elem, name, isXML ) {
		var val;
		if ( !isXML ) {
			return elem[ name ] === true ? name.toLowerCase() :
					(val = elem.getAttributeNode( name )) && val.specified ?
					val.value :
				null;
		}
	});
}

return Sizzle;

})( window );



jQuery.find = Sizzle;
jQuery.expr = Sizzle.selectors;
jQuery.expr[":"] = jQuery.expr.pseudos;
jQuery.unique = Sizzle.uniqueSort;
jQuery.text = Sizzle.getText;
jQuery.isXMLDoc = Sizzle.isXML;
jQuery.contains = Sizzle.contains;



var rneedsContext = jQuery.expr.match.needsContext;

var rsingleTag = (/^<(\w+)\s*\/?>(?:<\/\1>|)$/);



var risSimple = /^.[^:#\[\.,]*$/;

// Implement the identical functionality for filter and not
function winnow( elements, qualifier, not ) {
	if ( jQuery.isFunction( qualifier ) ) {
		return jQuery.grep( elements, function( elem, i ) {
			/* jshint -W018 */
			return !!qualifier.call( elem, i, elem ) !== not;
		});

	}

	if ( qualifier.nodeType ) {
		return jQuery.grep( elements, function( elem ) {
			return ( elem === qualifier ) !== not;
		});

	}

	if ( typeof qualifier === "string" ) {
		if ( risSimple.test( qualifier ) ) {
			return jQuery.filter( qualifier, elements, not );
		}

		qualifier = jQuery.filter( qualifier, elements );
	}

	return jQuery.grep( elements, function( elem ) {
		return ( indexOf.call( qualifier, elem ) >= 0 ) !== not;
	});
}

jQuery.filter = function( expr, elems, not ) {
	var elem = elems[ 0 ];

	if ( not ) {
		expr = ":not(" + expr + ")";
	}

	return elems.length === 1 && elem.nodeType === 1 ?
		jQuery.find.matchesSelector( elem, expr ) ? [ elem ] : [] :
		jQuery.find.matches( expr, jQuery.grep( elems, function( elem ) {
			return elem.nodeType === 1;
		}));
};

jQuery.fn.extend({
	find: function( selector ) {
		var i,
			len = this.length,
			ret = [],
			self = this;

		if ( typeof selector !== "string" ) {
			return this.pushStack( jQuery( selector ).filter(function() {
				for ( i = 0; i < len; i++ ) {
					if ( jQuery.contains( self[ i ], this ) ) {
						return true;
					}
				}
			}) );
		}

		for ( i = 0; i < len; i++ ) {
			jQuery.find( selector, self[ i ], ret );
		}

		// Needed because $( selector, context ) becomes $( context ).find( selector )
		ret = this.pushStack( len > 1 ? jQuery.unique( ret ) : ret );
		ret.selector = this.selector ? this.selector + " " + selector : selector;
		return ret;
	},
	filter: function( selector ) {
		return this.pushStack( winnow(this, selector || [], false) );
	},
	not: function( selector ) {
		return this.pushStack( winnow(this, selector || [], true) );
	},
	is: function( selector ) {
		return !!winnow(
			this,

			// If this is a positional/relative selector, check membership in the returned set
			// so $("p:first").is("p:last") won't return true for a doc with two "p".
			typeof selector === "string" && rneedsContext.test( selector ) ?
				jQuery( selector ) :
				selector || [],
			false
		).length;
	}
});


// Initialize a jQuery object


// A central reference to the root jQuery(document)
var rootjQuery,

	// A simple way to check for HTML strings
	// Prioritize #id over <tag> to avoid XSS via location.hash (#9521)
	// Strict HTML recognition (#11290: must start with <)
	rquickExpr = /^(?:\s*(<[\w\W]+>)[^>]*|#([\w-]*))$/,

	init = jQuery.fn.init = function( selector, context ) {
		var match, elem;

		// HANDLE: $(""), $(null), $(undefined), $(false)
		if ( !selector ) {
			return this;
		}

		// Handle HTML strings
		if ( typeof selector === "string" ) {
			if ( selector[0] === "<" && selector[ selector.length - 1 ] === ">" && selector.length >= 3 ) {
				// Assume that strings that start and end with <> are HTML and skip the regex check
				match = [ null, selector, null ];

			} else {
				match = rquickExpr.exec( selector );
			}

			// Match html or make sure no context is specified for #id
			if ( match && (match[1] || !context) ) {

				// HANDLE: $(html) -> $(array)
				if ( match[1] ) {
					context = context instanceof jQuery ? context[0] : context;

					// Option to run scripts is true for back-compat
					// Intentionally let the error be thrown if parseHTML is not present
					jQuery.merge( this, jQuery.parseHTML(
						match[1],
						context && context.nodeType ? context.ownerDocument || context : document,
						true
					) );

					// HANDLE: $(html, props)
					if ( rsingleTag.test( match[1] ) && jQuery.isPlainObject( context ) ) {
						for ( match in context ) {
							// Properties of context are called as methods if possible
							if ( jQuery.isFunction( this[ match ] ) ) {
								this[ match ]( context[ match ] );

							// ...and otherwise set as attributes
							} else {
								this.attr( match, context[ match ] );
							}
						}
					}

					return this;

				// HANDLE: $(#id)
				} else {
					elem = document.getElementById( match[2] );

					// Support: Blackberry 4.6
					// gEBID returns nodes no longer in the document (#6963)
					if ( elem && elem.parentNode ) {
						// Inject the element directly into the jQuery object
						this.length = 1;
						this[0] = elem;
					}

					this.context = document;
					this.selector = selector;
					return this;
				}

			// HANDLE: $(expr, $(...))
			} else if ( !context || context.jquery ) {
				return ( context || rootjQuery ).find( selector );

			// HANDLE: $(expr, context)
			// (which is just equivalent to: $(context).find(expr)
			} else {
				return this.constructor( context ).find( selector );
			}

		// HANDLE: $(DOMElement)
		} else if ( selector.nodeType ) {
			this.context = this[0] = selector;
			this.length = 1;
			return this;

		// HANDLE: $(function)
		// Shortcut for document ready
		} else if ( jQuery.isFunction( selector ) ) {
			return typeof rootjQuery.ready !== "undefined" ?
				rootjQuery.ready( selector ) :
				// Execute immediately if ready is not present
				selector( jQuery );
		}

		if ( selector.selector !== undefined ) {
			this.selector = selector.selector;
			this.context = selector.context;
		}

		return jQuery.makeArray( selector, this );
	};

// Give the init function the jQuery prototype for later instantiation
init.prototype = jQuery.fn;

// Initialize central reference
rootjQuery = jQuery( document );


var rparentsprev = /^(?:parents|prev(?:Until|All))/,
	// Methods guaranteed to produce a unique set when starting from a unique set
	guaranteedUnique = {
		children: true,
		contents: true,
		next: true,
		prev: true
	};

jQuery.extend({
	dir: function( elem, dir, until ) {
		var matched = [],
			truncate = until !== undefined;

		while ( (elem = elem[ dir ]) && elem.nodeType !== 9 ) {
			if ( elem.nodeType === 1 ) {
				if ( truncate && jQuery( elem ).is( until ) ) {
					break;
				}
				matched.push( elem );
			}
		}
		return matched;
	},

	sibling: function( n, elem ) {
		var matched = [];

		for ( ; n; n = n.nextSibling ) {
			if ( n.nodeType === 1 && n !== elem ) {
				matched.push( n );
			}
		}

		return matched;
	}
});

jQuery.fn.extend({
	has: function( target ) {
		var targets = jQuery( target, this ),
			l = targets.length;

		return this.filter(function() {
			var i = 0;
			for ( ; i < l; i++ ) {
				if ( jQuery.contains( this, targets[i] ) ) {
					return true;
				}
			}
		});
	},

	closest: function( selectors, context ) {
		var cur,
			i = 0,
			l = this.length,
			matched = [],
			pos = rneedsContext.test( selectors ) || typeof selectors !== "string" ?
				jQuery( selectors, context || this.context ) :
				0;

		for ( ; i < l; i++ ) {
			for ( cur = this[i]; cur && cur !== context; cur = cur.parentNode ) {
				// Always skip document fragments
				if ( cur.nodeType < 11 && (pos ?
					pos.index(cur) > -1 :

					// Don't pass non-elements to Sizzle
					cur.nodeType === 1 &&
						jQuery.find.matchesSelector(cur, selectors)) ) {

					matched.push( cur );
					break;
				}
			}
		}

		return this.pushStack( matched.length > 1 ? jQuery.unique( matched ) : matched );
	},

	// Determine the position of an element within the set
	index: function( elem ) {

		// No argument, return index in parent
		if ( !elem ) {
			return ( this[ 0 ] && this[ 0 ].parentNode ) ? this.first().prevAll().length : -1;
		}

		// Index in selector
		if ( typeof elem === "string" ) {
			return indexOf.call( jQuery( elem ), this[ 0 ] );
		}

		// Locate the position of the desired element
		return indexOf.call( this,

			// If it receives a jQuery object, the first element is used
			elem.jquery ? elem[ 0 ] : elem
		);
	},

	add: function( selector, context ) {
		return this.pushStack(
			jQuery.unique(
				jQuery.merge( this.get(), jQuery( selector, context ) )
			)
		);
	},

	addBack: function( selector ) {
		return this.add( selector == null ?
			this.prevObject : this.prevObject.filter(selector)
		);
	}
});

function sibling( cur, dir ) {
	while ( (cur = cur[dir]) && cur.nodeType !== 1 ) {}
	return cur;
}

jQuery.each({
	parent: function( elem ) {
		var parent = elem.parentNode;
		return parent && parent.nodeType !== 11 ? parent : null;
	},
	parents: function( elem ) {
		return jQuery.dir( elem, "parentNode" );
	},
	parentsUntil: function( elem, i, until ) {
		return jQuery.dir( elem, "parentNode", until );
	},
	next: function( elem ) {
		return sibling( elem, "nextSibling" );
	},
	prev: function( elem ) {
		return sibling( elem, "previousSibling" );
	},
	nextAll: function( elem ) {
		return jQuery.dir( elem, "nextSibling" );
	},
	prevAll: function( elem ) {
		return jQuery.dir( elem, "previousSibling" );
	},
	nextUntil: function( elem, i, until ) {
		return jQuery.dir( elem, "nextSibling", until );
	},
	prevUntil: function( elem, i, until ) {
		return jQuery.dir( elem, "previousSibling", until );
	},
	siblings: function( elem ) {
		return jQuery.sibling( ( elem.parentNode || {} ).firstChild, elem );
	},
	children: function( elem ) {
		return jQuery.sibling( elem.firstChild );
	},
	contents: function( elem ) {
		return elem.contentDocument || jQuery.merge( [], elem.childNodes );
	}
}, function( name, fn ) {
	jQuery.fn[ name ] = function( until, selector ) {
		var matched = jQuery.map( this, fn, until );

		if ( name.slice( -5 ) !== "Until" ) {
			selector = until;
		}

		if ( selector && typeof selector === "string" ) {
			matched = jQuery.filter( selector, matched );
		}

		if ( this.length > 1 ) {
			// Remove duplicates
			if ( !guaranteedUnique[ name ] ) {
				jQuery.unique( matched );
			}

			// Reverse order for parents* and prev-derivatives
			if ( rparentsprev.test( name ) ) {
				matched.reverse();
			}
		}

		return this.pushStack( matched );
	};
});
var rnotwhite = (/\S+/g);



// String to Object options format cache
var optionsCache = {};

// Convert String-formatted options into Object-formatted ones and store in cache
function createOptions( options ) {
	var object = optionsCache[ options ] = {};
	jQuery.each( options.match( rnotwhite ) || [], function( _, flag ) {
		object[ flag ] = true;
	});
	return object;
}

/*
 * Create a callback list using the following parameters:
 *
 *	options: an optional list of space-separated options that will change how
 *			the callback list behaves or a more traditional option object
 *
 * By default a callback list will act like an event callback list and can be
 * "fired" multiple times.
 *
 * Possible options:
 *
 *	once:			will ensure the callback list can only be fired once (like a Deferred)
 *
 *	memory:			will keep track of previous values and will call any callback added
 *					after the list has been fired right away with the latest "memorized"
 *					values (like a Deferred)
 *
 *	unique:			will ensure a callback can only be added once (no duplicate in the list)
 *
 *	stopOnFalse:	interrupt callings when a callback returns false
 *
 */
jQuery.Callbacks = function( options ) {

	// Convert options from String-formatted to Object-formatted if needed
	// (we check in cache first)
	options = typeof options === "string" ?
		( optionsCache[ options ] || createOptions( options ) ) :
		jQuery.extend( {}, options );

	var // Last fire value (for non-forgettable lists)
		memory,
		// Flag to know if list was already fired
		fired,
		// Flag to know if list is currently firing
		firing,
		// First callback to fire (used internally by add and fireWith)
		firingStart,
		// End of the loop when firing
		firingLength,
		// Index of currently firing callback (modified by remove if needed)
		firingIndex,
		// Actual callback list
		list = [],
		// Stack of fire calls for repeatable lists
		stack = !options.once && [],
		// Fire callbacks
		fire = function( data ) {
			memory = options.memory && data;
			fired = true;
			firingIndex = firingStart || 0;
			firingStart = 0;
			firingLength = list.length;
			firing = true;
			for ( ; list && firingIndex < firingLength; firingIndex++ ) {
				if ( list[ firingIndex ].apply( data[ 0 ], data[ 1 ] ) === false && options.stopOnFalse ) {
					memory = false; // To prevent further calls using add
					break;
				}
			}
			firing = false;
			if ( list ) {
				if ( stack ) {
					if ( stack.length ) {
						fire( stack.shift() );
					}
				} else if ( memory ) {
					list = [];
				} else {
					self.disable();
				}
			}
		},
		// Actual Callbacks object
		self = {
			// Add a callback or a collection of callbacks to the list
			add: function() {
				if ( list ) {
					// First, we save the current length
					var start = list.length;
					(function add( args ) {
						jQuery.each( args, function( _, arg ) {
							var type = jQuery.type( arg );
							if ( type === "function" ) {
								if ( !options.unique || !self.has( arg ) ) {
									list.push( arg );
								}
							} else if ( arg && arg.length && type !== "string" ) {
								// Inspect recursively
								add( arg );
							}
						});
					})( arguments );
					// Do we need to add the callbacks to the
					// current firing batch?
					if ( firing ) {
						firingLength = list.length;
					// With memory, if we're not firing then
					// we should call right away
					} else if ( memory ) {
						firingStart = start;
						fire( memory );
					}
				}
				return this;
			},
			// Remove a callback from the list
			remove: function() {
				if ( list ) {
					jQuery.each( arguments, function( _, arg ) {
						var index;
						while ( ( index = jQuery.inArray( arg, list, index ) ) > -1 ) {
							list.splice( index, 1 );
							// Handle firing indexes
							if ( firing ) {
								if ( index <= firingLength ) {
									firingLength--;
								}
								if ( index <= firingIndex ) {
									firingIndex--;
								}
							}
						}
					});
				}
				return this;
			},
			// Check if a given callback is in the list.
			// If no argument is given, return whether or not list has callbacks attached.
			has: function( fn ) {
				return fn ? jQuery.inArray( fn, list ) > -1 : !!( list && list.length );
			},
			// Remove all callbacks from the list
			empty: function() {
				list = [];
				firingLength = 0;
				return this;
			},
			// Have the list do nothing anymore
			disable: function() {
				list = stack = memory = undefined;
				return this;
			},
			// Is it disabled?
			disabled: function() {
				return !list;
			},
			// Lock the list in its current state
			lock: function() {
				stack = undefined;
				if ( !memory ) {
					self.disable();
				}
				return this;
			},
			// Is it locked?
			locked: function() {
				return !stack;
			},
			// Call all callbacks with the given context and arguments
			fireWith: function( context, args ) {
				if ( list && ( !fired || stack ) ) {
					args = args || [];
					args = [ context, args.slice ? args.slice() : args ];
					if ( firing ) {
						stack.push( args );
					} else {
						fire( args );
					}
				}
				return this;
			},
			// Call all the callbacks with the given arguments
			fire: function() {
				self.fireWith( this, arguments );
				return this;
			},
			// To know if the callbacks have already been called at least once
			fired: function() {
				return !!fired;
			}
		};

	return self;
};


jQuery.extend({

	Deferred: function( func ) {
		var tuples = [
				// action, add listener, listener list, final state
				[ "resolve", "done", jQuery.Callbacks("once memory"), "resolved" ],
				[ "reject", "fail", jQuery.Callbacks("once memory"), "rejected" ],
				[ "notify", "progress", jQuery.Callbacks("memory") ]
			],
			state = "pending",
			promise = {
				state: function() {
					return state;
				},
				always: function() {
					deferred.done( arguments ).fail( arguments );
					return this;
				},
				then: function( /* fnDone, fnFail, fnProgress */ ) {
					var fns = arguments;
					return jQuery.Deferred(function( newDefer ) {
						jQuery.each( tuples, function( i, tuple ) {
							var fn = jQuery.isFunction( fns[ i ] ) && fns[ i ];
							// deferred[ done | fail | progress ] for forwarding actions to newDefer
							deferred[ tuple[1] ](function() {
								var returned = fn && fn.apply( this, arguments );
								if ( returned && jQuery.isFunction( returned.promise ) ) {
									returned.promise()
										.done( newDefer.resolve )
										.fail( newDefer.reject )
										.progress( newDefer.notify );
								} else {
									newDefer[ tuple[ 0 ] + "With" ]( this === promise ? newDefer.promise() : this, fn ? [ returned ] : arguments );
								}
							});
						});
						fns = null;
					}).promise();
				},
				// Get a promise for this deferred
				// If obj is provided, the promise aspect is added to the object
				promise: function( obj ) {
					return obj != null ? jQuery.extend( obj, promise ) : promise;
				}
			},
			deferred = {};

		// Keep pipe for back-compat
		promise.pipe = promise.then;

		// Add list-specific methods
		jQuery.each( tuples, function( i, tuple ) {
			var list = tuple[ 2 ],
				stateString = tuple[ 3 ];

			// promise[ done | fail | progress ] = list.add
			promise[ tuple[1] ] = list.add;

			// Handle state
			if ( stateString ) {
				list.add(function() {
					// state = [ resolved | rejected ]
					state = stateString;

				// [ reject_list | resolve_list ].disable; progress_list.lock
				}, tuples[ i ^ 1 ][ 2 ].disable, tuples[ 2 ][ 2 ].lock );
			}

			// deferred[ resolve | reject | notify ]
			deferred[ tuple[0] ] = function() {
				deferred[ tuple[0] + "With" ]( this === deferred ? promise : this, arguments );
				return this;
			};
			deferred[ tuple[0] + "With" ] = list.fireWith;
		});

		// Make the deferred a promise
		promise.promise( deferred );

		// Call given func if any
		if ( func ) {
			func.call( deferred, deferred );
		}

		// All done!
		return deferred;
	},

	// Deferred helper
	when: function( subordinate /* , ..., subordinateN */ ) {
		var i = 0,
			resolveValues = slice.call( arguments ),
			length = resolveValues.length,

			// the count of uncompleted subordinates
			remaining = length !== 1 || ( subordinate && jQuery.isFunction( subordinate.promise ) ) ? length : 0,

			// the master Deferred. If resolveValues consist of only a single Deferred, just use that.
			deferred = remaining === 1 ? subordinate : jQuery.Deferred(),

			// Update function for both resolve and progress values
			updateFunc = function( i, contexts, values ) {
				return function( value ) {
					contexts[ i ] = this;
					values[ i ] = arguments.length > 1 ? slice.call( arguments ) : value;
					if ( values === progressValues ) {
						deferred.notifyWith( contexts, values );
					} else if ( !( --remaining ) ) {
						deferred.resolveWith( contexts, values );
					}
				};
			},

			progressValues, progressContexts, resolveContexts;

		// Add listeners to Deferred subordinates; treat others as resolved
		if ( length > 1 ) {
			progressValues = new Array( length );
			progressContexts = new Array( length );
			resolveContexts = new Array( length );
			for ( ; i < length; i++ ) {
				if ( resolveValues[ i ] && jQuery.isFunction( resolveValues[ i ].promise ) ) {
					resolveValues[ i ].promise()
						.done( updateFunc( i, resolveContexts, resolveValues ) )
						.fail( deferred.reject )
						.progress( updateFunc( i, progressContexts, progressValues ) );
				} else {
					--remaining;
				}
			}
		}

		// If we're not waiting on anything, resolve the master
		if ( !remaining ) {
			deferred.resolveWith( resolveContexts, resolveValues );
		}

		return deferred.promise();
	}
});


// The deferred used on DOM ready
var readyList;

jQuery.fn.ready = function( fn ) {
	// Add the callback
	jQuery.ready.promise().done( fn );

	return this;
};

jQuery.extend({
	// Is the DOM ready to be used? Set to true once it occurs.
	isReady: false,

	// A counter to track how many items to wait for before
	// the ready event fires. See #6781
	readyWait: 1,

	// Hold (or release) the ready event
	holdReady: function( hold ) {
		if ( hold ) {
			jQuery.readyWait++;
		} else {
			jQuery.ready( true );
		}
	},

	// Handle when the DOM is ready
	ready: function( wait ) {

		// Abort if there are pending holds or we're already ready
		if ( wait === true ? --jQuery.readyWait : jQuery.isReady ) {
			return;
		}

		// Remember that the DOM is ready
		jQuery.isReady = true;

		// If a normal DOM Ready event fired, decrement, and wait if need be
		if ( wait !== true && --jQuery.readyWait > 0 ) {
			return;
		}

		// If there are functions bound, to execute
		readyList.resolveWith( document, [ jQuery ] );

		// Trigger any bound ready events
		if ( jQuery.fn.triggerHandler ) {
			jQuery( document ).triggerHandler( "ready" );
			jQuery( document ).off( "ready" );
		}
	}
});

/**
 * The ready event handler and self cleanup method
 */
function completed() {
	document.removeEventListener( "DOMContentLoaded", completed, false );
	window.removeEventListener( "load", completed, false );
	jQuery.ready();
}

jQuery.ready.promise = function( obj ) {
	if ( !readyList ) {

		readyList = jQuery.Deferred();

		// Catch cases where $(document).ready() is called after the browser event has already occurred.
		// We once tried to use readyState "interactive" here, but it caused issues like the one
		// discovered by ChrisS here: http://bugs.jquery.com/ticket/12282#comment:15
		if ( document.readyState === "complete" ) {
			// Handle it asynchronously to allow scripts the opportunity to delay ready
			setTimeout( jQuery.ready );

		} else {

			// Use the handy event callback
			document.addEventListener( "DOMContentLoaded", completed, false );

			// A fallback to window.onload, that will always work
			window.addEventListener( "load", completed, false );
		}
	}
	return readyList.promise( obj );
};

// Kick off the DOM ready check even if the user does not
jQuery.ready.promise();




// Multifunctional method to get and set values of a collection
// The value/s can optionally be executed if it's a function
var access = jQuery.access = function( elems, fn, key, value, chainable, emptyGet, raw ) {
	var i = 0,
		len = elems.length,
		bulk = key == null;

	// Sets many values
	if ( jQuery.type( key ) === "object" ) {
		chainable = true;
		for ( i in key ) {
			jQuery.access( elems, fn, i, key[i], true, emptyGet, raw );
		}

	// Sets one value
	} else if ( value !== undefined ) {
		chainable = true;

		if ( !jQuery.isFunction( value ) ) {
			raw = true;
		}

		if ( bulk ) {
			// Bulk operations run against the entire set
			if ( raw ) {
				fn.call( elems, value );
				fn = null;

			// ...except when executing function values
			} else {
				bulk = fn;
				fn = function( elem, key, value ) {
					return bulk.call( jQuery( elem ), value );
				};
			}
		}

		if ( fn ) {
			for ( ; i < len; i++ ) {
				fn( elems[i], key, raw ? value : value.call( elems[i], i, fn( elems[i], key ) ) );
			}
		}
	}

	return chainable ?
		elems :

		// Gets
		bulk ?
			fn.call( elems ) :
			len ? fn( elems[0], key ) : emptyGet;
};


/**
 * Determines whether an object can have data
 */
jQuery.acceptData = function( owner ) {
	// Accepts only:
	//  - Node
	//    - Node.ELEMENT_NODE
	//    - Node.DOCUMENT_NODE
	//  - Object
	//    - Any
	/* jshint -W018 */
	return owner.nodeType === 1 || owner.nodeType === 9 || !( +owner.nodeType );
};


function Data() {
	// Support: Android<4,
	// Old WebKit does not have Object.preventExtensions/freeze method,
	// return new empty object instead with no [[set]] accessor
	Object.defineProperty( this.cache = {}, 0, {
		get: function() {
			return {};
		}
	});

	this.expando = jQuery.expando + Data.uid++;
}

Data.uid = 1;
Data.accepts = jQuery.acceptData;

Data.prototype = {
	key: function( owner ) {
		// We can accept data for non-element nodes in modern browsers,
		// but we should not, see #8335.
		// Always return the key for a frozen object.
		if ( !Data.accepts( owner ) ) {
			return 0;
		}

		var descriptor = {},
			// Check if the owner object already has a cache key
			unlock = owner[ this.expando ];

		// If not, create one
		if ( !unlock ) {
			unlock = Data.uid++;

			// Secure it in a non-enumerable, non-writable property
			try {
				descriptor[ this.expando ] = { value: unlock };
				Object.defineProperties( owner, descriptor );

			// Support: Android<4
			// Fallback to a less secure definition
			} catch ( e ) {
				descriptor[ this.expando ] = unlock;
				jQuery.extend( owner, descriptor );
			}
		}

		// Ensure the cache object
		if ( !this.cache[ unlock ] ) {
			this.cache[ unlock ] = {};
		}

		return unlock;
	},
	set: function( owner, data, value ) {
		var prop,
			// There may be an unlock assigned to this node,
			// if there is no entry for this "owner", create one inline
			// and set the unlock as though an owner entry had always existed
			unlock = this.key( owner ),
			cache = this.cache[ unlock ];

		// Handle: [ owner, key, value ] args
		if ( typeof data === "string" ) {
			cache[ data ] = value;

		// Handle: [ owner, { properties } ] args
		} else {
			// Fresh assignments by object are shallow copied
			if ( jQuery.isEmptyObject( cache ) ) {
				jQuery.extend( this.cache[ unlock ], data );
			// Otherwise, copy the properties one-by-one to the cache object
			} else {
				for ( prop in data ) {
					cache[ prop ] = data[ prop ];
				}
			}
		}
		return cache;
	},
	get: function( owner, key ) {
		// Either a valid cache is found, or will be created.
		// New caches will be created and the unlock returned,
		// allowing direct access to the newly created
		// empty data object. A valid owner object must be provided.
		var cache = this.cache[ this.key( owner ) ];

		return key === undefined ?
			cache : cache[ key ];
	},
	access: function( owner, key, value ) {
		var stored;
		// In cases where either:
		//
		//   1. No key was specified
		//   2. A string key was specified, but no value provided
		//
		// Take the "read" path and allow the get method to determine
		// which value to return, respectively either:
		//
		//   1. The entire cache object
		//   2. The data stored at the key
		//
		if ( key === undefined ||
				((key && typeof key === "string") && value === undefined) ) {

			stored = this.get( owner, key );

			return stored !== undefined ?
				stored : this.get( owner, jQuery.camelCase(key) );
		}

		// [*]When the key is not a string, or both a key and value
		// are specified, set or extend (existing objects) with either:
		//
		//   1. An object of properties
		//   2. A key and value
		//
		this.set( owner, key, value );

		// Since the "set" path can have two possible entry points
		// return the expected data based on which path was taken[*]
		return value !== undefined ? value : key;
	},
	remove: function( owner, key ) {
		var i, name, camel,
			unlock = this.key( owner ),
			cache = this.cache[ unlock ];

		if ( key === undefined ) {
			this.cache[ unlock ] = {};

		} else {
			// Support array or space separated string of keys
			if ( jQuery.isArray( key ) ) {
				// If "name" is an array of keys...
				// When data is initially created, via ("key", "val") signature,
				// keys will be converted to camelCase.
				// Since there is no way to tell _how_ a key was added, remove
				// both plain key and camelCase key. #12786
				// This will only penalize the array argument path.
				name = key.concat( key.map( jQuery.camelCase ) );
			} else {
				camel = jQuery.camelCase( key );
				// Try the string as a key before any manipulation
				if ( key in cache ) {
					name = [ key, camel ];
				} else {
					// If a key with the spaces exists, use it.
					// Otherwise, create an array by matching non-whitespace
					name = camel;
					name = name in cache ?
						[ name ] : ( name.match( rnotwhite ) || [] );
				}
			}

			i = name.length;
			while ( i-- ) {
				delete cache[ name[ i ] ];
			}
		}
	},
	hasData: function( owner ) {
		return !jQuery.isEmptyObject(
			this.cache[ owner[ this.expando ] ] || {}
		);
	},
	discard: function( owner ) {
		if ( owner[ this.expando ] ) {
			delete this.cache[ owner[ this.expando ] ];
		}
	}
};
var data_priv = new Data();

var data_user = new Data();



//	Implementation Summary
//
//	1. Enforce API surface and semantic compatibility with 1.9.x branch
//	2. Improve the module's maintainability by reducing the storage
//		paths to a single mechanism.
//	3. Use the same single mechanism to support "private" and "user" data.
//	4. _Never_ expose "private" data to user code (TODO: Drop _data, _removeData)
//	5. Avoid exposing implementation details on user objects (eg. expando properties)
//	6. Provide a clear path for implementation upgrade to WeakMap in 2014

var rbrace = /^(?:\{[\w\W]*\}|\[[\w\W]*\])$/,
	rmultiDash = /([A-Z])/g;

function dataAttr( elem, key, data ) {
	var name;

	// If nothing was found internally, try to fetch any
	// data from the HTML5 data-* attribute
	if ( data === undefined && elem.nodeType === 1 ) {
		name = "data-" + key.replace( rmultiDash, "-$1" ).toLowerCase();
		data = elem.getAttribute( name );

		if ( typeof data === "string" ) {
			try {
				data = data === "true" ? true :
					data === "false" ? false :
					data === "null" ? null :
					// Only convert to a number if it doesn't change the string
					+data + "" === data ? +data :
					rbrace.test( data ) ? jQuery.parseJSON( data ) :
					data;
			} catch( e ) {}

			// Make sure we set the data so it isn't changed later
			data_user.set( elem, key, data );
		} else {
			data = undefined;
		}
	}
	return data;
}

jQuery.extend({
	hasData: function( elem ) {
		return data_user.hasData( elem ) || data_priv.hasData( elem );
	},

	data: function( elem, name, data ) {
		return data_user.access( elem, name, data );
	},

	removeData: function( elem, name ) {
		data_user.remove( elem, name );
	},

	// TODO: Now that all calls to _data and _removeData have been replaced
	// with direct calls to data_priv methods, these can be deprecated.
	_data: function( elem, name, data ) {
		return data_priv.access( elem, name, data );
	},

	_removeData: function( elem, name ) {
		data_priv.remove( elem, name );
	}
});

jQuery.fn.extend({
	data: function( key, value ) {
		var i, name, data,
			elem = this[ 0 ],
			attrs = elem && elem.attributes;

		// Gets all values
		if ( key === undefined ) {
			if ( this.length ) {
				data = data_user.get( elem );

				if ( elem.nodeType === 1 && !data_priv.get( elem, "hasDataAttrs" ) ) {
					i = attrs.length;
					while ( i-- ) {

						// Support: IE11+
						// The attrs elements can be null (#14894)
						if ( attrs[ i ] ) {
							name = attrs[ i ].name;
							if ( name.indexOf( "data-" ) === 0 ) {
								name = jQuery.camelCase( name.slice(5) );
								dataAttr( elem, name, data[ name ] );
							}
						}
					}
					data_priv.set( elem, "hasDataAttrs", true );
				}
			}

			return data;
		}

		// Sets multiple values
		if ( typeof key === "object" ) {
			return this.each(function() {
				data_user.set( this, key );
			});
		}

		return access( this, function( value ) {
			var data,
				camelKey = jQuery.camelCase( key );

			// The calling jQuery object (element matches) is not empty
			// (and therefore has an element appears at this[ 0 ]) and the
			// `value` parameter was not undefined. An empty jQuery object
			// will result in `undefined` for elem = this[ 0 ] which will
			// throw an exception if an attempt to read a data cache is made.
			if ( elem && value === undefined ) {
				// Attempt to get data from the cache
				// with the key as-is
				data = data_user.get( elem, key );
				if ( data !== undefined ) {
					return data;
				}

				// Attempt to get data from the cache
				// with the key camelized
				data = data_user.get( elem, camelKey );
				if ( data !== undefined ) {
					return data;
				}

				// Attempt to "discover" the data in
				// HTML5 custom data-* attrs
				data = dataAttr( elem, camelKey, undefined );
				if ( data !== undefined ) {
					return data;
				}

				// We tried really hard, but the data doesn't exist.
				return;
			}

			// Set the data...
			this.each(function() {
				// First, attempt to store a copy or reference of any
				// data that might've been store with a camelCased key.
				var data = data_user.get( this, camelKey );

				// For HTML5 data-* attribute interop, we have to
				// store property names with dashes in a camelCase form.
				// This might not apply to all properties...*
				data_user.set( this, camelKey, value );

				// *... In the case of properties that might _actually_
				// have dashes, we need to also store a copy of that
				// unchanged property.
				if ( key.indexOf("-") !== -1 && data !== undefined ) {
					data_user.set( this, key, value );
				}
			});
		}, null, value, arguments.length > 1, null, true );
	},

	removeData: function( key ) {
		return this.each(function() {
			data_user.remove( this, key );
		});
	}
});


jQuery.extend({
	queue: function( elem, type, data ) {
		var queue;

		if ( elem ) {
			type = ( type || "fx" ) + "queue";
			queue = data_priv.get( elem, type );

			// Speed up dequeue by getting out quickly if this is just a lookup
			if ( data ) {
				if ( !queue || jQuery.isArray( data ) ) {
					queue = data_priv.access( elem, type, jQuery.makeArray(data) );
				} else {
					queue.push( data );
				}
			}
			return queue || [];
		}
	},

	dequeue: function( elem, type ) {
		type = type || "fx";

		var queue = jQuery.queue( elem, type ),
			startLength = queue.length,
			fn = queue.shift(),
			hooks = jQuery._queueHooks( elem, type ),
			next = function() {
				jQuery.dequeue( elem, type );
			};

		// If the fx queue is dequeued, always remove the progress sentinel
		if ( fn === "inprogress" ) {
			fn = queue.shift();
			startLength--;
		}

		if ( fn ) {

			// Add a progress sentinel to prevent the fx queue from being
			// automatically dequeued
			if ( type === "fx" ) {
				queue.unshift( "inprogress" );
			}

			// Clear up the last queue stop function
			delete hooks.stop;
			fn.call( elem, next, hooks );
		}

		if ( !startLength && hooks ) {
			hooks.empty.fire();
		}
	},

	// Not public - generate a queueHooks object, or return the current one
	_queueHooks: function( elem, type ) {
		var key = type + "queueHooks";
		return data_priv.get( elem, key ) || data_priv.access( elem, key, {
			empty: jQuery.Callbacks("once memory").add(function() {
				data_priv.remove( elem, [ type + "queue", key ] );
			})
		});
	}
});

jQuery.fn.extend({
	queue: function( type, data ) {
		var setter = 2;

		if ( typeof type !== "string" ) {
			data = type;
			type = "fx";
			setter--;
		}

		if ( arguments.length < setter ) {
			return jQuery.queue( this[0], type );
		}

		return data === undefined ?
			this :
			this.each(function() {
				var queue = jQuery.queue( this, type, data );

				// Ensure a hooks for this queue
				jQuery._queueHooks( this, type );

				if ( type === "fx" && queue[0] !== "inprogress" ) {
					jQuery.dequeue( this, type );
				}
			});
	},
	dequeue: function( type ) {
		return this.each(function() {
			jQuery.dequeue( this, type );
		});
	},
	clearQueue: function( type ) {
		return this.queue( type || "fx", [] );
	},
	// Get a promise resolved when queues of a certain type
	// are emptied (fx is the type by default)
	promise: function( type, obj ) {
		var tmp,
			count = 1,
			defer = jQuery.Deferred(),
			elements = this,
			i = this.length,
			resolve = function() {
				if ( !( --count ) ) {
					defer.resolveWith( elements, [ elements ] );
				}
			};

		if ( typeof type !== "string" ) {
			obj = type;
			type = undefined;
		}
		type = type || "fx";

		while ( i-- ) {
			tmp = data_priv.get( elements[ i ], type + "queueHooks" );
			if ( tmp && tmp.empty ) {
				count++;
				tmp.empty.add( resolve );
			}
		}
		resolve();
		return defer.promise( obj );
	}
});
var pnum = (/[+-]?(?:\d*\.|)\d+(?:[eE][+-]?\d+|)/).source;

var cssExpand = [ "Top", "Right", "Bottom", "Left" ];

var isHidden = function( elem, el ) {
		// isHidden might be called from jQuery#filter function;
		// in that case, element will be second argument
		elem = el || elem;
		return jQuery.css( elem, "display" ) === "none" || !jQuery.contains( elem.ownerDocument, elem );
	};

var rcheckableType = (/^(?:checkbox|radio)$/i);



(function() {
	var fragment = document.createDocumentFragment(),
		div = fragment.appendChild( document.createElement( "div" ) ),
		input = document.createElement( "input" );

	// Support: Safari<=5.1
	// Check state lost if the name is set (#11217)
	// Support: Windows Web Apps (WWA)
	// `name` and `type` must use .setAttribute for WWA (#14901)
	input.setAttribute( "type", "radio" );
	input.setAttribute( "checked", "checked" );
	input.setAttribute( "name", "t" );

	div.appendChild( input );

	// Support: Safari<=5.1, Android<4.2
	// Older WebKit doesn't clone checked state correctly in fragments
	support.checkClone = div.cloneNode( true ).cloneNode( true ).lastChild.checked;

	// Support: IE<=11+
	// Make sure textarea (and checkbox) defaultValue is properly cloned
	div.innerHTML = "<textarea>x</textarea>";
	support.noCloneChecked = !!div.cloneNode( true ).lastChild.defaultValue;
})();
var strundefined = typeof undefined;



support.focusinBubbles = "onfocusin" in window;


var
	rkeyEvent = /^key/,
	rmouseEvent = /^(?:mouse|pointer|contextmenu)|click/,
	rfocusMorph = /^(?:focusinfocus|focusoutblur)$/,
	rtypenamespace = /^([^.]*)(?:\.(.+)|)$/;

function returnTrue() {
	return true;
}

function returnFalse() {
	return false;
}

function safeActiveElement() {
	try {
		return document.activeElement;
	} catch ( err ) { }
}

/*
 * Helper functions for managing events -- not part of the public interface.
 * Props to Dean Edwards' addEvent library for many of the ideas.
 */
jQuery.event = {

	global: {},

	add: function( elem, types, handler, data, selector ) {

		var handleObjIn, eventHandle, tmp,
			events, t, handleObj,
			special, handlers, type, namespaces, origType,
			elemData = data_priv.get( elem );

		// Don't attach events to noData or text/comment nodes (but allow plain objects)
		if ( !elemData ) {
			return;
		}

		// Caller can pass in an object of custom data in lieu of the handler
		if ( handler.handler ) {
			handleObjIn = handler;
			handler = handleObjIn.handler;
			selector = handleObjIn.selector;
		}

		// Make sure that the handler has a unique ID, used to find/remove it later
		if ( !handler.guid ) {
			handler.guid = jQuery.guid++;
		}

		// Init the element's event structure and main handler, if this is the first
		if ( !(events = elemData.events) ) {
			events = elemData.events = {};
		}
		if ( !(eventHandle = elemData.handle) ) {
			eventHandle = elemData.handle = function( e ) {
				// Discard the second event of a jQuery.event.trigger() and
				// when an event is called after a page has unloaded
				return typeof jQuery !== strundefined && jQuery.event.triggered !== e.type ?
					jQuery.event.dispatch.apply( elem, arguments ) : undefined;
			};
		}

		// Handle multiple events separated by a space
		types = ( types || "" ).match( rnotwhite ) || [ "" ];
		t = types.length;
		while ( t-- ) {
			tmp = rtypenamespace.exec( types[t] ) || [];
			type = origType = tmp[1];
			namespaces = ( tmp[2] || "" ).split( "." ).sort();

			// There *must* be a type, no attaching namespace-only handlers
			if ( !type ) {
				continue;
			}

			// If event changes its type, use the special event handlers for the changed type
			special = jQuery.event.special[ type ] || {};

			// If selector defined, determine special event api type, otherwise given type
			type = ( selector ? special.delegateType : special.bindType ) || type;

			// Update special based on newly reset type
			special = jQuery.event.special[ type ] || {};

			// handleObj is passed to all event handlers
			handleObj = jQuery.extend({
				type: type,
				origType: origType,
				data: data,
				handler: handler,
				guid: handler.guid,
				selector: selector,
				needsContext: selector && jQuery.expr.match.needsContext.test( selector ),
				namespace: namespaces.join(".")
			}, handleObjIn );

			// Init the event handler queue if we're the first
			if ( !(handlers = events[ type ]) ) {
				handlers = events[ type ] = [];
				handlers.delegateCount = 0;

				// Only use addEventListener if the special events handler returns false
				if ( !special.setup || special.setup.call( elem, data, namespaces, eventHandle ) === false ) {
					if ( elem.addEventListener ) {
						elem.addEventListener( type, eventHandle, false );
					}
				}
			}

			if ( special.add ) {
				special.add.call( elem, handleObj );

				if ( !handleObj.handler.guid ) {
					handleObj.handler.guid = handler.guid;
				}
			}

			// Add to the element's handler list, delegates in front
			if ( selector ) {
				handlers.splice( handlers.delegateCount++, 0, handleObj );
			} else {
				handlers.push( handleObj );
			}

			// Keep track of which events have ever been used, for event optimization
			jQuery.event.global[ type ] = true;
		}

	},

	// Detach an event or set of events from an element
	remove: function( elem, types, handler, selector, mappedTypes ) {

		var j, origCount, tmp,
			events, t, handleObj,
			special, handlers, type, namespaces, origType,
			elemData = data_priv.hasData( elem ) && data_priv.get( elem );

		if ( !elemData || !(events = elemData.events) ) {
			return;
		}

		// Once for each type.namespace in types; type may be omitted
		types = ( types || "" ).match( rnotwhite ) || [ "" ];
		t = types.length;
		while ( t-- ) {
			tmp = rtypenamespace.exec( types[t] ) || [];
			type = origType = tmp[1];
			namespaces = ( tmp[2] || "" ).split( "." ).sort();

			// Unbind all events (on this namespace, if provided) for the element
			if ( !type ) {
				for ( type in events ) {
					jQuery.event.remove( elem, type + types[ t ], handler, selector, true );
				}
				continue;
			}

			special = jQuery.event.special[ type ] || {};
			type = ( selector ? special.delegateType : special.bindType ) || type;
			handlers = events[ type ] || [];
			tmp = tmp[2] && new RegExp( "(^|\\.)" + namespaces.join("\\.(?:.*\\.|)") + "(\\.|$)" );

			// Remove matching events
			origCount = j = handlers.length;
			while ( j-- ) {
				handleObj = handlers[ j ];

				if ( ( mappedTypes || origType === handleObj.origType ) &&
					( !handler || handler.guid === handleObj.guid ) &&
					( !tmp || tmp.test( handleObj.namespace ) ) &&
					( !selector || selector === handleObj.selector || selector === "**" && handleObj.selector ) ) {
					handlers.splice( j, 1 );

					if ( handleObj.selector ) {
						handlers.delegateCount--;
					}
					if ( special.remove ) {
						special.remove.call( elem, handleObj );
					}
				}
			}

			// Remove generic event handler if we removed something and no more handlers exist
			// (avoids potential for endless recursion during removal of special event handlers)
			if ( origCount && !handlers.length ) {
				if ( !special.teardown || special.teardown.call( elem, namespaces, elemData.handle ) === false ) {
					jQuery.removeEvent( elem, type, elemData.handle );
				}

				delete events[ type ];
			}
		}

		// Remove the expando if it's no longer used
		if ( jQuery.isEmptyObject( events ) ) {
			delete elemData.handle;
			data_priv.remove( elem, "events" );
		}
	},

	trigger: function( event, data, elem, onlyHandlers ) {

		var i, cur, tmp, bubbleType, ontype, handle, special,
			eventPath = [ elem || document ],
			type = hasOwn.call( event, "type" ) ? event.type : event,
			namespaces = hasOwn.call( event, "namespace" ) ? event.namespace.split(".") : [];

		cur = tmp = elem = elem || document;

		// Don't do events on text and comment nodes
		if ( elem.nodeType === 3 || elem.nodeType === 8 ) {
			return;
		}

		// focus/blur morphs to focusin/out; ensure we're not firing them right now
		if ( rfocusMorph.test( type + jQuery.event.triggered ) ) {
			return;
		}

		if ( type.indexOf(".") >= 0 ) {
			// Namespaced trigger; create a regexp to match event type in handle()
			namespaces = type.split(".");
			type = namespaces.shift();
			namespaces.sort();
		}
		ontype = type.indexOf(":") < 0 && "on" + type;

		// Caller can pass in a jQuery.Event object, Object, or just an event type string
		event = event[ jQuery.expando ] ?
			event :
			new jQuery.Event( type, typeof event === "object" && event );

		// Trigger bitmask: & 1 for native handlers; & 2 for jQuery (always true)
		event.isTrigger = onlyHandlers ? 2 : 3;
		event.namespace = namespaces.join(".");
		event.namespace_re = event.namespace ?
			new RegExp( "(^|\\.)" + namespaces.join("\\.(?:.*\\.|)") + "(\\.|$)" ) :
			null;

		// Clean up the event in case it is being reused
		event.result = undefined;
		if ( !event.target ) {
			event.target = elem;
		}

		// Clone any incoming data and prepend the event, creating the handler arg list
		data = data == null ?
			[ event ] :
			jQuery.makeArray( data, [ event ] );

		// Allow special events to draw outside the lines
		special = jQuery.event.special[ type ] || {};
		if ( !onlyHandlers && special.trigger && special.trigger.apply( elem, data ) === false ) {
			return;
		}

		// Determine event propagation path in advance, per W3C events spec (#9951)
		// Bubble up to document, then to window; watch for a global ownerDocument var (#9724)
		if ( !onlyHandlers && !special.noBubble && !jQuery.isWindow( elem ) ) {

			bubbleType = special.delegateType || type;
			if ( !rfocusMorph.test( bubbleType + type ) ) {
				cur = cur.parentNode;
			}
			for ( ; cur; cur = cur.parentNode ) {
				eventPath.push( cur );
				tmp = cur;
			}

			// Only add window if we got to document (e.g., not plain obj or detached DOM)
			if ( tmp === (elem.ownerDocument || document) ) {
				eventPath.push( tmp.defaultView || tmp.parentWindow || window );
			}
		}

		// Fire handlers on the event path
		i = 0;
		while ( (cur = eventPath[i++]) && !event.isPropagationStopped() ) {

			event.type = i > 1 ?
				bubbleType :
				special.bindType || type;

			// jQuery handler
			handle = ( data_priv.get( cur, "events" ) || {} )[ event.type ] && data_priv.get( cur, "handle" );
			if ( handle ) {
				handle.apply( cur, data );
			}

			// Native handler
			handle = ontype && cur[ ontype ];
			if ( handle && handle.apply && jQuery.acceptData( cur ) ) {
				event.result = handle.apply( cur, data );
				if ( event.result === false ) {
					event.preventDefault();
				}
			}
		}
		event.type = type;

		// If nobody prevented the default action, do it now
		if ( !onlyHandlers && !event.isDefaultPrevented() ) {

			if ( (!special._default || special._default.apply( eventPath.pop(), data ) === false) &&
				jQuery.acceptData( elem ) ) {

				// Call a native DOM method on the target with the same name name as the event.
				// Don't do default actions on window, that's where global variables be (#6170)
				if ( ontype && jQuery.isFunction( elem[ type ] ) && !jQuery.isWindow( elem ) ) {

					// Don't re-trigger an onFOO event when we call its FOO() method
					tmp = elem[ ontype ];

					if ( tmp ) {
						elem[ ontype ] = null;
					}

					// Prevent re-triggering of the same event, since we already bubbled it above
					jQuery.event.triggered = type;
					elem[ type ]();
					jQuery.event.triggered = undefined;

					if ( tmp ) {
						elem[ ontype ] = tmp;
					}
				}
			}
		}

		return event.result;
	},

	dispatch: function( event ) {

		// Make a writable jQuery.Event from the native event object
		event = jQuery.event.fix( event );

		var i, j, ret, matched, handleObj,
			handlerQueue = [],
			args = slice.call( arguments ),
			handlers = ( data_priv.get( this, "events" ) || {} )[ event.type ] || [],
			special = jQuery.event.special[ event.type ] || {};

		// Use the fix-ed jQuery.Event rather than the (read-only) native event
		args[0] = event;
		event.delegateTarget = this;

		// Call the preDispatch hook for the mapped type, and let it bail if desired
		if ( special.preDispatch && special.preDispatch.call( this, event ) === false ) {
			return;
		}

		// Determine handlers
		handlerQueue = jQuery.event.handlers.call( this, event, handlers );

		// Run delegates first; they may want to stop propagation beneath us
		i = 0;
		while ( (matched = handlerQueue[ i++ ]) && !event.isPropagationStopped() ) {
			event.currentTarget = matched.elem;

			j = 0;
			while ( (handleObj = matched.handlers[ j++ ]) && !event.isImmediatePropagationStopped() ) {

				// Triggered event must either 1) have no namespace, or 2) have namespace(s)
				// a subset or equal to those in the bound event (both can have no namespace).
				if ( !event.namespace_re || event.namespace_re.test( handleObj.namespace ) ) {

					event.handleObj = handleObj;
					event.data = handleObj.data;

					ret = ( (jQuery.event.special[ handleObj.origType ] || {}).handle || handleObj.handler )
							.apply( matched.elem, args );

					if ( ret !== undefined ) {
						if ( (event.result = ret) === false ) {
							event.preventDefault();
							event.stopPropagation();
						}
					}
				}
			}
		}

		// Call the postDispatch hook for the mapped type
		if ( special.postDispatch ) {
			special.postDispatch.call( this, event );
		}

		return event.result;
	},

	handlers: function( event, handlers ) {
		var i, matches, sel, handleObj,
			handlerQueue = [],
			delegateCount = handlers.delegateCount,
			cur = event.target;

		// Find delegate handlers
		// Black-hole SVG <use> instance trees (#13180)
		// Avoid non-left-click bubbling in Firefox (#3861)
		if ( delegateCount && cur.nodeType && (!event.button || event.type !== "click") ) {

			for ( ; cur !== this; cur = cur.parentNode || this ) {

				// Don't process clicks on disabled elements (#6911, #8165, #11382, #11764)
				if ( cur.disabled !== true || event.type !== "click" ) {
					matches = [];
					for ( i = 0; i < delegateCount; i++ ) {
						handleObj = handlers[ i ];

						// Don't conflict with Object.prototype properties (#13203)
						sel = handleObj.selector + " ";

						if ( matches[ sel ] === undefined ) {
							matches[ sel ] = handleObj.needsContext ?
								jQuery( sel, this ).index( cur ) >= 0 :
								jQuery.find( sel, this, null, [ cur ] ).length;
						}
						if ( matches[ sel ] ) {
							matches.push( handleObj );
						}
					}
					if ( matches.length ) {
						handlerQueue.push({ elem: cur, handlers: matches });
					}
				}
			}
		}

		// Add the remaining (directly-bound) handlers
		if ( delegateCount < handlers.length ) {
			handlerQueue.push({ elem: this, handlers: handlers.slice( delegateCount ) });
		}

		return handlerQueue;
	},

	// Includes some event props shared by KeyEvent and MouseEvent
	props: "altKey bubbles cancelable ctrlKey currentTarget eventPhase metaKey relatedTarget shiftKey target timeStamp view which".split(" "),

	fixHooks: {},

	keyHooks: {
		props: "char charCode key keyCode".split(" "),
		filter: function( event, original ) {

			// Add which for key events
			if ( event.which == null ) {
				event.which = original.charCode != null ? original.charCode : original.keyCode;
			}

			return event;
		}
	},

	mouseHooks: {
		props: "button buttons clientX clientY offsetX offsetY pageX pageY screenX screenY toElement".split(" "),
		filter: function( event, original ) {
			var eventDoc, doc, body,
				button = original.button;

			// Calculate pageX/Y if missing and clientX/Y available
			if ( event.pageX == null && original.clientX != null ) {
				eventDoc = event.target.ownerDocument || document;
				doc = eventDoc.documentElement;
				body = eventDoc.body;

				event.pageX = original.clientX + ( doc && doc.scrollLeft || body && body.scrollLeft || 0 ) - ( doc && doc.clientLeft || body && body.clientLeft || 0 );
				event.pageY = original.clientY + ( doc && doc.scrollTop  || body && body.scrollTop  || 0 ) - ( doc && doc.clientTop  || body && body.clientTop  || 0 );
			}

			// Add which for click: 1 === left; 2 === middle; 3 === right
			// Note: button is not normalized, so don't use it
			if ( !event.which && button !== undefined ) {
				event.which = ( button & 1 ? 1 : ( button & 2 ? 3 : ( button & 4 ? 2 : 0 ) ) );
			}

			return event;
		}
	},

	fix: function( event ) {
		if ( event[ jQuery.expando ] ) {
			return event;
		}

		// Create a writable copy of the event object and normalize some properties
		var i, prop, copy,
			type = event.type,
			originalEvent = event,
			fixHook = this.fixHooks[ type ];

		if ( !fixHook ) {
			this.fixHooks[ type ] = fixHook =
				rmouseEvent.test( type ) ? this.mouseHooks :
				rkeyEvent.test( type ) ? this.keyHooks :
				{};
		}
		copy = fixHook.props ? this.props.concat( fixHook.props ) : this.props;

		event = new jQuery.Event( originalEvent );

		i = copy.length;
		while ( i-- ) {
			prop = copy[ i ];
			event[ prop ] = originalEvent[ prop ];
		}

		// Support: Cordova 2.5 (WebKit) (#13255)
		// All events should have a target; Cordova deviceready doesn't
		if ( !event.target ) {
			event.target = document;
		}

		// Support: Safari 6.0+, Chrome<28
		// Target should not be a text node (#504, #13143)
		if ( event.target.nodeType === 3 ) {
			event.target = event.target.parentNode;
		}

		return fixHook.filter ? fixHook.filter( event, originalEvent ) : event;
	},

	special: {
		load: {
			// Prevent triggered image.load events from bubbling to window.load
			noBubble: true
		},
		focus: {
			// Fire native event if possible so blur/focus sequence is correct
			trigger: function() {
				if ( this !== safeActiveElement() && this.focus ) {
					this.focus();
					return false;
				}
			},
			delegateType: "focusin"
		},
		blur: {
			trigger: function() {
				if ( this === safeActiveElement() && this.blur ) {
					this.blur();
					return false;
				}
			},
			delegateType: "focusout"
		},
		click: {
			// For checkbox, fire native event so checked state will be right
			trigger: function() {
				if ( this.type === "checkbox" && this.click && jQuery.nodeName( this, "input" ) ) {
					this.click();
					return false;
				}
			},

			// For cross-browser consistency, don't fire native .click() on links
			_default: function( event ) {
				return jQuery.nodeName( event.target, "a" );
			}
		},

		beforeunload: {
			postDispatch: function( event ) {

				// Support: Firefox 20+
				// Firefox doesn't alert if the returnValue field is not set.
				if ( event.result !== undefined && event.originalEvent ) {
					event.originalEvent.returnValue = event.result;
				}
			}
		}
	},

	simulate: function( type, elem, event, bubble ) {
		// Piggyback on a donor event to simulate a different one.
		// Fake originalEvent to avoid donor's stopPropagation, but if the
		// simulated event prevents default then we do the same on the donor.
		var e = jQuery.extend(
			new jQuery.Event(),
			event,
			{
				type: type,
				isSimulated: true,
				originalEvent: {}
			}
		);
		if ( bubble ) {
			jQuery.event.trigger( e, null, elem );
		} else {
			jQuery.event.dispatch.call( elem, e );
		}
		if ( e.isDefaultPrevented() ) {
			event.preventDefault();
		}
	}
};

jQuery.removeEvent = function( elem, type, handle ) {
	if ( elem.removeEventListener ) {
		elem.removeEventListener( type, handle, false );
	}
};

jQuery.Event = function( src, props ) {
	// Allow instantiation without the 'new' keyword
	if ( !(this instanceof jQuery.Event) ) {
		return new jQuery.Event( src, props );
	}

	// Event object
	if ( src && src.type ) {
		this.originalEvent = src;
		this.type = src.type;

		// Events bubbling up the document may have been marked as prevented
		// by a handler lower down the tree; reflect the correct value.
		this.isDefaultPrevented = src.defaultPrevented ||
				src.defaultPrevented === undefined &&
				// Support: Android<4.0
				src.returnValue === false ?
			returnTrue :
			returnFalse;

	// Event type
	} else {
		this.type = src;
	}

	// Put explicitly provided properties onto the event object
	if ( props ) {
		jQuery.extend( this, props );
	}

	// Create a timestamp if incoming event doesn't have one
	this.timeStamp = src && src.timeStamp || jQuery.now();

	// Mark it as fixed
	this[ jQuery.expando ] = true;
};

// jQuery.Event is based on DOM3 Events as specified by the ECMAScript Language Binding
// http://www.w3.org/TR/2003/WD-DOM-Level-3-Events-20030331/ecma-script-binding.html
jQuery.Event.prototype = {
	isDefaultPrevented: returnFalse,
	isPropagationStopped: returnFalse,
	isImmediatePropagationStopped: returnFalse,

	preventDefault: function() {
		var e = this.originalEvent;

		this.isDefaultPrevented = returnTrue;

		if ( e && e.preventDefault ) {
			e.preventDefault();
		}
	},
	stopPropagation: function() {
		var e = this.originalEvent;

		this.isPropagationStopped = returnTrue;

		if ( e && e.stopPropagation ) {
			e.stopPropagation();
		}
	},
	stopImmediatePropagation: function() {
		var e = this.originalEvent;

		this.isImmediatePropagationStopped = returnTrue;

		if ( e && e.stopImmediatePropagation ) {
			e.stopImmediatePropagation();
		}

		this.stopPropagation();
	}
};

// Create mouseenter/leave events using mouseover/out and event-time checks
// Support: Chrome 15+
jQuery.each({
	mouseenter: "mouseover",
	mouseleave: "mouseout",
	pointerenter: "pointerover",
	pointerleave: "pointerout"
}, function( orig, fix ) {
	jQuery.event.special[ orig ] = {
		delegateType: fix,
		bindType: fix,

		handle: function( event ) {
			var ret,
				target = this,
				related = event.relatedTarget,
				handleObj = event.handleObj;

			// For mousenter/leave call the handler if related is outside the target.
			// NB: No relatedTarget if the mouse left/entered the browser window
			if ( !related || (related !== target && !jQuery.contains( target, related )) ) {
				event.type = handleObj.origType;
				ret = handleObj.handler.apply( this, arguments );
				event.type = fix;
			}
			return ret;
		}
	};
});

// Support: Firefox, Chrome, Safari
// Create "bubbling" focus and blur events
if ( !support.focusinBubbles ) {
	jQuery.each({ focus: "focusin", blur: "focusout" }, function( orig, fix ) {

		// Attach a single capturing handler on the document while someone wants focusin/focusout
		var handler = function( event ) {
				jQuery.event.simulate( fix, event.target, jQuery.event.fix( event ), true );
			};

		jQuery.event.special[ fix ] = {
			setup: function() {
				var doc = this.ownerDocument || this,
					attaches = data_priv.access( doc, fix );

				if ( !attaches ) {
					doc.addEventListener( orig, handler, true );
				}
				data_priv.access( doc, fix, ( attaches || 0 ) + 1 );
			},
			teardown: function() {
				var doc = this.ownerDocument || this,
					attaches = data_priv.access( doc, fix ) - 1;

				if ( !attaches ) {
					doc.removeEventListener( orig, handler, true );
					data_priv.remove( doc, fix );

				} else {
					data_priv.access( doc, fix, attaches );
				}
			}
		};
	});
}

jQuery.fn.extend({

	on: function( types, selector, data, fn, /*INTERNAL*/ one ) {
		var origFn, type;

		// Types can be a map of types/handlers
		if ( typeof types === "object" ) {
			// ( types-Object, selector, data )
			if ( typeof selector !== "string" ) {
				// ( types-Object, data )
				data = data || selector;
				selector = undefined;
			}
			for ( type in types ) {
				this.on( type, selector, data, types[ type ], one );
			}
			return this;
		}

		if ( data == null && fn == null ) {
			// ( types, fn )
			fn = selector;
			data = selector = undefined;
		} else if ( fn == null ) {
			if ( typeof selector === "string" ) {
				// ( types, selector, fn )
				fn = data;
				data = undefined;
			} else {
				// ( types, data, fn )
				fn = data;
				data = selector;
				selector = undefined;
			}
		}
		if ( fn === false ) {
			fn = returnFalse;
		} else if ( !fn ) {
			return this;
		}

		if ( one === 1 ) {
			origFn = fn;
			fn = function( event ) {
				// Can use an empty set, since event contains the info
				jQuery().off( event );
				return origFn.apply( this, arguments );
			};
			// Use same guid so caller can remove using origFn
			fn.guid = origFn.guid || ( origFn.guid = jQuery.guid++ );
		}
		return this.each( function() {
			jQuery.event.add( this, types, fn, data, selector );
		});
	},
	one: function( types, selector, data, fn ) {
		return this.on( types, selector, data, fn, 1 );
	},
	off: function( types, selector, fn ) {
		var handleObj, type;
		if ( types && types.preventDefault && types.handleObj ) {
			// ( event )  dispatched jQuery.Event
			handleObj = types.handleObj;
			jQuery( types.delegateTarget ).off(
				handleObj.namespace ? handleObj.origType + "." + handleObj.namespace : handleObj.origType,
				handleObj.selector,
				handleObj.handler
			);
			return this;
		}
		if ( typeof types === "object" ) {
			// ( types-object [, selector] )
			for ( type in types ) {
				this.off( type, selector, types[ type ] );
			}
			return this;
		}
		if ( selector === false || typeof selector === "function" ) {
			// ( types [, fn] )
			fn = selector;
			selector = undefined;
		}
		if ( fn === false ) {
			fn = returnFalse;
		}
		return this.each(function() {
			jQuery.event.remove( this, types, fn, selector );
		});
	},

	trigger: function( type, data ) {
		return this.each(function() {
			jQuery.event.trigger( type, data, this );
		});
	},
	triggerHandler: function( type, data ) {
		var elem = this[0];
		if ( elem ) {
			return jQuery.event.trigger( type, data, elem, true );
		}
	}
});


var
	rxhtmlTag = /<(?!area|br|col|embed|hr|img|input|link|meta|param)(([\w:]+)[^>]*)\/>/gi,
	rtagName = /<([\w:]+)/,
	rhtml = /<|&#?\w+;/,
	rnoInnerhtml = /<(?:script|style|link)/i,
	// checked="checked" or checked
	rchecked = /checked\s*(?:[^=]|=\s*.checked.)/i,
	rscriptType = /^$|\/(?:java|ecma)script/i,
	rscriptTypeMasked = /^true\/(.*)/,
	rcleanScript = /^\s*<!(?:\[CDATA\[|--)|(?:\]\]|--)>\s*$/g,

	// We have to close these tags to support XHTML (#13200)
	wrapMap = {

		// Support: IE9
		option: [ 1, "<select multiple='multiple'>", "</select>" ],

		thead: [ 1, "<table>", "</table>" ],
		col: [ 2, "<table><colgroup>", "</colgroup></table>" ],
		tr: [ 2, "<table><tbody>", "</tbody></table>" ],
		td: [ 3, "<table><tbody><tr>", "</tr></tbody></table>" ],

		_default: [ 0, "", "" ]
	};

// Support: IE9
wrapMap.optgroup = wrapMap.option;

wrapMap.tbody = wrapMap.tfoot = wrapMap.colgroup = wrapMap.caption = wrapMap.thead;
wrapMap.th = wrapMap.td;

// Support: 1.x compatibility
// Manipulating tables requires a tbody
function manipulationTarget( elem, content ) {
	return jQuery.nodeName( elem, "table" ) &&
		jQuery.nodeName( content.nodeType !== 11 ? content : content.firstChild, "tr" ) ?

		elem.getElementsByTagName("tbody")[0] ||
			elem.appendChild( elem.ownerDocument.createElement("tbody") ) :
		elem;
}

// Replace/restore the type attribute of script elements for safe DOM manipulation
function disableScript( elem ) {
	elem.type = (elem.getAttribute("type") !== null) + "/" + elem.type;
	return elem;
}
function restoreScript( elem ) {
	var match = rscriptTypeMasked.exec( elem.type );

	if ( match ) {
		elem.type = match[ 1 ];
	} else {
		elem.removeAttribute("type");
	}

	return elem;
}

// Mark scripts as having already been evaluated
function setGlobalEval( elems, refElements ) {
	var i = 0,
		l = elems.length;

	for ( ; i < l; i++ ) {
		data_priv.set(
			elems[ i ], "globalEval", !refElements || data_priv.get( refElements[ i ], "globalEval" )
		);
	}
}

function cloneCopyEvent( src, dest ) {
	var i, l, type, pdataOld, pdataCur, udataOld, udataCur, events;

	if ( dest.nodeType !== 1 ) {
		return;
	}

	// 1. Copy private data: events, handlers, etc.
	if ( data_priv.hasData( src ) ) {
		pdataOld = data_priv.access( src );
		pdataCur = data_priv.set( dest, pdataOld );
		events = pdataOld.events;

		if ( events ) {
			delete pdataCur.handle;
			pdataCur.events = {};

			for ( type in events ) {
				for ( i = 0, l = events[ type ].length; i < l; i++ ) {
					jQuery.event.add( dest, type, events[ type ][ i ] );
				}
			}
		}
	}

	// 2. Copy user data
	if ( data_user.hasData( src ) ) {
		udataOld = data_user.access( src );
		udataCur = jQuery.extend( {}, udataOld );

		data_user.set( dest, udataCur );
	}
}

function getAll( context, tag ) {
	var ret = context.getElementsByTagName ? context.getElementsByTagName( tag || "*" ) :
			context.querySelectorAll ? context.querySelectorAll( tag || "*" ) :
			[];

	return tag === undefined || tag && jQuery.nodeName( context, tag ) ?
		jQuery.merge( [ context ], ret ) :
		ret;
}

// Fix IE bugs, see support tests
function fixInput( src, dest ) {
	var nodeName = dest.nodeName.toLowerCase();

	// Fails to persist the checked state of a cloned checkbox or radio button.
	if ( nodeName === "input" && rcheckableType.test( src.type ) ) {
		dest.checked = src.checked;

	// Fails to return the selected option to the default selected state when cloning options
	} else if ( nodeName === "input" || nodeName === "textarea" ) {
		dest.defaultValue = src.defaultValue;
	}
}

jQuery.extend({
	clone: function( elem, dataAndEvents, deepDataAndEvents ) {
		var i, l, srcElements, destElements,
			clone = elem.cloneNode( true ),
			inPage = jQuery.contains( elem.ownerDocument, elem );

		// Fix IE cloning issues
		if ( !support.noCloneChecked && ( elem.nodeType === 1 || elem.nodeType === 11 ) &&
				!jQuery.isXMLDoc( elem ) ) {

			// We eschew Sizzle here for performance reasons: http://jsperf.com/getall-vs-sizzle/2
			destElements = getAll( clone );
			srcElements = getAll( elem );

			for ( i = 0, l = srcElements.length; i < l; i++ ) {
				fixInput( srcElements[ i ], destElements[ i ] );
			}
		}

		// Copy the events from the original to the clone
		if ( dataAndEvents ) {
			if ( deepDataAndEvents ) {
				srcElements = srcElements || getAll( elem );
				destElements = destElements || getAll( clone );

				for ( i = 0, l = srcElements.length; i < l; i++ ) {
					cloneCopyEvent( srcElements[ i ], destElements[ i ] );
				}
			} else {
				cloneCopyEvent( elem, clone );
			}
		}

		// Preserve script evaluation history
		destElements = getAll( clone, "script" );
		if ( destElements.length > 0 ) {
			setGlobalEval( destElements, !inPage && getAll( elem, "script" ) );
		}

		// Return the cloned set
		return clone;
	},

	buildFragment: function( elems, context, scripts, selection ) {
		var elem, tmp, tag, wrap, contains, j,
			fragment = context.createDocumentFragment(),
			nodes = [],
			i = 0,
			l = elems.length;

		for ( ; i < l; i++ ) {
			elem = elems[ i ];

			if ( elem || elem === 0 ) {

				// Add nodes directly
				if ( jQuery.type( elem ) === "object" ) {
					// Support: QtWebKit, PhantomJS
					// push.apply(_, arraylike) throws on ancient WebKit
					jQuery.merge( nodes, elem.nodeType ? [ elem ] : elem );

				// Convert non-html into a text node
				} else if ( !rhtml.test( elem ) ) {
					nodes.push( context.createTextNode( elem ) );

				// Convert html into DOM nodes
				} else {
					tmp = tmp || fragment.appendChild( context.createElement("div") );

					// Deserialize a standard representation
					tag = ( rtagName.exec( elem ) || [ "", "" ] )[ 1 ].toLowerCase();
					wrap = wrapMap[ tag ] || wrapMap._default;
					tmp.innerHTML = wrap[ 1 ] + elem.replace( rxhtmlTag, "<$1></$2>" ) + wrap[ 2 ];

					// Descend through wrappers to the right content
					j = wrap[ 0 ];
					while ( j-- ) {
						tmp = tmp.lastChild;
					}

					// Support: QtWebKit, PhantomJS
					// push.apply(_, arraylike) throws on ancient WebKit
					jQuery.merge( nodes, tmp.childNodes );

					// Remember the top-level container
					tmp = fragment.firstChild;

					// Ensure the created nodes are orphaned (#12392)
					tmp.textContent = "";
				}
			}
		}

		// Remove wrapper from fragment
		fragment.textContent = "";

		i = 0;
		while ( (elem = nodes[ i++ ]) ) {

			// #4087 - If origin and destination elements are the same, and this is
			// that element, do not do anything
			if ( selection && jQuery.inArray( elem, selection ) !== -1 ) {
				continue;
			}

			contains = jQuery.contains( elem.ownerDocument, elem );

			// Append to fragment
			tmp = getAll( fragment.appendChild( elem ), "script" );

			// Preserve script evaluation history
			if ( contains ) {
				setGlobalEval( tmp );
			}

			// Capture executables
			if ( scripts ) {
				j = 0;
				while ( (elem = tmp[ j++ ]) ) {
					if ( rscriptType.test( elem.type || "" ) ) {
						scripts.push( elem );
					}
				}
			}
		}

		return fragment;
	},

	cleanData: function( elems ) {
		var data, elem, type, key,
			special = jQuery.event.special,
			i = 0;

		for ( ; (elem = elems[ i ]) !== undefined; i++ ) {
			if ( jQuery.acceptData( elem ) ) {
				key = elem[ data_priv.expando ];

				if ( key && (data = data_priv.cache[ key ]) ) {
					if ( data.events ) {
						for ( type in data.events ) {
							if ( special[ type ] ) {
								jQuery.event.remove( elem, type );

							// This is a shortcut to avoid jQuery.event.remove's overhead
							} else {
								jQuery.removeEvent( elem, type, data.handle );
							}
						}
					}
					if ( data_priv.cache[ key ] ) {
						// Discard any remaining `private` data
						delete data_priv.cache[ key ];
					}
				}
			}
			// Discard any remaining `user` data
			delete data_user.cache[ elem[ data_user.expando ] ];
		}
	}
});

jQuery.fn.extend({
	text: function( value ) {
		return access( this, function( value ) {
			return value === undefined ?
				jQuery.text( this ) :
				this.empty().each(function() {
					if ( this.nodeType === 1 || this.nodeType === 11 || this.nodeType === 9 ) {
						this.textContent = value;
					}
				});
		}, null, value, arguments.length );
	},

	append: function() {
		return this.domManip( arguments, function( elem ) {
			if ( this.nodeType === 1 || this.nodeType === 11 || this.nodeType === 9 ) {
				var target = manipulationTarget( this, elem );
				target.appendChild( elem );
			}
		});
	},

	prepend: function() {
		return this.domManip( arguments, function( elem ) {
			if ( this.nodeType === 1 || this.nodeType === 11 || this.nodeType === 9 ) {
				var target = manipulationTarget( this, elem );
				target.insertBefore( elem, target.firstChild );
			}
		});
	},

	before: function() {
		return this.domManip( arguments, function( elem ) {
			if ( this.parentNode ) {
				this.parentNode.insertBefore( elem, this );
			}
		});
	},

	after: function() {
		return this.domManip( arguments, function( elem ) {
			if ( this.parentNode ) {
				this.parentNode.insertBefore( elem, this.nextSibling );
			}
		});
	},

	remove: function( selector, keepData /* Internal Use Only */ ) {
		var elem,
			elems = selector ? jQuery.filter( selector, this ) : this,
			i = 0;

		for ( ; (elem = elems[i]) != null; i++ ) {
			if ( !keepData && elem.nodeType === 1 ) {
				jQuery.cleanData( getAll( elem ) );
			}

			if ( elem.parentNode ) {
				if ( keepData && jQuery.contains( elem.ownerDocument, elem ) ) {
					setGlobalEval( getAll( elem, "script" ) );
				}
				elem.parentNode.removeChild( elem );
			}
		}

		return this;
	},

	empty: function() {
		var elem,
			i = 0;

		for ( ; (elem = this[i]) != null; i++ ) {
			if ( elem.nodeType === 1 ) {

				// Prevent memory leaks
				jQuery.cleanData( getAll( elem, false ) );

				// Remove any remaining nodes
				elem.textContent = "";
			}
		}

		return this;
	},

	clone: function( dataAndEvents, deepDataAndEvents ) {
		dataAndEvents = dataAndEvents == null ? false : dataAndEvents;
		deepDataAndEvents = deepDataAndEvents == null ? dataAndEvents : deepDataAndEvents;

		return this.map(function() {
			return jQuery.clone( this, dataAndEvents, deepDataAndEvents );
		});
	},

	html: function( value ) {
		return access( this, function( value ) {
			var elem = this[ 0 ] || {},
				i = 0,
				l = this.length;

			if ( value === undefined && elem.nodeType === 1 ) {
				return elem.innerHTML;
			}

			// See if we can take a shortcut and just use innerHTML
			if ( typeof value === "string" && !rnoInnerhtml.test( value ) &&
				!wrapMap[ ( rtagName.exec( value ) || [ "", "" ] )[ 1 ].toLowerCase() ] ) {

				value = value.replace( rxhtmlTag, "<$1></$2>" );

				try {
					for ( ; i < l; i++ ) {
						elem = this[ i ] || {};

						// Remove element nodes and prevent memory leaks
						if ( elem.nodeType === 1 ) {
							jQuery.cleanData( getAll( elem, false ) );
							elem.innerHTML = value;
						}
					}

					elem = 0;

				// If using innerHTML throws an exception, use the fallback method
				} catch( e ) {}
			}

			if ( elem ) {
				this.empty().append( value );
			}
		}, null, value, arguments.length );
	},

	replaceWith: function() {
		var arg = arguments[ 0 ];

		// Make the changes, replacing each context element with the new content
		this.domManip( arguments, function( elem ) {
			arg = this.parentNode;

			jQuery.cleanData( getAll( this ) );

			if ( arg ) {
				arg.replaceChild( elem, this );
			}
		});

		// Force removal if there was no new content (e.g., from empty arguments)
		return arg && (arg.length || arg.nodeType) ? this : this.remove();
	},

	detach: function( selector ) {
		return this.remove( selector, true );
	},

	domManip: function( args, callback ) {

		// Flatten any nested arrays
		args = concat.apply( [], args );

		var fragment, first, scripts, hasScripts, node, doc,
			i = 0,
			l = this.length,
			set = this,
			iNoClone = l - 1,
			value = args[ 0 ],
			isFunction = jQuery.isFunction( value );

		// We can't cloneNode fragments that contain checked, in WebKit
		if ( isFunction ||
				( l > 1 && typeof value === "string" &&
					!support.checkClone && rchecked.test( value ) ) ) {
			return this.each(function( index ) {
				var self = set.eq( index );
				if ( isFunction ) {
					args[ 0 ] = value.call( this, index, self.html() );
				}
				self.domManip( args, callback );
			});
		}

		if ( l ) {
			fragment = jQuery.buildFragment( args, this[ 0 ].ownerDocument, false, this );
			first = fragment.firstChild;

			if ( fragment.childNodes.length === 1 ) {
				fragment = first;
			}

			if ( first ) {
				scripts = jQuery.map( getAll( fragment, "script" ), disableScript );
				hasScripts = scripts.length;

				// Use the original fragment for the last item instead of the first because it can end up
				// being emptied incorrectly in certain situations (#8070).
				for ( ; i < l; i++ ) {
					node = fragment;

					if ( i !== iNoClone ) {
						node = jQuery.clone( node, true, true );

						// Keep references to cloned scripts for later restoration
						if ( hasScripts ) {
							// Support: QtWebKit
							// jQuery.merge because push.apply(_, arraylike) throws
							jQuery.merge( scripts, getAll( node, "script" ) );
						}
					}

					callback.call( this[ i ], node, i );
				}

				if ( hasScripts ) {
					doc = scripts[ scripts.length - 1 ].ownerDocument;

					// Reenable scripts
					jQuery.map( scripts, restoreScript );

					// Evaluate executable scripts on first document insertion
					for ( i = 0; i < hasScripts; i++ ) {
						node = scripts[ i ];
						if ( rscriptType.test( node.type || "" ) &&
							!data_priv.access( node, "globalEval" ) && jQuery.contains( doc, node ) ) {

							if ( node.src ) {
								// Optional AJAX dependency, but won't run scripts if not present
								if ( jQuery._evalUrl ) {
									jQuery._evalUrl( node.src );
								}
							} else {
								jQuery.globalEval( node.textContent.replace( rcleanScript, "" ) );
							}
						}
					}
				}
			}
		}

		return this;
	}
});

jQuery.each({
	appendTo: "append",
	prependTo: "prepend",
	insertBefore: "before",
	insertAfter: "after",
	replaceAll: "replaceWith"
}, function( name, original ) {
	jQuery.fn[ name ] = function( selector ) {
		var elems,
			ret = [],
			insert = jQuery( selector ),
			last = insert.length - 1,
			i = 0;

		for ( ; i <= last; i++ ) {
			elems = i === last ? this : this.clone( true );
			jQuery( insert[ i ] )[ original ]( elems );

			// Support: QtWebKit
			// .get() because push.apply(_, arraylike) throws
			push.apply( ret, elems.get() );
		}

		return this.pushStack( ret );
	};
});


var iframe,
	elemdisplay = {};

/**
 * Retrieve the actual display of a element
 * @param {String} name nodeName of the element
 * @param {Object} doc Document object
 */
// Called only from within defaultDisplay
function actualDisplay( name, doc ) {
	var style,
		elem = jQuery( doc.createElement( name ) ).appendTo( doc.body ),

		// getDefaultComputedStyle might be reliably used only on attached element
		display = window.getDefaultComputedStyle && ( style = window.getDefaultComputedStyle( elem[ 0 ] ) ) ?

			// Use of this method is a temporary fix (more like optimization) until something better comes along,
			// since it was removed from specification and supported only in FF
			style.display : jQuery.css( elem[ 0 ], "display" );

	// We don't have any data stored on the element,
	// so use "detach" method as fast way to get rid of the element
	elem.detach();

	return display;
}

/**
 * Try to determine the default display value of an element
 * @param {String} nodeName
 */
function defaultDisplay( nodeName ) {
	var doc = document,
		display = elemdisplay[ nodeName ];

	if ( !display ) {
		display = actualDisplay( nodeName, doc );

		// If the simple way fails, read from inside an iframe
		if ( display === "none" || !display ) {

			// Use the already-created iframe if possible
			iframe = (iframe || jQuery( "<iframe frameborder='0' width='0' height='0'/>" )).appendTo( doc.documentElement );

			// Always write a new HTML skeleton so Webkit and Firefox don't choke on reuse
			doc = iframe[ 0 ].contentDocument;

			// Support: IE
			doc.write();
			doc.close();

			display = actualDisplay( nodeName, doc );
			iframe.detach();
		}

		// Store the correct default display
		elemdisplay[ nodeName ] = display;
	}

	return display;
}
var rmargin = (/^margin/);

var rnumnonpx = new RegExp( "^(" + pnum + ")(?!px)[a-z%]+$", "i" );

var getStyles = function( elem ) {
		// Support: IE<=11+, Firefox<=30+ (#15098, #14150)
		// IE throws on elements created in popups
		// FF meanwhile throws on frame elements through "defaultView.getComputedStyle"
		if ( elem.ownerDocument.defaultView.opener ) {
			return elem.ownerDocument.defaultView.getComputedStyle( elem, null );
		}

		return window.getComputedStyle( elem, null );
	};



function curCSS( elem, name, computed ) {
	var width, minWidth, maxWidth, ret,
		style = elem.style;

	computed = computed || getStyles( elem );

	// Support: IE9
	// getPropertyValue is only needed for .css('filter') (#12537)
	if ( computed ) {
		ret = computed.getPropertyValue( name ) || computed[ name ];
	}

	if ( computed ) {

		if ( ret === "" && !jQuery.contains( elem.ownerDocument, elem ) ) {
			ret = jQuery.style( elem, name );
		}

		// Support: iOS < 6
		// A tribute to the "awesome hack by Dean Edwards"
		// iOS < 6 (at least) returns percentage for a larger set of values, but width seems to be reliably pixels
		// this is against the CSSOM draft spec: http://dev.w3.org/csswg/cssom/#resolved-values
		if ( rnumnonpx.test( ret ) && rmargin.test( name ) ) {

			// Remember the original values
			width = style.width;
			minWidth = style.minWidth;
			maxWidth = style.maxWidth;

			// Put in the new values to get a computed value out
			style.minWidth = style.maxWidth = style.width = ret;
			ret = computed.width;

			// Revert the changed values
			style.width = width;
			style.minWidth = minWidth;
			style.maxWidth = maxWidth;
		}
	}

	return ret !== undefined ?
		// Support: IE
		// IE returns zIndex value as an integer.
		ret + "" :
		ret;
}


function addGetHookIf( conditionFn, hookFn ) {
	// Define the hook, we'll check on the first run if it's really needed.
	return {
		get: function() {
			if ( conditionFn() ) {
				// Hook not needed (or it's not possible to use it due
				// to missing dependency), remove it.
				delete this.get;
				return;
			}

			// Hook needed; redefine it so that the support test is not executed again.
			return (this.get = hookFn).apply( this, arguments );
		}
	};
}


(function() {
	var pixelPositionVal, boxSizingReliableVal,
		docElem = document.documentElement,
		container = document.createElement( "div" ),
		div = document.createElement( "div" );

	if ( !div.style ) {
		return;
	}

	// Support: IE9-11+
	// Style of cloned element affects source element cloned (#8908)
	div.style.backgroundClip = "content-box";
	div.cloneNode( true ).style.backgroundClip = "";
	support.clearCloneStyle = div.style.backgroundClip === "content-box";

	container.style.cssText = "border:0;width:0;height:0;top:0;left:-9999px;margin-top:1px;" +
		"position:absolute";
	container.appendChild( div );

	// Executing both pixelPosition & boxSizingReliable tests require only one layout
	// so they're executed at the same time to save the second computation.
	function computePixelPositionAndBoxSizingReliable() {
		div.style.cssText =
			// Support: Firefox<29, Android 2.3
			// Vendor-prefix box-sizing
			"-webkit-box-sizing:border-box;-moz-box-sizing:border-box;" +
			"box-sizing:border-box;display:block;margin-top:1%;top:1%;" +
			"border:1px;padding:1px;width:4px;position:absolute";
		div.innerHTML = "";
		docElem.appendChild( container );

		var divStyle = window.getComputedStyle( div, null );
		pixelPositionVal = divStyle.top !== "1%";
		boxSizingReliableVal = divStyle.width === "4px";

		docElem.removeChild( container );
	}

	// Support: node.js jsdom
	// Don't assume that getComputedStyle is a property of the global object
	if ( window.getComputedStyle ) {
		jQuery.extend( support, {
			pixelPosition: function() {

				// This test is executed only once but we still do memoizing
				// since we can use the boxSizingReliable pre-computing.
				// No need to check if the test was already performed, though.
				computePixelPositionAndBoxSizingReliable();
				return pixelPositionVal;
			},
			boxSizingReliable: function() {
				if ( boxSizingReliableVal == null ) {
					computePixelPositionAndBoxSizingReliable();
				}
				return boxSizingReliableVal;
			},
			reliableMarginRight: function() {

				// Support: Android 2.3
				// Check if div with explicit width and no margin-right incorrectly
				// gets computed margin-right based on width of container. (#3333)
				// WebKit Bug 13343 - getComputedStyle returns wrong value for margin-right
				// This support function is only executed once so no memoizing is needed.
				var ret,
					marginDiv = div.appendChild( document.createElement( "div" ) );

				// Reset CSS: box-sizing; display; margin; border; padding
				marginDiv.style.cssText = div.style.cssText =
					// Support: Firefox<29, Android 2.3
					// Vendor-prefix box-sizing
					"-webkit-box-sizing:content-box;-moz-box-sizing:content-box;" +
					"box-sizing:content-box;display:block;margin:0;border:0;padding:0";
				marginDiv.style.marginRight = marginDiv.style.width = "0";
				div.style.width = "1px";
				docElem.appendChild( container );

				ret = !parseFloat( window.getComputedStyle( marginDiv, null ).marginRight );

				docElem.removeChild( container );
				div.removeChild( marginDiv );

				return ret;
			}
		});
	}
})();


// A method for quickly swapping in/out CSS properties to get correct calculations.
jQuery.swap = function( elem, options, callback, args ) {
	var ret, name,
		old = {};

	// Remember the old values, and insert the new ones
	for ( name in options ) {
		old[ name ] = elem.style[ name ];
		elem.style[ name ] = options[ name ];
	}

	ret = callback.apply( elem, args || [] );

	// Revert the old values
	for ( name in options ) {
		elem.style[ name ] = old[ name ];
	}

	return ret;
};


var
	// Swappable if display is none or starts with table except "table", "table-cell", or "table-caption"
	// See here for display values: https://developer.mozilla.org/en-US/docs/CSS/display
	rdisplayswap = /^(none|table(?!-c[ea]).+)/,
	rnumsplit = new RegExp( "^(" + pnum + ")(.*)$", "i" ),
	rrelNum = new RegExp( "^([+-])=(" + pnum + ")", "i" ),

	cssShow = { position: "absolute", visibility: "hidden", display: "block" },
	cssNormalTransform = {
		letterSpacing: "0",
		fontWeight: "400"
	},

	cssPrefixes = [ "Webkit", "O", "Moz", "ms" ];

// Return a css property mapped to a potentially vendor prefixed property
function vendorPropName( style, name ) {

	// Shortcut for names that are not vendor prefixed
	if ( name in style ) {
		return name;
	}

	// Check for vendor prefixed names
	var capName = name[0].toUpperCase() + name.slice(1),
		origName = name,
		i = cssPrefixes.length;

	while ( i-- ) {
		name = cssPrefixes[ i ] + capName;
		if ( name in style ) {
			return name;
		}
	}

	return origName;
}

function setPositiveNumber( elem, value, subtract ) {
	var matches = rnumsplit.exec( value );
	return matches ?
		// Guard against undefined "subtract", e.g., when used as in cssHooks
		Math.max( 0, matches[ 1 ] - ( subtract || 0 ) ) + ( matches[ 2 ] || "px" ) :
		value;
}

function augmentWidthOrHeight( elem, name, extra, isBorderBox, styles ) {
	var i = extra === ( isBorderBox ? "border" : "content" ) ?
		// If we already have the right measurement, avoid augmentation
		4 :
		// Otherwise initialize for horizontal or vertical properties
		name === "width" ? 1 : 0,

		val = 0;

	for ( ; i < 4; i += 2 ) {
		// Both box models exclude margin, so add it if we want it
		if ( extra === "margin" ) {
			val += jQuery.css( elem, extra + cssExpand[ i ], true, styles );
		}

		if ( isBorderBox ) {
			// border-box includes padding, so remove it if we want content
			if ( extra === "content" ) {
				val -= jQuery.css( elem, "padding" + cssExpand[ i ], true, styles );
			}

			// At this point, extra isn't border nor margin, so remove border
			if ( extra !== "margin" ) {
				val -= jQuery.css( elem, "border" + cssExpand[ i ] + "Width", true, styles );
			}
		} else {
			// At this point, extra isn't content, so add padding
			val += jQuery.css( elem, "padding" + cssExpand[ i ], true, styles );

			// At this point, extra isn't content nor padding, so add border
			if ( extra !== "padding" ) {
				val += jQuery.css( elem, "border" + cssExpand[ i ] + "Width", true, styles );
			}
		}
	}

	return val;
}

function getWidthOrHeight( elem, name, extra ) {

	// Start with offset property, which is equivalent to the border-box value
	var valueIsBorderBox = true,
		val = name === "width" ? elem.offsetWidth : elem.offsetHeight,
		styles = getStyles( elem ),
		isBorderBox = jQuery.css( elem, "boxSizing", false, styles ) === "border-box";

	// Some non-html elements return undefined for offsetWidth, so check for null/undefined
	// svg - https://bugzilla.mozilla.org/show_bug.cgi?id=649285
	// MathML - https://bugzilla.mozilla.org/show_bug.cgi?id=491668
	if ( val <= 0 || val == null ) {
		// Fall back to computed then uncomputed css if necessary
		val = curCSS( elem, name, styles );
		if ( val < 0 || val == null ) {
			val = elem.style[ name ];
		}

		// Computed unit is not pixels. Stop here and return.
		if ( rnumnonpx.test(val) ) {
			return val;
		}

		// Check for style in case a browser which returns unreliable values
		// for getComputedStyle silently falls back to the reliable elem.style
		valueIsBorderBox = isBorderBox &&
			( support.boxSizingReliable() || val === elem.style[ name ] );

		// Normalize "", auto, and prepare for extra
		val = parseFloat( val ) || 0;
	}

	// Use the active box-sizing model to add/subtract irrelevant styles
	return ( val +
		augmentWidthOrHeight(
			elem,
			name,
			extra || ( isBorderBox ? "border" : "content" ),
			valueIsBorderBox,
			styles
		)
	) + "px";
}

function showHide( elements, show ) {
	var display, elem, hidden,
		values = [],
		index = 0,
		length = elements.length;

	for ( ; index < length; index++ ) {
		elem = elements[ index ];
		if ( !elem.style ) {
			continue;
		}

		values[ index ] = data_priv.get( elem, "olddisplay" );
		display = elem.style.display;
		if ( show ) {
			// Reset the inline display of this element to learn if it is
			// being hidden by cascaded rules or not
			if ( !values[ index ] && display === "none" ) {
				elem.style.display = "";
			}

			// Set elements which have been overridden with display: none
			// in a stylesheet to whatever the default browser style is
			// for such an element
			if ( elem.style.display === "" && isHidden( elem ) ) {
				values[ index ] = data_priv.access( elem, "olddisplay", defaultDisplay(elem.nodeName) );
			}
		} else {
			hidden = isHidden( elem );

			if ( display !== "none" || !hidden ) {
				data_priv.set( elem, "olddisplay", hidden ? display : jQuery.css( elem, "display" ) );
			}
		}
	}

	// Set the display of most of the elements in a second loop
	// to avoid the constant reflow
	for ( index = 0; index < length; index++ ) {
		elem = elements[ index ];
		if ( !elem.style ) {
			continue;
		}
		if ( !show || elem.style.display === "none" || elem.style.display === "" ) {
			elem.style.display = show ? values[ index ] || "" : "none";
		}
	}

	return elements;
}

jQuery.extend({

	// Add in style property hooks for overriding the default
	// behavior of getting and setting a style property
	cssHooks: {
		opacity: {
			get: function( elem, computed ) {
				if ( computed ) {

					// We should always get a number back from opacity
					var ret = curCSS( elem, "opacity" );
					return ret === "" ? "1" : ret;
				}
			}
		}
	},

	// Don't automatically add "px" to these possibly-unitless properties
	cssNumber: {
		"columnCount": true,
		"fillOpacity": true,
		"flexGrow": true,
		"flexShrink": true,
		"fontWeight": true,
		"lineHeight": true,
		"opacity": true,
		"order": true,
		"orphans": true,
		"widows": true,
		"zIndex": true,
		"zoom": true
	},

	// Add in properties whose names you wish to fix before
	// setting or getting the value
	cssProps: {
		"float": "cssFloat"
	},

	// Get and set the style property on a DOM Node
	style: function( elem, name, value, extra ) {

		// Don't set styles on text and comment nodes
		if ( !elem || elem.nodeType === 3 || elem.nodeType === 8 || !elem.style ) {
			return;
		}

		// Make sure that we're working with the right name
		var ret, type, hooks,
			origName = jQuery.camelCase( name ),
			style = elem.style;

		name = jQuery.cssProps[ origName ] || ( jQuery.cssProps[ origName ] = vendorPropName( style, origName ) );

		// Gets hook for the prefixed version, then unprefixed version
		hooks = jQuery.cssHooks[ name ] || jQuery.cssHooks[ origName ];

		// Check if we're setting a value
		if ( value !== undefined ) {
			type = typeof value;

			// Convert "+=" or "-=" to relative numbers (#7345)
			if ( type === "string" && (ret = rrelNum.exec( value )) ) {
				value = ( ret[1] + 1 ) * ret[2] + parseFloat( jQuery.css( elem, name ) );
				// Fixes bug #9237
				type = "number";
			}

			// Make sure that null and NaN values aren't set (#7116)
			if ( value == null || value !== value ) {
				return;
			}

			// If a number, add 'px' to the (except for certain CSS properties)
			if ( type === "number" && !jQuery.cssNumber[ origName ] ) {
				value += "px";
			}

			// Support: IE9-11+
			// background-* props affect original clone's values
			if ( !support.clearCloneStyle && value === "" && name.indexOf( "background" ) === 0 ) {
				style[ name ] = "inherit";
			}

			// If a hook was provided, use that value, otherwise just set the specified value
			if ( !hooks || !("set" in hooks) || (value = hooks.set( elem, value, extra )) !== undefined ) {
				style[ name ] = value;
			}

		} else {
			// If a hook was provided get the non-computed value from there
			if ( hooks && "get" in hooks && (ret = hooks.get( elem, false, extra )) !== undefined ) {
				return ret;
			}

			// Otherwise just get the value from the style object
			return style[ name ];
		}
	},

	css: function( elem, name, extra, styles ) {
		var val, num, hooks,
			origName = jQuery.camelCase( name );

		// Make sure that we're working with the right name
		name = jQuery.cssProps[ origName ] || ( jQuery.cssProps[ origName ] = vendorPropName( elem.style, origName ) );

		// Try prefixed name followed by the unprefixed name
		hooks = jQuery.cssHooks[ name ] || jQuery.cssHooks[ origName ];

		// If a hook was provided get the computed value from there
		if ( hooks && "get" in hooks ) {
			val = hooks.get( elem, true, extra );
		}

		// Otherwise, if a way to get the computed value exists, use that
		if ( val === undefined ) {
			val = curCSS( elem, name, styles );
		}

		// Convert "normal" to computed value
		if ( val === "normal" && name in cssNormalTransform ) {
			val = cssNormalTransform[ name ];
		}

		// Make numeric if forced or a qualifier was provided and val looks numeric
		if ( extra === "" || extra ) {
			num = parseFloat( val );
			return extra === true || jQuery.isNumeric( num ) ? num || 0 : val;
		}
		return val;
	}
});

jQuery.each([ "height", "width" ], function( i, name ) {
	jQuery.cssHooks[ name ] = {
		get: function( elem, computed, extra ) {
			if ( computed ) {

				// Certain elements can have dimension info if we invisibly show them
				// but it must have a current display style that would benefit
				return rdisplayswap.test( jQuery.css( elem, "display" ) ) && elem.offsetWidth === 0 ?
					jQuery.swap( elem, cssShow, function() {
						return getWidthOrHeight( elem, name, extra );
					}) :
					getWidthOrHeight( elem, name, extra );
			}
		},

		set: function( elem, value, extra ) {
			var styles = extra && getStyles( elem );
			return setPositiveNumber( elem, value, extra ?
				augmentWidthOrHeight(
					elem,
					name,
					extra,
					jQuery.css( elem, "boxSizing", false, styles ) === "border-box",
					styles
				) : 0
			);
		}
	};
});

// Support: Android 2.3
jQuery.cssHooks.marginRight = addGetHookIf( support.reliableMarginRight,
	function( elem, computed ) {
		if ( computed ) {
			return jQuery.swap( elem, { "display": "inline-block" },
				curCSS, [ elem, "marginRight" ] );
		}
	}
);

// These hooks are used by animate to expand properties
jQuery.each({
	margin: "",
	padding: "",
	border: "Width"
}, function( prefix, suffix ) {
	jQuery.cssHooks[ prefix + suffix ] = {
		expand: function( value ) {
			var i = 0,
				expanded = {},

				// Assumes a single number if not a string
				parts = typeof value === "string" ? value.split(" ") : [ value ];

			for ( ; i < 4; i++ ) {
				expanded[ prefix + cssExpand[ i ] + suffix ] =
					parts[ i ] || parts[ i - 2 ] || parts[ 0 ];
			}

			return expanded;
		}
	};

	if ( !rmargin.test( prefix ) ) {
		jQuery.cssHooks[ prefix + suffix ].set = setPositiveNumber;
	}
});

jQuery.fn.extend({
	css: function( name, value ) {
		return access( this, function( elem, name, value ) {
			var styles, len,
				map = {},
				i = 0;

			if ( jQuery.isArray( name ) ) {
				styles = getStyles( elem );
				len = name.length;

				for ( ; i < len; i++ ) {
					map[ name[ i ] ] = jQuery.css( elem, name[ i ], false, styles );
				}

				return map;
			}

			return value !== undefined ?
				jQuery.style( elem, name, value ) :
				jQuery.css( elem, name );
		}, name, value, arguments.length > 1 );
	},
	show: function() {
		return showHide( this, true );
	},
	hide: function() {
		return showHide( this );
	},
	toggle: function( state ) {
		if ( typeof state === "boolean" ) {
			return state ? this.show() : this.hide();
		}

		return this.each(function() {
			if ( isHidden( this ) ) {
				jQuery( this ).show();
			} else {
				jQuery( this ).hide();
			}
		});
	}
});


function Tween( elem, options, prop, end, easing ) {
	return new Tween.prototype.init( elem, options, prop, end, easing );
}
jQuery.Tween = Tween;

Tween.prototype = {
	constructor: Tween,
	init: function( elem, options, prop, end, easing, unit ) {
		this.elem = elem;
		this.prop = prop;
		this.easing = easing || "swing";
		this.options = options;
		this.start = this.now = this.cur();
		this.end = end;
		this.unit = unit || ( jQuery.cssNumber[ prop ] ? "" : "px" );
	},
	cur: function() {
		var hooks = Tween.propHooks[ this.prop ];

		return hooks && hooks.get ?
			hooks.get( this ) :
			Tween.propHooks._default.get( this );
	},
	run: function( percent ) {
		var eased,
			hooks = Tween.propHooks[ this.prop ];

		if ( this.options.duration ) {
			this.pos = eased = jQuery.easing[ this.easing ](
				percent, this.options.duration * percent, 0, 1, this.options.duration
			);
		} else {
			this.pos = eased = percent;
		}
		this.now = ( this.end - this.start ) * eased + this.start;

		if ( this.options.step ) {
			this.options.step.call( this.elem, this.now, this );
		}

		if ( hooks && hooks.set ) {
			hooks.set( this );
		} else {
			Tween.propHooks._default.set( this );
		}
		return this;
	}
};

Tween.prototype.init.prototype = Tween.prototype;

Tween.propHooks = {
	_default: {
		get: function( tween ) {
			var result;

			if ( tween.elem[ tween.prop ] != null &&
				(!tween.elem.style || tween.elem.style[ tween.prop ] == null) ) {
				return tween.elem[ tween.prop ];
			}

			// Passing an empty string as a 3rd parameter to .css will automatically
			// attempt a parseFloat and fallback to a string if the parse fails.
			// Simple values such as "10px" are parsed to Float;
			// complex values such as "rotate(1rad)" are returned as-is.
			result = jQuery.css( tween.elem, tween.prop, "" );
			// Empty strings, null, undefined and "auto" are converted to 0.
			return !result || result === "auto" ? 0 : result;
		},
		set: function( tween ) {
			// Use step hook for back compat.
			// Use cssHook if its there.
			// Use .style if available and use plain properties where available.
			if ( jQuery.fx.step[ tween.prop ] ) {
				jQuery.fx.step[ tween.prop ]( tween );
			} else if ( tween.elem.style && ( tween.elem.style[ jQuery.cssProps[ tween.prop ] ] != null || jQuery.cssHooks[ tween.prop ] ) ) {
				jQuery.style( tween.elem, tween.prop, tween.now + tween.unit );
			} else {
				tween.elem[ tween.prop ] = tween.now;
			}
		}
	}
};

// Support: IE9
// Panic based approach to setting things on disconnected nodes
Tween.propHooks.scrollTop = Tween.propHooks.scrollLeft = {
	set: function( tween ) {
		if ( tween.elem.nodeType && tween.elem.parentNode ) {
			tween.elem[ tween.prop ] = tween.now;
		}
	}
};

jQuery.easing = {
	linear: function( p ) {
		return p;
	},
	swing: function( p ) {
		return 0.5 - Math.cos( p * Math.PI ) / 2;
	}
};

jQuery.fx = Tween.prototype.init;

// Back Compat <1.8 extension point
jQuery.fx.step = {};




var
	fxNow, timerId,
	rfxtypes = /^(?:toggle|show|hide)$/,
	rfxnum = new RegExp( "^(?:([+-])=|)(" + pnum + ")([a-z%]*)$", "i" ),
	rrun = /queueHooks$/,
	animationPrefilters = [ defaultPrefilter ],
	tweeners = {
		"*": [ function( prop, value ) {
			var tween = this.createTween( prop, value ),
				target = tween.cur(),
				parts = rfxnum.exec( value ),
				unit = parts && parts[ 3 ] || ( jQuery.cssNumber[ prop ] ? "" : "px" ),

				// Starting value computation is required for potential unit mismatches
				start = ( jQuery.cssNumber[ prop ] || unit !== "px" && +target ) &&
					rfxnum.exec( jQuery.css( tween.elem, prop ) ),
				scale = 1,
				maxIterations = 20;

			if ( start && start[ 3 ] !== unit ) {
				// Trust units reported by jQuery.css
				unit = unit || start[ 3 ];

				// Make sure we update the tween properties later on
				parts = parts || [];

				// Iteratively approximate from a nonzero starting point
				start = +target || 1;

				do {
					// If previous iteration zeroed out, double until we get *something*.
					// Use string for doubling so we don't accidentally see scale as unchanged below
					scale = scale || ".5";

					// Adjust and apply
					start = start / scale;
					jQuery.style( tween.elem, prop, start + unit );

				// Update scale, tolerating zero or NaN from tween.cur(),
				// break the loop if scale is unchanged or perfect, or if we've just had enough
				} while ( scale !== (scale = tween.cur() / target) && scale !== 1 && --maxIterations );
			}

			// Update tween properties
			if ( parts ) {
				start = tween.start = +start || +target || 0;
				tween.unit = unit;
				// If a +=/-= token was provided, we're doing a relative animation
				tween.end = parts[ 1 ] ?
					start + ( parts[ 1 ] + 1 ) * parts[ 2 ] :
					+parts[ 2 ];
			}

			return tween;
		} ]
	};

// Animations created synchronously will run synchronously
function createFxNow() {
	setTimeout(function() {
		fxNow = undefined;
	});
	return ( fxNow = jQuery.now() );
}

// Generate parameters to create a standard animation
function genFx( type, includeWidth ) {
	var which,
		i = 0,
		attrs = { height: type };

	// If we include width, step value is 1 to do all cssExpand values,
	// otherwise step value is 2 to skip over Left and Right
	includeWidth = includeWidth ? 1 : 0;
	for ( ; i < 4 ; i += 2 - includeWidth ) {
		which = cssExpand[ i ];
		attrs[ "margin" + which ] = attrs[ "padding" + which ] = type;
	}

	if ( includeWidth ) {
		attrs.opacity = attrs.width = type;
	}

	return attrs;
}

function createTween( value, prop, animation ) {
	var tween,
		collection = ( tweeners[ prop ] || [] ).concat( tweeners[ "*" ] ),
		index = 0,
		length = collection.length;
	for ( ; index < length; index++ ) {
		if ( (tween = collection[ index ].call( animation, prop, value )) ) {

			// We're done with this property
			return tween;
		}
	}
}

function defaultPrefilter( elem, props, opts ) {
	/* jshint validthis: true */
	var prop, value, toggle, tween, hooks, oldfire, display, checkDisplay,
		anim = this,
		orig = {},
		style = elem.style,
		hidden = elem.nodeType && isHidden( elem ),
		dataShow = data_priv.get( elem, "fxshow" );

	// Handle queue: false promises
	if ( !opts.queue ) {
		hooks = jQuery._queueHooks( elem, "fx" );
		if ( hooks.unqueued == null ) {
			hooks.unqueued = 0;
			oldfire = hooks.empty.fire;
			hooks.empty.fire = function() {
				if ( !hooks.unqueued ) {
					oldfire();
				}
			};
		}
		hooks.unqueued++;

		anim.always(function() {
			// Ensure the complete handler is called before this completes
			anim.always(function() {
				hooks.unqueued--;
				if ( !jQuery.queue( elem, "fx" ).length ) {
					hooks.empty.fire();
				}
			});
		});
	}

	// Height/width overflow pass
	if ( elem.nodeType === 1 && ( "height" in props || "width" in props ) ) {
		// Make sure that nothing sneaks out
		// Record all 3 overflow attributes because IE9-10 do not
		// change the overflow attribute when overflowX and
		// overflowY are set to the same value
		opts.overflow = [ style.overflow, style.overflowX, style.overflowY ];

		// Set display property to inline-block for height/width
		// animations on inline elements that are having width/height animated
		display = jQuery.css( elem, "display" );

		// Test default display if display is currently "none"
		checkDisplay = display === "none" ?
			data_priv.get( elem, "olddisplay" ) || defaultDisplay( elem.nodeName ) : display;

		if ( checkDisplay === "inline" && jQuery.css( elem, "float" ) === "none" ) {
			style.display = "inline-block";
		}
	}

	if ( opts.overflow ) {
		style.overflow = "hidden";
		anim.always(function() {
			style.overflow = opts.overflow[ 0 ];
			style.overflowX = opts.overflow[ 1 ];
			style.overflowY = opts.overflow[ 2 ];
		});
	}

	// show/hide pass
	for ( prop in props ) {
		value = props[ prop ];
		if ( rfxtypes.exec( value ) ) {
			delete props[ prop ];
			toggle = toggle || value === "toggle";
			if ( value === ( hidden ? "hide" : "show" ) ) {

				// If there is dataShow left over from a stopped hide or show and we are going to proceed with show, we should pretend to be hidden
				if ( value === "show" && dataShow && dataShow[ prop ] !== undefined ) {
					hidden = true;
				} else {
					continue;
				}
			}
			orig[ prop ] = dataShow && dataShow[ prop ] || jQuery.style( elem, prop );

		// Any non-fx value stops us from restoring the original display value
		} else {
			display = undefined;
		}
	}

	if ( !jQuery.isEmptyObject( orig ) ) {
		if ( dataShow ) {
			if ( "hidden" in dataShow ) {
				hidden = dataShow.hidden;
			}
		} else {
			dataShow = data_priv.access( elem, "fxshow", {} );
		}

		// Store state if its toggle - enables .stop().toggle() to "reverse"
		if ( toggle ) {
			dataShow.hidden = !hidden;
		}
		if ( hidden ) {
			jQuery( elem ).show();
		} else {
			anim.done(function() {
				jQuery( elem ).hide();
			});
		}
		anim.done(function() {
			var prop;

			data_priv.remove( elem, "fxshow" );
			for ( prop in orig ) {
				jQuery.style( elem, prop, orig[ prop ] );
			}
		});
		for ( prop in orig ) {
			tween = createTween( hidden ? dataShow[ prop ] : 0, prop, anim );

			if ( !( prop in dataShow ) ) {
				dataShow[ prop ] = tween.start;
				if ( hidden ) {
					tween.end = tween.start;
					tween.start = prop === "width" || prop === "height" ? 1 : 0;
				}
			}
		}

	// If this is a noop like .hide().hide(), restore an overwritten display value
	} else if ( (display === "none" ? defaultDisplay( elem.nodeName ) : display) === "inline" ) {
		style.display = display;
	}
}

function propFilter( props, specialEasing ) {
	var index, name, easing, value, hooks;

	// camelCase, specialEasing and expand cssHook pass
	for ( index in props ) {
		name = jQuery.camelCase( index );
		easing = specialEasing[ name ];
		value = props[ index ];
		if ( jQuery.isArray( value ) ) {
			easing = value[ 1 ];
			value = props[ index ] = value[ 0 ];
		}

		if ( index !== name ) {
			props[ name ] = value;
			delete props[ index ];
		}

		hooks = jQuery.cssHooks[ name ];
		if ( hooks && "expand" in hooks ) {
			value = hooks.expand( value );
			delete props[ name ];

			// Not quite $.extend, this won't overwrite existing keys.
			// Reusing 'index' because we have the correct "name"
			for ( index in value ) {
				if ( !( index in props ) ) {
					props[ index ] = value[ index ];
					specialEasing[ index ] = easing;
				}
			}
		} else {
			specialEasing[ name ] = easing;
		}
	}
}

function Animation( elem, properties, options ) {
	var result,
		stopped,
		index = 0,
		length = animationPrefilters.length,
		deferred = jQuery.Deferred().always( function() {
			// Don't match elem in the :animated selector
			delete tick.elem;
		}),
		tick = function() {
			if ( stopped ) {
				return false;
			}
			var currentTime = fxNow || createFxNow(),
				remaining = Math.max( 0, animation.startTime + animation.duration - currentTime ),
				// Support: Android 2.3
				// Archaic crash bug won't allow us to use `1 - ( 0.5 || 0 )` (#12497)
				temp = remaining / animation.duration || 0,
				percent = 1 - temp,
				index = 0,
				length = animation.tweens.length;

			for ( ; index < length ; index++ ) {
				animation.tweens[ index ].run( percent );
			}

			deferred.notifyWith( elem, [ animation, percent, remaining ]);

			if ( percent < 1 && length ) {
				return remaining;
			} else {
				deferred.resolveWith( elem, [ animation ] );
				return false;
			}
		},
		animation = deferred.promise({
			elem: elem,
			props: jQuery.extend( {}, properties ),
			opts: jQuery.extend( true, { specialEasing: {} }, options ),
			originalProperties: properties,
			originalOptions: options,
			startTime: fxNow || createFxNow(),
			duration: options.duration,
			tweens: [],
			createTween: function( prop, end ) {
				var tween = jQuery.Tween( elem, animation.opts, prop, end,
						animation.opts.specialEasing[ prop ] || animation.opts.easing );
				animation.tweens.push( tween );
				return tween;
			},
			stop: function( gotoEnd ) {
				var index = 0,
					// If we are going to the end, we want to run all the tweens
					// otherwise we skip this part
					length = gotoEnd ? animation.tweens.length : 0;
				if ( stopped ) {
					return this;
				}
				stopped = true;
				for ( ; index < length ; index++ ) {
					animation.tweens[ index ].run( 1 );
				}

				// Resolve when we played the last frame; otherwise, reject
				if ( gotoEnd ) {
					deferred.resolveWith( elem, [ animation, gotoEnd ] );
				} else {
					deferred.rejectWith( elem, [ animation, gotoEnd ] );
				}
				return this;
			}
		}),
		props = animation.props;

	propFilter( props, animation.opts.specialEasing );

	for ( ; index < length ; index++ ) {
		result = animationPrefilters[ index ].call( animation, elem, props, animation.opts );
		if ( result ) {
			return result;
		}
	}

	jQuery.map( props, createTween, animation );

	if ( jQuery.isFunction( animation.opts.start ) ) {
		animation.opts.start.call( elem, animation );
	}

	jQuery.fx.timer(
		jQuery.extend( tick, {
			elem: elem,
			anim: animation,
			queue: animation.opts.queue
		})
	);

	// attach callbacks from options
	return animation.progress( animation.opts.progress )
		.done( animation.opts.done, animation.opts.complete )
		.fail( animation.opts.fail )
		.always( animation.opts.always );
}

jQuery.Animation = jQuery.extend( Animation, {

	tweener: function( props, callback ) {
		if ( jQuery.isFunction( props ) ) {
			callback = props;
			props = [ "*" ];
		} else {
			props = props.split(" ");
		}

		var prop,
			index = 0,
			length = props.length;

		for ( ; index < length ; index++ ) {
			prop = props[ index ];
			tweeners[ prop ] = tweeners[ prop ] || [];
			tweeners[ prop ].unshift( callback );
		}
	},

	prefilter: function( callback, prepend ) {
		if ( prepend ) {
			animationPrefilters.unshift( callback );
		} else {
			animationPrefilters.push( callback );
		}
	}
});

jQuery.speed = function( speed, easing, fn ) {
	var opt = speed && typeof speed === "object" ? jQuery.extend( {}, speed ) : {
		complete: fn || !fn && easing ||
			jQuery.isFunction( speed ) && speed,
		duration: speed,
		easing: fn && easing || easing && !jQuery.isFunction( easing ) && easing
	};

	opt.duration = jQuery.fx.off ? 0 : typeof opt.duration === "number" ? opt.duration :
		opt.duration in jQuery.fx.speeds ? jQuery.fx.speeds[ opt.duration ] : jQuery.fx.speeds._default;

	// Normalize opt.queue - true/undefined/null -> "fx"
	if ( opt.queue == null || opt.queue === true ) {
		opt.queue = "fx";
	}

	// Queueing
	opt.old = opt.complete;

	opt.complete = function() {
		if ( jQuery.isFunction( opt.old ) ) {
			opt.old.call( this );
		}

		if ( opt.queue ) {
			jQuery.dequeue( this, opt.queue );
		}
	};

	return opt;
};

jQuery.fn.extend({
	fadeTo: function( speed, to, easing, callback ) {

		// Show any hidden elements after setting opacity to 0
		return this.filter( isHidden ).css( "opacity", 0 ).show()

			// Animate to the value specified
			.end().animate({ opacity: to }, speed, easing, callback );
	},
	animate: function( prop, speed, easing, callback ) {
		var empty = jQuery.isEmptyObject( prop ),
			optall = jQuery.speed( speed, easing, callback ),
			doAnimation = function() {
				// Operate on a copy of prop so per-property easing won't be lost
				var anim = Animation( this, jQuery.extend( {}, prop ), optall );

				// Empty animations, or finishing resolves immediately
				if ( empty || data_priv.get( this, "finish" ) ) {
					anim.stop( true );
				}
			};
			doAnimation.finish = doAnimation;

		return empty || optall.queue === false ?
			this.each( doAnimation ) :
			this.queue( optall.queue, doAnimation );
	},
	stop: function( type, clearQueue, gotoEnd ) {
		var stopQueue = function( hooks ) {
			var stop = hooks.stop;
			delete hooks.stop;
			stop( gotoEnd );
		};

		if ( typeof type !== "string" ) {
			gotoEnd = clearQueue;
			clearQueue = type;
			type = undefined;
		}
		if ( clearQueue && type !== false ) {
			this.queue( type || "fx", [] );
		}

		return this.each(function() {
			var dequeue = true,
				index = type != null && type + "queueHooks",
				timers = jQuery.timers,
				data = data_priv.get( this );

			if ( index ) {
				if ( data[ index ] && data[ index ].stop ) {
					stopQueue( data[ index ] );
				}
			} else {
				for ( index in data ) {
					if ( data[ index ] && data[ index ].stop && rrun.test( index ) ) {
						stopQueue( data[ index ] );
					}
				}
			}

			for ( index = timers.length; index--; ) {
				if ( timers[ index ].elem === this && (type == null || timers[ index ].queue === type) ) {
					timers[ index ].anim.stop( gotoEnd );
					dequeue = false;
					timers.splice( index, 1 );
				}
			}

			// Start the next in the queue if the last step wasn't forced.
			// Timers currently will call their complete callbacks, which
			// will dequeue but only if they were gotoEnd.
			if ( dequeue || !gotoEnd ) {
				jQuery.dequeue( this, type );
			}
		});
	},
	finish: function( type ) {
		if ( type !== false ) {
			type = type || "fx";
		}
		return this.each(function() {
			var index,
				data = data_priv.get( this ),
				queue = data[ type + "queue" ],
				hooks = data[ type + "queueHooks" ],
				timers = jQuery.timers,
				length = queue ? queue.length : 0;

			// Enable finishing flag on private data
			data.finish = true;

			// Empty the queue first
			jQuery.queue( this, type, [] );

			if ( hooks && hooks.stop ) {
				hooks.stop.call( this, true );
			}

			// Look for any active animations, and finish them
			for ( index = timers.length; index--; ) {
				if ( timers[ index ].elem === this && timers[ index ].queue === type ) {
					timers[ index ].anim.stop( true );
					timers.splice( index, 1 );
				}
			}

			// Look for any animations in the old queue and finish them
			for ( index = 0; index < length; index++ ) {
				if ( queue[ index ] && queue[ index ].finish ) {
					queue[ index ].finish.call( this );
				}
			}

			// Turn off finishing flag
			delete data.finish;
		});
	}
});

jQuery.each([ "toggle", "show", "hide" ], function( i, name ) {
	var cssFn = jQuery.fn[ name ];
	jQuery.fn[ name ] = function( speed, easing, callback ) {
		return speed == null || typeof speed === "boolean" ?
			cssFn.apply( this, arguments ) :
			this.animate( genFx( name, true ), speed, easing, callback );
	};
});

// Generate shortcuts for custom animations
jQuery.each({
	slideDown: genFx("show"),
	slideUp: genFx("hide"),
	slideToggle: genFx("toggle"),
	fadeIn: { opacity: "show" },
	fadeOut: { opacity: "hide" },
	fadeToggle: { opacity: "toggle" }
}, function( name, props ) {
	jQuery.fn[ name ] = function( speed, easing, callback ) {
		return this.animate( props, speed, easing, callback );
	};
});

jQuery.timers = [];
jQuery.fx.tick = function() {
	var timer,
		i = 0,
		timers = jQuery.timers;

	fxNow = jQuery.now();

	for ( ; i < timers.length; i++ ) {
		timer = timers[ i ];
		// Checks the timer has not already been removed
		if ( !timer() && timers[ i ] === timer ) {
			timers.splice( i--, 1 );
		}
	}

	if ( !timers.length ) {
		jQuery.fx.stop();
	}
	fxNow = undefined;
};

jQuery.fx.timer = function( timer ) {
	jQuery.timers.push( timer );
	if ( timer() ) {
		jQuery.fx.start();
	} else {
		jQuery.timers.pop();
	}
};

jQuery.fx.interval = 13;

jQuery.fx.start = function() {
	if ( !timerId ) {
		timerId = setInterval( jQuery.fx.tick, jQuery.fx.interval );
	}
};

jQuery.fx.stop = function() {
	clearInterval( timerId );
	timerId = null;
};

jQuery.fx.speeds = {
	slow: 600,
	fast: 200,
	// Default speed
	_default: 400
};


// Based off of the plugin by Clint Helfers, with permission.
// http://blindsignals.com/index.php/2009/07/jquery-delay/
jQuery.fn.delay = function( time, type ) {
	time = jQuery.fx ? jQuery.fx.speeds[ time ] || time : time;
	type = type || "fx";

	return this.queue( type, function( next, hooks ) {
		var timeout = setTimeout( next, time );
		hooks.stop = function() {
			clearTimeout( timeout );
		};
	});
};


(function() {
	var input = document.createElement( "input" ),
		select = document.createElement( "select" ),
		opt = select.appendChild( document.createElement( "option" ) );

	input.type = "checkbox";

	// Support: iOS<=5.1, Android<=4.2+
	// Default value for a checkbox should be "on"
	support.checkOn = input.value !== "";

	// Support: IE<=11+
	// Must access selectedIndex to make default options select
	support.optSelected = opt.selected;

	// Support: Android<=2.3
	// Options inside disabled selects are incorrectly marked as disabled
	select.disabled = true;
	support.optDisabled = !opt.disabled;

	// Support: IE<=11+
	// An input loses its value after becoming a radio
	input = document.createElement( "input" );
	input.value = "t";
	input.type = "radio";
	support.radioValue = input.value === "t";
})();


var nodeHook, boolHook,
	attrHandle = jQuery.expr.attrHandle;

jQuery.fn.extend({
	attr: function( name, value ) {
		return access( this, jQuery.attr, name, value, arguments.length > 1 );
	},

	removeAttr: function( name ) {
		return this.each(function() {
			jQuery.removeAttr( this, name );
		});
	}
});

jQuery.extend({
	attr: function( elem, name, value ) {
		var hooks, ret,
			nType = elem.nodeType;

		// don't get/set attributes on text, comment and attribute nodes
		if ( !elem || nType === 3 || nType === 8 || nType === 2 ) {
			return;
		}

		// Fallback to prop when attributes are not supported
		if ( typeof elem.getAttribute === strundefined ) {
			return jQuery.prop( elem, name, value );
		}

		// All attributes are lowercase
		// Grab necessary hook if one is defined
		if ( nType !== 1 || !jQuery.isXMLDoc( elem ) ) {
			name = name.toLowerCase();
			hooks = jQuery.attrHooks[ name ] ||
				( jQuery.expr.match.bool.test( name ) ? boolHook : nodeHook );
		}

		if ( value !== undefined ) {

			if ( value === null ) {
				jQuery.removeAttr( elem, name );

			} else if ( hooks && "set" in hooks && (ret = hooks.set( elem, value, name )) !== undefined ) {
				return ret;

			} else {
				elem.setAttribute( name, value + "" );
				return value;
			}

		} else if ( hooks && "get" in hooks && (ret = hooks.get( elem, name )) !== null ) {
			return ret;

		} else {
			ret = jQuery.find.attr( elem, name );

			// Non-existent attributes return null, we normalize to undefined
			return ret == null ?
				undefined :
				ret;
		}
	},

	removeAttr: function( elem, value ) {
		var name, propName,
			i = 0,
			attrNames = value && value.match( rnotwhite );

		if ( attrNames && elem.nodeType === 1 ) {
			while ( (name = attrNames[i++]) ) {
				propName = jQuery.propFix[ name ] || name;

				// Boolean attributes get special treatment (#10870)
				if ( jQuery.expr.match.bool.test( name ) ) {
					// Set corresponding property to false
					elem[ propName ] = false;
				}

				elem.removeAttribute( name );
			}
		}
	},

	attrHooks: {
		type: {
			set: function( elem, value ) {
				if ( !support.radioValue && value === "radio" &&
					jQuery.nodeName( elem, "input" ) ) {
					var val = elem.value;
					elem.setAttribute( "type", value );
					if ( val ) {
						elem.value = val;
					}
					return value;
				}
			}
		}
	}
});

// Hooks for boolean attributes
boolHook = {
	set: function( elem, value, name ) {
		if ( value === false ) {
			// Remove boolean attributes when set to false
			jQuery.removeAttr( elem, name );
		} else {
			elem.setAttribute( name, name );
		}
		return name;
	}
};
jQuery.each( jQuery.expr.match.bool.source.match( /\w+/g ), function( i, name ) {
	var getter = attrHandle[ name ] || jQuery.find.attr;

	attrHandle[ name ] = function( elem, name, isXML ) {
		var ret, handle;
		if ( !isXML ) {
			// Avoid an infinite loop by temporarily removing this function from the getter
			handle = attrHandle[ name ];
			attrHandle[ name ] = ret;
			ret = getter( elem, name, isXML ) != null ?
				name.toLowerCase() :
				null;
			attrHandle[ name ] = handle;
		}
		return ret;
	};
});




var rfocusable = /^(?:input|select|textarea|button)$/i;

jQuery.fn.extend({
	prop: function( name, value ) {
		return access( this, jQuery.prop, name, value, arguments.length > 1 );
	},

	removeProp: function( name ) {
		return this.each(function() {
			delete this[ jQuery.propFix[ name ] || name ];
		});
	}
});

jQuery.extend({
	propFix: {
		"for": "htmlFor",
		"class": "className"
	},

	prop: function( elem, name, value ) {
		var ret, hooks, notxml,
			nType = elem.nodeType;

		// Don't get/set properties on text, comment and attribute nodes
		if ( !elem || nType === 3 || nType === 8 || nType === 2 ) {
			return;
		}

		notxml = nType !== 1 || !jQuery.isXMLDoc( elem );

		if ( notxml ) {
			// Fix name and attach hooks
			name = jQuery.propFix[ name ] || name;
			hooks = jQuery.propHooks[ name ];
		}

		if ( value !== undefined ) {
			return hooks && "set" in hooks && (ret = hooks.set( elem, value, name )) !== undefined ?
				ret :
				( elem[ name ] = value );

		} else {
			return hooks && "get" in hooks && (ret = hooks.get( elem, name )) !== null ?
				ret :
				elem[ name ];
		}
	},

	propHooks: {
		tabIndex: {
			get: function( elem ) {
				return elem.hasAttribute( "tabindex" ) || rfocusable.test( elem.nodeName ) || elem.href ?
					elem.tabIndex :
					-1;
			}
		}
	}
});

if ( !support.optSelected ) {
	jQuery.propHooks.selected = {
		get: function( elem ) {
			var parent = elem.parentNode;
			if ( parent && parent.parentNode ) {
				parent.parentNode.selectedIndex;
			}
			return null;
		}
	};
}

jQuery.each([
	"tabIndex",
	"readOnly",
	"maxLength",
	"cellSpacing",
	"cellPadding",
	"rowSpan",
	"colSpan",
	"useMap",
	"frameBorder",
	"contentEditable"
], function() {
	jQuery.propFix[ this.toLowerCase() ] = this;
});




var rclass = /[\t\r\n\f]/g;

jQuery.fn.extend({
	addClass: function( value ) {
		var classes, elem, cur, clazz, j, finalValue,
			proceed = typeof value === "string" && value,
			i = 0,
			len = this.length;

		if ( jQuery.isFunction( value ) ) {
			return this.each(function( j ) {
				jQuery( this ).addClass( value.call( this, j, this.className ) );
			});
		}

		if ( proceed ) {
			// The disjunction here is for better compressibility (see removeClass)
			classes = ( value || "" ).match( rnotwhite ) || [];

			for ( ; i < len; i++ ) {
				elem = this[ i ];
				cur = elem.nodeType === 1 && ( elem.className ?
					( " " + elem.className + " " ).replace( rclass, " " ) :
					" "
				);

				if ( cur ) {
					j = 0;
					while ( (clazz = classes[j++]) ) {
						if ( cur.indexOf( " " + clazz + " " ) < 0 ) {
							cur += clazz + " ";
						}
					}

					// only assign if different to avoid unneeded rendering.
					finalValue = jQuery.trim( cur );
					if ( elem.className !== finalValue ) {
						elem.className = finalValue;
					}
				}
			}
		}

		return this;
	},

	removeClass: function( value ) {
		var classes, elem, cur, clazz, j, finalValue,
			proceed = arguments.length === 0 || typeof value === "string" && value,
			i = 0,
			len = this.length;

		if ( jQuery.isFunction( value ) ) {
			return this.each(function( j ) {
				jQuery( this ).removeClass( value.call( this, j, this.className ) );
			});
		}
		if ( proceed ) {
			classes = ( value || "" ).match( rnotwhite ) || [];

			for ( ; i < len; i++ ) {
				elem = this[ i ];
				// This expression is here for better compressibility (see addClass)
				cur = elem.nodeType === 1 && ( elem.className ?
					( " " + elem.className + " " ).replace( rclass, " " ) :
					""
				);

				if ( cur ) {
					j = 0;
					while ( (clazz = classes[j++]) ) {
						// Remove *all* instances
						while ( cur.indexOf( " " + clazz + " " ) >= 0 ) {
							cur = cur.replace( " " + clazz + " ", " " );
						}
					}

					// Only assign if different to avoid unneeded rendering.
					finalValue = value ? jQuery.trim( cur ) : "";
					if ( elem.className !== finalValue ) {
						elem.className = finalValue;
					}
				}
			}
		}

		return this;
	},

	toggleClass: function( value, stateVal ) {
		var type = typeof value;

		if ( typeof stateVal === "boolean" && type === "string" ) {
			return stateVal ? this.addClass( value ) : this.removeClass( value );
		}

		if ( jQuery.isFunction( value ) ) {
			return this.each(function( i ) {
				jQuery( this ).toggleClass( value.call(this, i, this.className, stateVal), stateVal );
			});
		}

		return this.each(function() {
			if ( type === "string" ) {
				// Toggle individual class names
				var className,
					i = 0,
					self = jQuery( this ),
					classNames = value.match( rnotwhite ) || [];

				while ( (className = classNames[ i++ ]) ) {
					// Check each className given, space separated list
					if ( self.hasClass( className ) ) {
						self.removeClass( className );
					} else {
						self.addClass( className );
					}
				}

			// Toggle whole class name
			} else if ( type === strundefined || type === "boolean" ) {
				if ( this.className ) {
					// store className if set
					data_priv.set( this, "__className__", this.className );
				}

				// If the element has a class name or if we're passed `false`,
				// then remove the whole classname (if there was one, the above saved it).
				// Otherwise bring back whatever was previously saved (if anything),
				// falling back to the empty string if nothing was stored.
				this.className = this.className || value === false ? "" : data_priv.get( this, "__className__" ) || "";
			}
		});
	},

	hasClass: function( selector ) {
		var className = " " + selector + " ",
			i = 0,
			l = this.length;
		for ( ; i < l; i++ ) {
			if ( this[i].nodeType === 1 && (" " + this[i].className + " ").replace(rclass, " ").indexOf( className ) >= 0 ) {
				return true;
			}
		}

		return false;
	}
});




var rreturn = /\r/g;

jQuery.fn.extend({
	val: function( value ) {
		var hooks, ret, isFunction,
			elem = this[0];

		if ( !arguments.length ) {
			if ( elem ) {
				hooks = jQuery.valHooks[ elem.type ] || jQuery.valHooks[ elem.nodeName.toLowerCase() ];

				if ( hooks && "get" in hooks && (ret = hooks.get( elem, "value" )) !== undefined ) {
					return ret;
				}

				ret = elem.value;

				return typeof ret === "string" ?
					// Handle most common string cases
					ret.replace(rreturn, "") :
					// Handle cases where value is null/undef or number
					ret == null ? "" : ret;
			}

			return;
		}

		isFunction = jQuery.isFunction( value );

		return this.each(function( i ) {
			var val;

			if ( this.nodeType !== 1 ) {
				return;
			}

			if ( isFunction ) {
				val = value.call( this, i, jQuery( this ).val() );
			} else {
				val = value;
			}

			// Treat null/undefined as ""; convert numbers to string
			if ( val == null ) {
				val = "";

			} else if ( typeof val === "number" ) {
				val += "";

			} else if ( jQuery.isArray( val ) ) {
				val = jQuery.map( val, function( value ) {
					return value == null ? "" : value + "";
				});
			}

			hooks = jQuery.valHooks[ this.type ] || jQuery.valHooks[ this.nodeName.toLowerCase() ];

			// If set returns undefined, fall back to normal setting
			if ( !hooks || !("set" in hooks) || hooks.set( this, val, "value" ) === undefined ) {
				this.value = val;
			}
		});
	}
});

jQuery.extend({
	valHooks: {
		option: {
			get: function( elem ) {
				var val = jQuery.find.attr( elem, "value" );
				return val != null ?
					val :
					// Support: IE10-11+
					// option.text throws exceptions (#14686, #14858)
					jQuery.trim( jQuery.text( elem ) );
			}
		},
		select: {
			get: function( elem ) {
				var value, option,
					options = elem.options,
					index = elem.selectedIndex,
					one = elem.type === "select-one" || index < 0,
					values = one ? null : [],
					max = one ? index + 1 : options.length,
					i = index < 0 ?
						max :
						one ? index : 0;

				// Loop through all the selected options
				for ( ; i < max; i++ ) {
					option = options[ i ];

					// IE6-9 doesn't update selected after form reset (#2551)
					if ( ( option.selected || i === index ) &&
							// Don't return options that are disabled or in a disabled optgroup
							( support.optDisabled ? !option.disabled : option.getAttribute( "disabled" ) === null ) &&
							( !option.parentNode.disabled || !jQuery.nodeName( option.parentNode, "optgroup" ) ) ) {

						// Get the specific value for the option
						value = jQuery( option ).val();

						// We don't need an array for one selects
						if ( one ) {
							return value;
						}

						// Multi-Selects return an array
						values.push( value );
					}
				}

				return values;
			},

			set: function( elem, value ) {
				var optionSet, option,
					options = elem.options,
					values = jQuery.makeArray( value ),
					i = options.length;

				while ( i-- ) {
					option = options[ i ];
					if ( (option.selected = jQuery.inArray( option.value, values ) >= 0) ) {
						optionSet = true;
					}
				}

				// Force browsers to behave consistently when non-matching value is set
				if ( !optionSet ) {
					elem.selectedIndex = -1;
				}
				return values;
			}
		}
	}
});

// Radios and checkboxes getter/setter
jQuery.each([ "radio", "checkbox" ], function() {
	jQuery.valHooks[ this ] = {
		set: function( elem, value ) {
			if ( jQuery.isArray( value ) ) {
				return ( elem.checked = jQuery.inArray( jQuery(elem).val(), value ) >= 0 );
			}
		}
	};
	if ( !support.checkOn ) {
		jQuery.valHooks[ this ].get = function( elem ) {
			return elem.getAttribute("value") === null ? "on" : elem.value;
		};
	}
});




// Return jQuery for attributes-only inclusion


jQuery.each( ("blur focus focusin focusout load resize scroll unload click dblclick " +
	"mousedown mouseup mousemove mouseover mouseout mouseenter mouseleave " +
	"change select submit keydown keypress keyup error contextmenu").split(" "), function( i, name ) {

	// Handle event binding
	jQuery.fn[ name ] = function( data, fn ) {
		return arguments.length > 0 ?
			this.on( name, null, data, fn ) :
			this.trigger( name );
	};
});

jQuery.fn.extend({
	hover: function( fnOver, fnOut ) {
		return this.mouseenter( fnOver ).mouseleave( fnOut || fnOver );
	},

	bind: function( types, data, fn ) {
		return this.on( types, null, data, fn );
	},
	unbind: function( types, fn ) {
		return this.off( types, null, fn );
	},

	delegate: function( selector, types, data, fn ) {
		return this.on( types, selector, data, fn );
	},
	undelegate: function( selector, types, fn ) {
		// ( namespace ) or ( selector, types [, fn] )
		return arguments.length === 1 ? this.off( selector, "**" ) : this.off( types, selector || "**", fn );
	}
});


var nonce = jQuery.now();

var rquery = (/\?/);



// Support: Android 2.3
// Workaround failure to string-cast null input
jQuery.parseJSON = function( data ) {
	return JSON.parse( data + "" );
};


// Cross-browser xml parsing
jQuery.parseXML = function( data ) {
	var xml, tmp;
	if ( !data || typeof data !== "string" ) {
		return null;
	}

	// Support: IE9
	try {
		tmp = new DOMParser();
		xml = tmp.parseFromString( data, "text/xml" );
	} catch ( e ) {
		xml = undefined;
	}

	if ( !xml || xml.getElementsByTagName( "parsererror" ).length ) {
		jQuery.error( "Invalid XML: " + data );
	}
	return xml;
};


var
	rhash = /#.*$/,
	rts = /([?&])_=[^&]*/,
	rheaders = /^(.*?):[ \t]*([^\r\n]*)$/mg,
	// #7653, #8125, #8152: local protocol detection
	rlocalProtocol = /^(?:about|app|app-storage|.+-extension|file|res|widget):$/,
	rnoContent = /^(?:GET|HEAD)$/,
	rprotocol = /^\/\//,
	rurl = /^([\w.+-]+:)(?:\/\/(?:[^\/?#]*@|)([^\/?#:]*)(?::(\d+)|)|)/,

	/* Prefilters
	 * 1) They are useful to introduce custom dataTypes (see ajax/jsonp.js for an example)
	 * 2) These are called:
	 *    - BEFORE asking for a transport
	 *    - AFTER param serialization (s.data is a string if s.processData is true)
	 * 3) key is the dataType
	 * 4) the catchall symbol "*" can be used
	 * 5) execution will start with transport dataType and THEN continue down to "*" if needed
	 */
	prefilters = {},

	/* Transports bindings
	 * 1) key is the dataType
	 * 2) the catchall symbol "*" can be used
	 * 3) selection will start with transport dataType and THEN go to "*" if needed
	 */
	transports = {},

	// Avoid comment-prolog char sequence (#10098); must appease lint and evade compression
	allTypes = "*/".concat( "*" ),

	// Document location
	ajaxLocation = window.location.href,

	// Segment location into parts
	ajaxLocParts = rurl.exec( ajaxLocation.toLowerCase() ) || [];

// Base "constructor" for jQuery.ajaxPrefilter and jQuery.ajaxTransport
function addToPrefiltersOrTransports( structure ) {

	// dataTypeExpression is optional and defaults to "*"
	return function( dataTypeExpression, func ) {

		if ( typeof dataTypeExpression !== "string" ) {
			func = dataTypeExpression;
			dataTypeExpression = "*";
		}

		var dataType,
			i = 0,
			dataTypes = dataTypeExpression.toLowerCase().match( rnotwhite ) || [];

		if ( jQuery.isFunction( func ) ) {
			// For each dataType in the dataTypeExpression
			while ( (dataType = dataTypes[i++]) ) {
				// Prepend if requested
				if ( dataType[0] === "+" ) {
					dataType = dataType.slice( 1 ) || "*";
					(structure[ dataType ] = structure[ dataType ] || []).unshift( func );

				// Otherwise append
				} else {
					(structure[ dataType ] = structure[ dataType ] || []).push( func );
				}
			}
		}
	};
}

// Base inspection function for prefilters and transports
function inspectPrefiltersOrTransports( structure, options, originalOptions, jqXHR ) {

	var inspected = {},
		seekingTransport = ( structure === transports );

	function inspect( dataType ) {
		var selected;
		inspected[ dataType ] = true;
		jQuery.each( structure[ dataType ] || [], function( _, prefilterOrFactory ) {
			var dataTypeOrTransport = prefilterOrFactory( options, originalOptions, jqXHR );
			if ( typeof dataTypeOrTransport === "string" && !seekingTransport && !inspected[ dataTypeOrTransport ] ) {
				options.dataTypes.unshift( dataTypeOrTransport );
				inspect( dataTypeOrTransport );
				return false;
			} else if ( seekingTransport ) {
				return !( selected = dataTypeOrTransport );
			}
		});
		return selected;
	}

	return inspect( options.dataTypes[ 0 ] ) || !inspected[ "*" ] && inspect( "*" );
}

// A special extend for ajax options
// that takes "flat" options (not to be deep extended)
// Fixes #9887
function ajaxExtend( target, src ) {
	var key, deep,
		flatOptions = jQuery.ajaxSettings.flatOptions || {};

	for ( key in src ) {
		if ( src[ key ] !== undefined ) {
			( flatOptions[ key ] ? target : ( deep || (deep = {}) ) )[ key ] = src[ key ];
		}
	}
	if ( deep ) {
		jQuery.extend( true, target, deep );
	}

	return target;
}

/* Handles responses to an ajax request:
 * - finds the right dataType (mediates between content-type and expected dataType)
 * - returns the corresponding response
 */
function ajaxHandleResponses( s, jqXHR, responses ) {

	var ct, type, finalDataType, firstDataType,
		contents = s.contents,
		dataTypes = s.dataTypes;

	// Remove auto dataType and get content-type in the process
	while ( dataTypes[ 0 ] === "*" ) {
		dataTypes.shift();
		if ( ct === undefined ) {
			ct = s.mimeType || jqXHR.getResponseHeader("Content-Type");
		}
	}

	// Check if we're dealing with a known content-type
	if ( ct ) {
		for ( type in contents ) {
			if ( contents[ type ] && contents[ type ].test( ct ) ) {
				dataTypes.unshift( type );
				break;
			}
		}
	}

	// Check to see if we have a response for the expected dataType
	if ( dataTypes[ 0 ] in responses ) {
		finalDataType = dataTypes[ 0 ];
	} else {
		// Try convertible dataTypes
		for ( type in responses ) {
			if ( !dataTypes[ 0 ] || s.converters[ type + " " + dataTypes[0] ] ) {
				finalDataType = type;
				break;
			}
			if ( !firstDataType ) {
				firstDataType = type;
			}
		}
		// Or just use first one
		finalDataType = finalDataType || firstDataType;
	}

	// If we found a dataType
	// We add the dataType to the list if needed
	// and return the corresponding response
	if ( finalDataType ) {
		if ( finalDataType !== dataTypes[ 0 ] ) {
			dataTypes.unshift( finalDataType );
		}
		return responses[ finalDataType ];
	}
}

/* Chain conversions given the request and the original response
 * Also sets the responseXXX fields on the jqXHR instance
 */
function ajaxConvert( s, response, jqXHR, isSuccess ) {
	var conv2, current, conv, tmp, prev,
		converters = {},
		// Work with a copy of dataTypes in case we need to modify it for conversion
		dataTypes = s.dataTypes.slice();

	// Create converters map with lowercased keys
	if ( dataTypes[ 1 ] ) {
		for ( conv in s.converters ) {
			converters[ conv.toLowerCase() ] = s.converters[ conv ];
		}
	}

	current = dataTypes.shift();

	// Convert to each sequential dataType
	while ( current ) {

		if ( s.responseFields[ current ] ) {
			jqXHR[ s.responseFields[ current ] ] = response;
		}

		// Apply the dataFilter if provided
		if ( !prev && isSuccess && s.dataFilter ) {
			response = s.dataFilter( response, s.dataType );
		}

		prev = current;
		current = dataTypes.shift();

		if ( current ) {

		// There's only work to do if current dataType is non-auto
			if ( current === "*" ) {

				current = prev;

			// Convert response if prev dataType is non-auto and differs from current
			} else if ( prev !== "*" && prev !== current ) {

				// Seek a direct converter
				conv = converters[ prev + " " + current ] || converters[ "* " + current ];

				// If none found, seek a pair
				if ( !conv ) {
					for ( conv2 in converters ) {

						// If conv2 outputs current
						tmp = conv2.split( " " );
						if ( tmp[ 1 ] === current ) {

							// If prev can be converted to accepted input
							conv = converters[ prev + " " + tmp[ 0 ] ] ||
								converters[ "* " + tmp[ 0 ] ];
							if ( conv ) {
								// Condense equivalence converters
								if ( conv === true ) {
									conv = converters[ conv2 ];

								// Otherwise, insert the intermediate dataType
								} else if ( converters[ conv2 ] !== true ) {
									current = tmp[ 0 ];
									dataTypes.unshift( tmp[ 1 ] );
								}
								break;
							}
						}
					}
				}

				// Apply converter (if not an equivalence)
				if ( conv !== true ) {

					// Unless errors are allowed to bubble, catch and return them
					if ( conv && s[ "throws" ] ) {
						response = conv( response );
					} else {
						try {
							response = conv( response );
						} catch ( e ) {
							return { state: "parsererror", error: conv ? e : "No conversion from " + prev + " to " + current };
						}
					}
				}
			}
		}
	}

	return { state: "success", data: response };
}

jQuery.extend({

	// Counter for holding the number of active queries
	active: 0,

	// Last-Modified header cache for next request
	lastModified: {},
	etag: {},

	ajaxSettings: {
		url: ajaxLocation,
		type: "GET",
		isLocal: rlocalProtocol.test( ajaxLocParts[ 1 ] ),
		global: true,
		processData: true,
		async: true,
		contentType: "application/x-www-form-urlencoded; charset=UTF-8",
		/*
		timeout: 0,
		data: null,
		dataType: null,
		username: null,
		password: null,
		cache: null,
		throws: false,
		traditional: false,
		headers: {},
		*/

		accepts: {
			"*": allTypes,
			text: "text/plain",
			html: "text/html",
			xml: "application/xml, text/xml",
			json: "application/json, text/javascript"
		},

		contents: {
			xml: /xml/,
			html: /html/,
			json: /json/
		},

		responseFields: {
			xml: "responseXML",
			text: "responseText",
			json: "responseJSON"
		},

		// Data converters
		// Keys separate source (or catchall "*") and destination types with a single space
		converters: {

			// Convert anything to text
			"* text": String,

			// Text to html (true = no transformation)
			"text html": true,

			// Evaluate text as a json expression
			"text json": jQuery.parseJSON,

			// Parse text as xml
			"text xml": jQuery.parseXML
		},

		// For options that shouldn't be deep extended:
		// you can add your own custom options here if
		// and when you create one that shouldn't be
		// deep extended (see ajaxExtend)
		flatOptions: {
			url: true,
			context: true
		}
	},

	// Creates a full fledged settings object into target
	// with both ajaxSettings and settings fields.
	// If target is omitted, writes into ajaxSettings.
	ajaxSetup: function( target, settings ) {
		return settings ?

			// Building a settings object
			ajaxExtend( ajaxExtend( target, jQuery.ajaxSettings ), settings ) :

			// Extending ajaxSettings
			ajaxExtend( jQuery.ajaxSettings, target );
	},

	ajaxPrefilter: addToPrefiltersOrTransports( prefilters ),
	ajaxTransport: addToPrefiltersOrTransports( transports ),

	// Main method
	ajax: function( url, options ) {

		// If url is an object, simulate pre-1.5 signature
		if ( typeof url === "object" ) {
			options = url;
			url = undefined;
		}

		// Force options to be an object
		options = options || {};

		var transport,
			// URL without anti-cache param
			cacheURL,
			// Response headers
			responseHeadersString,
			responseHeaders,
			// timeout handle
			timeoutTimer,
			// Cross-domain detection vars
			parts,
			// To know if global events are to be dispatched
			fireGlobals,
			// Loop variable
			i,
			// Create the final options object
			s = jQuery.ajaxSetup( {}, options ),
			// Callbacks context
			callbackContext = s.context || s,
			// Context for global events is callbackContext if it is a DOM node or jQuery collection
			globalEventContext = s.context && ( callbackContext.nodeType || callbackContext.jquery ) ?
				jQuery( callbackContext ) :
				jQuery.event,
			// Deferreds
			deferred = jQuery.Deferred(),
			completeDeferred = jQuery.Callbacks("once memory"),
			// Status-dependent callbacks
			statusCode = s.statusCode || {},
			// Headers (they are sent all at once)
			requestHeaders = {},
			requestHeadersNames = {},
			// The jqXHR state
			state = 0,
			// Default abort message
			strAbort = "canceled",
			// Fake xhr
			jqXHR = {
				readyState: 0,

				// Builds headers hashtable if needed
				getResponseHeader: function( key ) {
					var match;
					if ( state === 2 ) {
						if ( !responseHeaders ) {
							responseHeaders = {};
							while ( (match = rheaders.exec( responseHeadersString )) ) {
								responseHeaders[ match[1].toLowerCase() ] = match[ 2 ];
							}
						}
						match = responseHeaders[ key.toLowerCase() ];
					}
					return match == null ? null : match;
				},

				// Raw string
				getAllResponseHeaders: function() {
					return state === 2 ? responseHeadersString : null;
				},

				// Caches the header
				setRequestHeader: function( name, value ) {
					var lname = name.toLowerCase();
					if ( !state ) {
						name = requestHeadersNames[ lname ] = requestHeadersNames[ lname ] || name;
						requestHeaders[ name ] = value;
					}
					return this;
				},

				// Overrides response content-type header
				overrideMimeType: function( type ) {
					if ( !state ) {
						s.mimeType = type;
					}
					return this;
				},

				// Status-dependent callbacks
				statusCode: function( map ) {
					var code;
					if ( map ) {
						if ( state < 2 ) {
							for ( code in map ) {
								// Lazy-add the new callback in a way that preserves old ones
								statusCode[ code ] = [ statusCode[ code ], map[ code ] ];
							}
						} else {
							// Execute the appropriate callbacks
							jqXHR.always( map[ jqXHR.status ] );
						}
					}
					return this;
				},

				// Cancel the request
				abort: function( statusText ) {
					var finalText = statusText || strAbort;
					if ( transport ) {
						transport.abort( finalText );
					}
					done( 0, finalText );
					return this;
				}
			};

		// Attach deferreds
		deferred.promise( jqXHR ).complete = completeDeferred.add;
		jqXHR.success = jqXHR.done;
		jqXHR.error = jqXHR.fail;

		// Remove hash character (#7531: and string promotion)
		// Add protocol if not provided (prefilters might expect it)
		// Handle falsy url in the settings object (#10093: consistency with old signature)
		// We also use the url parameter if available
		s.url = ( ( url || s.url || ajaxLocation ) + "" ).replace( rhash, "" )
			.replace( rprotocol, ajaxLocParts[ 1 ] + "//" );

		// Alias method option to type as per ticket #12004
		s.type = options.method || options.type || s.method || s.type;

		// Extract dataTypes list
		s.dataTypes = jQuery.trim( s.dataType || "*" ).toLowerCase().match( rnotwhite ) || [ "" ];

		// A cross-domain request is in order when we have a protocol:host:port mismatch
		if ( s.crossDomain == null ) {
			parts = rurl.exec( s.url.toLowerCase() );
			s.crossDomain = !!( parts &&
				( parts[ 1 ] !== ajaxLocParts[ 1 ] || parts[ 2 ] !== ajaxLocParts[ 2 ] ||
					( parts[ 3 ] || ( parts[ 1 ] === "http:" ? "80" : "443" ) ) !==
						( ajaxLocParts[ 3 ] || ( ajaxLocParts[ 1 ] === "http:" ? "80" : "443" ) ) )
			);
		}

		// Convert data if not already a string
		if ( s.data && s.processData && typeof s.data !== "string" ) {
			s.data = jQuery.param( s.data, s.traditional );
		}

		// Apply prefilters
		inspectPrefiltersOrTransports( prefilters, s, options, jqXHR );

		// If request was aborted inside a prefilter, stop there
		if ( state === 2 ) {
			return jqXHR;
		}

		// We can fire global events as of now if asked to
		// Don't fire events if jQuery.event is undefined in an AMD-usage scenario (#15118)
		fireGlobals = jQuery.event && s.global;

		// Watch for a new set of requests
		if ( fireGlobals && jQuery.active++ === 0 ) {
			jQuery.event.trigger("ajaxStart");
		}

		// Uppercase the type
		s.type = s.type.toUpperCase();

		// Determine if request has content
		s.hasContent = !rnoContent.test( s.type );

		// Save the URL in case we're toying with the If-Modified-Since
		// and/or If-None-Match header later on
		cacheURL = s.url;

		// More options handling for requests with no content
		if ( !s.hasContent ) {

			// If data is available, append data to url
			if ( s.data ) {
				cacheURL = ( s.url += ( rquery.test( cacheURL ) ? "&" : "?" ) + s.data );
				// #9682: remove data so that it's not used in an eventual retry
				delete s.data;
			}

			// Add anti-cache in url if needed
			if ( s.cache === false ) {
				s.url = rts.test( cacheURL ) ?

					// If there is already a '_' parameter, set its value
					cacheURL.replace( rts, "$1_=" + nonce++ ) :

					// Otherwise add one to the end
					cacheURL + ( rquery.test( cacheURL ) ? "&" : "?" ) + "_=" + nonce++;
			}
		}

		// Set the If-Modified-Since and/or If-None-Match header, if in ifModified mode.
		if ( s.ifModified ) {
			if ( jQuery.lastModified[ cacheURL ] ) {
				jqXHR.setRequestHeader( "If-Modified-Since", jQuery.lastModified[ cacheURL ] );
			}
			if ( jQuery.etag[ cacheURL ] ) {
				jqXHR.setRequestHeader( "If-None-Match", jQuery.etag[ cacheURL ] );
			}
		}

		// Set the correct header, if data is being sent
		if ( s.data && s.hasContent && s.contentType !== false || options.contentType ) {
			jqXHR.setRequestHeader( "Content-Type", s.contentType );
		}

		// Set the Accepts header for the server, depending on the dataType
		jqXHR.setRequestHeader(
			"Accept",
			s.dataTypes[ 0 ] && s.accepts[ s.dataTypes[0] ] ?
				s.accepts[ s.dataTypes[0] ] + ( s.dataTypes[ 0 ] !== "*" ? ", " + allTypes + "; q=0.01" : "" ) :
				s.accepts[ "*" ]
		);

		// Check for headers option
		for ( i in s.headers ) {
			jqXHR.setRequestHeader( i, s.headers[ i ] );
		}

		// Allow custom headers/mimetypes and early abort
		if ( s.beforeSend && ( s.beforeSend.call( callbackContext, jqXHR, s ) === false || state === 2 ) ) {
			// Abort if not done already and return
			return jqXHR.abort();
		}

		// Aborting is no longer a cancellation
		strAbort = "abort";

		// Install callbacks on deferreds
		for ( i in { success: 1, error: 1, complete: 1 } ) {
			jqXHR[ i ]( s[ i ] );
		}

		// Get transport
		transport = inspectPrefiltersOrTransports( transports, s, options, jqXHR );

		// If no transport, we auto-abort
		if ( !transport ) {
			done( -1, "No Transport" );
		} else {
			jqXHR.readyState = 1;

			// Send global event
			if ( fireGlobals ) {
				globalEventContext.trigger( "ajaxSend", [ jqXHR, s ] );
			}
			// Timeout
			if ( s.async && s.timeout > 0 ) {
				timeoutTimer = setTimeout(function() {
					jqXHR.abort("timeout");
				}, s.timeout );
			}

			try {
				state = 1;
				transport.send( requestHeaders, done );
			} catch ( e ) {
				// Propagate exception as error if not done
				if ( state < 2 ) {
					done( -1, e );
				// Simply rethrow otherwise
				} else {
					throw e;
				}
			}
		}

		// Callback for when everything is done
		function done( status, nativeStatusText, responses, headers ) {
			var isSuccess, success, error, response, modified,
				statusText = nativeStatusText;

			// Called once
			if ( state === 2 ) {
				return;
			}

			// State is "done" now
			state = 2;

			// Clear timeout if it exists
			if ( timeoutTimer ) {
				clearTimeout( timeoutTimer );
			}

			// Dereference transport for early garbage collection
			// (no matter how long the jqXHR object will be used)
			transport = undefined;

			// Cache response headers
			responseHeadersString = headers || "";

			// Set readyState
			jqXHR.readyState = status > 0 ? 4 : 0;

			// Determine if successful
			isSuccess = status >= 200 && status < 300 || status === 304;

			// Get response data
			if ( responses ) {
				response = ajaxHandleResponses( s, jqXHR, responses );
			}

			// Convert no matter what (that way responseXXX fields are always set)
			response = ajaxConvert( s, response, jqXHR, isSuccess );

			// If successful, handle type chaining
			if ( isSuccess ) {

				// Set the If-Modified-Since and/or If-None-Match header, if in ifModified mode.
				if ( s.ifModified ) {
					modified = jqXHR.getResponseHeader("Last-Modified");
					if ( modified ) {
						jQuery.lastModified[ cacheURL ] = modified;
					}
					modified = jqXHR.getResponseHeader("etag");
					if ( modified ) {
						jQuery.etag[ cacheURL ] = modified;
					}
				}

				// if no content
				if ( status === 204 || s.type === "HEAD" ) {
					statusText = "nocontent";

				// if not modified
				} else if ( status === 304 ) {
					statusText = "notmodified";

				// If we have data, let's convert it
				} else {
					statusText = response.state;
					success = response.data;
					error = response.error;
					isSuccess = !error;
				}
			} else {
				// Extract error from statusText and normalize for non-aborts
				error = statusText;
				if ( status || !statusText ) {
					statusText = "error";
					if ( status < 0 ) {
						status = 0;
					}
				}
			}

			// Set data for the fake xhr object
			jqXHR.status = status;
			jqXHR.statusText = ( nativeStatusText || statusText ) + "";

			// Success/Error
			if ( isSuccess ) {
				deferred.resolveWith( callbackContext, [ success, statusText, jqXHR ] );
			} else {
				deferred.rejectWith( callbackContext, [ jqXHR, statusText, error ] );
			}

			// Status-dependent callbacks
			jqXHR.statusCode( statusCode );
			statusCode = undefined;

			if ( fireGlobals ) {
				globalEventContext.trigger( isSuccess ? "ajaxSuccess" : "ajaxError",
					[ jqXHR, s, isSuccess ? success : error ] );
			}

			// Complete
			completeDeferred.fireWith( callbackContext, [ jqXHR, statusText ] );

			if ( fireGlobals ) {
				globalEventContext.trigger( "ajaxComplete", [ jqXHR, s ] );
				// Handle the global AJAX counter
				if ( !( --jQuery.active ) ) {
					jQuery.event.trigger("ajaxStop");
				}
			}
		}

		return jqXHR;
	},

	getJSON: function( url, data, callback ) {
		return jQuery.get( url, data, callback, "json" );
	},

	getScript: function( url, callback ) {
		return jQuery.get( url, undefined, callback, "script" );
	}
});

jQuery.each( [ "get", "post" ], function( i, method ) {
	jQuery[ method ] = function( url, data, callback, type ) {
		// Shift arguments if data argument was omitted
		if ( jQuery.isFunction( data ) ) {
			type = type || callback;
			callback = data;
			data = undefined;
		}

		return jQuery.ajax({
			url: url,
			type: method,
			dataType: type,
			data: data,
			success: callback
		});
	};
});


jQuery._evalUrl = function( url ) {
	return jQuery.ajax({
		url: url,
		type: "GET",
		dataType: "script",
		async: false,
		global: false,
		"throws": true
	});
};


jQuery.fn.extend({
	wrapAll: function( html ) {
		var wrap;

		if ( jQuery.isFunction( html ) ) {
			return this.each(function( i ) {
				jQuery( this ).wrapAll( html.call(this, i) );
			});
		}

		if ( this[ 0 ] ) {

			// The elements to wrap the target around
			wrap = jQuery( html, this[ 0 ].ownerDocument ).eq( 0 ).clone( true );

			if ( this[ 0 ].parentNode ) {
				wrap.insertBefore( this[ 0 ] );
			}

			wrap.map(function() {
				var elem = this;

				while ( elem.firstElementChild ) {
					elem = elem.firstElementChild;
				}

				return elem;
			}).append( this );
		}

		return this;
	},

	wrapInner: function( html ) {
		if ( jQuery.isFunction( html ) ) {
			return this.each(function( i ) {
				jQuery( this ).wrapInner( html.call(this, i) );
			});
		}

		return this.each(function() {
			var self = jQuery( this ),
				contents = self.contents();

			if ( contents.length ) {
				contents.wrapAll( html );

			} else {
				self.append( html );
			}
		});
	},

	wrap: function( html ) {
		var isFunction = jQuery.isFunction( html );

		return this.each(function( i ) {
			jQuery( this ).wrapAll( isFunction ? html.call(this, i) : html );
		});
	},

	unwrap: function() {
		return this.parent().each(function() {
			if ( !jQuery.nodeName( this, "body" ) ) {
				jQuery( this ).replaceWith( this.childNodes );
			}
		}).end();
	}
});


jQuery.expr.filters.hidden = function( elem ) {
	// Support: Opera <= 12.12
	// Opera reports offsetWidths and offsetHeights less than zero on some elements
	return elem.offsetWidth <= 0 && elem.offsetHeight <= 0;
};
jQuery.expr.filters.visible = function( elem ) {
	return !jQuery.expr.filters.hidden( elem );
};




var r20 = /%20/g,
	rbracket = /\[\]$/,
	rCRLF = /\r?\n/g,
	rsubmitterTypes = /^(?:submit|button|image|reset|file)$/i,
	rsubmittable = /^(?:input|select|textarea|keygen)/i;

function buildParams( prefix, obj, traditional, add ) {
	var name;

	if ( jQuery.isArray( obj ) ) {
		// Serialize array item.
		jQuery.each( obj, function( i, v ) {
			if ( traditional || rbracket.test( prefix ) ) {
				// Treat each array item as a scalar.
				add( prefix, v );

			} else {
				// Item is non-scalar (array or object), encode its numeric index.
				buildParams( prefix + "[" + ( typeof v === "object" ? i : "" ) + "]", v, traditional, add );
			}
		});

	} else if ( !traditional && jQuery.type( obj ) === "object" ) {
		// Serialize object item.
		for ( name in obj ) {
			buildParams( prefix + "[" + name + "]", obj[ name ], traditional, add );
		}

	} else {
		// Serialize scalar item.
		add( prefix, obj );
	}
}

// Serialize an array of form elements or a set of
// key/values into a query string
jQuery.param = function( a, traditional ) {
	var prefix,
		s = [],
		add = function( key, value ) {
			// If value is a function, invoke it and return its value
			value = jQuery.isFunction( value ) ? value() : ( value == null ? "" : value );
			s[ s.length ] = encodeURIComponent( key ) + "=" + encodeURIComponent( value );
		};

	// Set traditional to true for jQuery <= 1.3.2 behavior.
	if ( traditional === undefined ) {
		traditional = jQuery.ajaxSettings && jQuery.ajaxSettings.traditional;
	}

	// If an array was passed in, assume that it is an array of form elements.
	if ( jQuery.isArray( a ) || ( a.jquery && !jQuery.isPlainObject( a ) ) ) {
		// Serialize the form elements
		jQuery.each( a, function() {
			add( this.name, this.value );
		});

	} else {
		// If traditional, encode the "old" way (the way 1.3.2 or older
		// did it), otherwise encode params recursively.
		for ( prefix in a ) {
			buildParams( prefix, a[ prefix ], traditional, add );
		}
	}

	// Return the resulting serialization
	return s.join( "&" ).replace( r20, "+" );
};

jQuery.fn.extend({
	serialize: function() {
		return jQuery.param( this.serializeArray() );
	},
	serializeArray: function() {
		return this.map(function() {
			// Can add propHook for "elements" to filter or add form elements
			var elements = jQuery.prop( this, "elements" );
			return elements ? jQuery.makeArray( elements ) : this;
		})
		.filter(function() {
			var type = this.type;

			// Use .is( ":disabled" ) so that fieldset[disabled] works
			return this.name && !jQuery( this ).is( ":disabled" ) &&
				rsubmittable.test( this.nodeName ) && !rsubmitterTypes.test( type ) &&
				( this.checked || !rcheckableType.test( type ) );
		})
		.map(function( i, elem ) {
			var val = jQuery( this ).val();

			return val == null ?
				null :
				jQuery.isArray( val ) ?
					jQuery.map( val, function( val ) {
						return { name: elem.name, value: val.replace( rCRLF, "\r\n" ) };
					}) :
					{ name: elem.name, value: val.replace( rCRLF, "\r\n" ) };
		}).get();
	}
});


jQuery.ajaxSettings.xhr = function() {
	try {
		return new XMLHttpRequest();
	} catch( e ) {}
};

var xhrId = 0,
	xhrCallbacks = {},
	xhrSuccessStatus = {
		// file protocol always yields status code 0, assume 200
		0: 200,
		// Support: IE9
		// #1450: sometimes IE returns 1223 when it should be 204
		1223: 204
	},
	xhrSupported = jQuery.ajaxSettings.xhr();

// Support: IE9
// Open requests must be manually aborted on unload (#5280)
// See https://support.microsoft.com/kb/2856746 for more info
if ( window.attachEvent ) {
	window.attachEvent( "onunload", function() {
		for ( var key in xhrCallbacks ) {
			xhrCallbacks[ key ]();
		}
	});
}

support.cors = !!xhrSupported && ( "withCredentials" in xhrSupported );
support.ajax = xhrSupported = !!xhrSupported;

jQuery.ajaxTransport(function( options ) {
	var callback;

	// Cross domain only allowed if supported through XMLHttpRequest
	if ( support.cors || xhrSupported && !options.crossDomain ) {
		return {
			send: function( headers, complete ) {
				var i,
					xhr = options.xhr(),
					id = ++xhrId;

				xhr.open( options.type, options.url, options.async, options.username, options.password );

				// Apply custom fields if provided
				if ( options.xhrFields ) {
					for ( i in options.xhrFields ) {
						xhr[ i ] = options.xhrFields[ i ];
					}
				}

				// Override mime type if needed
				if ( options.mimeType && xhr.overrideMimeType ) {
					xhr.overrideMimeType( options.mimeType );
				}

				// X-Requested-With header
				// For cross-domain requests, seeing as conditions for a preflight are
				// akin to a jigsaw puzzle, we simply never set it to be sure.
				// (it can always be set on a per-request basis or even using ajaxSetup)
				// For same-domain requests, won't change header if already provided.
				if ( !options.crossDomain && !headers["X-Requested-With"] ) {
					headers["X-Requested-With"] = "XMLHttpRequest";
				}

				// Set headers
				for ( i in headers ) {
					xhr.setRequestHeader( i, headers[ i ] );
				}

				// Callback
				callback = function( type ) {
					return function() {
						if ( callback ) {
							delete xhrCallbacks[ id ];
							callback = xhr.onload = xhr.onerror = null;

							if ( type === "abort" ) {
								xhr.abort();
							} else if ( type === "error" ) {
								complete(
									// file: protocol always yields status 0; see #8605, #14207
									xhr.status,
									xhr.statusText
								);
							} else {
								complete(
									xhrSuccessStatus[ xhr.status ] || xhr.status,
									xhr.statusText,
									// Support: IE9
									// Accessing binary-data responseText throws an exception
									// (#11426)
									typeof xhr.responseText === "string" ? {
										text: xhr.responseText
									} : undefined,
									xhr.getAllResponseHeaders()
								);
							}
						}
					};
				};

				// Listen to events
				xhr.onload = callback();
				xhr.onerror = callback("error");

				// Create the abort callback
				callback = xhrCallbacks[ id ] = callback("abort");

				try {
					// Do send the request (this may raise an exception)
					xhr.send( options.hasContent && options.data || null );
				} catch ( e ) {
					// #14683: Only rethrow if this hasn't been notified as an error yet
					if ( callback ) {
						throw e;
					}
				}
			},

			abort: function() {
				if ( callback ) {
					callback();
				}
			}
		};
	}
});




// Install script dataType
jQuery.ajaxSetup({
	accepts: {
		script: "text/javascript, application/javascript, application/ecmascript, application/x-ecmascript"
	},
	contents: {
		script: /(?:java|ecma)script/
	},
	converters: {
		"text script": function( text ) {
			jQuery.globalEval( text );
			return text;
		}
	}
});

// Handle cache's special case and crossDomain
jQuery.ajaxPrefilter( "script", function( s ) {
	if ( s.cache === undefined ) {
		s.cache = false;
	}
	if ( s.crossDomain ) {
		s.type = "GET";
	}
});

// Bind script tag hack transport
jQuery.ajaxTransport( "script", function( s ) {
	// This transport only deals with cross domain requests
	if ( s.crossDomain ) {
		var script, callback;
		return {
			send: function( _, complete ) {
				script = jQuery("<script>").prop({
					async: true,
					charset: s.scriptCharset,
					src: s.url
				}).on(
					"load error",
					callback = function( evt ) {
						script.remove();
						callback = null;
						if ( evt ) {
							complete( evt.type === "error" ? 404 : 200, evt.type );
						}
					}
				);
				document.head.appendChild( script[ 0 ] );
			},
			abort: function() {
				if ( callback ) {
					callback();
				}
			}
		};
	}
});




var oldCallbacks = [],
	rjsonp = /(=)\?(?=&|$)|\?\?/;

// Default jsonp settings
jQuery.ajaxSetup({
	jsonp: "callback",
	jsonpCallback: function() {
		var callback = oldCallbacks.pop() || ( jQuery.expando + "_" + ( nonce++ ) );
		this[ callback ] = true;
		return callback;
	}
});

// Detect, normalize options and install callbacks for jsonp requests
jQuery.ajaxPrefilter( "json jsonp", function( s, originalSettings, jqXHR ) {

	var callbackName, overwritten, responseContainer,
		jsonProp = s.jsonp !== false && ( rjsonp.test( s.url ) ?
			"url" :
			typeof s.data === "string" && !( s.contentType || "" ).indexOf("application/x-www-form-urlencoded") && rjsonp.test( s.data ) && "data"
		);

	// Handle iff the expected data type is "jsonp" or we have a parameter to set
	if ( jsonProp || s.dataTypes[ 0 ] === "jsonp" ) {

		// Get callback name, remembering preexisting value associated with it
		callbackName = s.jsonpCallback = jQuery.isFunction( s.jsonpCallback ) ?
			s.jsonpCallback() :
			s.jsonpCallback;

		// Insert callback into url or form data
		if ( jsonProp ) {
			s[ jsonProp ] = s[ jsonProp ].replace( rjsonp, "$1" + callbackName );
		} else if ( s.jsonp !== false ) {
			s.url += ( rquery.test( s.url ) ? "&" : "?" ) + s.jsonp + "=" + callbackName;
		}

		// Use data converter to retrieve json after script execution
		s.converters["script json"] = function() {
			if ( !responseContainer ) {
				jQuery.error( callbackName + " was not called" );
			}
			return responseContainer[ 0 ];
		};

		// force json dataType
		s.dataTypes[ 0 ] = "json";

		// Install callback
		overwritten = window[ callbackName ];
		window[ callbackName ] = function() {
			responseContainer = arguments;
		};

		// Clean-up function (fires after converters)
		jqXHR.always(function() {
			// Restore preexisting value
			window[ callbackName ] = overwritten;

			// Save back as free
			if ( s[ callbackName ] ) {
				// make sure that re-using the options doesn't screw things around
				s.jsonpCallback = originalSettings.jsonpCallback;

				// save the callback name for future use
				oldCallbacks.push( callbackName );
			}

			// Call if it was a function and we have a response
			if ( responseContainer && jQuery.isFunction( overwritten ) ) {
				overwritten( responseContainer[ 0 ] );
			}

			responseContainer = overwritten = undefined;
		});

		// Delegate to script
		return "script";
	}
});




// data: string of html
// context (optional): If specified, the fragment will be created in this context, defaults to document
// keepScripts (optional): If true, will include scripts passed in the html string
jQuery.parseHTML = function( data, context, keepScripts ) {
	if ( !data || typeof data !== "string" ) {
		return null;
	}
	if ( typeof context === "boolean" ) {
		keepScripts = context;
		context = false;
	}
	context = context || document;

	var parsed = rsingleTag.exec( data ),
		scripts = !keepScripts && [];

	// Single tag
	if ( parsed ) {
		return [ context.createElement( parsed[1] ) ];
	}

	parsed = jQuery.buildFragment( [ data ], context, scripts );

	if ( scripts && scripts.length ) {
		jQuery( scripts ).remove();
	}

	return jQuery.merge( [], parsed.childNodes );
};


// Keep a copy of the old load method
var _load = jQuery.fn.load;

/**
 * Load a url into a page
 */
jQuery.fn.load = function( url, params, callback ) {
	if ( typeof url !== "string" && _load ) {
		return _load.apply( this, arguments );
	}

	var selector, type, response,
		self = this,
		off = url.indexOf(" ");

	if ( off >= 0 ) {
		selector = jQuery.trim( url.slice( off ) );
		url = url.slice( 0, off );
	}

	// If it's a function
	if ( jQuery.isFunction( params ) ) {

		// We assume that it's the callback
		callback = params;
		params = undefined;

	// Otherwise, build a param string
	} else if ( params && typeof params === "object" ) {
		type = "POST";
	}

	// If we have elements to modify, make the request
	if ( self.length > 0 ) {
		jQuery.ajax({
			url: url,

			// if "type" variable is undefined, then "GET" method will be used
			type: type,
			dataType: "html",
			data: params
		}).done(function( responseText ) {

			// Save response for use in complete callback
			response = arguments;

			self.html( selector ?

				// If a selector was specified, locate the right elements in a dummy div
				// Exclude scripts to avoid IE 'Permission Denied' errors
				jQuery("<div>").append( jQuery.parseHTML( responseText ) ).find( selector ) :

				// Otherwise use the full result
				responseText );

		}).complete( callback && function( jqXHR, status ) {
			self.each( callback, response || [ jqXHR.responseText, status, jqXHR ] );
		});
	}

	return this;
};




// Attach a bunch of functions for handling common AJAX events
jQuery.each( [ "ajaxStart", "ajaxStop", "ajaxComplete", "ajaxError", "ajaxSuccess", "ajaxSend" ], function( i, type ) {
	jQuery.fn[ type ] = function( fn ) {
		return this.on( type, fn );
	};
});




jQuery.expr.filters.animated = function( elem ) {
	return jQuery.grep(jQuery.timers, function( fn ) {
		return elem === fn.elem;
	}).length;
};




var docElem = window.document.documentElement;

/**
 * Gets a window from an element
 */
function getWindow( elem ) {
	return jQuery.isWindow( elem ) ? elem : elem.nodeType === 9 && elem.defaultView;
}

jQuery.offset = {
	setOffset: function( elem, options, i ) {
		var curPosition, curLeft, curCSSTop, curTop, curOffset, curCSSLeft, calculatePosition,
			position = jQuery.css( elem, "position" ),
			curElem = jQuery( elem ),
			props = {};

		// Set position first, in-case top/left are set even on static elem
		if ( position === "static" ) {
			elem.style.position = "relative";
		}

		curOffset = curElem.offset();
		curCSSTop = jQuery.css( elem, "top" );
		curCSSLeft = jQuery.css( elem, "left" );
		calculatePosition = ( position === "absolute" || position === "fixed" ) &&
			( curCSSTop + curCSSLeft ).indexOf("auto") > -1;

		// Need to be able to calculate position if either
		// top or left is auto and position is either absolute or fixed
		if ( calculatePosition ) {
			curPosition = curElem.position();
			curTop = curPosition.top;
			curLeft = curPosition.left;

		} else {
			curTop = parseFloat( curCSSTop ) || 0;
			curLeft = parseFloat( curCSSLeft ) || 0;
		}

		if ( jQuery.isFunction( options ) ) {
			options = options.call( elem, i, curOffset );
		}

		if ( options.top != null ) {
			props.top = ( options.top - curOffset.top ) + curTop;
		}
		if ( options.left != null ) {
			props.left = ( options.left - curOffset.left ) + curLeft;
		}

		if ( "using" in options ) {
			options.using.call( elem, props );

		} else {
			curElem.css( props );
		}
	}
};

jQuery.fn.extend({
	offset: function( options ) {
		if ( arguments.length ) {
			return options === undefined ?
				this :
				this.each(function( i ) {
					jQuery.offset.setOffset( this, options, i );
				});
		}

		var docElem, win,
			elem = this[ 0 ],
			box = { top: 0, left: 0 },
			doc = elem && elem.ownerDocument;

		if ( !doc ) {
			return;
		}

		docElem = doc.documentElement;

		// Make sure it's not a disconnected DOM node
		if ( !jQuery.contains( docElem, elem ) ) {
			return box;
		}

		// Support: BlackBerry 5, iOS 3 (original iPhone)
		// If we don't have gBCR, just use 0,0 rather than error
		if ( typeof elem.getBoundingClientRect !== strundefined ) {
			box = elem.getBoundingClientRect();
		}
		win = getWindow( doc );
		return {
			top: box.top + win.pageYOffset - docElem.clientTop,
			left: box.left + win.pageXOffset - docElem.clientLeft
		};
	},

	position: function() {
		if ( !this[ 0 ] ) {
			return;
		}

		var offsetParent, offset,
			elem = this[ 0 ],
			parentOffset = { top: 0, left: 0 };

		// Fixed elements are offset from window (parentOffset = {top:0, left: 0}, because it is its only offset parent
		if ( jQuery.css( elem, "position" ) === "fixed" ) {
			// Assume getBoundingClientRect is there when computed position is fixed
			offset = elem.getBoundingClientRect();

		} else {
			// Get *real* offsetParent
			offsetParent = this.offsetParent();

			// Get correct offsets
			offset = this.offset();
			if ( !jQuery.nodeName( offsetParent[ 0 ], "html" ) ) {
				parentOffset = offsetParent.offset();
			}

			// Add offsetParent borders
			parentOffset.top += jQuery.css( offsetParent[ 0 ], "borderTopWidth", true );
			parentOffset.left += jQuery.css( offsetParent[ 0 ], "borderLeftWidth", true );
		}

		// Subtract parent offsets and element margins
		return {
			top: offset.top - parentOffset.top - jQuery.css( elem, "marginTop", true ),
			left: offset.left - parentOffset.left - jQuery.css( elem, "marginLeft", true )
		};
	},

	offsetParent: function() {
		return this.map(function() {
			var offsetParent = this.offsetParent || docElem;

			while ( offsetParent && ( !jQuery.nodeName( offsetParent, "html" ) && jQuery.css( offsetParent, "position" ) === "static" ) ) {
				offsetParent = offsetParent.offsetParent;
			}

			return offsetParent || docElem;
		});
	}
});

// Create scrollLeft and scrollTop methods
jQuery.each( { scrollLeft: "pageXOffset", scrollTop: "pageYOffset" }, function( method, prop ) {
	var top = "pageYOffset" === prop;

	jQuery.fn[ method ] = function( val ) {
		return access( this, function( elem, method, val ) {
			var win = getWindow( elem );

			if ( val === undefined ) {
				return win ? win[ prop ] : elem[ method ];
			}

			if ( win ) {
				win.scrollTo(
					!top ? val : window.pageXOffset,
					top ? val : window.pageYOffset
				);

			} else {
				elem[ method ] = val;
			}
		}, method, val, arguments.length, null );
	};
});

// Support: Safari<7+, Chrome<37+
// Add the top/left cssHooks using jQuery.fn.position
// Webkit bug: https://bugs.webkit.org/show_bug.cgi?id=29084
// Blink bug: https://code.google.com/p/chromium/issues/detail?id=229280
// getComputedStyle returns percent when specified for top/left/bottom/right;
// rather than make the css module depend on the offset module, just check for it here
jQuery.each( [ "top", "left" ], function( i, prop ) {
	jQuery.cssHooks[ prop ] = addGetHookIf( support.pixelPosition,
		function( elem, computed ) {
			if ( computed ) {
				computed = curCSS( elem, prop );
				// If curCSS returns percentage, fallback to offset
				return rnumnonpx.test( computed ) ?
					jQuery( elem ).position()[ prop ] + "px" :
					computed;
			}
		}
	);
});


// Create innerHeight, innerWidth, height, width, outerHeight and outerWidth methods
jQuery.each( { Height: "height", Width: "width" }, function( name, type ) {
	jQuery.each( { padding: "inner" + name, content: type, "": "outer" + name }, function( defaultExtra, funcName ) {
		// Margin is only for outerHeight, outerWidth
		jQuery.fn[ funcName ] = function( margin, value ) {
			var chainable = arguments.length && ( defaultExtra || typeof margin !== "boolean" ),
				extra = defaultExtra || ( margin === true || value === true ? "margin" : "border" );

			return access( this, function( elem, type, value ) {
				var doc;

				if ( jQuery.isWindow( elem ) ) {
					// As of 5/8/2012 this will yield incorrect results for Mobile Safari, but there
					// isn't a whole lot we can do. See pull request at this URL for discussion:
					// https://github.com/jquery/jquery/pull/764
					return elem.document.documentElement[ "client" + name ];
				}

				// Get document width or height
				if ( elem.nodeType === 9 ) {
					doc = elem.documentElement;

					// Either scroll[Width/Height] or offset[Width/Height] or client[Width/Height],
					// whichever is greatest
					return Math.max(
						elem.body[ "scroll" + name ], doc[ "scroll" + name ],
						elem.body[ "offset" + name ], doc[ "offset" + name ],
						doc[ "client" + name ]
					);
				}

				return value === undefined ?
					// Get width or height on the element, requesting but not forcing parseFloat
					jQuery.css( elem, type, extra ) :

					// Set width or height on the element
					jQuery.style( elem, type, value, extra );
			}, type, chainable ? margin : undefined, chainable, null );
		};
	});
});


// The number of elements contained in the matched element set
jQuery.fn.size = function() {
	return this.length;
};

jQuery.fn.andSelf = jQuery.fn.addBack;




// Register as a named AMD module, since jQuery can be concatenated with other
// files that may use define, but not via a proper concatenation script that
// understands anonymous AMD modules. A named AMD is safest and most robust
// way to register. Lowercase jquery is used because AMD module names are
// derived from file names, and jQuery is normally delivered in a lowercase
// file name. Do this after creating the global so that if an AMD module wants
// to call noConflict to hide this version of jQuery, it will work.

// Note that for maximum portability, libraries that are not jQuery should
// declare themselves as anonymous modules, and avoid setting a global if an
// AMD loader is present. jQuery is a special case. For more information, see
// https://github.com/jrburke/requirejs/wiki/Updating-existing-libraries#wiki-anon

if ( typeof define === "function" && define.amd ) {
	define( "jquery", [], function() {
		return jQuery;
	});
}




var
	// Map over jQuery in case of overwrite
	_jQuery = window.jQuery,

	// Map over the $ in case of overwrite
	_$ = window.$;

jQuery.noConflict = function( deep ) {
	if ( window.$ === jQuery ) {
		window.$ = _$;
	}

	if ( deep && window.jQuery === jQuery ) {
		window.jQuery = _jQuery;
	}

	return jQuery;
};

// Expose jQuery and $ identifiers, even in AMD
// (#7102#comment:10, https://github.com/jquery/jquery/pull/557)
// and CommonJS for browser emulators (#13566)
if ( typeof noGlobal === strundefined ) {
	window.jQuery = window.$ = jQuery;
}




return jQuery;

}));

/*! VelocityJS.org (1.0.0). (C) 2014 Julian Shapiro. MIT @license: en.wikipedia.org/wiki/MIT_License */

/*************************
   Velocity jQuery Shim
*************************/

/*! VelocityJS.org jQuery Shim (1.0.1). (C) 2014 The jQuery Foundation. MIT @license: en.wikipedia.org/wiki/MIT_License. */

/* This file contains the jQuery functions that Velocity relies on, thereby removing Velocity's dependency on a full copy of jQuery, and allowing it to work in any environment. */
/* These shimmed functions are only used if jQuery isn't present. If both this shim and jQuery are loaded, Velocity defaults to jQuery proper. */
/* Browser support: Using this shim instead of jQuery proper removes support for IE8. */

;(function (window) {
    /***************
         Setup
    ***************/

    /* If jQuery is already loaded, there's no point in loading this shim. */
    if (window.jQuery) {
        return;
    }

    /* jQuery base. */
    var $ = function (selector, context) {
        return new $.fn.init(selector, context);
    };

    /********************
       Private Methods
    ********************/

    /* jQuery */
    $.isWindow = function (obj) {
        /* jshint eqeqeq: false */
        return obj != null && obj == obj.window;
    };

    /* jQuery */
    $.type = function (obj) {
        if (obj == null) {
            return obj + "";
        }

        return typeof obj === "object" || typeof obj === "function" ?
            class2type[toString.call(obj)] || "object" :
            typeof obj;
    };

    /* jQuery */
    $.isArray = Array.isArray || function (obj) {
        return $.type(obj) === "array";
    };

    /* jQuery */
    function isArraylike (obj) {
        var length = obj.length,
            type = $.type(obj);

        if (type === "function" || $.isWindow(obj)) {
            return false;
        }

        if (obj.nodeType === 1 && length) {
            return true;
        }

        return type === "array" || length === 0 || typeof length === "number" && length > 0 && (length - 1) in obj;
    }

    /***************
       $ Methods
    ***************/

    /* jQuery: Support removed for IE<9. */
    $.isPlainObject = function (obj) {
        var key;

        if (!obj || $.type(obj) !== "object" || obj.nodeType || $.isWindow(obj)) {
            return false;
        }

        try {
            if (obj.constructor &&
                !hasOwn.call(obj, "constructor") &&
                !hasOwn.call(obj.constructor.prototype, "isPrototypeOf")) {
                return false;
            }
        } catch (e) {
            return false;
        }

        for (key in obj) {}

        return key === undefined || hasOwn.call(obj, key);
    };

    /* jQuery */
    $.each = function(obj, callback, args) {
        var value,
            i = 0,
            length = obj.length,
            isArray = isArraylike(obj);

        if (args) {
            if (isArray) {
                for (; i < length; i++) {
                    value = callback.apply(obj[i], args);

                    if (value === false) {
                        break;
                    }
                }
            } else {
                for (i in obj) {
                    value = callback.apply(obj[i], args);

                    if (value === false) {
                        break;
                    }
                }
            }

        } else {
            if (isArray) {
                for (; i < length; i++) {
                    value = callback.call(obj[i], i, obj[i]);

                    if (value === false) {
                        break;
                    }
                }
            } else {
                for (i in obj) {
                    value = callback.call(obj[i], i, obj[i]);

                    if (value === false) {
                        break;
                    }
                }
            }
        }

        return obj;
    };

    /* Custom */
    $.data = function (node, key, value) {
        /* $.getData() */
        if (value === undefined) {
            var id = node[$.expando],
                store = id && cache[id];

            if (key === undefined) {
                return store;
            } else if (store) {
                if (key in store) {
                    return store[key];
                }
            }
        /* $.setData() */
        } else if (key !== undefined) {
            var id = node[$.expando] || (node[$.expando] = ++$.uuid);

            cache[id] = cache[id] || {};
            cache[id][key] = value;

            return value;
        }
    };

    /* Custom */
    $.removeData = function (node, keys) {
        var id = node[$.expando],
            store = id && cache[id];

        if (store) {
            $.each(keys, function(_, key) {
                delete store[key];
            });
        }
    };

    /* jQuery */
    $.extend = function () {
        var src, copyIsArray, copy, name, options, clone,
            target = arguments[0] || {},
            i = 1,
            length = arguments.length,
            deep = false;

        if (typeof target === "boolean") {
            deep = target;

            target = arguments[i] || {};
            i++;
        }

        if (typeof target !== "object" && $.type(target) !== "function") {
            target = {};
        }

        if (i === length) {
            target = this;
            i--;
        }

        for (; i < length; i++) {
            if ((options = arguments[i]) != null) {
                for (name in options) {
                    src = target[name];
                    copy = options[name];

                    if (target === copy) {
                        continue;
                    }

                    if (deep && copy && ($.isPlainObject(copy) || (copyIsArray = $.isArray(copy)))) {
                        if (copyIsArray) {
                            copyIsArray = false;
                            clone = src && $.isArray(src) ? src : [];

                        } else {
                            clone = src && $.isPlainObject(src) ? src : {};
                        }

                        target[name] = $.extend(deep, clone, copy);

                    } else if (copy !== undefined) {
                        target[name] = copy;
                    }
                }
            }
        }

        return target;
    };

    /* jQuery 1.4.3 */
    $.queue = function (elem, type, data) {
        function $makeArray (arr, results) {
            var ret = results || [];

            if (arr != null) {
                if (isArraylike(Object(arr))) {
                    /* $.merge */
                    (function(first, second) {
                        var len = +second.length,
                            j = 0,
                            i = first.length;

                        while (j < len) {
                            first[i++] = second[j++];
                        }

                        if (len !== len) {
                            while (second[j] !== undefined) {
                                first[i++] = second[j++];
                            }
                        }

                        first.length = i;

                        return first;
                    })(ret, typeof arr === "string" ? [arr] : arr);
                } else {
                    [].push.call(ret, arr);
                }
            }

            return ret;
        }

        if (!elem) {
            return;
        }

        type = (type || "fx") + "queue";

        var q = $.data(elem, type);

        if (!data) {
            return q || [];
        }

        if (!q || $.isArray(data)) {
            q = $.data(elem, type, $makeArray(data));
        } else {
            q.push(data);
        }

        return q;
    };

    /* jQuery 1.4.3 */
    $.dequeue = function (elems, type) {
        /* Custom: Embed element iteration. */
        $.each(elems.nodeType ? [ elems ] : elems, function(i, elem) {
            type = type || "fx";

            var queue = $.queue(elem, type),
                fn = queue.shift();

            if (fn === "inprogress") {
                fn = queue.shift();
            }

            if (fn) {
                if (type === "fx") {
                    queue.unshift("inprogress");
                }

                fn.call(elem, function() {
                    $.dequeue(elem, type);
                });
            }
        });
    };

    /******************
       $.fn Methods
    ******************/

    /* jQuery */
    $.fn = $.prototype = {
        init: function (selector) {
            /* Just return the element wrapped inside an array; don't proceed with the actual jQuery node wrapping process. */
            if (selector.nodeType) {
                this[0] = selector;

                return this;
            } else {
                throw new Error("Not a DOM node.");
            }
        },

        offset: function () {
            /* jQuery altered code: Dropped disconnected DOM node checking. */
            var box = this[0].getBoundingClientRect ? this[0].getBoundingClientRect() : { top: 0, left: 0 };

            return {
                top: box.top + (window.pageYOffset || document.scrollTop  || 0)  - (document.clientTop  || 0),
                left: box.left + (window.pageXOffset || document.scrollLeft  || 0) - (document.clientLeft || 0)
            };
        },

        position: function () {
            /* jQuery */
            function offsetParent() {
                var offsetParent = this.offsetParent || document;

                while (offsetParent && (!offsetParent.nodeType.toLowerCase === "html" && offsetParent.style.position === "static")) {
                    offsetParent = offsetParent.offsetParent;
                }

                return offsetParent || document;
            }

            /* Zepto */
            var elem = this[0],
                offsetParent = offsetParent.apply(elem),
                offset = this.offset(),
                parentOffset = /^(?:body|html)$/i.test(offsetParent.nodeName) ? { top: 0, left: 0 } : $(offsetParent).offset()

            offset.top -= parseFloat(elem.style.marginTop) || 0;
            offset.left -= parseFloat(elem.style.marginLeft) || 0;

            if (offsetParent.style) {
                parentOffset.top += parseFloat(offsetParent.style.borderTopWidth) || 0
                parentOffset.left += parseFloat(offsetParent.style.borderLeftWidth) || 0
            }

            return {
                top: offset.top - parentOffset.top,
                left: offset.left - parentOffset.left
            };
        }
    };

    /**********************
       Private Variables
    **********************/

    /* For $.data() */
    var cache = {};
    $.expando = "velocity" + (new Date().getTime());
    $.uuid = 0;

    /* For $.queue() */
    var class2type = {},
        hasOwn = class2type.hasOwnProperty,
        toString = class2type.toString;

    var types = "Boolean Number String Function Array Date RegExp Object Error".split(" ");
    for (var i = 0; i < types.length; i++) {
        class2type["[object " + types[i] + "]"] = types[i].toLowerCase();
    }

    /* Makes $(node) possible, without having to call init. */
    $.fn.init.prototype = $.fn;

    /* Globalize Velocity onto the window, and assign its Utilities property. */
    window.Velocity = { Utilities: $ };
})(window);

/******************
    Velocity.js
******************/

;(function (factory) {
    /* CommonJS module. */
    if (typeof module === "object" && typeof module.exports === "object") {
        module.exports = factory();
    /* AMD module. */
    } else if (typeof define === "function" && define.amd) {
        define(factory);
    /* Browser globals. */
    } else {
        factory();
    }
}(function() {
return function (global, window, document, undefined) {

    /***************
        Summary
    ***************/

    /*
    - CSS: CSS stack that works independently from the rest of Velocity.
    - animate(): Core animation method that iterates over the targeted elements and queues the incoming call onto each element individually.
      - Pre-Queueing: Prepare the element for animation by instantiating its data cache and processing the call's options.
      - Queueing: The logic that runs once the call has reached its point of execution in the element's $.queue() stack.
                  Most logic is placed here to avoid risking it becoming stale (if the element's properties have changed).
      - Pushing: Consolidation of the tween data followed by its push onto the global in-progress calls container.
    - tick(): The single requestAnimationFrame loop responsible for tweening all in-progress calls.
    - completeCall(): Handles the cleanup process for each Velocity call.
    */

    /*********************
       Helper Functions
    *********************/

    /* IE detection. Gist: https://gist.github.com/julianshapiro/9098609 */
    var IE = (function() {
        if (document.documentMode) {
            return document.documentMode;
        } else {
            for (var i = 7; i > 4; i--) {
                var div = document.createElement("div");

                div.innerHTML = "<!--[if IE " + i + "]><span></span><![endif]-->";

                if (div.getElementsByTagName("span").length) {
                    div = null;

                    return i;
                }
            }
        }

        return undefined;
    })();

    /* rAF shim. Gist: https://gist.github.com/julianshapiro/9497513 */
    var rAFShim = (function() {
        var timeLast = 0;

        return window.webkitRequestAnimationFrame || window.mozRequestAnimationFrame || function(callback) {
            var timeCurrent = (new Date()).getTime(),
                timeDelta;

            /* Dynamically set delay on a per-tick basis to match 60fps. */
            /* Technique by Erik Moller. MIT license: https://gist.github.com/paulirish/1579671 */
            timeDelta = Math.max(0, 16 - (timeCurrent - timeLast));
            timeLast = timeCurrent + timeDelta;

            return setTimeout(function() { callback(timeCurrent + timeDelta); }, timeDelta);
        };
    })();

    /* Array compacting. Copyright Lo-Dash. MIT License: https://github.com/lodash/lodash/blob/master/LICENSE.txt */
    function compactSparseArray (array) {
        var index = -1,
            length = array ? array.length : 0,
            result = [];

        while (++index < length) {
            var value = array[index];

            if (value) {
                result.push(value);
            }
        }

        return result;
    }

    function sanitizeElements (elements) {
        /* Unwrap jQuery/Zepto objects. */
        if (Type.isWrapped(elements)) {
            elements = [].slice.call(elements);
        /* Wrap a single element in an array so that $.each() can iterate with the element instead of its node's children. */
        } else if (Type.isNode(elements)) {
            elements = [ elements ];
        }

        return elements;
    }

    var Type = {
        isString: function (variable) {
            return (typeof variable === "string");
        },
        isArray: Array.isArray || function (variable) {
            return Object.prototype.toString.call(variable) === "[object Array]";
        },
        isFunction: function (variable) {
            return Object.prototype.toString.call(variable) === "[object Function]";
        },
        isNode: function (variable) {
            return variable && variable.nodeType;
        },
        /* Copyright Martin Bohm. MIT License: https://gist.github.com/Tomalak/818a78a226a0738eaade */
        isNodeList: function (variable) {
            return typeof variable === "object" &&
                /^\[object (HTMLCollection|NodeList|Object)\]$/.test(Object.prototype.toString.call(variable)) &&
                variable.length !== undefined &&
                (variable.length === 0 || (typeof variable[0] === "object" && variable[0].nodeType > 0));
        },
        /* Determine if variable is a wrapped jQuery or Zepto element. */
        isWrapped: function (variable) {
            return variable && (variable.jquery || (window.Zepto && window.Zepto.zepto.isZ(variable)));
        },
        isSVG: function (variable) {
            return window.SVGElement && (variable instanceof window.SVGElement);
        },
        isEmptyObject: function (variable) {
            for (var name in variable) {
                return false;
            }

            return true;
        }
    };

    /*****************
       Dependencies
    *****************/

    var $,
        isJQuery = false;

    if (global.fn && global.fn.jquery) {
        $ = global;
        isJQuery = true;
    } else {
        $ = window.Velocity.Utilities;
    }

    if (IE <= 8 && !isJQuery) {
        throw new Error("Velocity: IE8 and below require jQuery to be loaded before Velocity.");
    } else if (IE <= 7) {
        /* Revert to jQuery's $.animate(), and lose Velocity's extra features. */
        jQuery.fn.velocity = jQuery.fn.animate;

        /* Now that $.fn.velocity is aliased, abort this Velocity declaration. */
        return;
    }

    /*****************
        Constants
    *****************/

    var DURATION_DEFAULT = 400,
        EASING_DEFAULT = "swing";

    /*************
        State
    *************/

    /* Note: The global object also doubles as a publicly-accessible data store for the purposes of unit testing. */
    /* Note: Alias the lowercase and uppercase variants of "velocity" to minimize user confusion due to the lowercase nature of the $.fn extension. */
    var Velocity = {
        /* Container for page-wide Velocity state data. */
        State: {
            /* Detect mobile devices to determine if mobileHA should be turned on. */
            isMobile: /Android|webOS|iPhone|iPad|iPod|BlackBerry|IEMobile|Opera Mini/i.test(navigator.userAgent),
            /* The mobileHA option's behavior changes on older Android devices (Gingerbread, versions 2.3.3-2.3.7). */
            isAndroid: /Android/i.test(navigator.userAgent),
            isGingerbread: /Android 2\.3\.[3-7]/i.test(navigator.userAgent),
            isChrome: window.chrome,
            isFirefox: /Firefox/i.test(navigator.userAgent),
            /* Create a cached element for re-use when checking for CSS property prefixes. */
            prefixElement: document.createElement("div"),
            /* Cache every prefix match to avoid repeating lookups. */
            prefixMatches: {},
            /* Cache the anchor used for animating window scrolling. */
            scrollAnchor: null,
            /* Cache the property names associated with the scroll anchor. */
            scrollPropertyLeft: null,
            scrollPropertyTop: null,
            /* Keep track of whether our RAF tick is running. */
            isTicking: false,
            /* Container for every in-progress call to Velocity. */
            calls: []
        },
        /* Velocity's custom CSS stack. Made global for unit testing. */
        CSS: { /* Defined below. */ },
        /* Defined by Velocity's optional jQuery shim. */
        Utilities: $,
        /* Container for the user's custom animation redirects that are referenced by name in place of a properties map object. */
        Redirects: { /* Manually registered by the user. */ },
        Easings: { /* Defined below. */ },
        /* Attempt to use ES6 Promises by default. Users can override this with a third-party promises library. */
        Promise: window.Promise,
        /* Page-wide option defaults, which can be overriden by the user. */
        defaults: {
            queue: "",
            duration: DURATION_DEFAULT,
            easing: EASING_DEFAULT,
            begin: undefined,
            complete: undefined,
            progress: undefined,
            display: undefined,
            visibility: undefined,
            loop: false,
            delay: false,
            mobileHA: true,
            /* Set to false to prevent property values from being cached between consecutive Velocity-initiated chain calls. */
            _cacheValues: true
        },
        /* A design goal of Velocity is to cache data wherever possible in order to avoid DOM requerying.
           Accordingly, each element has a data cache instantiated on it. */
        init: function (element) {
            $.data(element, "velocity", {
                /* Store whether this is an SVG element, since its properties are retrieved and updated differently than standard HTML elements. */
                isSVG: Type.isSVG(element),
                /* Keep track of whether the element is currently being animated by Velocity.
                   This is used to ensure that property values are not transferred between non-consecutive (stale) calls. */
                isAnimating: false,
                /* A reference to the element's live computedStyle object. Learn more here: https://developer.mozilla.org/en/docs/Web/API/window.getComputedStyle */
                computedStyle: null,
                /* Tween data is cached for each animation on the element so that data can be passed across calls --
                   in particular, end values are used as subsequent start values in consecutive Velocity calls. */
                tweensContainer: null,
                /* The full root property values of each CSS hook being animated on this element are cached so that:
                   1) Concurrently-animating hooks sharing the same root can have their root values' merged into one while tweening.
                   2) Post-hook-injection root values can be transferred over to consecutively chained Velocity calls as starting root values. */
                rootPropertyValueCache: {},
                /* A cache for transform updates, which must be manually flushed via CSS.flushTransformCache(). */
                transformCache: {}
            });
        },
        /* A parallel to jQuery's $.css(), used for getting/setting Velocity's hooked CSS properties. */
        hook: null, /* Defined below. */
        /* Velocity-wide animation time remapping for testing purposes. */
        mock: false,
        version: { major: 1, minor: 1, patch: 0 },
        /* Set to 1 or 2 (most verbose) to output debug info to console. */
        debug: false
    };

    /* Retrieve the appropriate scroll anchor and property name for the browser: https://developer.mozilla.org/en-US/docs/Web/API/Window.scrollY */
    if (window.pageYOffset !== undefined) {
        Velocity.State.scrollAnchor = window;
        Velocity.State.scrollPropertyLeft = "pageXOffset";
        Velocity.State.scrollPropertyTop = "pageYOffset";
    } else {
        Velocity.State.scrollAnchor = document.documentElement || document.body.parentNode || document.body;
        Velocity.State.scrollPropertyLeft = "scrollLeft";
        Velocity.State.scrollPropertyTop = "scrollTop";
    }

    /* Shorthand alias for jQuery's $.data() utility. */
    function Data (element) {
        /* Hardcode a reference to the plugin name. */
        var response = $.data(element, "velocity");

        /* jQuery <=1.4.2 returns null instead of undefined when no match is found. We normalize this behavior. */
        return response === null ? undefined : response;
    };

    /**************
        Easing
    **************/

    /* Step easing generator. */
    function generateStep (steps) {
        return function (p) {
            return Math.round(p * steps) * (1 / steps);
        };
    }

    /* Bezier curve function generator. Copyright Gaetan Renaudeau. MIT License: http://en.wikipedia.org/wiki/MIT_License */
    function generateBezier (mX1, mY1, mX2, mY2) {
        var NEWTON_ITERATIONS = 4,
            NEWTON_MIN_SLOPE = 0.001,
            SUBDIVISION_PRECISION = 0.0000001,
            SUBDIVISION_MAX_ITERATIONS = 10,
            kSplineTableSize = 11,
            kSampleStepSize = 1.0 / (kSplineTableSize - 1.0),
            float32ArraySupported = "Float32Array" in window;

        /* Must contain four arguments. */
        if (arguments.length !== 4) {
            return false;
        }

        /* Arguments must be numbers. */
        for (var i = 0; i < 4; ++i) {
            if (typeof arguments[i] !== "number" || isNaN(arguments[i]) || !isFinite(arguments[i])) {
                return false;
            }
        }

        /* X values must be in the [0, 1] range. */
        mX1 = Math.min(mX1, 1);
        mX2 = Math.min(mX2, 1);
        mX1 = Math.max(mX1, 0);
        mX2 = Math.max(mX2, 0);

        var mSampleValues = float32ArraySupported ? new Float32Array(kSplineTableSize) : new Array(kSplineTableSize);

        function A (aA1, aA2) { return 1.0 - 3.0 * aA2 + 3.0 * aA1; }
        function B (aA1, aA2) { return 3.0 * aA2 - 6.0 * aA1; }
        function C (aA1)      { return 3.0 * aA1; }

        function calcBezier (aT, aA1, aA2) {
            return ((A(aA1, aA2)*aT + B(aA1, aA2))*aT + C(aA1))*aT;
        }

        function getSlope (aT, aA1, aA2) {
            return 3.0 * A(aA1, aA2)*aT*aT + 2.0 * B(aA1, aA2) * aT + C(aA1);
        }

        function newtonRaphsonIterate (aX, aGuessT) {
            for (var i = 0; i < NEWTON_ITERATIONS; ++i) {
                var currentSlope = getSlope(aGuessT, mX1, mX2);

                if (currentSlope === 0.0) return aGuessT;

                var currentX = calcBezier(aGuessT, mX1, mX2) - aX;
                aGuessT -= currentX / currentSlope;
            }

            return aGuessT;
        }

        function calcSampleValues () {
            for (var i = 0; i < kSplineTableSize; ++i) {
                mSampleValues[i] = calcBezier(i * kSampleStepSize, mX1, mX2);
            }
        }

        function binarySubdivide (aX, aA, aB) {
            var currentX, currentT, i = 0;

            do {
                currentT = aA + (aB - aA) / 2.0;
                currentX = calcBezier(currentT, mX1, mX2) - aX;
                if (currentX > 0.0) {
                  aB = currentT;
                } else {
                  aA = currentT;
                }
            } while (Math.abs(currentX) > SUBDIVISION_PRECISION && ++i < SUBDIVISION_MAX_ITERATIONS);

            return currentT;
        }

        function getTForX (aX) {
            var intervalStart = 0.0,
                currentSample = 1,
                lastSample = kSplineTableSize - 1;

            for (; currentSample != lastSample && mSampleValues[currentSample] <= aX; ++currentSample) {
                intervalStart += kSampleStepSize;
            }

            --currentSample;

            var dist = (aX - mSampleValues[currentSample]) / (mSampleValues[currentSample+1] - mSampleValues[currentSample]),
                guessForT = intervalStart + dist * kSampleStepSize,
                initialSlope = getSlope(guessForT, mX1, mX2);

            if (initialSlope >= NEWTON_MIN_SLOPE) {
                return newtonRaphsonIterate(aX, guessForT);
            } else if (initialSlope == 0.0) {
                return guessForT;
            } else {
                return binarySubdivide(aX, intervalStart, intervalStart + kSampleStepSize);
            }
        }

        var _precomputed = false;

        function precompute() {
            _precomputed = true;
            if (mX1 != mY1 || mX2 != mY2) calcSampleValues();
        }

        var f = function (aX) {
            if (!_precomputed) precompute();
            if (mX1 === mY1 && mX2 === mY2) return aX;
            if (aX === 0) return 0;
            if (aX === 1) return 1;

            return calcBezier(getTForX(aX), mY1, mY2);
        };

        f.getControlPoints = function() { return [{ x: mX1, y: mY1 }, { x: mX2, y: mY2 }]; };

        var str = "generateBezier(" + [mX1, mY1, mX2, mY2] + ")";
        f.toString = function () { return str; };

        return f;
    }

    /* Runge-Kutta spring physics function generator. Adapted from Framer.js, copyright Koen Bok. MIT License: http://en.wikipedia.org/wiki/MIT_License */
    /* Given a tension, friction, and duration, a simulation at 60FPS will first run without a defined duration in order to calculate the full path. A second pass
       then adjusts the time delta -- using the relation between actual time and duration -- to calculate the path for the duration-constrained animation. */
    var generateSpringRK4 = (function () {
        function springAccelerationForState (state) {
            return (-state.tension * state.x) - (state.friction * state.v);
        }

        function springEvaluateStateWithDerivative (initialState, dt, derivative) {
            var state = {
                x: initialState.x + derivative.dx * dt,
                v: initialState.v + derivative.dv * dt,
                tension: initialState.tension,
                friction: initialState.friction
            };

            return { dx: state.v, dv: springAccelerationForState(state) };
        }

        function springIntegrateState (state, dt) {
            var a = {
                    dx: state.v,
                    dv: springAccelerationForState(state)
                },
                b = springEvaluateStateWithDerivative(state, dt * 0.5, a),
                c = springEvaluateStateWithDerivative(state, dt * 0.5, b),
                d = springEvaluateStateWithDerivative(state, dt, c),
                dxdt = 1.0 / 6.0 * (a.dx + 2.0 * (b.dx + c.dx) + d.dx),
                dvdt = 1.0 / 6.0 * (a.dv + 2.0 * (b.dv + c.dv) + d.dv);

            state.x = state.x + dxdt * dt;
            state.v = state.v + dvdt * dt;

            return state;
        }

        return function springRK4Factory (tension, friction, duration) {

            var initState = {
                    x: -1,
                    v: 0,
                    tension: null,
                    friction: null
                },
                path = [0],
                time_lapsed = 0,
                tolerance = 1 / 10000,
                DT = 16 / 1000,
                have_duration, dt, last_state;

            tension = parseFloat(tension) || 500;
            friction = parseFloat(friction) || 20;
            duration = duration || null;

            initState.tension = tension;
            initState.friction = friction;

            have_duration = duration !== null;

            /* Calculate the actual time it takes for this animation to complete with the provided conditions. */
            if (have_duration) {
                /* Run the simulation without a duration. */
                time_lapsed = springRK4Factory(tension, friction);
                /* Compute the adjusted time delta. */
                dt = time_lapsed / duration * DT;
            } else {
                dt = DT;
            }

            while (true) {
                /* Next/step function .*/
                last_state = springIntegrateState(last_state || initState, dt);
                /* Store the position. */
                path.push(1 + last_state.x);
                time_lapsed += 16;
                /* If the change threshold is reached, break. */
                if (!(Math.abs(last_state.x) > tolerance && Math.abs(last_state.v) > tolerance)) {
                    break;
                }
            }

            /* If duration is not defined, return the actual time required for completing this animation. Otherwise, return a closure that holds the
               computed path and returns a snapshot of the position according to a given percentComplete. */
            return !have_duration ? time_lapsed : function(percentComplete) { return path[ (percentComplete * (path.length - 1)) | 0 ]; };
        };
    }());

    /* jQuery easings. */
    Velocity.Easings = {
        linear: function(p) { return p; },
        swing: function(p) { return 0.5 - Math.cos( p * Math.PI ) / 2 },
        /* Bonus "spring" easing, which is a less exaggerated version of easeInOutElastic. */
        spring: function(p) { return 1 - (Math.cos(p * 4.5 * Math.PI) * Math.exp(-p * 6)); }
    };

    /* CSS3 and Robert Penner easings. */
    $.each(
        [
            [ "ease", [ 0.25, 0.1, 0.25, 1.0 ] ],
            [ "ease-in", [ 0.42, 0.0, 1.00, 1.0 ] ],
            [ "ease-out", [ 0.00, 0.0, 0.58, 1.0 ] ],
            [ "ease-in-out", [ 0.42, 0.0, 0.58, 1.0 ] ],
            [ "easeInSine", [ 0.47, 0, 0.745, 0.715 ] ],
            [ "easeOutSine", [ 0.39, 0.575, 0.565, 1 ] ],
            [ "easeInOutSine", [ 0.445, 0.05, 0.55, 0.95 ] ],
            [ "easeInQuad", [ 0.55, 0.085, 0.68, 0.53 ] ],
            [ "easeOutQuad", [ 0.25, 0.46, 0.45, 0.94 ] ],
            [ "easeInOutQuad", [ 0.455, 0.03, 0.515, 0.955 ] ],
            [ "easeInCubic", [ 0.55, 0.055, 0.675, 0.19 ] ],
            [ "easeOutCubic", [ 0.215, 0.61, 0.355, 1 ] ],
            [ "easeInOutCubic", [ 0.645, 0.045, 0.355, 1 ] ],
            [ "easeInQuart", [ 0.895, 0.03, 0.685, 0.22 ] ],
            [ "easeOutQuart", [ 0.165, 0.84, 0.44, 1 ] ],
            [ "easeInOutQuart", [ 0.77, 0, 0.175, 1 ] ],
            [ "easeInQuint", [ 0.755, 0.05, 0.855, 0.06 ] ],
            [ "easeOutQuint", [ 0.23, 1, 0.32, 1 ] ],
            [ "easeInOutQuint", [ 0.86, 0, 0.07, 1 ] ],
            [ "easeInExpo", [ 0.95, 0.05, 0.795, 0.035 ] ],
            [ "easeOutExpo", [ 0.19, 1, 0.22, 1 ] ],
            [ "easeInOutExpo", [ 1, 0, 0, 1 ] ],
            [ "easeInCirc", [ 0.6, 0.04, 0.98, 0.335 ] ],
            [ "easeOutCirc", [ 0.075, 0.82, 0.165, 1 ] ],
            [ "easeInOutCirc", [ 0.785, 0.135, 0.15, 0.86 ] ]
        ], function(i, easingArray) {
            Velocity.Easings[easingArray[0]] = generateBezier.apply(null, easingArray[1]);
        });

    /* Determine the appropriate easing type given an easing input. */
    function getEasing(value, duration) {
        var easing = value;

        /* The easing option can either be a string that references a pre-registered easing,
           or it can be a two-/four-item array of integers to be converted into a bezier/spring function. */
        if (Type.isString(value)) {
            /* Ensure that the easing has been assigned to jQuery's Velocity.Easings object. */
            if (!Velocity.Easings[value]) {
                easing = false;
            }
        } else if (Type.isArray(value) && value.length === 1) {
            easing = generateStep.apply(null, value);
        } else if (Type.isArray(value) && value.length === 2) {
            /* springRK4 must be passed the animation's duration. */
            /* Note: If the springRK4 array contains non-numbers, generateSpringRK4() returns an easing
               function generated with default tension and friction values. */
            easing = generateSpringRK4.apply(null, value.concat([ duration ]));
        } else if (Type.isArray(value) && value.length === 4) {
            /* Note: If the bezier array contains non-numbers, generateBezier() returns false. */
            easing = generateBezier.apply(null, value);
        } else {
            easing = false;
        }

        /* Revert to the Velocity-wide default easing type, or fall back to "swing" (which is also jQuery's default)
           if the Velocity-wide default has been incorrectly modified. */
        if (easing === false) {
            if (Velocity.Easings[Velocity.defaults.easing]) {
                easing = Velocity.defaults.easing;
            } else {
                easing = EASING_DEFAULT;
            }
        }

        return easing;
    }

    /*****************
        CSS Stack
    *****************/

    /* The CSS object is a highly condensed and performant CSS stack that fully replaces jQuery's.
       It handles the validation, getting, and setting of both standard CSS properties and CSS property hooks. */
    /* Note: A "CSS" shorthand is aliased so that our code is easier to read. */
    var CSS = Velocity.CSS = {

        /*************
            RegEx
        *************/

        RegEx: {
            isHex: /^#([A-f\d]{3}){1,2}$/i,
            /* Unwrap a property value's surrounding text, e.g. "rgba(4, 3, 2, 1)" ==> "4, 3, 2, 1" and "rect(4px 3px 2px 1px)" ==> "4px 3px 2px 1px". */
            valueUnwrap: /^[A-z]+\((.*)\)$/i,
            wrappedValueAlreadyExtracted: /[0-9.]+ [0-9.]+ [0-9.]+( [0-9.]+)?/,
            /* Split a multi-value property into an array of subvalues, e.g. "rgba(4, 3, 2, 1) 4px 3px 2px 1px" ==> [ "rgba(4, 3, 2, 1)", "4px", "3px", "2px", "1px" ]. */
            valueSplit: /([A-z]+\(.+\))|(([A-z0-9#-.]+?)(?=\s|$))/ig
        },

        /************
            Lists
        ************/

        Lists: {
            colors: [ "fill", "stroke", "stopColor", "color", "backgroundColor", "borderColor", "borderTopColor", "borderRightColor", "borderBottomColor", "borderLeftColor", "outlineColor" ],
            transformsBase: [ "translateX", "translateY", "scale", "scaleX", "scaleY", "skewX", "skewY", "rotateZ" ],
            transforms3D: [ "transformPerspective", "translateZ", "scaleZ", "rotateX", "rotateY" ]
        },

        /************
            Hooks
        ************/

        /* Hooks allow a subproperty (e.g. "boxShadowBlur") of a compound-value CSS property
           (e.g. "boxShadow: X Y Blur Spread Color") to be animated as if it were a discrete property. */
        /* Note: Beyond enabling fine-grained property animation, hooking is necessary since Velocity only
           tweens properties with single numeric values; unlike CSS transitions, Velocity does not interpolate compound-values. */
        Hooks: {
            /********************
                Registration
            ********************/

            /* Templates are a concise way of indicating which subproperties must be individually registered for each compound-value CSS property. */
            /* Each template consists of the compound-value's base name, its constituent subproperty names, and those subproperties' default values. */
            templates: {
                "textShadow": [ "Color X Y Blur", "black 0px 0px 0px" ],
                /* Todo: Add support for inset boxShadows. (webkit places it last whereas IE places it first.) */
                "boxShadow": [ "Color X Y Blur Spread", "black 0px 0px 0px 0px" ],
                "clip": [ "Top Right Bottom Left", "0px 0px 0px 0px" ],
                "backgroundPosition": [ "X Y", "0% 0%" ],
                "transformOrigin": [ "X Y Z", "50% 50% 0px" ],
                "perspectiveOrigin": [ "X Y", "50% 50%" ]
            },

            /* A "registered" hook is one that has been converted from its template form into a live,
               tweenable property. It contains data to associate it with its root property. */
            registered: {
                /* Note: A registered hook looks like this ==> textShadowBlur: [ "textShadow", 3 ],
                   which consists of the subproperty's name, the associated root property's name,
                   and the subproperty's position in the root's value. */
            },
            /* Convert the templates into individual hooks then append them to the registered object above. */
            register: function () {
                /* Color hooks registration: Colors are defaulted to white -- as opposed to black -- since colors that are
                   currently set to "transparent" default to their respective template below when color-animated,
                   and white is typically a closer match to transparent than black is. An exception is made for text ("color"),
                   which is almost always set closer to black than white. */
                for (var i = 0; i < CSS.Lists.colors.length; i++) {
                    var rgbComponents = (CSS.Lists.colors[i] === "color") ? "0 0 0 1" : "255 255 255 1";
                    CSS.Hooks.templates[CSS.Lists.colors[i]] = [ "Red Green Blue Alpha", rgbComponents ];
                }

                var rootProperty,
                    hookTemplate,
                    hookNames;

                /* In IE, color values inside compound-value properties are positioned at the end the value instead of at the beginning.
                   Thus, we re-arrange the templates accordingly. */
                if (IE) {
                    for (rootProperty in CSS.Hooks.templates) {
                        hookTemplate = CSS.Hooks.templates[rootProperty];
                        hookNames = hookTemplate[0].split(" ");

                        var defaultValues = hookTemplate[1].match(CSS.RegEx.valueSplit);

                        if (hookNames[0] === "Color") {
                            /* Reposition both the hook's name and its default value to the end of their respective strings. */
                            hookNames.push(hookNames.shift());
                            defaultValues.push(defaultValues.shift());

                            /* Replace the existing template for the hook's root property. */
                            CSS.Hooks.templates[rootProperty] = [ hookNames.join(" "), defaultValues.join(" ") ];
                        }
                    }
                }

                /* Hook registration. */
                for (rootProperty in CSS.Hooks.templates) {
                    hookTemplate = CSS.Hooks.templates[rootProperty];
                    hookNames = hookTemplate[0].split(" ");

                    for (var i in hookNames) {
                        var fullHookName = rootProperty + hookNames[i],
                            hookPosition = i;

                        /* For each hook, register its full name (e.g. textShadowBlur) with its root property (e.g. textShadow)
                           and the hook's position in its template's default value string. */
                        CSS.Hooks.registered[fullHookName] = [ rootProperty, hookPosition ];
                    }
                }
            },

            /*****************************
               Injection and Extraction
            *****************************/

            /* Look up the root property associated with the hook (e.g. return "textShadow" for "textShadowBlur"). */
            /* Since a hook cannot be set directly (the browser won't recognize it), style updating for hooks is routed through the hook's root property. */
            getRoot: function (property) {
                var hookData = CSS.Hooks.registered[property];

                if (hookData) {
                    return hookData[0];
                } else {
                    /* If there was no hook match, return the property name untouched. */
                    return property;
                }
            },
            /* Convert any rootPropertyValue, null or otherwise, into a space-delimited list of hook values so that
               the targeted hook can be injected or extracted at its standard position. */
            cleanRootPropertyValue: function(rootProperty, rootPropertyValue) {
                /* If the rootPropertyValue is wrapped with "rgb()", "clip()", etc., remove the wrapping to normalize the value before manipulation. */
                if (CSS.RegEx.valueUnwrap.test(rootPropertyValue)) {
                    rootPropertyValue = rootPropertyValue.match(CSS.RegEx.valueUnwrap)[1];
                }

                /* If rootPropertyValue is a CSS null-value (from which there's inherently no hook value to extract),
                   default to the root's default value as defined in CSS.Hooks.templates. */
                /* Note: CSS null-values include "none", "auto", and "transparent". They must be converted into their
                   zero-values (e.g. textShadow: "none" ==> textShadow: "0px 0px 0px black") for hook manipulation to proceed. */
                if (CSS.Values.isCSSNullValue(rootPropertyValue)) {
                    rootPropertyValue = CSS.Hooks.templates[rootProperty][1];
                }

                return rootPropertyValue;
            },
            /* Extracted the hook's value from its root property's value. This is used to get the starting value of an animating hook. */
            extractValue: function (fullHookName, rootPropertyValue) {
                var hookData = CSS.Hooks.registered[fullHookName];

                if (hookData) {
                    var hookRoot = hookData[0],
                        hookPosition = hookData[1];

                    rootPropertyValue = CSS.Hooks.cleanRootPropertyValue(hookRoot, rootPropertyValue);

                    /* Split rootPropertyValue into its constituent hook values then grab the desired hook at its standard position. */
                    return rootPropertyValue.toString().match(CSS.RegEx.valueSplit)[hookPosition];
                } else {
                    /* If the provided fullHookName isn't a registered hook, return the rootPropertyValue that was passed in. */
                    return rootPropertyValue;
                }
            },
            /* Inject the hook's value into its root property's value. This is used to piece back together the root property
               once Velocity has updated one of its individually hooked values through tweening. */
            injectValue: function (fullHookName, hookValue, rootPropertyValue) {
                var hookData = CSS.Hooks.registered[fullHookName];

                if (hookData) {
                    var hookRoot = hookData[0],
                        hookPosition = hookData[1],
                        rootPropertyValueParts,
                        rootPropertyValueUpdated;

                    rootPropertyValue = CSS.Hooks.cleanRootPropertyValue(hookRoot, rootPropertyValue);

                    /* Split rootPropertyValue into its individual hook values, replace the targeted value with hookValue,
                       then reconstruct the rootPropertyValue string. */
                    rootPropertyValueParts = rootPropertyValue.toString().match(CSS.RegEx.valueSplit);
                    rootPropertyValueParts[hookPosition] = hookValue;
                    rootPropertyValueUpdated = rootPropertyValueParts.join(" ");

                    return rootPropertyValueUpdated;
                } else {
                    /* If the provided fullHookName isn't a registered hook, return the rootPropertyValue that was passed in. */
                    return rootPropertyValue;
                }
            }
        },

        /*******************
           Normalizations
        *******************/

        /* Normalizations standardize CSS property manipulation by pollyfilling browser-specific implementations (e.g. opacity)
           and reformatting special properties (e.g. clip, rgba) to look like standard ones. */
        Normalizations: {
            /* Normalizations are passed a normalization target (either the property's name, its extracted value, or its injected value),
               the targeted element (which may need to be queried), and the targeted property value. */
            registered: {
                clip: function (type, element, propertyValue) {
                    switch (type) {
                        case "name":
                            return "clip";
                        /* Clip needs to be unwrapped and stripped of its commas during extraction. */
                        case "extract":
                            var extracted;

                            /* If Velocity also extracted this value, skip extraction. */
                            if (CSS.RegEx.wrappedValueAlreadyExtracted.test(propertyValue)) {
                                extracted = propertyValue;
                            } else {
                                /* Remove the "rect()" wrapper. */
                                extracted = propertyValue.toString().match(CSS.RegEx.valueUnwrap);

                                /* Strip off commas. */
                                extracted = extracted ? extracted[1].replace(/,(\s+)?/g, " ") : propertyValue;
                            }

                            return extracted;
                        /* Clip needs to be re-wrapped during injection. */
                        case "inject":
                            return "rect(" + propertyValue + ")";
                    }
                },

                blur: function(type, element, propertyValue) {
                    switch (type) {
                        case "name":
                            return "-webkit-filter";
                        case "extract":
                            var extracted = parseFloat(propertyValue);

                            /* If extracted is NaN, meaning the value isn't already extracted. */
                            if (!(extracted || extracted === 0)) {
                                var blurComponent = propertyValue.toString().match(/blur\(([0-9]+[A-z]+)\)/i);

                                /* If the filter string had a blur component, return just the blur value and unit type. */
                                if (blurComponent) {
                                    extracted = blurComponent[1];
                                /* If the component doesn't exist, default blur to 0. */
                                } else {
                                    extracted = 0;
                                }
                            }

                            return extracted;
                        /* Blur needs to be re-wrapped during injection. */
                        case "inject":
                            /* For the blur effect to be fully de-applied, it needs to be set to "none" instead of 0. */
                            if (!parseFloat(propertyValue)) {
                                return "none";
                            } else {
                                return "blur(" + propertyValue + ")";
                            }
                    }
                },

                /* <=IE8 do not support the standard opacity property. They use filter:alpha(opacity=INT) instead. */
                opacity: function (type, element, propertyValue) {
                    if (IE <= 8) {
                        switch (type) {
                            case "name":
                                return "filter";
                            case "extract":
                                /* <=IE8 return a "filter" value of "alpha(opacity=\d{1,3})".
                                   Extract the value and convert it to a decimal value to match the standard CSS opacity property's formatting. */
                                var extracted = propertyValue.toString().match(/alpha\(opacity=(.*)\)/i);

                                if (extracted) {
                                    /* Convert to decimal value. */
                                    propertyValue = extracted[1] / 100;
                                } else {
                                    /* When extracting opacity, default to 1 since a null value means opacity hasn't been set. */
                                    propertyValue = 1;
                                }

                                return propertyValue;
                            case "inject":
                                /* Opacified elements are required to have their zoom property set to a non-zero value. */
                                element.style.zoom = 1;

                                /* Setting the filter property on elements with certain font property combinations can result in a
                                   highly unappealing ultra-bolding effect. There's no way to remedy this throughout a tween, but dropping the
                                   value altogether (when opacity hits 1) at leasts ensures that the glitch is gone post-tweening. */
                                if (parseFloat(propertyValue) >= 1) {
                                    return "";
                                } else {
                                  /* As per the filter property's spec, convert the decimal value to a whole number and wrap the value. */
                                  return "alpha(opacity=" + parseInt(parseFloat(propertyValue) * 100, 10) + ")";
                                }
                        }
                    /* With all other browsers, normalization is not required; return the same values that were passed in. */
                    } else {
                        switch (type) {
                            case "name":
                                return "opacity";
                            case "extract":
                                return propertyValue;
                            case "inject":
                                return propertyValue;
                        }
                    }
                }
            },

            /*****************************
                Batched Registrations
            *****************************/

            /* Note: Batched normalizations extend the CSS.Normalizations.registered object. */
            register: function () {

                /*****************
                    Transforms
                *****************/

                /* Transforms are the subproperties contained by the CSS "transform" property. Transforms must undergo normalization
                   so that they can be referenced in a properties map by their individual names. */
                /* Note: When transforms are "set", they are actually assigned to a per-element transformCache. When all transform
                   setting is complete complete, CSS.flushTransformCache() must be manually called to flush the values to the DOM.
                   Transform setting is batched in this way to improve performance: the transform style only needs to be updated
                   once when multiple transform subproperties are being animated simultaneously. */
                /* Note: IE9 and Android Gingerbread have support for 2D -- but not 3D -- transforms. Since animating unsupported
                   transform properties results in the browser ignoring the *entire* transform string, we prevent these 3D values
                   from being normalized for these browsers so that tweening skips these properties altogether
                   (since it will ignore them as being unsupported by the browser.) */
                if (!(IE <= 9) && !Velocity.State.isGingerbread) {
                    /* Note: Since the standalone CSS "perspective" property and the CSS transform "perspective" subproperty
                    share the same name, the latter is given a unique token within Velocity: "transformPerspective". */
                    CSS.Lists.transformsBase = CSS.Lists.transformsBase.concat(CSS.Lists.transforms3D);
                }

                for (var i = 0; i < CSS.Lists.transformsBase.length; i++) {
                    /* Wrap the dynamically generated normalization function in a new scope so that transformName's value is
                    paired with its respective function. (Otherwise, all functions would take the final for loop's transformName.) */
                    (function() {
                        var transformName = CSS.Lists.transformsBase[i];

                        CSS.Normalizations.registered[transformName] = function (type, element, propertyValue) {
                            switch (type) {
                                /* The normalized property name is the parent "transform" property -- the property that is actually set in CSS. */
                                case "name":
                                    return "transform";
                                /* Transform values are cached onto a per-element transformCache object. */
                                case "extract":
                                    /* If this transform has yet to be assigned a value, return its null value. */
                                    if (Data(element) === undefined || Data(element).transformCache[transformName] === undefined) {
                                        /* Scale CSS.Lists.transformsBase default to 1 whereas all other transform properties default to 0. */
                                        return /^scale/i.test(transformName) ? 1 : 0;
                                    /* When transform values are set, they are wrapped in parentheses as per the CSS spec.
                                       Thus, when extracting their values (for tween calculations), we strip off the parentheses. */
                                    } else {
                                        return Data(element).transformCache[transformName].replace(/[()]/g, "");
                                    }
                                case "inject":
                                    var invalid = false;

                                    /* If an individual transform property contains an unsupported unit type, the browser ignores the *entire* transform property.
                                       Thus, protect users from themselves by skipping setting for transform values supplied with invalid unit types. */
                                    /* Switch on the base transform type; ignore the axis by removing the last letter from the transform's name. */
                                    switch (transformName.substr(0, transformName.length - 1)) {
                                        /* Whitelist unit types for each transform. */
                                        case "translate":
                                            invalid = !/(%|px|em|rem|vw|vh|\d)$/i.test(propertyValue);
                                            break;
                                        /* Since an axis-free "scale" property is supported as well, a little hack is used here to detect it by chopping off its last letter. */
                                        case "scal":
                                        case "scale":
                                            /* Chrome on Android has a bug in which scaled elements blur if their initial scale
                                               value is below 1 (which can happen with forcefeeding). Thus, we detect a yet-unset scale property
                                               and ensure that its first value is always 1. More info: http://stackoverflow.com/questions/10417890/css3-animations-with-transform-causes-blurred-elements-on-webkit/10417962#10417962 */
                                            if (Velocity.State.isAndroid && Data(element).transformCache[transformName] === undefined && propertyValue < 1) {
                                                propertyValue = 1;
                                            }

                                            invalid = !/(\d)$/i.test(propertyValue);
                                            break;
                                        case "skew":
                                            invalid = !/(deg|\d)$/i.test(propertyValue);
                                            break;
                                        case "rotate":
                                            invalid = !/(deg|\d)$/i.test(propertyValue);
                                            break;
                                    }

                                    if (!invalid) {
                                        /* As per the CSS spec, wrap the value in parentheses. */
                                        Data(element).transformCache[transformName] = "(" + propertyValue + ")";
                                    }

                                    /* Although the value is set on the transformCache object, return the newly-updated value for the calling code to process as normal. */
                                    return Data(element).transformCache[transformName];
                            }
                        };
                    })();
                }

                /*************
                    Colors
                *************/

                /* Since Velocity only animates a single numeric value per property, color animation is achieved by hooking the individual RGBA components of CSS color properties.
                   Accordingly, color values must be normalized (e.g. "#ff0000", "red", and "rgb(255, 0, 0)" ==> "255 0 0 1") so that their components can be injected/extracted by CSS.Hooks logic. */
                for (var i = 0; i < CSS.Lists.colors.length; i++) {
                    /* Wrap the dynamically generated normalization function in a new scope so that colorName's value is paired with its respective function.
                       (Otherwise, all functions would take the final for loop's colorName.) */
                    (function () {
                        var colorName = CSS.Lists.colors[i];

                        /* Note: In IE<=8, which support rgb but not rgba, color properties are reverted to rgb by stripping off the alpha component. */
                        CSS.Normalizations.registered[colorName] = function(type, element, propertyValue) {
                            switch (type) {
                                case "name":
                                    return colorName;
                                /* Convert all color values into the rgb format. (Old IE can return hex values and color names instead of rgb/rgba.) */
                                case "extract":
                                    var extracted;

                                    /* If the color is already in its hookable form (e.g. "255 255 255 1") due to having been previously extracted, skip extraction. */
                                    if (CSS.RegEx.wrappedValueAlreadyExtracted.test(propertyValue)) {
                                        extracted = propertyValue;
                                    } else {
                                        var converted,
                                            colorNames = {
                                                black: "rgb(0, 0, 0)",
                                                blue: "rgb(0, 0, 255)",
                                                gray: "rgb(128, 128, 128)",
                                                green: "rgb(0, 128, 0)",
                                                red: "rgb(255, 0, 0)",
                                                white: "rgb(255, 255, 255)"
                                            };

                                        /* Convert color names to rgb. */
                                        if (/^[A-z]+$/i.test(propertyValue)) {
                                            if (colorNames[propertyValue] !== undefined) {
                                                converted = colorNames[propertyValue]
                                            } else {
                                                /* If an unmatched color name is provided, default to black. */
                                                converted = colorNames.black;
                                            }
                                        /* Convert hex values to rgb. */
                                        } else if (CSS.RegEx.isHex.test(propertyValue)) {
                                            converted = "rgb(" + CSS.Values.hexToRgb(propertyValue).join(" ") + ")";
                                        /* If the provided color doesn't match any of the accepted color formats, default to black. */
                                        } else if (!(/^rgba?\(/i.test(propertyValue))) {
                                            converted = colorNames.black;
                                        }

                                        /* Remove the surrounding "rgb/rgba()" string then replace commas with spaces and strip
                                           repeated spaces (in case the value included spaces to begin with). */
                                        extracted = (converted || propertyValue).toString().match(CSS.RegEx.valueUnwrap)[1].replace(/,(\s+)?/g, " ");
                                    }

                                    /* So long as this isn't <=IE8, add a fourth (alpha) component if it's missing and default it to 1 (visible). */
                                    if (!(IE <= 8) && extracted.split(" ").length === 3) {
                                        extracted += " 1";
                                    }

                                    return extracted;
                                case "inject":
                                    /* If this is IE<=8 and an alpha component exists, strip it off. */
                                    if (IE <= 8) {
                                        if (propertyValue.split(" ").length === 4) {
                                            propertyValue = propertyValue.split(/\s+/).slice(0, 3).join(" ");
                                        }
                                    /* Otherwise, add a fourth (alpha) component if it's missing and default it to 1 (visible). */
                                    } else if (propertyValue.split(" ").length === 3) {
                                        propertyValue += " 1";
                                    }

                                    /* Re-insert the browser-appropriate wrapper("rgb/rgba()"), insert commas, and strip off decimal units
                                       on all values but the fourth (R, G, and B only accept whole numbers). */
                                    return (IE <= 8 ? "rgb" : "rgba") + "(" + propertyValue.replace(/\s+/g, ",").replace(/\.(\d)+(?=,)/g, "") + ")";
                            }
                        };
                    })();
                }
            }
        },

        /************************
           CSS Property Names
        ************************/

        Names: {
            /* Camelcase a property name into its JavaScript notation (e.g. "background-color" ==> "backgroundColor").
               Camelcasing is used to normalize property names between and across calls. */
            camelCase: function (property) {
                return property.replace(/-(\w)/g, function (match, subMatch) {
                    return subMatch.toUpperCase();
                });
            },

            /* For SVG elements, some properties (namely, dimensional ones) are GET/SET via the element's HTML attributes (instead of via CSS styles). */
            SVGAttribute: function (property) {
                var SVGAttributes = "width|height|x|y|cx|cy|r|rx|ry|x1|x2|y1|y2";

                /* Certain browsers require an SVG transform to be applied as an attribute. (Otherwise, application via CSS is preferable due to 3D support.) */
                if (IE || (Velocity.State.isAndroid && !Velocity.State.isChrome)) {
                    SVGAttributes += "|transform";
                }

                return new RegExp("^(" + SVGAttributes + ")$", "i").test(property);
            },

            /* Determine whether a property should be set with a vendor prefix. */
            /* If a prefixed version of the property exists, return it. Otherwise, return the original property name.
               If the property is not at all supported by the browser, return a false flag. */
            prefixCheck: function (property) {
                /* If this property has already been checked, return the cached value. */
                if (Velocity.State.prefixMatches[property]) {
                    return [ Velocity.State.prefixMatches[property], true ];
                } else {
                    var vendors = [ "", "Webkit", "Moz", "ms", "O" ];

                    for (var i = 0, vendorsLength = vendors.length; i < vendorsLength; i++) {
                        var propertyPrefixed;

                        if (i === 0) {
                            propertyPrefixed = property;
                        } else {
                            /* Capitalize the first letter of the property to conform to JavaScript vendor prefix notation (e.g. webkitFilter). */
                            propertyPrefixed = vendors[i] + property.replace(/^\w/, function(match) { return match.toUpperCase(); });
                        }

                        /* Check if the browser supports this property as prefixed. */
                        if (Type.isString(Velocity.State.prefixElement.style[propertyPrefixed])) {
                            /* Cache the match. */
                            Velocity.State.prefixMatches[property] = propertyPrefixed;

                            return [ propertyPrefixed, true ];
                        }
                    }

                    /* If the browser doesn't support this property in any form, include a false flag so that the caller can decide how to proceed. */
                    return [ property, false ];
                }
            }
        },

        /************************
           CSS Property Values
        ************************/

        Values: {
            /* Hex to RGB conversion. Copyright Tim Down: http://stackoverflow.com/questions/5623838/rgb-to-hex-and-hex-to-rgb */
            hexToRgb: function (hex) {
                var shortformRegex = /^#?([a-f\d])([a-f\d])([a-f\d])$/i,
                    longformRegex = /^#?([a-f\d]{2})([a-f\d]{2})([a-f\d]{2})$/i,
                    rgbParts;

                hex = hex.replace(shortformRegex, function (m, r, g, b) {
                    return r + r + g + g + b + b;
                });

                rgbParts = longformRegex.exec(hex);

                return rgbParts ? [ parseInt(rgbParts[1], 16), parseInt(rgbParts[2], 16), parseInt(rgbParts[3], 16) ] : [ 0, 0, 0 ];
            },

            isCSSNullValue: function (value) {
                /* The browser defaults CSS values that have not been set to either 0 or one of several possible null-value strings.
                   Thus, we check for both falsiness and these special strings. */
                /* Null-value checking is performed to default the special strings to 0 (for the sake of tweening) or their hook
                   templates as defined as CSS.Hooks (for the sake of hook injection/extraction). */
                /* Note: Chrome returns "rgba(0, 0, 0, 0)" for an undefined color whereas IE returns "transparent". */
                return (value == 0 || /^(none|auto|transparent|(rgba\(0, ?0, ?0, ?0\)))$/i.test(value));
            },

            /* Retrieve a property's default unit type. Used for assigning a unit type when one is not supplied by the user. */
            getUnitType: function (property) {
                if (/^(rotate|skew)/i.test(property)) {
                    return "deg";
                } else if (/(^(scale|scaleX|scaleY|scaleZ|alpha|flexGrow|flexHeight|zIndex|fontWeight)$)|((opacity|red|green|blue|alpha)$)/i.test(property)) {
                    /* The above properties are unitless. */
                    return "";
                } else {
                    /* Default to px for all other properties. */
                    return "px";
                }
            },

            /* HTML elements default to an associated display type when they're not set to display:none. */
            /* Note: This function is used for correctly setting the non-"none" display value in certain Velocity redirects, such as fadeIn/Out. */
            getDisplayType: function (element) {
                var tagName = element && element.tagName.toString().toLowerCase();

                if (/^(b|big|i|small|tt|abbr|acronym|cite|code|dfn|em|kbd|strong|samp|var|a|bdo|br|img|map|object|q|script|span|sub|sup|button|input|label|select|textarea)$/i.test(tagName)) {
                    return "inline";
                } else if (/^(li)$/i.test(tagName)) {
                    return "list-item";
                } else if (/^(tr)$/i.test(tagName)) {
                    return "table-row";
                /* Default to "block" when no match is found. */
                } else {
                    return "block";
                }
            },

            /* The class add/remove functions are used to temporarily apply a "velocity-animating" class to elements while they're animating. */
            addClass: function (element, className) {
                if (element.classList) {
                    element.classList.add(className);
                } else {
                    element.className += (element.className.length ? " " : "") + className;
                }
            },

            removeClass: function (element, className) {
                if (element.classList) {
                    element.classList.remove(className);
                } else {
                    element.className = element.className.toString().replace(new RegExp("(^|\\s)" + className.split(" ").join("|") + "(\\s|$)", "gi"), " ");
                }
            }
        },

        /****************************
           Style Getting & Setting
        ****************************/

        /* The singular getPropertyValue, which routes the logic for all normalizations, hooks, and standard CSS properties. */
        getPropertyValue: function (element, property, rootPropertyValue, forceStyleLookup) {
            /* Get an element's computed property value. */
            /* Note: Retrieving the value of a CSS property cannot simply be performed by checking an element's
               style attribute (which only reflects user-defined values). Instead, the browser must be queried for a property's
               *computed* value. You can read more about getComputedStyle here: https://developer.mozilla.org/en/docs/Web/API/window.getComputedStyle */
            function computePropertyValue (element, property) {
                /* When box-sizing isn't set to border-box, height and width style values are incorrectly computed when an
                   element's scrollbars are visible (which expands the element's dimensions). Thus, we defer to the more accurate
                   offsetHeight/Width property, which includes the total dimensions for interior, border, padding, and scrollbar.
                   We subtract border and padding to get the sum of interior + scrollbar. */
                var computedValue = 0;

                /* IE<=8 doesn't support window.getComputedStyle, thus we defer to jQuery, which has an extensive array
                   of hacks to accurately retrieve IE8 property values. Re-implementing that logic here is not worth bloating the
                   codebase for a dying browser. The performance repercussions of using jQuery here are minimal since
                   Velocity is optimized to rarely (and sometimes never) query the DOM. Further, the $.css() codepath isn't that slow. */
                if (IE <= 8) {
                    computedValue = $.css(element, property); /* GET */
                /* All other browsers support getComputedStyle. The returned live object reference is cached onto its
                   associated element so that it does not need to be refetched upon every GET. */
                } else {
                    /* Browsers do not return height and width values for elements that are set to display:"none". Thus, we temporarily
                       toggle display to the element type's default value. */
                    var toggleDisplay = false;

                    if (/^(width|height)$/.test(property) && CSS.getPropertyValue(element, "display") === 0) {
                        toggleDisplay = true;
                        CSS.setPropertyValue(element, "display", CSS.Values.getDisplayType(element));
                    }

                    function revertDisplay () {
                        if (toggleDisplay) {
                            CSS.setPropertyValue(element, "display", "none");
                        }
                    }

                    if (!forceStyleLookup) {
                        if (property === "height" && CSS.getPropertyValue(element, "boxSizing").toString().toLowerCase() !== "border-box") {
                            var contentBoxHeight = element.offsetHeight - (parseFloat(CSS.getPropertyValue(element, "borderTopWidth")) || 0) - (parseFloat(CSS.getPropertyValue(element, "borderBottomWidth")) || 0) - (parseFloat(CSS.getPropertyValue(element, "paddingTop")) || 0) - (parseFloat(CSS.getPropertyValue(element, "paddingBottom")) || 0);
                            revertDisplay();

                            return contentBoxHeight;
                        } else if (property === "width" && CSS.getPropertyValue(element, "boxSizing").toString().toLowerCase() !== "border-box") {
                            var contentBoxWidth = element.offsetWidth - (parseFloat(CSS.getPropertyValue(element, "borderLeftWidth")) || 0) - (parseFloat(CSS.getPropertyValue(element, "borderRightWidth")) || 0) - (parseFloat(CSS.getPropertyValue(element, "paddingLeft")) || 0) - (parseFloat(CSS.getPropertyValue(element, "paddingRight")) || 0);
                            revertDisplay();

                            return contentBoxWidth;
                        }
                    }

                    var computedStyle;

                    /* For elements that Velocity hasn't been called on directly (e.g. when Velocity queries the DOM on behalf
                       of a parent of an element its animating), perform a direct getComputedStyle lookup since the object isn't cached. */
                    if (Data(element) === undefined) {
                        computedStyle = window.getComputedStyle(element, null); /* GET */
                    /* If the computedStyle object has yet to be cached, do so now. */
                    } else if (!Data(element).computedStyle) {
                        computedStyle = Data(element).computedStyle = window.getComputedStyle(element, null); /* GET */
                    /* If computedStyle is cached, use it. */
                    } else {
                        computedStyle = Data(element).computedStyle;
                    }

                    /* IE and Firefox do not return a value for the generic borderColor -- they only return individual values for each border side's color.
                       As a polyfill for querying individual border side colors, just return the top border's color. */
                    if ((IE || Velocity.State.isFirefox) && property === "borderColor") {
                        property = "borderTopColor";
                    }

                    /* IE9 has a bug in which the "filter" property must be accessed from computedStyle using the getPropertyValue method
                       instead of a direct property lookup. The getPropertyValue method is slower than a direct lookup, which is why we avoid it by default. */
                    if (IE === 9 && property === "filter") {
                        computedValue = computedStyle.getPropertyValue(property); /* GET */
                    } else {
                        computedValue = computedStyle[property];
                    }

                    /* Fall back to the property's style value (if defined) when computedValue returns nothing,
                       which can happen when the element hasn't been painted. */
                    if (computedValue === "" || computedValue === null) {
                        computedValue = element.style[property];
                    }

                    revertDisplay();
                }

                /* For top, right, bottom, and left (TRBL) values that are set to "auto" on elements of "fixed" or "absolute" position,
                   defer to jQuery for converting "auto" to a numeric value. (For elements with a "static" or "relative" position, "auto" has the same
                   effect as being set to 0, so no conversion is necessary.) */
                /* An example of why numeric conversion is necessary: When an element with "position:absolute" has an untouched "left"
                   property, which reverts to "auto", left's value is 0 relative to its parent element, but is often non-zero relative
                   to its *containing* (not parent) element, which is the nearest "position:relative" ancestor or the viewport (and always the viewport in the case of "position:fixed"). */
                if (computedValue === "auto" && /^(top|right|bottom|left)$/i.test(property)) {
                    var position = computePropertyValue(element, "position"); /* GET */

                    /* For absolute positioning, jQuery's $.position() only returns values for top and left;
                       right and bottom will have their "auto" value reverted to 0. */
                    /* Note: A jQuery object must be created here since jQuery doesn't have a low-level alias for $.position().
                       Not a big deal since we're currently in a GET batch anyway. */
                    if (position === "fixed" || (position === "absolute" && /top|left/i.test(property))) {
                        /* Note: jQuery strips the pixel unit from its returned values; we re-add it here to conform with computePropertyValue's behavior. */
                        computedValue = $(element).position()[property] + "px"; /* GET */
                    }
                }

                return computedValue;
            }

            var propertyValue;

            /* If this is a hooked property (e.g. "clipLeft" instead of the root property of "clip"),
               extract the hook's value from a normalized rootPropertyValue using CSS.Hooks.extractValue(). */
            if (CSS.Hooks.registered[property]) {
                var hook = property,
                    hookRoot = CSS.Hooks.getRoot(hook);

                /* If a cached rootPropertyValue wasn't passed in (which Velocity always attempts to do in order to avoid requerying the DOM),
                   query the DOM for the root property's value. */
                if (rootPropertyValue === undefined) {
                    /* Since the browser is now being directly queried, use the official post-prefixing property name for this lookup. */
                    rootPropertyValue = CSS.getPropertyValue(element, CSS.Names.prefixCheck(hookRoot)[0]); /* GET */
                }

                /* If this root has a normalization registered, peform the associated normalization extraction. */
                if (CSS.Normalizations.registered[hookRoot]) {
                    rootPropertyValue = CSS.Normalizations.registered[hookRoot]("extract", element, rootPropertyValue);
                }

                /* Extract the hook's value. */
                propertyValue = CSS.Hooks.extractValue(hook, rootPropertyValue);

            /* If this is a normalized property (e.g. "opacity" becomes "filter" in <=IE8) or "translateX" becomes "transform"),
               normalize the property's name and value, and handle the special case of transforms. */
            /* Note: Normalizing a property is mutually exclusive from hooking a property since hook-extracted values are strictly
               numerical and therefore do not require normalization extraction. */
            } else if (CSS.Normalizations.registered[property]) {
                var normalizedPropertyName,
                    normalizedPropertyValue;

                normalizedPropertyName = CSS.Normalizations.registered[property]("name", element);

                /* Transform values are calculated via normalization extraction (see below), which checks against the element's transformCache.
                   At no point do transform GETs ever actually query the DOM; initial stylesheet values are never processed.
                   This is because parsing 3D transform matrices is not always accurate and would bloat our codebase;
                   thus, normalization extraction defaults initial transform values to their zero-values (e.g. 1 for scaleX and 0 for translateX). */
                if (normalizedPropertyName !== "transform") {
                    normalizedPropertyValue = computePropertyValue(element, CSS.Names.prefixCheck(normalizedPropertyName)[0]); /* GET */

                    /* If the value is a CSS null-value and this property has a hook template, use that zero-value template so that hooks can be extracted from it. */
                    if (CSS.Values.isCSSNullValue(normalizedPropertyValue) && CSS.Hooks.templates[property]) {
                        normalizedPropertyValue = CSS.Hooks.templates[property][1];
                    }
                }

                propertyValue = CSS.Normalizations.registered[property]("extract", element, normalizedPropertyValue);
            }

            /* If a (numeric) value wasn't produced via hook extraction or normalization, query the DOM. */
            if (!/^[\d-]/.test(propertyValue)) {
                /* For SVG elements, dimensional properties (which SVGAttribute() detects) are tweened via
                   their HTML attribute values instead of their CSS style values. */
                if (Data(element) && Data(element).isSVG && CSS.Names.SVGAttribute(property)) {
                    /* Since the height/width attribute values must be set manually, they don't reflect computed values.
                       Thus, we use use getBBox() to ensure we always get values for elements with undefined height/width attributes. */
                    if (/^(height|width)$/i.test(property)) {
                        propertyValue = element.getBBox()[property];
                    /* Otherwise, access the attribute value directly. */
                    } else {
                        propertyValue = element.getAttribute(property);
                    }
                } else {
                    propertyValue = computePropertyValue(element, CSS.Names.prefixCheck(property)[0]); /* GET */
                }
            }

            /* Since property lookups are for animation purposes (which entails computing the numeric delta between start and end values),
               convert CSS null-values to an integer of value 0. */
            if (CSS.Values.isCSSNullValue(propertyValue)) {
                propertyValue = 0;
            }

            if (Velocity.debug >= 2) console.log("Get " + property + ": " + propertyValue);

            return propertyValue;
        },

        /* The singular setPropertyValue, which routes the logic for all normalizations, hooks, and standard CSS properties. */
        setPropertyValue: function(element, property, propertyValue, rootPropertyValue, scrollData) {
            var propertyName = property;

            /* In order to be subjected to call options and element queueing, scroll animation is routed through Velocity as if it were a standard CSS property. */
            if (property === "scroll") {
                /* If a container option is present, scroll the container instead of the browser window. */
                if (scrollData.container) {
                    scrollData.container["scroll" + scrollData.direction] = propertyValue;
                /* Otherwise, Velocity defaults to scrolling the browser window. */
                } else {
                    if (scrollData.direction === "Left") {
                        window.scrollTo(propertyValue, scrollData.alternateValue);
                    } else {
                        window.scrollTo(scrollData.alternateValue, propertyValue);
                    }
                }
            } else {
                /* Transforms (translateX, rotateZ, etc.) are applied to a per-element transformCache object, which is manually flushed via flushTransformCache().
                   Thus, for now, we merely cache transforms being SET. */
                if (CSS.Normalizations.registered[property] && CSS.Normalizations.registered[property]("name", element) === "transform") {
                    /* Perform a normalization injection. */
                    /* Note: The normalization logic handles the transformCache updating. */
                    CSS.Normalizations.registered[property]("inject", element, propertyValue);

                    propertyName = "transform";
                    propertyValue = Data(element).transformCache[property];
                } else {
                    /* Inject hooks. */
                    if (CSS.Hooks.registered[property]) {
                        var hookName = property,
                            hookRoot = CSS.Hooks.getRoot(property);

                        /* If a cached rootPropertyValue was not provided, query the DOM for the hookRoot's current value. */
                        rootPropertyValue = rootPropertyValue || CSS.getPropertyValue(element, hookRoot); /* GET */

                        propertyValue = CSS.Hooks.injectValue(hookName, propertyValue, rootPropertyValue);
                        property = hookRoot;
                    }

                    /* Normalize names and values. */
                    if (CSS.Normalizations.registered[property]) {
                        propertyValue = CSS.Normalizations.registered[property]("inject", element, propertyValue);
                        property = CSS.Normalizations.registered[property]("name", element);
                    }

                    /* Assign the appropriate vendor prefix before performing an official style update. */
                    propertyName = CSS.Names.prefixCheck(property)[0];

                    /* A try/catch is used for IE<=8, which throws an error when "invalid" CSS values are set, e.g. a negative width.
                       Try/catch is avoided for other browsers since it incurs a performance overhead. */
                    if (IE <= 8) {
                        try {
                            element.style[propertyName] = propertyValue;
                        } catch (error) { if (Velocity.debug) console.log("Browser does not support [" + propertyValue + "] for [" + propertyName + "]"); }
                    /* SVG elements have their dimensional properties (width, height, x, y, cx, etc.) applied directly as attributes instead of as styles. */
                    /* Note: IE8 does not support SVG elements, so it's okay that we skip it for SVG animation. */
                    } else if (Data(element) && Data(element).isSVG && CSS.Names.SVGAttribute(property)) {
                        /* Note: For SVG attributes, vendor-prefixed property names are never used. */
                        /* Note: Not all CSS properties can be animated via attributes, but the browser won't throw an error for unsupported properties. */
                        element.setAttribute(property, propertyValue);
                    } else {
                        element.style[propertyName] = propertyValue;
                    }

                    if (Velocity.debug >= 2) console.log("Set " + property + " (" + propertyName + "): " + propertyValue);
                }
            }

            /* Return the normalized property name and value in case the caller wants to know how these values were modified before being applied to the DOM. */
            return [ propertyName, propertyValue ];
        },

        /* To increase performance by batching transform updates into a single SET, transforms are not directly applied to an element until flushTransformCache() is called. */
        /* Note: Velocity applies transform properties in the same order that they are chronogically introduced to the element's CSS styles. */
        flushTransformCache: function(element) {
            var transformString = "";

            /* Certain browsers require that SVG transforms be applied as an attribute. However, the SVG transform attribute takes a modified version of CSS's transform string
               (units are dropped and, except for skewX/Y, subproperties are merged into their master property -- e.g. scaleX and scaleY are merged into scale(X Y). */
            if ((IE || (Velocity.State.isAndroid && !Velocity.State.isChrome)) && Data(element).isSVG) {
                /* Since transform values are stored in their parentheses-wrapped form, we use a helper function to strip out their numeric values.
                   Further, SVG transform properties only take unitless (representing pixels) values, so it's okay that parseFloat() strips the unit suffixed to the float value. */
                function getTransformFloat (transformProperty) {
                    return parseFloat(CSS.getPropertyValue(element, transformProperty));
                }

                /* Create an object to organize all the transforms that we'll apply to the SVG element. To keep the logic simple,
                   we process *all* transform properties -- even those that may not be explicitly applied (since they default to their zero-values anyway). */
                var SVGTransforms = {
                    translate: [ getTransformFloat("translateX"), getTransformFloat("translateY") ],
                    skewX: [ getTransformFloat("skewX") ], skewY: [ getTransformFloat("skewY") ],
                    /* If the scale property is set (non-1), use that value for the scaleX and scaleY values
                       (this behavior mimics the result of animating all these properties at once on HTML elements). */
                    scale: getTransformFloat("scale") !== 1 ? [ getTransformFloat("scale"), getTransformFloat("scale") ] : [ getTransformFloat("scaleX"), getTransformFloat("scaleY") ],
                    /* Note: SVG's rotate transform takes three values: rotation degrees followed by the X and Y values
                       defining the rotation's origin point. We ignore the origin values (default them to 0). */
                    rotate: [ getTransformFloat("rotateZ"), 0, 0 ]
                };

                /* Iterate through the transform properties in the user-defined property map order.
                   (This mimics the behavior of non-SVG transform animation.) */
                $.each(Data(element).transformCache, function(transformName) {
                    /* Except for with skewX/Y, revert the axis-specific transform subproperties to their axis-free master
                       properties so that they match up with SVG's accepted transform properties. */
                    if (/^translate/i.test(transformName)) {
                        transformName = "translate";
                    } else if (/^scale/i.test(transformName)) {
                        transformName = "scale";
                    } else if (/^rotate/i.test(transformName)) {
                        transformName = "rotate";
                    }

                    /* Check that we haven't yet deleted the property from the SVGTransforms container. */
                    if (SVGTransforms[transformName]) {
                        /* Append the transform property in the SVG-supported transform format. As per the spec, surround the space-delimited values in parentheses. */
                        transformString += transformName + "(" + SVGTransforms[transformName].join(" ") + ")" + " ";

                        /* After processing an SVG transform property, delete it from the SVGTransforms container so we don't
                           re-insert the same master property if we encounter another one of its axis-specific properties. */
                        delete SVGTransforms[transformName];
                    }
                });
            } else {
                var transformValue,
                    perspective;

                /* Transform properties are stored as members of the transformCache object. Concatenate all the members into a string. */
                $.each(Data(element).transformCache, function(transformName) {
                    transformValue = Data(element).transformCache[transformName];

                    /* Transform's perspective subproperty must be set first in order to take effect. Store it temporarily. */
                    if (transformName === "transformPerspective") {
                        perspective = transformValue;
                        return true;
                    }

                    /* IE9 only supports one rotation type, rotateZ, which it refers to as "rotate". */
                    if (IE === 9 && transformName === "rotateZ") {
                        transformName = "rotate";
                    }

                    transformString += transformName + transformValue + " ";
                });

                /* If present, set the perspective subproperty first. */
                if (perspective) {
                    transformString = "perspective" + perspective + " " + transformString;
                }
            }

            CSS.setPropertyValue(element, "transform", transformString);
        }
    };

    /* Register hooks and normalizations. */
    CSS.Hooks.register();
    CSS.Normalizations.register();

    /* Allow hook setting in the same fashion as jQuery's $.css(). */
    Velocity.hook = function (elements, arg2, arg3) {
        var value = undefined;

        elements = sanitizeElements(elements);

        $.each(elements, function(i, element) {
            /* Initialize Velocity's per-element data cache if this element hasn't previously been animated. */
            if (Data(element) === undefined) {
                Velocity.init(element);
            }

            /* Get property value. If an element set was passed in, only return the value for the first element. */
            if (arg3 === undefined) {
                if (value === undefined) {
                    value = Velocity.CSS.getPropertyValue(element, arg2);
                }
            /* Set property value. */
            } else {
                /* sPV returns an array of the normalized propertyName/propertyValue pair used to update the DOM. */
                var adjustedSet = Velocity.CSS.setPropertyValue(element, arg2, arg3);

                /* Transform properties don't automatically set. They have to be flushed to the DOM. */
                if (adjustedSet[0] === "transform") {
                    Velocity.CSS.flushTransformCache(element);
                }

                value = adjustedSet;
            }
        });

        return value;
    };

    /*****************
        Animation
    *****************/

    var animate = function() {

        /******************
            Call Chain
        ******************/

        /* Logic for determining what to return to the call stack when exiting out of Velocity. */
        function getChain () {
            /* If we are using the utility function, attempt to return this call's promise. If no promise library was detected,
               default to null instead of returning the targeted elements so that utility function's return value is standardized. */
            if (isUtility) {
                return promiseData.promise || null;
            /* Otherwise, if we're using $.fn, return the jQuery-/Zepto-wrapped element set. */
            } else {
                return elementsWrapped;
            }
        }

        /*************************
           Arguments Assignment
        *************************/

        /* To allow for expressive CoffeeScript code, Velocity supports an alternative syntax in which "properties" and "options"
           objects are defined on a container object that's passed in as Velocity's sole argument. */
        /* Note: Some browsers automatically populate arguments with a "properties" object. We detect it by checking for its default "names" property. */
        var syntacticSugar = (arguments[0] && (($.isPlainObject(arguments[0].properties) && !arguments[0].properties.names) || Type.isString(arguments[0].properties))),
            /* Whether Velocity was called via the utility function (as opposed to on a jQuery/Zepto object). */
            isUtility,
            /* When Velocity is called via the utility function ($.Velocity()/Velocity()), elements are explicitly
               passed in as the first parameter. Thus, argument positioning varies. We normalize them here. */
            elementsWrapped,
            argumentIndex;

        var elements,
            propertiesMap,
            options;

        /* Detect jQuery/Zepto elements being animated via the $.fn method. */
        if (Type.isWrapped(this)) {
            isUtility = false;

            argumentIndex = 0;
            elements = this;
            elementsWrapped = this;
        /* Otherwise, raw elements are being animated via the utility function. */
        } else {
            isUtility = true;

            argumentIndex = 1;
            elements = syntacticSugar ? arguments[0].elements : arguments[0];
        }

        elements = sanitizeElements(elements);

        if (!elements) {
            return;
        }

        if (syntacticSugar) {
            propertiesMap = arguments[0].properties;
            options = arguments[0].options;
        } else {
            propertiesMap = arguments[argumentIndex];
            options = arguments[argumentIndex + 1];
        }

        /* The length of the element set (in the form of a nodeList or an array of elements) is defaulted to 1 in case a
           single raw DOM element is passed in (which doesn't contain a length property). */
        var elementsLength = elements.length,
            elementsIndex = 0;

        /***************************
            Argument Overloading
        ***************************/

        /* Support is included for jQuery's argument overloading: $.animate(propertyMap [, duration] [, easing] [, complete]).
           Overloading is detected by checking for the absence of an object being passed into options. */
        /* Note: The stop action does not accept animation options, and is therefore excluded from this check. */
        if (propertiesMap !== "stop" && !$.isPlainObject(options)) {
            /* The utility function shifts all arguments one position to the right, so we adjust for that offset. */
            var startingArgumentPosition = argumentIndex + 1;

            options = {};

            /* Iterate through all options arguments */
            for (var i = startingArgumentPosition; i < arguments.length; i++) {
                /* Treat a number as a duration. Parse it out. */
                /* Note: The following RegEx will return true if passed an array with a number as its first item.
                   Thus, arrays are skipped from this check. */
                if (!Type.isArray(arguments[i]) && (/^(fast|normal|slow)$/i.test(arguments[i]) || /^\d/.test(arguments[i]))) {
                    options.duration = arguments[i];
                /* Treat strings and arrays as easings. */
                } else if (Type.isString(arguments[i]) || Type.isArray(arguments[i])) {
                    options.easing = arguments[i];
                /* Treat a function as a complete callback. */
                } else if (Type.isFunction(arguments[i])) {
                    options.complete = arguments[i];
                }
            }
        }

        /***************
            Promises
        ***************/

        var promiseData = {
                promise: null,
                resolver: null,
                rejecter: null
            };

        /* If this call was made via the utility function (which is the default method of invocation when jQuery/Zepto are not being used), and if
           promise support was detected, create a promise object for this call and store references to its resolver and rejecter methods. The resolve
           method is used when a call completes naturally or is prematurely stopped by the user. In both cases, completeCall() handles the associated
           call cleanup and promise resolving logic. The reject method is used when an invalid set of arguments is passed into a Velocity call. */
        /* Note: Velocity employs a call-based queueing architecture, which means that stopping an animating element actually stops the full call that
           triggered it -- not that one element exclusively. Similarly, there is one promise per call, and all elements targeted by a Velocity call are
           grouped together for the purposes of resolving and rejecting a promise. */
        if (isUtility && Velocity.Promise) {
            promiseData.promise = new Velocity.Promise(function (resolve, reject) {
                promiseData.resolver = resolve;
                promiseData.rejecter = reject;
            });
        }

        /*********************
           Action Detection
        *********************/

        /* Velocity's behavior is categorized into "actions": Elements can either be specially scrolled into view,
           or they can be started, stopped, or reversed. If a literal or referenced properties map is passed in as Velocity's
           first argument, the associated action is "start". Alternatively, "scroll", "reverse", or "stop" can be passed in instead of a properties map. */
        var action;

        switch (propertiesMap) {
            case "scroll":
                action = "scroll";
                break;

            case "reverse":
                action = "reverse";
                break;

            case "stop":
                /*******************
                    Action: Stop
                *******************/

                /* Clear the currently-active delay on each targeted element. */
                $.each(elements, function(i, element) {
                    if (Data(element) && Data(element).delayTimer) {
                        /* Stop the timer from triggering its cached next() function. */
                        clearTimeout(Data(element).delayTimer.setTimeout);

                        /* Manually call the next() function so that the subsequent queue items can progress. */
                        if (Data(element).delayTimer.next) {
                            Data(element).delayTimer.next();
                        }

                        delete Data(element).delayTimer;
                    }
                });

                var callsToStop = [];

                /* When the stop action is triggered, the elements' currently active call is immediately stopped. The active call might have
                   been applied to multiple elements, in which case all of the call's elements will be subjected to stopping. When an element
                   is stopped, the next item in its animation queue is immediately triggered. */
                /* An additional argument may be passed in to clear an element's remaining queued calls. Either true (which defaults to the "fx" queue)
                   or a custom queue string can be passed in. */
                /* Note: The stop command runs prior to Queueing since its behavior is intended to take effect *immediately*,
                   regardless of the element's current queue state. */

                /* Iterate through every active call. */
                $.each(Velocity.State.calls, function(i, activeCall) {
                    /* Inactive calls are set to false by the logic inside completeCall(). Skip them. */
                    if (activeCall) {
                        /* Iterate through the active call's targeted elements. */
                        $.each(activeCall[1], function(k, activeElement) {
                            var queueName = Type.isString(options) ? options : "";

                            if (options !== undefined && activeCall[2].queue !== queueName) {
                                return true;
                            }

                            /* Iterate through the calls targeted by the stop command. */
                            $.each(elements, function(l, element) {
                                /* Check that this call was applied to the target element. */
                                if (element === activeElement) {
                                    /* Optionally clear the remaining queued calls. */
                                    if (options !== undefined) {
                                        /* Iterate through the items in the element's queue. */
                                        $.each($.queue(element, queueName), function(_, item) {
                                            /* The queue array can contain an "inprogress" string, which we skip. */
                                            if (Type.isFunction(item)) {
                                                /* Pass the item's callback a flag indicating that we want to abort from the queue call.
                                                   (Specifically, the queue will resolve the call's associated promise then abort.)  */
                                                item(null, true);
                                            }
                                        });

                                        /* Clearing the $.queue() array is achieved by resetting it to []. */
                                        $.queue(element, queueName, []);
                                    }

                                    if (Data(element) && queueName === "") {
                                        /* Since "reverse" uses cached start values (the previous call's endValues),
                                           these values must be changed to reflect the final value that the elements were actually tweened to. */
                                        $.each(Data(element).tweensContainer, function(m, activeTween) {
                                            activeTween.endValue = activeTween.currentValue;
                                        });
                                    }

                                    callsToStop.push(i);
                                }
                            });
                        });
                    }
                });

                /* Prematurely call completeCall() on each matched active call, passing an additional flag to indicate
                   that the complete callback and display:none setting should be skipped since we're completing prematurely. */
                $.each(callsToStop, function(i, j) {
                    completeCall(j, true);
                });

                if (promiseData.promise) {
                    /* Immediately resolve the promise associated with this stop call since stop runs synchronously. */
                    promiseData.resolver(elements);
                }

                /* Since we're stopping, and not proceeding with queueing, exit out of Velocity. */
                return getChain();

            default:
                /* Treat a non-empty plain object as a literal properties map. */
                if ($.isPlainObject(propertiesMap) && !Type.isEmptyObject(propertiesMap)) {
                    action = "start";

                /****************
                    Redirects
                ****************/

                /* Check if a string matches a registered redirect (see Redirects above). */
                } else if (Type.isString(propertiesMap) && Velocity.Redirects[propertiesMap]) {
                    var opts = $.extend({}, options),
                        durationOriginal = opts.duration,
                        delayOriginal = opts.delay || 0;

                    /* If the backwards option was passed in, reverse the element set so that elements animate from the last to the first. */
                    if (opts.backwards === true) {
                        elements = $.extend(true, [], elements).reverse();
                    }

                    /* Individually trigger the redirect for each element in the set to prevent users from having to handle iteration logic in their redirect. */
                    $.each(elements, function(elementIndex, element) {
                        /* If the stagger option was passed in, successively delay each element by the stagger value (in ms). Retain the original delay value. */
                        if (parseFloat(opts.stagger)) {
                            opts.delay = delayOriginal + (parseFloat(opts.stagger) * elementIndex);
                        } else if (Type.isFunction(opts.stagger)) {
                            opts.delay = delayOriginal + opts.stagger.call(element, elementIndex, elementsLength);
                        }

                        /* If the drag option was passed in, successively increase/decrease (depending on the presense of opts.backwards)
                           the duration of each element's animation, using floors to prevent producing very short durations. */
                        if (opts.drag) {
                            /* Default the duration of UI pack effects (callouts and transitions) to 1000ms instead of the usual default duration of 400ms. */
                            opts.duration = parseFloat(durationOriginal) || (/^(callout|transition)/.test(propertiesMap) ? 1000 : DURATION_DEFAULT);

                            /* For each element, take the greater duration of: A) animation completion percentage relative to the original duration,
                               B) 75% of the original duration, or C) a 200ms fallback (in case duration is already set to a low value).
                               The end result is a baseline of 75% of the redirect's duration that increases/decreases as the end of the element set is approached. */
                            opts.duration = Math.max(opts.duration * (opts.backwards ? 1 - elementIndex/elementsLength : (elementIndex + 1) / elementsLength), opts.duration * 0.75, 200);
                        }

                        /* Pass in the call's opts object so that the redirect can optionally extend it. It defaults to an empty object instead of null to
                           reduce the opts checking logic required inside the redirect. */
                        Velocity.Redirects[propertiesMap].call(element, element, opts || {}, elementIndex, elementsLength, elements, promiseData.promise ? promiseData : undefined);
                    });

                    /* Since the animation logic resides within the redirect's own code, abort the remainder of this call.
                       (The performance overhead up to this point is virtually non-existant.) */
                    /* Note: The jQuery call chain is kept intact by returning the complete element set. */
                    return getChain();
                } else {
                    var abortError = "Velocity: First argument (" + propertiesMap + ") was not a property map, a known action, or a registered redirect. Aborting.";

                    if (promiseData.promise) {
                        promiseData.rejecter(new Error(abortError));
                    } else {
                        console.log(abortError);
                    }

                    return getChain();
                }
        }

        /**************************
            Call-Wide Variables
        **************************/

        /* A container for CSS unit conversion ratios (e.g. %, rem, and em ==> px) that is used to cache ratios across all elements
           being animated in a single Velocity call. Calculating unit ratios necessitates DOM querying and updating, and is therefore
           avoided (via caching) wherever possible. This container is call-wide instead of page-wide to avoid the risk of using stale
           conversion metrics across Velocity animations that are not immediately consecutively chained. */
        var callUnitConversionData = {
                lastParent: null,
                lastPosition: null,
                lastFontSize: null,
                lastPercentToPxWidth: null,
                lastPercentToPxHeight: null,
                lastEmToPx: null,
                remToPx: null,
                vwToPx: null,
                vhToPx: null
            };

        /* A container for all the ensuing tween data and metadata associated with this call. This container gets pushed to the page-wide
           Velocity.State.calls array that is processed during animation ticking. */
        var call = [];

        /************************
           Element Processing
        ************************/

        /* Element processing consists of three parts -- data processing that cannot go stale and data processing that *can* go stale (i.e. third-party style modifications):
           1) Pre-Queueing: Element-wide variables, including the element's data storage, are instantiated. Call options are prepared. If triggered, the Stop action is executed.
           2) Queueing: The logic that runs once this call has reached its point of execution in the element's $.queue() stack. Most logic is placed here to avoid risking it becoming stale.
           3) Pushing: Consolidation of the tween data followed by its push onto the global in-progress calls container.
        */

        function processElement () {

            /*************************
               Part I: Pre-Queueing
            *************************/

            /***************************
               Element-Wide Variables
            ***************************/

            var element = this,
                /* The runtime opts object is the extension of the current call's options and Velocity's page-wide option defaults. */
                opts = $.extend({}, Velocity.defaults, options),
                /* A container for the processed data associated with each property in the propertyMap.
                   (Each property in the map produces its own "tween".) */
                tweensContainer = {},
                elementUnitConversionData;

            /******************
               Element Init
            ******************/

            if (Data(element) === undefined) {
                Velocity.init(element);
            }

            /******************
               Option: Delay
            ******************/

            /* Since queue:false doesn't respect the item's existing queue, we avoid injecting its delay here (it's set later on). */
            /* Note: Velocity rolls its own delay function since jQuery doesn't have a utility alias for $.fn.delay()
               (and thus requires jQuery element creation, which we avoid since its overhead includes DOM querying). */
            if (parseFloat(opts.delay) && opts.queue !== false) {
                $.queue(element, opts.queue, function(next) {
                    /* This is a flag used to indicate to the upcoming completeCall() function that this queue entry was initiated by Velocity. See completeCall() for further details. */
                    Velocity.velocityQueueEntryFlag = true;

                    /* The ensuing queue item (which is assigned to the "next" argument that $.queue() automatically passes in) will be triggered after a setTimeout delay.
                       The setTimeout is stored so that it can be subjected to clearTimeout() if this animation is prematurely stopped via Velocity's "stop" command. */
                    Data(element).delayTimer = {
                        setTimeout: setTimeout(next, parseFloat(opts.delay)),
                        next: next
                    };
                });
            }

            /*********************
               Option: Duration
            *********************/

            /* Support for jQuery's named durations. */
            switch (opts.duration.toString().toLowerCase()) {
                case "fast":
                    opts.duration = 200;
                    break;

                case "normal":
                    opts.duration = DURATION_DEFAULT;
                    break;

                case "slow":
                    opts.duration = 600;
                    break;

                default:
                    /* Remove the potential "ms" suffix and default to 1 if the user is attempting to set a duration of 0 (in order to produce an immediate style change). */
                    opts.duration = parseFloat(opts.duration) || 1;
            }

            /************************
               Global Option: Mock
            ************************/

            if (Velocity.mock !== false) {
                /* In mock mode, all animations are forced to 1ms so that they occur immediately upon the next rAF tick.
                   Alternatively, a multiplier can be passed in to time remap all delays and durations. */
                if (Velocity.mock === true) {
                    opts.duration = opts.delay = 1;
                } else {
                    opts.duration *= parseFloat(Velocity.mock) || 1;
                    opts.delay *= parseFloat(Velocity.mock) || 1;
                }
            }

            /*******************
               Option: Easing
            *******************/

            opts.easing = getEasing(opts.easing, opts.duration);

            /**********************
               Option: Callbacks
            **********************/

            /* Callbacks must functions. Otherwise, default to null. */
            if (opts.begin && !Type.isFunction(opts.begin)) {
                opts.begin = null;
            }

            if (opts.progress && !Type.isFunction(opts.progress)) {
                opts.progress = null;
            }

            if (opts.complete && !Type.isFunction(opts.complete)) {
                opts.complete = null;
            }

            /*********************************
               Option: Display & Visibility
            *********************************/

            /* Refer to Velocity's documentation (VelocityJS.org/#displayAndVisibility) for a description of the display and visibility options' behavior. */
            /* Note: We strictly check for undefined instead of falsiness because display accepts an empty string value. */
            if (opts.display !== undefined && opts.display !== null) {
                opts.display = opts.display.toString().toLowerCase();

                /* Users can pass in a special "auto" value to instruct Velocity to set the element to its default display value. */
                if (opts.display === "auto") {
                    opts.display = Velocity.CSS.Values.getDisplayType(element);
                }
            }

            if (opts.visibility !== undefined && opts.visibility !== null) {
                opts.visibility = opts.visibility.toString().toLowerCase();
            }

            /**********************
               Option: mobileHA
            **********************/

            /* When set to true, and if this is a mobile device, mobileHA automatically enables hardware acceleration (via a null transform hack)
               on animating elements. HA is removed from the element at the completion of its animation. */
            /* Note: Android Gingerbread doesn't support HA. If a null transform hack (mobileHA) is in fact set, it will prevent other tranform subproperties from taking effect. */
            /* Note: You can read more about the use of mobileHA in Velocity's documentation: VelocityJS.org/#mobileHA. */
            opts.mobileHA = (opts.mobileHA && Velocity.State.isMobile && !Velocity.State.isGingerbread);

            /***********************
               Part II: Queueing
            ***********************/

            /* When a set of elements is targeted by a Velocity call, the set is broken up and each element has the current Velocity call individually queued onto it.
               In this way, each element's existing queue is respected; some elements may already be animating and accordingly should not have this current Velocity call triggered immediately. */
            /* In each queue, tween data is processed for each animating property then pushed onto the call-wide calls array. When the last element in the set has had its tweens processed,
               the call array is pushed to Velocity.State.calls for live processing by the requestAnimationFrame tick. */
            function buildQueue (next) {

                /*******************
                   Option: Begin
                *******************/

                /* The begin callback is fired once per call -- not once per elemenet -- and is passed the full raw DOM element set as both its context and its first argument. */
                if (opts.begin && elementsIndex === 0) {
                    /* We throw callbacks in a setTimeout so that thrown errors don't halt the execution of Velocity itself. */
                    try {
                        opts.begin.call(elements, elements);
                    } catch (error) {
                        setTimeout(function() { throw error; }, 1);
                    }
                }

                /*****************************************
                   Tween Data Construction (for Scroll)
                *****************************************/

                /* Note: In order to be subjected to chaining and animation options, scroll's tweening is routed through Velocity as if it were a standard CSS property animation. */
                if (action === "scroll") {
                    /* The scroll action uniquely takes an optional "offset" option -- specified in pixels -- that offsets the targeted scroll position. */
                    var scrollDirection = (/^x$/i.test(opts.axis) ? "Left" : "Top"),
                        scrollOffset = parseFloat(opts.offset) || 0,
                        scrollPositionCurrent,
                        scrollPositionCurrentAlternate,
                        scrollPositionEnd;

                    /* Scroll also uniquely takes an optional "container" option, which indicates the parent element that should be scrolled --
                       as opposed to the browser window itself. This is useful for scrolling toward an element that's inside an overflowing parent element. */
                    if (opts.container) {
                        /* Ensure that either a jQuery object or a raw DOM element was passed in. */
                        if (Type.isWrapped(opts.container) || Type.isNode(opts.container)) {
                            /* Extract the raw DOM element from the jQuery wrapper. */
                            opts.container = opts.container[0] || opts.container;
                            /* Note: Unlike other properties in Velocity, the browser's scroll position is never cached since it so frequently changes
                               (due to the user's natural interaction with the page). */
                            scrollPositionCurrent = opts.container["scroll" + scrollDirection]; /* GET */

                            /* $.position() values are relative to the container's currently viewable area (without taking into account the container's true dimensions
                               -- say, for example, if the container was not overflowing). Thus, the scroll end value is the sum of the child element's position *and*
                               the scroll container's current scroll position. */
                            /* Note: jQuery does not offer a utility alias for $.position(), so we have to incur jQuery object conversion here.
                               This syncs up with an ensuing batch of GETs, so it fortunately does not trigger layout thrashing. */
                            scrollPositionEnd = (scrollPositionCurrent + $(element).position()[scrollDirection.toLowerCase()]) + scrollOffset; /* GET */
                        /* If a value other than a jQuery object or a raw DOM element was passed in, default to null so that this option is ignored. */
                        } else {
                            opts.container = null;
                        }
                    } else {
                        /* If the window itself is being scrolled -- not a containing element -- perform a live scroll position lookup using
                           the appropriate cached property names (which differ based on browser type). */
                        scrollPositionCurrent = Velocity.State.scrollAnchor[Velocity.State["scrollProperty" + scrollDirection]]; /* GET */
                        /* When scrolling the browser window, cache the alternate axis's current value since window.scrollTo() doesn't let us change only one value at a time. */
                        scrollPositionCurrentAlternate = Velocity.State.scrollAnchor[Velocity.State["scrollProperty" + (scrollDirection === "Left" ? "Top" : "Left")]]; /* GET */

                        /* Unlike $.position(), $.offset() values are relative to the browser window's true dimensions -- not merely its currently viewable area --
                           and therefore end values do not need to be compounded onto current values. */
                        scrollPositionEnd = $(element).offset()[scrollDirection.toLowerCase()] + scrollOffset; /* GET */
                    }

                    /* Since there's only one format that scroll's associated tweensContainer can take, we create it manually. */
                    tweensContainer = {
                        scroll: {
                            rootPropertyValue: false,
                            startValue: scrollPositionCurrent,
                            currentValue: scrollPositionCurrent,
                            endValue: scrollPositionEnd,
                            unitType: "",
                            easing: opts.easing,
                            scrollData: {
                                container: opts.container,
                                direction: scrollDirection,
                                alternateValue: scrollPositionCurrentAlternate
                            }
                        },
                        element: element
                    };

                    if (Velocity.debug) console.log("tweensContainer (scroll): ", tweensContainer.scroll, element);

                /******************************************
                   Tween Data Construction (for Reverse)
                ******************************************/

                /* Reverse acts like a "start" action in that a property map is animated toward. The only difference is
                   that the property map used for reverse is the inverse of the map used in the previous call. Thus, we manipulate
                   the previous call to construct our new map: use the previous map's end values as our new map's start values. Copy over all other data. */
                /* Note: Reverse can be directly called via the "reverse" parameter, or it can be indirectly triggered via the loop option. (Loops are composed of multiple reverses.) */
                /* Note: Reverse calls do not need to be consecutively chained onto a currently-animating element in order to operate on cached values;
                   there is no harm to reverse being called on a potentially stale data cache since reverse's behavior is simply defined
                   as reverting to the element's values as they were prior to the previous *Velocity* call. */
                } else if (action === "reverse") {
                    /* Abort if there is no prior animation data to reverse to. */
                    if (!Data(element).tweensContainer) {
                        /* Dequeue the element so that this queue entry releases itself immediately, allowing subsequent queue entries to run. */
                        $.dequeue(element, opts.queue);

                        return;
                    } else {
                        /*********************
                           Options Parsing
                        *********************/

                        /* If the element was hidden via the display option in the previous call,
                           revert display to "auto" prior to reversal so that the element is visible again. */
                        if (Data(element).opts.display === "none") {
                            Data(element).opts.display = "auto";
                        }

                        if (Data(element).opts.visibility === "hidden") {
                            Data(element).opts.visibility = "visible";
                        }

                        /* If the loop option was set in the previous call, disable it so that "reverse" calls aren't recursively generated.
                           Further, remove the previous call's callback options; typically, users do not want these to be refired. */
                        Data(element).opts.loop = false;
                        Data(element).opts.begin = null;
                        Data(element).opts.complete = null;

                        /* Since we're extending an opts object that has already been extended with the defaults options object,
                           we remove non-explicitly-defined properties that are auto-assigned values. */
                        if (!options.easing) {
                            delete opts.easing;
                        }

                        if (!options.duration) {
                            delete opts.duration;
                        }

                        /* The opts object used for reversal is an extension of the options object optionally passed into this
                           reverse call plus the options used in the previous Velocity call. */
                        opts = $.extend({}, Data(element).opts, opts);

                        /*************************************
                           Tweens Container Reconstruction
                        *************************************/

                        /* Create a deepy copy (indicated via the true flag) of the previous call's tweensContainer. */
                        var lastTweensContainer = $.extend(true, {}, Data(element).tweensContainer);

                        /* Manipulate the previous tweensContainer by replacing its end values and currentValues with its start values. */
                        for (var lastTween in lastTweensContainer) {
                            /* In addition to tween data, tweensContainers contain an element property that we ignore here. */
                            if (lastTween !== "element") {
                                var lastStartValue = lastTweensContainer[lastTween].startValue;

                                lastTweensContainer[lastTween].startValue = lastTweensContainer[lastTween].currentValue = lastTweensContainer[lastTween].endValue;
                                lastTweensContainer[lastTween].endValue = lastStartValue;

                                /* Easing is the only option that embeds into the individual tween data (since it can be defined on a per-property basis).
                                   Accordingly, every property's easing value must be updated when an options object is passed in with a reverse call.
                                   The side effect of this extensibility is that all per-property easing values are forcefully reset to the new value. */
                                if (!Type.isEmptyObject(options)) {
                                    lastTweensContainer[lastTween].easing = opts.easing;
                                }

                                if (Velocity.debug) console.log("reverse tweensContainer (" + lastTween + "): " + JSON.stringify(lastTweensContainer[lastTween]), element);
                            }
                        }

                        tweensContainer = lastTweensContainer;
                    }

                /*****************************************
                   Tween Data Construction (for Start)
                *****************************************/

                } else if (action === "start") {

                    /*************************
                        Value Transferring
                    *************************/

                    /* If this queue entry follows a previous Velocity-initiated queue entry *and* if this entry was created
                       while the element was in the process of being animated by Velocity, then this current call is safe to use
                       the end values from the prior call as its start values. Velocity attempts to perform this value transfer
                       process whenever possible in order to avoid requerying the DOM. */
                    /* If values aren't transferred from a prior call and start values were not forcefed by the user (more on this below),
                       then the DOM is queried for the element's current values as a last resort. */
                    /* Note: Conversely, animation reversal (and looping) *always* perform inter-call value transfers; they never requery the DOM. */
                    var lastTweensContainer;

                    /* The per-element isAnimating flag is used to indicate whether it's safe (i.e. the data isn't stale)
                       to transfer over end values to use as start values. If it's set to true and there is a previous
                       Velocity call to pull values from, do so. */
                    if (Data(element).tweensContainer && Data(element).isAnimating === true) {
                        lastTweensContainer = Data(element).tweensContainer;
                    }

                    /***************************
                       Tween Data Calculation
                    ***************************/

                    /* This function parses property data and defaults endValue, easing, and startValue as appropriate. */
                    /* Property map values can either take the form of 1) a single value representing the end value,
                       or 2) an array in the form of [ endValue, [, easing] [, startValue] ].
                       The optional third parameter is a forcefed startValue to be used instead of querying the DOM for
                       the element's current value. Read Velocity's docmentation to learn more about forcefeeding: VelocityJS.org/#forcefeeding */
                    function parsePropertyValue (valueData, skipResolvingEasing) {
                        var endValue = undefined,
                            easing = undefined,
                            startValue = undefined;

                        /* Handle the array format, which can be structured as one of three potential overloads:
                           A) [ endValue, easing, startValue ], B) [ endValue, easing ], or C) [ endValue, startValue ] */
                        if (Type.isArray(valueData)) {
                            /* endValue is always the first item in the array. Don't bother validating endValue's value now
                               since the ensuing property cycling logic does that. */
                            endValue = valueData[0];

                            /* Two-item array format: If the second item is a number, function, or hex string, treat it as a
                               start value since easings can only be non-hex strings or arrays. */
                            if ((!Type.isArray(valueData[1]) && /^[\d-]/.test(valueData[1])) || Type.isFunction(valueData[1]) || CSS.RegEx.isHex.test(valueData[1])) {
                                startValue = valueData[1];
                            /* Two or three-item array: If the second item is a non-hex string or an array, treat it as an easing. */
                            } else if ((Type.isString(valueData[1]) && !CSS.RegEx.isHex.test(valueData[1])) || Type.isArray(valueData[1])) {
                                easing = skipResolvingEasing ? valueData[1] : getEasing(valueData[1], opts.duration);

                                /* Don't bother validating startValue's value now since the ensuing property cycling logic inherently does that. */
                                if (valueData[2] !== undefined) {
                                    startValue = valueData[2];
                                }
                            }
                        /* Handle the single-value format. */
                        } else {
                            endValue = valueData;
                        }

                        /* Default to the call's easing if a per-property easing type was not defined. */
                        if (!skipResolvingEasing) {
                            easing = easing || opts.easing;
                        }

                        /* If functions were passed in as values, pass the function the current element as its context,
                           plus the element's index and the element set's size as arguments. Then, assign the returned value. */
                        if (Type.isFunction(endValue)) {
                            endValue = endValue.call(element, elementsIndex, elementsLength);
                        }

                        if (Type.isFunction(startValue)) {
                            startValue = startValue.call(element, elementsIndex, elementsLength);
                        }

                        /* Allow startValue to be left as undefined to indicate to the ensuing code that its value was not forcefed. */
                        return [ endValue || 0, easing, startValue ];
                    }

                    /* Cycle through each property in the map, looking for shorthand color properties (e.g. "color" as opposed to "colorRed"). Inject the corresponding
                       colorRed, colorGreen, and colorBlue RGB component tweens into the propertiesMap (which Velocity understands) and remove the shorthand property. */
                    $.each(propertiesMap, function(property, value) {
                        /* Find shorthand color properties that have been passed a hex string. */
                        if (RegExp("^" + CSS.Lists.colors.join("$|^") + "$").test(property)) {
                            /* Parse the value data for each shorthand. */
                            var valueData = parsePropertyValue(value, true),
                                endValue = valueData[0],
                                easing = valueData[1],
                                startValue = valueData[2];

                            if (CSS.RegEx.isHex.test(endValue)) {
                                /* Convert the hex strings into their RGB component arrays. */
                                var colorComponents = [ "Red", "Green", "Blue" ],
                                    endValueRGB = CSS.Values.hexToRgb(endValue),
                                    startValueRGB = startValue ? CSS.Values.hexToRgb(startValue) : undefined;

                                /* Inject the RGB component tweens into propertiesMap. */
                                for (var i = 0; i < colorComponents.length; i++) {
                                    var dataArray = [ endValueRGB[i] ];

                                    if (easing) {
                                        dataArray.push(easing);
                                    }

                                    if (startValueRGB !== undefined) {
                                        dataArray.push(startValueRGB[i]);
                                    }

                                    propertiesMap[property + colorComponents[i]] = dataArray;
                                }

                                /* Remove the intermediary shorthand property entry now that we've processed it. */
                                delete propertiesMap[property];
                            }
                        }
                    });

                    /* Create a tween out of each property, and append its associated data to tweensContainer. */
                    for (var property in propertiesMap) {

                        /**************************
                           Start Value Sourcing
                        **************************/

                        /* Parse out endValue, easing, and startValue from the property's data. */
                        var valueData = parsePropertyValue(propertiesMap[property]),
                            endValue = valueData[0],
                            easing = valueData[1],
                            startValue = valueData[2];

                        /* Now that the original property name's format has been used for the parsePropertyValue() lookup above,
                           we force the property to its camelCase styling to normalize it for manipulation. */
                        property = CSS.Names.camelCase(property);

                        /* In case this property is a hook, there are circumstances where we will intend to work on the hook's root property and not the hooked subproperty. */
                        var rootProperty = CSS.Hooks.getRoot(property),
                            rootPropertyValue = false;

                        /* Properties that are not supported by the browser (and do not have an associated normalization) will
                           inherently produce no style changes when set, so they are skipped in order to decrease animation tick overhead.
                           Property support is determined via prefixCheck(), which returns a false flag when no supported is detected. */
                        /* Note: Since SVG elements have some of their properties directly applied as HTML attributes,
                           there is no way to check for their explicit browser support, and so we skip skip this check for them. */
                        if (!Data(element).isSVG && CSS.Names.prefixCheck(rootProperty)[1] === false && CSS.Normalizations.registered[rootProperty] === undefined) {
                            if (Velocity.debug) console.log("Skipping [" + rootProperty + "] due to a lack of browser support.");

                            continue;
                        }

                        /* If the display option is being set to a non-"none" (e.g. "block") and opacity (filter on IE<=8) is being
                           animated to an endValue of non-zero, the user's intention is to fade in from invisible, thus we forcefeed opacity
                           a startValue of 0 if its startValue hasn't already been sourced by value transferring or prior forcefeeding. */
                        if (((opts.display !== undefined && opts.display !== null && opts.display !== "none") || (opts.visibility !== undefined && opts.visibility !== "hidden")) && /opacity|filter/.test(property) && !startValue && endValue !== 0) {
                            startValue = 0;
                        }

                        /* If values have been transferred from the previous Velocity call, extract the endValue and rootPropertyValue
                           for all of the current call's properties that were *also* animated in the previous call. */
                        /* Note: Value transferring can optionally be disabled by the user via the _cacheValues option. */
                        if (opts._cacheValues && lastTweensContainer && lastTweensContainer[property]) {
                            if (startValue === undefined) {
                                startValue = lastTweensContainer[property].endValue + lastTweensContainer[property].unitType;
                            }

                            /* The previous call's rootPropertyValue is extracted from the element's data cache since that's the
                               instance of rootPropertyValue that gets freshly updated by the tweening process, whereas the rootPropertyValue
                               attached to the incoming lastTweensContainer is equal to the root property's value prior to any tweening. */
                            rootPropertyValue = Data(element).rootPropertyValueCache[rootProperty];
                        /* If values were not transferred from a previous Velocity call, query the DOM as needed. */
                        } else {
                            /* Handle hooked properties. */
                            if (CSS.Hooks.registered[property]) {
                               if (startValue === undefined) {
                                    rootPropertyValue = CSS.getPropertyValue(element, rootProperty); /* GET */
                                    /* Note: The following getPropertyValue() call does not actually trigger a DOM query;
                                       getPropertyValue() will extract the hook from rootPropertyValue. */
                                    startValue = CSS.getPropertyValue(element, property, rootPropertyValue);
                                /* If startValue is already defined via forcefeeding, do not query the DOM for the root property's value;
                                   just grab rootProperty's zero-value template from CSS.Hooks. This overwrites the element's actual
                                   root property value (if one is set), but this is acceptable since the primary reason users forcefeed is
                                   to avoid DOM queries, and thus we likewise avoid querying the DOM for the root property's value. */
                                } else {
                                    /* Grab this hook's zero-value template, e.g. "0px 0px 0px black". */
                                    rootPropertyValue = CSS.Hooks.templates[rootProperty][1];
                                }
                            /* Handle non-hooked properties that haven't already been defined via forcefeeding. */
                            } else if (startValue === undefined) {
                                startValue = CSS.getPropertyValue(element, property); /* GET */
                            }
                        }

                        /**************************
                           Value Data Extraction
                        **************************/

                        var separatedValue,
                            endValueUnitType,
                            startValueUnitType,
                            operator = false;

                        /* Separates a property value into its numeric value and its unit type. */
                        function separateValue (property, value) {
                            var unitType,
                                numericValue;

                            numericValue = (value || "0")
                                .toString()
                                .toLowerCase()
                                /* Match the unit type at the end of the value. */
                                .replace(/[%A-z]+$/, function(match) {
                                    /* Grab the unit type. */
                                    unitType = match;

                                    /* Strip the unit type off of value. */
                                    return "";
                                });

                            /* If no unit type was supplied, assign one that is appropriate for this property (e.g. "deg" for rotateZ or "px" for width). */
                            if (!unitType) {
                                unitType = CSS.Values.getUnitType(property);
                            }

                            return [ numericValue, unitType ];
                        }

                        /* Separate startValue. */
                        separatedValue = separateValue(property, startValue);
                        startValue = separatedValue[0];
                        startValueUnitType = separatedValue[1];

                        /* Separate endValue, and extract a value operator (e.g. "+=", "-=") if one exists. */
                        separatedValue = separateValue(property, endValue);
                        endValue = separatedValue[0].replace(/^([+-\/*])=/, function(match, subMatch) {
                            operator = subMatch;

                            /* Strip the operator off of the value. */
                            return "";
                        });
                        endValueUnitType = separatedValue[1];

                        /* Parse float values from endValue and startValue. Default to 0 if NaN is returned. */
                        startValue = parseFloat(startValue) || 0;
                        endValue = parseFloat(endValue) || 0;

                        /***************************************
                           Property-Specific Value Conversion
                        ***************************************/

                        /* Custom support for properties that don't actually accept the % unit type, but where pollyfilling is trivial and relatively foolproof. */
                        if (endValueUnitType === "%") {
                            /* A %-value fontSize/lineHeight is relative to the parent's fontSize (as opposed to the parent's dimensions),
                               which is identical to the em unit's behavior, so we piggyback off of that. */
                            if (/^(fontSize|lineHeight)$/.test(property)) {
                                /* Convert % into an em decimal value. */
                                endValue = endValue / 100;
                                endValueUnitType = "em";
                            /* For scaleX and scaleY, convert the value into its decimal format and strip off the unit type. */
                            } else if (/^scale/.test(property)) {
                                endValue = endValue / 100;
                                endValueUnitType = "";
                            /* For RGB components, take the defined percentage of 255 and strip off the unit type. */
                            } else if (/(Red|Green|Blue)$/i.test(property)) {
                                endValue = (endValue / 100) * 255;
                                endValueUnitType = "";
                            }
                        }

                        /***************************
                           Unit Ratio Calculation
                        ***************************/

                        /* When queried, the browser returns (most) CSS property values in pixels. Therefore, if an endValue with a unit type of
                           %, em, or rem is animated toward, startValue must be converted from pixels into the same unit type as endValue in order
                           for value manipulation logic (increment/decrement) to proceed. Further, if the startValue was forcefed or transferred
                           from a previous call, startValue may also not be in pixels. Unit conversion logic therefore consists of two steps:
                           1) Calculating the ratio of %/em/rem/vh/vw relative to pixels
                           2) Converting startValue into the same unit of measurement as endValue based on these ratios. */
                        /* Unit conversion ratios are calculated by inserting a sibling node next to the target node, copying over its position property,
                           setting values with the target unit type then comparing the returned pixel value. */
                        /* Note: Even if only one of these unit types is being animated, all unit ratios are calculated at once since the overhead
                           of batching the SETs and GETs together upfront outweights the potential overhead
                           of layout thrashing caused by re-querying for uncalculated ratios for subsequently-processed properties. */
                        /* Todo: Shift this logic into the calls' first tick instance so that it's synced with RAF. */
                        function calculateUnitRatios () {

                            /************************
                                Same Ratio Checks
                            ************************/

                            /* The properties below are used to determine whether the element differs sufficiently from this call's
                               previously iterated element to also differ in its unit conversion ratios. If the properties match up with those
                               of the prior element, the prior element's conversion ratios are used. Like most optimizations in Velocity,
                               this is done to minimize DOM querying. */
                            var sameRatioIndicators = {
                                    myParent: element.parentNode || document.body, /* GET */
                                    position: CSS.getPropertyValue(element, "position"), /* GET */
                                    fontSize: CSS.getPropertyValue(element, "fontSize") /* GET */
                                },
                                /* Determine if the same % ratio can be used. % is based on the element's position value and its parent's width and height dimensions. */
                                samePercentRatio = ((sameRatioIndicators.position === callUnitConversionData.lastPosition) && (sameRatioIndicators.myParent === callUnitConversionData.lastParent)),
                                /* Determine if the same em ratio can be used. em is relative to the element's fontSize. */
                                sameEmRatio = (sameRatioIndicators.fontSize === callUnitConversionData.lastFontSize);

                            /* Store these ratio indicators call-wide for the next element to compare against. */
                            callUnitConversionData.lastParent = sameRatioIndicators.myParent;
                            callUnitConversionData.lastPosition = sameRatioIndicators.position;
                            callUnitConversionData.lastFontSize = sameRatioIndicators.fontSize;

                            /***************************
                               Element-Specific Units
                            ***************************/

                            /* Note: IE8 rounds to the nearest pixel when returning CSS values, thus we perform conversions using a measurement
                               of 100 (instead of 1) to give our ratios a precision of at least 2 decimal values. */
                            var measurement = 100,
                                unitRatios = {};

                            if (!sameEmRatio || !samePercentRatio) {
                                var dummy = Data(element).isSVG ? document.createElementNS("http://www.w3.org/2000/svg", "rect") : document.createElement("div");

                                Velocity.init(dummy);
                                sameRatioIndicators.myParent.appendChild(dummy);

                                /* To accurately and consistently calculate conversion ratios, the element's cascaded overflow and box-sizing are stripped.
                                   Similarly, since width/height can be artificially constrained by their min-/max- equivalents, these are controlled for as well. */
                                /* Note: Overflow must be also be controlled for per-axis since the overflow property overwrites its per-axis values. */
                                $.each([ "overflow", "overflowX", "overflowY" ], function(i, property) {
                                    Velocity.CSS.setPropertyValue(dummy, property, "hidden");
                                });
                                Velocity.CSS.setPropertyValue(dummy, "position", sameRatioIndicators.position);
                                Velocity.CSS.setPropertyValue(dummy, "fontSize", sameRatioIndicators.fontSize);
                                Velocity.CSS.setPropertyValue(dummy, "boxSizing", "content-box");

                                /* width and height act as our proxy properties for measuring the horizontal and vertical % ratios. */
                                $.each([ "minWidth", "maxWidth", "width", "minHeight", "maxHeight", "height" ], function(i, property) {
                                    Velocity.CSS.setPropertyValue(dummy, property, measurement + "%");
                                });
                                /* paddingLeft arbitrarily acts as our proxy property for the em ratio. */
                                Velocity.CSS.setPropertyValue(dummy, "paddingLeft", measurement + "em");

                                /* Divide the returned value by the measurement to get the ratio between 1% and 1px. Default to 1 since working with 0 can produce Infinite. */
                                unitRatios.percentToPxWidth = callUnitConversionData.lastPercentToPxWidth = (parseFloat(CSS.getPropertyValue(dummy, "width", null, true)) || 1) / measurement; /* GET */
                                unitRatios.percentToPxHeight = callUnitConversionData.lastPercentToPxHeight = (parseFloat(CSS.getPropertyValue(dummy, "height", null, true)) || 1) / measurement; /* GET */
                                unitRatios.emToPx = callUnitConversionData.lastEmToPx = (parseFloat(CSS.getPropertyValue(dummy, "paddingLeft")) || 1) / measurement; /* GET */

                                sameRatioIndicators.myParent.removeChild(dummy);
                            } else {
                                unitRatios.emToPx = callUnitConversionData.lastEmToPx;
                                unitRatios.percentToPxWidth = callUnitConversionData.lastPercentToPxWidth;
                                unitRatios.percentToPxHeight = callUnitConversionData.lastPercentToPxHeight;
                            }

                            /***************************
                               Element-Agnostic Units
                            ***************************/

                            /* Whereas % and em ratios are determined on a per-element basis, the rem unit only needs to be checked
                               once per call since it's exclusively dependant upon document.body's fontSize. If this is the first time
                               that calculateUnitRatios() is being run during this call, remToPx will still be set to its default value of null,
                               so we calculate it now. */
                            if (callUnitConversionData.remToPx === null) {
                                /* Default to browsers' default fontSize of 16px in the case of 0. */
                                callUnitConversionData.remToPx = parseFloat(CSS.getPropertyValue(document.body, "fontSize")) || 16; /* GET */
                            }

                            /* Similarly, viewport units are %-relative to the window's inner dimensions. */
                            if (callUnitConversionData.vwToPx === null) {
                                callUnitConversionData.vwToPx = parseFloat(window.innerWidth) / 100; /* GET */
                                callUnitConversionData.vhToPx = parseFloat(window.innerHeight) / 100; /* GET */
                            }

                            unitRatios.remToPx = callUnitConversionData.remToPx;
                            unitRatios.vwToPx = callUnitConversionData.vwToPx;
                            unitRatios.vhToPx = callUnitConversionData.vhToPx;

                            if (Velocity.debug >= 1) console.log("Unit ratios: " + JSON.stringify(unitRatios), element);

                            return unitRatios;
                        }

                        /********************
                           Unit Conversion
                        ********************/

                        /* The * and / operators, which are not passed in with an associated unit, inherently use startValue's unit. Skip value and unit conversion. */
                        if (/[\/*]/.test(operator)) {
                            endValueUnitType = startValueUnitType;
                        /* If startValue and endValue differ in unit type, convert startValue into the same unit type as endValue so that if endValueUnitType
                           is a relative unit (%, em, rem), the values set during tweening will continue to be accurately relative even if the metrics they depend
                           on are dynamically changing during the course of the animation. Conversely, if we always normalized into px and used px for setting values, the px ratio
                           would become stale if the original unit being animated toward was relative and the underlying metrics change during the animation. */
                        /* Since 0 is 0 in any unit type, no conversion is necessary when startValue is 0 -- we just start at 0 with endValueUnitType. */
                        } else if ((startValueUnitType !== endValueUnitType) && startValue !== 0) {
                            /* Unit conversion is also skipped when endValue is 0, but *startValueUnitType* must be used for tween values to remain accurate. */
                            /* Note: Skipping unit conversion here means that if endValueUnitType was originally a relative unit, the animation won't relatively
                               match the underlying metrics if they change, but this is acceptable since we're animating toward invisibility instead of toward visibility,
                               which remains past the point of the animation's completion. */
                            if (endValue === 0) {
                                endValueUnitType = startValueUnitType;
                            } else {
                                /* By this point, we cannot avoid unit conversion (it's undesirable since it causes layout thrashing).
                                   If we haven't already, we trigger calculateUnitRatios(), which runs once per element per call. */
                                elementUnitConversionData = elementUnitConversionData || calculateUnitRatios();

                                /* The following RegEx matches CSS properties that have their % values measured relative to the x-axis. */
                                /* Note: W3C spec mandates that all of margin and padding's properties (even top and bottom) are %-relative to the *width* of the parent element. */
                                var axis = (/margin|padding|left|right|width|text|word|letter/i.test(property) || /X$/.test(property) || property === "x") ? "x" : "y";

                                /* In order to avoid generating n^2 bespoke conversion functions, unit conversion is a two-step process:
                                   1) Convert startValue into pixels. 2) Convert this new pixel value into endValue's unit type. */
                                switch (startValueUnitType) {
                                    case "%":
                                        /* Note: translateX and translateY are the only properties that are %-relative to an element's own dimensions -- not its parent's dimensions.
                                           Velocity does not include a special conversion process to account for this behavior. Therefore, animating translateX/Y from a % value
                                           to a non-% value will produce an incorrect start value. Fortunately, this sort of cross-unit conversion is rarely done by users in practice. */
                                        startValue *= (axis === "x" ? elementUnitConversionData.percentToPxWidth : elementUnitConversionData.percentToPxHeight);
                                        break;

                                    case "px":
                                        /* px acts as our midpoint in the unit conversion process; do nothing. */
                                        break;

                                    default:
                                        startValue *= elementUnitConversionData[startValueUnitType + "ToPx"];
                                }

                                /* Invert the px ratios to convert into to the target unit. */
                                switch (endValueUnitType) {
                                    case "%":
                                        startValue *= 1 / (axis === "x" ? elementUnitConversionData.percentToPxWidth : elementUnitConversionData.percentToPxHeight);
                                        break;

                                    case "px":
                                        /* startValue is already in px, do nothing; we're done. */
                                        break;

                                    default:
                                        startValue *= 1 / elementUnitConversionData[endValueUnitType + "ToPx"];
                                }
                            }
                        }

                        /*********************
                           Relative Values
                        *********************/

                        /* Operator logic must be performed last since it requires unit-normalized start and end values. */
                        /* Note: Relative *percent values* do not behave how most people think; while one would expect "+=50%"
                           to increase the property 1.5x its current value, it in fact increases the percent units in absolute terms:
                           50 points is added on top of the current % value. */
                        switch (operator) {
                            case "+":
                                endValue = startValue + endValue;
                                break;

                            case "-":
                                endValue = startValue - endValue;
                                break;

                            case "*":
                                endValue = startValue * endValue;
                                break;

                            case "/":
                                endValue = startValue / endValue;
                                break;
                        }

                        /**************************
                           tweensContainer Push
                        **************************/

                        /* Construct the per-property tween object, and push it to the element's tweensContainer. */
                        tweensContainer[property] = {
                            rootPropertyValue: rootPropertyValue,
                            startValue: startValue,
                            currentValue: startValue,
                            endValue: endValue,
                            unitType: endValueUnitType,
                            easing: easing
                        };

                        if (Velocity.debug) console.log("tweensContainer (" + property + "): " + JSON.stringify(tweensContainer[property]), element);
                    }

                    /* Along with its property data, store a reference to the element itself onto tweensContainer. */
                    tweensContainer.element = element;
                }

                /*****************
                    Call Push
                *****************/

                /* Note: tweensContainer can be empty if all of the properties in this call's property map were skipped due to not
                   being supported by the browser. The element property is used for checking that the tweensContainer has been appended to. */
                if (tweensContainer.element) {
                    /* Apply the "velocity-animating" indicator class. */
                    CSS.Values.addClass(element, "velocity-animating");

                    /* The call array houses the tweensContainers for each element being animated in the current call. */
                    call.push(tweensContainer);

                    /* Store the tweensContainer and options if we're working on the default effects queue, so that they can be used by the reverse command. */
                    if (opts.queue === "") {
                        Data(element).tweensContainer = tweensContainer;
                        Data(element).opts = opts;
                    }

                    /* Switch on the element's animating flag. */
                    Data(element).isAnimating = true;

                    /* Once the final element in this call's element set has been processed, push the call array onto
                       Velocity.State.calls for the animation tick to immediately begin processing. */
                    if (elementsIndex === elementsLength - 1) {
                        /* To speed up iterating over this array, it is compacted (falsey items -- calls that have completed -- are removed)
                           when its length has ballooned to a point that can impact tick performance. This only becomes necessary when animation
                           has been continuous with many elements over a long period of time; whenever all active calls are completed, completeCall() clears Velocity.State.calls. */
                        if (Velocity.State.calls.length > 10000) {
                            Velocity.State.calls = compactSparseArray(Velocity.State.calls);
                        }

                        /* Add the current call plus its associated metadata (the element set and the call's options) onto the global call container.
                           Anything on this call container is subjected to tick() processing. */
                        Velocity.State.calls.push([ call, elements, opts, null, promiseData.resolver ]);

                        /* If the animation tick isn't running, start it. (Velocity shuts it off when there are no active calls to process.) */
                        if (Velocity.State.isTicking === false) {
                            Velocity.State.isTicking = true;

                            /* Start the tick loop. */
                            tick();
                        }
                    } else {
                        elementsIndex++;
                    }
                }
            }

            /* When the queue option is set to false, the call skips the element's queue and fires immediately. */
            if (opts.queue === false) {
                /* Since this buildQueue call doesn't respect the element's existing queue (which is where a delay option would have been appended),
                   we manually inject the delay property here with an explicit setTimeout. */
                if (opts.delay) {
                    setTimeout(buildQueue, opts.delay);
                } else {
                    buildQueue();
                }
            /* Otherwise, the call undergoes element queueing as normal. */
            /* Note: To interoperate with jQuery, Velocity uses jQuery's own $.queue() stack for queuing logic. */
            } else {
                $.queue(element, opts.queue, function(next, clearQueue) {
                    /* If the clearQueue flag was passed in by the stop command, resolve this call's promise. (Promises can only be resolved once,
                       so it's fine if this is repeatedly triggered for each element in the associated call.) */
                    if (clearQueue === true) {
                        if (promiseData.promise) {
                            promiseData.resolver(elements);
                        }

                        /* Do not continue with animation queueing. */
                        return true;
                    }

                    /* This flag indicates to the upcoming completeCall() function that this queue entry was initiated by Velocity.
                       See completeCall() for further details. */
                    Velocity.velocityQueueEntryFlag = true;

                    buildQueue(next);
                });
            }

            /*********************
                Auto-Dequeuing
            *********************/

            /* As per jQuery's $.queue() behavior, to fire the first non-custom-queue entry on an element, the element
               must be dequeued if its queue stack consists *solely* of the current call. (This can be determined by checking
               for the "inprogress" item that jQuery prepends to active queue stack arrays.) Regardless, whenever the element's
               queue is further appended with additional items -- including $.delay()'s or even $.animate() calls, the queue's
               first entry is automatically fired. This behavior contrasts that of custom queues, which never auto-fire. */
            /* Note: When an element set is being subjected to a non-parallel Velocity call, the animation will not begin until
               each one of the elements in the set has reached the end of its individually pre-existing queue chain. */
            /* Note: Unfortunately, most people don't fully grasp jQuery's powerful, yet quirky, $.queue() function.
               Lean more here: http://stackoverflow.com/questions/1058158/can-somebody-explain-jquery-queue-to-me */
            if ((opts.queue === "" || opts.queue === "fx") && $.queue(element)[0] !== "inprogress") {
                $.dequeue(element);
            }
        }

        /**************************
           Element Set Iteration
        **************************/

        /* If the "nodeType" property exists on the elements variable, we're animating a single element.
           Place it in an array so that $.each() can iterate over it. */
        $.each(elements, function(i, element) {
            /* Ensure each element in a set has a nodeType (is a real element) to avoid throwing errors. */
            if (Type.isNode(element)) {
                processElement.call(element);
            }
        });

        /******************
           Option: Loop
        ******************/

        /* The loop option accepts an integer indicating how many times the element should loop between the values in the
           current call's properties map and the element's property values prior to this call. */
        /* Note: The loop option's logic is performed here -- after element processing -- because the current call needs
           to undergo its queue insertion prior to the loop option generating its series of constituent "reverse" calls,
           which chain after the current call. Two reverse calls (two "alternations") constitute one loop. */
        var opts = $.extend({}, Velocity.defaults, options),
            reverseCallsCount;

        opts.loop = parseInt(opts.loop);
        reverseCallsCount = (opts.loop * 2) - 1;

        if (opts.loop) {
            /* Double the loop count to convert it into its appropriate number of "reverse" calls.
               Subtract 1 from the resulting value since the current call is included in the total alternation count. */
            for (var x = 0; x < reverseCallsCount; x++) {
                /* Since the logic for the reverse action occurs inside Queueing and therefore this call's options object
                   isn't parsed until then as well, the current call's delay option must be explicitly passed into the reverse
                   call so that the delay logic that occurs inside *Pre-Queueing* can process it. */
                var reverseOptions = {
                    delay: opts.delay,
                    progress: opts.progress
                };

                /* If a complete callback was passed into this call, transfer it to the loop redirect's final "reverse" call
                   so that it's triggered when the entire redirect is complete (and not when the very first animation is complete). */
                if (x === reverseCallsCount - 1) {
                    reverseOptions.display = opts.display;
                    reverseOptions.visibility = opts.visibility;
                    reverseOptions.complete = opts.complete;
                }

                animate(elements, "reverse", reverseOptions);
            }
        }

        /***************
            Chaining
        ***************/

        /* Return the elements back to the call chain, with wrapped elements taking precedence in case Velocity was called via the $.fn. extension. */
        return getChain();
    };

    /* Turn Velocity into the animation function, extended with the pre-existing Velocity object. */
    Velocity = $.extend(animate, Velocity);
    /* For legacy support, also expose the literal animate method. */
    Velocity.animate = animate;

    /**************
        Timing
    **************/

    /* Ticker function. */
    var ticker = window.requestAnimationFrame || rAFShim;

    /* Inactive browser tabs pause rAF, which results in all active animations immediately sprinting to their completion states when the tab refocuses.
       To get around this, we dynamically switch rAF to setTimeout (which the browser *doesn't* pause) when the tab loses focus. We skip this for mobile
       devices to avoid wasting battery power on inactive tabs. */
    /* Note: Tab focus detection doesn't work on older versions of IE, but that's okay since they don't support rAF to begin with. */
    if (!Velocity.State.isMobile && document.hidden !== undefined) {
        document.addEventListener("visibilitychange", function() {
            /* Reassign the rAF function (which the global tick() function uses) based on the tab's focus state. */
            if (document.hidden) {
                ticker = function(callback) {
                    /* The tick function needs a truthy first argument in order to pass its internal timestamp check. */
                    return setTimeout(function() { callback(true) }, 16);
                };

                /* The rAF loop has been paused by the browser, so we manually restart the tick. */
                tick();
            } else {
                ticker = window.requestAnimationFrame || rAFShim;
            }
        });
    }

    /************
        Tick
    ************/

    /* Note: All calls to Velocity are pushed to the Velocity.State.calls array, which is fully iterated through upon each tick. */
    function tick (timestamp) {
        /* An empty timestamp argument indicates that this is the first tick occurence since ticking was turned on.
           We leverage this metadata to fully ignore the first tick pass since RAF's initial pass is fired whenever
           the browser's next tick sync time occurs, which results in the first elements subjected to Velocity
           calls being animated out of sync with any elements animated immediately thereafter. In short, we ignore
           the first RAF tick pass so that elements being immediately consecutively animated -- instead of simultaneously animated
           by the same Velocity call -- are properly batched into the same initial RAF tick and consequently remain in sync thereafter. */
        if (timestamp) {
            /* We ignore RAF's high resolution timestamp since it can be significantly offset when the browser is
               under high stress; we opt for choppiness over allowing the browser to drop huge chunks of frames. */
            var timeCurrent = (new Date).getTime();

            /********************
               Call Iteration
            ********************/

            /* Iterate through each active call. */
            for (var i = 0, callsLength = Velocity.State.calls.length; i < callsLength; i++) {
                /* When a Velocity call is completed, its Velocity.State.calls entry is set to false. Continue on to the next call. */
                if (!Velocity.State.calls[i]) {
                    continue;
                }

                /************************
                   Call-Wide Variables
                ************************/

                var callContainer = Velocity.State.calls[i],
                    call = callContainer[0],
                    opts = callContainer[2],
                    timeStart = callContainer[3],
                    firstTick = !!timeStart;

                /* If timeStart is undefined, then this is the first time that this call has been processed by tick().
                   We assign timeStart now so that its value is as close to the real animation start time as possible.
                   (Conversely, had timeStart been defined when this call was added to Velocity.State.calls, the delay
                   between that time and now would cause the first few frames of the tween to be skipped since
                   percentComplete is calculated relative to timeStart.) */
                /* Further, subtract 16ms (the approximate resolution of RAF) from the current time value so that the
                   first tick iteration isn't wasted by animating at 0% tween completion, which would produce the
                   same style value as the element's current value. */
                if (!timeStart) {
                    timeStart = Velocity.State.calls[i][3] = timeCurrent - 16;
                }

                /* The tween's completion percentage is relative to the tween's start time, not the tween's start value
                   (which would result in unpredictable tween durations since JavaScript's timers are not particularly accurate).
                   Accordingly, we ensure that percentComplete does not exceed 1. */
                var percentComplete = Math.min((timeCurrent - timeStart) / opts.duration, 1);

                /**********************
                   Element Iteration
                **********************/

                /* For every call, iterate through each of the elements in its set. */
                for (var j = 0, callLength = call.length; j < callLength; j++) {
                    var tweensContainer = call[j],
                        element = tweensContainer.element;

                    /* Check to see if this element has been deleted midway through the animation by checking for the
                       continued existence of its data cache. If it's gone, skip animating this element. */
                    if (!Data(element)) {
                        continue;
                    }

                    var transformPropertyExists = false;

                    /**********************************
                       Display & Visibility Toggling
                    **********************************/

                    /* If the display option is set to non-"none", set it upfront so that the element can become visible before tweening begins.
                       (Otherwise, display's "none" value is set in completeCall() once the animation has completed.) */
                    if (opts.display !== undefined && opts.display !== null && opts.display !== "none") {
                        if (opts.display === "flex") {
                            var flexValues = [ "-webkit-box", "-moz-box", "-ms-flexbox", "-webkit-flex" ];

                            $.each(flexValues, function(i, flexValue) {
                                CSS.setPropertyValue(element, "display", flexValue);
                            });
                        }

                        CSS.setPropertyValue(element, "display", opts.display);
                    }

                    /* Same goes with the visibility option, but its "none" equivalent is "hidden". */
                    if (opts.visibility !== undefined && opts.visibility !== "hidden") {
                        CSS.setPropertyValue(element, "visibility", opts.visibility);
                    }

                    /************************
                       Property Iteration
                    ************************/

                    /* For every element, iterate through each property. */
                    for (var property in tweensContainer) {
                        /* Note: In addition to property tween data, tweensContainer contains a reference to its associated element. */
                        if (property !== "element") {
                            var tween = tweensContainer[property],
                                currentValue,
                                /* Easing can either be a pre-genereated function or a string that references a pre-registered easing
                                   on the Velocity.Easings object. In either case, return the appropriate easing *function*. */
                                easing = Type.isString(tween.easing) ? Velocity.Easings[tween.easing] : tween.easing;

                            /******************************
                               Current Value Calculation
                            ******************************/

                            /* If this is the last tick pass (if we've reached 100% completion for this tween),
                               ensure that currentValue is explicitly set to its target endValue so that it's not subjected to any rounding. */
                            if (percentComplete === 1) {
                                currentValue = tween.endValue;
                            /* Otherwise, calculate currentValue based on the current delta from startValue. */
                            } else {
                                currentValue = tween.startValue + ((tween.endValue - tween.startValue) * easing(percentComplete));

                                /* If no value change is occurring, don't proceed with DOM updating. */
                                if (!firstTick && (currentValue === tween.currentValue)) {
                                    continue;
                                }
                            }

                            tween.currentValue = currentValue;

                            /******************
                               Hooks: Part I
                            ******************/

                            /* For hooked properties, the newly-updated rootPropertyValueCache is cached onto the element so that it can be used
                               for subsequent hooks in this call that are associated with the same root property. If we didn't cache the updated
                               rootPropertyValue, each subsequent update to the root property in this tick pass would reset the previous hook's
                               updates to rootPropertyValue prior to injection. A nice performance byproduct of rootPropertyValue caching is that
                               subsequently chained animations using the same hookRoot but a different hook can use this cached rootPropertyValue. */
                            if (CSS.Hooks.registered[property]) {
                                var hookRoot = CSS.Hooks.getRoot(property),
                                    rootPropertyValueCache = Data(element).rootPropertyValueCache[hookRoot];

                                if (rootPropertyValueCache) {
                                    tween.rootPropertyValue = rootPropertyValueCache;
                                }
                            }

                            /*****************
                                DOM Update
                            *****************/

                            /* setPropertyValue() returns an array of the property name and property value post any normalization that may have been performed. */
                            /* Note: To solve an IE<=8 positioning bug, the unit type is dropped when setting a property value of 0. */
                            var adjustedSetData = CSS.setPropertyValue(element, /* SET */
                                                                       property,
                                                                       tween.currentValue + (parseFloat(currentValue) === 0 ? "" : tween.unitType),
                                                                       tween.rootPropertyValue,
                                                                       tween.scrollData);

                            /*******************
                               Hooks: Part II
                            *******************/

                            /* Now that we have the hook's updated rootPropertyValue (the post-processed value provided by adjustedSetData), cache it onto the element. */
                            if (CSS.Hooks.registered[property]) {
                                /* Since adjustedSetData contains normalized data ready for DOM updating, the rootPropertyValue needs to be re-extracted from its normalized form. ?? */
                                if (CSS.Normalizations.registered[hookRoot]) {
                                    Data(element).rootPropertyValueCache[hookRoot] = CSS.Normalizations.registered[hookRoot]("extract", null, adjustedSetData[1]);
                                } else {
                                    Data(element).rootPropertyValueCache[hookRoot] = adjustedSetData[1];
                                }
                            }

                            /***************
                               Transforms
                            ***************/

                            /* Flag whether a transform property is being animated so that flushTransformCache() can be triggered once this tick pass is complete. */
                            if (adjustedSetData[0] === "transform") {
                                transformPropertyExists = true;
                            }
                        }
                    }

                    /****************
                        mobileHA
                    ****************/

                    /* If mobileHA is enabled, set the translate3d transform to null to force hardware acceleration.
                       It's safe to override this property since Velocity doesn't actually support its animation (hooks are used in its place). */
                    if (opts.mobileHA) {
                        /* Don't set the null transform hack if we've already done so. */
                        if (Data(element).transformCache.translate3d === undefined) {
                            /* All entries on the transformCache object are later concatenated into a single transform string via flushTransformCache(). */
                            Data(element).transformCache.translate3d = "(0px, 0px, 0px)";

                            transformPropertyExists = true;
                        }
                    }

                    if (transformPropertyExists) {
                        CSS.flushTransformCache(element);
                    }
                }

                /* The non-"none" display value is only applied to an element once -- when its associated call is first ticked through.
                   Accordingly, it's set to false so that it isn't re-processed by this call in the next tick. */
                if (opts.display !== undefined && opts.display !== "none") {
                    Velocity.State.calls[i][2].display = false;
                }
                if (opts.visibility !== undefined && opts.visibility !== "hidden") {
                    Velocity.State.calls[i][2].visibility = false;
                }


                /* Pass the elements and the timing data (percentComplete, msRemaining, and timeStart) into the progress callback. */
                if (opts.progress) {
                    opts.progress.call(callContainer[1],
                                       callContainer[1],
                                       percentComplete,
                                       Math.max(0, (timeStart + opts.duration) - timeCurrent),
                                       timeStart);
                }

                /* If this call has finished tweening, pass its index to completeCall() to handle call cleanup. */
                if (percentComplete === 1) {
                    completeCall(i);
                }
            }
        }

        /* Note: completeCall() sets the isTicking flag to false when the last call on Velocity.State.calls has completed. */
        if (Velocity.State.isTicking) {
            ticker(tick);
        }
    }

    /**********************
        Call Completion
    **********************/

    /* Note: Unlike tick(), which processes all active calls at once, call completion is handled on a per-call basis. */
    function completeCall (callIndex, isStopped) {
        /* Ensure the call exists. */
        if (!Velocity.State.calls[callIndex]) {
            return false;
        }

        /* Pull the metadata from the call. */
        var call = Velocity.State.calls[callIndex][0],
            elements = Velocity.State.calls[callIndex][1],
            opts = Velocity.State.calls[callIndex][2],
            resolver = Velocity.State.calls[callIndex][4];

        var remainingCallsExist = false;

        /*************************
           Element Finalization
        *************************/

        for (var i = 0, callLength = call.length; i < callLength; i++) {
            var element = call[i].element;

            /* If the user set display to "none" (intending to hide the element), set it now that the animation has completed. */
            /* Note: display:none isn't set when calls are manually stopped (via Velocity("stop"). */
            /* Note: Display gets ignored with "reverse" calls and infinite loops, since this behavior would be undesirable. */
            if (!isStopped && !opts.loop) {
                if (opts.display === "none") {
                    CSS.setPropertyValue(element, "display", opts.display);
                }

                if (opts.visibility === "hidden") {
                    CSS.setPropertyValue(element, "visibility", opts.visibility);
                }
            }

            /* If the element's queue is empty (if only the "inprogress" item is left at position 0) or if its queue is about to run
               a non-Velocity-initiated entry, turn off the isAnimating flag. A non-Velocity-initiatied queue entry's logic might alter
               an element's CSS values and thereby cause Velocity's cached value data to go stale. To detect if a queue entry was initiated by Velocity,
               we check for the existence of our special Velocity.queueEntryFlag declaration, which minifiers won't rename since the flag
               is assigned to jQuery's global $ object and thus exists out of Velocity's own scope. */
            if (opts.loop !== true && ($.queue(element)[1] === undefined || !/\.velocityQueueEntryFlag/i.test($.queue(element)[1]))) {
                /* The element may have been deleted. Ensure that its data cache still exists before acting on it. */
                if (Data(element)) {
                    Data(element).isAnimating = false;
                    /* Clear the element's rootPropertyValueCache, which will become stale. */
                    Data(element).rootPropertyValueCache = {};

                    var transformHAPropertyExists = false;
                    /* If any 3D transform subproperty is at its default value (regardless of unit type), remove it. */
                    $.each(CSS.Lists.transforms3D, function(i, transformName) {
                        var defaultValue = /^scale/.test(transformName) ? 1 : 0,
                            currentValue = Data(element).transformCache[transformName];

                        if (Data(element).transformCache[transformName] !== undefined && new RegExp("^\\(" + defaultValue + "[^.]").test(currentValue)) {
                            transformHAPropertyExists = true;

                            delete Data(element).transformCache[transformName];
                        }
                    });

                    /* Mobile devices have hardware acceleration removed at the end of the animation in order to avoid hogging the GPU's memory. */
                    if (opts.mobileHA) {
                        transformHAPropertyExists = true;
                        delete Data(element).transformCache.translate3d;
                    }

                    /* Flush the subproperty removals to the DOM. */
                    if (transformHAPropertyExists) {
                        CSS.flushTransformCache(element);
                    }

                    /* Remove the "velocity-animating" indicator class. */
                    CSS.Values.removeClass(element, "velocity-animating");
                }
            }

            /*********************
               Option: Complete
            *********************/

            /* Complete is fired once per call (not once per element) and is passed the full raw DOM element set as both its context and its first argument. */
            /* Note: Callbacks aren't fired when calls are manually stopped (via Velocity("stop"). */
            if (!isStopped && opts.complete && !opts.loop && (i === callLength - 1)) {
                /* We throw callbacks in a setTimeout so that thrown errors don't halt the execution of Velocity itself. */
                try {
                    opts.complete.call(elements, elements);
                } catch (error) {
                    setTimeout(function() { throw error; }, 1);
                }
            }

            /**********************
               Promise Resolving
            **********************/

            /* Note: Infinite loops don't return promises. */
            if (resolver && opts.loop !== true) {
                resolver(elements);
            }

            /****************************
               Option: Loop (Infinite)
            ****************************/

            if (opts.loop === true && !isStopped) {
                /* If a rotateX/Y/Z property is being animated to 360 deg with loop:true, swap tween start/end values to enable
                   continuous iterative rotation looping. (Otherise, the element would just rotate back and forth.) */
                $.each(Data(element).tweensContainer, function(propertyName, tweenContainer) {
                    if (/^rotate/.test(propertyName) && parseFloat(tweenContainer.endValue) === 360) {
                        tweenContainer.endValue = 0;
                        tweenContainer.startValue = 360;
                    }
                });

                Velocity(element, "reverse", { loop: true, delay: opts.delay });
            }

            /***************
               Dequeueing
            ***************/

            /* Fire the next call in the queue so long as this call's queue wasn't set to false (to trigger a parallel animation),
               which would have already caused the next call to fire. Note: Even if the end of the animation queue has been reached,
               $.dequeue() must still be called in order to completely clear jQuery's animation queue. */
            if (opts.queue !== false) {
                $.dequeue(element, opts.queue);
            }
        }

        /************************
           Calls Array Cleanup
        ************************/

        /* Since this call is complete, set it to false so that the rAF tick skips it. This array is later compacted via compactSparseArray().
          (For performance reasons, the call is set to false instead of being deleted from the array: http://www.html5rocks.com/en/tutorials/speed/v8/) */
        Velocity.State.calls[callIndex] = false;

        /* Iterate through the calls array to determine if this was the final in-progress animation.
           If so, set a flag to end ticking and clear the calls array. */
        for (var j = 0, callsLength = Velocity.State.calls.length; j < callsLength; j++) {
            if (Velocity.State.calls[j] !== false) {
                remainingCallsExist = true;

                break;
            }
        }

        if (remainingCallsExist === false) {
            /* tick() will detect this flag upon its next iteration and subsequently turn itself off. */
            Velocity.State.isTicking = false;

            /* Clear the calls array so that its length is reset. */
            delete Velocity.State.calls;
            Velocity.State.calls = [];
        }
    }

    /******************
        Frameworks
    ******************/

    /* Both jQuery and Zepto allow their $.fn object to be extended to allow wrapped elements to be subjected to plugin calls.
       If either framework is loaded, register a "velocity" extension pointing to Velocity's core animate() method.  Velocity
       also registers itself onto a global container (window.jQuery || window.Zepto || window) so that certain features are
       accessible beyond just a per-element scope. This master object contains an .animate() method, which is later assigned to $.fn
       (if jQuery or Zepto are present). Accordingly, Velocity can both act on wrapped DOM elements and stand alone for targeting raw DOM elements. */
    global.Velocity = Velocity;

    if (global !== window) {
        /* Assign the element function to Velocity's core animate() method. */
        global.fn.velocity = animate;
        /* Assign the object function's defaults to Velocity's global defaults object. */
        global.fn.velocity.defaults = Velocity.defaults;
    }

    /***********************
       Packaged Redirects
    ***********************/

    /* slideUp, slideDown */
    $.each([ "Down", "Up" ], function(i, direction) {
        Velocity.Redirects["slide" + direction] = function (element, options, elementsIndex, elementsSize, elements, promiseData) {
            var opts = $.extend({}, options),
                begin = opts.begin,
                complete = opts.complete,
                computedValues = { height: "", marginTop: "", marginBottom: "", paddingTop: "", paddingBottom: "" },
                inlineValues = {};

            if (opts.display === undefined) {
                /* Show the element before slideDown begins and hide the element after slideUp completes. */
                /* Note: Inline elements cannot have dimensions animated, so they're reverted to inline-block. */
                opts.display = (direction === "Down" ? (Velocity.CSS.Values.getDisplayType(element) === "inline" ? "inline-block" : "block") : "none");
            }

            opts.begin = function() {
                /* If the user passed in a begin callback, fire it now. */
                begin && begin.call(elements, elements);

                /* Cache the elements' original vertical dimensional property values so that we can animate back to them. */
                for (var property in computedValues) {
                    /* Cache all inline values, we reset to upon animation completion. */
                    inlineValues[property] = element.style[property];

                    /* For slideDown, use forcefeeding to animate all vertical properties from 0. For slideUp,
                       use forcefeeding to start from computed values and animate down to 0. */
                    var propertyValue = Velocity.CSS.getPropertyValue(element, property);
                    computedValues[property] = (direction === "Down") ? [ propertyValue, 0 ] : [ 0, propertyValue ];
                }

                /* Force vertical overflow content to clip so that sliding works as expected. */
                inlineValues.overflow = element.style.overflow;
                element.style.overflow = "hidden";
            }

            opts.complete = function() {
                /* Reset element to its pre-slide inline values once its slide animation is complete. */
                for (var property in inlineValues) {
                    element.style[property] = inlineValues[property];
                }

                /* If the user passed in a complete callback, fire it now. */
                complete && complete.call(elements, elements);
                promiseData && promiseData.resolver(elements);
            };

            Velocity(element, computedValues, opts);
        };
    });

    /* fadeIn, fadeOut */
    $.each([ "In", "Out" ], function(i, direction) {
        Velocity.Redirects["fade" + direction] = function (element, options, elementsIndex, elementsSize, elements, promiseData) {
            var opts = $.extend({}, options),
                propertiesMap = { opacity: (direction === "In") ? 1 : 0 },
                originalComplete = opts.complete;

            /* Since redirects are triggered individually for each element in the animated set, avoid repeatedly triggering
               callbacks by firing them only when the final element has been reached. */
            if (elementsIndex !== elementsSize - 1) {
                opts.complete = opts.begin = null;
            } else {
                opts.complete = function() {
                    if (originalComplete) {
                        originalComplete.call(elements, elements);
                    }

                    promiseData && promiseData.resolver(elements);
                }
            }

            /* If a display was passed in, use it. Otherwise, default to "none" for fadeOut or the element-specific default for fadeIn. */
            /* Note: We allow users to pass in "null" to skip display setting altogether. */
            if (opts.display === undefined) {
                opts.display = (direction === "In" ? "auto" : "none");
            }

            Velocity(this, propertiesMap, opts);
        };
    });

    return Velocity;
}((window.jQuery || window.Zepto || window), window, document);
}));

/******************
   Known Issues
******************/

/* The CSS spec mandates that the translateX/Y/Z transforms are %-relative to the element itself -- not its parent.
Velocity, however, doesn't make this distinction. Thus, converting to or from the % unit with these subproperties
will produce an inaccurate conversion value. The same issue exists with the cx/cy attributes of SVG circles and ellipses. */
/**
 * @license AngularJS v1.3.20
 * (c) 2010-2014 Google, Inc. http://angularjs.org
 * License: MIT
 */
(function(window, document, undefined) {'use strict';

/**
 * @description
 *
 * This object provides a utility for producing rich Error messages within
 * Angular. It can be called as follows:
 *
 * var exampleMinErr = minErr('example');
 * throw exampleMinErr('one', 'This {0} is {1}', foo, bar);
 *
 * The above creates an instance of minErr in the example namespace. The
 * resulting error will have a namespaced error code of example.one.  The
 * resulting error will replace {0} with the value of foo, and {1} with the
 * value of bar. The object is not restricted in the number of arguments it can
 * take.
 *
 * If fewer arguments are specified than necessary for interpolation, the extra
 * interpolation markers will be preserved in the final string.
 *
 * Since data will be parsed statically during a build step, some restrictions
 * are applied with respect to how minErr instances are created and called.
 * Instances should have names of the form namespaceMinErr for a minErr created
 * using minErr('namespace') . Error codes, namespaces and template strings
 * should all be static strings, not variables or general expressions.
 *
 * @param {string} module The namespace to use for the new minErr instance.
 * @param {function} ErrorConstructor Custom error constructor to be instantiated when returning
 *   error from returned function, for cases when a particular type of error is useful.
 * @returns {function(code:string, template:string, ...templateArgs): Error} minErr instance
 */

function minErr(module, ErrorConstructor) {
  ErrorConstructor = ErrorConstructor || Error;
  return function() {
    var code = arguments[0],
      prefix = '[' + (module ? module + ':' : '') + code + '] ',
      template = arguments[1],
      templateArgs = arguments,

      message, i;

    message = prefix + template.replace(/\{\d+\}/g, function(match) {
      var index = +match.slice(1, -1), arg;

      if (index + 2 < templateArgs.length) {
        return toDebugString(templateArgs[index + 2]);
      }
      return match;
    });

    message = message + '\nhttp://errors.angularjs.org/1.3.20/' +
      (module ? module + '/' : '') + code;
    for (i = 2; i < arguments.length; i++) {
      message = message + (i == 2 ? '?' : '&') + 'p' + (i - 2) + '=' +
        encodeURIComponent(toDebugString(arguments[i]));
    }
    return new ErrorConstructor(message);
  };
}

/* We need to tell jshint what variables are being exported */
/* global angular: true,
  msie: true,
  jqLite: true,
  jQuery: true,
  slice: true,
  splice: true,
  push: true,
  toString: true,
  ngMinErr: true,
  angularModule: true,
  uid: true,
  REGEX_STRING_REGEXP: true,
  VALIDITY_STATE_PROPERTY: true,

  lowercase: true,
  uppercase: true,
  manualLowercase: true,
  manualUppercase: true,
  nodeName_: true,
  isArrayLike: true,
  forEach: true,
  sortedKeys: true,
  forEachSorted: true,
  reverseParams: true,
  nextUid: true,
  setHashKey: true,
  extend: true,
  int: true,
  inherit: true,
  noop: true,
  identity: true,
  valueFn: true,
  isUndefined: true,
  isDefined: true,
  isObject: true,
  isString: true,
  isNumber: true,
  isDate: true,
  isArray: true,
  isFunction: true,
  isRegExp: true,
  isWindow: true,
  isScope: true,
  isFile: true,
  isFormData: true,
  isBlob: true,
  isBoolean: true,
  isPromiseLike: true,
  trim: true,
  escapeForRegexp: true,
  isElement: true,
  makeMap: true,
  includes: true,
  arrayRemove: true,
  copy: true,
  shallowCopy: true,
  equals: true,
  csp: true,
  concat: true,
  sliceArgs: true,
  bind: true,
  toJsonReplacer: true,
  toJson: true,
  fromJson: true,
  startingTag: true,
  tryDecodeURIComponent: true,
  parseKeyValue: true,
  toKeyValue: true,
  encodeUriSegment: true,
  encodeUriQuery: true,
  angularInit: true,
  bootstrap: true,
  getTestability: true,
  snake_case: true,
  bindJQuery: true,
  assertArg: true,
  assertArgFn: true,
  assertNotHasOwnProperty: true,
  getter: true,
  getBlockNodes: true,
  hasOwnProperty: true,
  createMap: true,

  NODE_TYPE_ELEMENT: true,
  NODE_TYPE_ATTRIBUTE: true,
  NODE_TYPE_TEXT: true,
  NODE_TYPE_COMMENT: true,
  NODE_TYPE_DOCUMENT: true,
  NODE_TYPE_DOCUMENT_FRAGMENT: true,
*/

////////////////////////////////////

/**
 * @ngdoc module
 * @name ng
 * @module ng
 * @description
 *
 * # ng (core module)
 * The ng module is loaded by default when an AngularJS application is started. The module itself
 * contains the essential components for an AngularJS application to function. The table below
 * lists a high level breakdown of each of the services/factories, filters, directives and testing
 * components available within this core module.
 *
 * <div doc-module-components="ng"></div>
 */

var REGEX_STRING_REGEXP = /^\/(.+)\/([a-z]*)$/;

// The name of a form control's ValidityState property.
// This is used so that it's possible for internal tests to create mock ValidityStates.
var VALIDITY_STATE_PROPERTY = 'validity';

/**
 * @ngdoc function
 * @name angular.lowercase
 * @module ng
 * @kind function
 *
 * @description Converts the specified string to lowercase.
 * @param {string} string String to be converted to lowercase.
 * @returns {string} Lowercased string.
 */
var lowercase = function(string) {return isString(string) ? string.toLowerCase() : string;};
var hasOwnProperty = Object.prototype.hasOwnProperty;

/**
 * @ngdoc function
 * @name angular.uppercase
 * @module ng
 * @kind function
 *
 * @description Converts the specified string to uppercase.
 * @param {string} string String to be converted to uppercase.
 * @returns {string} Uppercased string.
 */
var uppercase = function(string) {return isString(string) ? string.toUpperCase() : string;};


var manualLowercase = function(s) {
  /* jshint bitwise: false */
  return isString(s)
      ? s.replace(/[A-Z]/g, function(ch) {return String.fromCharCode(ch.charCodeAt(0) | 32);})
      : s;
};
var manualUppercase = function(s) {
  /* jshint bitwise: false */
  return isString(s)
      ? s.replace(/[a-z]/g, function(ch) {return String.fromCharCode(ch.charCodeAt(0) & ~32);})
      : s;
};


// String#toLowerCase and String#toUpperCase don't produce correct results in browsers with Turkish
// locale, for this reason we need to detect this case and redefine lowercase/uppercase methods
// with correct but slower alternatives.
if ('i' !== 'I'.toLowerCase()) {
  lowercase = manualLowercase;
  uppercase = manualUppercase;
}


var
    msie,             // holds major version number for IE, or NaN if UA is not IE.
    jqLite,           // delay binding since jQuery could be loaded after us.
    jQuery,           // delay binding
    slice             = [].slice,
    splice            = [].splice,
    push              = [].push,
    toString          = Object.prototype.toString,
    ngMinErr          = minErr('ng'),

    /** @name angular */
    angular           = window.angular || (window.angular = {}),
    angularModule,
    uid               = 0;

/**
 * documentMode is an IE-only property
 * http://msdn.microsoft.com/en-us/library/ie/cc196988(v=vs.85).aspx
 */
msie = document.documentMode;


/**
 * @private
 * @param {*} obj
 * @return {boolean} Returns true if `obj` is an array or array-like object (NodeList, Arguments,
 *                   String ...)
 */
function isArrayLike(obj) {
  if (obj == null || isWindow(obj)) {
    return false;
  }

  // Support: iOS 8.2 (not reproducible in simulator)
  // "length" in obj used to prevent JIT error (gh-11508)
  var length = "length" in Object(obj) && obj.length;

  if (obj.nodeType === NODE_TYPE_ELEMENT && length) {
    return true;
  }

  return isString(obj) || isArray(obj) || length === 0 ||
         typeof length === 'number' && length > 0 && (length - 1) in obj;
}

/**
 * @ngdoc function
 * @name angular.forEach
 * @module ng
 * @kind function
 *
 * @description
 * Invokes the `iterator` function once for each item in `obj` collection, which can be either an
 * object or an array. The `iterator` function is invoked with `iterator(value, key, obj)`, where `value`
 * is the value of an object property or an array element, `key` is the object property key or
 * array element index and obj is the `obj` itself. Specifying a `context` for the function is optional.
 *
 * It is worth noting that `.forEach` does not iterate over inherited properties because it filters
 * using the `hasOwnProperty` method.
 *
 * Unlike ES262's
 * [Array.prototype.forEach](http://www.ecma-international.org/ecma-262/5.1/#sec-15.4.4.18),
 * Providing 'undefined' or 'null' values for `obj` will not throw a TypeError, but rather just
 * return the value provided.
 *
   ```js
     var values = {name: 'misko', gender: 'male'};
     var log = [];
     angular.forEach(values, function(value, key) {
       this.push(key + ': ' + value);
     }, log);
     expect(log).toEqual(['name: misko', 'gender: male']);
   ```
 *
 * @param {Object|Array} obj Object to iterate over.
 * @param {Function} iterator Iterator function.
 * @param {Object=} context Object to become context (`this`) for the iterator function.
 * @returns {Object|Array} Reference to `obj`.
 */

function forEach(obj, iterator, context) {
  var key, length;
  if (obj) {
    if (isFunction(obj)) {
      for (key in obj) {
        // Need to check if hasOwnProperty exists,
        // as on IE8 the result of querySelectorAll is an object without a hasOwnProperty function
        if (key != 'prototype' && key != 'length' && key != 'name' && (!obj.hasOwnProperty || obj.hasOwnProperty(key))) {
          iterator.call(context, obj[key], key, obj);
        }
      }
    } else if (isArray(obj) || isArrayLike(obj)) {
      var isPrimitive = typeof obj !== 'object';
      for (key = 0, length = obj.length; key < length; key++) {
        if (isPrimitive || key in obj) {
          iterator.call(context, obj[key], key, obj);
        }
      }
    } else if (obj.forEach && obj.forEach !== forEach) {
        obj.forEach(iterator, context, obj);
    } else {
      for (key in obj) {
        if (obj.hasOwnProperty(key)) {
          iterator.call(context, obj[key], key, obj);
        }
      }
    }
  }
  return obj;
}

function sortedKeys(obj) {
  return Object.keys(obj).sort();
}

function forEachSorted(obj, iterator, context) {
  var keys = sortedKeys(obj);
  for (var i = 0; i < keys.length; i++) {
    iterator.call(context, obj[keys[i]], keys[i]);
  }
  return keys;
}


/**
 * when using forEach the params are value, key, but it is often useful to have key, value.
 * @param {function(string, *)} iteratorFn
 * @returns {function(*, string)}
 */
function reverseParams(iteratorFn) {
  return function(value, key) { iteratorFn(key, value); };
}

/**
 * A consistent way of creating unique IDs in angular.
 *
 * Using simple numbers allows us to generate 28.6 million unique ids per second for 10 years before
 * we hit number precision issues in JavaScript.
 *
 * Math.pow(2,53) / 60 / 60 / 24 / 365 / 10 = 28.6M
 *
 * @returns {number} an unique alpha-numeric string
 */
function nextUid() {
  return ++uid;
}


/**
 * Set or clear the hashkey for an object.
 * @param obj object
 * @param h the hashkey (!truthy to delete the hashkey)
 */
function setHashKey(obj, h) {
  if (h) {
    obj.$$hashKey = h;
  } else {
    delete obj.$$hashKey;
  }
}

/**
 * @ngdoc function
 * @name angular.extend
 * @module ng
 * @kind function
 *
 * @description
 * Extends the destination object `dst` by copying own enumerable properties from the `src` object(s)
 * to `dst`. You can specify multiple `src` objects. If you want to preserve original objects, you can do so
 * by passing an empty object as the target: `var object = angular.extend({}, object1, object2)`.
 * Note: Keep in mind that `angular.extend` does not support recursive merge (deep copy).
 *
 * @param {Object} dst Destination object.
 * @param {...Object} src Source object(s).
 * @returns {Object} Reference to `dst`.
 */
function extend(dst) {
  var h = dst.$$hashKey;

  for (var i = 1, ii = arguments.length; i < ii; i++) {
    var obj = arguments[i];
    if (obj) {
      var keys = Object.keys(obj);
      for (var j = 0, jj = keys.length; j < jj; j++) {
        var key = keys[j];
        dst[key] = obj[key];
      }
    }
  }

  setHashKey(dst, h);
  return dst;
}

function int(str) {
  return parseInt(str, 10);
}


function inherit(parent, extra) {
  return extend(Object.create(parent), extra);
}

/**
 * @ngdoc function
 * @name angular.noop
 * @module ng
 * @kind function
 *
 * @description
 * A function that performs no operations. This function can be useful when writing code in the
 * functional style.
   ```js
     function foo(callback) {
       var result = calculateResult();
       (callback || angular.noop)(result);
     }
   ```
 */
function noop() {}
noop.$inject = [];


/**
 * @ngdoc function
 * @name angular.identity
 * @module ng
 * @kind function
 *
 * @description
 * A function that returns its first argument. This function is useful when writing code in the
 * functional style.
 *
   ```js
     function transformer(transformationFn, value) {
       return (transformationFn || angular.identity)(value);
     };
   ```
  * @param {*} value to be returned.
  * @returns {*} the value passed in.
 */
function identity($) {return $;}
identity.$inject = [];


function valueFn(value) {return function() {return value;};}

/**
 * @ngdoc function
 * @name angular.isUndefined
 * @module ng
 * @kind function
 *
 * @description
 * Determines if a reference is undefined.
 *
 * @param {*} value Reference to check.
 * @returns {boolean} True if `value` is undefined.
 */
function isUndefined(value) {return typeof value === 'undefined';}


/**
 * @ngdoc function
 * @name angular.isDefined
 * @module ng
 * @kind function
 *
 * @description
 * Determines if a reference is defined.
 *
 * @param {*} value Reference to check.
 * @returns {boolean} True if `value` is defined.
 */
function isDefined(value) {return typeof value !== 'undefined';}


/**
 * @ngdoc function
 * @name angular.isObject
 * @module ng
 * @kind function
 *
 * @description
 * Determines if a reference is an `Object`. Unlike `typeof` in JavaScript, `null`s are not
 * considered to be objects. Note that JavaScript arrays are objects.
 *
 * @param {*} value Reference to check.
 * @returns {boolean} True if `value` is an `Object` but not `null`.
 */
function isObject(value) {
  // http://jsperf.com/isobject4
  return value !== null && typeof value === 'object';
}


/**
 * @ngdoc function
 * @name angular.isString
 * @module ng
 * @kind function
 *
 * @description
 * Determines if a reference is a `String`.
 *
 * @param {*} value Reference to check.
 * @returns {boolean} True if `value` is a `String`.
 */
function isString(value) {return typeof value === 'string';}


/**
 * @ngdoc function
 * @name angular.isNumber
 * @module ng
 * @kind function
 *
 * @description
 * Determines if a reference is a `Number`.
 *
 * This includes the "special" numbers `NaN`, `+Infinity` and `-Infinity`.
 *
 * If you wish to exclude these then you can use the native
 * [`isFinite'](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/isFinite)
 * method.
 *
 * @param {*} value Reference to check.
 * @returns {boolean} True if `value` is a `Number`.
 */
function isNumber(value) {return typeof value === 'number';}


/**
 * @ngdoc function
 * @name angular.isDate
 * @module ng
 * @kind function
 *
 * @description
 * Determines if a value is a date.
 *
 * @param {*} value Reference to check.
 * @returns {boolean} True if `value` is a `Date`.
 */
function isDate(value) {
  return toString.call(value) === '[object Date]';
}


/**
 * @ngdoc function
 * @name angular.isArray
 * @module ng
 * @kind function
 *
 * @description
 * Determines if a reference is an `Array`.
 *
 * @param {*} value Reference to check.
 * @returns {boolean} True if `value` is an `Array`.
 */
var isArray = Array.isArray;

/**
 * @ngdoc function
 * @name angular.isFunction
 * @module ng
 * @kind function
 *
 * @description
 * Determines if a reference is a `Function`.
 *
 * @param {*} value Reference to check.
 * @returns {boolean} True if `value` is a `Function`.
 */
function isFunction(value) {return typeof value === 'function';}


/**
 * Determines if a value is a regular expression object.
 *
 * @private
 * @param {*} value Reference to check.
 * @returns {boolean} True if `value` is a `RegExp`.
 */
function isRegExp(value) {
  return toString.call(value) === '[object RegExp]';
}


/**
 * Checks if `obj` is a window object.
 *
 * @private
 * @param {*} obj Object to check
 * @returns {boolean} True if `obj` is a window obj.
 */
function isWindow(obj) {
  return obj && obj.window === obj;
}


function isScope(obj) {
  return obj && obj.$evalAsync && obj.$watch;
}


function isFile(obj) {
  return toString.call(obj) === '[object File]';
}


function isFormData(obj) {
  return toString.call(obj) === '[object FormData]';
}


function isBlob(obj) {
  return toString.call(obj) === '[object Blob]';
}


function isBoolean(value) {
  return typeof value === 'boolean';
}


function isPromiseLike(obj) {
  return obj && isFunction(obj.then);
}


var trim = function(value) {
  return isString(value) ? value.trim() : value;
};

// Copied from:
// http://docs.closure-library.googlecode.com/git/local_closure_goog_string_string.js.source.html#line1021
// Prereq: s is a string.
var escapeForRegexp = function(s) {
  return s.replace(/([-()\[\]{}+?*.$\^|,:#<!\\])/g, '\\$1').
           replace(/\x08/g, '\\x08');
};


/**
 * @ngdoc function
 * @name angular.isElement
 * @module ng
 * @kind function
 *
 * @description
 * Determines if a reference is a DOM element (or wrapped jQuery element).
 *
 * @param {*} value Reference to check.
 * @returns {boolean} True if `value` is a DOM element (or wrapped jQuery element).
 */
function isElement(node) {
  return !!(node &&
    (node.nodeName  // we are a direct element
    || (node.prop && node.attr && node.find)));  // we have an on and find method part of jQuery API
}

/**
 * @param str 'key1,key2,...'
 * @returns {object} in the form of {key1:true, key2:true, ...}
 */
function makeMap(str) {
  var obj = {}, items = str.split(","), i;
  for (i = 0; i < items.length; i++)
    obj[items[i]] = true;
  return obj;
}


function nodeName_(element) {
  return lowercase(element.nodeName || (element[0] && element[0].nodeName));
}

function includes(array, obj) {
  return Array.prototype.indexOf.call(array, obj) != -1;
}

function arrayRemove(array, value) {
  var index = array.indexOf(value);
  if (index >= 0)
    array.splice(index, 1);
  return value;
}

/**
 * @ngdoc function
 * @name angular.copy
 * @module ng
 * @kind function
 *
 * @description
 * Creates a deep copy of `source`, which should be an object or an array.
 *
 * * If no destination is supplied, a copy of the object or array is created.
 * * If a destination is provided, all of its elements (for arrays) or properties (for objects)
 *   are deleted and then all elements/properties from the source are copied to it.
 * * If `source` is not an object or array (inc. `null` and `undefined`), `source` is returned.
 * * If `source` is identical to 'destination' an exception will be thrown.
 *
 * @param {*} source The source that will be used to make a copy.
 *                   Can be any type, including primitives, `null`, and `undefined`.
 * @param {(Object|Array)=} destination Destination into which the source is copied. If
 *     provided, must be of the same type as `source`.
 * @returns {*} The copy or updated `destination`, if `destination` was specified.
 *
 * @example
 <example module="copyExample">
 <file name="index.html">
 <div ng-controller="ExampleController">
 <form novalidate class="simple-form">
 Name: <input type="text" ng-model="user.name" /><br />
 E-mail: <input type="email" ng-model="user.email" /><br />
 Gender: <input type="radio" ng-model="user.gender" value="male" />male
 <input type="radio" ng-model="user.gender" value="female" />female<br />
 <button ng-click="reset()">RESET</button>
 <button ng-click="update(user)">SAVE</button>
 </form>
 <pre>form = {{user | json}}</pre>
 <pre>master = {{master | json}}</pre>
 </div>

 <script>
  angular.module('copyExample', [])
    .controller('ExampleController', ['$scope', function($scope) {
      $scope.master= {};

      $scope.update = function(user) {
        // Example with 1 argument
        $scope.master= angular.copy(user);
      };

      $scope.reset = function() {
        // Example with 2 arguments
        angular.copy($scope.master, $scope.user);
      };

      $scope.reset();
    }]);
 </script>
 </file>
 </example>
 */
function copy(source, destination, stackSource, stackDest) {
  if (isWindow(source) || isScope(source)) {
    throw ngMinErr('cpws',
      "Can't copy! Making copies of Window or Scope instances is not supported.");
  }

  if (!destination) {
    destination = source;
    if (source) {
      if (isArray(source)) {
        destination = copy(source, [], stackSource, stackDest);
      } else if (isDate(source)) {
        destination = new Date(source.getTime());
      } else if (isRegExp(source)) {
        destination = new RegExp(source.source, source.toString().match(/[^\/]*$/)[0]);
        destination.lastIndex = source.lastIndex;
      } else if (isObject(source)) {
        var emptyObject = Object.create(Object.getPrototypeOf(source));
        destination = copy(source, emptyObject, stackSource, stackDest);
      }
    }
  } else {
    if (source === destination) throw ngMinErr('cpi',
      "Can't copy! Source and destination are identical.");

    stackSource = stackSource || [];
    stackDest = stackDest || [];

    if (isObject(source)) {
      var index = stackSource.indexOf(source);
      if (index !== -1) return stackDest[index];

      stackSource.push(source);
      stackDest.push(destination);
    }

    var result;
    if (isArray(source)) {
      destination.length = 0;
      for (var i = 0; i < source.length; i++) {
        result = copy(source[i], null, stackSource, stackDest);
        if (isObject(source[i])) {
          stackSource.push(source[i]);
          stackDest.push(result);
        }
        destination.push(result);
      }
    } else {
      var h = destination.$$hashKey;
      if (isArray(destination)) {
        destination.length = 0;
      } else {
        forEach(destination, function(value, key) {
          delete destination[key];
        });
      }
      for (var key in source) {
        if (source.hasOwnProperty(key)) {
          result = copy(source[key], null, stackSource, stackDest);
          if (isObject(source[key])) {
            stackSource.push(source[key]);
            stackDest.push(result);
          }
          destination[key] = result;
        }
      }
      setHashKey(destination,h);
    }

  }
  return destination;
}

/**
 * Creates a shallow copy of an object, an array or a primitive.
 *
 * Assumes that there are no proto properties for objects.
 */
function shallowCopy(src, dst) {
  if (isArray(src)) {
    dst = dst || [];

    for (var i = 0, ii = src.length; i < ii; i++) {
      dst[i] = src[i];
    }
  } else if (isObject(src)) {
    dst = dst || {};

    for (var key in src) {
      if (!(key.charAt(0) === '$' && key.charAt(1) === '$')) {
        dst[key] = src[key];
      }
    }
  }

  return dst || src;
}


/**
 * @ngdoc function
 * @name angular.equals
 * @module ng
 * @kind function
 *
 * @description
 * Determines if two objects or two values are equivalent. Supports value types, regular
 * expressions, arrays and objects.
 *
 * Two objects or values are considered equivalent if at least one of the following is true:
 *
 * * Both objects or values pass `===` comparison.
 * * Both objects or values are of the same type and all of their properties are equal by
 *   comparing them with `angular.equals`.
 * * Both values are NaN. (In JavaScript, NaN == NaN => false. But we consider two NaN as equal)
 * * Both values represent the same regular expression (In JavaScript,
 *   /abc/ == /abc/ => false. But we consider two regular expressions as equal when their textual
 *   representation matches).
 *
 * During a property comparison, properties of `function` type and properties with names
 * that begin with `$` are ignored.
 *
 * Scope and DOMWindow objects are being compared only by identify (`===`).
 *
 * @param {*} o1 Object or value to compare.
 * @param {*} o2 Object or value to compare.
 * @returns {boolean} True if arguments are equal.
 */
function equals(o1, o2) {
  if (o1 === o2) return true;
  if (o1 === null || o2 === null) return false;
  if (o1 !== o1 && o2 !== o2) return true; // NaN === NaN
  var t1 = typeof o1, t2 = typeof o2, length, key, keySet;
  if (t1 == t2) {
    if (t1 == 'object') {
      if (isArray(o1)) {
        if (!isArray(o2)) return false;
        if ((length = o1.length) == o2.length) {
          for (key = 0; key < length; key++) {
            if (!equals(o1[key], o2[key])) return false;
          }
          return true;
        }
      } else if (isDate(o1)) {
        if (!isDate(o2)) return false;
        return equals(o1.getTime(), o2.getTime());
      } else if (isRegExp(o1)) {
        return isRegExp(o2) ? o1.toString() == o2.toString() : false;
      } else {
        if (isScope(o1) || isScope(o2) || isWindow(o1) || isWindow(o2) ||
          isArray(o2) || isDate(o2) || isRegExp(o2)) return false;
        keySet = {};
        for (key in o1) {
          if (key.charAt(0) === '$' || isFunction(o1[key])) continue;
          if (!equals(o1[key], o2[key])) return false;
          keySet[key] = true;
        }
        for (key in o2) {
          if (!keySet.hasOwnProperty(key) &&
              key.charAt(0) !== '$' &&
              o2[key] !== undefined &&
              !isFunction(o2[key])) return false;
        }
        return true;
      }
    }
  }
  return false;
}

var csp = function() {
  if (isDefined(csp.isActive_)) return csp.isActive_;

  var active = !!(document.querySelector('[ng-csp]') ||
                  document.querySelector('[data-ng-csp]'));

  if (!active) {
    try {
      /* jshint -W031, -W054 */
      new Function('');
      /* jshint +W031, +W054 */
    } catch (e) {
      active = true;
    }
  }

  return (csp.isActive_ = active);
};



function concat(array1, array2, index) {
  return array1.concat(slice.call(array2, index));
}

function sliceArgs(args, startIndex) {
  return slice.call(args, startIndex || 0);
}


/* jshint -W101 */
/**
 * @ngdoc function
 * @name angular.bind
 * @module ng
 * @kind function
 *
 * @description
 * Returns a function which calls function `fn` bound to `self` (`self` becomes the `this` for
 * `fn`). You can supply optional `args` that are prebound to the function. This feature is also
 * known as [partial application](http://en.wikipedia.org/wiki/Partial_application), as
 * distinguished from [function currying](http://en.wikipedia.org/wiki/Currying#Contrast_with_partial_function_application).
 *
 * @param {Object} self Context which `fn` should be evaluated in.
 * @param {function()} fn Function to be bound.
 * @param {...*} args Optional arguments to be prebound to the `fn` function call.
 * @returns {function()} Function that wraps the `fn` with all the specified bindings.
 */
/* jshint +W101 */
function bind(self, fn) {
  var curryArgs = arguments.length > 2 ? sliceArgs(arguments, 2) : [];
  if (isFunction(fn) && !(fn instanceof RegExp)) {
    return curryArgs.length
      ? function() {
          return arguments.length
            ? fn.apply(self, concat(curryArgs, arguments, 0))
            : fn.apply(self, curryArgs);
        }
      : function() {
          return arguments.length
            ? fn.apply(self, arguments)
            : fn.call(self);
        };
  } else {
    // in IE, native methods are not functions so they cannot be bound (note: they don't need to be)
    return fn;
  }
}


function toJsonReplacer(key, value) {
  var val = value;

  if (typeof key === 'string' && key.charAt(0) === '$' && key.charAt(1) === '$') {
    val = undefined;
  } else if (isWindow(value)) {
    val = '$WINDOW';
  } else if (value &&  document === value) {
    val = '$DOCUMENT';
  } else if (isScope(value)) {
    val = '$SCOPE';
  }

  return val;
}


/**
 * @ngdoc function
 * @name angular.toJson
 * @module ng
 * @kind function
 *
 * @description
 * Serializes input into a JSON-formatted string. Properties with leading $$ characters will be
 * stripped since angular uses this notation internally.
 *
 * @param {Object|Array|Date|string|number} obj Input to be serialized into JSON.
 * @param {boolean|number} [pretty=2] If set to true, the JSON output will contain newlines and whitespace.
 *    If set to an integer, the JSON output will contain that many spaces per indentation.
 * @returns {string|undefined} JSON-ified string representing `obj`.
 */
function toJson(obj, pretty) {
  if (typeof obj === 'undefined') return undefined;
  if (!isNumber(pretty)) {
    pretty = pretty ? 2 : null;
  }
  return JSON.stringify(obj, toJsonReplacer, pretty);
}


/**
 * @ngdoc function
 * @name angular.fromJson
 * @module ng
 * @kind function
 *
 * @description
 * Deserializes a JSON string.
 *
 * @param {string} json JSON string to deserialize.
 * @returns {Object|Array|string|number} Deserialized JSON string.
 */
function fromJson(json) {
  return isString(json)
      ? JSON.parse(json)
      : json;
}


/**
 * @returns {string} Returns the string representation of the element.
 */
function startingTag(element) {
  element = jqLite(element).clone();
  try {
    // turns out IE does not let you set .html() on elements which
    // are not allowed to have children. So we just ignore it.
    element.empty();
  } catch (e) {}
  var elemHtml = jqLite('<div>').append(element).html();
  try {
    return element[0].nodeType === NODE_TYPE_TEXT ? lowercase(elemHtml) :
        elemHtml.
          match(/^(<[^>]+>)/)[1].
          replace(/^<([\w\-]+)/, function(match, nodeName) { return '<' + lowercase(nodeName); });
  } catch (e) {
    return lowercase(elemHtml);
  }

}


/////////////////////////////////////////////////

/**
 * Tries to decode the URI component without throwing an exception.
 *
 * @private
 * @param str value potential URI component to check.
 * @returns {boolean} True if `value` can be decoded
 * with the decodeURIComponent function.
 */
function tryDecodeURIComponent(value) {
  try {
    return decodeURIComponent(value);
  } catch (e) {
    // Ignore any invalid uri component
  }
}


/**
 * Parses an escaped url query string into key-value pairs.
 * @returns {Object.<string,boolean|Array>}
 */
function parseKeyValue(/**string*/keyValue) {
  var obj = {}, key_value, key;
  forEach((keyValue || "").split('&'), function(keyValue) {
    if (keyValue) {
      key_value = keyValue.replace(/\+/g,'%20').split('=');
      key = tryDecodeURIComponent(key_value[0]);
      if (isDefined(key)) {
        var val = isDefined(key_value[1]) ? tryDecodeURIComponent(key_value[1]) : true;
        if (!hasOwnProperty.call(obj, key)) {
          obj[key] = val;
        } else if (isArray(obj[key])) {
          obj[key].push(val);
        } else {
          obj[key] = [obj[key],val];
        }
      }
    }
  });
  return obj;
}

function toKeyValue(obj) {
  var parts = [];
  forEach(obj, function(value, key) {
    if (isArray(value)) {
      forEach(value, function(arrayValue) {
        parts.push(encodeUriQuery(key, true) +
                   (arrayValue === true ? '' : '=' + encodeUriQuery(arrayValue, true)));
      });
    } else {
    parts.push(encodeUriQuery(key, true) +
               (value === true ? '' : '=' + encodeUriQuery(value, true)));
    }
  });
  return parts.length ? parts.join('&') : '';
}


/**
 * We need our custom method because encodeURIComponent is too aggressive and doesn't follow
 * http://www.ietf.org/rfc/rfc3986.txt with regards to the character set (pchar) allowed in path
 * segments:
 *    segment       = *pchar
 *    pchar         = unreserved / pct-encoded / sub-delims / ":" / "@"
 *    pct-encoded   = "%" HEXDIG HEXDIG
 *    unreserved    = ALPHA / DIGIT / "-" / "." / "_" / "~"
 *    sub-delims    = "!" / "$" / "&" / "'" / "(" / ")"
 *                     / "*" / "+" / "," / ";" / "="
 */
function encodeUriSegment(val) {
  return encodeUriQuery(val, true).
             replace(/%26/gi, '&').
             replace(/%3D/gi, '=').
             replace(/%2B/gi, '+');
}


/**
 * This method is intended for encoding *key* or *value* parts of query component. We need a custom
 * method because encodeURIComponent is too aggressive and encodes stuff that doesn't have to be
 * encoded per http://tools.ietf.org/html/rfc3986:
 *    query       = *( pchar / "/" / "?" )
 *    pchar         = unreserved / pct-encoded / sub-delims / ":" / "@"
 *    unreserved    = ALPHA / DIGIT / "-" / "." / "_" / "~"
 *    pct-encoded   = "%" HEXDIG HEXDIG
 *    sub-delims    = "!" / "$" / "&" / "'" / "(" / ")"
 *                     / "*" / "+" / "," / ";" / "="
 */
function encodeUriQuery(val, pctEncodeSpaces) {
  return encodeURIComponent(val).
             replace(/%40/gi, '@').
             replace(/%3A/gi, ':').
             replace(/%24/g, '$').
             replace(/%2C/gi, ',').
             replace(/%3B/gi, ';').
             replace(/%20/g, (pctEncodeSpaces ? '%20' : '+'));
}

var ngAttrPrefixes = ['ng-', 'data-ng-', 'ng:', 'x-ng-'];

function getNgAttribute(element, ngAttr) {
  var attr, i, ii = ngAttrPrefixes.length;
  element = jqLite(element);
  for (i = 0; i < ii; ++i) {
    attr = ngAttrPrefixes[i] + ngAttr;
    if (isString(attr = element.attr(attr))) {
      return attr;
    }
  }
  return null;
}

/**
 * @ngdoc directive
 * @name ngApp
 * @module ng
 *
 * @element ANY
 * @param {angular.Module} ngApp an optional application
 *   {@link angular.module module} name to load.
 * @param {boolean=} ngStrictDi if this attribute is present on the app element, the injector will be
 *   created in "strict-di" mode. This means that the application will fail to invoke functions which
 *   do not use explicit function annotation (and are thus unsuitable for minification), as described
 *   in {@link guide/di the Dependency Injection guide}, and useful debugging info will assist in
 *   tracking down the root of these bugs.
 *
 * @description
 *
 * Use this directive to **auto-bootstrap** an AngularJS application. The `ngApp` directive
 * designates the **root element** of the application and is typically placed near the root element
 * of the page - e.g. on the `<body>` or `<html>` tags.
 *
 * Only one AngularJS application can be auto-bootstrapped per HTML document. The first `ngApp`
 * found in the document will be used to define the root element to auto-bootstrap as an
 * application. To run multiple applications in an HTML document you must manually bootstrap them using
 * {@link angular.bootstrap} instead. AngularJS applications cannot be nested within each other.
 *
 * You can specify an **AngularJS module** to be used as the root module for the application.  This
 * module will be loaded into the {@link auto.$injector} when the application is bootstrapped. It
 * should contain the application code needed or have dependencies on other modules that will
 * contain the code. See {@link angular.module} for more information.
 *
 * In the example below if the `ngApp` directive were not placed on the `html` element then the
 * document would not be compiled, the `AppController` would not be instantiated and the `{{ a+b }}`
 * would not be resolved to `3`.
 *
 * `ngApp` is the easiest, and most common way to bootstrap an application.
 *
 <example module="ngAppDemo">
   <file name="index.html">
   <div ng-controller="ngAppDemoController">
     I can add: {{a}} + {{b}} =  {{ a+b }}
   </div>
   </file>
   <file name="script.js">
   angular.module('ngAppDemo', []).controller('ngAppDemoController', function($scope) {
     $scope.a = 1;
     $scope.b = 2;
   });
   </file>
 </example>
 *
 * Using `ngStrictDi`, you would see something like this:
 *
 <example ng-app-included="true">
   <file name="index.html">
   <div ng-app="ngAppStrictDemo" ng-strict-di>
       <div ng-controller="GoodController1">
           I can add: {{a}} + {{b}} =  {{ a+b }}

           <p>This renders because the controller does not fail to
              instantiate, by using explicit annotation style (see
              script.js for details)
           </p>
       </div>

       <div ng-controller="GoodController2">
           Name: <input ng-model="name"><br />
           Hello, {{name}}!

           <p>This renders because the controller does not fail to
              instantiate, by using explicit annotation style
              (see script.js for details)
           </p>
       </div>

       <div ng-controller="BadController">
           I can add: {{a}} + {{b}} =  {{ a+b }}

           <p>The controller could not be instantiated, due to relying
              on automatic function annotations (which are disabled in
              strict mode). As such, the content of this section is not
              interpolated, and there should be an error in your web console.
           </p>
       </div>
   </div>
   </file>
   <file name="script.js">
   angular.module('ngAppStrictDemo', [])
     // BadController will fail to instantiate, due to relying on automatic function annotation,
     // rather than an explicit annotation
     .controller('BadController', function($scope) {
       $scope.a = 1;
       $scope.b = 2;
     })
     // Unlike BadController, GoodController1 and GoodController2 will not fail to be instantiated,
     // due to using explicit annotations using the array style and $inject property, respectively.
     .controller('GoodController1', ['$scope', function($scope) {
       $scope.a = 1;
       $scope.b = 2;
     }])
     .controller('GoodController2', GoodController2);
     function GoodController2($scope) {
       $scope.name = "World";
     }
     GoodController2.$inject = ['$scope'];
   </file>
   <file name="style.css">
   div[ng-controller] {
       margin-bottom: 1em;
       -webkit-border-radius: 4px;
       border-radius: 4px;
       border: 1px solid;
       padding: .5em;
   }
   div[ng-controller^=Good] {
       border-color: #d6e9c6;
       background-color: #dff0d8;
       color: #3c763d;
   }
   div[ng-controller^=Bad] {
       border-color: #ebccd1;
       background-color: #f2dede;
       color: #a94442;
       margin-bottom: 0;
   }
   </file>
 </example>
 */
function angularInit(element, bootstrap) {
  var appElement,
      module,
      config = {};

  // The element `element` has priority over any other element
  forEach(ngAttrPrefixes, function(prefix) {
    var name = prefix + 'app';

    if (!appElement && element.hasAttribute && element.hasAttribute(name)) {
      appElement = element;
      module = element.getAttribute(name);
    }
  });
  forEach(ngAttrPrefixes, function(prefix) {
    var name = prefix + 'app';
    var candidate;

    if (!appElement && (candidate = element.querySelector('[' + name.replace(':', '\\:') + ']'))) {
      appElement = candidate;
      module = candidate.getAttribute(name);
    }
  });
  if (appElement) {
    config.strictDi = getNgAttribute(appElement, "strict-di") !== null;
    bootstrap(appElement, module ? [module] : [], config);
  }
}

/**
 * @ngdoc function
 * @name angular.bootstrap
 * @module ng
 * @description
 * Use this function to manually start up angular application.
 *
 * See: {@link guide/bootstrap Bootstrap}
 *
 * Note that Protractor based end-to-end tests cannot use this function to bootstrap manually.
 * They must use {@link ng.directive:ngApp ngApp}.
 *
 * Angular will detect if it has been loaded into the browser more than once and only allow the
 * first loaded script to be bootstrapped and will report a warning to the browser console for
 * each of the subsequent scripts. This prevents strange results in applications, where otherwise
 * multiple instances of Angular try to work on the DOM.
 *
 * ```html
 * <!doctype html>
 * <html>
 * <body>
 * <div ng-controller="WelcomeController">
 *   {{greeting}}
 * </div>
 *
 * <script src="angular.js"></script>
 * <script>
 *   var app = angular.module('demo', [])
 *   .controller('WelcomeController', function($scope) {
 *       $scope.greeting = 'Welcome!';
 *   });
 *   angular.bootstrap(document, ['demo']);
 * </script>
 * </body>
 * </html>
 * ```
 *
 * @param {DOMElement} element DOM element which is the root of angular application.
 * @param {Array<String|Function|Array>=} modules an array of modules to load into the application.
 *     Each item in the array should be the name of a predefined module or a (DI annotated)
 *     function that will be invoked by the injector as a `config` block.
 *     See: {@link angular.module modules}
 * @param {Object=} config an object for defining configuration options for the application. The
 *     following keys are supported:
 *
 * * `strictDi` - disable automatic function annotation for the application. This is meant to
 *   assist in finding bugs which break minified code. Defaults to `false`.
 *
 * @returns {auto.$injector} Returns the newly created injector for this app.
 */
function bootstrap(element, modules, config) {
  if (!isObject(config)) config = {};
  var defaultConfig = {
    strictDi: false
  };
  config = extend(defaultConfig, config);
  var doBootstrap = function() {
    element = jqLite(element);

    if (element.injector()) {
      var tag = (element[0] === document) ? 'document' : startingTag(element);
      //Encode angle brackets to prevent input from being sanitized to empty string #8683
      throw ngMinErr(
          'btstrpd',
          "App Already Bootstrapped with this Element '{0}'",
          tag.replace(/</,'&lt;').replace(/>/,'&gt;'));
    }

    modules = modules || [];
    modules.unshift(['$provide', function($provide) {
      $provide.value('$rootElement', element);
    }]);

    if (config.debugInfoEnabled) {
      // Pushing so that this overrides `debugInfoEnabled` setting defined in user's `modules`.
      modules.push(['$compileProvider', function($compileProvider) {
        $compileProvider.debugInfoEnabled(true);
      }]);
    }

    modules.unshift('ng');
    var injector = createInjector(modules, config.strictDi);
    injector.invoke(['$rootScope', '$rootElement', '$compile', '$injector',
       function bootstrapApply(scope, element, compile, injector) {
        scope.$apply(function() {
          element.data('$injector', injector);
          compile(element)(scope);
        });
      }]
    );
    return injector;
  };

  var NG_ENABLE_DEBUG_INFO = /^NG_ENABLE_DEBUG_INFO!/;
  var NG_DEFER_BOOTSTRAP = /^NG_DEFER_BOOTSTRAP!/;

  if (window && NG_ENABLE_DEBUG_INFO.test(window.name)) {
    config.debugInfoEnabled = true;
    window.name = window.name.replace(NG_ENABLE_DEBUG_INFO, '');
  }

  if (window && !NG_DEFER_BOOTSTRAP.test(window.name)) {
    return doBootstrap();
  }

  window.name = window.name.replace(NG_DEFER_BOOTSTRAP, '');
  angular.resumeBootstrap = function(extraModules) {
    forEach(extraModules, function(module) {
      modules.push(module);
    });
    return doBootstrap();
  };

  if (isFunction(angular.resumeDeferredBootstrap)) {
    angular.resumeDeferredBootstrap();
  }
}

/**
 * @ngdoc function
 * @name angular.reloadWithDebugInfo
 * @module ng
 * @description
 * Use this function to reload the current application with debug information turned on.
 * This takes precedence over a call to `$compileProvider.debugInfoEnabled(false)`.
 *
 * See {@link ng.$compileProvider#debugInfoEnabled} for more.
 */
function reloadWithDebugInfo() {
  window.name = 'NG_ENABLE_DEBUG_INFO!' + window.name;
  window.location.reload();
}

/**
 * @name angular.getTestability
 * @module ng
 * @description
 * Get the testability service for the instance of Angular on the given
 * element.
 * @param {DOMElement} element DOM element which is the root of angular application.
 */
function getTestability(rootElement) {
  var injector = angular.element(rootElement).injector();
  if (!injector) {
    throw ngMinErr('test',
      'no injector found for element argument to getTestability');
  }
  return injector.get('$$testability');
}

var SNAKE_CASE_REGEXP = /[A-Z]/g;
function snake_case(name, separator) {
  separator = separator || '_';
  return name.replace(SNAKE_CASE_REGEXP, function(letter, pos) {
    return (pos ? separator : '') + letter.toLowerCase();
  });
}

var bindJQueryFired = false;
var skipDestroyOnNextJQueryCleanData;
function bindJQuery() {
  var originalCleanData;

  if (bindJQueryFired) {
    return;
  }

  // bind to jQuery if present;
  jQuery = window.jQuery;
  // Use jQuery if it exists with proper functionality, otherwise default to us.
  // Angular 1.2+ requires jQuery 1.7+ for on()/off() support.
  // Angular 1.3+ technically requires at least jQuery 2.1+ but it may work with older
  // versions. It will not work for sure with jQuery <1.7, though.
  if (jQuery && jQuery.fn.on) {
    jqLite = jQuery;
    extend(jQuery.fn, {
      scope: JQLitePrototype.scope,
      isolateScope: JQLitePrototype.isolateScope,
      controller: JQLitePrototype.controller,
      injector: JQLitePrototype.injector,
      inheritedData: JQLitePrototype.inheritedData
    });

    // All nodes removed from the DOM via various jQuery APIs like .remove()
    // are passed through jQuery.cleanData. Monkey-patch this method to fire
    // the $destroy event on all removed nodes.
    originalCleanData = jQuery.cleanData;
    jQuery.cleanData = function(elems) {
      var events;
      if (!skipDestroyOnNextJQueryCleanData) {
        for (var i = 0, elem; (elem = elems[i]) != null; i++) {
          events = jQuery._data(elem, "events");
          if (events && events.$destroy) {
            jQuery(elem).triggerHandler('$destroy');
          }
        }
      } else {
        skipDestroyOnNextJQueryCleanData = false;
      }
      originalCleanData(elems);
    };
  } else {
    jqLite = JQLite;
  }

  angular.element = jqLite;

  // Prevent double-proxying.
  bindJQueryFired = true;
}

/**
 * throw error if the argument is falsy.
 */
function assertArg(arg, name, reason) {
  if (!arg) {
    throw ngMinErr('areq', "Argument '{0}' is {1}", (name || '?'), (reason || "required"));
  }
  return arg;
}

function assertArgFn(arg, name, acceptArrayAnnotation) {
  if (acceptArrayAnnotation && isArray(arg)) {
      arg = arg[arg.length - 1];
  }

  assertArg(isFunction(arg), name, 'not a function, got ' +
      (arg && typeof arg === 'object' ? arg.constructor.name || 'Object' : typeof arg));
  return arg;
}

/**
 * throw error if the name given is hasOwnProperty
 * @param  {String} name    the name to test
 * @param  {String} context the context in which the name is used, such as module or directive
 */
function assertNotHasOwnProperty(name, context) {
  if (name === 'hasOwnProperty') {
    throw ngMinErr('badname', "hasOwnProperty is not a valid {0} name", context);
  }
}

/**
 * Return the value accessible from the object by path. Any undefined traversals are ignored
 * @param {Object} obj starting object
 * @param {String} path path to traverse
 * @param {boolean} [bindFnToScope=true]
 * @returns {Object} value as accessible by path
 */
//TODO(misko): this function needs to be removed
function getter(obj, path, bindFnToScope) {
  if (!path) return obj;
  var keys = path.split('.');
  var key;
  var lastInstance = obj;
  var len = keys.length;

  for (var i = 0; i < len; i++) {
    key = keys[i];
    if (obj) {
      obj = (lastInstance = obj)[key];
    }
  }
  if (!bindFnToScope && isFunction(obj)) {
    return bind(lastInstance, obj);
  }
  return obj;
}

/**
 * Return the DOM siblings between the first and last node in the given array.
 * @param {Array} array like object
 * @returns {jqLite} jqLite collection containing the nodes
 */
function getBlockNodes(nodes) {
  // TODO(perf): just check if all items in `nodes` are siblings and if they are return the original
  //             collection, otherwise update the original collection.
  var node = nodes[0];
  var endNode = nodes[nodes.length - 1];
  var blockNodes = [node];

  do {
    node = node.nextSibling;
    if (!node) break;
    blockNodes.push(node);
  } while (node !== endNode);

  return jqLite(blockNodes);
}


/**
 * Creates a new object without a prototype. This object is useful for lookup without having to
 * guard against prototypically inherited properties via hasOwnProperty.
 *
 * Related micro-benchmarks:
 * - http://jsperf.com/object-create2
 * - http://jsperf.com/proto-map-lookup/2
 * - http://jsperf.com/for-in-vs-object-keys2
 *
 * @returns {Object}
 */
function createMap() {
  return Object.create(null);
}

var NODE_TYPE_ELEMENT = 1;
var NODE_TYPE_ATTRIBUTE = 2;
var NODE_TYPE_TEXT = 3;
var NODE_TYPE_COMMENT = 8;
var NODE_TYPE_DOCUMENT = 9;
var NODE_TYPE_DOCUMENT_FRAGMENT = 11;

/**
 * @ngdoc type
 * @name angular.Module
 * @module ng
 * @description
 *
 * Interface for configuring angular {@link angular.module modules}.
 */

function setupModuleLoader(window) {

  var $injectorMinErr = minErr('$injector');
  var ngMinErr = minErr('ng');

  function ensure(obj, name, factory) {
    return obj[name] || (obj[name] = factory());
  }

  var angular = ensure(window, 'angular', Object);

  // We need to expose `angular.$$minErr` to modules such as `ngResource` that reference it during bootstrap
  angular.$$minErr = angular.$$minErr || minErr;

  return ensure(angular, 'module', function() {
    /** @type {Object.<string, angular.Module>} */
    var modules = {};

    /**
     * @ngdoc function
     * @name angular.module
     * @module ng
     * @description
     *
     * The `angular.module` is a global place for creating, registering and retrieving Angular
     * modules.
     * All modules (angular core or 3rd party) that should be available to an application must be
     * registered using this mechanism.
     *
     * When passed two or more arguments, a new module is created.  If passed only one argument, an
     * existing module (the name passed as the first argument to `module`) is retrieved.
     *
     *
     * # Module
     *
     * A module is a collection of services, directives, controllers, filters, and configuration information.
     * `angular.module` is used to configure the {@link auto.$injector $injector}.
     *
     * ```js
     * // Create a new module
     * var myModule = angular.module('myModule', []);
     *
     * // register a new service
     * myModule.value('appName', 'MyCoolApp');
     *
     * // configure existing services inside initialization blocks.
     * myModule.config(['$locationProvider', function($locationProvider) {
     *   // Configure existing providers
     *   $locationProvider.hashPrefix('!');
     * }]);
     * ```
     *
     * Then you can create an injector and load your modules like this:
     *
     * ```js
     * var injector = angular.injector(['ng', 'myModule'])
     * ```
     *
     * However it's more likely that you'll just use
     * {@link ng.directive:ngApp ngApp} or
     * {@link angular.bootstrap} to simplify this process for you.
     *
     * @param {!string} name The name of the module to create or retrieve.
     * @param {!Array.<string>=} requires If specified then new module is being created. If
     *        unspecified then the module is being retrieved for further configuration.
     * @param {Function=} configFn Optional configuration function for the module. Same as
     *        {@link angular.Module#config Module#config()}.
     * @returns {module} new module with the {@link angular.Module} api.
     */
    return function module(name, requires, configFn) {
      var assertNotHasOwnProperty = function(name, context) {
        if (name === 'hasOwnProperty') {
          throw ngMinErr('badname', 'hasOwnProperty is not a valid {0} name', context);
        }
      };

      assertNotHasOwnProperty(name, 'module');
      if (requires && modules.hasOwnProperty(name)) {
        modules[name] = null;
      }
      return ensure(modules, name, function() {
        if (!requires) {
          throw $injectorMinErr('nomod', "Module '{0}' is not available! You either misspelled " +
             "the module name or forgot to load it. If registering a module ensure that you " +
             "specify the dependencies as the second argument.", name);
        }

        /** @type {!Array.<Array.<*>>} */
        var invokeQueue = [];

        /** @type {!Array.<Function>} */
        var configBlocks = [];

        /** @type {!Array.<Function>} */
        var runBlocks = [];

        var config = invokeLater('$injector', 'invoke', 'push', configBlocks);

        /** @type {angular.Module} */
        var moduleInstance = {
          // Private state
          _invokeQueue: invokeQueue,
          _configBlocks: configBlocks,
          _runBlocks: runBlocks,

          /**
           * @ngdoc property
           * @name angular.Module#requires
           * @module ng
           *
           * @description
           * Holds the list of modules which the injector will load before the current module is
           * loaded.
           */
          requires: requires,

          /**
           * @ngdoc property
           * @name angular.Module#name
           * @module ng
           *
           * @description
           * Name of the module.
           */
          name: name,


          /**
           * @ngdoc method
           * @name angular.Module#provider
           * @module ng
           * @param {string} name service name
           * @param {Function} providerType Construction function for creating new instance of the
           *                                service.
           * @description
           * See {@link auto.$provide#provider $provide.provider()}.
           */
          provider: invokeLater('$provide', 'provider'),

          /**
           * @ngdoc method
           * @name angular.Module#factory
           * @module ng
           * @param {string} name service name
           * @param {Function} providerFunction Function for creating new instance of the service.
           * @description
           * See {@link auto.$provide#factory $provide.factory()}.
           */
          factory: invokeLater('$provide', 'factory'),

          /**
           * @ngdoc method
           * @name angular.Module#service
           * @module ng
           * @param {string} name service name
           * @param {Function} constructor A constructor function that will be instantiated.
           * @description
           * See {@link auto.$provide#service $provide.service()}.
           */
          service: invokeLater('$provide', 'service'),

          /**
           * @ngdoc method
           * @name angular.Module#value
           * @module ng
           * @param {string} name service name
           * @param {*} object Service instance object.
           * @description
           * See {@link auto.$provide#value $provide.value()}.
           */
          value: invokeLater('$provide', 'value'),

          /**
           * @ngdoc method
           * @name angular.Module#constant
           * @module ng
           * @param {string} name constant name
           * @param {*} object Constant value.
           * @description
           * Because the constant are fixed, they get applied before other provide methods.
           * See {@link auto.$provide#constant $provide.constant()}.
           */
          constant: invokeLater('$provide', 'constant', 'unshift'),

          /**
           * @ngdoc method
           * @name angular.Module#animation
           * @module ng
           * @param {string} name animation name
           * @param {Function} animationFactory Factory function for creating new instance of an
           *                                    animation.
           * @description
           *
           * **NOTE**: animations take effect only if the **ngAnimate** module is loaded.
           *
           *
           * Defines an animation hook that can be later used with
           * {@link ngAnimate.$animate $animate} service and directives that use this service.
           *
           * ```js
           * module.animation('.animation-name', function($inject1, $inject2) {
           *   return {
           *     eventName : function(element, done) {
           *       //code to run the animation
           *       //once complete, then run done()
           *       return function cancellationFunction(element) {
           *         //code to cancel the animation
           *       }
           *     }
           *   }
           * })
           * ```
           *
           * See {@link ng.$animateProvider#register $animateProvider.register()} and
           * {@link ngAnimate ngAnimate module} for more information.
           */
          animation: invokeLater('$animateProvider', 'register'),

          /**
           * @ngdoc method
           * @name angular.Module#filter
           * @module ng
           * @param {string} name Filter name - this must be a valid angular expression identifier
           * @param {Function} filterFactory Factory function for creating new instance of filter.
           * @description
           * See {@link ng.$filterProvider#register $filterProvider.register()}.
           *
           * <div class="alert alert-warning">
           * **Note:** Filter names must be valid angular {@link expression} identifiers, such as `uppercase` or `orderBy`.
           * Names with special characters, such as hyphens and dots, are not allowed. If you wish to namespace
           * your filters, then you can use capitalization (`myappSubsectionFilterx`) or underscores
           * (`myapp_subsection_filterx`).
           * </div>
           */
          filter: invokeLater('$filterProvider', 'register'),

          /**
           * @ngdoc method
           * @name angular.Module#controller
           * @module ng
           * @param {string|Object} name Controller name, or an object map of controllers where the
           *    keys are the names and the values are the constructors.
           * @param {Function} constructor Controller constructor function.
           * @description
           * See {@link ng.$controllerProvider#register $controllerProvider.register()}.
           */
          controller: invokeLater('$controllerProvider', 'register'),

          /**
           * @ngdoc method
           * @name angular.Module#directive
           * @module ng
           * @param {string|Object} name Directive name, or an object map of directives where the
           *    keys are the names and the values are the factories.
           * @param {Function} directiveFactory Factory function for creating new instance of
           * directives.
           * @description
           * See {@link ng.$compileProvider#directive $compileProvider.directive()}.
           */
          directive: invokeLater('$compileProvider', 'directive'),

          /**
           * @ngdoc method
           * @name angular.Module#config
           * @module ng
           * @param {Function} configFn Execute this function on module load. Useful for service
           *    configuration.
           * @description
           * Use this method to register work which needs to be performed on module loading.
           * For more about how to configure services, see
           * {@link providers#provider-recipe Provider Recipe}.
           */
          config: config,

          /**
           * @ngdoc method
           * @name angular.Module#run
           * @module ng
           * @param {Function} initializationFn Execute this function after injector creation.
           *    Useful for application initialization.
           * @description
           * Use this method to register work which should be performed when the injector is done
           * loading all modules.
           */
          run: function(block) {
            runBlocks.push(block);
            return this;
          }
        };

        if (configFn) {
          config(configFn);
        }

        return moduleInstance;

        /**
         * @param {string} provider
         * @param {string} method
         * @param {String=} insertMethod
         * @returns {angular.Module}
         */
        function invokeLater(provider, method, insertMethod, queue) {
          if (!queue) queue = invokeQueue;
          return function() {
            queue[insertMethod || 'push']([provider, method, arguments]);
            return moduleInstance;
          };
        }
      });
    };
  });

}

/* global: toDebugString: true */

function serializeObject(obj) {
  var seen = [];

  return JSON.stringify(obj, function(key, val) {
    val = toJsonReplacer(key, val);
    if (isObject(val)) {

      if (seen.indexOf(val) >= 0) return '<<already seen>>';

      seen.push(val);
    }
    return val;
  });
}

function toDebugString(obj) {
  if (typeof obj === 'function') {
    return obj.toString().replace(/ \{[\s\S]*$/, '');
  } else if (typeof obj === 'undefined') {
    return 'undefined';
  } else if (typeof obj !== 'string') {
    return serializeObject(obj);
  }
  return obj;
}

/* global angularModule: true,
  version: true,

  $LocaleProvider,
  $CompileProvider,

  htmlAnchorDirective,
  inputDirective,
  inputDirective,
  formDirective,
  scriptDirective,
  selectDirective,
  styleDirective,
  optionDirective,
  ngBindDirective,
  ngBindHtmlDirective,
  ngBindTemplateDirective,
  ngClassDirective,
  ngClassEvenDirective,
  ngClassOddDirective,
  ngCspDirective,
  ngCloakDirective,
  ngControllerDirective,
  ngFormDirective,
  ngHideDirective,
  ngIfDirective,
  ngIncludeDirective,
  ngIncludeFillContentDirective,
  ngInitDirective,
  ngNonBindableDirective,
  ngPluralizeDirective,
  ngRepeatDirective,
  ngShowDirective,
  ngStyleDirective,
  ngSwitchDirective,
  ngSwitchWhenDirective,
  ngSwitchDefaultDirective,
  ngOptionsDirective,
  ngTranscludeDirective,
  ngModelDirective,
  ngListDirective,
  ngChangeDirective,
  patternDirective,
  patternDirective,
  requiredDirective,
  requiredDirective,
  minlengthDirective,
  minlengthDirective,
  maxlengthDirective,
  maxlengthDirective,
  ngValueDirective,
  ngModelOptionsDirective,
  ngAttributeAliasDirectives,
  ngEventDirectives,

  $AnchorScrollProvider,
  $AnimateProvider,
  $BrowserProvider,
  $CacheFactoryProvider,
  $ControllerProvider,
  $DocumentProvider,
  $ExceptionHandlerProvider,
  $FilterProvider,
  $InterpolateProvider,
  $IntervalProvider,
  $HttpProvider,
  $HttpBackendProvider,
  $LocationProvider,
  $LogProvider,
  $ParseProvider,
  $RootScopeProvider,
  $QProvider,
  $$QProvider,
  $$SanitizeUriProvider,
  $SceProvider,
  $SceDelegateProvider,
  $SnifferProvider,
  $TemplateCacheProvider,
  $TemplateRequestProvider,
  $$TestabilityProvider,
  $TimeoutProvider,
  $$RAFProvider,
  $$AsyncCallbackProvider,
  $WindowProvider,
  $$jqLiteProvider
*/


/**
 * @ngdoc object
 * @name angular.version
 * @module ng
 * @description
 * An object that contains information about the current AngularJS version. This object has the
 * following properties:
 *
 * - `full` – `{string}` – Full version string, such as "0.9.18".
 * - `major` – `{number}` – Major version number, such as "0".
 * - `minor` – `{number}` – Minor version number, such as "9".
 * - `dot` – `{number}` – Dot version number, such as "18".
 * - `codeName` – `{string}` – Code name of the release, such as "jiggling-armfat".
 */
var version = {
  full: '1.3.20',    // all of these placeholder strings will be replaced by grunt's
  major: 1,    // package task
  minor: 3,
  dot: 20,
  codeName: 'shallow-translucence'
};


function publishExternalAPI(angular) {
  extend(angular, {
    'bootstrap': bootstrap,
    'copy': copy,
    'extend': extend,
    'equals': equals,
    'element': jqLite,
    'forEach': forEach,
    'injector': createInjector,
    'noop': noop,
    'bind': bind,
    'toJson': toJson,
    'fromJson': fromJson,
    'identity': identity,
    'isUndefined': isUndefined,
    'isDefined': isDefined,
    'isString': isString,
    'isFunction': isFunction,
    'isObject': isObject,
    'isNumber': isNumber,
    'isElement': isElement,
    'isArray': isArray,
    'version': version,
    'isDate': isDate,
    'lowercase': lowercase,
    'uppercase': uppercase,
    'callbacks': {counter: 0},
    'getTestability': getTestability,
    '$$minErr': minErr,
    '$$csp': csp,
    'reloadWithDebugInfo': reloadWithDebugInfo
  });

  angularModule = setupModuleLoader(window);
  try {
    angularModule('ngLocale');
  } catch (e) {
    angularModule('ngLocale', []).provider('$locale', $LocaleProvider);
  }

  angularModule('ng', ['ngLocale'], ['$provide',
    function ngModule($provide) {
      // $$sanitizeUriProvider needs to be before $compileProvider as it is used by it.
      $provide.provider({
        $$sanitizeUri: $$SanitizeUriProvider
      });
      $provide.provider('$compile', $CompileProvider).
        directive({
            a: htmlAnchorDirective,
            input: inputDirective,
            textarea: inputDirective,
            form: formDirective,
            script: scriptDirective,
            select: selectDirective,
            style: styleDirective,
            option: optionDirective,
            ngBind: ngBindDirective,
            ngBindHtml: ngBindHtmlDirective,
            ngBindTemplate: ngBindTemplateDirective,
            ngClass: ngClassDirective,
            ngClassEven: ngClassEvenDirective,
            ngClassOdd: ngClassOddDirective,
            ngCloak: ngCloakDirective,
            ngController: ngControllerDirective,
            ngForm: ngFormDirective,
            ngHide: ngHideDirective,
            ngIf: ngIfDirective,
            ngInclude: ngIncludeDirective,
            ngInit: ngInitDirective,
            ngNonBindable: ngNonBindableDirective,
            ngPluralize: ngPluralizeDirective,
            ngRepeat: ngRepeatDirective,
            ngShow: ngShowDirective,
            ngStyle: ngStyleDirective,
            ngSwitch: ngSwitchDirective,
            ngSwitchWhen: ngSwitchWhenDirective,
            ngSwitchDefault: ngSwitchDefaultDirective,
            ngOptions: ngOptionsDirective,
            ngTransclude: ngTranscludeDirective,
            ngModel: ngModelDirective,
            ngList: ngListDirective,
            ngChange: ngChangeDirective,
            pattern: patternDirective,
            ngPattern: patternDirective,
            required: requiredDirective,
            ngRequired: requiredDirective,
            minlength: minlengthDirective,
            ngMinlength: minlengthDirective,
            maxlength: maxlengthDirective,
            ngMaxlength: maxlengthDirective,
            ngValue: ngValueDirective,
            ngModelOptions: ngModelOptionsDirective
        }).
        directive({
          ngInclude: ngIncludeFillContentDirective
        }).
        directive(ngAttributeAliasDirectives).
        directive(ngEventDirectives);
      $provide.provider({
        $anchorScroll: $AnchorScrollProvider,
        $animate: $AnimateProvider,
        $browser: $BrowserProvider,
        $cacheFactory: $CacheFactoryProvider,
        $controller: $ControllerProvider,
        $document: $DocumentProvider,
        $exceptionHandler: $ExceptionHandlerProvider,
        $filter: $FilterProvider,
        $interpolate: $InterpolateProvider,
        $interval: $IntervalProvider,
        $http: $HttpProvider,
        $httpBackend: $HttpBackendProvider,
        $location: $LocationProvider,
        $log: $LogProvider,
        $parse: $ParseProvider,
        $rootScope: $RootScopeProvider,
        $q: $QProvider,
        $$q: $$QProvider,
        $sce: $SceProvider,
        $sceDelegate: $SceDelegateProvider,
        $sniffer: $SnifferProvider,
        $templateCache: $TemplateCacheProvider,
        $templateRequest: $TemplateRequestProvider,
        $$testability: $$TestabilityProvider,
        $timeout: $TimeoutProvider,
        $window: $WindowProvider,
        $$rAF: $$RAFProvider,
        $$asyncCallback: $$AsyncCallbackProvider,
        $$jqLite: $$jqLiteProvider
      });
    }
  ]);
}

/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
 *     Any commits to this file should be reviewed with security in mind.  *
 *   Changes to this file can potentially create security vulnerabilities. *
 *          An approval from 2 Core members with history of modifying      *
 *                         this file is required.                          *
 *                                                                         *
 *  Does the change somehow allow for arbitrary javascript to be executed? *
 *    Or allows for someone to change the prototype of built-in objects?   *
 *     Or gives undesired access to variables likes document or window?    *
 * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

/* global JQLitePrototype: true,
  addEventListenerFn: true,
  removeEventListenerFn: true,
  BOOLEAN_ATTR: true,
  ALIASED_ATTR: true,
*/

//////////////////////////////////
//JQLite
//////////////////////////////////

/**
 * @ngdoc function
 * @name angular.element
 * @module ng
 * @kind function
 *
 * @description
 * Wraps a raw DOM element or HTML string as a [jQuery](http://jquery.com) element.
 *
 * If jQuery is available, `angular.element` is an alias for the
 * [jQuery](http://api.jquery.com/jQuery/) function. If jQuery is not available, `angular.element`
 * delegates to Angular's built-in subset of jQuery, called "jQuery lite" or "jqLite."
 *
 * <div class="alert alert-success">jqLite is a tiny, API-compatible subset of jQuery that allows
 * Angular to manipulate the DOM in a cross-browser compatible way. **jqLite** implements only the most
 * commonly needed functionality with the goal of having a very small footprint.</div>
 *
 * To use `jQuery`, simply ensure it is loaded before the `angular.js` file.
 *
 * <div class="alert">**Note:** all element references in Angular are always wrapped with jQuery or
 * jqLite; they are never raw DOM references.</div>
 *
 * ## Angular's jqLite
 * jqLite provides only the following jQuery methods:
 *
 * - [`addClass()`](http://api.jquery.com/addClass/)
 * - [`after()`](http://api.jquery.com/after/)
 * - [`append()`](http://api.jquery.com/append/)
 * - [`attr()`](http://api.jquery.com/attr/) - Does not support functions as parameters
 * - [`bind()`](http://api.jquery.com/bind/) - Does not support namespaces, selectors or eventData
 * - [`children()`](http://api.jquery.com/children/) - Does not support selectors
 * - [`clone()`](http://api.jquery.com/clone/)
 * - [`contents()`](http://api.jquery.com/contents/)
 * - [`css()`](http://api.jquery.com/css/) - Only retrieves inline-styles, does not call `getComputedStyle()`. As a setter, does not convert numbers to strings or append 'px'.
 * - [`data()`](http://api.jquery.com/data/)
 * - [`detach()`](http://api.jquery.com/detach/)
 * - [`empty()`](http://api.jquery.com/empty/)
 * - [`eq()`](http://api.jquery.com/eq/)
 * - [`find()`](http://api.jquery.com/find/) - Limited to lookups by tag name
 * - [`hasClass()`](http://api.jquery.com/hasClass/)
 * - [`html()`](http://api.jquery.com/html/)
 * - [`next()`](http://api.jquery.com/next/) - Does not support selectors
 * - [`on()`](http://api.jquery.com/on/) - Does not support namespaces, selectors or eventData
 * - [`off()`](http://api.jquery.com/off/) - Does not support namespaces or selectors
 * - [`one()`](http://api.jquery.com/one/) - Does not support namespaces or selectors
 * - [`parent()`](http://api.jquery.com/parent/) - Does not support selectors
 * - [`prepend()`](http://api.jquery.com/prepend/)
 * - [`prop()`](http://api.jquery.com/prop/)
 * - [`ready()`](http://api.jquery.com/ready/)
 * - [`remove()`](http://api.jquery.com/remove/)
 * - [`removeAttr()`](http://api.jquery.com/removeAttr/)
 * - [`removeClass()`](http://api.jquery.com/removeClass/)
 * - [`removeData()`](http://api.jquery.com/removeData/)
 * - [`replaceWith()`](http://api.jquery.com/replaceWith/)
 * - [`text()`](http://api.jquery.com/text/)
 * - [`toggleClass()`](http://api.jquery.com/toggleClass/)
 * - [`triggerHandler()`](http://api.jquery.com/triggerHandler/) - Passes a dummy event object to handlers.
 * - [`unbind()`](http://api.jquery.com/unbind/) - Does not support namespaces
 * - [`val()`](http://api.jquery.com/val/)
 * - [`wrap()`](http://api.jquery.com/wrap/)
 *
 * ## jQuery/jqLite Extras
 * Angular also provides the following additional methods and events to both jQuery and jqLite:
 *
 * ### Events
 * - `$destroy` - AngularJS intercepts all jqLite/jQuery's DOM destruction apis and fires this event
 *    on all DOM nodes being removed.  This can be used to clean up any 3rd party bindings to the DOM
 *    element before it is removed.
 *
 * ### Methods
 * - `controller(name)` - retrieves the controller of the current element or its parent. By default
 *   retrieves controller associated with the `ngController` directive. If `name` is provided as
 *   camelCase directive name, then the controller for this directive will be retrieved (e.g.
 *   `'ngModel'`).
 * - `injector()` - retrieves the injector of the current element or its parent.
 * - `scope()` - retrieves the {@link ng.$rootScope.Scope scope} of the current
 *   element or its parent. Requires {@link guide/production#disabling-debug-data Debug Data} to
 *   be enabled.
 * - `isolateScope()` - retrieves an isolate {@link ng.$rootScope.Scope scope} if one is attached directly to the
 *   current element. This getter should be used only on elements that contain a directive which starts a new isolate
 *   scope. Calling `scope()` on this element always returns the original non-isolate scope.
 *   Requires {@link guide/production#disabling-debug-data Debug Data} to be enabled.
 * - `inheritedData()` - same as `data()`, but walks up the DOM until a value is found or the top
 *   parent element is reached.
 *
 * @param {string|DOMElement} element HTML string or DOMElement to be wrapped into jQuery.
 * @returns {Object} jQuery object.
 */

JQLite.expando = 'ng339';

var jqCache = JQLite.cache = {},
    jqId = 1,
    addEventListenerFn = function(element, type, fn) {
      element.addEventListener(type, fn, false);
    },
    removeEventListenerFn = function(element, type, fn) {
      element.removeEventListener(type, fn, false);
    };

/*
 * !!! This is an undocumented "private" function !!!
 */
JQLite._data = function(node) {
  //jQuery always returns an object on cache miss
  return this.cache[node[this.expando]] || {};
};

function jqNextId() { return ++jqId; }


var SPECIAL_CHARS_REGEXP = /([\:\-\_]+(.))/g;
var MOZ_HACK_REGEXP = /^moz([A-Z])/;
var MOUSE_EVENT_MAP= { mouseleave: "mouseout", mouseenter: "mouseover"};
var jqLiteMinErr = minErr('jqLite');

/**
 * Converts snake_case to camelCase.
 * Also there is special case for Moz prefix starting with upper case letter.
 * @param name Name to normalize
 */
function camelCase(name) {
  return name.
    replace(SPECIAL_CHARS_REGEXP, function(_, separator, letter, offset) {
      return offset ? letter.toUpperCase() : letter;
    }).
    replace(MOZ_HACK_REGEXP, 'Moz$1');
}

var SINGLE_TAG_REGEXP = /^<(\w+)\s*\/?>(?:<\/\1>|)$/;
var HTML_REGEXP = /<|&#?\w+;/;
var TAG_NAME_REGEXP = /<([\w:]+)/;
var XHTML_TAG_REGEXP = /<(?!area|br|col|embed|hr|img|input|link|meta|param)(([\w:]+)[^>]*)\/>/gi;

var wrapMap = {
  'option': [1, '<select multiple="multiple">', '</select>'],

  'thead': [1, '<table>', '</table>'],
  'col': [2, '<table><colgroup>', '</colgroup></table>'],
  'tr': [2, '<table><tbody>', '</tbody></table>'],
  'td': [3, '<table><tbody><tr>', '</tr></tbody></table>'],
  '_default': [0, "", ""]
};

wrapMap.optgroup = wrapMap.option;
wrapMap.tbody = wrapMap.tfoot = wrapMap.colgroup = wrapMap.caption = wrapMap.thead;
wrapMap.th = wrapMap.td;


function jqLiteIsTextNode(html) {
  return !HTML_REGEXP.test(html);
}

function jqLiteAcceptsData(node) {
  // The window object can accept data but has no nodeType
  // Otherwise we are only interested in elements (1) and documents (9)
  var nodeType = node.nodeType;
  return nodeType === NODE_TYPE_ELEMENT || !nodeType || nodeType === NODE_TYPE_DOCUMENT;
}

function jqLiteBuildFragment(html, context) {
  var tmp, tag, wrap,
      fragment = context.createDocumentFragment(),
      nodes = [], i;

  if (jqLiteIsTextNode(html)) {
    // Convert non-html into a text node
    nodes.push(context.createTextNode(html));
  } else {
    // Convert html into DOM nodes
    tmp = tmp || fragment.appendChild(context.createElement("div"));
    tag = (TAG_NAME_REGEXP.exec(html) || ["", ""])[1].toLowerCase();
    wrap = wrapMap[tag] || wrapMap._default;
    tmp.innerHTML = wrap[1] + html.replace(XHTML_TAG_REGEXP, "<$1></$2>") + wrap[2];

    // Descend through wrappers to the right content
    i = wrap[0];
    while (i--) {
      tmp = tmp.lastChild;
    }

    nodes = concat(nodes, tmp.childNodes);

    tmp = fragment.firstChild;
    tmp.textContent = "";
  }

  // Remove wrapper from fragment
  fragment.textContent = "";
  fragment.innerHTML = ""; // Clear inner HTML
  forEach(nodes, function(node) {
    fragment.appendChild(node);
  });

  return fragment;
}

function jqLiteParseHTML(html, context) {
  context = context || document;
  var parsed;

  if ((parsed = SINGLE_TAG_REGEXP.exec(html))) {
    return [context.createElement(parsed[1])];
  }

  if ((parsed = jqLiteBuildFragment(html, context))) {
    return parsed.childNodes;
  }

  return [];
}

/////////////////////////////////////////////
function JQLite(element) {
  if (element instanceof JQLite) {
    return element;
  }

  var argIsString;

  if (isString(element)) {
    element = trim(element);
    argIsString = true;
  }
  if (!(this instanceof JQLite)) {
    if (argIsString && element.charAt(0) != '<') {
      throw jqLiteMinErr('nosel', 'Looking up elements via selectors is not supported by jqLite! See: http://docs.angularjs.org/api/angular.element');
    }
    return new JQLite(element);
  }

  if (argIsString) {
    jqLiteAddNodes(this, jqLiteParseHTML(element));
  } else {
    jqLiteAddNodes(this, element);
  }
}

function jqLiteClone(element) {
  return element.cloneNode(true);
}

function jqLiteDealoc(element, onlyDescendants) {
  if (!onlyDescendants) jqLiteRemoveData(element);

  if (element.querySelectorAll) {
    var descendants = element.querySelectorAll('*');
    for (var i = 0, l = descendants.length; i < l; i++) {
      jqLiteRemoveData(descendants[i]);
    }
  }
}

function jqLiteOff(element, type, fn, unsupported) {
  if (isDefined(unsupported)) throw jqLiteMinErr('offargs', 'jqLite#off() does not support the `selector` argument');

  var expandoStore = jqLiteExpandoStore(element);
  var events = expandoStore && expandoStore.events;
  var handle = expandoStore && expandoStore.handle;

  if (!handle) return; //no listeners registered

  if (!type) {
    for (type in events) {
      if (type !== '$destroy') {
        removeEventListenerFn(element, type, handle);
      }
      delete events[type];
    }
  } else {
    forEach(type.split(' '), function(type) {
      if (isDefined(fn)) {
        var listenerFns = events[type];
        arrayRemove(listenerFns || [], fn);
        if (listenerFns && listenerFns.length > 0) {
          return;
        }
      }

      removeEventListenerFn(element, type, handle);
      delete events[type];
    });
  }
}

function jqLiteRemoveData(element, name) {
  var expandoId = element.ng339;
  var expandoStore = expandoId && jqCache[expandoId];

  if (expandoStore) {
    if (name) {
      delete expandoStore.data[name];
      return;
    }

    if (expandoStore.handle) {
      if (expandoStore.events.$destroy) {
        expandoStore.handle({}, '$destroy');
      }
      jqLiteOff(element);
    }
    delete jqCache[expandoId];
    element.ng339 = undefined; // don't delete DOM expandos. IE and Chrome don't like it
  }
}


function jqLiteExpandoStore(element, createIfNecessary) {
  var expandoId = element.ng339,
      expandoStore = expandoId && jqCache[expandoId];

  if (createIfNecessary && !expandoStore) {
    element.ng339 = expandoId = jqNextId();
    expandoStore = jqCache[expandoId] = {events: {}, data: {}, handle: undefined};
  }

  return expandoStore;
}


function jqLiteData(element, key, value) {
  if (jqLiteAcceptsData(element)) {

    var isSimpleSetter = isDefined(value);
    var isSimpleGetter = !isSimpleSetter && key && !isObject(key);
    var massGetter = !key;
    var expandoStore = jqLiteExpandoStore(element, !isSimpleGetter);
    var data = expandoStore && expandoStore.data;

    if (isSimpleSetter) { // data('key', value)
      data[key] = value;
    } else {
      if (massGetter) {  // data()
        return data;
      } else {
        if (isSimpleGetter) { // data('key')
          // don't force creation of expandoStore if it doesn't exist yet
          return data && data[key];
        } else { // mass-setter: data({key1: val1, key2: val2})
          extend(data, key);
        }
      }
    }
  }
}

function jqLiteHasClass(element, selector) {
  if (!element.getAttribute) return false;
  return ((" " + (element.getAttribute('class') || '') + " ").replace(/[\n\t]/g, " ").
      indexOf(" " + selector + " ") > -1);
}

function jqLiteRemoveClass(element, cssClasses) {
  if (cssClasses && element.setAttribute) {
    forEach(cssClasses.split(' '), function(cssClass) {
      element.setAttribute('class', trim(
          (" " + (element.getAttribute('class') || '') + " ")
          .replace(/[\n\t]/g, " ")
          .replace(" " + trim(cssClass) + " ", " "))
      );
    });
  }
}

function jqLiteAddClass(element, cssClasses) {
  if (cssClasses && element.setAttribute) {
    var existingClasses = (' ' + (element.getAttribute('class') || '') + ' ')
                            .replace(/[\n\t]/g, " ");

    forEach(cssClasses.split(' '), function(cssClass) {
      cssClass = trim(cssClass);
      if (existingClasses.indexOf(' ' + cssClass + ' ') === -1) {
        existingClasses += cssClass + ' ';
      }
    });

    element.setAttribute('class', trim(existingClasses));
  }
}


function jqLiteAddNodes(root, elements) {
  // THIS CODE IS VERY HOT. Don't make changes without benchmarking.

  if (elements) {

    // if a Node (the most common case)
    if (elements.nodeType) {
      root[root.length++] = elements;
    } else {
      var length = elements.length;

      // if an Array or NodeList and not a Window
      if (typeof length === 'number' && elements.window !== elements) {
        if (length) {
          for (var i = 0; i < length; i++) {
            root[root.length++] = elements[i];
          }
        }
      } else {
        root[root.length++] = elements;
      }
    }
  }
}


function jqLiteController(element, name) {
  return jqLiteInheritedData(element, '$' + (name || 'ngController') + 'Controller');
}

function jqLiteInheritedData(element, name, value) {
  // if element is the document object work with the html element instead
  // this makes $(document).scope() possible
  if (element.nodeType == NODE_TYPE_DOCUMENT) {
    element = element.documentElement;
  }
  var names = isArray(name) ? name : [name];

  while (element) {
    for (var i = 0, ii = names.length; i < ii; i++) {
      if ((value = jqLite.data(element, names[i])) !== undefined) return value;
    }

    // If dealing with a document fragment node with a host element, and no parent, use the host
    // element as the parent. This enables directives within a Shadow DOM or polyfilled Shadow DOM
    // to lookup parent controllers.
    element = element.parentNode || (element.nodeType === NODE_TYPE_DOCUMENT_FRAGMENT && element.host);
  }
}

function jqLiteEmpty(element) {
  jqLiteDealoc(element, true);
  while (element.firstChild) {
    element.removeChild(element.firstChild);
  }
}

function jqLiteRemove(element, keepData) {
  if (!keepData) jqLiteDealoc(element);
  var parent = element.parentNode;
  if (parent) parent.removeChild(element);
}


function jqLiteDocumentLoaded(action, win) {
  win = win || window;
  if (win.document.readyState === 'complete') {
    // Force the action to be run async for consistent behaviour
    // from the action's point of view
    // i.e. it will definitely not be in a $apply
    win.setTimeout(action);
  } else {
    // No need to unbind this handler as load is only ever called once
    jqLite(win).on('load', action);
  }
}

//////////////////////////////////////////
// Functions which are declared directly.
//////////////////////////////////////////
var JQLitePrototype = JQLite.prototype = {
  ready: function(fn) {
    var fired = false;

    function trigger() {
      if (fired) return;
      fired = true;
      fn();
    }

    // check if document is already loaded
    if (document.readyState === 'complete') {
      setTimeout(trigger);
    } else {
      this.on('DOMContentLoaded', trigger); // works for modern browsers and IE9
      // we can not use jqLite since we are not done loading and jQuery could be loaded later.
      // jshint -W064
      JQLite(window).on('load', trigger); // fallback to window.onload for others
      // jshint +W064
    }
  },
  toString: function() {
    var value = [];
    forEach(this, function(e) { value.push('' + e);});
    return '[' + value.join(', ') + ']';
  },

  eq: function(index) {
      return (index >= 0) ? jqLite(this[index]) : jqLite(this[this.length + index]);
  },

  length: 0,
  push: push,
  sort: [].sort,
  splice: [].splice
};

//////////////////////////////////////////
// Functions iterating getter/setters.
// these functions return self on setter and
// value on get.
//////////////////////////////////////////
var BOOLEAN_ATTR = {};
forEach('multiple,selected,checked,disabled,readOnly,required,open'.split(','), function(value) {
  BOOLEAN_ATTR[lowercase(value)] = value;
});
var BOOLEAN_ELEMENTS = {};
forEach('input,select,option,textarea,button,form,details'.split(','), function(value) {
  BOOLEAN_ELEMENTS[value] = true;
});
var ALIASED_ATTR = {
  'ngMinlength': 'minlength',
  'ngMaxlength': 'maxlength',
  'ngMin': 'min',
  'ngMax': 'max',
  'ngPattern': 'pattern'
};

function getBooleanAttrName(element, name) {
  // check dom last since we will most likely fail on name
  var booleanAttr = BOOLEAN_ATTR[name.toLowerCase()];

  // booleanAttr is here twice to minimize DOM access
  return booleanAttr && BOOLEAN_ELEMENTS[nodeName_(element)] && booleanAttr;
}

function getAliasedAttrName(element, name) {
  var nodeName = element.nodeName;
  return (nodeName === 'INPUT' || nodeName === 'TEXTAREA') && ALIASED_ATTR[name];
}

forEach({
  data: jqLiteData,
  removeData: jqLiteRemoveData
}, function(fn, name) {
  JQLite[name] = fn;
});

forEach({
  data: jqLiteData,
  inheritedData: jqLiteInheritedData,

  scope: function(element) {
    // Can't use jqLiteData here directly so we stay compatible with jQuery!
    return jqLite.data(element, '$scope') || jqLiteInheritedData(element.parentNode || element, ['$isolateScope', '$scope']);
  },

  isolateScope: function(element) {
    // Can't use jqLiteData here directly so we stay compatible with jQuery!
    return jqLite.data(element, '$isolateScope') || jqLite.data(element, '$isolateScopeNoTemplate');
  },

  controller: jqLiteController,

  injector: function(element) {
    return jqLiteInheritedData(element, '$injector');
  },

  removeAttr: function(element, name) {
    element.removeAttribute(name);
  },

  hasClass: jqLiteHasClass,

  css: function(element, name, value) {
    name = camelCase(name);

    if (isDefined(value)) {
      element.style[name] = value;
    } else {
      return element.style[name];
    }
  },

  attr: function(element, name, value) {
    var nodeType = element.nodeType;
    if (nodeType === NODE_TYPE_TEXT || nodeType === NODE_TYPE_ATTRIBUTE || nodeType === NODE_TYPE_COMMENT) {
      return;
    }
    var lowercasedName = lowercase(name);
    if (BOOLEAN_ATTR[lowercasedName]) {
      if (isDefined(value)) {
        if (!!value) {
          element[name] = true;
          element.setAttribute(name, lowercasedName);
        } else {
          element[name] = false;
          element.removeAttribute(lowercasedName);
        }
      } else {
        return (element[name] ||
                 (element.attributes.getNamedItem(name) || noop).specified)
               ? lowercasedName
               : undefined;
      }
    } else if (isDefined(value)) {
      element.setAttribute(name, value);
    } else if (element.getAttribute) {
      // the extra argument "2" is to get the right thing for a.href in IE, see jQuery code
      // some elements (e.g. Document) don't have get attribute, so return undefined
      var ret = element.getAttribute(name, 2);
      // normalize non-existing attributes to undefined (as jQuery)
      return ret === null ? undefined : ret;
    }
  },

  prop: function(element, name, value) {
    if (isDefined(value)) {
      element[name] = value;
    } else {
      return element[name];
    }
  },

  text: (function() {
    getText.$dv = '';
    return getText;

    function getText(element, value) {
      if (isUndefined(value)) {
        var nodeType = element.nodeType;
        return (nodeType === NODE_TYPE_ELEMENT || nodeType === NODE_TYPE_TEXT) ? element.textContent : '';
      }
      element.textContent = value;
    }
  })(),

  val: function(element, value) {
    if (isUndefined(value)) {
      if (element.multiple && nodeName_(element) === 'select') {
        var result = [];
        forEach(element.options, function(option) {
          if (option.selected) {
            result.push(option.value || option.text);
          }
        });
        return result.length === 0 ? null : result;
      }
      return element.value;
    }
    element.value = value;
  },

  html: function(element, value) {
    if (isUndefined(value)) {
      return element.innerHTML;
    }
    jqLiteDealoc(element, true);
    element.innerHTML = value;
  },

  empty: jqLiteEmpty
}, function(fn, name) {
  /**
   * Properties: writes return selection, reads return first value
   */
  JQLite.prototype[name] = function(arg1, arg2) {
    var i, key;
    var nodeCount = this.length;

    // jqLiteHasClass has only two arguments, but is a getter-only fn, so we need to special-case it
    // in a way that survives minification.
    // jqLiteEmpty takes no arguments but is a setter.
    if (fn !== jqLiteEmpty &&
        (((fn.length == 2 && (fn !== jqLiteHasClass && fn !== jqLiteController)) ? arg1 : arg2) === undefined)) {
      if (isObject(arg1)) {

        // we are a write, but the object properties are the key/values
        for (i = 0; i < nodeCount; i++) {
          if (fn === jqLiteData) {
            // data() takes the whole object in jQuery
            fn(this[i], arg1);
          } else {
            for (key in arg1) {
              fn(this[i], key, arg1[key]);
            }
          }
        }
        // return self for chaining
        return this;
      } else {
        // we are a read, so read the first child.
        // TODO: do we still need this?
        var value = fn.$dv;
        // Only if we have $dv do we iterate over all, otherwise it is just the first element.
        var jj = (value === undefined) ? Math.min(nodeCount, 1) : nodeCount;
        for (var j = 0; j < jj; j++) {
          var nodeValue = fn(this[j], arg1, arg2);
          value = value ? value + nodeValue : nodeValue;
        }
        return value;
      }
    } else {
      // we are a write, so apply to all children
      for (i = 0; i < nodeCount; i++) {
        fn(this[i], arg1, arg2);
      }
      // return self for chaining
      return this;
    }
  };
});

function createEventHandler(element, events) {
  var eventHandler = function(event, type) {
    // jQuery specific api
    event.isDefaultPrevented = function() {
      return event.defaultPrevented;
    };

    var eventFns = events[type || event.type];
    var eventFnsLength = eventFns ? eventFns.length : 0;

    if (!eventFnsLength) return;

    if (isUndefined(event.immediatePropagationStopped)) {
      var originalStopImmediatePropagation = event.stopImmediatePropagation;
      event.stopImmediatePropagation = function() {
        event.immediatePropagationStopped = true;

        if (event.stopPropagation) {
          event.stopPropagation();
        }

        if (originalStopImmediatePropagation) {
          originalStopImmediatePropagation.call(event);
        }
      };
    }

    event.isImmediatePropagationStopped = function() {
      return event.immediatePropagationStopped === true;
    };

    // Copy event handlers in case event handlers array is modified during execution.
    if ((eventFnsLength > 1)) {
      eventFns = shallowCopy(eventFns);
    }

    for (var i = 0; i < eventFnsLength; i++) {
      if (!event.isImmediatePropagationStopped()) {
        eventFns[i].call(element, event);
      }
    }
  };

  // TODO: this is a hack for angularMocks/clearDataCache that makes it possible to deregister all
  //       events on `element`
  eventHandler.elem = element;
  return eventHandler;
}

//////////////////////////////////////////
// Functions iterating traversal.
// These functions chain results into a single
// selector.
//////////////////////////////////////////
forEach({
  removeData: jqLiteRemoveData,

  on: function jqLiteOn(element, type, fn, unsupported) {
    if (isDefined(unsupported)) throw jqLiteMinErr('onargs', 'jqLite#on() does not support the `selector` or `eventData` parameters');

    // Do not add event handlers to non-elements because they will not be cleaned up.
    if (!jqLiteAcceptsData(element)) {
      return;
    }

    var expandoStore = jqLiteExpandoStore(element, true);
    var events = expandoStore.events;
    var handle = expandoStore.handle;

    if (!handle) {
      handle = expandoStore.handle = createEventHandler(element, events);
    }

    // http://jsperf.com/string-indexof-vs-split
    var types = type.indexOf(' ') >= 0 ? type.split(' ') : [type];
    var i = types.length;

    while (i--) {
      type = types[i];
      var eventFns = events[type];

      if (!eventFns) {
        events[type] = [];

        if (type === 'mouseenter' || type === 'mouseleave') {
          // Refer to jQuery's implementation of mouseenter & mouseleave
          // Read about mouseenter and mouseleave:
          // http://www.quirksmode.org/js/events_mouse.html#link8

          jqLiteOn(element, MOUSE_EVENT_MAP[type], function(event) {
            var target = this, related = event.relatedTarget;
            // For mousenter/leave call the handler if related is outside the target.
            // NB: No relatedTarget if the mouse left/entered the browser window
            if (!related || (related !== target && !target.contains(related))) {
              handle(event, type);
            }
          });

        } else {
          if (type !== '$destroy') {
            addEventListenerFn(element, type, handle);
          }
        }
        eventFns = events[type];
      }
      eventFns.push(fn);
    }
  },

  off: jqLiteOff,

  one: function(element, type, fn) {
    element = jqLite(element);

    //add the listener twice so that when it is called
    //you can remove the original function and still be
    //able to call element.off(ev, fn) normally
    element.on(type, function onFn() {
      element.off(type, fn);
      element.off(type, onFn);
    });
    element.on(type, fn);
  },

  replaceWith: function(element, replaceNode) {
    var index, parent = element.parentNode;
    jqLiteDealoc(element);
    forEach(new JQLite(replaceNode), function(node) {
      if (index) {
        parent.insertBefore(node, index.nextSibling);
      } else {
        parent.replaceChild(node, element);
      }
      index = node;
    });
  },

  children: function(element) {
    var children = [];
    forEach(element.childNodes, function(element) {
      if (element.nodeType === NODE_TYPE_ELEMENT)
        children.push(element);
    });
    return children;
  },

  contents: function(element) {
    return element.contentDocument || element.childNodes || [];
  },

  append: function(element, node) {
    var nodeType = element.nodeType;
    if (nodeType !== NODE_TYPE_ELEMENT && nodeType !== NODE_TYPE_DOCUMENT_FRAGMENT) return;

    node = new JQLite(node);

    for (var i = 0, ii = node.length; i < ii; i++) {
      var child = node[i];
      element.appendChild(child);
    }
  },

  prepend: function(element, node) {
    if (element.nodeType === NODE_TYPE_ELEMENT) {
      var index = element.firstChild;
      forEach(new JQLite(node), function(child) {
        element.insertBefore(child, index);
      });
    }
  },

  wrap: function(element, wrapNode) {
    wrapNode = jqLite(wrapNode).eq(0).clone()[0];
    var parent = element.parentNode;
    if (parent) {
      parent.replaceChild(wrapNode, element);
    }
    wrapNode.appendChild(element);
  },

  remove: jqLiteRemove,

  detach: function(element) {
    jqLiteRemove(element, true);
  },

  after: function(element, newElement) {
    var index = element, parent = element.parentNode;
    newElement = new JQLite(newElement);

    for (var i = 0, ii = newElement.length; i < ii; i++) {
      var node = newElement[i];
      parent.insertBefore(node, index.nextSibling);
      index = node;
    }
  },

  addClass: jqLiteAddClass,
  removeClass: jqLiteRemoveClass,

  toggleClass: function(element, selector, condition) {
    if (selector) {
      forEach(selector.split(' '), function(className) {
        var classCondition = condition;
        if (isUndefined(classCondition)) {
          classCondition = !jqLiteHasClass(element, className);
        }
        (classCondition ? jqLiteAddClass : jqLiteRemoveClass)(element, className);
      });
    }
  },

  parent: function(element) {
    var parent = element.parentNode;
    return parent && parent.nodeType !== NODE_TYPE_DOCUMENT_FRAGMENT ? parent : null;
  },

  next: function(element) {
    return element.nextElementSibling;
  },

  find: function(element, selector) {
    if (element.getElementsByTagName) {
      return element.getElementsByTagName(selector);
    } else {
      return [];
    }
  },

  clone: jqLiteClone,

  triggerHandler: function(element, event, extraParameters) {

    var dummyEvent, eventFnsCopy, handlerArgs;
    var eventName = event.type || event;
    var expandoStore = jqLiteExpandoStore(element);
    var events = expandoStore && expandoStore.events;
    var eventFns = events && events[eventName];

    if (eventFns) {
      // Create a dummy event to pass to the handlers
      dummyEvent = {
        preventDefault: function() { this.defaultPrevented = true; },
        isDefaultPrevented: function() { return this.defaultPrevented === true; },
        stopImmediatePropagation: function() { this.immediatePropagationStopped = true; },
        isImmediatePropagationStopped: function() { return this.immediatePropagationStopped === true; },
        stopPropagation: noop,
        type: eventName,
        target: element
      };

      // If a custom event was provided then extend our dummy event with it
      if (event.type) {
        dummyEvent = extend(dummyEvent, event);
      }

      // Copy event handlers in case event handlers array is modified during execution.
      eventFnsCopy = shallowCopy(eventFns);
      handlerArgs = extraParameters ? [dummyEvent].concat(extraParameters) : [dummyEvent];

      forEach(eventFnsCopy, function(fn) {
        if (!dummyEvent.isImmediatePropagationStopped()) {
          fn.apply(element, handlerArgs);
        }
      });
    }
  }
}, function(fn, name) {
  /**
   * chaining functions
   */
  JQLite.prototype[name] = function(arg1, arg2, arg3) {
    var value;

    for (var i = 0, ii = this.length; i < ii; i++) {
      if (isUndefined(value)) {
        value = fn(this[i], arg1, arg2, arg3);
        if (isDefined(value)) {
          // any function which returns a value needs to be wrapped
          value = jqLite(value);
        }
      } else {
        jqLiteAddNodes(value, fn(this[i], arg1, arg2, arg3));
      }
    }
    return isDefined(value) ? value : this;
  };

  // bind legacy bind/unbind to on/off
  JQLite.prototype.bind = JQLite.prototype.on;
  JQLite.prototype.unbind = JQLite.prototype.off;
});


// Provider for private $$jqLite service
function $$jqLiteProvider() {
  this.$get = function $$jqLite() {
    return extend(JQLite, {
      hasClass: function(node, classes) {
        if (node.attr) node = node[0];
        return jqLiteHasClass(node, classes);
      },
      addClass: function(node, classes) {
        if (node.attr) node = node[0];
        return jqLiteAddClass(node, classes);
      },
      removeClass: function(node, classes) {
        if (node.attr) node = node[0];
        return jqLiteRemoveClass(node, classes);
      }
    });
  };
}

/**
 * Computes a hash of an 'obj'.
 * Hash of a:
 *  string is string
 *  number is number as string
 *  object is either result of calling $$hashKey function on the object or uniquely generated id,
 *         that is also assigned to the $$hashKey property of the object.
 *
 * @param obj
 * @returns {string} hash string such that the same input will have the same hash string.
 *         The resulting string key is in 'type:hashKey' format.
 */
function hashKey(obj, nextUidFn) {
  var key = obj && obj.$$hashKey;

  if (key) {
    if (typeof key === 'function') {
      key = obj.$$hashKey();
    }
    return key;
  }

  var objType = typeof obj;
  if (objType == 'function' || (objType == 'object' && obj !== null)) {
    key = obj.$$hashKey = objType + ':' + (nextUidFn || nextUid)();
  } else {
    key = objType + ':' + obj;
  }

  return key;
}

/**
 * HashMap which can use objects as keys
 */
function HashMap(array, isolatedUid) {
  if (isolatedUid) {
    var uid = 0;
    this.nextUid = function() {
      return ++uid;
    };
  }
  forEach(array, this.put, this);
}
HashMap.prototype = {
  /**
   * Store key value pair
   * @param key key to store can be any type
   * @param value value to store can be any type
   */
  put: function(key, value) {
    this[hashKey(key, this.nextUid)] = value;
  },

  /**
   * @param key
   * @returns {Object} the value for the key
   */
  get: function(key) {
    return this[hashKey(key, this.nextUid)];
  },

  /**
   * Remove the key/value pair
   * @param key
   */
  remove: function(key) {
    var value = this[key = hashKey(key, this.nextUid)];
    delete this[key];
    return value;
  }
};

/**
 * @ngdoc function
 * @module ng
 * @name angular.injector
 * @kind function
 *
 * @description
 * Creates an injector object that can be used for retrieving services as well as for
 * dependency injection (see {@link guide/di dependency injection}).
 *
 * @param {Array.<string|Function>} modules A list of module functions or their aliases. See
 *     {@link angular.module}. The `ng` module must be explicitly added.
 * @param {boolean=} [strictDi=false] Whether the injector should be in strict mode, which
 *     disallows argument name annotation inference.
 * @returns {injector} Injector object. See {@link auto.$injector $injector}.
 *
 * @example
 * Typical usage
 * ```js
 *   // create an injector
 *   var $injector = angular.injector(['ng']);
 *
 *   // use the injector to kick off your application
 *   // use the type inference to auto inject arguments, or use implicit injection
 *   $injector.invoke(function($rootScope, $compile, $document) {
 *     $compile($document)($rootScope);
 *     $rootScope.$digest();
 *   });
 * ```
 *
 * Sometimes you want to get access to the injector of a currently running Angular app
 * from outside Angular. Perhaps, you want to inject and compile some markup after the
 * application has been bootstrapped. You can do this using the extra `injector()` added
 * to JQuery/jqLite elements. See {@link angular.element}.
 *
 * *This is fairly rare but could be the case if a third party library is injecting the
 * markup.*
 *
 * In the following example a new block of HTML containing a `ng-controller`
 * directive is added to the end of the document body by JQuery. We then compile and link
 * it into the current AngularJS scope.
 *
 * ```js
 * var $div = $('<div ng-controller="MyCtrl">{{content.label}}</div>');
 * $(document.body).append($div);
 *
 * angular.element(document).injector().invoke(function($compile) {
 *   var scope = angular.element($div).scope();
 *   $compile($div)(scope);
 * });
 * ```
 */


/**
 * @ngdoc module
 * @name auto
 * @description
 *
 * Implicit module which gets automatically added to each {@link auto.$injector $injector}.
 */

var FN_ARGS = /^function\s*[^\(]*\(\s*([^\)]*)\)/m;
var FN_ARG_SPLIT = /,/;
var FN_ARG = /^\s*(_?)(\S+?)\1\s*$/;
var STRIP_COMMENTS = /((\/\/.*$)|(\/\*[\s\S]*?\*\/))/mg;
var $injectorMinErr = minErr('$injector');

function anonFn(fn) {
  // For anonymous functions, showing at the very least the function signature can help in
  // debugging.
  var fnText = fn.toString().replace(STRIP_COMMENTS, ''),
      args = fnText.match(FN_ARGS);
  if (args) {
    return 'function(' + (args[1] || '').replace(/[\s\r\n]+/, ' ') + ')';
  }
  return 'fn';
}

function annotate(fn, strictDi, name) {
  var $inject,
      fnText,
      argDecl,
      last;

  if (typeof fn === 'function') {
    if (!($inject = fn.$inject)) {
      $inject = [];
      if (fn.length) {
        if (strictDi) {
          if (!isString(name) || !name) {
            name = fn.name || anonFn(fn);
          }
          throw $injectorMinErr('strictdi',
            '{0} is not using explicit annotation and cannot be invoked in strict mode', name);
        }
        fnText = fn.toString().replace(STRIP_COMMENTS, '');
        argDecl = fnText.match(FN_ARGS);
        forEach(argDecl[1].split(FN_ARG_SPLIT), function(arg) {
          arg.replace(FN_ARG, function(all, underscore, name) {
            $inject.push(name);
          });
        });
      }
      fn.$inject = $inject;
    }
  } else if (isArray(fn)) {
    last = fn.length - 1;
    assertArgFn(fn[last], 'fn');
    $inject = fn.slice(0, last);
  } else {
    assertArgFn(fn, 'fn', true);
  }
  return $inject;
}

///////////////////////////////////////

/**
 * @ngdoc service
 * @name $injector
 *
 * @description
 *
 * `$injector` is used to retrieve object instances as defined by
 * {@link auto.$provide provider}, instantiate types, invoke methods,
 * and load modules.
 *
 * The following always holds true:
 *
 * ```js
 *   var $injector = angular.injector();
 *   expect($injector.get('$injector')).toBe($injector);
 *   expect($injector.invoke(function($injector) {
 *     return $injector;
 *   })).toBe($injector);
 * ```
 *
 * # Injection Function Annotation
 *
 * JavaScript does not have annotations, and annotations are needed for dependency injection. The
 * following are all valid ways of annotating function with injection arguments and are equivalent.
 *
 * ```js
 *   // inferred (only works if code not minified/obfuscated)
 *   $injector.invoke(function(serviceA){});
 *
 *   // annotated
 *   function explicit(serviceA) {};
 *   explicit.$inject = ['serviceA'];
 *   $injector.invoke(explicit);
 *
 *   // inline
 *   $injector.invoke(['serviceA', function(serviceA){}]);
 * ```
 *
 * ## Inference
 *
 * In JavaScript calling `toString()` on a function returns the function definition. The definition
 * can then be parsed and the function arguments can be extracted. This method of discovering
 * annotations is disallowed when the injector is in strict mode.
 * *NOTE:* This does not work with minification, and obfuscation tools since these tools change the
 * argument names.
 *
 * ## `$inject` Annotation
 * By adding an `$inject` property onto a function the injection parameters can be specified.
 *
 * ## Inline
 * As an array of injection names, where the last item in the array is the function to call.
 */

/**
 * @ngdoc method
 * @name $injector#get
 *
 * @description
 * Return an instance of the service.
 *
 * @param {string} name The name of the instance to retrieve.
 * @param {string=} caller An optional string to provide the origin of the function call for error messages.
 * @return {*} The instance.
 */

/**
 * @ngdoc method
 * @name $injector#invoke
 *
 * @description
 * Invoke the method and supply the method arguments from the `$injector`.
 *
 * @param {Function|Array.<string|Function>} fn The injectable function to invoke. Function parameters are
 *   injected according to the {@link guide/di $inject Annotation} rules.
 * @param {Object=} self The `this` for the invoked method.
 * @param {Object=} locals Optional object. If preset then any argument names are read from this
 *                         object first, before the `$injector` is consulted.
 * @returns {*} the value returned by the invoked `fn` function.
 */

/**
 * @ngdoc method
 * @name $injector#has
 *
 * @description
 * Allows the user to query if the particular service exists.
 *
 * @param {string} name Name of the service to query.
 * @returns {boolean} `true` if injector has given service.
 */

/**
 * @ngdoc method
 * @name $injector#instantiate
 * @description
 * Create a new instance of JS type. The method takes a constructor function, invokes the new
 * operator, and supplies all of the arguments to the constructor function as specified by the
 * constructor annotation.
 *
 * @param {Function} Type Annotated constructor function.
 * @param {Object=} locals Optional object. If preset then any argument names are read from this
 * object first, before the `$injector` is consulted.
 * @returns {Object} new instance of `Type`.
 */

/**
 * @ngdoc method
 * @name $injector#annotate
 *
 * @description
 * Returns an array of service names which the function is requesting for injection. This API is
 * used by the injector to determine which services need to be injected into the function when the
 * function is invoked. There are three ways in which the function can be annotated with the needed
 * dependencies.
 *
 * # Argument names
 *
 * The simplest form is to extract the dependencies from the arguments of the function. This is done
 * by converting the function into a string using `toString()` method and extracting the argument
 * names.
 * ```js
 *   // Given
 *   function MyController($scope, $route) {
 *     // ...
 *   }
 *
 *   // Then
 *   expect(injector.annotate(MyController)).toEqual(['$scope', '$route']);
 * ```
 *
 * You can disallow this method by using strict injection mode.
 *
 * This method does not work with code minification / obfuscation. For this reason the following
 * annotation strategies are supported.
 *
 * # The `$inject` property
 *
 * If a function has an `$inject` property and its value is an array of strings, then the strings
 * represent names of services to be injected into the function.
 * ```js
 *   // Given
 *   var MyController = function(obfuscatedScope, obfuscatedRoute) {
 *     // ...
 *   }
 *   // Define function dependencies
 *   MyController['$inject'] = ['$scope', '$route'];
 *
 *   // Then
 *   expect(injector.annotate(MyController)).toEqual(['$scope', '$route']);
 * ```
 *
 * # The array notation
 *
 * It is often desirable to inline Injected functions and that's when setting the `$inject` property
 * is very inconvenient. In these situations using the array notation to specify the dependencies in
 * a way that survives minification is a better choice:
 *
 * ```js
 *   // We wish to write this (not minification / obfuscation safe)
 *   injector.invoke(function($compile, $rootScope) {
 *     // ...
 *   });
 *
 *   // We are forced to write break inlining
 *   var tmpFn = function(obfuscatedCompile, obfuscatedRootScope) {
 *     // ...
 *   };
 *   tmpFn.$inject = ['$compile', '$rootScope'];
 *   injector.invoke(tmpFn);
 *
 *   // To better support inline function the inline annotation is supported
 *   injector.invoke(['$compile', '$rootScope', function(obfCompile, obfRootScope) {
 *     // ...
 *   }]);
 *
 *   // Therefore
 *   expect(injector.annotate(
 *      ['$compile', '$rootScope', function(obfus_$compile, obfus_$rootScope) {}])
 *    ).toEqual(['$compile', '$rootScope']);
 * ```
 *
 * @param {Function|Array.<string|Function>} fn Function for which dependent service names need to
 * be retrieved as described above.
 *
 * @param {boolean=} [strictDi=false] Disallow argument name annotation inference.
 *
 * @returns {Array.<string>} The names of the services which the function requires.
 */




/**
 * @ngdoc service
 * @name $provide
 *
 * @description
 *
 * The {@link auto.$provide $provide} service has a number of methods for registering components
 * with the {@link auto.$injector $injector}. Many of these functions are also exposed on
 * {@link angular.Module}.
 *
 * An Angular **service** is a singleton object created by a **service factory**.  These **service
 * factories** are functions which, in turn, are created by a **service provider**.
 * The **service providers** are constructor functions. When instantiated they must contain a
 * property called `$get`, which holds the **service factory** function.
 *
 * When you request a service, the {@link auto.$injector $injector} is responsible for finding the
 * correct **service provider**, instantiating it and then calling its `$get` **service factory**
 * function to get the instance of the **service**.
 *
 * Often services have no configuration options and there is no need to add methods to the service
 * provider.  The provider will be no more than a constructor function with a `$get` property. For
 * these cases the {@link auto.$provide $provide} service has additional helper methods to register
 * services without specifying a provider.
 *
 * * {@link auto.$provide#provider provider(provider)} - registers a **service provider** with the
 *     {@link auto.$injector $injector}
 * * {@link auto.$provide#constant constant(obj)} - registers a value/object that can be accessed by
 *     providers and services.
 * * {@link auto.$provide#value value(obj)} - registers a value/object that can only be accessed by
 *     services, not providers.
 * * {@link auto.$provide#factory factory(fn)} - registers a service **factory function**, `fn`,
 *     that will be wrapped in a **service provider** object, whose `$get` property will contain the
 *     given factory function.
 * * {@link auto.$provide#service service(class)} - registers a **constructor function**, `class`
 *     that will be wrapped in a **service provider** object, whose `$get` property will instantiate
 *      a new object using the given constructor function.
 *
 * See the individual methods for more information and examples.
 */

/**
 * @ngdoc method
 * @name $provide#provider
 * @description
 *
 * Register a **provider function** with the {@link auto.$injector $injector}. Provider functions
 * are constructor functions, whose instances are responsible for "providing" a factory for a
 * service.
 *
 * Service provider names start with the name of the service they provide followed by `Provider`.
 * For example, the {@link ng.$log $log} service has a provider called
 * {@link ng.$logProvider $logProvider}.
 *
 * Service provider objects can have additional methods which allow configuration of the provider
 * and its service. Importantly, you can configure what kind of service is created by the `$get`
 * method, or how that service will act. For example, the {@link ng.$logProvider $logProvider} has a
 * method {@link ng.$logProvider#debugEnabled debugEnabled}
 * which lets you specify whether the {@link ng.$log $log} service will log debug messages to the
 * console or not.
 *
 * @param {string} name The name of the instance. NOTE: the provider will be available under `name +
                        'Provider'` key.
 * @param {(Object|function())} provider If the provider is:
 *
 *   - `Object`: then it should have a `$get` method. The `$get` method will be invoked using
 *     {@link auto.$injector#invoke $injector.invoke()} when an instance needs to be created.
 *   - `Constructor`: a new instance of the provider will be created using
 *     {@link auto.$injector#instantiate $injector.instantiate()}, then treated as `object`.
 *
 * @returns {Object} registered provider instance

 * @example
 *
 * The following example shows how to create a simple event tracking service and register it using
 * {@link auto.$provide#provider $provide.provider()}.
 *
 * ```js
 *  // Define the eventTracker provider
 *  function EventTrackerProvider() {
 *    var trackingUrl = '/track';
 *
 *    // A provider method for configuring where the tracked events should been saved
 *    this.setTrackingUrl = function(url) {
 *      trackingUrl = url;
 *    };
 *
 *    // The service factory function
 *    this.$get = ['$http', function($http) {
 *      var trackedEvents = {};
 *      return {
 *        // Call this to track an event
 *        event: function(event) {
 *          var count = trackedEvents[event] || 0;
 *          count += 1;
 *          trackedEvents[event] = count;
 *          return count;
 *        },
 *        // Call this to save the tracked events to the trackingUrl
 *        save: function() {
 *          $http.post(trackingUrl, trackedEvents);
 *        }
 *      };
 *    }];
 *  }
 *
 *  describe('eventTracker', function() {
 *    var postSpy;
 *
 *    beforeEach(module(function($provide) {
 *      // Register the eventTracker provider
 *      $provide.provider('eventTracker', EventTrackerProvider);
 *    }));
 *
 *    beforeEach(module(function(eventTrackerProvider) {
 *      // Configure eventTracker provider
 *      eventTrackerProvider.setTrackingUrl('/custom-track');
 *    }));
 *
 *    it('tracks events', inject(function(eventTracker) {
 *      expect(eventTracker.event('login')).toEqual(1);
 *      expect(eventTracker.event('login')).toEqual(2);
 *    }));
 *
 *    it('saves to the tracking url', inject(function(eventTracker, $http) {
 *      postSpy = spyOn($http, 'post');
 *      eventTracker.event('login');
 *      eventTracker.save();
 *      expect(postSpy).toHaveBeenCalled();
 *      expect(postSpy.mostRecentCall.args[0]).not.toEqual('/track');
 *      expect(postSpy.mostRecentCall.args[0]).toEqual('/custom-track');
 *      expect(postSpy.mostRecentCall.args[1]).toEqual({ 'login': 1 });
 *    }));
 *  });
 * ```
 */

/**
 * @ngdoc method
 * @name $provide#factory
 * @description
 *
 * Register a **service factory**, which will be called to return the service instance.
 * This is short for registering a service where its provider consists of only a `$get` property,
 * which is the given service factory function.
 * You should use {@link auto.$provide#factory $provide.factory(getFn)} if you do not need to
 * configure your service in a provider.
 *
 * @param {string} name The name of the instance.
 * @param {Function|Array.<string|Function>} $getFn The injectable $getFn for the instance creation.
 *                      Internally this is a short hand for `$provide.provider(name, {$get: $getFn})`.
 * @returns {Object} registered provider instance
 *
 * @example
 * Here is an example of registering a service
 * ```js
 *   $provide.factory('ping', ['$http', function($http) {
 *     return function ping() {
 *       return $http.send('/ping');
 *     };
 *   }]);
 * ```
 * You would then inject and use this service like this:
 * ```js
 *   someModule.controller('Ctrl', ['ping', function(ping) {
 *     ping();
 *   }]);
 * ```
 */


/**
 * @ngdoc method
 * @name $provide#service
 * @description
 *
 * Register a **service constructor**, which will be invoked with `new` to create the service
 * instance.
 * This is short for registering a service where its provider's `$get` property is the service
 * constructor function that will be used to instantiate the service instance.
 *
 * You should use {@link auto.$provide#service $provide.service(class)} if you define your service
 * as a type/class.
 *
 * @param {string} name The name of the instance.
 * @param {Function|Array.<string|Function>} constructor An injectable class (constructor function)
 *     that will be instantiated.
 * @returns {Object} registered provider instance
 *
 * @example
 * Here is an example of registering a service using
 * {@link auto.$provide#service $provide.service(class)}.
 * ```js
 *   var Ping = function($http) {
 *     this.$http = $http;
 *   };
 *
 *   Ping.$inject = ['$http'];
 *
 *   Ping.prototype.send = function() {
 *     return this.$http.get('/ping');
 *   };
 *   $provide.service('ping', Ping);
 * ```
 * You would then inject and use this service like this:
 * ```js
 *   someModule.controller('Ctrl', ['ping', function(ping) {
 *     ping.send();
 *   }]);
 * ```
 */


/**
 * @ngdoc method
 * @name $provide#value
 * @description
 *
 * Register a **value service** with the {@link auto.$injector $injector}, such as a string, a
 * number, an array, an object or a function.  This is short for registering a service where its
 * provider's `$get` property is a factory function that takes no arguments and returns the **value
 * service**.
 *
 * Value services are similar to constant services, except that they cannot be injected into a
 * module configuration function (see {@link angular.Module#config}) but they can be overridden by
 * an Angular
 * {@link auto.$provide#decorator decorator}.
 *
 * @param {string} name The name of the instance.
 * @param {*} value The value.
 * @returns {Object} registered provider instance
 *
 * @example
 * Here are some examples of creating value services.
 * ```js
 *   $provide.value('ADMIN_USER', 'admin');
 *
 *   $provide.value('RoleLookup', { admin: 0, writer: 1, reader: 2 });
 *
 *   $provide.value('halfOf', function(value) {
 *     return value / 2;
 *   });
 * ```
 */


/**
 * @ngdoc method
 * @name $provide#constant
 * @description
 *
 * Register a **constant service**, such as a string, a number, an array, an object or a function,
 * with the {@link auto.$injector $injector}. Unlike {@link auto.$provide#value value} it can be
 * injected into a module configuration function (see {@link angular.Module#config}) and it cannot
 * be overridden by an Angular {@link auto.$provide#decorator decorator}.
 *
 * @param {string} name The name of the constant.
 * @param {*} value The constant value.
 * @returns {Object} registered instance
 *
 * @example
 * Here a some examples of creating constants:
 * ```js
 *   $provide.constant('SHARD_HEIGHT', 306);
 *
 *   $provide.constant('MY_COLOURS', ['red', 'blue', 'grey']);
 *
 *   $provide.constant('double', function(value) {
 *     return value * 2;
 *   });
 * ```
 */


/**
 * @ngdoc method
 * @name $provide#decorator
 * @description
 *
 * Register a **service decorator** with the {@link auto.$injector $injector}. A service decorator
 * intercepts the creation of a service, allowing it to override or modify the behaviour of the
 * service. The object returned by the decorator may be the original service, or a new service
 * object which replaces or wraps and delegates to the original service.
 *
 * @param {string} name The name of the service to decorate.
 * @param {Function|Array.<string|Function>} decorator This function will be invoked when the service needs to be
 *    instantiated and should return the decorated service instance. The function is called using
 *    the {@link auto.$injector#invoke injector.invoke} method and is therefore fully injectable.
 *    Local injection arguments:
 *
 *    * `$delegate` - The original service instance, which can be monkey patched, configured,
 *      decorated or delegated to.
 *
 * @example
 * Here we decorate the {@link ng.$log $log} service to convert warnings to errors by intercepting
 * calls to {@link ng.$log#error $log.warn()}.
 * ```js
 *   $provide.decorator('$log', ['$delegate', function($delegate) {
 *     $delegate.warn = $delegate.error;
 *     return $delegate;
 *   }]);
 * ```
 */


function createInjector(modulesToLoad, strictDi) {
  strictDi = (strictDi === true);
  var INSTANTIATING = {},
      providerSuffix = 'Provider',
      path = [],
      loadedModules = new HashMap([], true),
      providerCache = {
        $provide: {
            provider: supportObject(provider),
            factory: supportObject(factory),
            service: supportObject(service),
            value: supportObject(value),
            constant: supportObject(constant),
            decorator: decorator
          }
      },
      providerInjector = (providerCache.$injector =
          createInternalInjector(providerCache, function(serviceName, caller) {
            if (angular.isString(caller)) {
              path.push(caller);
            }
            throw $injectorMinErr('unpr', "Unknown provider: {0}", path.join(' <- '));
          })),
      instanceCache = {},
      instanceInjector = (instanceCache.$injector =
          createInternalInjector(instanceCache, function(serviceName, caller) {
            var provider = providerInjector.get(serviceName + providerSuffix, caller);
            return instanceInjector.invoke(provider.$get, provider, undefined, serviceName);
          }));


  forEach(loadModules(modulesToLoad), function(fn) { instanceInjector.invoke(fn || noop); });

  return instanceInjector;

  ////////////////////////////////////
  // $provider
  ////////////////////////////////////

  function supportObject(delegate) {
    return function(key, value) {
      if (isObject(key)) {
        forEach(key, reverseParams(delegate));
      } else {
        return delegate(key, value);
      }
    };
  }

  function provider(name, provider_) {
    assertNotHasOwnProperty(name, 'service');
    if (isFunction(provider_) || isArray(provider_)) {
      provider_ = providerInjector.instantiate(provider_);
    }
    if (!provider_.$get) {
      throw $injectorMinErr('pget', "Provider '{0}' must define $get factory method.", name);
    }
    return providerCache[name + providerSuffix] = provider_;
  }

  function enforceReturnValue(name, factory) {
    return function enforcedReturnValue() {
      var result = instanceInjector.invoke(factory, this);
      if (isUndefined(result)) {
        throw $injectorMinErr('undef', "Provider '{0}' must return a value from $get factory method.", name);
      }
      return result;
    };
  }

  function factory(name, factoryFn, enforce) {
    return provider(name, {
      $get: enforce !== false ? enforceReturnValue(name, factoryFn) : factoryFn
    });
  }

  function service(name, constructor) {
    return factory(name, ['$injector', function($injector) {
      return $injector.instantiate(constructor);
    }]);
  }

  function value(name, val) { return factory(name, valueFn(val), false); }

  function constant(name, value) {
    assertNotHasOwnProperty(name, 'constant');
    providerCache[name] = value;
    instanceCache[name] = value;
  }

  function decorator(serviceName, decorFn) {
    var origProvider = providerInjector.get(serviceName + providerSuffix),
        orig$get = origProvider.$get;

    origProvider.$get = function() {
      var origInstance = instanceInjector.invoke(orig$get, origProvider);
      return instanceInjector.invoke(decorFn, null, {$delegate: origInstance});
    };
  }

  ////////////////////////////////////
  // Module Loading
  ////////////////////////////////////
  function loadModules(modulesToLoad) {
    var runBlocks = [], moduleFn;
    forEach(modulesToLoad, function(module) {
      if (loadedModules.get(module)) return;
      loadedModules.put(module, true);

      function runInvokeQueue(queue) {
        var i, ii;
        for (i = 0, ii = queue.length; i < ii; i++) {
          var invokeArgs = queue[i],
              provider = providerInjector.get(invokeArgs[0]);

          provider[invokeArgs[1]].apply(provider, invokeArgs[2]);
        }
      }

      try {
        if (isString(module)) {
          moduleFn = angularModule(module);
          runBlocks = runBlocks.concat(loadModules(moduleFn.requires)).concat(moduleFn._runBlocks);
          runInvokeQueue(moduleFn._invokeQueue);
          runInvokeQueue(moduleFn._configBlocks);
        } else if (isFunction(module)) {
            runBlocks.push(providerInjector.invoke(module));
        } else if (isArray(module)) {
            runBlocks.push(providerInjector.invoke(module));
        } else {
          assertArgFn(module, 'module');
        }
      } catch (e) {
        if (isArray(module)) {
          module = module[module.length - 1];
        }
        if (e.message && e.stack && e.stack.indexOf(e.message) == -1) {
          // Safari & FF's stack traces don't contain error.message content
          // unlike those of Chrome and IE
          // So if stack doesn't contain message, we create a new string that contains both.
          // Since error.stack is read-only in Safari, I'm overriding e and not e.stack here.
          /* jshint -W022 */
          e = e.message + '\n' + e.stack;
        }
        throw $injectorMinErr('modulerr', "Failed to instantiate module {0} due to:\n{1}",
                  module, e.stack || e.message || e);
      }
    });
    return runBlocks;
  }

  ////////////////////////////////////
  // internal Injector
  ////////////////////////////////////

  function createInternalInjector(cache, factory) {

    function getService(serviceName, caller) {
      if (cache.hasOwnProperty(serviceName)) {
        if (cache[serviceName] === INSTANTIATING) {
          throw $injectorMinErr('cdep', 'Circular dependency found: {0}',
                    serviceName + ' <- ' + path.join(' <- '));
        }
        return cache[serviceName];
      } else {
        try {
          path.unshift(serviceName);
          cache[serviceName] = INSTANTIATING;
          return cache[serviceName] = factory(serviceName, caller);
        } catch (err) {
          if (cache[serviceName] === INSTANTIATING) {
            delete cache[serviceName];
          }
          throw err;
        } finally {
          path.shift();
        }
      }
    }

    function invoke(fn, self, locals, serviceName) {
      if (typeof locals === 'string') {
        serviceName = locals;
        locals = null;
      }

      var args = [],
          $inject = createInjector.$$annotate(fn, strictDi, serviceName),
          length, i,
          key;

      for (i = 0, length = $inject.length; i < length; i++) {
        key = $inject[i];
        if (typeof key !== 'string') {
          throw $injectorMinErr('itkn',
                  'Incorrect injection token! Expected service name as string, got {0}', key);
        }
        args.push(
          locals && locals.hasOwnProperty(key)
          ? locals[key]
          : getService(key, serviceName)
        );
      }
      if (isArray(fn)) {
        fn = fn[length];
      }

      // http://jsperf.com/angularjs-invoke-apply-vs-switch
      // #5388
      return fn.apply(self, args);
    }

    function instantiate(Type, locals, serviceName) {
      // Check if Type is annotated and use just the given function at n-1 as parameter
      // e.g. someModule.factory('greeter', ['$window', function(renamed$window) {}]);
      // Object creation: http://jsperf.com/create-constructor/2
      var instance = Object.create((isArray(Type) ? Type[Type.length - 1] : Type).prototype || null);
      var returnedValue = invoke(Type, instance, locals, serviceName);

      return isObject(returnedValue) || isFunction(returnedValue) ? returnedValue : instance;
    }

    return {
      invoke: invoke,
      instantiate: instantiate,
      get: getService,
      annotate: createInjector.$$annotate,
      has: function(name) {
        return providerCache.hasOwnProperty(name + providerSuffix) || cache.hasOwnProperty(name);
      }
    };
  }
}

createInjector.$$annotate = annotate;

/**
 * @ngdoc provider
 * @name $anchorScrollProvider
 *
 * @description
 * Use `$anchorScrollProvider` to disable automatic scrolling whenever
 * {@link ng.$location#hash $location.hash()} changes.
 */
function $AnchorScrollProvider() {

  var autoScrollingEnabled = true;

  /**
   * @ngdoc method
   * @name $anchorScrollProvider#disableAutoScrolling
   *
   * @description
   * By default, {@link ng.$anchorScroll $anchorScroll()} will automatically detect changes to
   * {@link ng.$location#hash $location.hash()} and scroll to the element matching the new hash.<br />
   * Use this method to disable automatic scrolling.
   *
   * If automatic scrolling is disabled, one must explicitly call
   * {@link ng.$anchorScroll $anchorScroll()} in order to scroll to the element related to the
   * current hash.
   */
  this.disableAutoScrolling = function() {
    autoScrollingEnabled = false;
  };

  /**
   * @ngdoc service
   * @name $anchorScroll
   * @kind function
   * @requires $window
   * @requires $location
   * @requires $rootScope
   *
   * @description
   * When called, it checks the current value of {@link ng.$location#hash $location.hash()} and
   * scrolls to the related element, according to the rules specified in the
   * [Html5 spec](http://dev.w3.org/html5/spec/Overview.html#the-indicated-part-of-the-document).
   *
   * It also watches the {@link ng.$location#hash $location.hash()} and automatically scrolls to
   * match any anchor whenever it changes. This can be disabled by calling
   * {@link ng.$anchorScrollProvider#disableAutoScrolling $anchorScrollProvider.disableAutoScrolling()}.
   *
   * Additionally, you can use its {@link ng.$anchorScroll#yOffset yOffset} property to specify a
   * vertical scroll-offset (either fixed or dynamic).
   *
   * @property {(number|function|jqLite)} yOffset
   * If set, specifies a vertical scroll-offset. This is often useful when there are fixed
   * positioned elements at the top of the page, such as navbars, headers etc.
   *
   * `yOffset` can be specified in various ways:
   * - **number**: A fixed number of pixels to be used as offset.<br /><br />
   * - **function**: A getter function called everytime `$anchorScroll()` is executed. Must return
   *   a number representing the offset (in pixels).<br /><br />
   * - **jqLite**: A jqLite/jQuery element to be used for specifying the offset. The distance from
   *   the top of the page to the element's bottom will be used as offset.<br />
   *   **Note**: The element will be taken into account only as long as its `position` is set to
   *   `fixed`. This option is useful, when dealing with responsive navbars/headers that adjust
   *   their height and/or positioning according to the viewport's size.
   *
   * <br />
   * <div class="alert alert-warning">
   * In order for `yOffset` to work properly, scrolling should take place on the document's root and
   * not some child element.
   * </div>
   *
   * @example
     <example module="anchorScrollExample">
       <file name="index.html">
         <div id="scrollArea" ng-controller="ScrollController">
           <a ng-click="gotoBottom()">Go to bottom</a>
           <a id="bottom"></a> You're at the bottom!
         </div>
       </file>
       <file name="script.js">
         angular.module('anchorScrollExample', [])
           .controller('ScrollController', ['$scope', '$location', '$anchorScroll',
             function ($scope, $location, $anchorScroll) {
               $scope.gotoBottom = function() {
                 // set the location.hash to the id of
                 // the element you wish to scroll to.
                 $location.hash('bottom');

                 // call $anchorScroll()
                 $anchorScroll();
               };
             }]);
       </file>
       <file name="style.css">
         #scrollArea {
           height: 280px;
           overflow: auto;
         }

         #bottom {
           display: block;
           margin-top: 2000px;
         }
       </file>
     </example>
   *
   * <hr />
   * The example below illustrates the use of a vertical scroll-offset (specified as a fixed value).
   * See {@link ng.$anchorScroll#yOffset $anchorScroll.yOffset} for more details.
   *
   * @example
     <example module="anchorScrollOffsetExample">
       <file name="index.html">
         <div class="fixed-header" ng-controller="headerCtrl">
           <a href="" ng-click="gotoAnchor(x)" ng-repeat="x in [1,2,3,4,5]">
             Go to anchor {{x}}
           </a>
         </div>
         <div id="anchor{{x}}" class="anchor" ng-repeat="x in [1,2,3,4,5]">
           Anchor {{x}} of 5
         </div>
       </file>
       <file name="script.js">
         angular.module('anchorScrollOffsetExample', [])
           .run(['$anchorScroll', function($anchorScroll) {
             $anchorScroll.yOffset = 50;   // always scroll by 50 extra pixels
           }])
           .controller('headerCtrl', ['$anchorScroll', '$location', '$scope',
             function ($anchorScroll, $location, $scope) {
               $scope.gotoAnchor = function(x) {
                 var newHash = 'anchor' + x;
                 if ($location.hash() !== newHash) {
                   // set the $location.hash to `newHash` and
                   // $anchorScroll will automatically scroll to it
                   $location.hash('anchor' + x);
                 } else {
                   // call $anchorScroll() explicitly,
                   // since $location.hash hasn't changed
                   $anchorScroll();
                 }
               };
             }
           ]);
       </file>
       <file name="style.css">
         body {
           padding-top: 50px;
         }

         .anchor {
           border: 2px dashed DarkOrchid;
           padding: 10px 10px 200px 10px;
         }

         .fixed-header {
           background-color: rgba(0, 0, 0, 0.2);
           height: 50px;
           position: fixed;
           top: 0; left: 0; right: 0;
         }

         .fixed-header > a {
           display: inline-block;
           margin: 5px 15px;
         }
       </file>
     </example>
   */
  this.$get = ['$window', '$location', '$rootScope', function($window, $location, $rootScope) {
    var document = $window.document;

    // Helper function to get first anchor from a NodeList
    // (using `Array#some()` instead of `angular#forEach()` since it's more performant
    //  and working in all supported browsers.)
    function getFirstAnchor(list) {
      var result = null;
      Array.prototype.some.call(list, function(element) {
        if (nodeName_(element) === 'a') {
          result = element;
          return true;
        }
      });
      return result;
    }

    function getYOffset() {

      var offset = scroll.yOffset;

      if (isFunction(offset)) {
        offset = offset();
      } else if (isElement(offset)) {
        var elem = offset[0];
        var style = $window.getComputedStyle(elem);
        if (style.position !== 'fixed') {
          offset = 0;
        } else {
          offset = elem.getBoundingClientRect().bottom;
        }
      } else if (!isNumber(offset)) {
        offset = 0;
      }

      return offset;
    }

    function scrollTo(elem) {
      if (elem) {
        elem.scrollIntoView();

        var offset = getYOffset();

        if (offset) {
          // `offset` is the number of pixels we should scroll UP in order to align `elem` properly.
          // This is true ONLY if the call to `elem.scrollIntoView()` initially aligns `elem` at the
          // top of the viewport.
          //
          // IF the number of pixels from the top of `elem` to the end of the page's content is less
          // than the height of the viewport, then `elem.scrollIntoView()` will align the `elem` some
          // way down the page.
          //
          // This is often the case for elements near the bottom of the page.
          //
          // In such cases we do not need to scroll the whole `offset` up, just the difference between
          // the top of the element and the offset, which is enough to align the top of `elem` at the
          // desired position.
          var elemTop = elem.getBoundingClientRect().top;
          $window.scrollBy(0, elemTop - offset);
        }
      } else {
        $window.scrollTo(0, 0);
      }
    }

    function scroll() {
      var hash = $location.hash(), elm;

      // empty hash, scroll to the top of the page
      if (!hash) scrollTo(null);

      // element with given id
      else if ((elm = document.getElementById(hash))) scrollTo(elm);

      // first anchor with given name :-D
      else if ((elm = getFirstAnchor(document.getElementsByName(hash)))) scrollTo(elm);

      // no element and hash == 'top', scroll to the top of the page
      else if (hash === 'top') scrollTo(null);
    }

    // does not scroll when user clicks on anchor link that is currently on
    // (no url change, no $location.hash() change), browser native does scroll
    if (autoScrollingEnabled) {
      $rootScope.$watch(function autoScrollWatch() {return $location.hash();},
        function autoScrollWatchAction(newVal, oldVal) {
          // skip the initial scroll if $location.hash is empty
          if (newVal === oldVal && newVal === '') return;

          jqLiteDocumentLoaded(function() {
            $rootScope.$evalAsync(scroll);
          });
        });
    }

    return scroll;
  }];
}

var $animateMinErr = minErr('$animate');

/**
 * @ngdoc provider
 * @name $animateProvider
 *
 * @description
 * Default implementation of $animate that doesn't perform any animations, instead just
 * synchronously performs DOM
 * updates and calls done() callbacks.
 *
 * In order to enable animations the ngAnimate module has to be loaded.
 *
 * To see the functional implementation check out src/ngAnimate/animate.js
 */
var $AnimateProvider = ['$provide', function($provide) {


  this.$$selectors = {};


  /**
   * @ngdoc method
   * @name $animateProvider#register
   *
   * @description
   * Registers a new injectable animation factory function. The factory function produces the
   * animation object which contains callback functions for each event that is expected to be
   * animated.
   *
   *   * `eventFn`: `function(Element, doneFunction)` The element to animate, the `doneFunction`
   *   must be called once the element animation is complete. If a function is returned then the
   *   animation service will use this function to cancel the animation whenever a cancel event is
   *   triggered.
   *
   *
   * ```js
   *   return {
     *     eventFn : function(element, done) {
     *       //code to run the animation
     *       //once complete, then run done()
     *       return function cancellationFunction() {
     *         //code to cancel the animation
     *       }
     *     }
     *   }
   * ```
   *
   * @param {string} name The name of the animation.
   * @param {Function} factory The factory function that will be executed to return the animation
   *                           object.
   */
  this.register = function(name, factory) {
    var key = name + '-animation';
    if (name && name.charAt(0) != '.') throw $animateMinErr('notcsel',
        "Expecting class selector starting with '.' got '{0}'.", name);
    this.$$selectors[name.substr(1)] = key;
    $provide.factory(key, factory);
  };

  /**
   * @ngdoc method
   * @name $animateProvider#classNameFilter
   *
   * @description
   * Sets and/or returns the CSS class regular expression that is checked when performing
   * an animation. Upon bootstrap the classNameFilter value is not set at all and will
   * therefore enable $animate to attempt to perform an animation on any element.
   * When setting the classNameFilter value, animations will only be performed on elements
   * that successfully match the filter expression. This in turn can boost performance
   * for low-powered devices as well as applications containing a lot of structural operations.
   * @param {RegExp=} expression The className expression which will be checked against all animations
   * @return {RegExp} The current CSS className expression value. If null then there is no expression value
   */
  this.classNameFilter = function(expression) {
    if (arguments.length === 1) {
      this.$$classNameFilter = (expression instanceof RegExp) ? expression : null;
    }
    return this.$$classNameFilter;
  };

  this.$get = ['$$q', '$$asyncCallback', '$rootScope', function($$q, $$asyncCallback, $rootScope) {

    var currentDefer;

    function runAnimationPostDigest(fn) {
      var cancelFn, defer = $$q.defer();
      defer.promise.$$cancelFn = function ngAnimateMaybeCancel() {
        cancelFn && cancelFn();
      };

      $rootScope.$$postDigest(function ngAnimatePostDigest() {
        cancelFn = fn(function ngAnimateNotifyComplete() {
          defer.resolve();
        });
      });

      return defer.promise;
    }

    function resolveElementClasses(element, classes) {
      var toAdd = [], toRemove = [];

      var hasClasses = createMap();
      forEach((element.attr('class') || '').split(/\s+/), function(className) {
        hasClasses[className] = true;
      });

      forEach(classes, function(status, className) {
        var hasClass = hasClasses[className];

        // If the most recent class manipulation (via $animate) was to remove the class, and the
        // element currently has the class, the class is scheduled for removal. Otherwise, if
        // the most recent class manipulation (via $animate) was to add the class, and the
        // element does not currently have the class, the class is scheduled to be added.
        if (status === false && hasClass) {
          toRemove.push(className);
        } else if (status === true && !hasClass) {
          toAdd.push(className);
        }
      });

      return (toAdd.length + toRemove.length) > 0 &&
        [toAdd.length ? toAdd : null, toRemove.length ? toRemove : null];
    }

    function cachedClassManipulation(cache, classes, op) {
      for (var i=0, ii = classes.length; i < ii; ++i) {
        var className = classes[i];
        cache[className] = op;
      }
    }

    function asyncPromise() {
      // only serve one instance of a promise in order to save CPU cycles
      if (!currentDefer) {
        currentDefer = $$q.defer();
        $$asyncCallback(function() {
          currentDefer.resolve();
          currentDefer = null;
        });
      }
      return currentDefer.promise;
    }

    function applyStyles(element, options) {
      if (angular.isObject(options)) {
        var styles = extend(options.from || {}, options.to || {});
        element.css(styles);
      }
    }

    /**
     *
     * @ngdoc service
     * @name $animate
     * @description The $animate service provides rudimentary DOM manipulation functions to
     * insert, remove and move elements within the DOM, as well as adding and removing classes.
     * This service is the core service used by the ngAnimate $animator service which provides
     * high-level animation hooks for CSS and JavaScript.
     *
     * $animate is available in the AngularJS core, however, the ngAnimate module must be included
     * to enable full out animation support. Otherwise, $animate will only perform simple DOM
     * manipulation operations.
     *
     * To learn more about enabling animation support, click here to visit the {@link ngAnimate
     * ngAnimate module page} as well as the {@link ngAnimate.$animate ngAnimate $animate service
     * page}.
     */
    return {
      animate: function(element, from, to) {
        applyStyles(element, { from: from, to: to });
        return asyncPromise();
      },

      /**
       *
       * @ngdoc method
       * @name $animate#enter
       * @kind function
       * @description Inserts the element into the DOM either after the `after` element or
       * as the first child within the `parent` element. When the function is called a promise
       * is returned that will be resolved at a later time.
       * @param {DOMElement} element the element which will be inserted into the DOM
       * @param {DOMElement} parent the parent element which will append the element as
       *   a child (if the after element is not present)
       * @param {DOMElement} after the sibling element which will append the element
       *   after itself
       * @param {object=} options an optional collection of styles that will be applied to the element.
       * @return {Promise} the animation callback promise
       */
      enter: function(element, parent, after, options) {
        applyStyles(element, options);
        after ? after.after(element)
              : parent.prepend(element);
        return asyncPromise();
      },

      /**
       *
       * @ngdoc method
       * @name $animate#leave
       * @kind function
       * @description Removes the element from the DOM. When the function is called a promise
       * is returned that will be resolved at a later time.
       * @param {DOMElement} element the element which will be removed from the DOM
       * @param {object=} options an optional collection of options that will be applied to the element.
       * @return {Promise} the animation callback promise
       */
      leave: function(element, options) {
        applyStyles(element, options);
        element.remove();
        return asyncPromise();
      },

      /**
       *
       * @ngdoc method
       * @name $animate#move
       * @kind function
       * @description Moves the position of the provided element within the DOM to be placed
       * either after the `after` element or inside of the `parent` element. When the function
       * is called a promise is returned that will be resolved at a later time.
       *
       * @param {DOMElement} element the element which will be moved around within the
       *   DOM
       * @param {DOMElement} parent the parent element where the element will be
       *   inserted into (if the after element is not present)
       * @param {DOMElement} after the sibling element where the element will be
       *   positioned next to
       * @param {object=} options an optional collection of options that will be applied to the element.
       * @return {Promise} the animation callback promise
       */
      move: function(element, parent, after, options) {
        // Do not remove element before insert. Removing will cause data associated with the
        // element to be dropped. Insert will implicitly do the remove.
        return this.enter(element, parent, after, options);
      },

      /**
       *
       * @ngdoc method
       * @name $animate#addClass
       * @kind function
       * @description Adds the provided className CSS class value to the provided element.
       * When the function is called a promise is returned that will be resolved at a later time.
       * @param {DOMElement} element the element which will have the className value
       *   added to it
       * @param {string} className the CSS class which will be added to the element
       * @param {object=} options an optional collection of options that will be applied to the element.
       * @return {Promise} the animation callback promise
       */
      addClass: function(element, className, options) {
        return this.setClass(element, className, [], options);
      },

      $$addClassImmediately: function(element, className, options) {
        element = jqLite(element);
        className = !isString(className)
                        ? (isArray(className) ? className.join(' ') : '')
                        : className;
        forEach(element, function(element) {
          jqLiteAddClass(element, className);
        });
        applyStyles(element, options);
        return asyncPromise();
      },

      /**
       *
       * @ngdoc method
       * @name $animate#removeClass
       * @kind function
       * @description Removes the provided className CSS class value from the provided element.
       * When the function is called a promise is returned that will be resolved at a later time.
       * @param {DOMElement} element the element which will have the className value
       *   removed from it
       * @param {string} className the CSS class which will be removed from the element
       * @param {object=} options an optional collection of options that will be applied to the element.
       * @return {Promise} the animation callback promise
       */
      removeClass: function(element, className, options) {
        return this.setClass(element, [], className, options);
      },

      $$removeClassImmediately: function(element, className, options) {
        element = jqLite(element);
        className = !isString(className)
                        ? (isArray(className) ? className.join(' ') : '')
                        : className;
        forEach(element, function(element) {
          jqLiteRemoveClass(element, className);
        });
        applyStyles(element, options);
        return asyncPromise();
      },

      /**
       *
       * @ngdoc method
       * @name $animate#setClass
       * @kind function
       * @description Adds and/or removes the given CSS classes to and from the element.
       * When the function is called a promise is returned that will be resolved at a later time.
       * @param {DOMElement} element the element which will have its CSS classes changed
       *   removed from it
       * @param {string} add the CSS classes which will be added to the element
       * @param {string} remove the CSS class which will be removed from the element
       * @param {object=} options an optional collection of options that will be applied to the element.
       * @return {Promise} the animation callback promise
       */
      setClass: function(element, add, remove, options) {
        var self = this;
        var STORAGE_KEY = '$$animateClasses';
        var createdCache = false;
        element = jqLite(element);

        var cache = element.data(STORAGE_KEY);
        if (!cache) {
          cache = {
            classes: {},
            options: options
          };
          createdCache = true;
        } else if (options && cache.options) {
          cache.options = angular.extend(cache.options || {}, options);
        }

        var classes = cache.classes;

        add = isArray(add) ? add : add.split(' ');
        remove = isArray(remove) ? remove : remove.split(' ');
        cachedClassManipulation(classes, add, true);
        cachedClassManipulation(classes, remove, false);

        if (createdCache) {
          cache.promise = runAnimationPostDigest(function(done) {
            var cache = element.data(STORAGE_KEY);
            element.removeData(STORAGE_KEY);

            // in the event that the element is removed before postDigest
            // is run then the cache will be undefined and there will be
            // no need anymore to add or remove and of the element classes
            if (cache) {
              var classes = resolveElementClasses(element, cache.classes);
              if (classes) {
                self.$$setClassImmediately(element, classes[0], classes[1], cache.options);
              }
            }

            done();
          });
          element.data(STORAGE_KEY, cache);
        }

        return cache.promise;
      },

      $$setClassImmediately: function(element, add, remove, options) {
        add && this.$$addClassImmediately(element, add);
        remove && this.$$removeClassImmediately(element, remove);
        applyStyles(element, options);
        return asyncPromise();
      },

      enabled: noop,
      cancel: noop
    };
  }];
}];

function $$AsyncCallbackProvider() {
  this.$get = ['$$rAF', '$timeout', function($$rAF, $timeout) {
    return $$rAF.supported
      ? function(fn) { return $$rAF(fn); }
      : function(fn) {
        return $timeout(fn, 0, false);
      };
  }];
}

/* global stripHash: true */

/**
 * ! This is a private undocumented service !
 *
 * @name $browser
 * @requires $log
 * @description
 * This object has two goals:
 *
 * - hide all the global state in the browser caused by the window object
 * - abstract away all the browser specific features and inconsistencies
 *
 * For tests we provide {@link ngMock.$browser mock implementation} of the `$browser`
 * service, which can be used for convenient testing of the application without the interaction with
 * the real browser apis.
 */
/**
 * @param {object} window The global window object.
 * @param {object} document jQuery wrapped document.
 * @param {object} $log window.console or an object with the same interface.
 * @param {object} $sniffer $sniffer service
 */
function Browser(window, document, $log, $sniffer) {
  var self = this,
      rawDocument = document[0],
      location = window.location,
      history = window.history,
      setTimeout = window.setTimeout,
      clearTimeout = window.clearTimeout,
      pendingDeferIds = {};

  self.isMock = false;

  var outstandingRequestCount = 0;
  var outstandingRequestCallbacks = [];

  // TODO(vojta): remove this temporary api
  self.$$completeOutstandingRequest = completeOutstandingRequest;
  self.$$incOutstandingRequestCount = function() { outstandingRequestCount++; };

  /**
   * Executes the `fn` function(supports currying) and decrements the `outstandingRequestCallbacks`
   * counter. If the counter reaches 0, all the `outstandingRequestCallbacks` are executed.
   */
  function completeOutstandingRequest(fn) {
    try {
      fn.apply(null, sliceArgs(arguments, 1));
    } finally {
      outstandingRequestCount--;
      if (outstandingRequestCount === 0) {
        while (outstandingRequestCallbacks.length) {
          try {
            outstandingRequestCallbacks.pop()();
          } catch (e) {
            $log.error(e);
          }
        }
      }
    }
  }

  function getHash(url) {
    var index = url.indexOf('#');
    return index === -1 ? '' : url.substr(index);
  }

  /**
   * @private
   * Note: this method is used only by scenario runner
   * TODO(vojta): prefix this method with $$ ?
   * @param {function()} callback Function that will be called when no outstanding request
   */
  self.notifyWhenNoOutstandingRequests = function(callback) {
    // force browser to execute all pollFns - this is needed so that cookies and other pollers fire
    // at some deterministic time in respect to the test runner's actions. Leaving things up to the
    // regular poller would result in flaky tests.
    forEach(pollFns, function(pollFn) { pollFn(); });

    if (outstandingRequestCount === 0) {
      callback();
    } else {
      outstandingRequestCallbacks.push(callback);
    }
  };

  //////////////////////////////////////////////////////////////
  // Poll Watcher API
  //////////////////////////////////////////////////////////////
  var pollFns = [],
      pollTimeout;

  /**
   * @name $browser#addPollFn
   *
   * @param {function()} fn Poll function to add
   *
   * @description
   * Adds a function to the list of functions that poller periodically executes,
   * and starts polling if not started yet.
   *
   * @returns {function()} the added function
   */
  self.addPollFn = function(fn) {
    if (isUndefined(pollTimeout)) startPoller(100, setTimeout);
    pollFns.push(fn);
    return fn;
  };

  /**
   * @param {number} interval How often should browser call poll functions (ms)
   * @param {function()} setTimeout Reference to a real or fake `setTimeout` function.
   *
   * @description
   * Configures the poller to run in the specified intervals, using the specified
   * setTimeout fn and kicks it off.
   */
  function startPoller(interval, setTimeout) {
    (function check() {
      forEach(pollFns, function(pollFn) { pollFn(); });
      pollTimeout = setTimeout(check, interval);
    })();
  }

  //////////////////////////////////////////////////////////////
  // URL API
  //////////////////////////////////////////////////////////////

  var cachedState, lastHistoryState,
      lastBrowserUrl = location.href,
      baseElement = document.find('base'),
      reloadLocation = null;

  cacheState();
  lastHistoryState = cachedState;

  /**
   * @name $browser#url
   *
   * @description
   * GETTER:
   * Without any argument, this method just returns current value of location.href.
   *
   * SETTER:
   * With at least one argument, this method sets url to new value.
   * If html5 history api supported, pushState/replaceState is used, otherwise
   * location.href/location.replace is used.
   * Returns its own instance to allow chaining
   *
   * NOTE: this api is intended for use only by the $location service. Please use the
   * {@link ng.$location $location service} to change url.
   *
   * @param {string} url New url (when used as setter)
   * @param {boolean=} replace Should new url replace current history record?
   * @param {object=} state object to use with pushState/replaceState
   */
  self.url = function(url, replace, state) {
    // In modern browsers `history.state` is `null` by default; treating it separately
    // from `undefined` would cause `$browser.url('/foo')` to change `history.state`
    // to undefined via `pushState`. Instead, let's change `undefined` to `null` here.
    if (isUndefined(state)) {
      state = null;
    }

    // Android Browser BFCache causes location, history reference to become stale.
    if (location !== window.location) location = window.location;
    if (history !== window.history) history = window.history;

    // setter
    if (url) {
      var sameState = lastHistoryState === state;

      // Don't change anything if previous and current URLs and states match. This also prevents
      // IE<10 from getting into redirect loop when in LocationHashbangInHtml5Url mode.
      // See https://github.com/angular/angular.js/commit/ffb2701
      if (lastBrowserUrl === url && (!$sniffer.history || sameState)) {
        return self;
      }
      var sameBase = lastBrowserUrl && stripHash(lastBrowserUrl) === stripHash(url);
      lastBrowserUrl = url;
      lastHistoryState = state;
      // Don't use history API if only the hash changed
      // due to a bug in IE10/IE11 which leads
      // to not firing a `hashchange` nor `popstate` event
      // in some cases (see #9143).
      if ($sniffer.history && (!sameBase || !sameState)) {
        history[replace ? 'replaceState' : 'pushState'](state, '', url);
        cacheState();
        // Do the assignment again so that those two variables are referentially identical.
        lastHistoryState = cachedState;
      } else {
        if (!sameBase || reloadLocation) {
          reloadLocation = url;
        }
        if (replace) {
          location.replace(url);
        } else if (!sameBase) {
          location.href = url;
        } else {
          location.hash = getHash(url);
        }
      }
      return self;
    // getter
    } else {
      // - reloadLocation is needed as browsers don't allow to read out
      //   the new location.href if a reload happened.
      // - the replacement is a workaround for https://bugzilla.mozilla.org/show_bug.cgi?id=407172
      return reloadLocation || location.href.replace(/%27/g,"'");
    }
  };

  /**
   * @name $browser#state
   *
   * @description
   * This method is a getter.
   *
   * Return history.state or null if history.state is undefined.
   *
   * @returns {object} state
   */
  self.state = function() {
    return cachedState;
  };

  var urlChangeListeners = [],
      urlChangeInit = false;

  function cacheStateAndFireUrlChange() {
    cacheState();
    fireUrlChange();
  }

  function getCurrentState() {
    try {
      return history.state;
    } catch (e) {
      // MSIE can reportedly throw when there is no state (UNCONFIRMED).
    }
  }

  // This variable should be used *only* inside the cacheState function.
  var lastCachedState = null;
  function cacheState() {
    // This should be the only place in $browser where `history.state` is read.
    cachedState = getCurrentState();
    cachedState = isUndefined(cachedState) ? null : cachedState;

    // Prevent callbacks fo fire twice if both hashchange & popstate were fired.
    if (equals(cachedState, lastCachedState)) {
      cachedState = lastCachedState;
    }
    lastCachedState = cachedState;
  }

  function fireUrlChange() {
    if (lastBrowserUrl === self.url() && lastHistoryState === cachedState) {
      return;
    }

    lastBrowserUrl = self.url();
    lastHistoryState = cachedState;
    forEach(urlChangeListeners, function(listener) {
      listener(self.url(), cachedState);
    });
  }

  /**
   * @name $browser#onUrlChange
   *
   * @description
   * Register callback function that will be called, when url changes.
   *
   * It's only called when the url is changed from outside of angular:
   * - user types different url into address bar
   * - user clicks on history (forward/back) button
   * - user clicks on a link
   *
   * It's not called when url is changed by $browser.url() method
   *
   * The listener gets called with new url as parameter.
   *
   * NOTE: this api is intended for use only by the $location service. Please use the
   * {@link ng.$location $location service} to monitor url changes in angular apps.
   *
   * @param {function(string)} listener Listener function to be called when url changes.
   * @return {function(string)} Returns the registered listener fn - handy if the fn is anonymous.
   */
  self.onUrlChange = function(callback) {
    // TODO(vojta): refactor to use node's syntax for events
    if (!urlChangeInit) {
      // We listen on both (hashchange/popstate) when available, as some browsers (e.g. Opera)
      // don't fire popstate when user change the address bar and don't fire hashchange when url
      // changed by push/replaceState

      // html5 history api - popstate event
      if ($sniffer.history) jqLite(window).on('popstate', cacheStateAndFireUrlChange);
      // hashchange event
      jqLite(window).on('hashchange', cacheStateAndFireUrlChange);

      urlChangeInit = true;
    }

    urlChangeListeners.push(callback);
    return callback;
  };

  /**
   * Checks whether the url has changed outside of Angular.
   * Needs to be exported to be able to check for changes that have been done in sync,
   * as hashchange/popstate events fire in async.
   */
  self.$$checkUrlChange = fireUrlChange;

  //////////////////////////////////////////////////////////////
  // Misc API
  //////////////////////////////////////////////////////////////

  /**
   * @name $browser#baseHref
   *
   * @description
   * Returns current <base href>
   * (always relative - without domain)
   *
   * @returns {string} The current base href
   */
  self.baseHref = function() {
    var href = baseElement.attr('href');
    return href ? href.replace(/^(https?\:)?\/\/[^\/]*/, '') : '';
  };

  //////////////////////////////////////////////////////////////
  // Cookies API
  //////////////////////////////////////////////////////////////
  var lastCookies = {};
  var lastCookieString = '';
  var cookiePath = self.baseHref();

  function safeDecodeURIComponent(str) {
    try {
      return decodeURIComponent(str);
    } catch (e) {
      return str;
    }
  }

  /**
   * @name $browser#cookies
   *
   * @param {string=} name Cookie name
   * @param {string=} value Cookie value
   *
   * @description
   * The cookies method provides a 'private' low level access to browser cookies.
   * It is not meant to be used directly, use the $cookie service instead.
   *
   * The return values vary depending on the arguments that the method was called with as follows:
   *
   * - cookies() -> hash of all cookies, this is NOT a copy of the internal state, so do not modify
   *   it
   * - cookies(name, value) -> set name to value, if value is undefined delete the cookie
   * - cookies(name) -> the same as (name, undefined) == DELETES (no one calls it right now that
   *   way)
   *
   * @returns {Object} Hash of all cookies (if called without any parameter)
   */
  self.cookies = function(name, value) {
    var cookieLength, cookieArray, cookie, i, index;

    if (name) {
      if (value === undefined) {
        rawDocument.cookie = encodeURIComponent(name) + "=;path=" + cookiePath +
                                ";expires=Thu, 01 Jan 1970 00:00:00 GMT";
      } else {
        if (isString(value)) {
          cookieLength = (rawDocument.cookie = encodeURIComponent(name) + '=' + encodeURIComponent(value) +
                                ';path=' + cookiePath).length + 1;

          // per http://www.ietf.org/rfc/rfc2109.txt browser must allow at minimum:
          // - 300 cookies
          // - 20 cookies per unique domain
          // - 4096 bytes per cookie
          if (cookieLength > 4096) {
            $log.warn("Cookie '" + name +
              "' possibly not set or overflowed because it was too large (" +
              cookieLength + " > 4096 bytes)!");
          }
        }
      }
    } else {
      if (rawDocument.cookie !== lastCookieString) {
        lastCookieString = rawDocument.cookie;
        cookieArray = lastCookieString.split("; ");
        lastCookies = {};

        for (i = 0; i < cookieArray.length; i++) {
          cookie = cookieArray[i];
          index = cookie.indexOf('=');
          if (index > 0) { //ignore nameless cookies
            name = safeDecodeURIComponent(cookie.substring(0, index));
            // the first value that is seen for a cookie is the most
            // specific one.  values for the same cookie name that
            // follow are for less specific paths.
            if (lastCookies[name] === undefined) {
              lastCookies[name] = safeDecodeURIComponent(cookie.substring(index + 1));
            }
          }
        }
      }
      return lastCookies;
    }
  };


  /**
   * @name $browser#defer
   * @param {function()} fn A function, who's execution should be deferred.
   * @param {number=} [delay=0] of milliseconds to defer the function execution.
   * @returns {*} DeferId that can be used to cancel the task via `$browser.defer.cancel()`.
   *
   * @description
   * Executes a fn asynchronously via `setTimeout(fn, delay)`.
   *
   * Unlike when calling `setTimeout` directly, in test this function is mocked and instead of using
   * `setTimeout` in tests, the fns are queued in an array, which can be programmatically flushed
   * via `$browser.defer.flush()`.
   *
   */
  self.defer = function(fn, delay) {
    var timeoutId;
    outstandingRequestCount++;
    timeoutId = setTimeout(function() {
      delete pendingDeferIds[timeoutId];
      completeOutstandingRequest(fn);
    }, delay || 0);
    pendingDeferIds[timeoutId] = true;
    return timeoutId;
  };


  /**
   * @name $browser#defer.cancel
   *
   * @description
   * Cancels a deferred task identified with `deferId`.
   *
   * @param {*} deferId Token returned by the `$browser.defer` function.
   * @returns {boolean} Returns `true` if the task hasn't executed yet and was successfully
   *                    canceled.
   */
  self.defer.cancel = function(deferId) {
    if (pendingDeferIds[deferId]) {
      delete pendingDeferIds[deferId];
      clearTimeout(deferId);
      completeOutstandingRequest(noop);
      return true;
    }
    return false;
  };

}

function $BrowserProvider() {
  this.$get = ['$window', '$log', '$sniffer', '$document',
      function($window, $log, $sniffer, $document) {
        return new Browser($window, $document, $log, $sniffer);
      }];
}

/**
 * @ngdoc service
 * @name $cacheFactory
 *
 * @description
 * Factory that constructs {@link $cacheFactory.Cache Cache} objects and gives access to
 * them.
 *
 * ```js
 *
 *  var cache = $cacheFactory('cacheId');
 *  expect($cacheFactory.get('cacheId')).toBe(cache);
 *  expect($cacheFactory.get('noSuchCacheId')).not.toBeDefined();
 *
 *  cache.put("key", "value");
 *  cache.put("another key", "another value");
 *
 *  // We've specified no options on creation
 *  expect(cache.info()).toEqual({id: 'cacheId', size: 2});
 *
 * ```
 *
 *
 * @param {string} cacheId Name or id of the newly created cache.
 * @param {object=} options Options object that specifies the cache behavior. Properties:
 *
 *   - `{number=}` `capacity` — turns the cache into LRU cache.
 *
 * @returns {object} Newly created cache object with the following set of methods:
 *
 * - `{object}` `info()` — Returns id, size, and options of cache.
 * - `{{*}}` `put({string} key, {*} value)` — Puts a new key-value pair into the cache and returns
 *   it.
 * - `{{*}}` `get({string} key)` — Returns cached value for `key` or undefined for cache miss.
 * - `{void}` `remove({string} key)` — Removes a key-value pair from the cache.
 * - `{void}` `removeAll()` — Removes all cached values.
 * - `{void}` `destroy()` — Removes references to this cache from $cacheFactory.
 *
 * @example
   <example module="cacheExampleApp">
     <file name="index.html">
       <div ng-controller="CacheController">
         <input ng-model="newCacheKey" placeholder="Key">
         <input ng-model="newCacheValue" placeholder="Value">
         <button ng-click="put(newCacheKey, newCacheValue)">Cache</button>

         <p ng-if="keys.length">Cached Values</p>
         <div ng-repeat="key in keys">
           <span ng-bind="key"></span>
           <span>: </span>
           <b ng-bind="cache.get(key)"></b>
         </div>

         <p>Cache Info</p>
         <div ng-repeat="(key, value) in cache.info()">
           <span ng-bind="key"></span>
           <span>: </span>
           <b ng-bind="value"></b>
         </div>
       </div>
     </file>
     <file name="script.js">
       angular.module('cacheExampleApp', []).
         controller('CacheController', ['$scope', '$cacheFactory', function($scope, $cacheFactory) {
           $scope.keys = [];
           $scope.cache = $cacheFactory('cacheId');
           $scope.put = function(key, value) {
             if ($scope.cache.get(key) === undefined) {
               $scope.keys.push(key);
             }
             $scope.cache.put(key, value === undefined ? null : value);
           };
         }]);
     </file>
     <file name="style.css">
       p {
         margin: 10px 0 3px;
       }
     </file>
   </example>
 */
function $CacheFactoryProvider() {

  this.$get = function() {
    var caches = {};

    function cacheFactory(cacheId, options) {
      if (cacheId in caches) {
        throw minErr('$cacheFactory')('iid', "CacheId '{0}' is already taken!", cacheId);
      }

      var size = 0,
          stats = extend({}, options, {id: cacheId}),
          data = {},
          capacity = (options && options.capacity) || Number.MAX_VALUE,
          lruHash = {},
          freshEnd = null,
          staleEnd = null;

      /**
       * @ngdoc type
       * @name $cacheFactory.Cache
       *
       * @description
       * A cache object used to store and retrieve data, primarily used by
       * {@link $http $http} and the {@link ng.directive:script script} directive to cache
       * templates and other data.
       *
       * ```js
       *  angular.module('superCache')
       *    .factory('superCache', ['$cacheFactory', function($cacheFactory) {
       *      return $cacheFactory('super-cache');
       *    }]);
       * ```
       *
       * Example test:
       *
       * ```js
       *  it('should behave like a cache', inject(function(superCache) {
       *    superCache.put('key', 'value');
       *    superCache.put('another key', 'another value');
       *
       *    expect(superCache.info()).toEqual({
       *      id: 'super-cache',
       *      size: 2
       *    });
       *
       *    superCache.remove('another key');
       *    expect(superCache.get('another key')).toBeUndefined();
       *
       *    superCache.removeAll();
       *    expect(superCache.info()).toEqual({
       *      id: 'super-cache',
       *      size: 0
       *    });
       *  }));
       * ```
       */
      return caches[cacheId] = {

        /**
         * @ngdoc method
         * @name $cacheFactory.Cache#put
         * @kind function
         *
         * @description
         * Inserts a named entry into the {@link $cacheFactory.Cache Cache} object to be
         * retrieved later, and incrementing the size of the cache if the key was not already
         * present in the cache. If behaving like an LRU cache, it will also remove stale
         * entries from the set.
         *
         * It will not insert undefined values into the cache.
         *
         * @param {string} key the key under which the cached data is stored.
         * @param {*} value the value to store alongside the key. If it is undefined, the key
         *    will not be stored.
         * @returns {*} the value stored.
         */
        put: function(key, value) {
          if (capacity < Number.MAX_VALUE) {
            var lruEntry = lruHash[key] || (lruHash[key] = {key: key});

            refresh(lruEntry);
          }

          if (isUndefined(value)) return;
          if (!(key in data)) size++;
          data[key] = value;

          if (size > capacity) {
            this.remove(staleEnd.key);
          }

          return value;
        },

        /**
         * @ngdoc method
         * @name $cacheFactory.Cache#get
         * @kind function
         *
         * @description
         * Retrieves named data stored in the {@link $cacheFactory.Cache Cache} object.
         *
         * @param {string} key the key of the data to be retrieved
         * @returns {*} the value stored.
         */
        get: function(key) {
          if (capacity < Number.MAX_VALUE) {
            var lruEntry = lruHash[key];

            if (!lruEntry) return;

            refresh(lruEntry);
          }

          return data[key];
        },


        /**
         * @ngdoc method
         * @name $cacheFactory.Cache#remove
         * @kind function
         *
         * @description
         * Removes an entry from the {@link $cacheFactory.Cache Cache} object.
         *
         * @param {string} key the key of the entry to be removed
         */
        remove: function(key) {
          if (capacity < Number.MAX_VALUE) {
            var lruEntry = lruHash[key];

            if (!lruEntry) return;

            if (lruEntry == freshEnd) freshEnd = lruEntry.p;
            if (lruEntry == staleEnd) staleEnd = lruEntry.n;
            link(lruEntry.n,lruEntry.p);

            delete lruHash[key];
          }

          delete data[key];
          size--;
        },


        /**
         * @ngdoc method
         * @name $cacheFactory.Cache#removeAll
         * @kind function
         *
         * @description
         * Clears the cache object of any entries.
         */
        removeAll: function() {
          data = {};
          size = 0;
          lruHash = {};
          freshEnd = staleEnd = null;
        },


        /**
         * @ngdoc method
         * @name $cacheFactory.Cache#destroy
         * @kind function
         *
         * @description
         * Destroys the {@link $cacheFactory.Cache Cache} object entirely,
         * removing it from the {@link $cacheFactory $cacheFactory} set.
         */
        destroy: function() {
          data = null;
          stats = null;
          lruHash = null;
          delete caches[cacheId];
        },


        /**
         * @ngdoc method
         * @name $cacheFactory.Cache#info
         * @kind function
         *
         * @description
         * Retrieve information regarding a particular {@link $cacheFactory.Cache Cache}.
         *
         * @returns {object} an object with the following properties:
         *   <ul>
         *     <li>**id**: the id of the cache instance</li>
         *     <li>**size**: the number of entries kept in the cache instance</li>
         *     <li>**...**: any additional properties from the options object when creating the
         *       cache.</li>
         *   </ul>
         */
        info: function() {
          return extend({}, stats, {size: size});
        }
      };


      /**
       * makes the `entry` the freshEnd of the LRU linked list
       */
      function refresh(entry) {
        if (entry != freshEnd) {
          if (!staleEnd) {
            staleEnd = entry;
          } else if (staleEnd == entry) {
            staleEnd = entry.n;
          }

          link(entry.n, entry.p);
          link(entry, freshEnd);
          freshEnd = entry;
          freshEnd.n = null;
        }
      }


      /**
       * bidirectionally links two entries of the LRU linked list
       */
      function link(nextEntry, prevEntry) {
        if (nextEntry != prevEntry) {
          if (nextEntry) nextEntry.p = prevEntry; //p stands for previous, 'prev' didn't minify
          if (prevEntry) prevEntry.n = nextEntry; //n stands for next, 'next' didn't minify
        }
      }
    }


  /**
   * @ngdoc method
   * @name $cacheFactory#info
   *
   * @description
   * Get information about all the caches that have been created
   *
   * @returns {Object} - key-value map of `cacheId` to the result of calling `cache#info`
   */
    cacheFactory.info = function() {
      var info = {};
      forEach(caches, function(cache, cacheId) {
        info[cacheId] = cache.info();
      });
      return info;
    };


  /**
   * @ngdoc method
   * @name $cacheFactory#get
   *
   * @description
   * Get access to a cache object by the `cacheId` used when it was created.
   *
   * @param {string} cacheId Name or id of a cache to access.
   * @returns {object} Cache object identified by the cacheId or undefined if no such cache.
   */
    cacheFactory.get = function(cacheId) {
      return caches[cacheId];
    };


    return cacheFactory;
  };
}

/**
 * @ngdoc service
 * @name $templateCache
 *
 * @description
 * The first time a template is used, it is loaded in the template cache for quick retrieval. You
 * can load templates directly into the cache in a `script` tag, or by consuming the
 * `$templateCache` service directly.
 *
 * Adding via the `script` tag:
 *
 * ```html
 *   <script type="text/ng-template" id="templateId.html">
 *     <p>This is the content of the template</p>
 *   </script>
 * ```
 *
 * **Note:** the `script` tag containing the template does not need to be included in the `head` of
 * the document, but it must be a descendent of the {@link ng.$rootElement $rootElement} (IE,
 * element with ng-app attribute), otherwise the template will be ignored.
 *
 * Adding via the `$templateCache` service:
 *
 * ```js
 * var myApp = angular.module('myApp', []);
 * myApp.run(function($templateCache) {
 *   $templateCache.put('templateId.html', 'This is the content of the template');
 * });
 * ```
 *
 * To retrieve the template later, simply use it in your HTML:
 * ```html
 * <div ng-include=" 'templateId.html' "></div>
 * ```
 *
 * or get it via Javascript:
 * ```js
 * $templateCache.get('templateId.html')
 * ```
 *
 * See {@link ng.$cacheFactory $cacheFactory}.
 *
 */
function $TemplateCacheProvider() {
  this.$get = ['$cacheFactory', function($cacheFactory) {
    return $cacheFactory('templates');
  }];
}

/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
 *     Any commits to this file should be reviewed with security in mind.  *
 *   Changes to this file can potentially create security vulnerabilities. *
 *          An approval from 2 Core members with history of modifying      *
 *                         this file is required.                          *
 *                                                                         *
 *  Does the change somehow allow for arbitrary javascript to be executed? *
 *    Or allows for someone to change the prototype of built-in objects?   *
 *     Or gives undesired access to variables likes document or window?    *
 * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

/* ! VARIABLE/FUNCTION NAMING CONVENTIONS THAT APPLY TO THIS FILE!
 *
 * DOM-related variables:
 *
 * - "node" - DOM Node
 * - "element" - DOM Element or Node
 * - "$node" or "$element" - jqLite-wrapped node or element
 *
 *
 * Compiler related stuff:
 *
 * - "linkFn" - linking fn of a single directive
 * - "nodeLinkFn" - function that aggregates all linking fns for a particular node
 * - "childLinkFn" -  function that aggregates all linking fns for child nodes of a particular node
 * - "compositeLinkFn" - function that aggregates all linking fns for a compilation root (nodeList)
 */


/**
 * @ngdoc service
 * @name $compile
 * @kind function
 *
 * @description
 * Compiles an HTML string or DOM into a template and produces a template function, which
 * can then be used to link {@link ng.$rootScope.Scope `scope`} and the template together.
 *
 * The compilation is a process of walking the DOM tree and matching DOM elements to
 * {@link ng.$compileProvider#directive directives}.
 *
 * <div class="alert alert-warning">
 * **Note:** This document is an in-depth reference of all directive options.
 * For a gentle introduction to directives with examples of common use cases,
 * see the {@link guide/directive directive guide}.
 * </div>
 *
 * ## Comprehensive Directive API
 *
 * There are many different options for a directive.
 *
 * The difference resides in the return value of the factory function.
 * You can either return a "Directive Definition Object" (see below) that defines the directive properties,
 * or just the `postLink` function (all other properties will have the default values).
 *
 * <div class="alert alert-success">
 * **Best Practice:** It's recommended to use the "directive definition object" form.
 * </div>
 *
 * Here's an example directive declared with a Directive Definition Object:
 *
 * ```js
 *   var myModule = angular.module(...);
 *
 *   myModule.directive('directiveName', function factory(injectables) {
 *     var directiveDefinitionObject = {
 *       priority: 0,
 *       template: '<div></div>', // or // function(tElement, tAttrs) { ... },
 *       // or
 *       // templateUrl: 'directive.html', // or // function(tElement, tAttrs) { ... },
 *       transclude: false,
 *       restrict: 'A',
 *       templateNamespace: 'html',
 *       scope: false,
 *       controller: function($scope, $element, $attrs, $transclude, otherInjectables) { ... },
 *       controllerAs: 'stringIdentifier',
 *       bindToController: false,
 *       require: 'siblingDirectiveName', // or // ['^parentDirectiveName', '?optionalDirectiveName', '?^optionalParent'],
 *       compile: function compile(tElement, tAttrs, transclude) {
 *         return {
 *           pre: function preLink(scope, iElement, iAttrs, controller) { ... },
 *           post: function postLink(scope, iElement, iAttrs, controller) { ... }
 *         }
 *         // or
 *         // return function postLink( ... ) { ... }
 *       },
 *       // or
 *       // link: {
 *       //  pre: function preLink(scope, iElement, iAttrs, controller) { ... },
 *       //  post: function postLink(scope, iElement, iAttrs, controller) { ... }
 *       // }
 *       // or
 *       // link: function postLink( ... ) { ... }
 *     };
 *     return directiveDefinitionObject;
 *   });
 * ```
 *
 * <div class="alert alert-warning">
 * **Note:** Any unspecified options will use the default value. You can see the default values below.
 * </div>
 *
 * Therefore the above can be simplified as:
 *
 * ```js
 *   var myModule = angular.module(...);
 *
 *   myModule.directive('directiveName', function factory(injectables) {
 *     var directiveDefinitionObject = {
 *       link: function postLink(scope, iElement, iAttrs) { ... }
 *     };
 *     return directiveDefinitionObject;
 *     // or
 *     // return function postLink(scope, iElement, iAttrs) { ... }
 *   });
 * ```
 *
 *
 *
 * ### Directive Definition Object
 *
 * The directive definition object provides instructions to the {@link ng.$compile
 * compiler}. The attributes are:
 *
 * #### `multiElement`
 * When this property is set to true, the HTML compiler will collect DOM nodes between
 * nodes with the attributes `directive-name-start` and `directive-name-end`, and group them
 * together as the directive elements. It is recommended that this feature be used on directives
 * which are not strictly behavioural (such as {@link ngClick}), and which
 * do not manipulate or replace child nodes (such as {@link ngInclude}).
 *
 * #### `priority`
 * When there are multiple directives defined on a single DOM element, sometimes it
 * is necessary to specify the order in which the directives are applied. The `priority` is used
 * to sort the directives before their `compile` functions get called. Priority is defined as a
 * number. Directives with greater numerical `priority` are compiled first. Pre-link functions
 * are also run in priority order, but post-link functions are run in reverse order. The order
 * of directives with the same priority is undefined. The default priority is `0`.
 *
 * #### `terminal`
 * If set to true then the current `priority` will be the last set of directives
 * which will execute (any directives at the current priority will still execute
 * as the order of execution on same `priority` is undefined). Note that expressions
 * and other directives used in the directive's template will also be excluded from execution.
 *
 * #### `scope`
 * **If set to `true`,** then a new scope will be created for this directive. If multiple directives on the
 * same element request a new scope, only one new scope is created. The new scope rule does not
 * apply for the root of the template since the root of the template always gets a new scope.
 *
 * **If set to `{}` (object hash),** then a new "isolate" scope is created. The 'isolate' scope differs from
 * normal scope in that it does not prototypically inherit from the parent scope. This is useful
 * when creating reusable components, which should not accidentally read or modify data in the
 * parent scope.
 *
 * The 'isolate' scope takes an object hash which defines a set of local scope properties
 * derived from the parent scope. These local properties are useful for aliasing values for
 * templates. Locals definition is a hash of local scope property to its source:
 *
 * * `@` or `@attr` - bind a local scope property to the value of DOM attribute. The result is
 *   always a string since DOM attributes are strings. If no `attr` name is specified  then the
 *   attribute name is assumed to be the same as the local name.
 *   Given `<widget my-attr="hello {{name}}">` and widget definition
 *   of `scope: { localName:'@myAttr' }`, then widget scope property `localName` will reflect
 *   the interpolated value of `hello {{name}}`. As the `name` attribute changes so will the
 *   `localName` property on the widget scope. The `name` is read from the parent scope (not
 *   component scope).
 *
 * * `=` or `=attr` - set up bi-directional binding between a local scope property and the
 *   parent scope property of name defined via the value of the `attr` attribute. If no `attr`
 *   name is specified then the attribute name is assumed to be the same as the local name.
 *   Given `<widget my-attr="parentModel">` and widget definition of
 *   `scope: { localModel:'=myAttr' }`, then widget scope property `localModel` will reflect the
 *   value of `parentModel` on the parent scope. Any changes to `parentModel` will be reflected
 *   in `localModel` and any changes in `localModel` will reflect in `parentModel`. If the parent
 *   scope property doesn't exist, it will throw a NON_ASSIGNABLE_MODEL_EXPRESSION exception. You
 *   can avoid this behavior using `=?` or `=?attr` in order to flag the property as optional. If
 *   you want to shallow watch for changes (i.e. $watchCollection instead of $watch) you can use
 *   `=*` or `=*attr` (`=*?` or `=*?attr` if the property is optional).
 *
 * * `&` or `&attr` - provides a way to execute an expression in the context of the parent scope.
 *   If no `attr` name is specified then the attribute name is assumed to be the same as the
 *   local name. Given `<widget my-attr="count = count + value">` and widget definition of
 *   `scope: { localFn:'&myAttr' }`, then isolate scope property `localFn` will point to
 *   a function wrapper for the `count = count + value` expression. Often it's desirable to
 *   pass data from the isolated scope via an expression to the parent scope, this can be
 *   done by passing a map of local variable names and values into the expression wrapper fn.
 *   For example, if the expression is `increment(amount)` then we can specify the amount value
 *   by calling the `localFn` as `localFn({amount: 22})`.
 *
 *
 * #### `bindToController`
 * When an isolate scope is used for a component (see above), and `controllerAs` is used, `bindToController: true` will
 * allow a component to have its properties bound to the controller, rather than to scope. When the controller
 * is instantiated, the initial values of the isolate scope bindings are already available.
 *
 * #### `controller`
 * Controller constructor function. The controller is instantiated before the
 * pre-linking phase and it is shared with other directives (see
 * `require` attribute). This allows the directives to communicate with each other and augment
 * each other's behavior. The controller is injectable (and supports bracket notation) with the following locals:
 *
 * * `$scope` - Current scope associated with the element
 * * `$element` - Current element
 * * `$attrs` - Current attributes object for the element
 * * `$transclude` - A transclude linking function pre-bound to the correct transclusion scope:
 *   `function([scope], cloneLinkingFn, futureParentElement)`.
 *    * `scope`: optional argument to override the scope.
 *    * `cloneLinkingFn`: optional argument to create clones of the original transcluded content.
 *    * `futureParentElement`:
 *        * defines the parent to which the `cloneLinkingFn` will add the cloned elements.
 *        * default: `$element.parent()` resp. `$element` for `transclude:'element'` resp. `transclude:true`.
 *        * only needed for transcludes that are allowed to contain non html elements (e.g. SVG elements)
 *          and when the `cloneLinkinFn` is passed,
 *          as those elements need to created and cloned in a special way when they are defined outside their
 *          usual containers (e.g. like `<svg>`).
 *        * See also the `directive.templateNamespace` property.
 *
 *
 * #### `require`
 * Require another directive and inject its controller as the fourth argument to the linking function. The
 * `require` takes a string name (or array of strings) of the directive(s) to pass in. If an array is used, the
 * injected argument will be an array in corresponding order. If no such directive can be
 * found, or if the directive does not have a controller, then an error is raised (unless no link function
 * is specified, in which case error checking is skipped). The name can be prefixed with:
 *
 * * (no prefix) - Locate the required controller on the current element. Throw an error if not found.
 * * `?` - Attempt to locate the required controller or pass `null` to the `link` fn if not found.
 * * `^` - Locate the required controller by searching the element and its parents. Throw an error if not found.
 * * `^^` - Locate the required controller by searching the element's parents. Throw an error if not found.
 * * `?^` - Attempt to locate the required controller by searching the element and its parents or pass
 *   `null` to the `link` fn if not found.
 * * `?^^` - Attempt to locate the required controller by searching the element's parents, or pass
 *   `null` to the `link` fn if not found.
 *
 *
 * #### `controllerAs`
 * Controller alias at the directive scope. An alias for the controller so it
 * can be referenced at the directive template. The directive needs to define a scope for this
 * configuration to be used. Useful in the case when directive is used as component.
 *
 *
 * #### `restrict`
 * String of subset of `EACM` which restricts the directive to a specific directive
 * declaration style. If omitted, the defaults (elements and attributes) are used.
 *
 * * `E` - Element name (default): `<my-directive></my-directive>`
 * * `A` - Attribute (default): `<div my-directive="exp"></div>`
 * * `C` - Class: `<div class="my-directive: exp;"></div>`
 * * `M` - Comment: `<!-- directive: my-directive exp -->`
 *
 *
 * #### `templateNamespace`
 * String representing the document type used by the markup in the template.
 * AngularJS needs this information as those elements need to be created and cloned
 * in a special way when they are defined outside their usual containers like `<svg>` and `<math>`.
 *
 * * `html` - All root nodes in the template are HTML. Root nodes may also be
 *   top-level elements such as `<svg>` or `<math>`.
 * * `svg` - The root nodes in the template are SVG elements (excluding `<math>`).
 * * `math` - The root nodes in the template are MathML elements (excluding `<svg>`).
 *
 * If no `templateNamespace` is specified, then the namespace is considered to be `html`.
 *
 * #### `template`
 * HTML markup that may:
 * * Replace the contents of the directive's element (default).
 * * Replace the directive's element itself (if `replace` is true - DEPRECATED).
 * * Wrap the contents of the directive's element (if `transclude` is true).
 *
 * Value may be:
 *
 * * A string. For example `<div red-on-hover>{{delete_str}}</div>`.
 * * A function which takes two arguments `tElement` and `tAttrs` (described in the `compile`
 *   function api below) and returns a string value.
 *
 *
 * #### `templateUrl`
 * This is similar to `template` but the template is loaded from the specified URL, asynchronously.
 *
 * Because template loading is asynchronous the compiler will suspend compilation of directives on that element
 * for later when the template has been resolved.  In the meantime it will continue to compile and link
 * sibling and parent elements as though this element had not contained any directives.
 *
 * The compiler does not suspend the entire compilation to wait for templates to be loaded because this
 * would result in the whole app "stalling" until all templates are loaded asynchronously - even in the
 * case when only one deeply nested directive has `templateUrl`.
 *
 * Template loading is asynchronous even if the template has been preloaded into the {@link $templateCache}
 *
 * You can specify `templateUrl` as a string representing the URL or as a function which takes two
 * arguments `tElement` and `tAttrs` (described in the `compile` function api below) and returns
 * a string value representing the url.  In either case, the template URL is passed through {@link
 * $sce#getTrustedResourceUrl $sce.getTrustedResourceUrl}.
 *
 *
 * #### `replace` ([*DEPRECATED*!], will be removed in next major release - i.e. v2.0)
 * specify what the template should replace. Defaults to `false`.
 *
 * * `true` - the template will replace the directive's element.
 * * `false` - the template will replace the contents of the directive's element.
 *
 * The replacement process migrates all of the attributes / classes from the old element to the new
 * one. See the {@link guide/directive#template-expanding-directive
 * Directives Guide} for an example.
 *
 * There are very few scenarios where element replacement is required for the application function,
 * the main one being reusable custom components that are used within SVG contexts
 * (because SVG doesn't work with custom elements in the DOM tree).
 *
 * #### `transclude`
 * Extract the contents of the element where the directive appears and make it available to the directive.
 * The contents are compiled and provided to the directive as a **transclusion function**. See the
 * {@link $compile#transclusion Transclusion} section below.
 *
 * There are two kinds of transclusion depending upon whether you want to transclude just the contents of the
 * directive's element or the entire element:
 *
 * * `true` - transclude the content (i.e. the child nodes) of the directive's element.
 * * `'element'` - transclude the whole of the directive's element including any directives on this
 *   element that defined at a lower priority than this directive. When used, the `template`
 *   property is ignored.
 *
 *
 * #### `compile`
 *
 * ```js
 *   function compile(tElement, tAttrs, transclude) { ... }
 * ```
 *
 * The compile function deals with transforming the template DOM. Since most directives do not do
 * template transformation, it is not used often. The compile function takes the following arguments:
 *
 *   * `tElement` - template element - The element where the directive has been declared. It is
 *     safe to do template transformation on the element and child elements only.
 *
 *   * `tAttrs` - template attributes - Normalized list of attributes declared on this element shared
 *     between all directive compile functions.
 *
 *   * `transclude` -  [*DEPRECATED*!] A transclude linking function: `function(scope, cloneLinkingFn)`
 *
 * <div class="alert alert-warning">
 * **Note:** The template instance and the link instance may be different objects if the template has
 * been cloned. For this reason it is **not** safe to do anything other than DOM transformations that
 * apply to all cloned DOM nodes within the compile function. Specifically, DOM listener registration
 * should be done in a linking function rather than in a compile function.
 * </div>

 * <div class="alert alert-warning">
 * **Note:** The compile function cannot handle directives that recursively use themselves in their
 * own templates or compile functions. Compiling these directives results in an infinite loop and a
 * stack overflow errors.
 *
 * This can be avoided by manually using $compile in the postLink function to imperatively compile
 * a directive's template instead of relying on automatic template compilation via `template` or
 * `templateUrl` declaration or manual compilation inside the compile function.
 * </div>
 *
 * <div class="alert alert-error">
 * **Note:** The `transclude` function that is passed to the compile function is deprecated, as it
 *   e.g. does not know about the right outer scope. Please use the transclude function that is passed
 *   to the link function instead.
 * </div>

 * A compile function can have a return value which can be either a function or an object.
 *
 * * returning a (post-link) function - is equivalent to registering the linking function via the
 *   `link` property of the config object when the compile function is empty.
 *
 * * returning an object with function(s) registered via `pre` and `post` properties - allows you to
 *   control when a linking function should be called during the linking phase. See info about
 *   pre-linking and post-linking functions below.
 *
 *
 * #### `link`
 * This property is used only if the `compile` property is not defined.
 *
 * ```js
 *   function link(scope, iElement, iAttrs, controller, transcludeFn) { ... }
 * ```
 *
 * The link function is responsible for registering DOM listeners as well as updating the DOM. It is
 * executed after the template has been cloned. This is where most of the directive logic will be
 * put.
 *
 *   * `scope` - {@link ng.$rootScope.Scope Scope} - The scope to be used by the
 *     directive for registering {@link ng.$rootScope.Scope#$watch watches}.
 *
 *   * `iElement` - instance element - The element where the directive is to be used. It is safe to
 *     manipulate the children of the element only in `postLink` function since the children have
 *     already been linked.
 *
 *   * `iAttrs` - instance attributes - Normalized list of attributes declared on this element shared
 *     between all directive linking functions.
 *
 *   * `controller` - the directive's required controller instance(s) - Instances are shared
 *     among all directives, which allows the directives to use the controllers as a communication
 *     channel. The exact value depends on the directive's `require` property:
 *       * `string`: the controller instance
 *       * `array`: array of controller instances
 *       * no controller(s) required: `undefined`
 *
 *     If a required controller cannot be found, and it is optional, the instance is `null`,
 *     otherwise the {@link error:$compile:ctreq Missing Required Controller} error is thrown.
 *
 *   * `transcludeFn` - A transclude linking function pre-bound to the correct transclusion scope.
 *     This is the same as the `$transclude`
 *     parameter of directive controllers, see there for details.
 *     `function([scope], cloneLinkingFn, futureParentElement)`.
 *
 * #### Pre-linking function
 *
 * Executed before the child elements are linked. Not safe to do DOM transformation since the
 * compiler linking function will fail to locate the correct elements for linking.
 *
 * #### Post-linking function
 *
 * Executed after the child elements are linked.
 *
 * Note that child elements that contain `templateUrl` directives will not have been compiled
 * and linked since they are waiting for their template to load asynchronously and their own
 * compilation and linking has been suspended until that occurs.
 *
 * It is safe to do DOM transformation in the post-linking function on elements that are not waiting
 * for their async templates to be resolved.
 *
 *
 * ### Transclusion
 *
 * Transclusion is the process of extracting a collection of DOM elements from one part of the DOM and
 * copying them to another part of the DOM, while maintaining their connection to the original AngularJS
 * scope from where they were taken.
 *
 * Transclusion is used (often with {@link ngTransclude}) to insert the
 * original contents of a directive's element into a specified place in the template of the directive.
 * The benefit of transclusion, over simply moving the DOM elements manually, is that the transcluded
 * content has access to the properties on the scope from which it was taken, even if the directive
 * has isolated scope.
 * See the {@link guide/directive#creating-a-directive-that-wraps-other-elements Directives Guide}.
 *
 * This makes it possible for the widget to have private state for its template, while the transcluded
 * content has access to its originating scope.
 *
 * <div class="alert alert-warning">
 * **Note:** When testing an element transclude directive you must not place the directive at the root of the
 * DOM fragment that is being compiled. See {@link guide/unit-testing#testing-transclusion-directives
 * Testing Transclusion Directives}.
 * </div>
 *
 * #### Transclusion Functions
 *
 * When a directive requests transclusion, the compiler extracts its contents and provides a **transclusion
 * function** to the directive's `link` function and `controller`. This transclusion function is a special
 * **linking function** that will return the compiled contents linked to a new transclusion scope.
 *
 * <div class="alert alert-info">
 * If you are just using {@link ngTransclude} then you don't need to worry about this function, since
 * ngTransclude will deal with it for us.
 * </div>
 *
 * If you want to manually control the insertion and removal of the transcluded content in your directive
 * then you must use this transclude function. When you call a transclude function it returns a a jqLite/JQuery
 * object that contains the compiled DOM, which is linked to the correct transclusion scope.
 *
 * When you call a transclusion function you can pass in a **clone attach function**. This function accepts
 * two parameters, `function(clone, scope) { ... }`, where the `clone` is a fresh compiled copy of your transcluded
 * content and the `scope` is the newly created transclusion scope, to which the clone is bound.
 *
 * <div class="alert alert-info">
 * **Best Practice**: Always provide a `cloneFn` (clone attach function) when you call a translude function
 * since you then get a fresh clone of the original DOM and also have access to the new transclusion scope.
 * </div>
 *
 * It is normal practice to attach your transcluded content (`clone`) to the DOM inside your **clone
 * attach function**:
 *
 * ```js
 * var transcludedContent, transclusionScope;
 *
 * $transclude(function(clone, scope) {
 *   element.append(clone);
 *   transcludedContent = clone;
 *   transclusionScope = scope;
 * });
 * ```
 *
 * Later, if you want to remove the transcluded content from your DOM then you should also destroy the
 * associated transclusion scope:
 *
 * ```js
 * transcludedContent.remove();
 * transclusionScope.$destroy();
 * ```
 *
 * <div class="alert alert-info">
 * **Best Practice**: if you intend to add and remove transcluded content manually in your directive
 * (by calling the transclude function to get the DOM and and calling `element.remove()` to remove it),
 * then you are also responsible for calling `$destroy` on the transclusion scope.
 * </div>
 *
 * The built-in DOM manipulation directives, such as {@link ngIf}, {@link ngSwitch} and {@link ngRepeat}
 * automatically destroy their transluded clones as necessary so you do not need to worry about this if
 * you are simply using {@link ngTransclude} to inject the transclusion into your directive.
 *
 *
 * #### Transclusion Scopes
 *
 * When you call a transclude function it returns a DOM fragment that is pre-bound to a **transclusion
 * scope**. This scope is special, in that it is a child of the directive's scope (and so gets destroyed
 * when the directive's scope gets destroyed) but it inherits the properties of the scope from which it
 * was taken.
 *
 * For example consider a directive that uses transclusion and isolated scope. The DOM hierarchy might look
 * like this:
 *
 * ```html
 * <div ng-app>
 *   <div isolate>
 *     <div transclusion>
 *     </div>
 *   </div>
 * </div>
 * ```
 *
 * The `$parent` scope hierarchy will look like this:
 *
 * ```
 * - $rootScope
 *   - isolate
 *     - transclusion
 * ```
 *
 * but the scopes will inherit prototypically from different scopes to their `$parent`.
 *
 * ```
 * - $rootScope
 *   - transclusion
 * - isolate
 * ```
 *
 *
 * ### Attributes
 *
 * The {@link ng.$compile.directive.Attributes Attributes} object - passed as a parameter in the
 * `link()` or `compile()` functions. It has a variety of uses.
 *
 * accessing *Normalized attribute names:*
 * Directives like 'ngBind' can be expressed in many ways: 'ng:bind', `data-ng-bind`, or 'x-ng-bind'.
 * the attributes object allows for normalized access to
 *   the attributes.
 *
 * * *Directive inter-communication:* All directives share the same instance of the attributes
 *   object which allows the directives to use the attributes object as inter directive
 *   communication.
 *
 * * *Supports interpolation:* Interpolation attributes are assigned to the attribute object
 *   allowing other directives to read the interpolated value.
 *
 * * *Observing interpolated attributes:* Use `$observe` to observe the value changes of attributes
 *   that contain interpolation (e.g. `src="{{bar}}"`). Not only is this very efficient but it's also
 *   the only way to easily get the actual value because during the linking phase the interpolation
 *   hasn't been evaluated yet and so the value is at this time set to `undefined`.
 *
 * ```js
 * function linkingFn(scope, elm, attrs, ctrl) {
 *   // get the attribute value
 *   console.log(attrs.ngModel);
 *
 *   // change the attribute
 *   attrs.$set('ngModel', 'new value');
 *
 *   // observe changes to interpolated attribute
 *   attrs.$observe('ngModel', function(value) {
 *     console.log('ngModel has changed value to ' + value);
 *   });
 * }
 * ```
 *
 * ## Example
 *
 * <div class="alert alert-warning">
 * **Note**: Typically directives are registered with `module.directive`. The example below is
 * to illustrate how `$compile` works.
 * </div>
 *
 <example module="compileExample">
   <file name="index.html">
    <script>
      angular.module('compileExample', [], function($compileProvider) {
        // configure new 'compile' directive by passing a directive
        // factory function. The factory function injects the '$compile'
        $compileProvider.directive('compile', function($compile) {
          // directive factory creates a link function
          return function(scope, element, attrs) {
            scope.$watch(
              function(scope) {
                 // watch the 'compile' expression for changes
                return scope.$eval(attrs.compile);
              },
              function(value) {
                // when the 'compile' expression changes
                // assign it into the current DOM
                element.html(value);

                // compile the new DOM and link it to the current
                // scope.
                // NOTE: we only compile .childNodes so that
                // we don't get into infinite loop compiling ourselves
                $compile(element.contents())(scope);
              }
            );
          };
        });
      })
      .controller('GreeterController', ['$scope', function($scope) {
        $scope.name = 'Angular';
        $scope.html = 'Hello {{name}}';
      }]);
    </script>
    <div ng-controller="GreeterController">
      <input ng-model="name"> <br>
      <textarea ng-model="html"></textarea> <br>
      <div compile="html"></div>
    </div>
   </file>
   <file name="protractor.js" type="protractor">
     it('should auto compile', function() {
       var textarea = $('textarea');
       var output = $('div[compile]');
       // The initial state reads 'Hello Angular'.
       expect(output.getText()).toBe('Hello Angular');
       textarea.clear();
       textarea.sendKeys('{{name}}!');
       expect(output.getText()).toBe('Angular!');
     });
   </file>
 </example>

 *
 *
 * @param {string|DOMElement} element Element or HTML string to compile into a template function.
 * @param {function(angular.Scope, cloneAttachFn=)} transclude function available to directives - DEPRECATED.
 *
 * <div class="alert alert-error">
 * **Note:** Passing a `transclude` function to the $compile function is deprecated, as it
 *   e.g. will not use the right outer scope. Please pass the transclude function as a
 *   `parentBoundTranscludeFn` to the link function instead.
 * </div>
 *
 * @param {number} maxPriority only apply directives lower than given priority (Only effects the
 *                 root element(s), not their children)
 * @returns {function(scope, cloneAttachFn=, options=)} a link function which is used to bind template
 * (a DOM element/tree) to a scope. Where:
 *
 *  * `scope` - A {@link ng.$rootScope.Scope Scope} to bind to.
 *  * `cloneAttachFn` - If `cloneAttachFn` is provided, then the link function will clone the
 *  `template` and call the `cloneAttachFn` function allowing the caller to attach the
 *  cloned elements to the DOM document at the appropriate place. The `cloneAttachFn` is
 *  called as: <br> `cloneAttachFn(clonedElement, scope)` where:
 *
 *      * `clonedElement` - is a clone of the original `element` passed into the compiler.
 *      * `scope` - is the current scope with which the linking function is working with.
 *
 *  * `options` - An optional object hash with linking options. If `options` is provided, then the following
 *  keys may be used to control linking behavior:
 *
 *      * `parentBoundTranscludeFn` - the transclude function made available to
 *        directives; if given, it will be passed through to the link functions of
 *        directives found in `element` during compilation.
 *      * `transcludeControllers` - an object hash with keys that map controller names
 *        to controller instances; if given, it will make the controllers
 *        available to directives.
 *      * `futureParentElement` - defines the parent to which the `cloneAttachFn` will add
 *        the cloned elements; only needed for transcludes that are allowed to contain non html
 *        elements (e.g. SVG elements). See also the directive.controller property.
 *
 * Calling the linking function returns the element of the template. It is either the original
 * element passed in, or the clone of the element if the `cloneAttachFn` is provided.
 *
 * After linking the view is not updated until after a call to $digest which typically is done by
 * Angular automatically.
 *
 * If you need access to the bound view, there are two ways to do it:
 *
 * - If you are not asking the linking function to clone the template, create the DOM element(s)
 *   before you send them to the compiler and keep this reference around.
 *   ```js
 *     var element = $compile('<p>{{total}}</p>')(scope);
 *   ```
 *
 * - if on the other hand, you need the element to be cloned, the view reference from the original
 *   example would not point to the clone, but rather to the original template that was cloned. In
 *   this case, you can access the clone via the cloneAttachFn:
 *   ```js
 *     var templateElement = angular.element('<p>{{total}}</p>'),
 *         scope = ....;
 *
 *     var clonedElement = $compile(templateElement)(scope, function(clonedElement, scope) {
 *       //attach the clone to DOM document at the right place
 *     });
 *
 *     //now we have reference to the cloned DOM via `clonedElement`
 *   ```
 *
 *
 * For information on how the compiler works, see the
 * {@link guide/compiler Angular HTML Compiler} section of the Developer Guide.
 */

var $compileMinErr = minErr('$compile');

/**
 * @ngdoc provider
 * @name $compileProvider
 *
 * @description
 */
$CompileProvider.$inject = ['$provide', '$$sanitizeUriProvider'];
function $CompileProvider($provide, $$sanitizeUriProvider) {
  var hasDirectives = {},
      Suffix = 'Directive',
      COMMENT_DIRECTIVE_REGEXP = /^\s*directive\:\s*([\w\-]+)\s+(.*)$/,
      CLASS_DIRECTIVE_REGEXP = /(([\w\-]+)(?:\:([^;]+))?;?)/,
      ALL_OR_NOTHING_ATTRS = makeMap('ngSrc,ngSrcset,src,srcset'),
      REQUIRE_PREFIX_REGEXP = /^(?:(\^\^?)?(\?)?(\^\^?)?)?/;

  // Ref: http://developers.whatwg.org/webappapis.html#event-handler-idl-attributes
  // The assumption is that future DOM event attribute names will begin with
  // 'on' and be composed of only English letters.
  var EVENT_HANDLER_ATTR_REGEXP = /^(on[a-z]+|formaction)$/;

  function parseIsolateBindings(scope, directiveName) {
    var LOCAL_REGEXP = /^\s*([@&]|=(\*?))(\??)\s*(\w*)\s*$/;

    var bindings = {};

    forEach(scope, function(definition, scopeName) {
      var match = definition.match(LOCAL_REGEXP);

      if (!match) {
        throw $compileMinErr('iscp',
            "Invalid isolate scope definition for directive '{0}'." +
            " Definition: {... {1}: '{2}' ...}",
            directiveName, scopeName, definition);
      }

      bindings[scopeName] = {
        mode: match[1][0],
        collection: match[2] === '*',
        optional: match[3] === '?',
        attrName: match[4] || scopeName
      };
    });

    return bindings;
  }

  /**
   * @ngdoc method
   * @name $compileProvider#directive
   * @kind function
   *
   * @description
   * Register a new directive with the compiler.
   *
   * @param {string|Object} name Name of the directive in camel-case (i.e. <code>ngBind</code> which
   *    will match as <code>ng-bind</code>), or an object map of directives where the keys are the
   *    names and the values are the factories.
   * @param {Function|Array} directiveFactory An injectable directive factory function. See
   *    {@link guide/directive} for more info.
   * @returns {ng.$compileProvider} Self for chaining.
   */
   this.directive = function registerDirective(name, directiveFactory) {
    assertNotHasOwnProperty(name, 'directive');
    if (isString(name)) {
      assertArg(directiveFactory, 'directiveFactory');
      if (!hasDirectives.hasOwnProperty(name)) {
        hasDirectives[name] = [];
        $provide.factory(name + Suffix, ['$injector', '$exceptionHandler',
          function($injector, $exceptionHandler) {
            var directives = [];
            forEach(hasDirectives[name], function(directiveFactory, index) {
              try {
                var directive = $injector.invoke(directiveFactory);
                if (isFunction(directive)) {
                  directive = { compile: valueFn(directive) };
                } else if (!directive.compile && directive.link) {
                  directive.compile = valueFn(directive.link);
                }
                directive.priority = directive.priority || 0;
                directive.index = index;
                directive.name = directive.name || name;
                directive.require = directive.require || (directive.controller && directive.name);
                directive.restrict = directive.restrict || 'EA';
                if (isObject(directive.scope)) {
                  directive.$$isolateBindings = parseIsolateBindings(directive.scope, directive.name);
                }
                directives.push(directive);
              } catch (e) {
                $exceptionHandler(e);
              }
            });
            return directives;
          }]);
      }
      hasDirectives[name].push(directiveFactory);
    } else {
      forEach(name, reverseParams(registerDirective));
    }
    return this;
  };


  /**
   * @ngdoc method
   * @name $compileProvider#aHrefSanitizationWhitelist
   * @kind function
   *
   * @description
   * Retrieves or overrides the default regular expression that is used for whitelisting of safe
   * urls during a[href] sanitization.
   *
   * The sanitization is a security measure aimed at preventing XSS attacks via html links.
   *
   * Any url about to be assigned to a[href] via data-binding is first normalized and turned into
   * an absolute url. Afterwards, the url is matched against the `aHrefSanitizationWhitelist`
   * regular expression. If a match is found, the original url is written into the dom. Otherwise,
   * the absolute url is prefixed with `'unsafe:'` string and only then is it written into the DOM.
   *
   * @param {RegExp=} regexp New regexp to whitelist urls with.
   * @returns {RegExp|ng.$compileProvider} Current RegExp if called without value or self for
   *    chaining otherwise.
   */
  this.aHrefSanitizationWhitelist = function(regexp) {
    if (isDefined(regexp)) {
      $$sanitizeUriProvider.aHrefSanitizationWhitelist(regexp);
      return this;
    } else {
      return $$sanitizeUriProvider.aHrefSanitizationWhitelist();
    }
  };


  /**
   * @ngdoc method
   * @name $compileProvider#imgSrcSanitizationWhitelist
   * @kind function
   *
   * @description
   * Retrieves or overrides the default regular expression that is used for whitelisting of safe
   * urls during img[src] sanitization.
   *
   * The sanitization is a security measure aimed at prevent XSS attacks via html links.
   *
   * Any url about to be assigned to img[src] via data-binding is first normalized and turned into
   * an absolute url. Afterwards, the url is matched against the `imgSrcSanitizationWhitelist`
   * regular expression. If a match is found, the original url is written into the dom. Otherwise,
   * the absolute url is prefixed with `'unsafe:'` string and only then is it written into the DOM.
   *
   * @param {RegExp=} regexp New regexp to whitelist urls with.
   * @returns {RegExp|ng.$compileProvider} Current RegExp if called without value or self for
   *    chaining otherwise.
   */
  this.imgSrcSanitizationWhitelist = function(regexp) {
    if (isDefined(regexp)) {
      $$sanitizeUriProvider.imgSrcSanitizationWhitelist(regexp);
      return this;
    } else {
      return $$sanitizeUriProvider.imgSrcSanitizationWhitelist();
    }
  };

  /**
   * @ngdoc method
   * @name  $compileProvider#debugInfoEnabled
   *
   * @param {boolean=} enabled update the debugInfoEnabled state if provided, otherwise just return the
   * current debugInfoEnabled state
   * @returns {*} current value if used as getter or itself (chaining) if used as setter
   *
   * @kind function
   *
   * @description
   * Call this method to enable/disable various debug runtime information in the compiler such as adding
   * binding information and a reference to the current scope on to DOM elements.
   * If enabled, the compiler will add the following to DOM elements that have been bound to the scope
   * * `ng-binding` CSS class
   * * `$binding` data property containing an array of the binding expressions
   *
   * You may want to disable this in production for a significant performance boost. See
   * {@link guide/production#disabling-debug-data Disabling Debug Data} for more.
   *
   * The default value is true.
   */
  var debugInfoEnabled = true;
  this.debugInfoEnabled = function(enabled) {
    if (isDefined(enabled)) {
      debugInfoEnabled = enabled;
      return this;
    }
    return debugInfoEnabled;
  };

  this.$get = [
            '$injector', '$interpolate', '$exceptionHandler', '$templateRequest', '$parse',
            '$controller', '$rootScope', '$document', '$sce', '$animate', '$$sanitizeUri',
    function($injector,   $interpolate,   $exceptionHandler,   $templateRequest,   $parse,
             $controller,   $rootScope,   $document,   $sce,   $animate,   $$sanitizeUri) {

    var Attributes = function(element, attributesToCopy) {
      if (attributesToCopy) {
        var keys = Object.keys(attributesToCopy);
        var i, l, key;

        for (i = 0, l = keys.length; i < l; i++) {
          key = keys[i];
          this[key] = attributesToCopy[key];
        }
      } else {
        this.$attr = {};
      }

      this.$$element = element;
    };

    Attributes.prototype = {
      /**
       * @ngdoc method
       * @name $compile.directive.Attributes#$normalize
       * @kind function
       *
       * @description
       * Converts an attribute name (e.g. dash/colon/underscore-delimited string, optionally prefixed with `x-` or
       * `data-`) to its normalized, camelCase form.
       *
       * Also there is special case for Moz prefix starting with upper case letter.
       *
       * For further information check out the guide on {@link guide/directive#matching-directives Matching Directives}
       *
       * @param {string} name Name to normalize
       */
      $normalize: directiveNormalize,


      /**
       * @ngdoc method
       * @name $compile.directive.Attributes#$addClass
       * @kind function
       *
       * @description
       * Adds the CSS class value specified by the classVal parameter to the element. If animations
       * are enabled then an animation will be triggered for the class addition.
       *
       * @param {string} classVal The className value that will be added to the element
       */
      $addClass: function(classVal) {
        if (classVal && classVal.length > 0) {
          $animate.addClass(this.$$element, classVal);
        }
      },

      /**
       * @ngdoc method
       * @name $compile.directive.Attributes#$removeClass
       * @kind function
       *
       * @description
       * Removes the CSS class value specified by the classVal parameter from the element. If
       * animations are enabled then an animation will be triggered for the class removal.
       *
       * @param {string} classVal The className value that will be removed from the element
       */
      $removeClass: function(classVal) {
        if (classVal && classVal.length > 0) {
          $animate.removeClass(this.$$element, classVal);
        }
      },

      /**
       * @ngdoc method
       * @name $compile.directive.Attributes#$updateClass
       * @kind function
       *
       * @description
       * Adds and removes the appropriate CSS class values to the element based on the difference
       * between the new and old CSS class values (specified as newClasses and oldClasses).
       *
       * @param {string} newClasses The current CSS className value
       * @param {string} oldClasses The former CSS className value
       */
      $updateClass: function(newClasses, oldClasses) {
        var toAdd = tokenDifference(newClasses, oldClasses);
        if (toAdd && toAdd.length) {
          $animate.addClass(this.$$element, toAdd);
        }

        var toRemove = tokenDifference(oldClasses, newClasses);
        if (toRemove && toRemove.length) {
          $animate.removeClass(this.$$element, toRemove);
        }
      },

      /**
       * Set a normalized attribute on the element in a way such that all directives
       * can share the attribute. This function properly handles boolean attributes.
       * @param {string} key Normalized key. (ie ngAttribute)
       * @param {string|boolean} value The value to set. If `null` attribute will be deleted.
       * @param {boolean=} writeAttr If false, does not write the value to DOM element attribute.
       *     Defaults to true.
       * @param {string=} attrName Optional none normalized name. Defaults to key.
       */
      $set: function(key, value, writeAttr, attrName) {
        // TODO: decide whether or not to throw an error if "class"
        //is set through this function since it may cause $updateClass to
        //become unstable.

        var node = this.$$element[0],
            booleanKey = getBooleanAttrName(node, key),
            aliasedKey = getAliasedAttrName(node, key),
            observer = key,
            nodeName;

        if (booleanKey) {
          this.$$element.prop(key, value);
          attrName = booleanKey;
        } else if (aliasedKey) {
          this[aliasedKey] = value;
          observer = aliasedKey;
        }

        this[key] = value;

        // translate normalized key to actual key
        if (attrName) {
          this.$attr[key] = attrName;
        } else {
          attrName = this.$attr[key];
          if (!attrName) {
            this.$attr[key] = attrName = snake_case(key, '-');
          }
        }

        nodeName = nodeName_(this.$$element);

        if ((nodeName === 'a' && key === 'href') ||
            (nodeName === 'img' && key === 'src')) {
          // sanitize a[href] and img[src] values
          this[key] = value = $$sanitizeUri(value, key === 'src');
        } else if (nodeName === 'img' && key === 'srcset') {
          // sanitize img[srcset] values
          var result = "";

          // first check if there are spaces because it's not the same pattern
          var trimmedSrcset = trim(value);
          //                (   999x   ,|   999w   ,|   ,|,   )
          var srcPattern = /(\s+\d+x\s*,|\s+\d+w\s*,|\s+,|,\s+)/;
          var pattern = /\s/.test(trimmedSrcset) ? srcPattern : /(,)/;

          // split srcset into tuple of uri and descriptor except for the last item
          var rawUris = trimmedSrcset.split(pattern);

          // for each tuples
          var nbrUrisWith2parts = Math.floor(rawUris.length / 2);
          for (var i = 0; i < nbrUrisWith2parts; i++) {
            var innerIdx = i * 2;
            // sanitize the uri
            result += $$sanitizeUri(trim(rawUris[innerIdx]), true);
            // add the descriptor
            result += (" " + trim(rawUris[innerIdx + 1]));
          }

          // split the last item into uri and descriptor
          var lastTuple = trim(rawUris[i * 2]).split(/\s/);

          // sanitize the last uri
          result += $$sanitizeUri(trim(lastTuple[0]), true);

          // and add the last descriptor if any
          if (lastTuple.length === 2) {
            result += (" " + trim(lastTuple[1]));
          }
          this[key] = value = result;
        }

        if (writeAttr !== false) {
          if (value === null || value === undefined) {
            this.$$element.removeAttr(attrName);
          } else {
            this.$$element.attr(attrName, value);
          }
        }

        // fire observers
        var $$observers = this.$$observers;
        $$observers && forEach($$observers[observer], function(fn) {
          try {
            fn(value);
          } catch (e) {
            $exceptionHandler(e);
          }
        });
      },


      /**
       * @ngdoc method
       * @name $compile.directive.Attributes#$observe
       * @kind function
       *
       * @description
       * Observes an interpolated attribute.
       *
       * The observer function will be invoked once during the next `$digest` following
       * compilation. The observer is then invoked whenever the interpolated value
       * changes.
       *
       * @param {string} key Normalized key. (ie ngAttribute) .
       * @param {function(interpolatedValue)} fn Function that will be called whenever
                the interpolated value of the attribute changes.
       *        See the {@link guide/directive#text-and-attribute-bindings Directives} guide for more info.
       * @returns {function()} Returns a deregistration function for this observer.
       */
      $observe: function(key, fn) {
        var attrs = this,
            $$observers = (attrs.$$observers || (attrs.$$observers = createMap())),
            listeners = ($$observers[key] || ($$observers[key] = []));

        listeners.push(fn);
        $rootScope.$evalAsync(function() {
          if (!listeners.$$inter && attrs.hasOwnProperty(key)) {
            // no one registered attribute interpolation function, so lets call it manually
            fn(attrs[key]);
          }
        });

        return function() {
          arrayRemove(listeners, fn);
        };
      }
    };


    function safeAddClass($element, className) {
      try {
        $element.addClass(className);
      } catch (e) {
        // ignore, since it means that we are trying to set class on
        // SVG element, where class name is read-only.
      }
    }


    var startSymbol = $interpolate.startSymbol(),
        endSymbol = $interpolate.endSymbol(),
        denormalizeTemplate = (startSymbol == '{{' || endSymbol  == '}}')
            ? identity
            : function denormalizeTemplate(template) {
              return template.replace(/\{\{/g, startSymbol).replace(/}}/g, endSymbol);
        },
        NG_ATTR_BINDING = /^ngAttr[A-Z]/;

    compile.$$addBindingInfo = debugInfoEnabled ? function $$addBindingInfo($element, binding) {
      var bindings = $element.data('$binding') || [];

      if (isArray(binding)) {
        bindings = bindings.concat(binding);
      } else {
        bindings.push(binding);
      }

      $element.data('$binding', bindings);
    } : noop;

    compile.$$addBindingClass = debugInfoEnabled ? function $$addBindingClass($element) {
      safeAddClass($element, 'ng-binding');
    } : noop;

    compile.$$addScopeInfo = debugInfoEnabled ? function $$addScopeInfo($element, scope, isolated, noTemplate) {
      var dataName = isolated ? (noTemplate ? '$isolateScopeNoTemplate' : '$isolateScope') : '$scope';
      $element.data(dataName, scope);
    } : noop;

    compile.$$addScopeClass = debugInfoEnabled ? function $$addScopeClass($element, isolated) {
      safeAddClass($element, isolated ? 'ng-isolate-scope' : 'ng-scope');
    } : noop;

    return compile;

    //================================

    function compile($compileNodes, transcludeFn, maxPriority, ignoreDirective,
                        previousCompileContext) {
      if (!($compileNodes instanceof jqLite)) {
        // jquery always rewraps, whereas we need to preserve the original selector so that we can
        // modify it.
        $compileNodes = jqLite($compileNodes);
      }
      // We can not compile top level text elements since text nodes can be merged and we will
      // not be able to attach scope data to them, so we will wrap them in <span>
      forEach($compileNodes, function(node, index) {
        if (node.nodeType == NODE_TYPE_TEXT && node.nodeValue.match(/\S+/) /* non-empty */ ) {
          $compileNodes[index] = jqLite(node).wrap('<span></span>').parent()[0];
        }
      });
      var compositeLinkFn =
              compileNodes($compileNodes, transcludeFn, $compileNodes,
                           maxPriority, ignoreDirective, previousCompileContext);
      compile.$$addScopeClass($compileNodes);
      var namespace = null;
      return function publicLinkFn(scope, cloneConnectFn, options) {
        assertArg(scope, 'scope');

        options = options || {};
        var parentBoundTranscludeFn = options.parentBoundTranscludeFn,
          transcludeControllers = options.transcludeControllers,
          futureParentElement = options.futureParentElement;

        // When `parentBoundTranscludeFn` is passed, it is a
        // `controllersBoundTransclude` function (it was previously passed
        // as `transclude` to directive.link) so we must unwrap it to get
        // its `boundTranscludeFn`
        if (parentBoundTranscludeFn && parentBoundTranscludeFn.$$boundTransclude) {
          parentBoundTranscludeFn = parentBoundTranscludeFn.$$boundTransclude;
        }

        if (!namespace) {
          namespace = detectNamespaceForChildElements(futureParentElement);
        }
        var $linkNode;
        if (namespace !== 'html') {
          // When using a directive with replace:true and templateUrl the $compileNodes
          // (or a child element inside of them)
          // might change, so we need to recreate the namespace adapted compileNodes
          // for call to the link function.
          // Note: This will already clone the nodes...
          $linkNode = jqLite(
            wrapTemplate(namespace, jqLite('<div>').append($compileNodes).html())
          );
        } else if (cloneConnectFn) {
          // important!!: we must call our jqLite.clone() since the jQuery one is trying to be smart
          // and sometimes changes the structure of the DOM.
          $linkNode = JQLitePrototype.clone.call($compileNodes);
        } else {
          $linkNode = $compileNodes;
        }

        if (transcludeControllers) {
          for (var controllerName in transcludeControllers) {
            $linkNode.data('$' + controllerName + 'Controller', transcludeControllers[controllerName].instance);
          }
        }

        compile.$$addScopeInfo($linkNode, scope);

        if (cloneConnectFn) cloneConnectFn($linkNode, scope);
        if (compositeLinkFn) compositeLinkFn(scope, $linkNode, $linkNode, parentBoundTranscludeFn);
        return $linkNode;
      };
    }

    function detectNamespaceForChildElements(parentElement) {
      // TODO: Make this detect MathML as well...
      var node = parentElement && parentElement[0];
      if (!node) {
        return 'html';
      } else {
        return nodeName_(node) !== 'foreignobject' && node.toString().match(/SVG/) ? 'svg' : 'html';
      }
    }

    /**
     * Compile function matches each node in nodeList against the directives. Once all directives
     * for a particular node are collected their compile functions are executed. The compile
     * functions return values - the linking functions - are combined into a composite linking
     * function, which is the a linking function for the node.
     *
     * @param {NodeList} nodeList an array of nodes or NodeList to compile
     * @param {function(angular.Scope, cloneAttachFn=)} transcludeFn A linking function, where the
     *        scope argument is auto-generated to the new child of the transcluded parent scope.
     * @param {DOMElement=} $rootElement If the nodeList is the root of the compilation tree then
     *        the rootElement must be set the jqLite collection of the compile root. This is
     *        needed so that the jqLite collection items can be replaced with widgets.
     * @param {number=} maxPriority Max directive priority.
     * @returns {Function} A composite linking function of all of the matched directives or null.
     */
    function compileNodes(nodeList, transcludeFn, $rootElement, maxPriority, ignoreDirective,
                            previousCompileContext) {
      var linkFns = [],
          attrs, directives, nodeLinkFn, childNodes, childLinkFn, linkFnFound, nodeLinkFnFound;

      for (var i = 0; i < nodeList.length; i++) {
        attrs = new Attributes();

        // we must always refer to nodeList[i] since the nodes can be replaced underneath us.
        directives = collectDirectives(nodeList[i], [], attrs, i === 0 ? maxPriority : undefined,
                                        ignoreDirective);

        nodeLinkFn = (directives.length)
            ? applyDirectivesToNode(directives, nodeList[i], attrs, transcludeFn, $rootElement,
                                      null, [], [], previousCompileContext)
            : null;

        if (nodeLinkFn && nodeLinkFn.scope) {
          compile.$$addScopeClass(attrs.$$element);
        }

        childLinkFn = (nodeLinkFn && nodeLinkFn.terminal ||
                      !(childNodes = nodeList[i].childNodes) ||
                      !childNodes.length)
            ? null
            : compileNodes(childNodes,
                 nodeLinkFn ? (
                  (nodeLinkFn.transcludeOnThisElement || !nodeLinkFn.templateOnThisElement)
                     && nodeLinkFn.transclude) : transcludeFn);

        if (nodeLinkFn || childLinkFn) {
          linkFns.push(i, nodeLinkFn, childLinkFn);
          linkFnFound = true;
          nodeLinkFnFound = nodeLinkFnFound || nodeLinkFn;
        }

        //use the previous context only for the first element in the virtual group
        previousCompileContext = null;
      }

      // return a linking function if we have found anything, null otherwise
      return linkFnFound ? compositeLinkFn : null;

      function compositeLinkFn(scope, nodeList, $rootElement, parentBoundTranscludeFn) {
        var nodeLinkFn, childLinkFn, node, childScope, i, ii, idx, childBoundTranscludeFn;
        var stableNodeList;


        if (nodeLinkFnFound) {
          // copy nodeList so that if a nodeLinkFn removes or adds an element at this DOM level our
          // offsets don't get screwed up
          var nodeListLength = nodeList.length;
          stableNodeList = new Array(nodeListLength);

          // create a sparse array by only copying the elements which have a linkFn
          for (i = 0; i < linkFns.length; i+=3) {
            idx = linkFns[i];
            stableNodeList[idx] = nodeList[idx];
          }
        } else {
          stableNodeList = nodeList;
        }

        for (i = 0, ii = linkFns.length; i < ii;) {
          node = stableNodeList[linkFns[i++]];
          nodeLinkFn = linkFns[i++];
          childLinkFn = linkFns[i++];

          if (nodeLinkFn) {
            if (nodeLinkFn.scope) {
              childScope = scope.$new();
              compile.$$addScopeInfo(jqLite(node), childScope);
            } else {
              childScope = scope;
            }

            if (nodeLinkFn.transcludeOnThisElement) {
              childBoundTranscludeFn = createBoundTranscludeFn(
                  scope, nodeLinkFn.transclude, parentBoundTranscludeFn,
                  nodeLinkFn.elementTranscludeOnThisElement);

            } else if (!nodeLinkFn.templateOnThisElement && parentBoundTranscludeFn) {
              childBoundTranscludeFn = parentBoundTranscludeFn;

            } else if (!parentBoundTranscludeFn && transcludeFn) {
              childBoundTranscludeFn = createBoundTranscludeFn(scope, transcludeFn);

            } else {
              childBoundTranscludeFn = null;
            }

            nodeLinkFn(childLinkFn, childScope, node, $rootElement, childBoundTranscludeFn);

          } else if (childLinkFn) {
            childLinkFn(scope, node.childNodes, undefined, parentBoundTranscludeFn);
          }
        }
      }
    }

    function createBoundTranscludeFn(scope, transcludeFn, previousBoundTranscludeFn, elementTransclusion) {

      var boundTranscludeFn = function(transcludedScope, cloneFn, controllers, futureParentElement, containingScope) {

        if (!transcludedScope) {
          transcludedScope = scope.$new(false, containingScope);
          transcludedScope.$$transcluded = true;
        }

        return transcludeFn(transcludedScope, cloneFn, {
          parentBoundTranscludeFn: previousBoundTranscludeFn,
          transcludeControllers: controllers,
          futureParentElement: futureParentElement
        });
      };

      return boundTranscludeFn;
    }

    /**
     * Looks for directives on the given node and adds them to the directive collection which is
     * sorted.
     *
     * @param node Node to search.
     * @param directives An array to which the directives are added to. This array is sorted before
     *        the function returns.
     * @param attrs The shared attrs object which is used to populate the normalized attributes.
     * @param {number=} maxPriority Max directive priority.
     */
    function collectDirectives(node, directives, attrs, maxPriority, ignoreDirective) {
      var nodeType = node.nodeType,
          attrsMap = attrs.$attr,
          match,
          className;

      switch (nodeType) {
        case NODE_TYPE_ELEMENT: /* Element */
          // use the node name: <directive>
          addDirective(directives,
              directiveNormalize(nodeName_(node)), 'E', maxPriority, ignoreDirective);

          // iterate over the attributes
          for (var attr, name, nName, ngAttrName, value, isNgAttr, nAttrs = node.attributes,
                   j = 0, jj = nAttrs && nAttrs.length; j < jj; j++) {
            var attrStartName = false;
            var attrEndName = false;

            attr = nAttrs[j];
            name = attr.name;
            value = trim(attr.value);

            // support ngAttr attribute binding
            ngAttrName = directiveNormalize(name);
            if (isNgAttr = NG_ATTR_BINDING.test(ngAttrName)) {
              name = name.replace(PREFIX_REGEXP, '')
                .substr(8).replace(/_(.)/g, function(match, letter) {
                  return letter.toUpperCase();
                });
            }

            var directiveNName = ngAttrName.replace(/(Start|End)$/, '');
            if (directiveIsMultiElement(directiveNName)) {
              if (ngAttrName === directiveNName + 'Start') {
                attrStartName = name;
                attrEndName = name.substr(0, name.length - 5) + 'end';
                name = name.substr(0, name.length - 6);
              }
            }

            nName = directiveNormalize(name.toLowerCase());
            attrsMap[nName] = name;
            if (isNgAttr || !attrs.hasOwnProperty(nName)) {
                attrs[nName] = value;
                if (getBooleanAttrName(node, nName)) {
                  attrs[nName] = true; // presence means true
                }
            }
            addAttrInterpolateDirective(node, directives, value, nName, isNgAttr);
            addDirective(directives, nName, 'A', maxPriority, ignoreDirective, attrStartName,
                          attrEndName);
          }

          // use class as directive
          className = node.className;
          if (isObject(className)) {
              // Maybe SVGAnimatedString
              className = className.animVal;
          }
          if (isString(className) && className !== '') {
            while (match = CLASS_DIRECTIVE_REGEXP.exec(className)) {
              nName = directiveNormalize(match[2]);
              if (addDirective(directives, nName, 'C', maxPriority, ignoreDirective)) {
                attrs[nName] = trim(match[3]);
              }
              className = className.substr(match.index + match[0].length);
            }
          }
          break;
        case NODE_TYPE_TEXT: /* Text Node */
          addTextInterpolateDirective(directives, node.nodeValue);
          break;
        case NODE_TYPE_COMMENT: /* Comment */
          try {
            match = COMMENT_DIRECTIVE_REGEXP.exec(node.nodeValue);
            if (match) {
              nName = directiveNormalize(match[1]);
              if (addDirective(directives, nName, 'M', maxPriority, ignoreDirective)) {
                attrs[nName] = trim(match[2]);
              }
            }
          } catch (e) {
            // turns out that under some circumstances IE9 throws errors when one attempts to read
            // comment's node value.
            // Just ignore it and continue. (Can't seem to reproduce in test case.)
          }
          break;
      }

      directives.sort(byPriority);
      return directives;
    }

    /**
     * Given a node with an directive-start it collects all of the siblings until it finds
     * directive-end.
     * @param node
     * @param attrStart
     * @param attrEnd
     * @returns {*}
     */
    function groupScan(node, attrStart, attrEnd) {
      var nodes = [];
      var depth = 0;
      if (attrStart && node.hasAttribute && node.hasAttribute(attrStart)) {
        do {
          if (!node) {
            throw $compileMinErr('uterdir',
                      "Unterminated attribute, found '{0}' but no matching '{1}' found.",
                      attrStart, attrEnd);
          }
          if (node.nodeType == NODE_TYPE_ELEMENT) {
            if (node.hasAttribute(attrStart)) depth++;
            if (node.hasAttribute(attrEnd)) depth--;
          }
          nodes.push(node);
          node = node.nextSibling;
        } while (depth > 0);
      } else {
        nodes.push(node);
      }

      return jqLite(nodes);
    }

    /**
     * Wrapper for linking function which converts normal linking function into a grouped
     * linking function.
     * @param linkFn
     * @param attrStart
     * @param attrEnd
     * @returns {Function}
     */
    function groupElementsLinkFnWrapper(linkFn, attrStart, attrEnd) {
      return function(scope, element, attrs, controllers, transcludeFn) {
        element = groupScan(element[0], attrStart, attrEnd);
        return linkFn(scope, element, attrs, controllers, transcludeFn);
      };
    }

    /**
     * Once the directives have been collected, their compile functions are executed. This method
     * is responsible for inlining directive templates as well as terminating the application
     * of the directives if the terminal directive has been reached.
     *
     * @param {Array} directives Array of collected directives to execute their compile function.
     *        this needs to be pre-sorted by priority order.
     * @param {Node} compileNode The raw DOM node to apply the compile functions to
     * @param {Object} templateAttrs The shared attribute function
     * @param {function(angular.Scope, cloneAttachFn=)} transcludeFn A linking function, where the
     *                                                  scope argument is auto-generated to the new
     *                                                  child of the transcluded parent scope.
     * @param {JQLite} jqCollection If we are working on the root of the compile tree then this
     *                              argument has the root jqLite array so that we can replace nodes
     *                              on it.
     * @param {Object=} originalReplaceDirective An optional directive that will be ignored when
     *                                           compiling the transclusion.
     * @param {Array.<Function>} preLinkFns
     * @param {Array.<Function>} postLinkFns
     * @param {Object} previousCompileContext Context used for previous compilation of the current
     *                                        node
     * @returns {Function} linkFn
     */
    function applyDirectivesToNode(directives, compileNode, templateAttrs, transcludeFn,
                                   jqCollection, originalReplaceDirective, preLinkFns, postLinkFns,
                                   previousCompileContext) {
      previousCompileContext = previousCompileContext || {};

      var terminalPriority = -Number.MAX_VALUE,
          newScopeDirective,
          controllerDirectives = previousCompileContext.controllerDirectives,
          controllers,
          newIsolateScopeDirective = previousCompileContext.newIsolateScopeDirective,
          templateDirective = previousCompileContext.templateDirective,
          nonTlbTranscludeDirective = previousCompileContext.nonTlbTranscludeDirective,
          hasTranscludeDirective = false,
          hasTemplate = false,
          hasElementTranscludeDirective = previousCompileContext.hasElementTranscludeDirective,
          $compileNode = templateAttrs.$$element = jqLite(compileNode),
          directive,
          directiveName,
          $template,
          replaceDirective = originalReplaceDirective,
          childTranscludeFn = transcludeFn,
          linkFn,
          directiveValue;

      // executes all directives on the current element
      for (var i = 0, ii = directives.length; i < ii; i++) {
        directive = directives[i];
        var attrStart = directive.$$start;
        var attrEnd = directive.$$end;

        // collect multiblock sections
        if (attrStart) {
          $compileNode = groupScan(compileNode, attrStart, attrEnd);
        }
        $template = undefined;

        if (terminalPriority > directive.priority) {
          break; // prevent further processing of directives
        }

        if (directiveValue = directive.scope) {

          // skip the check for directives with async templates, we'll check the derived sync
          // directive when the template arrives
          if (!directive.templateUrl) {
            if (isObject(directiveValue)) {
              // This directive is trying to add an isolated scope.
              // Check that there is no scope of any kind already
              assertNoDuplicate('new/isolated scope', newIsolateScopeDirective || newScopeDirective,
                                directive, $compileNode);
              newIsolateScopeDirective = directive;
            } else {
              // This directive is trying to add a child scope.
              // Check that there is no isolated scope already
              assertNoDuplicate('new/isolated scope', newIsolateScopeDirective, directive,
                                $compileNode);
            }
          }

          newScopeDirective = newScopeDirective || directive;
        }

        directiveName = directive.name;

        if (!directive.templateUrl && directive.controller) {
          directiveValue = directive.controller;
          controllerDirectives = controllerDirectives || {};
          assertNoDuplicate("'" + directiveName + "' controller",
              controllerDirectives[directiveName], directive, $compileNode);
          controllerDirectives[directiveName] = directive;
        }

        if (directiveValue = directive.transclude) {
          hasTranscludeDirective = true;

          // Special case ngIf and ngRepeat so that we don't complain about duplicate transclusion.
          // This option should only be used by directives that know how to safely handle element transclusion,
          // where the transcluded nodes are added or replaced after linking.
          if (!directive.$$tlb) {
            assertNoDuplicate('transclusion', nonTlbTranscludeDirective, directive, $compileNode);
            nonTlbTranscludeDirective = directive;
          }

          if (directiveValue == 'element') {
            hasElementTranscludeDirective = true;
            terminalPriority = directive.priority;
            $template = $compileNode;
            $compileNode = templateAttrs.$$element =
                jqLite(document.createComment(' ' + directiveName + ': ' +
                                              templateAttrs[directiveName] + ' '));
            compileNode = $compileNode[0];
            replaceWith(jqCollection, sliceArgs($template), compileNode);

            childTranscludeFn = compile($template, transcludeFn, terminalPriority,
                                        replaceDirective && replaceDirective.name, {
                                          // Don't pass in:
                                          // - controllerDirectives - otherwise we'll create duplicates controllers
                                          // - newIsolateScopeDirective or templateDirective - combining templates with
                                          //   element transclusion doesn't make sense.
                                          //
                                          // We need only nonTlbTranscludeDirective so that we prevent putting transclusion
                                          // on the same element more than once.
                                          nonTlbTranscludeDirective: nonTlbTranscludeDirective
                                        });
          } else {
            $template = jqLite(jqLiteClone(compileNode)).contents();
            $compileNode.empty(); // clear contents
            childTranscludeFn = compile($template, transcludeFn);
          }
        }

        if (directive.template) {
          hasTemplate = true;
          assertNoDuplicate('template', templateDirective, directive, $compileNode);
          templateDirective = directive;

          directiveValue = (isFunction(directive.template))
              ? directive.template($compileNode, templateAttrs)
              : directive.template;

          directiveValue = denormalizeTemplate(directiveValue);

          if (directive.replace) {
            replaceDirective = directive;
            if (jqLiteIsTextNode(directiveValue)) {
              $template = [];
            } else {
              $template = removeComments(wrapTemplate(directive.templateNamespace, trim(directiveValue)));
            }
            compileNode = $template[0];

            if ($template.length != 1 || compileNode.nodeType !== NODE_TYPE_ELEMENT) {
              throw $compileMinErr('tplrt',
                  "Template for directive '{0}' must have exactly one root element. {1}",
                  directiveName, '');
            }

            replaceWith(jqCollection, $compileNode, compileNode);

            var newTemplateAttrs = {$attr: {}};

            // combine directives from the original node and from the template:
            // - take the array of directives for this element
            // - split it into two parts, those that already applied (processed) and those that weren't (unprocessed)
            // - collect directives from the template and sort them by priority
            // - combine directives as: processed + template + unprocessed
            var templateDirectives = collectDirectives(compileNode, [], newTemplateAttrs);
            var unprocessedDirectives = directives.splice(i + 1, directives.length - (i + 1));

            if (newIsolateScopeDirective) {
              markDirectivesAsIsolate(templateDirectives);
            }
            directives = directives.concat(templateDirectives).concat(unprocessedDirectives);
            mergeTemplateAttributes(templateAttrs, newTemplateAttrs);

            ii = directives.length;
          } else {
            $compileNode.html(directiveValue);
          }
        }

        if (directive.templateUrl) {
          hasTemplate = true;
          assertNoDuplicate('template', templateDirective, directive, $compileNode);
          templateDirective = directive;

          if (directive.replace) {
            replaceDirective = directive;
          }

          nodeLinkFn = compileTemplateUrl(directives.splice(i, directives.length - i), $compileNode,
              templateAttrs, jqCollection, hasTranscludeDirective && childTranscludeFn, preLinkFns, postLinkFns, {
                controllerDirectives: controllerDirectives,
                newIsolateScopeDirective: newIsolateScopeDirective,
                templateDirective: templateDirective,
                nonTlbTranscludeDirective: nonTlbTranscludeDirective
              });
          ii = directives.length;
        } else if (directive.compile) {
          try {
            linkFn = directive.compile($compileNode, templateAttrs, childTranscludeFn);
            if (isFunction(linkFn)) {
              addLinkFns(null, linkFn, attrStart, attrEnd);
            } else if (linkFn) {
              addLinkFns(linkFn.pre, linkFn.post, attrStart, attrEnd);
            }
          } catch (e) {
            $exceptionHandler(e, startingTag($compileNode));
          }
        }

        if (directive.terminal) {
          nodeLinkFn.terminal = true;
          terminalPriority = Math.max(terminalPriority, directive.priority);
        }

      }

      nodeLinkFn.scope = newScopeDirective && newScopeDirective.scope === true;
      nodeLinkFn.transcludeOnThisElement = hasTranscludeDirective;
      nodeLinkFn.elementTranscludeOnThisElement = hasElementTranscludeDirective;
      nodeLinkFn.templateOnThisElement = hasTemplate;
      nodeLinkFn.transclude = childTranscludeFn;

      previousCompileContext.hasElementTranscludeDirective = hasElementTranscludeDirective;

      // might be normal or delayed nodeLinkFn depending on if templateUrl is present
      return nodeLinkFn;

      ////////////////////

      function addLinkFns(pre, post, attrStart, attrEnd) {
        if (pre) {
          if (attrStart) pre = groupElementsLinkFnWrapper(pre, attrStart, attrEnd);
          pre.require = directive.require;
          pre.directiveName = directiveName;
          if (newIsolateScopeDirective === directive || directive.$$isolateScope) {
            pre = cloneAndAnnotateFn(pre, {isolateScope: true});
          }
          preLinkFns.push(pre);
        }
        if (post) {
          if (attrStart) post = groupElementsLinkFnWrapper(post, attrStart, attrEnd);
          post.require = directive.require;
          post.directiveName = directiveName;
          if (newIsolateScopeDirective === directive || directive.$$isolateScope) {
            post = cloneAndAnnotateFn(post, {isolateScope: true});
          }
          postLinkFns.push(post);
        }
      }


      function getControllers(directiveName, require, $element, elementControllers) {
        var value, retrievalMethod = 'data', optional = false;
        var $searchElement = $element;
        var match;
        if (isString(require)) {
          match = require.match(REQUIRE_PREFIX_REGEXP);
          require = require.substring(match[0].length);

          if (match[3]) {
            if (match[1]) match[3] = null;
            else match[1] = match[3];
          }
          if (match[1] === '^') {
            retrievalMethod = 'inheritedData';
          } else if (match[1] === '^^') {
            retrievalMethod = 'inheritedData';
            $searchElement = $element.parent();
          }
          if (match[2] === '?') {
            optional = true;
          }

          value = null;

          if (elementControllers && retrievalMethod === 'data') {
            if (value = elementControllers[require]) {
              value = value.instance;
            }
          }
          value = value || $searchElement[retrievalMethod]('$' + require + 'Controller');

          if (!value && !optional) {
            throw $compileMinErr('ctreq',
                "Controller '{0}', required by directive '{1}', can't be found!",
                require, directiveName);
          }
          return value || null;
        } else if (isArray(require)) {
          value = [];
          forEach(require, function(require) {
            value.push(getControllers(directiveName, require, $element, elementControllers));
          });
        }
        return value;
      }


      function nodeLinkFn(childLinkFn, scope, linkNode, $rootElement, boundTranscludeFn) {
        var i, ii, linkFn, controller, isolateScope, elementControllers, transcludeFn, $element,
            attrs;

        if (compileNode === linkNode) {
          attrs = templateAttrs;
          $element = templateAttrs.$$element;
        } else {
          $element = jqLite(linkNode);
          attrs = new Attributes($element, templateAttrs);
        }

        if (newIsolateScopeDirective) {
          isolateScope = scope.$new(true);
        }

        if (boundTranscludeFn) {
          // track `boundTranscludeFn` so it can be unwrapped if `transcludeFn`
          // is later passed as `parentBoundTranscludeFn` to `publicLinkFn`
          transcludeFn = controllersBoundTransclude;
          transcludeFn.$$boundTransclude = boundTranscludeFn;
        }

        if (controllerDirectives) {
          // TODO: merge `controllers` and `elementControllers` into single object.
          controllers = {};
          elementControllers = {};
          forEach(controllerDirectives, function(directive) {
            var locals = {
              $scope: directive === newIsolateScopeDirective || directive.$$isolateScope ? isolateScope : scope,
              $element: $element,
              $attrs: attrs,
              $transclude: transcludeFn
            }, controllerInstance;

            controller = directive.controller;
            if (controller == '@') {
              controller = attrs[directive.name];
            }

            controllerInstance = $controller(controller, locals, true, directive.controllerAs);

            // For directives with element transclusion the element is a comment,
            // but jQuery .data doesn't support attaching data to comment nodes as it's hard to
            // clean up (http://bugs.jquery.com/ticket/8335).
            // Instead, we save the controllers for the element in a local hash and attach to .data
            // later, once we have the actual element.
            elementControllers[directive.name] = controllerInstance;
            if (!hasElementTranscludeDirective) {
              $element.data('$' + directive.name + 'Controller', controllerInstance.instance);
            }

            controllers[directive.name] = controllerInstance;
          });
        }

        if (newIsolateScopeDirective) {
          compile.$$addScopeInfo($element, isolateScope, true, !(templateDirective && (templateDirective === newIsolateScopeDirective ||
              templateDirective === newIsolateScopeDirective.$$originalDirective)));
          compile.$$addScopeClass($element, true);

          var isolateScopeController = controllers && controllers[newIsolateScopeDirective.name];
          var isolateBindingContext = isolateScope;
          if (isolateScopeController && isolateScopeController.identifier &&
              newIsolateScopeDirective.bindToController === true) {
            isolateBindingContext = isolateScopeController.instance;
          }

          forEach(isolateScope.$$isolateBindings = newIsolateScopeDirective.$$isolateBindings, function(definition, scopeName) {
            var attrName = definition.attrName,
                optional = definition.optional,
                mode = definition.mode, // @, =, or &
                lastValue,
                parentGet, parentSet, compare;

            switch (mode) {

              case '@':
                attrs.$observe(attrName, function(value) {
                  isolateBindingContext[scopeName] = value;
                });
                attrs.$$observers[attrName].$$scope = scope;
                if (attrs[attrName]) {
                  // If the attribute has been provided then we trigger an interpolation to ensure
                  // the value is there for use in the link fn
                  isolateBindingContext[scopeName] = $interpolate(attrs[attrName])(scope);
                }
                break;

              case '=':
                if (optional && !attrs[attrName]) {
                  return;
                }
                parentGet = $parse(attrs[attrName]);
                if (parentGet.literal) {
                  compare = equals;
                } else {
                  compare = function(a, b) { return a === b || (a !== a && b !== b); };
                }
                parentSet = parentGet.assign || function() {
                  // reset the change, or we will throw this exception on every $digest
                  lastValue = isolateBindingContext[scopeName] = parentGet(scope);
                  throw $compileMinErr('nonassign',
                      "Expression '{0}' used with directive '{1}' is non-assignable!",
                      attrs[attrName], newIsolateScopeDirective.name);
                };
                lastValue = isolateBindingContext[scopeName] = parentGet(scope);
                var parentValueWatch = function parentValueWatch(parentValue) {
                  if (!compare(parentValue, isolateBindingContext[scopeName])) {
                    // we are out of sync and need to copy
                    if (!compare(parentValue, lastValue)) {
                      // parent changed and it has precedence
                      isolateBindingContext[scopeName] = parentValue;
                    } else {
                      // if the parent can be assigned then do so
                      parentSet(scope, parentValue = isolateBindingContext[scopeName]);
                    }
                  }
                  return lastValue = parentValue;
                };
                parentValueWatch.$stateful = true;
                var unwatch;
                if (definition.collection) {
                  unwatch = scope.$watchCollection(attrs[attrName], parentValueWatch);
                } else {
                  unwatch = scope.$watch($parse(attrs[attrName], parentValueWatch), null, parentGet.literal);
                }
                isolateScope.$on('$destroy', unwatch);
                break;

              case '&':
                parentGet = $parse(attrs[attrName]);
                isolateBindingContext[scopeName] = function(locals) {
                  return parentGet(scope, locals);
                };
                break;
            }
          });
        }
        if (controllers) {
          forEach(controllers, function(controller) {
            controller();
          });
          controllers = null;
        }

        // PRELINKING
        for (i = 0, ii = preLinkFns.length; i < ii; i++) {
          linkFn = preLinkFns[i];
          invokeLinkFn(linkFn,
              linkFn.isolateScope ? isolateScope : scope,
              $element,
              attrs,
              linkFn.require && getControllers(linkFn.directiveName, linkFn.require, $element, elementControllers),
              transcludeFn
          );
        }

        // RECURSION
        // We only pass the isolate scope, if the isolate directive has a template,
        // otherwise the child elements do not belong to the isolate directive.
        var scopeToChild = scope;
        if (newIsolateScopeDirective && (newIsolateScopeDirective.template || newIsolateScopeDirective.templateUrl === null)) {
          scopeToChild = isolateScope;
        }
        childLinkFn && childLinkFn(scopeToChild, linkNode.childNodes, undefined, boundTranscludeFn);

        // POSTLINKING
        for (i = postLinkFns.length - 1; i >= 0; i--) {
          linkFn = postLinkFns[i];
          invokeLinkFn(linkFn,
              linkFn.isolateScope ? isolateScope : scope,
              $element,
              attrs,
              linkFn.require && getControllers(linkFn.directiveName, linkFn.require, $element, elementControllers),
              transcludeFn
          );
        }

        // This is the function that is injected as `$transclude`.
        // Note: all arguments are optional!
        function controllersBoundTransclude(scope, cloneAttachFn, futureParentElement) {
          var transcludeControllers;

          // No scope passed in:
          if (!isScope(scope)) {
            futureParentElement = cloneAttachFn;
            cloneAttachFn = scope;
            scope = undefined;
          }

          if (hasElementTranscludeDirective) {
            transcludeControllers = elementControllers;
          }
          if (!futureParentElement) {
            futureParentElement = hasElementTranscludeDirective ? $element.parent() : $element;
          }
          return boundTranscludeFn(scope, cloneAttachFn, transcludeControllers, futureParentElement, scopeToChild);
        }
      }
    }

    function markDirectivesAsIsolate(directives) {
      // mark all directives as needing isolate scope.
      for (var j = 0, jj = directives.length; j < jj; j++) {
        directives[j] = inherit(directives[j], {$$isolateScope: true});
      }
    }

    /**
     * looks up the directive and decorates it with exception handling and proper parameters. We
     * call this the boundDirective.
     *
     * @param {string} name name of the directive to look up.
     * @param {string} location The directive must be found in specific format.
     *   String containing any of theses characters:
     *
     *   * `E`: element name
     *   * `A': attribute
     *   * `C`: class
     *   * `M`: comment
     * @returns {boolean} true if directive was added.
     */
    function addDirective(tDirectives, name, location, maxPriority, ignoreDirective, startAttrName,
                          endAttrName) {
      if (name === ignoreDirective) return null;
      var match = null;
      if (hasDirectives.hasOwnProperty(name)) {
        for (var directive, directives = $injector.get(name + Suffix),
            i = 0, ii = directives.length; i < ii; i++) {
          try {
            directive = directives[i];
            if ((maxPriority === undefined || maxPriority > directive.priority) &&
                 directive.restrict.indexOf(location) != -1) {
              if (startAttrName) {
                directive = inherit(directive, {$$start: startAttrName, $$end: endAttrName});
              }
              tDirectives.push(directive);
              match = directive;
            }
          } catch (e) { $exceptionHandler(e); }
        }
      }
      return match;
    }


    /**
     * looks up the directive and returns true if it is a multi-element directive,
     * and therefore requires DOM nodes between -start and -end markers to be grouped
     * together.
     *
     * @param {string} name name of the directive to look up.
     * @returns true if directive was registered as multi-element.
     */
    function directiveIsMultiElement(name) {
      if (hasDirectives.hasOwnProperty(name)) {
        for (var directive, directives = $injector.get(name + Suffix),
            i = 0, ii = directives.length; i < ii; i++) {
          directive = directives[i];
          if (directive.multiElement) {
            return true;
          }
        }
      }
      return false;
    }

    /**
     * When the element is replaced with HTML template then the new attributes
     * on the template need to be merged with the existing attributes in the DOM.
     * The desired effect is to have both of the attributes present.
     *
     * @param {object} dst destination attributes (original DOM)
     * @param {object} src source attributes (from the directive template)
     */
    function mergeTemplateAttributes(dst, src) {
      var srcAttr = src.$attr,
          dstAttr = dst.$attr,
          $element = dst.$$element;

      // reapply the old attributes to the new element
      forEach(dst, function(value, key) {
        if (key.charAt(0) != '$') {
          if (src[key] && src[key] !== value) {
            value += (key === 'style' ? ';' : ' ') + src[key];
          }
          dst.$set(key, value, true, srcAttr[key]);
        }
      });

      // copy the new attributes on the old attrs object
      forEach(src, function(value, key) {
        if (key == 'class') {
          safeAddClass($element, value);
          dst['class'] = (dst['class'] ? dst['class'] + ' ' : '') + value;
        } else if (key == 'style') {
          $element.attr('style', $element.attr('style') + ';' + value);
          dst['style'] = (dst['style'] ? dst['style'] + ';' : '') + value;
          // `dst` will never contain hasOwnProperty as DOM parser won't let it.
          // You will get an "InvalidCharacterError: DOM Exception 5" error if you
          // have an attribute like "has-own-property" or "data-has-own-property", etc.
        } else if (key.charAt(0) != '$' && !dst.hasOwnProperty(key)) {
          dst[key] = value;
          dstAttr[key] = srcAttr[key];
        }
      });
    }


    function compileTemplateUrl(directives, $compileNode, tAttrs,
        $rootElement, childTranscludeFn, preLinkFns, postLinkFns, previousCompileContext) {
      var linkQueue = [],
          afterTemplateNodeLinkFn,
          afterTemplateChildLinkFn,
          beforeTemplateCompileNode = $compileNode[0],
          origAsyncDirective = directives.shift(),
          derivedSyncDirective = inherit(origAsyncDirective, {
            templateUrl: null, transclude: null, replace: null, $$originalDirective: origAsyncDirective
          }),
          templateUrl = (isFunction(origAsyncDirective.templateUrl))
              ? origAsyncDirective.templateUrl($compileNode, tAttrs)
              : origAsyncDirective.templateUrl,
          templateNamespace = origAsyncDirective.templateNamespace;

      $compileNode.empty();

      $templateRequest(templateUrl)
        .then(function(content) {
          var compileNode, tempTemplateAttrs, $template, childBoundTranscludeFn;

          content = denormalizeTemplate(content);

          if (origAsyncDirective.replace) {
            if (jqLiteIsTextNode(content)) {
              $template = [];
            } else {
              $template = removeComments(wrapTemplate(templateNamespace, trim(content)));
            }
            compileNode = $template[0];

            if ($template.length != 1 || compileNode.nodeType !== NODE_TYPE_ELEMENT) {
              throw $compileMinErr('tplrt',
                  "Template for directive '{0}' must have exactly one root element. {1}",
                  origAsyncDirective.name, templateUrl);
            }

            tempTemplateAttrs = {$attr: {}};
            replaceWith($rootElement, $compileNode, compileNode);
            var templateDirectives = collectDirectives(compileNode, [], tempTemplateAttrs);

            if (isObject(origAsyncDirective.scope)) {
              markDirectivesAsIsolate(templateDirectives);
            }
            directives = templateDirectives.concat(directives);
            mergeTemplateAttributes(tAttrs, tempTemplateAttrs);
          } else {
            compileNode = beforeTemplateCompileNode;
            $compileNode.html(content);
          }

          directives.unshift(derivedSyncDirective);

          afterTemplateNodeLinkFn = applyDirectivesToNode(directives, compileNode, tAttrs,
              childTranscludeFn, $compileNode, origAsyncDirective, preLinkFns, postLinkFns,
              previousCompileContext);
          forEach($rootElement, function(node, i) {
            if (node == compileNode) {
              $rootElement[i] = $compileNode[0];
            }
          });
          afterTemplateChildLinkFn = compileNodes($compileNode[0].childNodes, childTranscludeFn);

          while (linkQueue.length) {
            var scope = linkQueue.shift(),
                beforeTemplateLinkNode = linkQueue.shift(),
                linkRootElement = linkQueue.shift(),
                boundTranscludeFn = linkQueue.shift(),
                linkNode = $compileNode[0];

            if (scope.$$destroyed) continue;

            if (beforeTemplateLinkNode !== beforeTemplateCompileNode) {
              var oldClasses = beforeTemplateLinkNode.className;

              if (!(previousCompileContext.hasElementTranscludeDirective &&
                  origAsyncDirective.replace)) {
                // it was cloned therefore we have to clone as well.
                linkNode = jqLiteClone(compileNode);
              }
              replaceWith(linkRootElement, jqLite(beforeTemplateLinkNode), linkNode);

              // Copy in CSS classes from original node
              safeAddClass(jqLite(linkNode), oldClasses);
            }
            if (afterTemplateNodeLinkFn.transcludeOnThisElement) {
              childBoundTranscludeFn = createBoundTranscludeFn(scope, afterTemplateNodeLinkFn.transclude, boundTranscludeFn);
            } else {
              childBoundTranscludeFn = boundTranscludeFn;
            }
            afterTemplateNodeLinkFn(afterTemplateChildLinkFn, scope, linkNode, $rootElement,
              childBoundTranscludeFn);
          }
          linkQueue = null;
        });

      return function delayedNodeLinkFn(ignoreChildLinkFn, scope, node, rootElement, boundTranscludeFn) {
        var childBoundTranscludeFn = boundTranscludeFn;
        if (scope.$$destroyed) return;
        if (linkQueue) {
          linkQueue.push(scope,
                         node,
                         rootElement,
                         childBoundTranscludeFn);
        } else {
          if (afterTemplateNodeLinkFn.transcludeOnThisElement) {
            childBoundTranscludeFn = createBoundTranscludeFn(scope, afterTemplateNodeLinkFn.transclude, boundTranscludeFn);
          }
          afterTemplateNodeLinkFn(afterTemplateChildLinkFn, scope, node, rootElement, childBoundTranscludeFn);
        }
      };
    }


    /**
     * Sorting function for bound directives.
     */
    function byPriority(a, b) {
      var diff = b.priority - a.priority;
      if (diff !== 0) return diff;
      if (a.name !== b.name) return (a.name < b.name) ? -1 : 1;
      return a.index - b.index;
    }


    function assertNoDuplicate(what, previousDirective, directive, element) {
      if (previousDirective) {
        throw $compileMinErr('multidir', 'Multiple directives [{0}, {1}] asking for {2} on: {3}',
            previousDirective.name, directive.name, what, startingTag(element));
      }
    }


    function addTextInterpolateDirective(directives, text) {
      var interpolateFn = $interpolate(text, true);
      if (interpolateFn) {
        directives.push({
          priority: 0,
          compile: function textInterpolateCompileFn(templateNode) {
            var templateNodeParent = templateNode.parent(),
                hasCompileParent = !!templateNodeParent.length;

            // When transcluding a template that has bindings in the root
            // we don't have a parent and thus need to add the class during linking fn.
            if (hasCompileParent) compile.$$addBindingClass(templateNodeParent);

            return function textInterpolateLinkFn(scope, node) {
              var parent = node.parent();
              if (!hasCompileParent) compile.$$addBindingClass(parent);
              compile.$$addBindingInfo(parent, interpolateFn.expressions);
              scope.$watch(interpolateFn, function interpolateFnWatchAction(value) {
                node[0].nodeValue = value;
              });
            };
          }
        });
      }
    }


    function wrapTemplate(type, template) {
      type = lowercase(type || 'html');
      switch (type) {
      case 'svg':
      case 'math':
        var wrapper = document.createElement('div');
        wrapper.innerHTML = '<' + type + '>' + template + '</' + type + '>';
        return wrapper.childNodes[0].childNodes;
      default:
        return template;
      }
    }


    function getTrustedContext(node, attrNormalizedName) {
      if (attrNormalizedName == "srcdoc") {
        return $sce.HTML;
      }
      var tag = nodeName_(node);
      // maction[xlink:href] can source SVG.  It's not limited to <maction>.
      if (attrNormalizedName == "xlinkHref" ||
          (tag == "form" && attrNormalizedName == "action") ||
          (tag != "img" && (attrNormalizedName == "src" ||
                            attrNormalizedName == "ngSrc"))) {
        return $sce.RESOURCE_URL;
      }
    }


    function addAttrInterpolateDirective(node, directives, value, name, allOrNothing) {
      var trustedContext = getTrustedContext(node, name);
      allOrNothing = ALL_OR_NOTHING_ATTRS[name] || allOrNothing;

      var interpolateFn = $interpolate(value, true, trustedContext, allOrNothing);

      // no interpolation found -> ignore
      if (!interpolateFn) return;


      if (name === "multiple" && nodeName_(node) === "select") {
        throw $compileMinErr("selmulti",
            "Binding to the 'multiple' attribute is not supported. Element: {0}",
            startingTag(node));
      }

      directives.push({
        priority: 100,
        compile: function() {
            return {
              pre: function attrInterpolatePreLinkFn(scope, element, attr) {
                var $$observers = (attr.$$observers || (attr.$$observers = {}));

                if (EVENT_HANDLER_ATTR_REGEXP.test(name)) {
                  throw $compileMinErr('nodomevents',
                      "Interpolations for HTML DOM event attributes are disallowed.  Please use the " +
                          "ng- versions (such as ng-click instead of onclick) instead.");
                }

                // If the attribute has changed since last $interpolate()ed
                var newValue = attr[name];
                if (newValue !== value) {
                  // we need to interpolate again since the attribute value has been updated
                  // (e.g. by another directive's compile function)
                  // ensure unset/empty values make interpolateFn falsy
                  interpolateFn = newValue && $interpolate(newValue, true, trustedContext, allOrNothing);
                  value = newValue;
                }

                // if attribute was updated so that there is no interpolation going on we don't want to
                // register any observers
                if (!interpolateFn) return;

                // initialize attr object so that it's ready in case we need the value for isolate
                // scope initialization, otherwise the value would not be available from isolate
                // directive's linking fn during linking phase
                attr[name] = interpolateFn(scope);

                ($$observers[name] || ($$observers[name] = [])).$$inter = true;
                (attr.$$observers && attr.$$observers[name].$$scope || scope).
                  $watch(interpolateFn, function interpolateFnWatchAction(newValue, oldValue) {
                    //special case for class attribute addition + removal
                    //so that class changes can tap into the animation
                    //hooks provided by the $animate service. Be sure to
                    //skip animations when the first digest occurs (when
                    //both the new and the old values are the same) since
                    //the CSS classes are the non-interpolated values
                    if (name === 'class' && newValue != oldValue) {
                      attr.$updateClass(newValue, oldValue);
                    } else {
                      attr.$set(name, newValue);
                    }
                  });
              }
            };
          }
      });
    }


    /**
     * This is a special jqLite.replaceWith, which can replace items which
     * have no parents, provided that the containing jqLite collection is provided.
     *
     * @param {JqLite=} $rootElement The root of the compile tree. Used so that we can replace nodes
     *                               in the root of the tree.
     * @param {JqLite} elementsToRemove The jqLite element which we are going to replace. We keep
     *                                  the shell, but replace its DOM node reference.
     * @param {Node} newNode The new DOM node.
     */
    function replaceWith($rootElement, elementsToRemove, newNode) {
      var firstElementToRemove = elementsToRemove[0],
          removeCount = elementsToRemove.length,
          parent = firstElementToRemove.parentNode,
          i, ii;

      if ($rootElement) {
        for (i = 0, ii = $rootElement.length; i < ii; i++) {
          if ($rootElement[i] == firstElementToRemove) {
            $rootElement[i++] = newNode;
            for (var j = i, j2 = j + removeCount - 1,
                     jj = $rootElement.length;
                 j < jj; j++, j2++) {
              if (j2 < jj) {
                $rootElement[j] = $rootElement[j2];
              } else {
                delete $rootElement[j];
              }
            }
            $rootElement.length -= removeCount - 1;

            // If the replaced element is also the jQuery .context then replace it
            // .context is a deprecated jQuery api, so we should set it only when jQuery set it
            // http://api.jquery.com/context/
            if ($rootElement.context === firstElementToRemove) {
              $rootElement.context = newNode;
            }
            break;
          }
        }
      }

      if (parent) {
        parent.replaceChild(newNode, firstElementToRemove);
      }

      // TODO(perf): what's this document fragment for? is it needed? can we at least reuse it?
      var fragment = document.createDocumentFragment();
      fragment.appendChild(firstElementToRemove);

      // Copy over user data (that includes Angular's $scope etc.). Don't copy private
      // data here because there's no public interface in jQuery to do that and copying over
      // event listeners (which is the main use of private data) wouldn't work anyway.
      jqLite(newNode).data(jqLite(firstElementToRemove).data());

      // Remove data of the replaced element. We cannot just call .remove()
      // on the element it since that would deallocate scope that is needed
      // for the new node. Instead, remove the data "manually".
      if (!jQuery) {
        delete jqLite.cache[firstElementToRemove[jqLite.expando]];
      } else {
        // jQuery 2.x doesn't expose the data storage. Use jQuery.cleanData to clean up after
        // the replaced element. The cleanData version monkey-patched by Angular would cause
        // the scope to be trashed and we do need the very same scope to work with the new
        // element. However, we cannot just cache the non-patched version and use it here as
        // that would break if another library patches the method after Angular does (one
        // example is jQuery UI). Instead, set a flag indicating scope destroying should be
        // skipped this one time.
        skipDestroyOnNextJQueryCleanData = true;
        jQuery.cleanData([firstElementToRemove]);
      }

      for (var k = 1, kk = elementsToRemove.length; k < kk; k++) {
        var element = elementsToRemove[k];
        jqLite(element).remove(); // must do this way to clean up expando
        fragment.appendChild(element);
        delete elementsToRemove[k];
      }

      elementsToRemove[0] = newNode;
      elementsToRemove.length = 1;
    }


    function cloneAndAnnotateFn(fn, annotation) {
      return extend(function() { return fn.apply(null, arguments); }, fn, annotation);
    }


    function invokeLinkFn(linkFn, scope, $element, attrs, controllers, transcludeFn) {
      try {
        linkFn(scope, $element, attrs, controllers, transcludeFn);
      } catch (e) {
        $exceptionHandler(e, startingTag($element));
      }
    }
  }];
}

var PREFIX_REGEXP = /^((?:x|data)[\:\-_])/i;
/**
 * Converts all accepted directives format into proper directive name.
 * @param name Name to normalize
 */
function directiveNormalize(name) {
  return camelCase(name.replace(PREFIX_REGEXP, ''));
}

/**
 * @ngdoc type
 * @name $compile.directive.Attributes
 *
 * @description
 * A shared object between directive compile / linking functions which contains normalized DOM
 * element attributes. The values reflect current binding state `{{ }}`. The normalization is
 * needed since all of these are treated as equivalent in Angular:
 *
 * ```
 *    <span ng:bind="a" ng-bind="a" data-ng-bind="a" x-ng-bind="a">
 * ```
 */

/**
 * @ngdoc property
 * @name $compile.directive.Attributes#$attr
 *
 * @description
 * A map of DOM element attribute names to the normalized name. This is
 * needed to do reverse lookup from normalized name back to actual name.
 */


/**
 * @ngdoc method
 * @name $compile.directive.Attributes#$set
 * @kind function
 *
 * @description
 * Set DOM element attribute value.
 *
 *
 * @param {string} name Normalized element attribute name of the property to modify. The name is
 *          reverse-translated using the {@link ng.$compile.directive.Attributes#$attr $attr}
 *          property to the original name.
 * @param {string} value Value to set the attribute to. The value can be an interpolated string.
 */



/**
 * Closure compiler type information
 */

function nodesetLinkingFn(
  /* angular.Scope */ scope,
  /* NodeList */ nodeList,
  /* Element */ rootElement,
  /* function(Function) */ boundTranscludeFn
) {}

function directiveLinkingFn(
  /* nodesetLinkingFn */ nodesetLinkingFn,
  /* angular.Scope */ scope,
  /* Node */ node,
  /* Element */ rootElement,
  /* function(Function) */ boundTranscludeFn
) {}

function tokenDifference(str1, str2) {
  var values = '',
      tokens1 = str1.split(/\s+/),
      tokens2 = str2.split(/\s+/);

  outer:
  for (var i = 0; i < tokens1.length; i++) {
    var token = tokens1[i];
    for (var j = 0; j < tokens2.length; j++) {
      if (token == tokens2[j]) continue outer;
    }
    values += (values.length > 0 ? ' ' : '') + token;
  }
  return values;
}

function removeComments(jqNodes) {
  jqNodes = jqLite(jqNodes);
  var i = jqNodes.length;

  if (i <= 1) {
    return jqNodes;
  }

  while (i--) {
    var node = jqNodes[i];
    if (node.nodeType === NODE_TYPE_COMMENT) {
      splice.call(jqNodes, i, 1);
    }
  }
  return jqNodes;
}

var $controllerMinErr = minErr('$controller');

/**
 * @ngdoc provider
 * @name $controllerProvider
 * @description
 * The {@link ng.$controller $controller service} is used by Angular to create new
 * controllers.
 *
 * This provider allows controller registration via the
 * {@link ng.$controllerProvider#register register} method.
 */
function $ControllerProvider() {
  var controllers = {},
      globals = false,
      CNTRL_REG = /^(\S+)(\s+as\s+(\w+))?$/;


  /**
   * @ngdoc method
   * @name $controllerProvider#register
   * @param {string|Object} name Controller name, or an object map of controllers where the keys are
   *    the names and the values are the constructors.
   * @param {Function|Array} constructor Controller constructor fn (optionally decorated with DI
   *    annotations in the array notation).
   */
  this.register = function(name, constructor) {
    assertNotHasOwnProperty(name, 'controller');
    if (isObject(name)) {
      extend(controllers, name);
    } else {
      controllers[name] = constructor;
    }
  };

  /**
   * @ngdoc method
   * @name $controllerProvider#allowGlobals
   * @description If called, allows `$controller` to find controller constructors on `window`
   */
  this.allowGlobals = function() {
    globals = true;
  };


  this.$get = ['$injector', '$window', function($injector, $window) {

    /**
     * @ngdoc service
     * @name $controller
     * @requires $injector
     *
     * @param {Function|string} constructor If called with a function then it's considered to be the
     *    controller constructor function. Otherwise it's considered to be a string which is used
     *    to retrieve the controller constructor using the following steps:
     *
     *    * check if a controller with given name is registered via `$controllerProvider`
     *    * check if evaluating the string on the current scope returns a constructor
     *    * if $controllerProvider#allowGlobals, check `window[constructor]` on the global
     *      `window` object (not recommended)
     *
     *    The string can use the `controller as property` syntax, where the controller instance is published
     *    as the specified property on the `scope`; the `scope` must be injected into `locals` param for this
     *    to work correctly.
     *
     * @param {Object} locals Injection locals for Controller.
     * @return {Object} Instance of given controller.
     *
     * @description
     * `$controller` service is responsible for instantiating controllers.
     *
     * It's just a simple call to {@link auto.$injector $injector}, but extracted into
     * a service, so that one can override this service with [BC version](https://gist.github.com/1649788).
     */
    return function(expression, locals, later, ident) {
      // PRIVATE API:
      //   param `later` --- indicates that the controller's constructor is invoked at a later time.
      //                     If true, $controller will allocate the object with the correct
      //                     prototype chain, but will not invoke the controller until a returned
      //                     callback is invoked.
      //   param `ident` --- An optional label which overrides the label parsed from the controller
      //                     expression, if any.
      var instance, match, constructor, identifier;
      later = later === true;
      if (ident && isString(ident)) {
        identifier = ident;
      }

      if (isString(expression)) {
        match = expression.match(CNTRL_REG);
        if (!match) {
          throw $controllerMinErr('ctrlfmt',
            "Badly formed controller string '{0}'. " +
            "Must match `__name__ as __id__` or `__name__`.", expression);
        }
        constructor = match[1],
        identifier = identifier || match[3];
        expression = controllers.hasOwnProperty(constructor)
            ? controllers[constructor]
            : getter(locals.$scope, constructor, true) ||
                (globals ? getter($window, constructor, true) : undefined);

        assertArgFn(expression, constructor, true);
      }

      if (later) {
        // Instantiate controller later:
        // This machinery is used to create an instance of the object before calling the
        // controller's constructor itself.
        //
        // This allows properties to be added to the controller before the constructor is
        // invoked. Primarily, this is used for isolate scope bindings in $compile.
        //
        // This feature is not intended for use by applications, and is thus not documented
        // publicly.
        // Object creation: http://jsperf.com/create-constructor/2
        var controllerPrototype = (isArray(expression) ?
          expression[expression.length - 1] : expression).prototype;
        instance = Object.create(controllerPrototype || null);

        if (identifier) {
          addIdentifier(locals, identifier, instance, constructor || expression.name);
        }

        return extend(function() {
          $injector.invoke(expression, instance, locals, constructor);
          return instance;
        }, {
          instance: instance,
          identifier: identifier
        });
      }

      instance = $injector.instantiate(expression, locals, constructor);

      if (identifier) {
        addIdentifier(locals, identifier, instance, constructor || expression.name);
      }

      return instance;
    };

    function addIdentifier(locals, identifier, instance, name) {
      if (!(locals && isObject(locals.$scope))) {
        throw minErr('$controller')('noscp',
          "Cannot export controller '{0}' as '{1}'! No $scope object provided via `locals`.",
          name, identifier);
      }

      locals.$scope[identifier] = instance;
    }
  }];
}

/**
 * @ngdoc service
 * @name $document
 * @requires $window
 *
 * @description
 * A {@link angular.element jQuery or jqLite} wrapper for the browser's `window.document` object.
 *
 * @example
   <example module="documentExample">
     <file name="index.html">
       <div ng-controller="ExampleController">
         <p>$document title: <b ng-bind="title"></b></p>
         <p>window.document title: <b ng-bind="windowTitle"></b></p>
       </div>
     </file>
     <file name="script.js">
       angular.module('documentExample', [])
         .controller('ExampleController', ['$scope', '$document', function($scope, $document) {
           $scope.title = $document[0].title;
           $scope.windowTitle = angular.element(window.document)[0].title;
         }]);
     </file>
   </example>
 */
function $DocumentProvider() {
  this.$get = ['$window', function(window) {
    return jqLite(window.document);
  }];
}

/**
 * @ngdoc service
 * @name $exceptionHandler
 * @requires ng.$log
 *
 * @description
 * Any uncaught exception in angular expressions is delegated to this service.
 * The default implementation simply delegates to `$log.error` which logs it into
 * the browser console.
 *
 * In unit tests, if `angular-mocks.js` is loaded, this service is overridden by
 * {@link ngMock.$exceptionHandler mock $exceptionHandler} which aids in testing.
 *
 * ## Example:
 *
 * ```js
 *   angular.module('exceptionOverride', []).factory('$exceptionHandler', function() {
 *     return function(exception, cause) {
 *       exception.message += ' (caused by "' + cause + '")';
 *       throw exception;
 *     };
 *   });
 * ```
 *
 * This example will override the normal action of `$exceptionHandler`, to make angular
 * exceptions fail hard when they happen, instead of just logging to the console.
 *
 * <hr />
 * Note, that code executed in event-listeners (even those registered using jqLite's `on`/`bind`
 * methods) does not delegate exceptions to the {@link ng.$exceptionHandler $exceptionHandler}
 * (unless executed during a digest).
 *
 * If you wish, you can manually delegate exceptions, e.g.
 * `try { ... } catch(e) { $exceptionHandler(e); }`
 *
 * @param {Error} exception Exception associated with the error.
 * @param {string=} cause optional information about the context in which
 *       the error was thrown.
 *
 */
function $ExceptionHandlerProvider() {
  this.$get = ['$log', function($log) {
    return function(exception, cause) {
      $log.error.apply($log, arguments);
    };
  }];
}

var APPLICATION_JSON = 'application/json';
var CONTENT_TYPE_APPLICATION_JSON = {'Content-Type': APPLICATION_JSON + ';charset=utf-8'};
var JSON_START = /^\[|^\{(?!\{)/;
var JSON_ENDS = {
  '[': /]$/,
  '{': /}$/
};
var JSON_PROTECTION_PREFIX = /^\)\]\}',?\n/;

function defaultHttpResponseTransform(data, headers) {
  if (isString(data)) {
    // Strip json vulnerability protection prefix and trim whitespace
    var tempData = data.replace(JSON_PROTECTION_PREFIX, '').trim();

    if (tempData) {
      var contentType = headers('Content-Type');
      if ((contentType && (contentType.indexOf(APPLICATION_JSON) === 0)) || isJsonLike(tempData)) {
        data = fromJson(tempData);
      }
    }
  }

  return data;
}

function isJsonLike(str) {
    var jsonStart = str.match(JSON_START);
    return jsonStart && JSON_ENDS[jsonStart[0]].test(str);
}

/**
 * Parse headers into key value object
 *
 * @param {string} headers Raw headers as a string
 * @returns {Object} Parsed headers as key value object
 */
function parseHeaders(headers) {
  var parsed = createMap(), key, val, i;

  if (!headers) return parsed;

  forEach(headers.split('\n'), function(line) {
    i = line.indexOf(':');
    key = lowercase(trim(line.substr(0, i)));
    val = trim(line.substr(i + 1));

    if (key) {
      parsed[key] = parsed[key] ? parsed[key] + ', ' + val : val;
    }
  });

  return parsed;
}


/**
 * Returns a function that provides access to parsed headers.
 *
 * Headers are lazy parsed when first requested.
 * @see parseHeaders
 *
 * @param {(string|Object)} headers Headers to provide access to.
 * @returns {function(string=)} Returns a getter function which if called with:
 *
 *   - if called with single an argument returns a single header value or null
 *   - if called with no arguments returns an object containing all headers.
 */
function headersGetter(headers) {
  var headersObj = isObject(headers) ? headers : undefined;

  return function(name) {
    if (!headersObj) headersObj =  parseHeaders(headers);

    if (name) {
      var value = headersObj[lowercase(name)];
      if (value === void 0) {
        value = null;
      }
      return value;
    }

    return headersObj;
  };
}


/**
 * Chain all given functions
 *
 * This function is used for both request and response transforming
 *
 * @param {*} data Data to transform.
 * @param {function(string=)} headers HTTP headers getter fn.
 * @param {number} status HTTP status code of the response.
 * @param {(Function|Array.<Function>)} fns Function or an array of functions.
 * @returns {*} Transformed data.
 */
function transformData(data, headers, status, fns) {
  if (isFunction(fns))
    return fns(data, headers, status);

  forEach(fns, function(fn) {
    data = fn(data, headers, status);
  });

  return data;
}


function isSuccess(status) {
  return 200 <= status && status < 300;
}


/**
 * @ngdoc provider
 * @name $httpProvider
 * @description
 * Use `$httpProvider` to change the default behavior of the {@link ng.$http $http} service.
 * */
function $HttpProvider() {
  /**
   * @ngdoc property
   * @name $httpProvider#defaults
   * @description
   *
   * Object containing default values for all {@link ng.$http $http} requests.
   *
   * - **`defaults.cache`** - {Object} - an object built with {@link ng.$cacheFactory `$cacheFactory`}
   * that will provide the cache for all requests who set their `cache` property to `true`.
   * If you set the `default.cache = false` then only requests that specify their own custom
   * cache object will be cached. See {@link $http#caching $http Caching} for more information.
   *
   * - **`defaults.xsrfCookieName`** - {string} - Name of cookie containing the XSRF token.
   * Defaults value is `'XSRF-TOKEN'`.
   *
   * - **`defaults.xsrfHeaderName`** - {string} - Name of HTTP header to populate with the
   * XSRF token. Defaults value is `'X-XSRF-TOKEN'`.
   *
   * - **`defaults.headers`** - {Object} - Default headers for all $http requests.
   * Refer to {@link ng.$http#setting-http-headers $http} for documentation on
   * setting default headers.
   *     - **`defaults.headers.common`**
   *     - **`defaults.headers.post`**
   *     - **`defaults.headers.put`**
   *     - **`defaults.headers.patch`**
   *
   **/
  var defaults = this.defaults = {
    // transform incoming response data
    transformResponse: [defaultHttpResponseTransform],

    // transform outgoing request data
    transformRequest: [function(d) {
      return isObject(d) && !isFile(d) && !isBlob(d) && !isFormData(d) ? toJson(d) : d;
    }],

    // default headers
    headers: {
      common: {
        'Accept': 'application/json, text/plain, */*'
      },
      post:   shallowCopy(CONTENT_TYPE_APPLICATION_JSON),
      put:    shallowCopy(CONTENT_TYPE_APPLICATION_JSON),
      patch:  shallowCopy(CONTENT_TYPE_APPLICATION_JSON)
    },

    xsrfCookieName: 'XSRF-TOKEN',
    xsrfHeaderName: 'X-XSRF-TOKEN'
  };

  var useApplyAsync = false;
  /**
   * @ngdoc method
   * @name $httpProvider#useApplyAsync
   * @description
   *
   * Configure $http service to combine processing of multiple http responses received at around
   * the same time via {@link ng.$rootScope.Scope#$applyAsync $rootScope.$applyAsync}. This can result in
   * significant performance improvement for bigger applications that make many HTTP requests
   * concurrently (common during application bootstrap).
   *
   * Defaults to false. If no value is specifed, returns the current configured value.
   *
   * @param {boolean=} value If true, when requests are loaded, they will schedule a deferred
   *    "apply" on the next tick, giving time for subsequent requests in a roughly ~10ms window
   *    to load and share the same digest cycle.
   *
   * @returns {boolean|Object} If a value is specified, returns the $httpProvider for chaining.
   *    otherwise, returns the current configured value.
   **/
  this.useApplyAsync = function(value) {
    if (isDefined(value)) {
      useApplyAsync = !!value;
      return this;
    }
    return useApplyAsync;
  };

  /**
   * @ngdoc property
   * @name $httpProvider#interceptors
   * @description
   *
   * Array containing service factories for all synchronous or asynchronous {@link ng.$http $http}
   * pre-processing of request or postprocessing of responses.
   *
   * These service factories are ordered by request, i.e. they are applied in the same order as the
   * array, on request, but reverse order, on response.
   *
   * {@link ng.$http#interceptors Interceptors detailed info}
   **/
  var interceptorFactories = this.interceptors = [];

  this.$get = ['$httpBackend', '$browser', '$cacheFactory', '$rootScope', '$q', '$injector',
      function($httpBackend, $browser, $cacheFactory, $rootScope, $q, $injector) {

    var defaultCache = $cacheFactory('$http');

    /**
     * Interceptors stored in reverse order. Inner interceptors before outer interceptors.
     * The reversal is needed so that we can build up the interception chain around the
     * server request.
     */
    var reversedInterceptors = [];

    forEach(interceptorFactories, function(interceptorFactory) {
      reversedInterceptors.unshift(isString(interceptorFactory)
          ? $injector.get(interceptorFactory) : $injector.invoke(interceptorFactory));
    });

    /**
     * @ngdoc service
     * @kind function
     * @name $http
     * @requires ng.$httpBackend
     * @requires $cacheFactory
     * @requires $rootScope
     * @requires $q
     * @requires $injector
     *
     * @description
     * The `$http` service is a core Angular service that facilitates communication with the remote
     * HTTP servers via the browser's [XMLHttpRequest](https://developer.mozilla.org/en/xmlhttprequest)
     * object or via [JSONP](http://en.wikipedia.org/wiki/JSONP).
     *
     * For unit testing applications that use `$http` service, see
     * {@link ngMock.$httpBackend $httpBackend mock}.
     *
     * For a higher level of abstraction, please check out the {@link ngResource.$resource
     * $resource} service.
     *
     * The $http API is based on the {@link ng.$q deferred/promise APIs} exposed by
     * the $q service. While for simple usage patterns this doesn't matter much, for advanced usage
     * it is important to familiarize yourself with these APIs and the guarantees they provide.
     *
     *
     * ## General usage
     * The `$http` service is a function which takes a single argument — a configuration object —
     * that is used to generate an HTTP request and returns  a {@link ng.$q promise}
     * with two $http specific methods: `success` and `error`.
     *
     * ```js
     *   // Simple GET request example :
     *   $http.get('/someUrl').
     *     success(function(data, status, headers, config) {
     *       // this callback will be called asynchronously
     *       // when the response is available
     *     }).
     *     error(function(data, status, headers, config) {
     *       // called asynchronously if an error occurs
     *       // or server returns response with an error status.
     *     });
     * ```
     *
     * ```js
     *   // Simple POST request example (passing data) :
     *   $http.post('/someUrl', {msg:'hello word!'}).
     *     success(function(data, status, headers, config) {
     *       // this callback will be called asynchronously
     *       // when the response is available
     *     }).
     *     error(function(data, status, headers, config) {
     *       // called asynchronously if an error occurs
     *       // or server returns response with an error status.
     *     });
     * ```
     *
     *
     * Since the returned value of calling the $http function is a `promise`, you can also use
     * the `then` method to register callbacks, and these callbacks will receive a single argument –
     * an object representing the response. See the API signature and type info below for more
     * details.
     *
     * A response status code between 200 and 299 is considered a success status and
     * will result in the success callback being called. Note that if the response is a redirect,
     * XMLHttpRequest will transparently follow it, meaning that the error callback will not be
     * called for such responses.
     *
     * ## Writing Unit Tests that use $http
     * When unit testing (using {@link ngMock ngMock}), it is necessary to call
     * {@link ngMock.$httpBackend#flush $httpBackend.flush()} to flush each pending
     * request using trained responses.
     *
     * ```
     * $httpBackend.expectGET(...);
     * $http.get(...);
     * $httpBackend.flush();
     * ```
     *
     * ## Shortcut methods
     *
     * Shortcut methods are also available. All shortcut methods require passing in the URL, and
     * request data must be passed in for POST/PUT requests.
     *
     * ```js
     *   $http.get('/someUrl').success(successCallback);
     *   $http.post('/someUrl', data).success(successCallback);
     * ```
     *
     * Complete list of shortcut methods:
     *
     * - {@link ng.$http#get $http.get}
     * - {@link ng.$http#head $http.head}
     * - {@link ng.$http#post $http.post}
     * - {@link ng.$http#put $http.put}
     * - {@link ng.$http#delete $http.delete}
     * - {@link ng.$http#jsonp $http.jsonp}
     * - {@link ng.$http#patch $http.patch}
     *
     *
     * ## Setting HTTP Headers
     *
     * The $http service will automatically add certain HTTP headers to all requests. These defaults
     * can be fully configured by accessing the `$httpProvider.defaults.headers` configuration
     * object, which currently contains this default configuration:
     *
     * - `$httpProvider.defaults.headers.common` (headers that are common for all requests):
     *   - `Accept: application/json, text/plain, * / *`
     * - `$httpProvider.defaults.headers.post`: (header defaults for POST requests)
     *   - `Content-Type: application/json`
     * - `$httpProvider.defaults.headers.put` (header defaults for PUT requests)
     *   - `Content-Type: application/json`
     *
     * To add or overwrite these defaults, simply add or remove a property from these configuration
     * objects. To add headers for an HTTP method other than POST or PUT, simply add a new object
     * with the lowercased HTTP method name as the key, e.g.
     * `$httpProvider.defaults.headers.get = { 'My-Header' : 'value' }.
     *
     * The defaults can also be set at runtime via the `$http.defaults` object in the same
     * fashion. For example:
     *
     * ```
     * module.run(function($http) {
     *   $http.defaults.headers.common.Authorization = 'Basic YmVlcDpib29w'
     * });
     * ```
     *
     * In addition, you can supply a `headers` property in the config object passed when
     * calling `$http(config)`, which overrides the defaults without changing them globally.
     *
     * To explicitly remove a header automatically added via $httpProvider.defaults.headers on a per request basis,
     * Use the `headers` property, setting the desired header to `undefined`. For example:
     *
     * ```js
     * var req = {
     *  method: 'POST',
     *  url: 'http://example.com',
     *  headers: {
     *    'Content-Type': undefined
     *  },
     *  data: { test: 'test' }
     * }
     *
     * $http(req).success(function(){...}).error(function(){...});
     * ```
     *
     * ## Transforming Requests and Responses
     *
     * Both requests and responses can be transformed using transformation functions: `transformRequest`
     * and `transformResponse`. These properties can be a single function that returns
     * the transformed value (`function(data, headersGetter, status)`) or an array of such transformation functions,
     * which allows you to `push` or `unshift` a new transformation function into the transformation chain.
     *
     * ### Default Transformations
     *
     * The `$httpProvider` provider and `$http` service expose `defaults.transformRequest` and
     * `defaults.transformResponse` properties. If a request does not provide its own transformations
     * then these will be applied.
     *
     * You can augment or replace the default transformations by modifying these properties by adding to or
     * replacing the array.
     *
     * Angular provides the following default transformations:
     *
     * Request transformations (`$httpProvider.defaults.transformRequest` and `$http.defaults.transformRequest`):
     *
     * - If the `data` property of the request configuration object contains an object, serialize it
     *   into JSON format.
     *
     * Response transformations (`$httpProvider.defaults.transformResponse` and `$http.defaults.transformResponse`):
     *
     *  - If XSRF prefix is detected, strip it (see Security Considerations section below).
     *  - If JSON response is detected, deserialize it using a JSON parser.
     *
     *
     * ### Overriding the Default Transformations Per Request
     *
     * If you wish override the request/response transformations only for a single request then provide
     * `transformRequest` and/or `transformResponse` properties on the configuration object passed
     * into `$http`.
     *
     * Note that if you provide these properties on the config object the default transformations will be
     * overwritten. If you wish to augment the default transformations then you must include them in your
     * local transformation array.
     *
     * The following code demonstrates adding a new response transformation to be run after the default response
     * transformations have been run.
     *
     * ```js
     * function appendTransform(defaults, transform) {
     *
     *   // We can't guarantee that the default transformation is an array
     *   defaults = angular.isArray(defaults) ? defaults : [defaults];
     *
     *   // Append the new transformation to the defaults
     *   return defaults.concat(transform);
     * }
     *
     * $http({
     *   url: '...',
     *   method: 'GET',
     *   transformResponse: appendTransform($http.defaults.transformResponse, function(value) {
     *     return doTransform(value);
     *   })
     * });
     * ```
     *
     *
     * ## Caching
     *
     * To enable caching, set the request configuration `cache` property to `true` (to use default
     * cache) or to a custom cache object (built with {@link ng.$cacheFactory `$cacheFactory`}).
     * When the cache is enabled, `$http` stores the response from the server in the specified
     * cache. The next time the same request is made, the response is served from the cache without
     * sending a request to the server.
     *
     * Note that even if the response is served from cache, delivery of the data is asynchronous in
     * the same way that real requests are.
     *
     * If there are multiple GET requests for the same URL that should be cached using the same
     * cache, but the cache is not populated yet, only one request to the server will be made and
     * the remaining requests will be fulfilled using the response from the first request.
     *
     * You can change the default cache to a new object (built with
     * {@link ng.$cacheFactory `$cacheFactory`}) by updating the
     * {@link ng.$http#defaults `$http.defaults.cache`} property. All requests who set
     * their `cache` property to `true` will now use this cache object.
     *
     * If you set the default cache to `false` then only requests that specify their own custom
     * cache object will be cached.
     *
     * ## Interceptors
     *
     * Before you start creating interceptors, be sure to understand the
     * {@link ng.$q $q and deferred/promise APIs}.
     *
     * For purposes of global error handling, authentication, or any kind of synchronous or
     * asynchronous pre-processing of request or postprocessing of responses, it is desirable to be
     * able to intercept requests before they are handed to the server and
     * responses before they are handed over to the application code that
     * initiated these requests. The interceptors leverage the {@link ng.$q
     * promise APIs} to fulfill this need for both synchronous and asynchronous pre-processing.
     *
     * The interceptors are service factories that are registered with the `$httpProvider` by
     * adding them to the `$httpProvider.interceptors` array. The factory is called and
     * injected with dependencies (if specified) and returns the interceptor.
     *
     * There are two kinds of interceptors (and two kinds of rejection interceptors):
     *
     *   * `request`: interceptors get called with a http `config` object. The function is free to
     *     modify the `config` object or create a new one. The function needs to return the `config`
     *     object directly, or a promise containing the `config` or a new `config` object.
     *   * `requestError`: interceptor gets called when a previous interceptor threw an error or
     *     resolved with a rejection.
     *   * `response`: interceptors get called with http `response` object. The function is free to
     *     modify the `response` object or create a new one. The function needs to return the `response`
     *     object directly, or as a promise containing the `response` or a new `response` object.
     *   * `responseError`: interceptor gets called when a previous interceptor threw an error or
     *     resolved with a rejection.
     *
     *
     * ```js
     *   // register the interceptor as a service
     *   $provide.factory('myHttpInterceptor', function($q, dependency1, dependency2) {
     *     return {
     *       // optional method
     *       'request': function(config) {
     *         // do something on success
     *         return config;
     *       },
     *
     *       // optional method
     *      'requestError': function(rejection) {
     *         // do something on error
     *         if (canRecover(rejection)) {
     *           return responseOrNewPromise
     *         }
     *         return $q.reject(rejection);
     *       },
     *
     *
     *
     *       // optional method
     *       'response': function(response) {
     *         // do something on success
     *         return response;
     *       },
     *
     *       // optional method
     *      'responseError': function(rejection) {
     *         // do something on error
     *         if (canRecover(rejection)) {
     *           return responseOrNewPromise
     *         }
     *         return $q.reject(rejection);
     *       }
     *     };
     *   });
     *
     *   $httpProvider.interceptors.push('myHttpInterceptor');
     *
     *
     *   // alternatively, register the interceptor via an anonymous factory
     *   $httpProvider.interceptors.push(function($q, dependency1, dependency2) {
     *     return {
     *      'request': function(config) {
     *          // same as above
     *       },
     *
     *       'response': function(response) {
     *          // same as above
     *       }
     *     };
     *   });
     * ```
     *
     * ## Security Considerations
     *
     * When designing web applications, consider security threats from:
     *
     * - [JSON vulnerability](http://haacked.com/archive/2008/11/20/anatomy-of-a-subtle-json-vulnerability.aspx)
     * - [XSRF](http://en.wikipedia.org/wiki/Cross-site_request_forgery)
     *
     * Both server and the client must cooperate in order to eliminate these threats. Angular comes
     * pre-configured with strategies that address these issues, but for this to work backend server
     * cooperation is required.
     *
     * ### JSON Vulnerability Protection
     *
     * A [JSON vulnerability](http://haacked.com/archive/2008/11/20/anatomy-of-a-subtle-json-vulnerability.aspx)
     * allows third party website to turn your JSON resource URL into
     * [JSONP](http://en.wikipedia.org/wiki/JSONP) request under some conditions. To
     * counter this your server can prefix all JSON requests with following string `")]}',\n"`.
     * Angular will automatically strip the prefix before processing it as JSON.
     *
     * For example if your server needs to return:
     * ```js
     * ['one','two']
     * ```
     *
     * which is vulnerable to attack, your server can return:
     * ```js
     * )]}',
     * ['one','two']
     * ```
     *
     * Angular will strip the prefix, before processing the JSON.
     *
     *
     * ### Cross Site Request Forgery (XSRF) Protection
     *
     * [XSRF](http://en.wikipedia.org/wiki/Cross-site_request_forgery) is a technique by which
     * an unauthorized site can gain your user's private data. Angular provides a mechanism
     * to counter XSRF. When performing XHR requests, the $http service reads a token from a cookie
     * (by default, `XSRF-TOKEN`) and sets it as an HTTP header (`X-XSRF-TOKEN`). Since only
     * JavaScript that runs on your domain could read the cookie, your server can be assured that
     * the XHR came from JavaScript running on your domain. The header will not be set for
     * cross-domain requests.
     *
     * To take advantage of this, your server needs to set a token in a JavaScript readable session
     * cookie called `XSRF-TOKEN` on the first HTTP GET request. On subsequent XHR requests the
     * server can verify that the cookie matches `X-XSRF-TOKEN` HTTP header, and therefore be sure
     * that only JavaScript running on your domain could have sent the request. The token must be
     * unique for each user and must be verifiable by the server (to prevent the JavaScript from
     * making up its own tokens). We recommend that the token is a digest of your site's
     * authentication cookie with a [salt](https://en.wikipedia.org/wiki/Salt_(cryptography&#41;)
     * for added security.
     *
     * The name of the headers can be specified using the xsrfHeaderName and xsrfCookieName
     * properties of either $httpProvider.defaults at config-time, $http.defaults at run-time,
     * or the per-request config object.
     *
     *
     * @param {object} config Object describing the request to be made and how it should be
     *    processed. The object has following properties:
     *
     *    - **method** – `{string}` – HTTP method (e.g. 'GET', 'POST', etc)
     *    - **url** – `{string}` – Absolute or relative URL of the resource that is being requested.
     *    - **params** – `{Object.<string|Object>}` – Map of strings or objects which will be turned
     *      to `?key1=value1&key2=value2` after the url. If the value is not a string, it will be
     *      JSONified.
     *    - **data** – `{string|Object}` – Data to be sent as the request message data.
     *    - **headers** – `{Object}` – Map of strings or functions which return strings representing
     *      HTTP headers to send to the server. If the return value of a function is null, the
     *      header will not be sent.
     *    - **xsrfHeaderName** – `{string}` – Name of HTTP header to populate with the XSRF token.
     *    - **xsrfCookieName** – `{string}` – Name of cookie containing the XSRF token.
     *    - **transformRequest** –
     *      `{function(data, headersGetter)|Array.<function(data, headersGetter)>}` –
     *      transform function or an array of such functions. The transform function takes the http
     *      request body and headers and returns its transformed (typically serialized) version.
     *      See {@link ng.$http#overriding-the-default-transformations-per-request
     *      Overriding the Default Transformations}
     *    - **transformResponse** –
     *      `{function(data, headersGetter, status)|Array.<function(data, headersGetter, status)>}` –
     *      transform function or an array of such functions. The transform function takes the http
     *      response body, headers and status and returns its transformed (typically deserialized) version.
     *      See {@link ng.$http#overriding-the-default-transformations-per-request
     *      Overriding the Default Transformations}
     *    - **cache** – `{boolean|Cache}` – If true, a default $http cache will be used to cache the
     *      GET request, otherwise if a cache instance built with
     *      {@link ng.$cacheFactory $cacheFactory}, this cache will be used for
     *      caching.
     *    - **timeout** – `{number|Promise}` – timeout in milliseconds, or {@link ng.$q promise}
     *      that should abort the request when resolved.
     *    - **withCredentials** - `{boolean}` - whether to set the `withCredentials` flag on the
     *      XHR object. See [requests with credentials](https://developer.mozilla.org/docs/Web/HTTP/Access_control_CORS#Requests_with_credentials)
     *      for more information.
     *    - **responseType** - `{string}` - see
     *      [requestType](https://developer.mozilla.org/en-US/docs/DOM/XMLHttpRequest#responseType).
     *
     * @returns {HttpPromise} Returns a {@link ng.$q promise} object with the
     *   standard `then` method and two http specific methods: `success` and `error`. The `then`
     *   method takes two arguments a success and an error callback which will be called with a
     *   response object. The `success` and `error` methods take a single argument - a function that
     *   will be called when the request succeeds or fails respectively. The arguments passed into
     *   these functions are destructured representation of the response object passed into the
     *   `then` method. The response object has these properties:
     *
     *   - **data** – `{string|Object}` – The response body transformed with the transform
     *     functions.
     *   - **status** – `{number}` – HTTP status code of the response.
     *   - **headers** – `{function([headerName])}` – Header getter function.
     *   - **config** – `{Object}` – The configuration object that was used to generate the request.
     *   - **statusText** – `{string}` – HTTP status text of the response.
     *
     * @property {Array.<Object>} pendingRequests Array of config objects for currently pending
     *   requests. This is primarily meant to be used for debugging purposes.
     *
     *
     * @example
<example module="httpExample">
<file name="index.html">
  <div ng-controller="FetchController">
    <select ng-model="method">
      <option>GET</option>
      <option>JSONP</option>
    </select>
    <input type="text" ng-model="url" size="80"/>
    <button id="fetchbtn" ng-click="fetch()">fetch</button><br>
    <button id="samplegetbtn" ng-click="updateModel('GET', 'http-hello.html')">Sample GET</button>
    <button id="samplejsonpbtn"
      ng-click="updateModel('JSONP',
                    'https://angularjs.org/greet.php?callback=JSON_CALLBACK&name=Super%20Hero')">
      Sample JSONP
    </button>
    <button id="invalidjsonpbtn"
      ng-click="updateModel('JSONP', 'https://angularjs.org/doesntexist&callback=JSON_CALLBACK')">
        Invalid JSONP
      </button>
    <pre>http status code: {{status}}</pre>
    <pre>http response data: {{data}}</pre>
  </div>
</file>
<file name="script.js">
  angular.module('httpExample', [])
    .controller('FetchController', ['$scope', '$http', '$templateCache',
      function($scope, $http, $templateCache) {
        $scope.method = 'GET';
        $scope.url = 'http-hello.html';

        $scope.fetch = function() {
          $scope.code = null;
          $scope.response = null;

          $http({method: $scope.method, url: $scope.url, cache: $templateCache}).
            success(function(data, status) {
              $scope.status = status;
              $scope.data = data;
            }).
            error(function(data, status) {
              $scope.data = data || "Request failed";
              $scope.status = status;
          });
        };

        $scope.updateModel = function(method, url) {
          $scope.method = method;
          $scope.url = url;
        };
      }]);
</file>
<file name="http-hello.html">
  Hello, $http!
</file>
<file name="protractor.js" type="protractor">
  var status = element(by.binding('status'));
  var data = element(by.binding('data'));
  var fetchBtn = element(by.id('fetchbtn'));
  var sampleGetBtn = element(by.id('samplegetbtn'));
  var sampleJsonpBtn = element(by.id('samplejsonpbtn'));
  var invalidJsonpBtn = element(by.id('invalidjsonpbtn'));

  it('should make an xhr GET request', function() {
    sampleGetBtn.click();
    fetchBtn.click();
    expect(status.getText()).toMatch('200');
    expect(data.getText()).toMatch(/Hello, \$http!/);
  });

// Commented out due to flakes. See https://github.com/angular/angular.js/issues/9185
// it('should make a JSONP request to angularjs.org', function() {
//   sampleJsonpBtn.click();
//   fetchBtn.click();
//   expect(status.getText()).toMatch('200');
//   expect(data.getText()).toMatch(/Super Hero!/);
// });

  it('should make JSONP request to invalid URL and invoke the error handler',
      function() {
    invalidJsonpBtn.click();
    fetchBtn.click();
    expect(status.getText()).toMatch('0');
    expect(data.getText()).toMatch('Request failed');
  });
</file>
</example>
     */
    function $http(requestConfig) {

      if (!angular.isObject(requestConfig)) {
        throw minErr('$http')('badreq', 'Http request configuration must be an object.  Received: {0}', requestConfig);
      }

      var config = extend({
        method: 'get',
        transformRequest: defaults.transformRequest,
        transformResponse: defaults.transformResponse
      }, requestConfig);

      config.headers = mergeHeaders(requestConfig);
      config.method = uppercase(config.method);

      var serverRequest = function(config) {
        var headers = config.headers;
        var reqData = transformData(config.data, headersGetter(headers), undefined, config.transformRequest);

        // strip content-type if data is undefined
        if (isUndefined(reqData)) {
          forEach(headers, function(value, header) {
            if (lowercase(header) === 'content-type') {
                delete headers[header];
            }
          });
        }

        if (isUndefined(config.withCredentials) && !isUndefined(defaults.withCredentials)) {
          config.withCredentials = defaults.withCredentials;
        }

        // send request
        return sendReq(config, reqData).then(transformResponse, transformResponse);
      };

      var chain = [serverRequest, undefined];
      var promise = $q.when(config);

      // apply interceptors
      forEach(reversedInterceptors, function(interceptor) {
        if (interceptor.request || interceptor.requestError) {
          chain.unshift(interceptor.request, interceptor.requestError);
        }
        if (interceptor.response || interceptor.responseError) {
          chain.push(interceptor.response, interceptor.responseError);
        }
      });

      while (chain.length) {
        var thenFn = chain.shift();
        var rejectFn = chain.shift();

        promise = promise.then(thenFn, rejectFn);
      }

      promise.success = function(fn) {
        assertArgFn(fn, 'fn');

        promise.then(function(response) {
          fn(response.data, response.status, response.headers, config);
        });
        return promise;
      };

      promise.error = function(fn) {
        assertArgFn(fn, 'fn');

        promise.then(null, function(response) {
          fn(response.data, response.status, response.headers, config);
        });
        return promise;
      };

      return promise;

      function transformResponse(response) {
        // make a copy since the response must be cacheable
        var resp = extend({}, response);
        if (!response.data) {
          resp.data = response.data;
        } else {
          resp.data = transformData(response.data, response.headers, response.status, config.transformResponse);
        }
        return (isSuccess(response.status))
          ? resp
          : $q.reject(resp);
      }

      function executeHeaderFns(headers) {
        var headerContent, processedHeaders = {};

        forEach(headers, function(headerFn, header) {
          if (isFunction(headerFn)) {
            headerContent = headerFn();
            if (headerContent != null) {
              processedHeaders[header] = headerContent;
            }
          } else {
            processedHeaders[header] = headerFn;
          }
        });

        return processedHeaders;
      }

      function mergeHeaders(config) {
        var defHeaders = defaults.headers,
            reqHeaders = extend({}, config.headers),
            defHeaderName, lowercaseDefHeaderName, reqHeaderName;

        defHeaders = extend({}, defHeaders.common, defHeaders[lowercase(config.method)]);

        // using for-in instead of forEach to avoid unecessary iteration after header has been found
        defaultHeadersIteration:
        for (defHeaderName in defHeaders) {
          lowercaseDefHeaderName = lowercase(defHeaderName);

          for (reqHeaderName in reqHeaders) {
            if (lowercase(reqHeaderName) === lowercaseDefHeaderName) {
              continue defaultHeadersIteration;
            }
          }

          reqHeaders[defHeaderName] = defHeaders[defHeaderName];
        }

        // execute if header value is a function for merged headers
        return executeHeaderFns(reqHeaders);
      }
    }

    $http.pendingRequests = [];

    /**
     * @ngdoc method
     * @name $http#get
     *
     * @description
     * Shortcut method to perform `GET` request.
     *
     * @param {string} url Relative or absolute URL specifying the destination of the request
     * @param {Object=} config Optional configuration object
     * @returns {HttpPromise} Future object
     */

    /**
     * @ngdoc method
     * @name $http#delete
     *
     * @description
     * Shortcut method to perform `DELETE` request.
     *
     * @param {string} url Relative or absolute URL specifying the destination of the request
     * @param {Object=} config Optional configuration object
     * @returns {HttpPromise} Future object
     */

    /**
     * @ngdoc method
     * @name $http#head
     *
     * @description
     * Shortcut method to perform `HEAD` request.
     *
     * @param {string} url Relative or absolute URL specifying the destination of the request
     * @param {Object=} config Optional configuration object
     * @returns {HttpPromise} Future object
     */

    /**
     * @ngdoc method
     * @name $http#jsonp
     *
     * @description
     * Shortcut method to perform `JSONP` request.
     *
     * @param {string} url Relative or absolute URL specifying the destination of the request.
     *                     The name of the callback should be the string `JSON_CALLBACK`.
     * @param {Object=} config Optional configuration object
     * @returns {HttpPromise} Future object
     */
    createShortMethods('get', 'delete', 'head', 'jsonp');

    /**
     * @ngdoc method
     * @name $http#post
     *
     * @description
     * Shortcut method to perform `POST` request.
     *
     * @param {string} url Relative or absolute URL specifying the destination of the request
     * @param {*} data Request content
     * @param {Object=} config Optional configuration object
     * @returns {HttpPromise} Future object
     */

    /**
     * @ngdoc method
     * @name $http#put
     *
     * @description
     * Shortcut method to perform `PUT` request.
     *
     * @param {string} url Relative or absolute URL specifying the destination of the request
     * @param {*} data Request content
     * @param {Object=} config Optional configuration object
     * @returns {HttpPromise} Future object
     */

     /**
      * @ngdoc method
      * @name $http#patch
      *
      * @description
      * Shortcut method to perform `PATCH` request.
      *
      * @param {string} url Relative or absolute URL specifying the destination of the request
      * @param {*} data Request content
      * @param {Object=} config Optional configuration object
      * @returns {HttpPromise} Future object
      */
    createShortMethodsWithData('post', 'put', 'patch');

        /**
         * @ngdoc property
         * @name $http#defaults
         *
         * @description
         * Runtime equivalent of the `$httpProvider.defaults` property. Allows configuration of
         * default headers, withCredentials as well as request and response transformations.
         *
         * See "Setting HTTP Headers" and "Transforming Requests and Responses" sections above.
         */
    $http.defaults = defaults;


    return $http;


    function createShortMethods(names) {
      forEach(arguments, function(name) {
        $http[name] = function(url, config) {
          return $http(extend(config || {}, {
            method: name,
            url: url
          }));
        };
      });
    }


    function createShortMethodsWithData(name) {
      forEach(arguments, function(name) {
        $http[name] = function(url, data, config) {
          return $http(extend(config || {}, {
            method: name,
            url: url,
            data: data
          }));
        };
      });
    }


    /**
     * Makes the request.
     *
     * !!! ACCESSES CLOSURE VARS:
     * $httpBackend, defaults, $log, $rootScope, defaultCache, $http.pendingRequests
     */
    function sendReq(config, reqData) {
      var deferred = $q.defer(),
          promise = deferred.promise,
          cache,
          cachedResp,
          reqHeaders = config.headers,
          url = buildUrl(config.url, config.params);

      $http.pendingRequests.push(config);
      promise.then(removePendingReq, removePendingReq);


      if ((config.cache || defaults.cache) && config.cache !== false &&
          (config.method === 'GET' || config.method === 'JSONP')) {
        cache = isObject(config.cache) ? config.cache
              : isObject(defaults.cache) ? defaults.cache
              : defaultCache;
      }

      if (cache) {
        cachedResp = cache.get(url);
        if (isDefined(cachedResp)) {
          if (isPromiseLike(cachedResp)) {
            // cached request has already been sent, but there is no response yet
            cachedResp.then(resolvePromiseWithResult, resolvePromiseWithResult);
          } else {
            // serving from cache
            if (isArray(cachedResp)) {
              resolvePromise(cachedResp[1], cachedResp[0], shallowCopy(cachedResp[2]), cachedResp[3]);
            } else {
              resolvePromise(cachedResp, 200, {}, 'OK');
            }
          }
        } else {
          // put the promise for the non-transformed response into cache as a placeholder
          cache.put(url, promise);
        }
      }


      // if we won't have the response in cache, set the xsrf headers and
      // send the request to the backend
      if (isUndefined(cachedResp)) {
        var xsrfValue = urlIsSameOrigin(config.url)
            ? $browser.cookies()[config.xsrfCookieName || defaults.xsrfCookieName]
            : undefined;
        if (xsrfValue) {
          reqHeaders[(config.xsrfHeaderName || defaults.xsrfHeaderName)] = xsrfValue;
        }

        $httpBackend(config.method, url, reqData, done, reqHeaders, config.timeout,
            config.withCredentials, config.responseType);
      }

      return promise;


      /**
       * Callback registered to $httpBackend():
       *  - caches the response if desired
       *  - resolves the raw $http promise
       *  - calls $apply
       */
      function done(status, response, headersString, statusText) {
        if (cache) {
          if (isSuccess(status)) {
            cache.put(url, [status, response, parseHeaders(headersString), statusText]);
          } else {
            // remove promise from the cache
            cache.remove(url);
          }
        }

        function resolveHttpPromise() {
          resolvePromise(response, status, headersString, statusText);
        }

        if (useApplyAsync) {
          $rootScope.$applyAsync(resolveHttpPromise);
        } else {
          resolveHttpPromise();
          if (!$rootScope.$$phase) $rootScope.$apply();
        }
      }


      /**
       * Resolves the raw $http promise.
       */
      function resolvePromise(response, status, headers, statusText) {
        //status: HTTP response status code, 0, -1 (aborted by timeout / promise)
        status = status >= -1 ? status : 0;

        (isSuccess(status) ? deferred.resolve : deferred.reject)({
          data: response,
          status: status,
          headers: headersGetter(headers),
          config: config,
          statusText: statusText
        });
      }

      function resolvePromiseWithResult(result) {
        resolvePromise(result.data, result.status, shallowCopy(result.headers()), result.statusText);
      }

      function removePendingReq() {
        var idx = $http.pendingRequests.indexOf(config);
        if (idx !== -1) $http.pendingRequests.splice(idx, 1);
      }
    }


    function buildUrl(url, params) {
      if (!params) return url;
      var parts = [];
      forEachSorted(params, function(value, key) {
        if (value === null || isUndefined(value)) return;
        if (!isArray(value)) value = [value];

        forEach(value, function(v) {
          if (isObject(v)) {
            if (isDate(v)) {
              v = v.toISOString();
            } else {
              v = toJson(v);
            }
          }
          parts.push(encodeUriQuery(key) + '=' +
                     encodeUriQuery(v));
        });
      });
      if (parts.length > 0) {
        url += ((url.indexOf('?') == -1) ? '?' : '&') + parts.join('&');
      }
      return url;
    }
  }];
}

function createXhr() {
    return new window.XMLHttpRequest();
}

/**
 * @ngdoc service
 * @name $httpBackend
 * @requires $window
 * @requires $document
 *
 * @description
 * HTTP backend used by the {@link ng.$http service} that delegates to
 * XMLHttpRequest object or JSONP and deals with browser incompatibilities.
 *
 * You should never need to use this service directly, instead use the higher-level abstractions:
 * {@link ng.$http $http} or {@link ngResource.$resource $resource}.
 *
 * During testing this implementation is swapped with {@link ngMock.$httpBackend mock
 * $httpBackend} which can be trained with responses.
 */
function $HttpBackendProvider() {
  this.$get = ['$browser', '$window', '$document', function($browser, $window, $document) {
    return createHttpBackend($browser, createXhr, $browser.defer, $window.angular.callbacks, $document[0]);
  }];
}

function createHttpBackend($browser, createXhr, $browserDefer, callbacks, rawDocument) {
  // TODO(vojta): fix the signature
  return function(method, url, post, callback, headers, timeout, withCredentials, responseType) {
    $browser.$$incOutstandingRequestCount();
    url = url || $browser.url();

    if (lowercase(method) == 'jsonp') {
      var callbackId = '_' + (callbacks.counter++).toString(36);
      callbacks[callbackId] = function(data) {
        callbacks[callbackId].data = data;
        callbacks[callbackId].called = true;
      };

      var jsonpDone = jsonpReq(url.replace('JSON_CALLBACK', 'angular.callbacks.' + callbackId),
          callbackId, function(status, text) {
        completeRequest(callback, status, callbacks[callbackId].data, "", text);
        callbacks[callbackId] = noop;
      });
    } else {

      var xhr = createXhr();

      xhr.open(method, url, true);
      forEach(headers, function(value, key) {
        if (isDefined(value)) {
            xhr.setRequestHeader(key, value);
        }
      });

      xhr.onload = function requestLoaded() {
        var statusText = xhr.statusText || '';

        // responseText is the old-school way of retrieving response (supported by IE9)
        // response/responseType properties were introduced in XHR Level2 spec (supported by IE10)
        var response = ('response' in xhr) ? xhr.response : xhr.responseText;

        // normalize IE9 bug (http://bugs.jquery.com/ticket/1450)
        var status = xhr.status === 1223 ? 204 : xhr.status;

        // fix status code when it is 0 (0 status is undocumented).
        // Occurs when accessing file resources or on Android 4.1 stock browser
        // while retrieving files from application cache.
        if (status === 0) {
          status = response ? 200 : urlResolve(url).protocol == 'file' ? 404 : 0;
        }

        completeRequest(callback,
            status,
            response,
            xhr.getAllResponseHeaders(),
            statusText);
      };

      var requestError = function() {
        // The response is always empty
        // See https://xhr.spec.whatwg.org/#request-error-steps and https://fetch.spec.whatwg.org/#concept-network-error
        completeRequest(callback, -1, null, null, '');
      };

      xhr.onerror = requestError;
      xhr.onabort = requestError;

      if (withCredentials) {
        xhr.withCredentials = true;
      }

      if (responseType) {
        try {
          xhr.responseType = responseType;
        } catch (e) {
          // WebKit added support for the json responseType value on 09/03/2013
          // https://bugs.webkit.org/show_bug.cgi?id=73648. Versions of Safari prior to 7 are
          // known to throw when setting the value "json" as the response type. Other older
          // browsers implementing the responseType
          //
          // The json response type can be ignored if not supported, because JSON payloads are
          // parsed on the client-side regardless.
          if (responseType !== 'json') {
            throw e;
          }
        }
      }

      xhr.send(post || null);
    }

    if (timeout > 0) {
      var timeoutId = $browserDefer(timeoutRequest, timeout);
    } else if (isPromiseLike(timeout)) {
      timeout.then(timeoutRequest);
    }


    function timeoutRequest() {
      jsonpDone && jsonpDone();
      xhr && xhr.abort();
    }

    function completeRequest(callback, status, response, headersString, statusText) {
      // cancel timeout and subsequent timeout promise resolution
      if (timeoutId !== undefined) {
        $browserDefer.cancel(timeoutId);
      }
      jsonpDone = xhr = null;

      callback(status, response, headersString, statusText);
      $browser.$$completeOutstandingRequest(noop);
    }
  };

  function jsonpReq(url, callbackId, done) {
    // we can't use jQuery/jqLite here because jQuery does crazy stuff with script elements, e.g.:
    // - fetches local scripts via XHR and evals them
    // - adds and immediately removes script elements from the document
    var script = rawDocument.createElement('script'), callback = null;
    script.type = "text/javascript";
    script.src = url;
    script.async = true;

    callback = function(event) {
      removeEventListenerFn(script, "load", callback);
      removeEventListenerFn(script, "error", callback);
      rawDocument.body.removeChild(script);
      script = null;
      var status = -1;
      var text = "unknown";

      if (event) {
        if (event.type === "load" && !callbacks[callbackId].called) {
          event = { type: "error" };
        }
        text = event.type;
        status = event.type === "error" ? 404 : 200;
      }

      if (done) {
        done(status, text);
      }
    };

    addEventListenerFn(script, "load", callback);
    addEventListenerFn(script, "error", callback);
    rawDocument.body.appendChild(script);
    return callback;
  }
}

var $interpolateMinErr = minErr('$interpolate');

/**
 * @ngdoc provider
 * @name $interpolateProvider
 *
 * @description
 *
 * Used for configuring the interpolation markup. Defaults to `{{` and `}}`.
 *
 * @example
<example module="customInterpolationApp">
<file name="index.html">
<script>
  var customInterpolationApp = angular.module('customInterpolationApp', []);

  customInterpolationApp.config(function($interpolateProvider) {
    $interpolateProvider.startSymbol('//');
    $interpolateProvider.endSymbol('//');
  });


  customInterpolationApp.controller('DemoController', function() {
      this.label = "This binding is brought you by // interpolation symbols.";
  });
</script>
<div ng-app="App" ng-controller="DemoController as demo">
    //demo.label//
</div>
</file>
<file name="protractor.js" type="protractor">
  it('should interpolate binding with custom symbols', function() {
    expect(element(by.binding('demo.label')).getText()).toBe('This binding is brought you by // interpolation symbols.');
  });
</file>
</example>
 */
function $InterpolateProvider() {
  var startSymbol = '{{';
  var endSymbol = '}}';

  /**
   * @ngdoc method
   * @name $interpolateProvider#startSymbol
   * @description
   * Symbol to denote start of expression in the interpolated string. Defaults to `{{`.
   *
   * @param {string=} value new value to set the starting symbol to.
   * @returns {string|self} Returns the symbol when used as getter and self if used as setter.
   */
  this.startSymbol = function(value) {
    if (value) {
      startSymbol = value;
      return this;
    } else {
      return startSymbol;
    }
  };

  /**
   * @ngdoc method
   * @name $interpolateProvider#endSymbol
   * @description
   * Symbol to denote the end of expression in the interpolated string. Defaults to `}}`.
   *
   * @param {string=} value new value to set the ending symbol to.
   * @returns {string|self} Returns the symbol when used as getter and self if used as setter.
   */
  this.endSymbol = function(value) {
    if (value) {
      endSymbol = value;
      return this;
    } else {
      return endSymbol;
    }
  };


  this.$get = ['$parse', '$exceptionHandler', '$sce', function($parse, $exceptionHandler, $sce) {
    var startSymbolLength = startSymbol.length,
        endSymbolLength = endSymbol.length,
        escapedStartRegexp = new RegExp(startSymbol.replace(/./g, escape), 'g'),
        escapedEndRegexp = new RegExp(endSymbol.replace(/./g, escape), 'g');

    function escape(ch) {
      return '\\\\\\' + ch;
    }

    /**
     * @ngdoc service
     * @name $interpolate
     * @kind function
     *
     * @requires $parse
     * @requires $sce
     *
     * @description
     *
     * Compiles a string with markup into an interpolation function. This service is used by the
     * HTML {@link ng.$compile $compile} service for data binding. See
     * {@link ng.$interpolateProvider $interpolateProvider} for configuring the
     * interpolation markup.
     *
     *
     * ```js
     *   var $interpolate = ...; // injected
     *   var exp = $interpolate('Hello {{name | uppercase}}!');
     *   expect(exp({name:'Angular'}).toEqual('Hello ANGULAR!');
     * ```
     *
     * `$interpolate` takes an optional fourth argument, `allOrNothing`. If `allOrNothing` is
     * `true`, the interpolation function will return `undefined` unless all embedded expressions
     * evaluate to a value other than `undefined`.
     *
     * ```js
     *   var $interpolate = ...; // injected
     *   var context = {greeting: 'Hello', name: undefined };
     *
     *   // default "forgiving" mode
     *   var exp = $interpolate('{{greeting}} {{name}}!');
     *   expect(exp(context)).toEqual('Hello !');
     *
     *   // "allOrNothing" mode
     *   exp = $interpolate('{{greeting}} {{name}}!', false, null, true);
     *   expect(exp(context)).toBeUndefined();
     *   context.name = 'Angular';
     *   expect(exp(context)).toEqual('Hello Angular!');
     * ```
     *
     * `allOrNothing` is useful for interpolating URLs. `ngSrc` and `ngSrcset` use this behavior.
     *
     * ####Escaped Interpolation
     * $interpolate provides a mechanism for escaping interpolation markers. Start and end markers
     * can be escaped by preceding each of their characters with a REVERSE SOLIDUS U+005C (backslash).
     * It will be rendered as a regular start/end marker, and will not be interpreted as an expression
     * or binding.
     *
     * This enables web-servers to prevent script injection attacks and defacing attacks, to some
     * degree, while also enabling code examples to work without relying on the
     * {@link ng.directive:ngNonBindable ngNonBindable} directive.
     *
     * **For security purposes, it is strongly encouraged that web servers escape user-supplied data,
     * replacing angle brackets (&lt;, &gt;) with &amp;lt; and &amp;gt; respectively, and replacing all
     * interpolation start/end markers with their escaped counterparts.**
     *
     * Escaped interpolation markers are only replaced with the actual interpolation markers in rendered
     * output when the $interpolate service processes the text. So, for HTML elements interpolated
     * by {@link ng.$compile $compile}, or otherwise interpolated with the `mustHaveExpression` parameter
     * set to `true`, the interpolated text must contain an unescaped interpolation expression. As such,
     * this is typically useful only when user-data is used in rendering a template from the server, or
     * when otherwise untrusted data is used by a directive.
     *
     * <example>
     *  <file name="index.html">
     *    <div ng-init="username='A user'">
     *      <p ng-init="apptitle='Escaping demo'">{{apptitle}}: \{\{ username = "defaced value"; \}\}
     *        </p>
     *      <p><strong>{{username}}</strong> attempts to inject code which will deface the
     *        application, but fails to accomplish their task, because the server has correctly
     *        escaped the interpolation start/end markers with REVERSE SOLIDUS U+005C (backslash)
     *        characters.</p>
     *      <p>Instead, the result of the attempted script injection is visible, and can be removed
     *        from the database by an administrator.</p>
     *    </div>
     *  </file>
     * </example>
     *
     * @param {string} text The text with markup to interpolate.
     * @param {boolean=} mustHaveExpression if set to true then the interpolation string must have
     *    embedded expression in order to return an interpolation function. Strings with no
     *    embedded expression will return null for the interpolation function.
     * @param {string=} trustedContext when provided, the returned function passes the interpolated
     *    result through {@link ng.$sce#getTrusted $sce.getTrusted(interpolatedResult,
     *    trustedContext)} before returning it.  Refer to the {@link ng.$sce $sce} service that
     *    provides Strict Contextual Escaping for details.
     * @param {boolean=} allOrNothing if `true`, then the returned function returns undefined
     *    unless all embedded expressions evaluate to a value other than `undefined`.
     * @returns {function(context)} an interpolation function which is used to compute the
     *    interpolated string. The function has these parameters:
     *
     * - `context`: evaluation context for all expressions embedded in the interpolated text
     */
    function $interpolate(text, mustHaveExpression, trustedContext, allOrNothing) {
      allOrNothing = !!allOrNothing;
      var startIndex,
          endIndex,
          index = 0,
          expressions = [],
          parseFns = [],
          textLength = text.length,
          exp,
          concat = [],
          expressionPositions = [];

      while (index < textLength) {
        if (((startIndex = text.indexOf(startSymbol, index)) != -1) &&
             ((endIndex = text.indexOf(endSymbol, startIndex + startSymbolLength)) != -1)) {
          if (index !== startIndex) {
            concat.push(unescapeText(text.substring(index, startIndex)));
          }
          exp = text.substring(startIndex + startSymbolLength, endIndex);
          expressions.push(exp);
          parseFns.push($parse(exp, parseStringifyInterceptor));
          index = endIndex + endSymbolLength;
          expressionPositions.push(concat.length);
          concat.push('');
        } else {
          // we did not find an interpolation, so we have to add the remainder to the separators array
          if (index !== textLength) {
            concat.push(unescapeText(text.substring(index)));
          }
          break;
        }
      }

      // Concatenating expressions makes it hard to reason about whether some combination of
      // concatenated values are unsafe to use and could easily lead to XSS.  By requiring that a
      // single expression be used for iframe[src], object[src], etc., we ensure that the value
      // that's used is assigned or constructed by some JS code somewhere that is more testable or
      // make it obvious that you bound the value to some user controlled value.  This helps reduce
      // the load when auditing for XSS issues.
      if (trustedContext && concat.length > 1) {
          throw $interpolateMinErr('noconcat',
              "Error while interpolating: {0}\nStrict Contextual Escaping disallows " +
              "interpolations that concatenate multiple expressions when a trusted value is " +
              "required.  See http://docs.angularjs.org/api/ng.$sce", text);
      }

      if (!mustHaveExpression || expressions.length) {
        var compute = function(values) {
          for (var i = 0, ii = expressions.length; i < ii; i++) {
            if (allOrNothing && isUndefined(values[i])) return;
            concat[expressionPositions[i]] = values[i];
          }
          return concat.join('');
        };

        var getValue = function(value) {
          return trustedContext ?
            $sce.getTrusted(trustedContext, value) :
            $sce.valueOf(value);
        };

        var stringify = function(value) {
          if (value == null) { // null || undefined
            return '';
          }
          switch (typeof value) {
            case 'string':
              break;
            case 'number':
              value = '' + value;
              break;
            default:
              value = toJson(value);
          }

          return value;
        };

        return extend(function interpolationFn(context) {
            var i = 0;
            var ii = expressions.length;
            var values = new Array(ii);

            try {
              for (; i < ii; i++) {
                values[i] = parseFns[i](context);
              }

              return compute(values);
            } catch (err) {
              var newErr = $interpolateMinErr('interr', "Can't interpolate: {0}\n{1}", text,
                  err.toString());
              $exceptionHandler(newErr);
            }

          }, {
          // all of these properties are undocumented for now
          exp: text, //just for compatibility with regular watchers created via $watch
          expressions: expressions,
          $$watchDelegate: function(scope, listener, objectEquality) {
            var lastValue;
            return scope.$watchGroup(parseFns, function interpolateFnWatcher(values, oldValues) {
              var currValue = compute(values);
              if (isFunction(listener)) {
                listener.call(this, currValue, values !== oldValues ? lastValue : currValue, scope);
              }
              lastValue = currValue;
            }, objectEquality);
          }
        });
      }

      function unescapeText(text) {
        return text.replace(escapedStartRegexp, startSymbol).
          replace(escapedEndRegexp, endSymbol);
      }

      function parseStringifyInterceptor(value) {
        try {
          value = getValue(value);
          return allOrNothing && !isDefined(value) ? value : stringify(value);
        } catch (err) {
          var newErr = $interpolateMinErr('interr', "Can't interpolate: {0}\n{1}", text,
            err.toString());
          $exceptionHandler(newErr);
        }
      }
    }


    /**
     * @ngdoc method
     * @name $interpolate#startSymbol
     * @description
     * Symbol to denote the start of expression in the interpolated string. Defaults to `{{`.
     *
     * Use {@link ng.$interpolateProvider#startSymbol `$interpolateProvider.startSymbol`} to change
     * the symbol.
     *
     * @returns {string} start symbol.
     */
    $interpolate.startSymbol = function() {
      return startSymbol;
    };


    /**
     * @ngdoc method
     * @name $interpolate#endSymbol
     * @description
     * Symbol to denote the end of expression in the interpolated string. Defaults to `}}`.
     *
     * Use {@link ng.$interpolateProvider#endSymbol `$interpolateProvider.endSymbol`} to change
     * the symbol.
     *
     * @returns {string} end symbol.
     */
    $interpolate.endSymbol = function() {
      return endSymbol;
    };

    return $interpolate;
  }];
}

function $IntervalProvider() {
  this.$get = ['$rootScope', '$window', '$q', '$$q',
       function($rootScope,   $window,   $q,   $$q) {
    var intervals = {};


     /**
      * @ngdoc service
      * @name $interval
      *
      * @description
      * Angular's wrapper for `window.setInterval`. The `fn` function is executed every `delay`
      * milliseconds.
      *
      * The return value of registering an interval function is a promise. This promise will be
      * notified upon each tick of the interval, and will be resolved after `count` iterations, or
      * run indefinitely if `count` is not defined. The value of the notification will be the
      * number of iterations that have run.
      * To cancel an interval, call `$interval.cancel(promise)`.
      *
      * In tests you can use {@link ngMock.$interval#flush `$interval.flush(millis)`} to
      * move forward by `millis` milliseconds and trigger any functions scheduled to run in that
      * time.
      *
      * <div class="alert alert-warning">
      * **Note**: Intervals created by this service must be explicitly destroyed when you are finished
      * with them.  In particular they are not automatically destroyed when a controller's scope or a
      * directive's element are destroyed.
      * You should take this into consideration and make sure to always cancel the interval at the
      * appropriate moment.  See the example below for more details on how and when to do this.
      * </div>
      *
      * @param {function()} fn A function that should be called repeatedly.
      * @param {number} delay Number of milliseconds between each function call.
      * @param {number=} [count=0] Number of times to repeat. If not set, or 0, will repeat
      *   indefinitely.
      * @param {boolean=} [invokeApply=true] If set to `false` skips model dirty checking, otherwise
      *   will invoke `fn` within the {@link ng.$rootScope.Scope#$apply $apply} block.
      * @returns {promise} A promise which will be notified on each iteration.
      *
      * @example
      * <example module="intervalExample">
      * <file name="index.html">
      *   <script>
      *     angular.module('intervalExample', [])
      *       .controller('ExampleController', ['$scope', '$interval',
      *         function($scope, $interval) {
      *           $scope.format = 'M/d/yy h:mm:ss a';
      *           $scope.blood_1 = 100;
      *           $scope.blood_2 = 120;
      *
      *           var stop;
      *           $scope.fight = function() {
      *             // Don't start a new fight if we are already fighting
      *             if ( angular.isDefined(stop) ) return;
      *
      *             stop = $interval(function() {
      *               if ($scope.blood_1 > 0 && $scope.blood_2 > 0) {
      *                 $scope.blood_1 = $scope.blood_1 - 3;
      *                 $scope.blood_2 = $scope.blood_2 - 4;
      *               } else {
      *                 $scope.stopFight();
      *               }
      *             }, 100);
      *           };
      *
      *           $scope.stopFight = function() {
      *             if (angular.isDefined(stop)) {
      *               $interval.cancel(stop);
      *               stop = undefined;
      *             }
      *           };
      *
      *           $scope.resetFight = function() {
      *             $scope.blood_1 = 100;
      *             $scope.blood_2 = 120;
      *           };
      *
      *           $scope.$on('$destroy', function() {
      *             // Make sure that the interval is destroyed too
      *             $scope.stopFight();
      *           });
      *         }])
      *       // Register the 'myCurrentTime' directive factory method.
      *       // We inject $interval and dateFilter service since the factory method is DI.
      *       .directive('myCurrentTime', ['$interval', 'dateFilter',
      *         function($interval, dateFilter) {
      *           // return the directive link function. (compile function not needed)
      *           return function(scope, element, attrs) {
      *             var format,  // date format
      *                 stopTime; // so that we can cancel the time updates
      *
      *             // used to update the UI
      *             function updateTime() {
      *               element.text(dateFilter(new Date(), format));
      *             }
      *
      *             // watch the expression, and update the UI on change.
      *             scope.$watch(attrs.myCurrentTime, function(value) {
      *               format = value;
      *               updateTime();
      *             });
      *
      *             stopTime = $interval(updateTime, 1000);
      *
      *             // listen on DOM destroy (removal) event, and cancel the next UI update
      *             // to prevent updating time after the DOM element was removed.
      *             element.on('$destroy', function() {
      *               $interval.cancel(stopTime);
      *             });
      *           }
      *         }]);
      *   </script>
      *
      *   <div>
      *     <div ng-controller="ExampleController">
      *       Date format: <input ng-model="format"> <hr/>
      *       Current time is: <span my-current-time="format"></span>
      *       <hr/>
      *       Blood 1 : <font color='red'>{{blood_1}}</font>
      *       Blood 2 : <font color='red'>{{blood_2}}</font>
      *       <button type="button" data-ng-click="fight()">Fight</button>
      *       <button type="button" data-ng-click="stopFight()">StopFight</button>
      *       <button type="button" data-ng-click="resetFight()">resetFight</button>
      *     </div>
      *   </div>
      *
      * </file>
      * </example>
      */
    function interval(fn, delay, count, invokeApply) {
      var setInterval = $window.setInterval,
          clearInterval = $window.clearInterval,
          iteration = 0,
          skipApply = (isDefined(invokeApply) && !invokeApply),
          deferred = (skipApply ? $$q : $q).defer(),
          promise = deferred.promise;

      count = isDefined(count) ? count : 0;

      promise.then(null, null, fn);

      promise.$$intervalId = setInterval(function tick() {
        deferred.notify(iteration++);

        if (count > 0 && iteration >= count) {
          deferred.resolve(iteration);
          clearInterval(promise.$$intervalId);
          delete intervals[promise.$$intervalId];
        }

        if (!skipApply) $rootScope.$apply();

      }, delay);

      intervals[promise.$$intervalId] = deferred;

      return promise;
    }


     /**
      * @ngdoc method
      * @name $interval#cancel
      *
      * @description
      * Cancels a task associated with the `promise`.
      *
      * @param {promise} promise returned by the `$interval` function.
      * @returns {boolean} Returns `true` if the task was successfully canceled.
      */
    interval.cancel = function(promise) {
      if (promise && promise.$$intervalId in intervals) {
        intervals[promise.$$intervalId].reject('canceled');
        $window.clearInterval(promise.$$intervalId);
        delete intervals[promise.$$intervalId];
        return true;
      }
      return false;
    };

    return interval;
  }];
}

/**
 * @ngdoc service
 * @name $locale
 *
 * @description
 * $locale service provides localization rules for various Angular components. As of right now the
 * only public api is:
 *
 * * `id` – `{string}` – locale id formatted as `languageId-countryId` (e.g. `en-us`)
 */
function $LocaleProvider() {
  this.$get = function() {
    return {
      id: 'en-us',

      NUMBER_FORMATS: {
        DECIMAL_SEP: '.',
        GROUP_SEP: ',',
        PATTERNS: [
          { // Decimal Pattern
            minInt: 1,
            minFrac: 0,
            maxFrac: 3,
            posPre: '',
            posSuf: '',
            negPre: '-',
            negSuf: '',
            gSize: 3,
            lgSize: 3
          },{ //Currency Pattern
            minInt: 1,
            minFrac: 2,
            maxFrac: 2,
            posPre: '\u00A4',
            posSuf: '',
            negPre: '(\u00A4',
            negSuf: ')',
            gSize: 3,
            lgSize: 3
          }
        ],
        CURRENCY_SYM: '$'
      },

      DATETIME_FORMATS: {
        MONTH:
            'January,February,March,April,May,June,July,August,September,October,November,December'
            .split(','),
        SHORTMONTH:  'Jan,Feb,Mar,Apr,May,Jun,Jul,Aug,Sep,Oct,Nov,Dec'.split(','),
        DAY: 'Sunday,Monday,Tuesday,Wednesday,Thursday,Friday,Saturday'.split(','),
        SHORTDAY: 'Sun,Mon,Tue,Wed,Thu,Fri,Sat'.split(','),
        AMPMS: ['AM','PM'],
        medium: 'MMM d, y h:mm:ss a',
        'short': 'M/d/yy h:mm a',
        fullDate: 'EEEE, MMMM d, y',
        longDate: 'MMMM d, y',
        mediumDate: 'MMM d, y',
        shortDate: 'M/d/yy',
        mediumTime: 'h:mm:ss a',
        shortTime: 'h:mm a',
        ERANAMES: [
          "Before Christ",
          "Anno Domini"
        ],
        ERAS: [
          "BC",
          "AD"
        ]
      },

      pluralCat: function(num) {
        if (num === 1) {
          return 'one';
        }
        return 'other';
      }
    };
  };
}

var PATH_MATCH = /^([^\?#]*)(\?([^#]*))?(#(.*))?$/,
    DEFAULT_PORTS = {'http': 80, 'https': 443, 'ftp': 21};
var $locationMinErr = minErr('$location');


/**
 * Encode path using encodeUriSegment, ignoring forward slashes
 *
 * @param {string} path Path to encode
 * @returns {string}
 */
function encodePath(path) {
  var segments = path.split('/'),
      i = segments.length;

  while (i--) {
    segments[i] = encodeUriSegment(segments[i]);
  }

  return segments.join('/');
}

function parseAbsoluteUrl(absoluteUrl, locationObj) {
  var parsedUrl = urlResolve(absoluteUrl);

  locationObj.$$protocol = parsedUrl.protocol;
  locationObj.$$host = parsedUrl.hostname;
  locationObj.$$port = int(parsedUrl.port) || DEFAULT_PORTS[parsedUrl.protocol] || null;
}


function parseAppUrl(relativeUrl, locationObj) {
  var prefixed = (relativeUrl.charAt(0) !== '/');
  if (prefixed) {
    relativeUrl = '/' + relativeUrl;
  }
  var match = urlResolve(relativeUrl);
  locationObj.$$path = decodeURIComponent(prefixed && match.pathname.charAt(0) === '/' ?
      match.pathname.substring(1) : match.pathname);
  locationObj.$$search = parseKeyValue(match.search);
  locationObj.$$hash = decodeURIComponent(match.hash);

  // make sure path starts with '/';
  if (locationObj.$$path && locationObj.$$path.charAt(0) != '/') {
    locationObj.$$path = '/' + locationObj.$$path;
  }
}


/**
 *
 * @param {string} begin
 * @param {string} whole
 * @returns {string} returns text from whole after begin or undefined if it does not begin with
 *                   expected string.
 */
function beginsWith(begin, whole) {
  if (whole.indexOf(begin) === 0) {
    return whole.substr(begin.length);
  }
}


function stripHash(url) {
  var index = url.indexOf('#');
  return index == -1 ? url : url.substr(0, index);
}

function trimEmptyHash(url) {
  return url.replace(/(#.+)|#$/, '$1');
}


function stripFile(url) {
  return url.substr(0, stripHash(url).lastIndexOf('/') + 1);
}

/* return the server only (scheme://host:port) */
function serverBase(url) {
  return url.substring(0, url.indexOf('/', url.indexOf('//') + 2));
}


/**
 * LocationHtml5Url represents an url
 * This object is exposed as $location service when HTML5 mode is enabled and supported
 *
 * @constructor
 * @param {string} appBase application base URL
 * @param {string} appBaseNoFile application base URL stripped of any filename
 * @param {string} basePrefix url path prefix
 */
function LocationHtml5Url(appBase, appBaseNoFile, basePrefix) {
  this.$$html5 = true;
  basePrefix = basePrefix || '';
  parseAbsoluteUrl(appBase, this);


  /**
   * Parse given html5 (regular) url string into properties
   * @param {string} url HTML5 url
   * @private
   */
  this.$$parse = function(url) {
    var pathUrl = beginsWith(appBaseNoFile, url);
    if (!isString(pathUrl)) {
      throw $locationMinErr('ipthprfx', 'Invalid url "{0}", missing path prefix "{1}".', url,
          appBaseNoFile);
    }

    parseAppUrl(pathUrl, this);

    if (!this.$$path) {
      this.$$path = '/';
    }

    this.$$compose();
  };

  /**
   * Compose url and update `absUrl` property
   * @private
   */
  this.$$compose = function() {
    var search = toKeyValue(this.$$search),
        hash = this.$$hash ? '#' + encodeUriSegment(this.$$hash) : '';

    this.$$url = encodePath(this.$$path) + (search ? '?' + search : '') + hash;
    this.$$absUrl = appBaseNoFile + this.$$url.substr(1); // first char is always '/'
  };

  this.$$parseLinkUrl = function(url, relHref) {
    if (relHref && relHref[0] === '#') {
      // special case for links to hash fragments:
      // keep the old url and only replace the hash fragment
      this.hash(relHref.slice(1));
      return true;
    }
    var appUrl, prevAppUrl;
    var rewrittenUrl;

    if ((appUrl = beginsWith(appBase, url)) !== undefined) {
      prevAppUrl = appUrl;
      if ((appUrl = beginsWith(basePrefix, appUrl)) !== undefined) {
        rewrittenUrl = appBaseNoFile + (beginsWith('/', appUrl) || appUrl);
      } else {
        rewrittenUrl = appBase + prevAppUrl;
      }
    } else if ((appUrl = beginsWith(appBaseNoFile, url)) !== undefined) {
      rewrittenUrl = appBaseNoFile + appUrl;
    } else if (appBaseNoFile == url + '/') {
      rewrittenUrl = appBaseNoFile;
    }
    if (rewrittenUrl) {
      this.$$parse(rewrittenUrl);
    }
    return !!rewrittenUrl;
  };
}


/**
 * LocationHashbangUrl represents url
 * This object is exposed as $location service when developer doesn't opt into html5 mode.
 * It also serves as the base class for html5 mode fallback on legacy browsers.
 *
 * @constructor
 * @param {string} appBase application base URL
 * @param {string} appBaseNoFile application base URL stripped of any filename
 * @param {string} hashPrefix hashbang prefix
 */
function LocationHashbangUrl(appBase, appBaseNoFile, hashPrefix) {

  parseAbsoluteUrl(appBase, this);


  /**
   * Parse given hashbang url into properties
   * @param {string} url Hashbang url
   * @private
   */
  this.$$parse = function(url) {
    var withoutBaseUrl = beginsWith(appBase, url) || beginsWith(appBaseNoFile, url);
    var withoutHashUrl;

    if (!isUndefined(withoutBaseUrl) && withoutBaseUrl.charAt(0) === '#') {

      // The rest of the url starts with a hash so we have
      // got either a hashbang path or a plain hash fragment
      withoutHashUrl = beginsWith(hashPrefix, withoutBaseUrl);
      if (isUndefined(withoutHashUrl)) {
        // There was no hashbang prefix so we just have a hash fragment
        withoutHashUrl = withoutBaseUrl;
      }

    } else {
      // There was no hashbang path nor hash fragment:
      // If we are in HTML5 mode we use what is left as the path;
      // Otherwise we ignore what is left
      if (this.$$html5) {
        withoutHashUrl = withoutBaseUrl;
      } else {
        withoutHashUrl = '';
        if (isUndefined(withoutBaseUrl)) {
          appBase = url;
          this.replace();
        }
      }
    }

    parseAppUrl(withoutHashUrl, this);

    this.$$path = removeWindowsDriveName(this.$$path, withoutHashUrl, appBase);

    this.$$compose();

    /*
     * In Windows, on an anchor node on documents loaded from
     * the filesystem, the browser will return a pathname
     * prefixed with the drive name ('/C:/path') when a
     * pathname without a drive is set:
     *  * a.setAttribute('href', '/foo')
     *   * a.pathname === '/C:/foo' //true
     *
     * Inside of Angular, we're always using pathnames that
     * do not include drive names for routing.
     */
    function removeWindowsDriveName(path, url, base) {
      /*
      Matches paths for file protocol on windows,
      such as /C:/foo/bar, and captures only /foo/bar.
      */
      var windowsFilePathExp = /^\/[A-Z]:(\/.*)/;

      var firstPathSegmentMatch;

      //Get the relative path from the input URL.
      if (url.indexOf(base) === 0) {
        url = url.replace(base, '');
      }

      // The input URL intentionally contains a first path segment that ends with a colon.
      if (windowsFilePathExp.exec(url)) {
        return path;
      }

      firstPathSegmentMatch = windowsFilePathExp.exec(path);
      return firstPathSegmentMatch ? firstPathSegmentMatch[1] : path;
    }
  };

  /**
   * Compose hashbang url and update `absUrl` property
   * @private
   */
  this.$$compose = function() {
    var search = toKeyValue(this.$$search),
        hash = this.$$hash ? '#' + encodeUriSegment(this.$$hash) : '';

    this.$$url = encodePath(this.$$path) + (search ? '?' + search : '') + hash;
    this.$$absUrl = appBase + (this.$$url ? hashPrefix + this.$$url : '');
  };

  this.$$parseLinkUrl = function(url, relHref) {
    if (stripHash(appBase) == stripHash(url)) {
      this.$$parse(url);
      return true;
    }
    return false;
  };
}


/**
 * LocationHashbangUrl represents url
 * This object is exposed as $location service when html5 history api is enabled but the browser
 * does not support it.
 *
 * @constructor
 * @param {string} appBase application base URL
 * @param {string} appBaseNoFile application base URL stripped of any filename
 * @param {string} hashPrefix hashbang prefix
 */
function LocationHashbangInHtml5Url(appBase, appBaseNoFile, hashPrefix) {
  this.$$html5 = true;
  LocationHashbangUrl.apply(this, arguments);

  this.$$parseLinkUrl = function(url, relHref) {
    if (relHref && relHref[0] === '#') {
      // special case for links to hash fragments:
      // keep the old url and only replace the hash fragment
      this.hash(relHref.slice(1));
      return true;
    }

    var rewrittenUrl;
    var appUrl;

    if (appBase == stripHash(url)) {
      rewrittenUrl = url;
    } else if ((appUrl = beginsWith(appBaseNoFile, url))) {
      rewrittenUrl = appBase + hashPrefix + appUrl;
    } else if (appBaseNoFile === url + '/') {
      rewrittenUrl = appBaseNoFile;
    }
    if (rewrittenUrl) {
      this.$$parse(rewrittenUrl);
    }
    return !!rewrittenUrl;
  };

  this.$$compose = function() {
    var search = toKeyValue(this.$$search),
        hash = this.$$hash ? '#' + encodeUriSegment(this.$$hash) : '';

    this.$$url = encodePath(this.$$path) + (search ? '?' + search : '') + hash;
    // include hashPrefix in $$absUrl when $$url is empty so IE9 does not reload page because of removal of '#'
    this.$$absUrl = appBase + hashPrefix + this.$$url;
  };

}


var locationPrototype = {

  /**
   * Are we in html5 mode?
   * @private
   */
  $$html5: false,

  /**
   * Has any change been replacing?
   * @private
   */
  $$replace: false,

  /**
   * @ngdoc method
   * @name $location#absUrl
   *
   * @description
   * This method is getter only.
   *
   * Return full url representation with all segments encoded according to rules specified in
   * [RFC 3986](http://www.ietf.org/rfc/rfc3986.txt).
   *
   *
   * ```js
   * // given url http://example.com/#/some/path?foo=bar&baz=xoxo
   * var absUrl = $location.absUrl();
   * // => "http://example.com/#/some/path?foo=bar&baz=xoxo"
   * ```
   *
   * @return {string} full url
   */
  absUrl: locationGetter('$$absUrl'),

  /**
   * @ngdoc method
   * @name $location#url
   *
   * @description
   * This method is getter / setter.
   *
   * Return url (e.g. `/path?a=b#hash`) when called without any parameter.
   *
   * Change path, search and hash, when called with parameter and return `$location`.
   *
   *
   * ```js
   * // given url http://example.com/#/some/path?foo=bar&baz=xoxo
   * var url = $location.url();
   * // => "/some/path?foo=bar&baz=xoxo"
   * ```
   *
   * @param {string=} url New url without base prefix (e.g. `/path?a=b#hash`)
   * @return {string} url
   */
  url: function(url) {
    if (isUndefined(url))
      return this.$$url;

    var match = PATH_MATCH.exec(url);
    if (match[1] || url === '') this.path(decodeURIComponent(match[1]));
    if (match[2] || match[1] || url === '') this.search(match[3] || '');
    this.hash(match[5] || '');

    return this;
  },

  /**
   * @ngdoc method
   * @name $location#protocol
   *
   * @description
   * This method is getter only.
   *
   * Return protocol of current url.
   *
   *
   * ```js
   * // given url http://example.com/#/some/path?foo=bar&baz=xoxo
   * var protocol = $location.protocol();
   * // => "http"
   * ```
   *
   * @return {string} protocol of current url
   */
  protocol: locationGetter('$$protocol'),

  /**
   * @ngdoc method
   * @name $location#host
   *
   * @description
   * This method is getter only.
   *
   * Return host of current url.
   *
   * Note: compared to the non-angular version `location.host` which returns `hostname:port`, this returns the `hostname` portion only.
   *
   *
   * ```js
   * // given url http://example.com/#/some/path?foo=bar&baz=xoxo
   * var host = $location.host();
   * // => "example.com"
   *
   * // given url http://user:password@example.com:8080/#/some/path?foo=bar&baz=xoxo
   * host = $location.host();
   * // => "example.com"
   * host = location.host;
   * // => "example.com:8080"
   * ```
   *
   * @return {string} host of current url.
   */
  host: locationGetter('$$host'),

  /**
   * @ngdoc method
   * @name $location#port
   *
   * @description
   * This method is getter only.
   *
   * Return port of current url.
   *
   *
   * ```js
   * // given url http://example.com/#/some/path?foo=bar&baz=xoxo
   * var port = $location.port();
   * // => 80
   * ```
   *
   * @return {Number} port
   */
  port: locationGetter('$$port'),

  /**
   * @ngdoc method
   * @name $location#path
   *
   * @description
   * This method is getter / setter.
   *
   * Return path of current url when called without any parameter.
   *
   * Change path when called with parameter and return `$location`.
   *
   * Note: Path should always begin with forward slash (/), this method will add the forward slash
   * if it is missing.
   *
   *
   * ```js
   * // given url http://example.com/#/some/path?foo=bar&baz=xoxo
   * var path = $location.path();
   * // => "/some/path"
   * ```
   *
   * @param {(string|number)=} path New path
   * @return {string} path
   */
  path: locationGetterSetter('$$path', function(path) {
    path = path !== null ? path.toString() : '';
    return path.charAt(0) == '/' ? path : '/' + path;
  }),

  /**
   * @ngdoc method
   * @name $location#search
   *
   * @description
   * This method is getter / setter.
   *
   * Return search part (as object) of current url when called without any parameter.
   *
   * Change search part when called with parameter and return `$location`.
   *
   *
   * ```js
   * // given url http://example.com/#/some/path?foo=bar&baz=xoxo
   * var searchObject = $location.search();
   * // => {foo: 'bar', baz: 'xoxo'}
   *
   * // set foo to 'yipee'
   * $location.search('foo', 'yipee');
   * // $location.search() => {foo: 'yipee', baz: 'xoxo'}
   * ```
   *
   * @param {string|Object.<string>|Object.<Array.<string>>} search New search params - string or
   * hash object.
   *
   * When called with a single argument the method acts as a setter, setting the `search` component
   * of `$location` to the specified value.
   *
   * If the argument is a hash object containing an array of values, these values will be encoded
   * as duplicate search parameters in the url.
   *
   * @param {(string|Number|Array<string>|boolean)=} paramValue If `search` is a string or number, then `paramValue`
   * will override only a single search property.
   *
   * If `paramValue` is an array, it will override the property of the `search` component of
   * `$location` specified via the first argument.
   *
   * If `paramValue` is `null`, the property specified via the first argument will be deleted.
   *
   * If `paramValue` is `true`, the property specified via the first argument will be added with no
   * value nor trailing equal sign.
   *
   * @return {Object} If called with no arguments returns the parsed `search` object. If called with
   * one or more arguments returns `$location` object itself.
   */
  search: function(search, paramValue) {
    switch (arguments.length) {
      case 0:
        return this.$$search;
      case 1:
        if (isString(search) || isNumber(search)) {
          search = search.toString();
          this.$$search = parseKeyValue(search);
        } else if (isObject(search)) {
          search = copy(search, {});
          // remove object undefined or null properties
          forEach(search, function(value, key) {
            if (value == null) delete search[key];
          });

          this.$$search = search;
        } else {
          throw $locationMinErr('isrcharg',
              'The first argument of the `$location#search()` call must be a string or an object.');
        }
        break;
      default:
        if (isUndefined(paramValue) || paramValue === null) {
          delete this.$$search[search];
        } else {
          this.$$search[search] = paramValue;
        }
    }

    this.$$compose();
    return this;
  },

  /**
   * @ngdoc method
   * @name $location#hash
   *
   * @description
   * This method is getter / setter.
   *
   * Return hash fragment when called without any parameter.
   *
   * Change hash fragment when called with parameter and return `$location`.
   *
   *
   * ```js
   * // given url http://example.com/#/some/path?foo=bar&baz=xoxo#hashValue
   * var hash = $location.hash();
   * // => "hashValue"
   * ```
   *
   * @param {(string|number)=} hash New hash fragment
   * @return {string} hash
   */
  hash: locationGetterSetter('$$hash', function(hash) {
    return hash !== null ? hash.toString() : '';
  }),

  /**
   * @ngdoc method
   * @name $location#replace
   *
   * @description
   * If called, all changes to $location during current `$digest` will be replacing current history
   * record, instead of adding new one.
   */
  replace: function() {
    this.$$replace = true;
    return this;
  }
};

forEach([LocationHashbangInHtml5Url, LocationHashbangUrl, LocationHtml5Url], function(Location) {
  Location.prototype = Object.create(locationPrototype);

  /**
   * @ngdoc method
   * @name $location#state
   *
   * @description
   * This method is getter / setter.
   *
   * Return the history state object when called without any parameter.
   *
   * Change the history state object when called with one parameter and return `$location`.
   * The state object is later passed to `pushState` or `replaceState`.
   *
   * NOTE: This method is supported only in HTML5 mode and only in browsers supporting
   * the HTML5 History API (i.e. methods `pushState` and `replaceState`). If you need to support
   * older browsers (like IE9 or Android < 4.0), don't use this method.
   *
   * @param {object=} state State object for pushState or replaceState
   * @return {object} state
   */
  Location.prototype.state = function(state) {
    if (!arguments.length)
      return this.$$state;

    if (Location !== LocationHtml5Url || !this.$$html5) {
      throw $locationMinErr('nostate', 'History API state support is available only ' +
        'in HTML5 mode and only in browsers supporting HTML5 History API');
    }
    // The user might modify `stateObject` after invoking `$location.state(stateObject)`
    // but we're changing the $$state reference to $browser.state() during the $digest
    // so the modification window is narrow.
    this.$$state = isUndefined(state) ? null : state;

    return this;
  };
});


function locationGetter(property) {
  return function() {
    return this[property];
  };
}


function locationGetterSetter(property, preprocess) {
  return function(value) {
    if (isUndefined(value))
      return this[property];

    this[property] = preprocess(value);
    this.$$compose();

    return this;
  };
}


/**
 * @ngdoc service
 * @name $location
 *
 * @requires $rootElement
 *
 * @description
 * The $location service parses the URL in the browser address bar (based on the
 * [window.location](https://developer.mozilla.org/en/window.location)) and makes the URL
 * available to your application. Changes to the URL in the address bar are reflected into
 * $location service and changes to $location are reflected into the browser address bar.
 *
 * **The $location service:**
 *
 * - Exposes the current URL in the browser address bar, so you can
 *   - Watch and observe the URL.
 *   - Change the URL.
 * - Synchronizes the URL with the browser when the user
 *   - Changes the address bar.
 *   - Clicks the back or forward button (or clicks a History link).
 *   - Clicks on a link.
 * - Represents the URL object as a set of methods (protocol, host, port, path, search, hash).
 *
 * For more information see {@link guide/$location Developer Guide: Using $location}
 */

/**
 * @ngdoc provider
 * @name $locationProvider
 * @description
 * Use the `$locationProvider` to configure how the application deep linking paths are stored.
 */
function $LocationProvider() {
  var hashPrefix = '',
      html5Mode = {
        enabled: false,
        requireBase: true,
        rewriteLinks: true
      };

  /**
   * @ngdoc method
   * @name $locationProvider#hashPrefix
   * @description
   * @param {string=} prefix Prefix for hash part (containing path and search)
   * @returns {*} current value if used as getter or itself (chaining) if used as setter
   */
  this.hashPrefix = function(prefix) {
    if (isDefined(prefix)) {
      hashPrefix = prefix;
      return this;
    } else {
      return hashPrefix;
    }
  };

  /**
   * @ngdoc method
   * @name $locationProvider#html5Mode
   * @description
   * @param {(boolean|Object)=} mode If boolean, sets `html5Mode.enabled` to value.
   *   If object, sets `enabled`, `requireBase` and `rewriteLinks` to respective values. Supported
   *   properties:
   *   - **enabled** – `{boolean}` – (default: false) If true, will rely on `history.pushState` to
   *     change urls where supported. Will fall back to hash-prefixed paths in browsers that do not
   *     support `pushState`.
   *   - **requireBase** - `{boolean}` - (default: `true`) When html5Mode is enabled, specifies
   *     whether or not a <base> tag is required to be present. If `enabled` and `requireBase` are
   *     true, and a base tag is not present, an error will be thrown when `$location` is injected.
   *     See the {@link guide/$location $location guide for more information}
   *   - **rewriteLinks** - `{boolean}` - (default: `true`) When html5Mode is enabled,
   *     enables/disables url rewriting for relative links.
   *
   * @returns {Object} html5Mode object if used as getter or itself (chaining) if used as setter
   */
  this.html5Mode = function(mode) {
    if (isBoolean(mode)) {
      html5Mode.enabled = mode;
      return this;
    } else if (isObject(mode)) {

      if (isBoolean(mode.enabled)) {
        html5Mode.enabled = mode.enabled;
      }

      if (isBoolean(mode.requireBase)) {
        html5Mode.requireBase = mode.requireBase;
      }

      if (isBoolean(mode.rewriteLinks)) {
        html5Mode.rewriteLinks = mode.rewriteLinks;
      }

      return this;
    } else {
      return html5Mode;
    }
  };

  /**
   * @ngdoc event
   * @name $location#$locationChangeStart
   * @eventType broadcast on root scope
   * @description
   * Broadcasted before a URL will change.
   *
   * This change can be prevented by calling
   * `preventDefault` method of the event. See {@link ng.$rootScope.Scope#$on} for more
   * details about event object. Upon successful change
   * {@link ng.$location#$locationChangeSuccess $locationChangeSuccess} is fired.
   *
   * The `newState` and `oldState` parameters may be defined only in HTML5 mode and when
   * the browser supports the HTML5 History API.
   *
   * @param {Object} angularEvent Synthetic event object.
   * @param {string} newUrl New URL
   * @param {string=} oldUrl URL that was before it was changed.
   * @param {string=} newState New history state object
   * @param {string=} oldState History state object that was before it was changed.
   */

  /**
   * @ngdoc event
   * @name $location#$locationChangeSuccess
   * @eventType broadcast on root scope
   * @description
   * Broadcasted after a URL was changed.
   *
   * The `newState` and `oldState` parameters may be defined only in HTML5 mode and when
   * the browser supports the HTML5 History API.
   *
   * @param {Object} angularEvent Synthetic event object.
   * @param {string} newUrl New URL
   * @param {string=} oldUrl URL that was before it was changed.
   * @param {string=} newState New history state object
   * @param {string=} oldState History state object that was before it was changed.
   */

  this.$get = ['$rootScope', '$browser', '$sniffer', '$rootElement', '$window',
      function($rootScope, $browser, $sniffer, $rootElement, $window) {
    var $location,
        LocationMode,
        baseHref = $browser.baseHref(), // if base[href] is undefined, it defaults to ''
        initialUrl = $browser.url(),
        appBase;

    if (html5Mode.enabled) {
      if (!baseHref && html5Mode.requireBase) {
        throw $locationMinErr('nobase',
          "$location in HTML5 mode requires a <base> tag to be present!");
      }
      appBase = serverBase(initialUrl) + (baseHref || '/');
      LocationMode = $sniffer.history ? LocationHtml5Url : LocationHashbangInHtml5Url;
    } else {
      appBase = stripHash(initialUrl);
      LocationMode = LocationHashbangUrl;
    }
    var appBaseNoFile = stripFile(appBase);

    $location = new LocationMode(appBase, appBaseNoFile, '#' + hashPrefix);
    $location.$$parseLinkUrl(initialUrl, initialUrl);

    $location.$$state = $browser.state();

    var IGNORE_URI_REGEXP = /^\s*(javascript|mailto):/i;

    function setBrowserUrlWithFallback(url, replace, state) {
      var oldUrl = $location.url();
      var oldState = $location.$$state;
      try {
        $browser.url(url, replace, state);

        // Make sure $location.state() returns referentially identical (not just deeply equal)
        // state object; this makes possible quick checking if the state changed in the digest
        // loop. Checking deep equality would be too expensive.
        $location.$$state = $browser.state();
      } catch (e) {
        // Restore old values if pushState fails
        $location.url(oldUrl);
        $location.$$state = oldState;

        throw e;
      }
    }

    $rootElement.on('click', function(event) {
      // TODO(vojta): rewrite link when opening in new tab/window (in legacy browser)
      // currently we open nice url link and redirect then

      if (!html5Mode.rewriteLinks || event.ctrlKey || event.metaKey || event.shiftKey || event.which == 2 || event.button == 2) return;

      var elm = jqLite(event.target);

      // traverse the DOM up to find first A tag
      while (nodeName_(elm[0]) !== 'a') {
        // ignore rewriting if no A tag (reached root element, or no parent - removed from document)
        if (elm[0] === $rootElement[0] || !(elm = elm.parent())[0]) return;
      }

      var absHref = elm.prop('href');
      // get the actual href attribute - see
      // http://msdn.microsoft.com/en-us/library/ie/dd347148(v=vs.85).aspx
      var relHref = elm.attr('href') || elm.attr('xlink:href');

      if (isObject(absHref) && absHref.toString() === '[object SVGAnimatedString]') {
        // SVGAnimatedString.animVal should be identical to SVGAnimatedString.baseVal, unless during
        // an animation.
        absHref = urlResolve(absHref.animVal).href;
      }

      // Ignore when url is started with javascript: or mailto:
      if (IGNORE_URI_REGEXP.test(absHref)) return;

      if (absHref && !elm.attr('target') && !event.isDefaultPrevented()) {
        if ($location.$$parseLinkUrl(absHref, relHref)) {
          // We do a preventDefault for all urls that are part of the angular application,
          // in html5mode and also without, so that we are able to abort navigation without
          // getting double entries in the location history.
          event.preventDefault();
          // update location manually
          if ($location.absUrl() != $browser.url()) {
            $rootScope.$apply();
            // hack to work around FF6 bug 684208 when scenario runner clicks on links
            $window.angular['ff-684208-preventDefault'] = true;
          }
        }
      }
    });


    // rewrite hashbang url <> html5 url
    if (trimEmptyHash($location.absUrl()) != trimEmptyHash(initialUrl)) {
      $browser.url($location.absUrl(), true);
    }

    var initializing = true;

    // update $location when $browser url changes
    $browser.onUrlChange(function(newUrl, newState) {

      if (isUndefined(beginsWith(appBaseNoFile, newUrl))) {
        // If we are navigating outside of the app then force a reload
        $window.location.href = newUrl;
        return;
      }

      $rootScope.$evalAsync(function() {
        var oldUrl = $location.absUrl();
        var oldState = $location.$$state;
        var defaultPrevented;

        $location.$$parse(newUrl);
        $location.$$state = newState;

        defaultPrevented = $rootScope.$broadcast('$locationChangeStart', newUrl, oldUrl,
            newState, oldState).defaultPrevented;

        // if the location was changed by a `$locationChangeStart` handler then stop
        // processing this location change
        if ($location.absUrl() !== newUrl) return;

        if (defaultPrevented) {
          $location.$$parse(oldUrl);
          $location.$$state = oldState;
          setBrowserUrlWithFallback(oldUrl, false, oldState);
        } else {
          initializing = false;
          afterLocationChange(oldUrl, oldState);
        }
      });
      if (!$rootScope.$$phase) $rootScope.$digest();
    });

    // update browser
    $rootScope.$watch(function $locationWatch() {
      var oldUrl = trimEmptyHash($browser.url());
      var newUrl = trimEmptyHash($location.absUrl());
      var oldState = $browser.state();
      var currentReplace = $location.$$replace;
      var urlOrStateChanged = oldUrl !== newUrl ||
        ($location.$$html5 && $sniffer.history && oldState !== $location.$$state);

      if (initializing || urlOrStateChanged) {
        initializing = false;

        $rootScope.$evalAsync(function() {
          var newUrl = $location.absUrl();
          var defaultPrevented = $rootScope.$broadcast('$locationChangeStart', newUrl, oldUrl,
              $location.$$state, oldState).defaultPrevented;

          // if the location was changed by a `$locationChangeStart` handler then stop
          // processing this location change
          if ($location.absUrl() !== newUrl) return;

          if (defaultPrevented) {
            $location.$$parse(oldUrl);
            $location.$$state = oldState;
          } else {
            if (urlOrStateChanged) {
              setBrowserUrlWithFallback(newUrl, currentReplace,
                                        oldState === $location.$$state ? null : $location.$$state);
            }
            afterLocationChange(oldUrl, oldState);
          }
        });
      }

      $location.$$replace = false;

      // we don't need to return anything because $evalAsync will make the digest loop dirty when
      // there is a change
    });

    return $location;

    function afterLocationChange(oldUrl, oldState) {
      $rootScope.$broadcast('$locationChangeSuccess', $location.absUrl(), oldUrl,
        $location.$$state, oldState);
    }
}];
}

/**
 * @ngdoc service
 * @name $log
 * @requires $window
 *
 * @description
 * Simple service for logging. Default implementation safely writes the message
 * into the browser's console (if present).
 *
 * The main purpose of this service is to simplify debugging and troubleshooting.
 *
 * The default is to log `debug` messages. You can use
 * {@link ng.$logProvider ng.$logProvider#debugEnabled} to change this.
 *
 * @example
   <example module="logExample">
     <file name="script.js">
       angular.module('logExample', [])
         .controller('LogController', ['$scope', '$log', function($scope, $log) {
           $scope.$log = $log;
           $scope.message = 'Hello World!';
         }]);
     </file>
     <file name="index.html">
       <div ng-controller="LogController">
         <p>Reload this page with open console, enter text and hit the log button...</p>
         Message:
         <input type="text" ng-model="message"/>
         <button ng-click="$log.log(message)">log</button>
         <button ng-click="$log.warn(message)">warn</button>
         <button ng-click="$log.info(message)">info</button>
         <button ng-click="$log.error(message)">error</button>
         <button ng-click="$log.debug(message)">debug</button>
       </div>
     </file>
   </example>
 */

/**
 * @ngdoc provider
 * @name $logProvider
 * @description
 * Use the `$logProvider` to configure how the application logs messages
 */
function $LogProvider() {
  var debug = true,
      self = this;

  /**
   * @ngdoc method
   * @name $logProvider#debugEnabled
   * @description
   * @param {boolean=} flag enable or disable debug level messages
   * @returns {*} current value if used as getter or itself (chaining) if used as setter
   */
  this.debugEnabled = function(flag) {
    if (isDefined(flag)) {
      debug = flag;
    return this;
    } else {
      return debug;
    }
  };

  this.$get = ['$window', function($window) {
    return {
      /**
       * @ngdoc method
       * @name $log#log
       *
       * @description
       * Write a log message
       */
      log: consoleLog('log'),

      /**
       * @ngdoc method
       * @name $log#info
       *
       * @description
       * Write an information message
       */
      info: consoleLog('info'),

      /**
       * @ngdoc method
       * @name $log#warn
       *
       * @description
       * Write a warning message
       */
      warn: consoleLog('warn'),

      /**
       * @ngdoc method
       * @name $log#error
       *
       * @description
       * Write an error message
       */
      error: consoleLog('error'),

      /**
       * @ngdoc method
       * @name $log#debug
       *
       * @description
       * Write a debug message
       */
      debug: (function() {
        var fn = consoleLog('debug');

        return function() {
          if (debug) {
            fn.apply(self, arguments);
          }
        };
      }())
    };

    function formatError(arg) {
      if (arg instanceof Error) {
        if (arg.stack) {
          arg = (arg.message && arg.stack.indexOf(arg.message) === -1)
              ? 'Error: ' + arg.message + '\n' + arg.stack
              : arg.stack;
        } else if (arg.sourceURL) {
          arg = arg.message + '\n' + arg.sourceURL + ':' + arg.line;
        }
      }
      return arg;
    }

    function consoleLog(type) {
      var console = $window.console || {},
          logFn = console[type] || console.log || noop,
          hasApply = false;

      // Note: reading logFn.apply throws an error in IE11 in IE8 document mode.
      // The reason behind this is that console.log has type "object" in IE8...
      try {
        hasApply = !!logFn.apply;
      } catch (e) {}

      if (hasApply) {
        return function() {
          var args = [];
          forEach(arguments, function(arg) {
            args.push(formatError(arg));
          });
          return logFn.apply(console, args);
        };
      }

      // we are IE which either doesn't have window.console => this is noop and we do nothing,
      // or we are IE where console.log doesn't have apply so we log at least first 2 args
      return function(arg1, arg2) {
        logFn(arg1, arg2 == null ? '' : arg2);
      };
    }
  }];
}

/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
 *     Any commits to this file should be reviewed with security in mind.  *
 *   Changes to this file can potentially create security vulnerabilities. *
 *          An approval from 2 Core members with history of modifying      *
 *                         this file is required.                          *
 *                                                                         *
 *  Does the change somehow allow for arbitrary javascript to be executed? *
 *    Or allows for someone to change the prototype of built-in objects?   *
 *     Or gives undesired access to variables likes document or window?    *
 * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

var $parseMinErr = minErr('$parse');

// Sandboxing Angular Expressions
// ------------------------------
// Angular expressions are generally considered safe because these expressions only have direct
// access to `$scope` and locals. However, one can obtain the ability to execute arbitrary JS code by
// obtaining a reference to native JS functions such as the Function constructor.
//
// As an example, consider the following Angular expression:
//
//   {}.toString.constructor('alert("evil JS code")')
//
// This sandboxing technique is not perfect and doesn't aim to be. The goal is to prevent exploits
// against the expression language, but not to prevent exploits that were enabled by exposing
// sensitive JavaScript or browser APIs on Scope. Exposing such objects on a Scope is never a good
// practice and therefore we are not even trying to protect against interaction with an object
// explicitly exposed in this way.
//
// In general, it is not possible to access a Window object from an angular expression unless a
// window or some DOM object that has a reference to window is published onto a Scope.
// Similarly we prevent invocations of function known to be dangerous, as well as assignments to
// native objects.
//
// See https://docs.angularjs.org/guide/security


function ensureSafeMemberName(name, fullExpression) {
  if (name === "__defineGetter__" || name === "__defineSetter__"
      || name === "__lookupGetter__" || name === "__lookupSetter__"
      || name === "__proto__") {
    throw $parseMinErr('isecfld',
        'Attempting to access a disallowed field in Angular expressions! '
        + 'Expression: {0}', fullExpression);
  }
  return name;
}

function getStringValue(name, fullExpression) {
  // From the JavaScript docs:
  // Property names must be strings. This means that non-string objects cannot be used
  // as keys in an object. Any non-string object, including a number, is typecasted
  // into a string via the toString method.
  //
  // So, to ensure that we are checking the same `name` that JavaScript would use,
  // we cast it to a string, if possible.
  // Doing `name + ''` can cause a repl error if the result to `toString` is not a string,
  // this is, this will handle objects that misbehave.
  name = name + '';
  if (!isString(name)) {
    throw $parseMinErr('iseccst',
        'Cannot convert object to primitive value! '
        + 'Expression: {0}', fullExpression);
  }
  return name;
}

function ensureSafeObject(obj, fullExpression) {
  // nifty check if obj is Function that is fast and works across iframes and other contexts
  if (obj) {
    if (obj.constructor === obj) {
      throw $parseMinErr('isecfn',
          'Referencing Function in Angular expressions is disallowed! Expression: {0}',
          fullExpression);
    } else if (// isWindow(obj)
        obj.window === obj) {
      throw $parseMinErr('isecwindow',
          'Referencing the Window in Angular expressions is disallowed! Expression: {0}',
          fullExpression);
    } else if (// isElement(obj)
        obj.children && (obj.nodeName || (obj.prop && obj.attr && obj.find))) {
      throw $parseMinErr('isecdom',
          'Referencing DOM nodes in Angular expressions is disallowed! Expression: {0}',
          fullExpression);
    } else if (// block Object so that we can't get hold of dangerous Object.* methods
        obj === Object) {
      throw $parseMinErr('isecobj',
          'Referencing Object in Angular expressions is disallowed! Expression: {0}',
          fullExpression);
    }
  }
  return obj;
}

var CALL = Function.prototype.call;
var APPLY = Function.prototype.apply;
var BIND = Function.prototype.bind;

function ensureSafeFunction(obj, fullExpression) {
  if (obj) {
    if (obj.constructor === obj) {
      throw $parseMinErr('isecfn',
        'Referencing Function in Angular expressions is disallowed! Expression: {0}',
        fullExpression);
    } else if (obj === CALL || obj === APPLY || obj === BIND) {
      throw $parseMinErr('isecff',
        'Referencing call, apply or bind in Angular expressions is disallowed! Expression: {0}',
        fullExpression);
    }
  }
}

//Keyword constants
var CONSTANTS = createMap();
forEach({
  'null': function() { return null; },
  'true': function() { return true; },
  'false': function() { return false; },
  'undefined': function() {}
}, function(constantGetter, name) {
  constantGetter.constant = constantGetter.literal = constantGetter.sharedGetter = true;
  CONSTANTS[name] = constantGetter;
});

//Not quite a constant, but can be lex/parsed the same
CONSTANTS['this'] = function(self) { return self; };
CONSTANTS['this'].sharedGetter = true;


//Operators - will be wrapped by binaryFn/unaryFn/assignment/filter
var OPERATORS = extend(createMap(), {
    '+':function(self, locals, a, b) {
      a=a(self, locals); b=b(self, locals);
      if (isDefined(a)) {
        if (isDefined(b)) {
          return a + b;
        }
        return a;
      }
      return isDefined(b) ? b : undefined;},
    '-':function(self, locals, a, b) {
          a=a(self, locals); b=b(self, locals);
          return (isDefined(a) ? a : 0) - (isDefined(b) ? b : 0);
        },
    '*':function(self, locals, a, b) {return a(self, locals) * b(self, locals);},
    '/':function(self, locals, a, b) {return a(self, locals) / b(self, locals);},
    '%':function(self, locals, a, b) {return a(self, locals) % b(self, locals);},
    '===':function(self, locals, a, b) {return a(self, locals) === b(self, locals);},
    '!==':function(self, locals, a, b) {return a(self, locals) !== b(self, locals);},
    '==':function(self, locals, a, b) {return a(self, locals) == b(self, locals);},
    '!=':function(self, locals, a, b) {return a(self, locals) != b(self, locals);},
    '<':function(self, locals, a, b) {return a(self, locals) < b(self, locals);},
    '>':function(self, locals, a, b) {return a(self, locals) > b(self, locals);},
    '<=':function(self, locals, a, b) {return a(self, locals) <= b(self, locals);},
    '>=':function(self, locals, a, b) {return a(self, locals) >= b(self, locals);},
    '&&':function(self, locals, a, b) {return a(self, locals) && b(self, locals);},
    '||':function(self, locals, a, b) {return a(self, locals) || b(self, locals);},
    '!':function(self, locals, a) {return !a(self, locals);},

    //Tokenized as operators but parsed as assignment/filters
    '=':true,
    '|':true
});
var ESCAPE = {"n":"\n", "f":"\f", "r":"\r", "t":"\t", "v":"\v", "'":"'", '"':'"'};


/////////////////////////////////////////


/**
 * @constructor
 */
var Lexer = function(options) {
  this.options = options;
};

Lexer.prototype = {
  constructor: Lexer,

  lex: function(text) {
    this.text = text;
    this.index = 0;
    this.tokens = [];

    while (this.index < this.text.length) {
      var ch = this.text.charAt(this.index);
      if (ch === '"' || ch === "'") {
        this.readString(ch);
      } else if (this.isNumber(ch) || ch === '.' && this.isNumber(this.peek())) {
        this.readNumber();
      } else if (this.isIdent(ch)) {
        this.readIdent();
      } else if (this.is(ch, '(){}[].,;:?')) {
        this.tokens.push({index: this.index, text: ch});
        this.index++;
      } else if (this.isWhitespace(ch)) {
        this.index++;
      } else {
        var ch2 = ch + this.peek();
        var ch3 = ch2 + this.peek(2);
        var op1 = OPERATORS[ch];
        var op2 = OPERATORS[ch2];
        var op3 = OPERATORS[ch3];
        if (op1 || op2 || op3) {
          var token = op3 ? ch3 : (op2 ? ch2 : ch);
          this.tokens.push({index: this.index, text: token, operator: true});
          this.index += token.length;
        } else {
          this.throwError('Unexpected next character ', this.index, this.index + 1);
        }
      }
    }
    return this.tokens;
  },

  is: function(ch, chars) {
    return chars.indexOf(ch) !== -1;
  },

  peek: function(i) {
    var num = i || 1;
    return (this.index + num < this.text.length) ? this.text.charAt(this.index + num) : false;
  },

  isNumber: function(ch) {
    return ('0' <= ch && ch <= '9') && typeof ch === "string";
  },

  isWhitespace: function(ch) {
    // IE treats non-breaking space as \u00A0
    return (ch === ' ' || ch === '\r' || ch === '\t' ||
            ch === '\n' || ch === '\v' || ch === '\u00A0');
  },

  isIdent: function(ch) {
    return ('a' <= ch && ch <= 'z' ||
            'A' <= ch && ch <= 'Z' ||
            '_' === ch || ch === '$');
  },

  isExpOperator: function(ch) {
    return (ch === '-' || ch === '+' || this.isNumber(ch));
  },

  throwError: function(error, start, end) {
    end = end || this.index;
    var colStr = (isDefined(start)
            ? 's ' + start +  '-' + this.index + ' [' + this.text.substring(start, end) + ']'
            : ' ' + end);
    throw $parseMinErr('lexerr', 'Lexer Error: {0} at column{1} in expression [{2}].',
        error, colStr, this.text);
  },

  readNumber: function() {
    var number = '';
    var start = this.index;
    while (this.index < this.text.length) {
      var ch = lowercase(this.text.charAt(this.index));
      if (ch == '.' || this.isNumber(ch)) {
        number += ch;
      } else {
        var peekCh = this.peek();
        if (ch == 'e' && this.isExpOperator(peekCh)) {
          number += ch;
        } else if (this.isExpOperator(ch) &&
            peekCh && this.isNumber(peekCh) &&
            number.charAt(number.length - 1) == 'e') {
          number += ch;
        } else if (this.isExpOperator(ch) &&
            (!peekCh || !this.isNumber(peekCh)) &&
            number.charAt(number.length - 1) == 'e') {
          this.throwError('Invalid exponent');
        } else {
          break;
        }
      }
      this.index++;
    }
    this.tokens.push({
      index: start,
      text: number,
      constant: true,
      value: Number(number)
    });
  },

  readIdent: function() {
    var start = this.index;
    while (this.index < this.text.length) {
      var ch = this.text.charAt(this.index);
      if (!(this.isIdent(ch) || this.isNumber(ch))) {
        break;
      }
      this.index++;
    }
    this.tokens.push({
      index: start,
      text: this.text.slice(start, this.index),
      identifier: true
    });
  },

  readString: function(quote) {
    var start = this.index;
    this.index++;
    var string = '';
    var rawString = quote;
    var escape = false;
    while (this.index < this.text.length) {
      var ch = this.text.charAt(this.index);
      rawString += ch;
      if (escape) {
        if (ch === 'u') {
          var hex = this.text.substring(this.index + 1, this.index + 5);
          if (!hex.match(/[\da-f]{4}/i))
            this.throwError('Invalid unicode escape [\\u' + hex + ']');
          this.index += 4;
          string += String.fromCharCode(parseInt(hex, 16));
        } else {
          var rep = ESCAPE[ch];
          string = string + (rep || ch);
        }
        escape = false;
      } else if (ch === '\\') {
        escape = true;
      } else if (ch === quote) {
        this.index++;
        this.tokens.push({
          index: start,
          text: rawString,
          constant: true,
          value: string
        });
        return;
      } else {
        string += ch;
      }
      this.index++;
    }
    this.throwError('Unterminated quote', start);
  }
};


function isConstant(exp) {
  return exp.constant;
}

/**
 * @constructor
 */
var Parser = function(lexer, $filter, options) {
  this.lexer = lexer;
  this.$filter = $filter;
  this.options = options;
};

Parser.ZERO = extend(function() {
  return 0;
}, {
  sharedGetter: true,
  constant: true
});

Parser.prototype = {
  constructor: Parser,

  parse: function(text) {
    this.text = text;
    this.tokens = this.lexer.lex(text);

    var value = this.statements();

    if (this.tokens.length !== 0) {
      this.throwError('is an unexpected token', this.tokens[0]);
    }

    value.literal = !!value.literal;
    value.constant = !!value.constant;

    return value;
  },

  primary: function() {
    var primary;
    if (this.expect('(')) {
      primary = this.filterChain();
      this.consume(')');
    } else if (this.expect('[')) {
      primary = this.arrayDeclaration();
    } else if (this.expect('{')) {
      primary = this.object();
    } else if (this.peek().identifier && this.peek().text in CONSTANTS) {
      primary = CONSTANTS[this.consume().text];
    } else if (this.peek().identifier) {
      primary = this.identifier();
    } else if (this.peek().constant) {
      primary = this.constant();
    } else {
      this.throwError('not a primary expression', this.peek());
    }

    var next, context;
    while ((next = this.expect('(', '[', '.'))) {
      if (next.text === '(') {
        primary = this.functionCall(primary, context);
        context = null;
      } else if (next.text === '[') {
        context = primary;
        primary = this.objectIndex(primary);
      } else if (next.text === '.') {
        context = primary;
        primary = this.fieldAccess(primary);
      } else {
        this.throwError('IMPOSSIBLE');
      }
    }
    return primary;
  },

  throwError: function(msg, token) {
    throw $parseMinErr('syntax',
        'Syntax Error: Token \'{0}\' {1} at column {2} of the expression [{3}] starting at [{4}].',
          token.text, msg, (token.index + 1), this.text, this.text.substring(token.index));
  },

  peekToken: function() {
    if (this.tokens.length === 0)
      throw $parseMinErr('ueoe', 'Unexpected end of expression: {0}', this.text);
    return this.tokens[0];
  },

  peek: function(e1, e2, e3, e4) {
    return this.peekAhead(0, e1, e2, e3, e4);
  },
  peekAhead: function(i, e1, e2, e3, e4) {
    if (this.tokens.length > i) {
      var token = this.tokens[i];
      var t = token.text;
      if (t === e1 || t === e2 || t === e3 || t === e4 ||
          (!e1 && !e2 && !e3 && !e4)) {
        return token;
      }
    }
    return false;
  },

  expect: function(e1, e2, e3, e4) {
    var token = this.peek(e1, e2, e3, e4);
    if (token) {
      this.tokens.shift();
      return token;
    }
    return false;
  },

  consume: function(e1) {
    if (this.tokens.length === 0) {
      throw $parseMinErr('ueoe', 'Unexpected end of expression: {0}', this.text);
    }

    var token = this.expect(e1);
    if (!token) {
      this.throwError('is unexpected, expecting [' + e1 + ']', this.peek());
    }
    return token;
  },

  unaryFn: function(op, right) {
    var fn = OPERATORS[op];
    return extend(function $parseUnaryFn(self, locals) {
      return fn(self, locals, right);
    }, {
      constant:right.constant,
      inputs: [right]
    });
  },

  binaryFn: function(left, op, right, isBranching) {
    var fn = OPERATORS[op];
    return extend(function $parseBinaryFn(self, locals) {
      return fn(self, locals, left, right);
    }, {
      constant: left.constant && right.constant,
      inputs: !isBranching && [left, right]
    });
  },

  identifier: function() {
    var id = this.consume().text;

    //Continue reading each `.identifier` unless it is a method invocation
    while (this.peek('.') && this.peekAhead(1).identifier && !this.peekAhead(2, '(')) {
      id += this.consume().text + this.consume().text;
    }

    return getterFn(id, this.options, this.text);
  },

  constant: function() {
    var value = this.consume().value;

    return extend(function $parseConstant() {
      return value;
    }, {
      constant: true,
      literal: true
    });
  },

  statements: function() {
    var statements = [];
    while (true) {
      if (this.tokens.length > 0 && !this.peek('}', ')', ';', ']'))
        statements.push(this.filterChain());
      if (!this.expect(';')) {
        // optimize for the common case where there is only one statement.
        // TODO(size): maybe we should not support multiple statements?
        return (statements.length === 1)
            ? statements[0]
            : function $parseStatements(self, locals) {
                var value;
                for (var i = 0, ii = statements.length; i < ii; i++) {
                  value = statements[i](self, locals);
                }
                return value;
              };
      }
    }
  },

  filterChain: function() {
    var left = this.expression();
    var token;
    while ((token = this.expect('|'))) {
      left = this.filter(left);
    }
    return left;
  },

  filter: function(inputFn) {
    var fn = this.$filter(this.consume().text);
    var argsFn;
    var args;

    if (this.peek(':')) {
      argsFn = [];
      args = []; // we can safely reuse the array
      while (this.expect(':')) {
        argsFn.push(this.expression());
      }
    }

    var inputs = [inputFn].concat(argsFn || []);

    return extend(function $parseFilter(self, locals) {
      var input = inputFn(self, locals);
      if (args) {
        args[0] = input;

        var i = argsFn.length;
        while (i--) {
          args[i + 1] = argsFn[i](self, locals);
        }

        return fn.apply(undefined, args);
      }

      return fn(input);
    }, {
      constant: !fn.$stateful && inputs.every(isConstant),
      inputs: !fn.$stateful && inputs
    });
  },

  expression: function() {
    return this.assignment();
  },

  assignment: function() {
    var left = this.ternary();
    var right;
    var token;
    if ((token = this.expect('='))) {
      if (!left.assign) {
        this.throwError('implies assignment but [' +
            this.text.substring(0, token.index) + '] can not be assigned to', token);
      }
      right = this.ternary();
      return extend(function $parseAssignment(scope, locals) {
        return left.assign(scope, right(scope, locals), locals);
      }, {
        inputs: [left, right]
      });
    }
    return left;
  },

  ternary: function() {
    var left = this.logicalOR();
    var middle;
    var token;
    if ((token = this.expect('?'))) {
      middle = this.assignment();
      if (this.consume(':')) {
        var right = this.assignment();

        return extend(function $parseTernary(self, locals) {
          return left(self, locals) ? middle(self, locals) : right(self, locals);
        }, {
          constant: left.constant && middle.constant && right.constant
        });
      }
    }

    return left;
  },

  logicalOR: function() {
    var left = this.logicalAND();
    var token;
    while ((token = this.expect('||'))) {
      left = this.binaryFn(left, token.text, this.logicalAND(), true);
    }
    return left;
  },

  logicalAND: function() {
    var left = this.equality();
    var token;
    while ((token = this.expect('&&'))) {
      left = this.binaryFn(left, token.text, this.equality(), true);
    }
    return left;
  },

  equality: function() {
    var left = this.relational();
    var token;
    while ((token = this.expect('==','!=','===','!=='))) {
      left = this.binaryFn(left, token.text, this.relational());
    }
    return left;
  },

  relational: function() {
    var left = this.additive();
    var token;
    while ((token = this.expect('<', '>', '<=', '>='))) {
      left = this.binaryFn(left, token.text, this.additive());
    }
    return left;
  },

  additive: function() {
    var left = this.multiplicative();
    var token;
    while ((token = this.expect('+','-'))) {
      left = this.binaryFn(left, token.text, this.multiplicative());
    }
    return left;
  },

  multiplicative: function() {
    var left = this.unary();
    var token;
    while ((token = this.expect('*','/','%'))) {
      left = this.binaryFn(left, token.text, this.unary());
    }
    return left;
  },

  unary: function() {
    var token;
    if (this.expect('+')) {
      return this.primary();
    } else if ((token = this.expect('-'))) {
      return this.binaryFn(Parser.ZERO, token.text, this.unary());
    } else if ((token = this.expect('!'))) {
      return this.unaryFn(token.text, this.unary());
    } else {
      return this.primary();
    }
  },

  fieldAccess: function(object) {
    var getter = this.identifier();

    return extend(function $parseFieldAccess(scope, locals, self) {
      var o = self || object(scope, locals);
      return (o == null) ? undefined : getter(o);
    }, {
      assign: function(scope, value, locals) {
        var o = object(scope, locals);
        if (!o) object.assign(scope, o = {}, locals);
        return getter.assign(o, value);
      }
    });
  },

  objectIndex: function(obj) {
    var expression = this.text;

    var indexFn = this.expression();
    this.consume(']');

    return extend(function $parseObjectIndex(self, locals) {
      var o = obj(self, locals),
          i = getStringValue(indexFn(self, locals), expression),
          v;

      ensureSafeMemberName(i, expression);
      if (!o) return undefined;
      v = ensureSafeObject(o[i], expression);
      return v;
    }, {
      assign: function(self, value, locals) {
        var key = ensureSafeMemberName(getStringValue(indexFn(self, locals), expression), expression);
        // prevent overwriting of Function.constructor which would break ensureSafeObject check
        var o = ensureSafeObject(obj(self, locals), expression);
        if (!o) obj.assign(self, o = {}, locals);
        return o[key] = value;
      }
    });
  },

  functionCall: function(fnGetter, contextGetter) {
    var argsFn = [];
    if (this.peekToken().text !== ')') {
      do {
        argsFn.push(this.expression());
      } while (this.expect(','));
    }
    this.consume(')');

    var expressionText = this.text;
    // we can safely reuse the array across invocations
    var args = argsFn.length ? [] : null;

    return function $parseFunctionCall(scope, locals) {
      var context = contextGetter ? contextGetter(scope, locals) : isDefined(contextGetter) ? undefined : scope;
      var fn = fnGetter(scope, locals, context) || noop;

      if (args) {
        var i = argsFn.length;
        while (i--) {
          args[i] = ensureSafeObject(argsFn[i](scope, locals), expressionText);
        }
      }

      ensureSafeObject(context, expressionText);
      ensureSafeFunction(fn, expressionText);

      // IE doesn't have apply for some native functions
      var v = fn.apply
            ? fn.apply(context, args)
            : fn(args[0], args[1], args[2], args[3], args[4]);

      if (args) {
        // Free-up the memory (arguments of the last function call).
        args.length = 0;
      }

      return ensureSafeObject(v, expressionText);
      };
  },

  // This is used with json array declaration
  arrayDeclaration: function() {
    var elementFns = [];
    if (this.peekToken().text !== ']') {
      do {
        if (this.peek(']')) {
          // Support trailing commas per ES5.1.
          break;
        }
        elementFns.push(this.expression());
      } while (this.expect(','));
    }
    this.consume(']');

    return extend(function $parseArrayLiteral(self, locals) {
      var array = [];
      for (var i = 0, ii = elementFns.length; i < ii; i++) {
        array.push(elementFns[i](self, locals));
      }
      return array;
    }, {
      literal: true,
      constant: elementFns.every(isConstant),
      inputs: elementFns
    });
  },

  object: function() {
    var keys = [], valueFns = [];
    if (this.peekToken().text !== '}') {
      do {
        if (this.peek('}')) {
          // Support trailing commas per ES5.1.
          break;
        }
        var token = this.consume();
        if (token.constant) {
          keys.push(token.value);
        } else if (token.identifier) {
          keys.push(token.text);
        } else {
          this.throwError("invalid key", token);
        }
        this.consume(':');
        valueFns.push(this.expression());
      } while (this.expect(','));
    }
    this.consume('}');

    return extend(function $parseObjectLiteral(self, locals) {
      var object = {};
      for (var i = 0, ii = valueFns.length; i < ii; i++) {
        object[keys[i]] = valueFns[i](self, locals);
      }
      return object;
    }, {
      literal: true,
      constant: valueFns.every(isConstant),
      inputs: valueFns
    });
  }
};


//////////////////////////////////////////////////
// Parser helper functions
//////////////////////////////////////////////////

function setter(obj, locals, path, setValue, fullExp) {
  ensureSafeObject(obj, fullExp);
  ensureSafeObject(locals, fullExp);

  var element = path.split('.'), key;
  for (var i = 0; element.length > 1; i++) {
    key = ensureSafeMemberName(element.shift(), fullExp);
    var propertyObj = (i === 0 && locals && locals[key]) || obj[key];
    if (!propertyObj) {
      propertyObj = {};
      obj[key] = propertyObj;
    }
    obj = ensureSafeObject(propertyObj, fullExp);
  }
  key = ensureSafeMemberName(element.shift(), fullExp);
  ensureSafeObject(obj[key], fullExp);
  obj[key] = setValue;
  return setValue;
}

var getterFnCacheDefault = createMap();
var getterFnCacheExpensive = createMap();

function isPossiblyDangerousMemberName(name) {
  return name == 'constructor';
}

/**
 * Implementation of the "Black Hole" variant from:
 * - http://jsperf.com/angularjs-parse-getter/4
 * - http://jsperf.com/path-evaluation-simplified/7
 */
function cspSafeGetterFn(key0, key1, key2, key3, key4, fullExp, expensiveChecks) {
  ensureSafeMemberName(key0, fullExp);
  ensureSafeMemberName(key1, fullExp);
  ensureSafeMemberName(key2, fullExp);
  ensureSafeMemberName(key3, fullExp);
  ensureSafeMemberName(key4, fullExp);
  var eso = function(o) {
    return ensureSafeObject(o, fullExp);
  };
  var eso0 = (expensiveChecks || isPossiblyDangerousMemberName(key0)) ? eso : identity;
  var eso1 = (expensiveChecks || isPossiblyDangerousMemberName(key1)) ? eso : identity;
  var eso2 = (expensiveChecks || isPossiblyDangerousMemberName(key2)) ? eso : identity;
  var eso3 = (expensiveChecks || isPossiblyDangerousMemberName(key3)) ? eso : identity;
  var eso4 = (expensiveChecks || isPossiblyDangerousMemberName(key4)) ? eso : identity;

  return function cspSafeGetter(scope, locals) {
    var pathVal = (locals && locals.hasOwnProperty(key0)) ? locals : scope;

    if (pathVal == null) return pathVal;
    pathVal = eso0(pathVal[key0]);

    if (!key1) return pathVal;
    if (pathVal == null) return undefined;
    pathVal = eso1(pathVal[key1]);

    if (!key2) return pathVal;
    if (pathVal == null) return undefined;
    pathVal = eso2(pathVal[key2]);

    if (!key3) return pathVal;
    if (pathVal == null) return undefined;
    pathVal = eso3(pathVal[key3]);

    if (!key4) return pathVal;
    if (pathVal == null) return undefined;
    pathVal = eso4(pathVal[key4]);

    return pathVal;
  };
}

function getterFnWithEnsureSafeObject(fn, fullExpression) {
  return function(s, l) {
    return fn(s, l, ensureSafeObject, fullExpression);
  };
}

function getterFn(path, options, fullExp) {
  var expensiveChecks = options.expensiveChecks;
  var getterFnCache = (expensiveChecks ? getterFnCacheExpensive : getterFnCacheDefault);
  var fn = getterFnCache[path];
  if (fn) return fn;


  var pathKeys = path.split('.'),
      pathKeysLength = pathKeys.length;

  // http://jsperf.com/angularjs-parse-getter/6
  if (options.csp) {
    if (pathKeysLength < 6) {
      fn = cspSafeGetterFn(pathKeys[0], pathKeys[1], pathKeys[2], pathKeys[3], pathKeys[4], fullExp, expensiveChecks);
    } else {
      fn = function cspSafeGetter(scope, locals) {
        var i = 0, val;
        do {
          val = cspSafeGetterFn(pathKeys[i++], pathKeys[i++], pathKeys[i++], pathKeys[i++],
                                pathKeys[i++], fullExp, expensiveChecks)(scope, locals);

          locals = undefined; // clear after first iteration
          scope = val;
        } while (i < pathKeysLength);
        return val;
      };
    }
  } else {
    var code = '';
    if (expensiveChecks) {
      code += 's = eso(s, fe);\nl = eso(l, fe);\n';
    }
    var needsEnsureSafeObject = expensiveChecks;
    forEach(pathKeys, function(key, index) {
      ensureSafeMemberName(key, fullExp);
      var lookupJs = (index
                      // we simply dereference 's' on any .dot notation
                      ? 's'
                      // but if we are first then we check locals first, and if so read it first
                      : '((l&&l.hasOwnProperty("' + key + '"))?l:s)') + '.' + key;
      if (expensiveChecks || isPossiblyDangerousMemberName(key)) {
        lookupJs = 'eso(' + lookupJs + ', fe)';
        needsEnsureSafeObject = true;
      }
      code += 'if(s == null) return undefined;\n' +
              's=' + lookupJs + ';\n';
    });
    code += 'return s;';

    /* jshint -W054 */
    var evaledFnGetter = new Function('s', 'l', 'eso', 'fe', code); // s=scope, l=locals, eso=ensureSafeObject
    /* jshint +W054 */
    evaledFnGetter.toString = valueFn(code);
    if (needsEnsureSafeObject) {
      evaledFnGetter = getterFnWithEnsureSafeObject(evaledFnGetter, fullExp);
    }
    fn = evaledFnGetter;
  }

  fn.sharedGetter = true;
  fn.assign = function(self, value, locals) {
    return setter(self, locals, path, value, path);
  };
  getterFnCache[path] = fn;
  return fn;
}

var objectValueOf = Object.prototype.valueOf;

function getValueOf(value) {
  return isFunction(value.valueOf) ? value.valueOf() : objectValueOf.call(value);
}

///////////////////////////////////

/**
 * @ngdoc service
 * @name $parse
 * @kind function
 *
 * @description
 *
 * Converts Angular {@link guide/expression expression} into a function.
 *
 * ```js
 *   var getter = $parse('user.name');
 *   var setter = getter.assign;
 *   var context = {user:{name:'angular'}};
 *   var locals = {user:{name:'local'}};
 *
 *   expect(getter(context)).toEqual('angular');
 *   setter(context, 'newValue');
 *   expect(context.user.name).toEqual('newValue');
 *   expect(getter(context, locals)).toEqual('local');
 * ```
 *
 *
 * @param {string} expression String expression to compile.
 * @returns {function(context, locals)} a function which represents the compiled expression:
 *
 *    * `context` – `{object}` – an object against which any expressions embedded in the strings
 *      are evaluated against (typically a scope object).
 *    * `locals` – `{object=}` – local variables context object, useful for overriding values in
 *      `context`.
 *
 *    The returned function also has the following properties:
 *      * `literal` – `{boolean}` – whether the expression's top-level node is a JavaScript
 *        literal.
 *      * `constant` – `{boolean}` – whether the expression is made entirely of JavaScript
 *        constant literals.
 *      * `assign` – `{?function(context, value)}` – if the expression is assignable, this will be
 *        set to a function to change its value on the given context.
 *
 */


/**
 * @ngdoc provider
 * @name $parseProvider
 *
 * @description
 * `$parseProvider` can be used for configuring the default behavior of the {@link ng.$parse $parse}
 *  service.
 */
function $ParseProvider() {
  var cacheDefault = createMap();
  var cacheExpensive = createMap();



  this.$get = ['$filter', '$sniffer', function($filter, $sniffer) {
    var $parseOptions = {
          csp: $sniffer.csp,
          expensiveChecks: false
        },
        $parseOptionsExpensive = {
          csp: $sniffer.csp,
          expensiveChecks: true
        };

    function wrapSharedExpression(exp) {
      var wrapped = exp;

      if (exp.sharedGetter) {
        wrapped = function $parseWrapper(self, locals) {
          return exp(self, locals);
        };
        wrapped.literal = exp.literal;
        wrapped.constant = exp.constant;
        wrapped.assign = exp.assign;
      }

      return wrapped;
    }

    return function $parse(exp, interceptorFn, expensiveChecks) {
      var parsedExpression, oneTime, cacheKey;

      switch (typeof exp) {
        case 'string':
          cacheKey = exp = exp.trim();

          var cache = (expensiveChecks ? cacheExpensive : cacheDefault);
          parsedExpression = cache[cacheKey];

          if (!parsedExpression) {
            if (exp.charAt(0) === ':' && exp.charAt(1) === ':') {
              oneTime = true;
              exp = exp.substring(2);
            }

            var parseOptions = expensiveChecks ? $parseOptionsExpensive : $parseOptions;
            var lexer = new Lexer(parseOptions);
            var parser = new Parser(lexer, $filter, parseOptions);
            parsedExpression = parser.parse(exp);

            if (parsedExpression.constant) {
              parsedExpression.$$watchDelegate = constantWatchDelegate;
            } else if (oneTime) {
              //oneTime is not part of the exp passed to the Parser so we may have to
              //wrap the parsedExpression before adding a $$watchDelegate
              parsedExpression = wrapSharedExpression(parsedExpression);
              parsedExpression.$$watchDelegate = parsedExpression.literal ?
                oneTimeLiteralWatchDelegate : oneTimeWatchDelegate;
            } else if (parsedExpression.inputs) {
              parsedExpression.$$watchDelegate = inputsWatchDelegate;
            }

            cache[cacheKey] = parsedExpression;
          }
          return addInterceptor(parsedExpression, interceptorFn);

        case 'function':
          return addInterceptor(exp, interceptorFn);

        default:
          return addInterceptor(noop, interceptorFn);
      }
    };

    function collectExpressionInputs(inputs, list) {
      for (var i = 0, ii = inputs.length; i < ii; i++) {
        var input = inputs[i];
        if (!input.constant) {
          if (input.inputs) {
            collectExpressionInputs(input.inputs, list);
          } else if (list.indexOf(input) === -1) { // TODO(perf) can we do better?
            list.push(input);
          }
        }
      }

      return list;
    }

    function expressionInputDirtyCheck(newValue, oldValueOfValue) {

      if (newValue == null || oldValueOfValue == null) { // null/undefined
        return newValue === oldValueOfValue;
      }

      if (typeof newValue === 'object') {

        // attempt to convert the value to a primitive type
        // TODO(docs): add a note to docs that by implementing valueOf even objects and arrays can
        //             be cheaply dirty-checked
        newValue = getValueOf(newValue);

        if (typeof newValue === 'object') {
          // objects/arrays are not supported - deep-watching them would be too expensive
          return false;
        }

        // fall-through to the primitive equality check
      }

      //Primitive or NaN
      return newValue === oldValueOfValue || (newValue !== newValue && oldValueOfValue !== oldValueOfValue);
    }

    function inputsWatchDelegate(scope, listener, objectEquality, parsedExpression) {
      var inputExpressions = parsedExpression.$$inputs ||
                    (parsedExpression.$$inputs = collectExpressionInputs(parsedExpression.inputs, []));

      var lastResult;

      if (inputExpressions.length === 1) {
        var oldInputValue = expressionInputDirtyCheck; // init to something unique so that equals check fails
        inputExpressions = inputExpressions[0];
        return scope.$watch(function expressionInputWatch(scope) {
          var newInputValue = inputExpressions(scope);
          if (!expressionInputDirtyCheck(newInputValue, oldInputValue)) {
            lastResult = parsedExpression(scope);
            oldInputValue = newInputValue && getValueOf(newInputValue);
          }
          return lastResult;
        }, listener, objectEquality);
      }

      var oldInputValueOfValues = [];
      for (var i = 0, ii = inputExpressions.length; i < ii; i++) {
        oldInputValueOfValues[i] = expressionInputDirtyCheck; // init to something unique so that equals check fails
      }

      return scope.$watch(function expressionInputsWatch(scope) {
        var changed = false;

        for (var i = 0, ii = inputExpressions.length; i < ii; i++) {
          var newInputValue = inputExpressions[i](scope);
          if (changed || (changed = !expressionInputDirtyCheck(newInputValue, oldInputValueOfValues[i]))) {
            oldInputValueOfValues[i] = newInputValue && getValueOf(newInputValue);
          }
        }

        if (changed) {
          lastResult = parsedExpression(scope);
        }

        return lastResult;
      }, listener, objectEquality);
    }

    function oneTimeWatchDelegate(scope, listener, objectEquality, parsedExpression) {
      var unwatch, lastValue;
      return unwatch = scope.$watch(function oneTimeWatch(scope) {
        return parsedExpression(scope);
      }, function oneTimeListener(value, old, scope) {
        lastValue = value;
        if (isFunction(listener)) {
          listener.apply(this, arguments);
        }
        if (isDefined(value)) {
          scope.$$postDigest(function() {
            if (isDefined(lastValue)) {
              unwatch();
            }
          });
        }
      }, objectEquality);
    }

    function oneTimeLiteralWatchDelegate(scope, listener, objectEquality, parsedExpression) {
      var unwatch, lastValue;
      return unwatch = scope.$watch(function oneTimeWatch(scope) {
        return parsedExpression(scope);
      }, function oneTimeListener(value, old, scope) {
        lastValue = value;
        if (isFunction(listener)) {
          listener.call(this, value, old, scope);
        }
        if (isAllDefined(value)) {
          scope.$$postDigest(function() {
            if (isAllDefined(lastValue)) unwatch();
          });
        }
      }, objectEquality);

      function isAllDefined(value) {
        var allDefined = true;
        forEach(value, function(val) {
          if (!isDefined(val)) allDefined = false;
        });
        return allDefined;
      }
    }

    function constantWatchDelegate(scope, listener, objectEquality, parsedExpression) {
      var unwatch;
      return unwatch = scope.$watch(function constantWatch(scope) {
        return parsedExpression(scope);
      }, function constantListener(value, old, scope) {
        if (isFunction(listener)) {
          listener.apply(this, arguments);
        }
        unwatch();
      }, objectEquality);
    }

    function addInterceptor(parsedExpression, interceptorFn) {
      if (!interceptorFn) return parsedExpression;
      var watchDelegate = parsedExpression.$$watchDelegate;

      var regularWatch =
          watchDelegate !== oneTimeLiteralWatchDelegate &&
          watchDelegate !== oneTimeWatchDelegate;

      var fn = regularWatch ? function regularInterceptedExpression(scope, locals) {
        var value = parsedExpression(scope, locals);
        return interceptorFn(value, scope, locals);
      } : function oneTimeInterceptedExpression(scope, locals) {
        var value = parsedExpression(scope, locals);
        var result = interceptorFn(value, scope, locals);
        // we only return the interceptor's result if the
        // initial value is defined (for bind-once)
        return isDefined(value) ? result : value;
      };

      // Propagate $$watchDelegates other then inputsWatchDelegate
      if (parsedExpression.$$watchDelegate &&
          parsedExpression.$$watchDelegate !== inputsWatchDelegate) {
        fn.$$watchDelegate = parsedExpression.$$watchDelegate;
      } else if (!interceptorFn.$stateful) {
        // If there is an interceptor, but no watchDelegate then treat the interceptor like
        // we treat filters - it is assumed to be a pure function unless flagged with $stateful
        fn.$$watchDelegate = inputsWatchDelegate;
        fn.inputs = [parsedExpression];
      }

      return fn;
    }
  }];
}

/**
 * @ngdoc service
 * @name $q
 * @requires $rootScope
 *
 * @description
 * A service that helps you run functions asynchronously, and use their return values (or exceptions)
 * when they are done processing.
 *
 * This is an implementation of promises/deferred objects inspired by
 * [Kris Kowal's Q](https://github.com/kriskowal/q).
 *
 * $q can be used in two fashions --- one which is more similar to Kris Kowal's Q or jQuery's Deferred
 * implementations, and the other which resembles ES6 promises to some degree.
 *
 * # $q constructor
 *
 * The streamlined ES6 style promise is essentially just using $q as a constructor which takes a `resolver`
 * function as the first argument. This is similar to the native Promise implementation from ES6 Harmony,
 * see [MDN](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Promise).
 *
 * While the constructor-style use is supported, not all of the supporting methods from ES6 Harmony promises are
 * available yet.
 *
 * It can be used like so:
 *
 * ```js
 *   // for the purpose of this example let's assume that variables `$q` and `okToGreet`
 *   // are available in the current lexical scope (they could have been injected or passed in).
 *
 *   function asyncGreet(name) {
 *     // perform some asynchronous operation, resolve or reject the promise when appropriate.
 *     return $q(function(resolve, reject) {
 *       setTimeout(function() {
 *         if (okToGreet(name)) {
 *           resolve('Hello, ' + name + '!');
 *         } else {
 *           reject('Greeting ' + name + ' is not allowed.');
 *         }
 *       }, 1000);
 *     });
 *   }
 *
 *   var promise = asyncGreet('Robin Hood');
 *   promise.then(function(greeting) {
 *     alert('Success: ' + greeting);
 *   }, function(reason) {
 *     alert('Failed: ' + reason);
 *   });
 * ```
 *
 * Note: progress/notify callbacks are not currently supported via the ES6-style interface.
 *
 * However, the more traditional CommonJS-style usage is still available, and documented below.
 *
 * [The CommonJS Promise proposal](http://wiki.commonjs.org/wiki/Promises) describes a promise as an
 * interface for interacting with an object that represents the result of an action that is
 * performed asynchronously, and may or may not be finished at any given point in time.
 *
 * From the perspective of dealing with error handling, deferred and promise APIs are to
 * asynchronous programming what `try`, `catch` and `throw` keywords are to synchronous programming.
 *
 * ```js
 *   // for the purpose of this example let's assume that variables `$q` and `okToGreet`
 *   // are available in the current lexical scope (they could have been injected or passed in).
 *
 *   function asyncGreet(name) {
 *     var deferred = $q.defer();
 *
 *     setTimeout(function() {
 *       deferred.notify('About to greet ' + name + '.');
 *
 *       if (okToGreet(name)) {
 *         deferred.resolve('Hello, ' + name + '!');
 *       } else {
 *         deferred.reject('Greeting ' + name + ' is not allowed.');
 *       }
 *     }, 1000);
 *
 *     return deferred.promise;
 *   }
 *
 *   var promise = asyncGreet('Robin Hood');
 *   promise.then(function(greeting) {
 *     alert('Success: ' + greeting);
 *   }, function(reason) {
 *     alert('Failed: ' + reason);
 *   }, function(update) {
 *     alert('Got notification: ' + update);
 *   });
 * ```
 *
 * At first it might not be obvious why this extra complexity is worth the trouble. The payoff
 * comes in the way of guarantees that promise and deferred APIs make, see
 * https://github.com/kriskowal/uncommonjs/blob/master/promises/specification.md.
 *
 * Additionally the promise api allows for composition that is very hard to do with the
 * traditional callback ([CPS](http://en.wikipedia.org/wiki/Continuation-passing_style)) approach.
 * For more on this please see the [Q documentation](https://github.com/kriskowal/q) especially the
 * section on serial or parallel joining of promises.
 *
 * # The Deferred API
 *
 * A new instance of deferred is constructed by calling `$q.defer()`.
 *
 * The purpose of the deferred object is to expose the associated Promise instance as well as APIs
 * that can be used for signaling the successful or unsuccessful completion, as well as the status
 * of the task.
 *
 * **Methods**
 *
 * - `resolve(value)` – resolves the derived promise with the `value`. If the value is a rejection
 *   constructed via `$q.reject`, the promise will be rejected instead.
 * - `reject(reason)` – rejects the derived promise with the `reason`. This is equivalent to
 *   resolving it with a rejection constructed via `$q.reject`.
 * - `notify(value)` - provides updates on the status of the promise's execution. This may be called
 *   multiple times before the promise is either resolved or rejected.
 *
 * **Properties**
 *
 * - promise – `{Promise}` – promise object associated with this deferred.
 *
 *
 * # The Promise API
 *
 * A new promise instance is created when a deferred instance is created and can be retrieved by
 * calling `deferred.promise`.
 *
 * The purpose of the promise object is to allow for interested parties to get access to the result
 * of the deferred task when it completes.
 *
 * **Methods**
 *
 * - `then(successCallback, errorCallback, notifyCallback)` – regardless of when the promise was or
 *   will be resolved or rejected, `then` calls one of the success or error callbacks asynchronously
 *   as soon as the result is available. The callbacks are called with a single argument: the result
 *   or rejection reason. Additionally, the notify callback may be called zero or more times to
 *   provide a progress indication, before the promise is resolved or rejected.
 *
 *   This method *returns a new promise* which is resolved or rejected via the return value of the
 *   `successCallback`, `errorCallback`. It also notifies via the return value of the
 *   `notifyCallback` method. The promise cannot be resolved or rejected from the notifyCallback
 *   method.
 *
 * - `catch(errorCallback)` – shorthand for `promise.then(null, errorCallback)`
 *
 * - `finally(callback, notifyCallback)` – allows you to observe either the fulfillment or rejection of a promise,
 *   but to do so without modifying the final value. This is useful to release resources or do some
 *   clean-up that needs to be done whether the promise was rejected or resolved. See the [full
 *   specification](https://github.com/kriskowal/q/wiki/API-Reference#promisefinallycallback) for
 *   more information.
 *
 * # Chaining promises
 *
 * Because calling the `then` method of a promise returns a new derived promise, it is easily
 * possible to create a chain of promises:
 *
 * ```js
 *   promiseB = promiseA.then(function(result) {
 *     return result + 1;
 *   });
 *
 *   // promiseB will be resolved immediately after promiseA is resolved and its value
 *   // will be the result of promiseA incremented by 1
 * ```
 *
 * It is possible to create chains of any length and since a promise can be resolved with another
 * promise (which will defer its resolution further), it is possible to pause/defer resolution of
 * the promises at any point in the chain. This makes it possible to implement powerful APIs like
 * $http's response interceptors.
 *
 *
 * # Differences between Kris Kowal's Q and $q
 *
 *  There are two main differences:
 *
 * - $q is integrated with the {@link ng.$rootScope.Scope} Scope model observation
 *   mechanism in angular, which means faster propagation of resolution or rejection into your
 *   models and avoiding unnecessary browser repaints, which would result in flickering UI.
 * - Q has many more features than $q, but that comes at a cost of bytes. $q is tiny, but contains
 *   all the important functionality needed for common async tasks.
 *
 *  # Testing
 *
 *  ```js
 *    it('should simulate promise', inject(function($q, $rootScope) {
 *      var deferred = $q.defer();
 *      var promise = deferred.promise;
 *      var resolvedValue;
 *
 *      promise.then(function(value) { resolvedValue = value; });
 *      expect(resolvedValue).toBeUndefined();
 *
 *      // Simulate resolving of promise
 *      deferred.resolve(123);
 *      // Note that the 'then' function does not get called synchronously.
 *      // This is because we want the promise API to always be async, whether or not
 *      // it got called synchronously or asynchronously.
 *      expect(resolvedValue).toBeUndefined();
 *
 *      // Propagate promise resolution to 'then' functions using $apply().
 *      $rootScope.$apply();
 *      expect(resolvedValue).toEqual(123);
 *    }));
 *  ```
 *
 * @param {function(function, function)} resolver Function which is responsible for resolving or
 *   rejecting the newly created promise. The first parameter is a function which resolves the
 *   promise, the second parameter is a function which rejects the promise.
 *
 * @returns {Promise} The newly created promise.
 */
function $QProvider() {

  this.$get = ['$rootScope', '$exceptionHandler', function($rootScope, $exceptionHandler) {
    return qFactory(function(callback) {
      $rootScope.$evalAsync(callback);
    }, $exceptionHandler);
  }];
}

function $$QProvider() {
  this.$get = ['$browser', '$exceptionHandler', function($browser, $exceptionHandler) {
    return qFactory(function(callback) {
      $browser.defer(callback);
    }, $exceptionHandler);
  }];
}

/**
 * Constructs a promise manager.
 *
 * @param {function(function)} nextTick Function for executing functions in the next turn.
 * @param {function(...*)} exceptionHandler Function into which unexpected exceptions are passed for
 *     debugging purposes.
 * @returns {object} Promise manager.
 */
function qFactory(nextTick, exceptionHandler) {
  var $qMinErr = minErr('$q', TypeError);
  function callOnce(self, resolveFn, rejectFn) {
    var called = false;
    function wrap(fn) {
      return function(value) {
        if (called) return;
        called = true;
        fn.call(self, value);
      };
    }

    return [wrap(resolveFn), wrap(rejectFn)];
  }

  /**
   * @ngdoc method
   * @name ng.$q#defer
   * @kind function
   *
   * @description
   * Creates a `Deferred` object which represents a task which will finish in the future.
   *
   * @returns {Deferred} Returns a new instance of deferred.
   */
  var defer = function() {
    return new Deferred();
  };

  function Promise() {
    this.$$state = { status: 0 };
  }

  Promise.prototype = {
    then: function(onFulfilled, onRejected, progressBack) {
      var result = new Deferred();

      this.$$state.pending = this.$$state.pending || [];
      this.$$state.pending.push([result, onFulfilled, onRejected, progressBack]);
      if (this.$$state.status > 0) scheduleProcessQueue(this.$$state);

      return result.promise;
    },

    "catch": function(callback) {
      return this.then(null, callback);
    },

    "finally": function(callback, progressBack) {
      return this.then(function(value) {
        return handleCallback(value, true, callback);
      }, function(error) {
        return handleCallback(error, false, callback);
      }, progressBack);
    }
  };

  //Faster, more basic than angular.bind http://jsperf.com/angular-bind-vs-custom-vs-native
  function simpleBind(context, fn) {
    return function(value) {
      fn.call(context, value);
    };
  }

  function processQueue(state) {
    var fn, promise, pending;

    pending = state.pending;
    state.processScheduled = false;
    state.pending = undefined;
    for (var i = 0, ii = pending.length; i < ii; ++i) {
      promise = pending[i][0];
      fn = pending[i][state.status];
      try {
        if (isFunction(fn)) {
          promise.resolve(fn(state.value));
        } else if (state.status === 1) {
          promise.resolve(state.value);
        } else {
          promise.reject(state.value);
        }
      } catch (e) {
        promise.reject(e);
        exceptionHandler(e);
      }
    }
  }

  function scheduleProcessQueue(state) {
    if (state.processScheduled || !state.pending) return;
    state.processScheduled = true;
    nextTick(function() { processQueue(state); });
  }

  function Deferred() {
    this.promise = new Promise();
    //Necessary to support unbound execution :/
    this.resolve = simpleBind(this, this.resolve);
    this.reject = simpleBind(this, this.reject);
    this.notify = simpleBind(this, this.notify);
  }

  Deferred.prototype = {
    resolve: function(val) {
      if (this.promise.$$state.status) return;
      if (val === this.promise) {
        this.$$reject($qMinErr(
          'qcycle',
          "Expected promise to be resolved with value other than itself '{0}'",
          val));
      } else {
        this.$$resolve(val);
      }

    },

    $$resolve: function(val) {
      var then, fns;

      fns = callOnce(this, this.$$resolve, this.$$reject);
      try {
        if ((isObject(val) || isFunction(val))) then = val && val.then;
        if (isFunction(then)) {
          this.promise.$$state.status = -1;
          then.call(val, fns[0], fns[1], this.notify);
        } else {
          this.promise.$$state.value = val;
          this.promise.$$state.status = 1;
          scheduleProcessQueue(this.promise.$$state);
        }
      } catch (e) {
        fns[1](e);
        exceptionHandler(e);
      }
    },

    reject: function(reason) {
      if (this.promise.$$state.status) return;
      this.$$reject(reason);
    },

    $$reject: function(reason) {
      this.promise.$$state.value = reason;
      this.promise.$$state.status = 2;
      scheduleProcessQueue(this.promise.$$state);
    },

    notify: function(progress) {
      var callbacks = this.promise.$$state.pending;

      if ((this.promise.$$state.status <= 0) && callbacks && callbacks.length) {
        nextTick(function() {
          var callback, result;
          for (var i = 0, ii = callbacks.length; i < ii; i++) {
            result = callbacks[i][0];
            callback = callbacks[i][3];
            try {
              result.notify(isFunction(callback) ? callback(progress) : progress);
            } catch (e) {
              exceptionHandler(e);
            }
          }
        });
      }
    }
  };

  /**
   * @ngdoc method
   * @name $q#reject
   * @kind function
   *
   * @description
   * Creates a promise that is resolved as rejected with the specified `reason`. This api should be
   * used to forward rejection in a chain of promises. If you are dealing with the last promise in
   * a promise chain, you don't need to worry about it.
   *
   * When comparing deferreds/promises to the familiar behavior of try/catch/throw, think of
   * `reject` as the `throw` keyword in JavaScript. This also means that if you "catch" an error via
   * a promise error callback and you want to forward the error to the promise derived from the
   * current promise, you have to "rethrow" the error by returning a rejection constructed via
   * `reject`.
   *
   * ```js
   *   promiseB = promiseA.then(function(result) {
   *     // success: do something and resolve promiseB
   *     //          with the old or a new result
   *     return result;
   *   }, function(reason) {
   *     // error: handle the error if possible and
   *     //        resolve promiseB with newPromiseOrValue,
   *     //        otherwise forward the rejection to promiseB
   *     if (canHandle(reason)) {
   *      // handle the error and recover
   *      return newPromiseOrValue;
   *     }
   *     return $q.reject(reason);
   *   });
   * ```
   *
   * @param {*} reason Constant, message, exception or an object representing the rejection reason.
   * @returns {Promise} Returns a promise that was already resolved as rejected with the `reason`.
   */
  var reject = function(reason) {
    var result = new Deferred();
    result.reject(reason);
    return result.promise;
  };

  var makePromise = function makePromise(value, resolved) {
    var result = new Deferred();
    if (resolved) {
      result.resolve(value);
    } else {
      result.reject(value);
    }
    return result.promise;
  };

  var handleCallback = function handleCallback(value, isResolved, callback) {
    var callbackOutput = null;
    try {
      if (isFunction(callback)) callbackOutput = callback();
    } catch (e) {
      return makePromise(e, false);
    }
    if (isPromiseLike(callbackOutput)) {
      return callbackOutput.then(function() {
        return makePromise(value, isResolved);
      }, function(error) {
        return makePromise(error, false);
      });
    } else {
      return makePromise(value, isResolved);
    }
  };

  /**
   * @ngdoc method
   * @name $q#when
   * @kind function
   *
   * @description
   * Wraps an object that might be a value or a (3rd party) then-able promise into a $q promise.
   * This is useful when you are dealing with an object that might or might not be a promise, or if
   * the promise comes from a source that can't be trusted.
   *
   * @param {*} value Value or a promise
   * @returns {Promise} Returns a promise of the passed value or promise
   */


  var when = function(value, callback, errback, progressBack) {
    var result = new Deferred();
    result.resolve(value);
    return result.promise.then(callback, errback, progressBack);
  };

  /**
   * @ngdoc method
   * @name $q#all
   * @kind function
   *
   * @description
   * Combines multiple promises into a single promise that is resolved when all of the input
   * promises are resolved.
   *
   * @param {Array.<Promise>|Object.<Promise>} promises An array or hash of promises.
   * @returns {Promise} Returns a single promise that will be resolved with an array/hash of values,
   *   each value corresponding to the promise at the same index/key in the `promises` array/hash.
   *   If any of the promises is resolved with a rejection, this resulting promise will be rejected
   *   with the same rejection value.
   */

  function all(promises) {
    var deferred = new Deferred(),
        counter = 0,
        results = isArray(promises) ? [] : {};

    forEach(promises, function(promise, key) {
      counter++;
      when(promise).then(function(value) {
        if (results.hasOwnProperty(key)) return;
        results[key] = value;
        if (!(--counter)) deferred.resolve(results);
      }, function(reason) {
        if (results.hasOwnProperty(key)) return;
        deferred.reject(reason);
      });
    });

    if (counter === 0) {
      deferred.resolve(results);
    }

    return deferred.promise;
  }

  var $Q = function Q(resolver) {
    if (!isFunction(resolver)) {
      throw $qMinErr('norslvr', "Expected resolverFn, got '{0}'", resolver);
    }

    if (!(this instanceof Q)) {
      // More useful when $Q is the Promise itself.
      return new Q(resolver);
    }

    var deferred = new Deferred();

    function resolveFn(value) {
      deferred.resolve(value);
    }

    function rejectFn(reason) {
      deferred.reject(reason);
    }

    resolver(resolveFn, rejectFn);

    return deferred.promise;
  };

  $Q.defer = defer;
  $Q.reject = reject;
  $Q.when = when;
  $Q.all = all;

  return $Q;
}

function $$RAFProvider() { //rAF
  this.$get = ['$window', '$timeout', function($window, $timeout) {
    var requestAnimationFrame = $window.requestAnimationFrame ||
                                $window.webkitRequestAnimationFrame;

    var cancelAnimationFrame = $window.cancelAnimationFrame ||
                               $window.webkitCancelAnimationFrame ||
                               $window.webkitCancelRequestAnimationFrame;

    var rafSupported = !!requestAnimationFrame;
    var rafFn = rafSupported
      ? function(fn) {
          var id = requestAnimationFrame(fn);
          return function() {
            cancelAnimationFrame(id);
          };
        }
      : function(fn) {
          var timer = $timeout(fn, 16.66, false); // 1000 / 60 = 16.666
          return function() {
            $timeout.cancel(timer);
          };
        };

    queueFn.supported = rafSupported;

    var cancelLastRAF;
    var taskCount = 0;
    var taskQueue = [];
    return queueFn;

    function flush() {
      for (var i = 0; i < taskQueue.length; i++) {
        var task = taskQueue[i];
        if (task) {
          taskQueue[i] = null;
          task();
        }
      }
      taskCount = taskQueue.length = 0;
    }

    function queueFn(asyncFn) {
      var index = taskQueue.length;

      taskCount++;
      taskQueue.push(asyncFn);

      if (index === 0) {
        cancelLastRAF = rafFn(flush);
      }

      return function cancelQueueFn() {
        if (index >= 0) {
          taskQueue[index] = null;
          index = null;

          if (--taskCount === 0 && cancelLastRAF) {
            cancelLastRAF();
            cancelLastRAF = null;
            taskQueue.length = 0;
          }
        }
      };
    }
  }];
}

/**
 * DESIGN NOTES
 *
 * The design decisions behind the scope are heavily favored for speed and memory consumption.
 *
 * The typical use of scope is to watch the expressions, which most of the time return the same
 * value as last time so we optimize the operation.
 *
 * Closures construction is expensive in terms of speed as well as memory:
 *   - No closures, instead use prototypical inheritance for API
 *   - Internal state needs to be stored on scope directly, which means that private state is
 *     exposed as $$____ properties
 *
 * Loop operations are optimized by using while(count--) { ... }
 *   - this means that in order to keep the same order of execution as addition we have to add
 *     items to the array at the beginning (unshift) instead of at the end (push)
 *
 * Child scopes are created and removed often
 *   - Using an array would be slow since inserts in middle are expensive so we use linked list
 *
 * There are few watches then a lot of observers. This is why you don't want the observer to be
 * implemented in the same way as watch. Watch requires return of initialization function which
 * are expensive to construct.
 */


/**
 * @ngdoc provider
 * @name $rootScopeProvider
 * @description
 *
 * Provider for the $rootScope service.
 */

/**
 * @ngdoc method
 * @name $rootScopeProvider#digestTtl
 * @description
 *
 * Sets the number of `$digest` iterations the scope should attempt to execute before giving up and
 * assuming that the model is unstable.
 *
 * The current default is 10 iterations.
 *
 * In complex applications it's possible that the dependencies between `$watch`s will result in
 * several digest iterations. However if an application needs more than the default 10 digest
 * iterations for its model to stabilize then you should investigate what is causing the model to
 * continuously change during the digest.
 *
 * Increasing the TTL could have performance implications, so you should not change it without
 * proper justification.
 *
 * @param {number} limit The number of digest iterations.
 */


/**
 * @ngdoc service
 * @name $rootScope
 * @description
 *
 * Every application has a single root {@link ng.$rootScope.Scope scope}.
 * All other scopes are descendant scopes of the root scope. Scopes provide separation
 * between the model and the view, via a mechanism for watching the model for changes.
 * They also provide an event emission/broadcast and subscription facility. See the
 * {@link guide/scope developer guide on scopes}.
 */
function $RootScopeProvider() {
  var TTL = 10;
  var $rootScopeMinErr = minErr('$rootScope');
  var lastDirtyWatch = null;
  var applyAsyncId = null;

  this.digestTtl = function(value) {
    if (arguments.length) {
      TTL = value;
    }
    return TTL;
  };

  function createChildScopeClass(parent) {
    function ChildScope() {
      this.$$watchers = this.$$nextSibling =
          this.$$childHead = this.$$childTail = null;
      this.$$listeners = {};
      this.$$listenerCount = {};
      this.$id = nextUid();
      this.$$ChildScope = null;
    }
    ChildScope.prototype = parent;
    return ChildScope;
  }

  this.$get = ['$injector', '$exceptionHandler', '$parse', '$browser',
      function($injector, $exceptionHandler, $parse, $browser) {

    function destroyChildScope($event) {
        $event.currentScope.$$destroyed = true;
    }

    /**
     * @ngdoc type
     * @name $rootScope.Scope
     *
     * @description
     * A root scope can be retrieved using the {@link ng.$rootScope $rootScope} key from the
     * {@link auto.$injector $injector}. Child scopes are created using the
     * {@link ng.$rootScope.Scope#$new $new()} method. (Most scopes are created automatically when
     * compiled HTML template is executed.) See also the {@link guide/scope Scopes guide} for
     * an in-depth introduction and usage examples.
     *
     *
     * # Inheritance
     * A scope can inherit from a parent scope, as in this example:
     * ```js
         var parent = $rootScope;
         var child = parent.$new();

         parent.salutation = "Hello";
         expect(child.salutation).toEqual('Hello');

         child.salutation = "Welcome";
         expect(child.salutation).toEqual('Welcome');
         expect(parent.salutation).toEqual('Hello');
     * ```
     *
     * When interacting with `Scope` in tests, additional helper methods are available on the
     * instances of `Scope` type. See {@link ngMock.$rootScope.Scope ngMock Scope} for additional
     * details.
     *
     *
     * @param {Object.<string, function()>=} providers Map of service factory which need to be
     *                                       provided for the current scope. Defaults to {@link ng}.
     * @param {Object.<string, *>=} instanceCache Provides pre-instantiated services which should
     *                              append/override services provided by `providers`. This is handy
     *                              when unit-testing and having the need to override a default
     *                              service.
     * @returns {Object} Newly created scope.
     *
     */
    function Scope() {
      this.$id = nextUid();
      this.$$phase = this.$parent = this.$$watchers =
                     this.$$nextSibling = this.$$prevSibling =
                     this.$$childHead = this.$$childTail = null;
      this.$root = this;
      this.$$destroyed = false;
      this.$$listeners = {};
      this.$$listenerCount = {};
      this.$$isolateBindings = null;
    }

    /**
     * @ngdoc property
     * @name $rootScope.Scope#$id
     *
     * @description
     * Unique scope ID (monotonically increasing) useful for debugging.
     */

     /**
      * @ngdoc property
      * @name $rootScope.Scope#$parent
      *
      * @description
      * Reference to the parent scope.
      */

      /**
       * @ngdoc property
       * @name $rootScope.Scope#$root
       *
       * @description
       * Reference to the root scope.
       */

    Scope.prototype = {
      constructor: Scope,
      /**
       * @ngdoc method
       * @name $rootScope.Scope#$new
       * @kind function
       *
       * @description
       * Creates a new child {@link ng.$rootScope.Scope scope}.
       *
       * The parent scope will propagate the {@link ng.$rootScope.Scope#$digest $digest()} event.
       * The scope can be removed from the scope hierarchy using {@link ng.$rootScope.Scope#$destroy $destroy()}.
       *
       * {@link ng.$rootScope.Scope#$destroy $destroy()} must be called on a scope when it is
       * desired for the scope and its child scopes to be permanently detached from the parent and
       * thus stop participating in model change detection and listener notification by invoking.
       *
       * @param {boolean} isolate If true, then the scope does not prototypically inherit from the
       *         parent scope. The scope is isolated, as it can not see parent scope properties.
       *         When creating widgets, it is useful for the widget to not accidentally read parent
       *         state.
       *
       * @param {Scope} [parent=this] The {@link ng.$rootScope.Scope `Scope`} that will be the `$parent`
       *                              of the newly created scope. Defaults to `this` scope if not provided.
       *                              This is used when creating a transclude scope to correctly place it
       *                              in the scope hierarchy while maintaining the correct prototypical
       *                              inheritance.
       *
       * @returns {Object} The newly created child scope.
       *
       */
      $new: function(isolate, parent) {
        var child;

        parent = parent || this;

        if (isolate) {
          child = new Scope();
          child.$root = this.$root;
        } else {
          // Only create a child scope class if somebody asks for one,
          // but cache it to allow the VM to optimize lookups.
          if (!this.$$ChildScope) {
            this.$$ChildScope = createChildScopeClass(this);
          }
          child = new this.$$ChildScope();
        }
        child.$parent = parent;
        child.$$prevSibling = parent.$$childTail;
        if (parent.$$childHead) {
          parent.$$childTail.$$nextSibling = child;
          parent.$$childTail = child;
        } else {
          parent.$$childHead = parent.$$childTail = child;
        }

        // When the new scope is not isolated or we inherit from `this`, and
        // the parent scope is destroyed, the property `$$destroyed` is inherited
        // prototypically. In all other cases, this property needs to be set
        // when the parent scope is destroyed.
        // The listener needs to be added after the parent is set
        if (isolate || parent != this) child.$on('$destroy', destroyChildScope);

        return child;
      },

      /**
       * @ngdoc method
       * @name $rootScope.Scope#$watch
       * @kind function
       *
       * @description
       * Registers a `listener` callback to be executed whenever the `watchExpression` changes.
       *
       * - The `watchExpression` is called on every call to {@link ng.$rootScope.Scope#$digest
       *   $digest()} and should return the value that will be watched. (Since
       *   {@link ng.$rootScope.Scope#$digest $digest()} reruns when it detects changes the
       *   `watchExpression` can execute multiple times per
       *   {@link ng.$rootScope.Scope#$digest $digest()} and should be idempotent.)
       * - The `listener` is called only when the value from the current `watchExpression` and the
       *   previous call to `watchExpression` are not equal (with the exception of the initial run,
       *   see below). Inequality is determined according to reference inequality,
       *   [strict comparison](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Operators/Comparison_Operators)
       *    via the `!==` Javascript operator, unless `objectEquality == true`
       *   (see next point)
       * - When `objectEquality == true`, inequality of the `watchExpression` is determined
       *   according to the {@link angular.equals} function. To save the value of the object for
       *   later comparison, the {@link angular.copy} function is used. This therefore means that
       *   watching complex objects will have adverse memory and performance implications.
       * - The watch `listener` may change the model, which may trigger other `listener`s to fire.
       *   This is achieved by rerunning the watchers until no changes are detected. The rerun
       *   iteration limit is 10 to prevent an infinite loop deadlock.
       *
       *
       * If you want to be notified whenever {@link ng.$rootScope.Scope#$digest $digest} is called,
       * you can register a `watchExpression` function with no `listener`. (Be prepared for
       * multiple calls to your `watchExpression` because it will execute multiple times in a
       * single {@link ng.$rootScope.Scope#$digest $digest} cycle if a change is detected.)
       *
       * After a watcher is registered with the scope, the `listener` fn is called asynchronously
       * (via {@link ng.$rootScope.Scope#$evalAsync $evalAsync}) to initialize the
       * watcher. In rare cases, this is undesirable because the listener is called when the result
       * of `watchExpression` didn't change. To detect this scenario within the `listener` fn, you
       * can compare the `newVal` and `oldVal`. If these two values are identical (`===`) then the
       * listener was called due to initialization.
       *
       *
       *
       * # Example
       * ```js
           // let's assume that scope was dependency injected as the $rootScope
           var scope = $rootScope;
           scope.name = 'misko';
           scope.counter = 0;

           expect(scope.counter).toEqual(0);
           scope.$watch('name', function(newValue, oldValue) {
             scope.counter = scope.counter + 1;
           });
           expect(scope.counter).toEqual(0);

           scope.$digest();
           // the listener is always called during the first $digest loop after it was registered
           expect(scope.counter).toEqual(1);

           scope.$digest();
           // but now it will not be called unless the value changes
           expect(scope.counter).toEqual(1);

           scope.name = 'adam';
           scope.$digest();
           expect(scope.counter).toEqual(2);



           // Using a function as a watchExpression
           var food;
           scope.foodCounter = 0;
           expect(scope.foodCounter).toEqual(0);
           scope.$watch(
             // This function returns the value being watched. It is called for each turn of the $digest loop
             function() { return food; },
             // This is the change listener, called when the value returned from the above function changes
             function(newValue, oldValue) {
               if ( newValue !== oldValue ) {
                 // Only increment the counter if the value changed
                 scope.foodCounter = scope.foodCounter + 1;
               }
             }
           );
           // No digest has been run so the counter will be zero
           expect(scope.foodCounter).toEqual(0);

           // Run the digest but since food has not changed count will still be zero
           scope.$digest();
           expect(scope.foodCounter).toEqual(0);

           // Update food and run digest.  Now the counter will increment
           food = 'cheeseburger';
           scope.$digest();
           expect(scope.foodCounter).toEqual(1);

       * ```
       *
       *
       *
       * @param {(function()|string)} watchExpression Expression that is evaluated on each
       *    {@link ng.$rootScope.Scope#$digest $digest} cycle. A change in the return value triggers
       *    a call to the `listener`.
       *
       *    - `string`: Evaluated as {@link guide/expression expression}
       *    - `function(scope)`: called with current `scope` as a parameter.
       * @param {function(newVal, oldVal, scope)} listener Callback called whenever the value
       *    of `watchExpression` changes.
       *
       *    - `newVal` contains the current value of the `watchExpression`
       *    - `oldVal` contains the previous value of the `watchExpression`
       *    - `scope` refers to the current scope
       * @param {boolean=} objectEquality Compare for object equality using {@link angular.equals} instead of
       *     comparing for reference equality.
       * @returns {function()} Returns a deregistration function for this listener.
       */
      $watch: function(watchExp, listener, objectEquality) {
        var get = $parse(watchExp);

        if (get.$$watchDelegate) {
          return get.$$watchDelegate(this, listener, objectEquality, get);
        }
        var scope = this,
            array = scope.$$watchers,
            watcher = {
              fn: listener,
              last: initWatchVal,
              get: get,
              exp: watchExp,
              eq: !!objectEquality
            };

        lastDirtyWatch = null;

        if (!isFunction(listener)) {
          watcher.fn = noop;
        }

        if (!array) {
          array = scope.$$watchers = [];
        }
        // we use unshift since we use a while loop in $digest for speed.
        // the while loop reads in reverse order.
        array.unshift(watcher);

        return function deregisterWatch() {
          arrayRemove(array, watcher);
          lastDirtyWatch = null;
        };
      },

      /**
       * @ngdoc method
       * @name $rootScope.Scope#$watchGroup
       * @kind function
       *
       * @description
       * A variant of {@link ng.$rootScope.Scope#$watch $watch()} where it watches an array of `watchExpressions`.
       * If any one expression in the collection changes the `listener` is executed.
       *
       * - The items in the `watchExpressions` array are observed via standard $watch operation and are examined on every
       *   call to $digest() to see if any items changes.
       * - The `listener` is called whenever any expression in the `watchExpressions` array changes.
       *
       * @param {Array.<string|Function(scope)>} watchExpressions Array of expressions that will be individually
       * watched using {@link ng.$rootScope.Scope#$watch $watch()}
       *
       * @param {function(newValues, oldValues, scope)} listener Callback called whenever the return value of any
       *    expression in `watchExpressions` changes
       *    The `newValues` array contains the current values of the `watchExpressions`, with the indexes matching
       *    those of `watchExpression`
       *    and the `oldValues` array contains the previous values of the `watchExpressions`, with the indexes matching
       *    those of `watchExpression`
       *    The `scope` refers to the current scope.
       * @returns {function()} Returns a de-registration function for all listeners.
       */
      $watchGroup: function(watchExpressions, listener) {
        var oldValues = new Array(watchExpressions.length);
        var newValues = new Array(watchExpressions.length);
        var deregisterFns = [];
        var self = this;
        var changeReactionScheduled = false;
        var firstRun = true;

        if (!watchExpressions.length) {
          // No expressions means we call the listener ASAP
          var shouldCall = true;
          self.$evalAsync(function() {
            if (shouldCall) listener(newValues, newValues, self);
          });
          return function deregisterWatchGroup() {
            shouldCall = false;
          };
        }

        if (watchExpressions.length === 1) {
          // Special case size of one
          return this.$watch(watchExpressions[0], function watchGroupAction(value, oldValue, scope) {
            newValues[0] = value;
            oldValues[0] = oldValue;
            listener(newValues, (value === oldValue) ? newValues : oldValues, scope);
          });
        }

        forEach(watchExpressions, function(expr, i) {
          var unwatchFn = self.$watch(expr, function watchGroupSubAction(value, oldValue) {
            newValues[i] = value;
            oldValues[i] = oldValue;
            if (!changeReactionScheduled) {
              changeReactionScheduled = true;
              self.$evalAsync(watchGroupAction);
            }
          });
          deregisterFns.push(unwatchFn);
        });

        function watchGroupAction() {
          changeReactionScheduled = false;

          if (firstRun) {
            firstRun = false;
            listener(newValues, newValues, self);
          } else {
            listener(newValues, oldValues, self);
          }
        }

        return function deregisterWatchGroup() {
          while (deregisterFns.length) {
            deregisterFns.shift()();
          }
        };
      },


      /**
       * @ngdoc method
       * @name $rootScope.Scope#$watchCollection
       * @kind function
       *
       * @description
       * Shallow watches the properties of an object and fires whenever any of the properties change
       * (for arrays, this implies watching the array items; for object maps, this implies watching
       * the properties). If a change is detected, the `listener` callback is fired.
       *
       * - The `obj` collection is observed via standard $watch operation and is examined on every
       *   call to $digest() to see if any items have been added, removed, or moved.
       * - The `listener` is called whenever anything within the `obj` has changed. Examples include
       *   adding, removing, and moving items belonging to an object or array.
       *
       *
       * # Example
       * ```js
          $scope.names = ['igor', 'matias', 'misko', 'james'];
          $scope.dataCount = 4;

          $scope.$watchCollection('names', function(newNames, oldNames) {
            $scope.dataCount = newNames.length;
          });

          expect($scope.dataCount).toEqual(4);
          $scope.$digest();

          //still at 4 ... no changes
          expect($scope.dataCount).toEqual(4);

          $scope.names.pop();
          $scope.$digest();

          //now there's been a change
          expect($scope.dataCount).toEqual(3);
       * ```
       *
       *
       * @param {string|function(scope)} obj Evaluated as {@link guide/expression expression}. The
       *    expression value should evaluate to an object or an array which is observed on each
       *    {@link ng.$rootScope.Scope#$digest $digest} cycle. Any shallow change within the
       *    collection will trigger a call to the `listener`.
       *
       * @param {function(newCollection, oldCollection, scope)} listener a callback function called
       *    when a change is detected.
       *    - The `newCollection` object is the newly modified data obtained from the `obj` expression
       *    - The `oldCollection` object is a copy of the former collection data.
       *      Due to performance considerations, the`oldCollection` value is computed only if the
       *      `listener` function declares two or more arguments.
       *    - The `scope` argument refers to the current scope.
       *
       * @returns {function()} Returns a de-registration function for this listener. When the
       *    de-registration function is executed, the internal watch operation is terminated.
       */
      $watchCollection: function(obj, listener) {
        $watchCollectionInterceptor.$stateful = true;

        var self = this;
        // the current value, updated on each dirty-check run
        var newValue;
        // a shallow copy of the newValue from the last dirty-check run,
        // updated to match newValue during dirty-check run
        var oldValue;
        // a shallow copy of the newValue from when the last change happened
        var veryOldValue;
        // only track veryOldValue if the listener is asking for it
        var trackVeryOldValue = (listener.length > 1);
        var changeDetected = 0;
        var changeDetector = $parse(obj, $watchCollectionInterceptor);
        var internalArray = [];
        var internalObject = {};
        var initRun = true;
        var oldLength = 0;

        function $watchCollectionInterceptor(_value) {
          newValue = _value;
          var newLength, key, bothNaN, newItem, oldItem;

          // If the new value is undefined, then return undefined as the watch may be a one-time watch
          if (isUndefined(newValue)) return;

          if (!isObject(newValue)) { // if primitive
            if (oldValue !== newValue) {
              oldValue = newValue;
              changeDetected++;
            }
          } else if (isArrayLike(newValue)) {
            if (oldValue !== internalArray) {
              // we are transitioning from something which was not an array into array.
              oldValue = internalArray;
              oldLength = oldValue.length = 0;
              changeDetected++;
            }

            newLength = newValue.length;

            if (oldLength !== newLength) {
              // if lengths do not match we need to trigger change notification
              changeDetected++;
              oldValue.length = oldLength = newLength;
            }
            // copy the items to oldValue and look for changes.
            for (var i = 0; i < newLength; i++) {
              oldItem = oldValue[i];
              newItem = newValue[i];

              bothNaN = (oldItem !== oldItem) && (newItem !== newItem);
              if (!bothNaN && (oldItem !== newItem)) {
                changeDetected++;
                oldValue[i] = newItem;
              }
            }
          } else {
            if (oldValue !== internalObject) {
              // we are transitioning from something which was not an object into object.
              oldValue = internalObject = {};
              oldLength = 0;
              changeDetected++;
            }
            // copy the items to oldValue and look for changes.
            newLength = 0;
            for (key in newValue) {
              if (newValue.hasOwnProperty(key)) {
                newLength++;
                newItem = newValue[key];
                oldItem = oldValue[key];

                if (key in oldValue) {
                  bothNaN = (oldItem !== oldItem) && (newItem !== newItem);
                  if (!bothNaN && (oldItem !== newItem)) {
                    changeDetected++;
                    oldValue[key] = newItem;
                  }
                } else {
                  oldLength++;
                  oldValue[key] = newItem;
                  changeDetected++;
                }
              }
            }
            if (oldLength > newLength) {
              // we used to have more keys, need to find them and destroy them.
              changeDetected++;
              for (key in oldValue) {
                if (!newValue.hasOwnProperty(key)) {
                  oldLength--;
                  delete oldValue[key];
                }
              }
            }
          }
          return changeDetected;
        }

        function $watchCollectionAction() {
          if (initRun) {
            initRun = false;
            listener(newValue, newValue, self);
          } else {
            listener(newValue, veryOldValue, self);
          }

          // make a copy for the next time a collection is changed
          if (trackVeryOldValue) {
            if (!isObject(newValue)) {
              //primitive
              veryOldValue = newValue;
            } else if (isArrayLike(newValue)) {
              veryOldValue = new Array(newValue.length);
              for (var i = 0; i < newValue.length; i++) {
                veryOldValue[i] = newValue[i];
              }
            } else { // if object
              veryOldValue = {};
              for (var key in newValue) {
                if (hasOwnProperty.call(newValue, key)) {
                  veryOldValue[key] = newValue[key];
                }
              }
            }
          }
        }

        return this.$watch(changeDetector, $watchCollectionAction);
      },

      /**
       * @ngdoc method
       * @name $rootScope.Scope#$digest
       * @kind function
       *
       * @description
       * Processes all of the {@link ng.$rootScope.Scope#$watch watchers} of the current scope and
       * its children. Because a {@link ng.$rootScope.Scope#$watch watcher}'s listener can change
       * the model, the `$digest()` keeps calling the {@link ng.$rootScope.Scope#$watch watchers}
       * until no more listeners are firing. This means that it is possible to get into an infinite
       * loop. This function will throw `'Maximum iteration limit exceeded.'` if the number of
       * iterations exceeds 10.
       *
       * Usually, you don't call `$digest()` directly in
       * {@link ng.directive:ngController controllers} or in
       * {@link ng.$compileProvider#directive directives}.
       * Instead, you should call {@link ng.$rootScope.Scope#$apply $apply()} (typically from within
       * a {@link ng.$compileProvider#directive directive}), which will force a `$digest()`.
       *
       * If you want to be notified whenever `$digest()` is called,
       * you can register a `watchExpression` function with
       * {@link ng.$rootScope.Scope#$watch $watch()} with no `listener`.
       *
       * In unit tests, you may need to call `$digest()` to simulate the scope life cycle.
       *
       * # Example
       * ```js
           var scope = ...;
           scope.name = 'misko';
           scope.counter = 0;

           expect(scope.counter).toEqual(0);
           scope.$watch('name', function(newValue, oldValue) {
             scope.counter = scope.counter + 1;
           });
           expect(scope.counter).toEqual(0);

           scope.$digest();
           // the listener is always called during the first $digest loop after it was registered
           expect(scope.counter).toEqual(1);

           scope.$digest();
           // but now it will not be called unless the value changes
           expect(scope.counter).toEqual(1);

           scope.name = 'adam';
           scope.$digest();
           expect(scope.counter).toEqual(2);
       * ```
       *
       */
      $digest: function() {
        var watch, value, last,
            watchers,
            length,
            dirty, ttl = TTL,
            next, current, target = this,
            watchLog = [],
            logIdx, logMsg, asyncTask;

        beginPhase('$digest');
        // Check for changes to browser url that happened in sync before the call to $digest
        $browser.$$checkUrlChange();

        if (this === $rootScope && applyAsyncId !== null) {
          // If this is the root scope, and $applyAsync has scheduled a deferred $apply(), then
          // cancel the scheduled $apply and flush the queue of expressions to be evaluated.
          $browser.defer.cancel(applyAsyncId);
          flushApplyAsync();
        }

        lastDirtyWatch = null;

        do { // "while dirty" loop
          dirty = false;
          current = target;

          while (asyncQueue.length) {
            try {
              asyncTask = asyncQueue.shift();
              asyncTask.scope.$eval(asyncTask.expression, asyncTask.locals);
            } catch (e) {
              $exceptionHandler(e);
            }
            lastDirtyWatch = null;
          }

          traverseScopesLoop:
          do { // "traverse the scopes" loop
            if ((watchers = current.$$watchers)) {
              // process our watches
              length = watchers.length;
              while (length--) {
                try {
                  watch = watchers[length];
                  // Most common watches are on primitives, in which case we can short
                  // circuit it with === operator, only when === fails do we use .equals
                  if (watch) {
                    if ((value = watch.get(current)) !== (last = watch.last) &&
                        !(watch.eq
                            ? equals(value, last)
                            : (typeof value === 'number' && typeof last === 'number'
                               && isNaN(value) && isNaN(last)))) {
                      dirty = true;
                      lastDirtyWatch = watch;
                      watch.last = watch.eq ? copy(value, null) : value;
                      watch.fn(value, ((last === initWatchVal) ? value : last), current);
                      if (ttl < 5) {
                        logIdx = 4 - ttl;
                        if (!watchLog[logIdx]) watchLog[logIdx] = [];
                        watchLog[logIdx].push({
                          msg: isFunction(watch.exp) ? 'fn: ' + (watch.exp.name || watch.exp.toString()) : watch.exp,
                          newVal: value,
                          oldVal: last
                        });
                      }
                    } else if (watch === lastDirtyWatch) {
                      // If the most recently dirty watcher is now clean, short circuit since the remaining watchers
                      // have already been tested.
                      dirty = false;
                      break traverseScopesLoop;
                    }
                  }
                } catch (e) {
                  $exceptionHandler(e);
                }
              }
            }

            // Insanity Warning: scope depth-first traversal
            // yes, this code is a bit crazy, but it works and we have tests to prove it!
            // this piece should be kept in sync with the traversal in $broadcast
            if (!(next = (current.$$childHead ||
                (current !== target && current.$$nextSibling)))) {
              while (current !== target && !(next = current.$$nextSibling)) {
                current = current.$parent;
              }
            }
          } while ((current = next));

          // `break traverseScopesLoop;` takes us to here

          if ((dirty || asyncQueue.length) && !(ttl--)) {
            clearPhase();
            throw $rootScopeMinErr('infdig',
                '{0} $digest() iterations reached. Aborting!\n' +
                'Watchers fired in the last 5 iterations: {1}',
                TTL, watchLog);
          }

        } while (dirty || asyncQueue.length);

        clearPhase();

        while (postDigestQueue.length) {
          try {
            postDigestQueue.shift()();
          } catch (e) {
            $exceptionHandler(e);
          }
        }
      },


      /**
       * @ngdoc event
       * @name $rootScope.Scope#$destroy
       * @eventType broadcast on scope being destroyed
       *
       * @description
       * Broadcasted when a scope and its children are being destroyed.
       *
       * Note that, in AngularJS, there is also a `$destroy` jQuery event, which can be used to
       * clean up DOM bindings before an element is removed from the DOM.
       */

      /**
       * @ngdoc method
       * @name $rootScope.Scope#$destroy
       * @kind function
       *
       * @description
       * Removes the current scope (and all of its children) from the parent scope. Removal implies
       * that calls to {@link ng.$rootScope.Scope#$digest $digest()} will no longer
       * propagate to the current scope and its children. Removal also implies that the current
       * scope is eligible for garbage collection.
       *
       * The `$destroy()` is usually used by directives such as
       * {@link ng.directive:ngRepeat ngRepeat} for managing the
       * unrolling of the loop.
       *
       * Just before a scope is destroyed, a `$destroy` event is broadcasted on this scope.
       * Application code can register a `$destroy` event handler that will give it a chance to
       * perform any necessary cleanup.
       *
       * Note that, in AngularJS, there is also a `$destroy` jQuery event, which can be used to
       * clean up DOM bindings before an element is removed from the DOM.
       */
      $destroy: function() {
        // we can't destroy the root scope or a scope that has been already destroyed
        if (this.$$destroyed) return;
        var parent = this.$parent;

        this.$broadcast('$destroy');
        this.$$destroyed = true;
        if (this === $rootScope) return;

        for (var eventName in this.$$listenerCount) {
          decrementListenerCount(this, this.$$listenerCount[eventName], eventName);
        }

        // sever all the references to parent scopes (after this cleanup, the current scope should
        // not be retained by any of our references and should be eligible for garbage collection)
        if (parent.$$childHead == this) parent.$$childHead = this.$$nextSibling;
        if (parent.$$childTail == this) parent.$$childTail = this.$$prevSibling;
        if (this.$$prevSibling) this.$$prevSibling.$$nextSibling = this.$$nextSibling;
        if (this.$$nextSibling) this.$$nextSibling.$$prevSibling = this.$$prevSibling;

        // Disable listeners, watchers and apply/digest methods
        this.$destroy = this.$digest = this.$apply = this.$evalAsync = this.$applyAsync = noop;
        this.$on = this.$watch = this.$watchGroup = function() { return noop; };
        this.$$listeners = {};

        // All of the code below is bogus code that works around V8's memory leak via optimized code
        // and inline caches.
        //
        // see:
        // - https://code.google.com/p/v8/issues/detail?id=2073#c26
        // - https://github.com/angular/angular.js/issues/6794#issuecomment-38648909
        // - https://github.com/angular/angular.js/issues/1313#issuecomment-10378451

        this.$parent = this.$$nextSibling = this.$$prevSibling = this.$$childHead =
            this.$$childTail = this.$root = this.$$watchers = null;
      },

      /**
       * @ngdoc method
       * @name $rootScope.Scope#$eval
       * @kind function
       *
       * @description
       * Executes the `expression` on the current scope and returns the result. Any exceptions in
       * the expression are propagated (uncaught). This is useful when evaluating Angular
       * expressions.
       *
       * # Example
       * ```js
           var scope = ng.$rootScope.Scope();
           scope.a = 1;
           scope.b = 2;

           expect(scope.$eval('a+b')).toEqual(3);
           expect(scope.$eval(function(scope){ return scope.a + scope.b; })).toEqual(3);
       * ```
       *
       * @param {(string|function())=} expression An angular expression to be executed.
       *
       *    - `string`: execute using the rules as defined in  {@link guide/expression expression}.
       *    - `function(scope)`: execute the function with the current `scope` parameter.
       *
       * @param {(object)=} locals Local variables object, useful for overriding values in scope.
       * @returns {*} The result of evaluating the expression.
       */
      $eval: function(expr, locals) {
        return $parse(expr)(this, locals);
      },

      /**
       * @ngdoc method
       * @name $rootScope.Scope#$evalAsync
       * @kind function
       *
       * @description
       * Executes the expression on the current scope at a later point in time.
       *
       * The `$evalAsync` makes no guarantees as to when the `expression` will be executed, only
       * that:
       *
       *   - it will execute after the function that scheduled the evaluation (preferably before DOM
       *     rendering).
       *   - at least one {@link ng.$rootScope.Scope#$digest $digest cycle} will be performed after
       *     `expression` execution.
       *
       * Any exceptions from the execution of the expression are forwarded to the
       * {@link ng.$exceptionHandler $exceptionHandler} service.
       *
       * __Note:__ if this function is called outside of a `$digest` cycle, a new `$digest` cycle
       * will be scheduled. However, it is encouraged to always call code that changes the model
       * from within an `$apply` call. That includes code evaluated via `$evalAsync`.
       *
       * @param {(string|function())=} expression An angular expression to be executed.
       *
       *    - `string`: execute using the rules as defined in {@link guide/expression expression}.
       *    - `function(scope)`: execute the function with the current `scope` parameter.
       *
       * @param {(object)=} locals Local variables object, useful for overriding values in scope.
       */
      $evalAsync: function(expr, locals) {
        // if we are outside of an $digest loop and this is the first time we are scheduling async
        // task also schedule async auto-flush
        if (!$rootScope.$$phase && !asyncQueue.length) {
          $browser.defer(function() {
            if (asyncQueue.length) {
              $rootScope.$digest();
            }
          });
        }

        asyncQueue.push({scope: this, expression: expr, locals: locals});
      },

      $$postDigest: function(fn) {
        postDigestQueue.push(fn);
      },

      /**
       * @ngdoc method
       * @name $rootScope.Scope#$apply
       * @kind function
       *
       * @description
       * `$apply()` is used to execute an expression in angular from outside of the angular
       * framework. (For example from browser DOM events, setTimeout, XHR or third party libraries).
       * Because we are calling into the angular framework we need to perform proper scope life
       * cycle of {@link ng.$exceptionHandler exception handling},
       * {@link ng.$rootScope.Scope#$digest executing watches}.
       *
       * ## Life cycle
       *
       * # Pseudo-Code of `$apply()`
       * ```js
           function $apply(expr) {
             try {
               return $eval(expr);
             } catch (e) {
               $exceptionHandler(e);
             } finally {
               $root.$digest();
             }
           }
       * ```
       *
       *
       * Scope's `$apply()` method transitions through the following stages:
       *
       * 1. The {@link guide/expression expression} is executed using the
       *    {@link ng.$rootScope.Scope#$eval $eval()} method.
       * 2. Any exceptions from the execution of the expression are forwarded to the
       *    {@link ng.$exceptionHandler $exceptionHandler} service.
       * 3. The {@link ng.$rootScope.Scope#$watch watch} listeners are fired immediately after the
       *    expression was executed using the {@link ng.$rootScope.Scope#$digest $digest()} method.
       *
       *
       * @param {(string|function())=} exp An angular expression to be executed.
       *
       *    - `string`: execute using the rules as defined in {@link guide/expression expression}.
       *    - `function(scope)`: execute the function with current `scope` parameter.
       *
       * @returns {*} The result of evaluating the expression.
       */
      $apply: function(expr) {
        try {
          beginPhase('$apply');
          return this.$eval(expr);
        } catch (e) {
          $exceptionHandler(e);
        } finally {
          clearPhase();
          try {
            $rootScope.$digest();
          } catch (e) {
            $exceptionHandler(e);
            throw e;
          }
        }
      },

      /**
       * @ngdoc method
       * @name $rootScope.Scope#$applyAsync
       * @kind function
       *
       * @description
       * Schedule the invocation of $apply to occur at a later time. The actual time difference
       * varies across browsers, but is typically around ~10 milliseconds.
       *
       * This can be used to queue up multiple expressions which need to be evaluated in the same
       * digest.
       *
       * @param {(string|function())=} exp An angular expression to be executed.
       *
       *    - `string`: execute using the rules as defined in {@link guide/expression expression}.
       *    - `function(scope)`: execute the function with current `scope` parameter.
       */
      $applyAsync: function(expr) {
        var scope = this;
        expr && applyAsyncQueue.push($applyAsyncExpression);
        scheduleApplyAsync();

        function $applyAsyncExpression() {
          scope.$eval(expr);
        }
      },

      /**
       * @ngdoc method
       * @name $rootScope.Scope#$on
       * @kind function
       *
       * @description
       * Listens on events of a given type. See {@link ng.$rootScope.Scope#$emit $emit} for
       * discussion of event life cycle.
       *
       * The event listener function format is: `function(event, args...)`. The `event` object
       * passed into the listener has the following attributes:
       *
       *   - `targetScope` - `{Scope}`: the scope on which the event was `$emit`-ed or
       *     `$broadcast`-ed.
       *   - `currentScope` - `{Scope}`: the scope that is currently handling the event. Once the
       *     event propagates through the scope hierarchy, this property is set to null.
       *   - `name` - `{string}`: name of the event.
       *   - `stopPropagation` - `{function=}`: calling `stopPropagation` function will cancel
       *     further event propagation (available only for events that were `$emit`-ed).
       *   - `preventDefault` - `{function}`: calling `preventDefault` sets `defaultPrevented` flag
       *     to true.
       *   - `defaultPrevented` - `{boolean}`: true if `preventDefault` was called.
       *
       * @param {string} name Event name to listen on.
       * @param {function(event, ...args)} listener Function to call when the event is emitted.
       * @returns {function()} Returns a deregistration function for this listener.
       */
      $on: function(name, listener) {
        var namedListeners = this.$$listeners[name];
        if (!namedListeners) {
          this.$$listeners[name] = namedListeners = [];
        }
        namedListeners.push(listener);

        var current = this;
        do {
          if (!current.$$listenerCount[name]) {
            current.$$listenerCount[name] = 0;
          }
          current.$$listenerCount[name]++;
        } while ((current = current.$parent));

        var self = this;
        return function() {
          var indexOfListener = namedListeners.indexOf(listener);
          if (indexOfListener !== -1) {
            namedListeners[indexOfListener] = null;
            decrementListenerCount(self, 1, name);
          }
        };
      },


      /**
       * @ngdoc method
       * @name $rootScope.Scope#$emit
       * @kind function
       *
       * @description
       * Dispatches an event `name` upwards through the scope hierarchy notifying the
       * registered {@link ng.$rootScope.Scope#$on} listeners.
       *
       * The event life cycle starts at the scope on which `$emit` was called. All
       * {@link ng.$rootScope.Scope#$on listeners} listening for `name` event on this scope get
       * notified. Afterwards, the event traverses upwards toward the root scope and calls all
       * registered listeners along the way. The event will stop propagating if one of the listeners
       * cancels it.
       *
       * Any exception emitted from the {@link ng.$rootScope.Scope#$on listeners} will be passed
       * onto the {@link ng.$exceptionHandler $exceptionHandler} service.
       *
       * @param {string} name Event name to emit.
       * @param {...*} args Optional one or more arguments which will be passed onto the event listeners.
       * @return {Object} Event object (see {@link ng.$rootScope.Scope#$on}).
       */
      $emit: function(name, args) {
        var empty = [],
            namedListeners,
            scope = this,
            stopPropagation = false,
            event = {
              name: name,
              targetScope: scope,
              stopPropagation: function() {stopPropagation = true;},
              preventDefault: function() {
                event.defaultPrevented = true;
              },
              defaultPrevented: false
            },
            listenerArgs = concat([event], arguments, 1),
            i, length;

        do {
          namedListeners = scope.$$listeners[name] || empty;
          event.currentScope = scope;
          for (i = 0, length = namedListeners.length; i < length; i++) {

            // if listeners were deregistered, defragment the array
            if (!namedListeners[i]) {
              namedListeners.splice(i, 1);
              i--;
              length--;
              continue;
            }
            try {
              //allow all listeners attached to the current scope to run
              namedListeners[i].apply(null, listenerArgs);
            } catch (e) {
              $exceptionHandler(e);
            }
          }
          //if any listener on the current scope stops propagation, prevent bubbling
          if (stopPropagation) {
            event.currentScope = null;
            return event;
          }
          //traverse upwards
          scope = scope.$parent;
        } while (scope);

        event.currentScope = null;

        return event;
      },


      /**
       * @ngdoc method
       * @name $rootScope.Scope#$broadcast
       * @kind function
       *
       * @description
       * Dispatches an event `name` downwards to all child scopes (and their children) notifying the
       * registered {@link ng.$rootScope.Scope#$on} listeners.
       *
       * The event life cycle starts at the scope on which `$broadcast` was called. All
       * {@link ng.$rootScope.Scope#$on listeners} listening for `name` event on this scope get
       * notified. Afterwards, the event propagates to all direct and indirect scopes of the current
       * scope and calls all registered listeners along the way. The event cannot be canceled.
       *
       * Any exception emitted from the {@link ng.$rootScope.Scope#$on listeners} will be passed
       * onto the {@link ng.$exceptionHandler $exceptionHandler} service.
       *
       * @param {string} name Event name to broadcast.
       * @param {...*} args Optional one or more arguments which will be passed onto the event listeners.
       * @return {Object} Event object, see {@link ng.$rootScope.Scope#$on}
       */
      $broadcast: function(name, args) {
        var target = this,
            current = target,
            next = target,
            event = {
              name: name,
              targetScope: target,
              preventDefault: function() {
                event.defaultPrevented = true;
              },
              defaultPrevented: false
            };

        if (!target.$$listenerCount[name]) return event;

        var listenerArgs = concat([event], arguments, 1),
            listeners, i, length;

        //down while you can, then up and next sibling or up and next sibling until back at root
        while ((current = next)) {
          event.currentScope = current;
          listeners = current.$$listeners[name] || [];
          for (i = 0, length = listeners.length; i < length; i++) {
            // if listeners were deregistered, defragment the array
            if (!listeners[i]) {
              listeners.splice(i, 1);
              i--;
              length--;
              continue;
            }

            try {
              listeners[i].apply(null, listenerArgs);
            } catch (e) {
              $exceptionHandler(e);
            }
          }

          // Insanity Warning: scope depth-first traversal
          // yes, this code is a bit crazy, but it works and we have tests to prove it!
          // this piece should be kept in sync with the traversal in $digest
          // (though it differs due to having the extra check for $$listenerCount)
          if (!(next = ((current.$$listenerCount[name] && current.$$childHead) ||
              (current !== target && current.$$nextSibling)))) {
            while (current !== target && !(next = current.$$nextSibling)) {
              current = current.$parent;
            }
          }
        }

        event.currentScope = null;
        return event;
      }
    };

    var $rootScope = new Scope();

    //The internal queues. Expose them on the $rootScope for debugging/testing purposes.
    var asyncQueue = $rootScope.$$asyncQueue = [];
    var postDigestQueue = $rootScope.$$postDigestQueue = [];
    var applyAsyncQueue = $rootScope.$$applyAsyncQueue = [];

    return $rootScope;


    function beginPhase(phase) {
      if ($rootScope.$$phase) {
        throw $rootScopeMinErr('inprog', '{0} already in progress', $rootScope.$$phase);
      }

      $rootScope.$$phase = phase;
    }

    function clearPhase() {
      $rootScope.$$phase = null;
    }


    function decrementListenerCount(current, count, name) {
      do {
        current.$$listenerCount[name] -= count;

        if (current.$$listenerCount[name] === 0) {
          delete current.$$listenerCount[name];
        }
      } while ((current = current.$parent));
    }

    /**
     * function used as an initial value for watchers.
     * because it's unique we can easily tell it apart from other values
     */
    function initWatchVal() {}

    function flushApplyAsync() {
      while (applyAsyncQueue.length) {
        try {
          applyAsyncQueue.shift()();
        } catch (e) {
          $exceptionHandler(e);
        }
      }
      applyAsyncId = null;
    }

    function scheduleApplyAsync() {
      if (applyAsyncId === null) {
        applyAsyncId = $browser.defer(function() {
          $rootScope.$apply(flushApplyAsync);
        });
      }
    }
  }];
}

/**
 * @description
 * Private service to sanitize uris for links and images. Used by $compile and $sanitize.
 */
function $$SanitizeUriProvider() {
  var aHrefSanitizationWhitelist = /^\s*(https?|ftp|mailto|tel|file):/,
    imgSrcSanitizationWhitelist = /^\s*((https?|ftp|file|blob):|data:image\/)/;

  /**
   * @description
   * Retrieves or overrides the default regular expression that is used for whitelisting of safe
   * urls during a[href] sanitization.
   *
   * The sanitization is a security measure aimed at prevent XSS attacks via html links.
   *
   * Any url about to be assigned to a[href] via data-binding is first normalized and turned into
   * an absolute url. Afterwards, the url is matched against the `aHrefSanitizationWhitelist`
   * regular expression. If a match is found, the original url is written into the dom. Otherwise,
   * the absolute url is prefixed with `'unsafe:'` string and only then is it written into the DOM.
   *
   * @param {RegExp=} regexp New regexp to whitelist urls with.
   * @returns {RegExp|ng.$compileProvider} Current RegExp if called without value or self for
   *    chaining otherwise.
   */
  this.aHrefSanitizationWhitelist = function(regexp) {
    if (isDefined(regexp)) {
      aHrefSanitizationWhitelist = regexp;
      return this;
    }
    return aHrefSanitizationWhitelist;
  };


  /**
   * @description
   * Retrieves or overrides the default regular expression that is used for whitelisting of safe
   * urls during img[src] sanitization.
   *
   * The sanitization is a security measure aimed at prevent XSS attacks via html links.
   *
   * Any url about to be assigned to img[src] via data-binding is first normalized and turned into
   * an absolute url. Afterwards, the url is matched against the `imgSrcSanitizationWhitelist`
   * regular expression. If a match is found, the original url is written into the dom. Otherwise,
   * the absolute url is prefixed with `'unsafe:'` string and only then is it written into the DOM.
   *
   * @param {RegExp=} regexp New regexp to whitelist urls with.
   * @returns {RegExp|ng.$compileProvider} Current RegExp if called without value or self for
   *    chaining otherwise.
   */
  this.imgSrcSanitizationWhitelist = function(regexp) {
    if (isDefined(regexp)) {
      imgSrcSanitizationWhitelist = regexp;
      return this;
    }
    return imgSrcSanitizationWhitelist;
  };

  this.$get = function() {
    return function sanitizeUri(uri, isImage) {
      var regex = isImage ? imgSrcSanitizationWhitelist : aHrefSanitizationWhitelist;
      var normalizedVal;
      normalizedVal = urlResolve(uri).href;
      if (normalizedVal !== '' && !normalizedVal.match(regex)) {
        return 'unsafe:' + normalizedVal;
      }
      return uri;
    };
  };
}

/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
 *     Any commits to this file should be reviewed with security in mind.  *
 *   Changes to this file can potentially create security vulnerabilities. *
 *          An approval from 2 Core members with history of modifying      *
 *                         this file is required.                          *
 *                                                                         *
 *  Does the change somehow allow for arbitrary javascript to be executed? *
 *    Or allows for someone to change the prototype of built-in objects?   *
 *     Or gives undesired access to variables likes document or window?    *
 * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

var $sceMinErr = minErr('$sce');

var SCE_CONTEXTS = {
  HTML: 'html',
  CSS: 'css',
  URL: 'url',
  // RESOURCE_URL is a subtype of URL used in contexts where a privileged resource is sourced from a
  // url.  (e.g. ng-include, script src, templateUrl)
  RESOURCE_URL: 'resourceUrl',
  JS: 'js'
};

// Helper functions follow.

function adjustMatcher(matcher) {
  if (matcher === 'self') {
    return matcher;
  } else if (isString(matcher)) {
    // Strings match exactly except for 2 wildcards - '*' and '**'.
    // '*' matches any character except those from the set ':/.?&'.
    // '**' matches any character (like .* in a RegExp).
    // More than 2 *'s raises an error as it's ill defined.
    if (matcher.indexOf('***') > -1) {
      throw $sceMinErr('iwcard',
          'Illegal sequence *** in string matcher.  String: {0}', matcher);
    }
    matcher = escapeForRegexp(matcher).
                  replace('\\*\\*', '.*').
                  replace('\\*', '[^:/.?&;]*');
    return new RegExp('^' + matcher + '$');
  } else if (isRegExp(matcher)) {
    // The only other type of matcher allowed is a Regexp.
    // Match entire URL / disallow partial matches.
    // Flags are reset (i.e. no global, ignoreCase or multiline)
    return new RegExp('^' + matcher.source + '$');
  } else {
    throw $sceMinErr('imatcher',
        'Matchers may only be "self", string patterns or RegExp objects');
  }
}


function adjustMatchers(matchers) {
  var adjustedMatchers = [];
  if (isDefined(matchers)) {
    forEach(matchers, function(matcher) {
      adjustedMatchers.push(adjustMatcher(matcher));
    });
  }
  return adjustedMatchers;
}


/**
 * @ngdoc service
 * @name $sceDelegate
 * @kind function
 *
 * @description
 *
 * `$sceDelegate` is a service that is used by the `$sce` service to provide {@link ng.$sce Strict
 * Contextual Escaping (SCE)} services to AngularJS.
 *
 * Typically, you would configure or override the {@link ng.$sceDelegate $sceDelegate} instead of
 * the `$sce` service to customize the way Strict Contextual Escaping works in AngularJS.  This is
 * because, while the `$sce` provides numerous shorthand methods, etc., you really only need to
 * override 3 core functions (`trustAs`, `getTrusted` and `valueOf`) to replace the way things
 * work because `$sce` delegates to `$sceDelegate` for these operations.
 *
 * Refer {@link ng.$sceDelegateProvider $sceDelegateProvider} to configure this service.
 *
 * The default instance of `$sceDelegate` should work out of the box with little pain.  While you
 * can override it completely to change the behavior of `$sce`, the common case would
 * involve configuring the {@link ng.$sceDelegateProvider $sceDelegateProvider} instead by setting
 * your own whitelists and blacklists for trusting URLs used for loading AngularJS resources such as
 * templates.  Refer {@link ng.$sceDelegateProvider#resourceUrlWhitelist
 * $sceDelegateProvider.resourceUrlWhitelist} and {@link
 * ng.$sceDelegateProvider#resourceUrlBlacklist $sceDelegateProvider.resourceUrlBlacklist}
 */

/**
 * @ngdoc provider
 * @name $sceDelegateProvider
 * @description
 *
 * The `$sceDelegateProvider` provider allows developers to configure the {@link ng.$sceDelegate
 * $sceDelegate} service.  This allows one to get/set the whitelists and blacklists used to ensure
 * that the URLs used for sourcing Angular templates are safe.  Refer {@link
 * ng.$sceDelegateProvider#resourceUrlWhitelist $sceDelegateProvider.resourceUrlWhitelist} and
 * {@link ng.$sceDelegateProvider#resourceUrlBlacklist $sceDelegateProvider.resourceUrlBlacklist}
 *
 * For the general details about this service in Angular, read the main page for {@link ng.$sce
 * Strict Contextual Escaping (SCE)}.
 *
 * **Example**:  Consider the following case. <a name="example"></a>
 *
 * - your app is hosted at url `http://myapp.example.com/`
 * - but some of your templates are hosted on other domains you control such as
 *   `http://srv01.assets.example.com/`,  `http://srv02.assets.example.com/`, etc.
 * - and you have an open redirect at `http://myapp.example.com/clickThru?...`.
 *
 * Here is what a secure configuration for this scenario might look like:
 *
 * ```
 *  angular.module('myApp', []).config(function($sceDelegateProvider) {
 *    $sceDelegateProvider.resourceUrlWhitelist([
 *      // Allow same origin resource loads.
 *      'self',
 *      // Allow loading from our assets domain.  Notice the difference between * and **.
 *      'http://srv*.assets.example.com/**'
 *    ]);
 *
 *    // The blacklist overrides the whitelist so the open redirect here is blocked.
 *    $sceDelegateProvider.resourceUrlBlacklist([
 *      'http://myapp.example.com/clickThru**'
 *    ]);
 *  });
 * ```
 */

function $SceDelegateProvider() {
  this.SCE_CONTEXTS = SCE_CONTEXTS;

  // Resource URLs can also be trusted by policy.
  var resourceUrlWhitelist = ['self'],
      resourceUrlBlacklist = [];

  /**
   * @ngdoc method
   * @name $sceDelegateProvider#resourceUrlWhitelist
   * @kind function
   *
   * @param {Array=} whitelist When provided, replaces the resourceUrlWhitelist with the value
   *     provided.  This must be an array or null.  A snapshot of this array is used so further
   *     changes to the array are ignored.
   *
   *     Follow {@link ng.$sce#resourceUrlPatternItem this link} for a description of the items
   *     allowed in this array.
   *
   *     Note: **an empty whitelist array will block all URLs**!
   *
   * @return {Array} the currently set whitelist array.
   *
   * The **default value** when no whitelist has been explicitly set is `['self']` allowing only
   * same origin resource requests.
   *
   * @description
   * Sets/Gets the whitelist of trusted resource URLs.
   */
  this.resourceUrlWhitelist = function(value) {
    if (arguments.length) {
      resourceUrlWhitelist = adjustMatchers(value);
    }
    return resourceUrlWhitelist;
  };

  /**
   * @ngdoc method
   * @name $sceDelegateProvider#resourceUrlBlacklist
   * @kind function
   *
   * @param {Array=} blacklist When provided, replaces the resourceUrlBlacklist with the value
   *     provided.  This must be an array or null.  A snapshot of this array is used so further
   *     changes to the array are ignored.
   *
   *     Follow {@link ng.$sce#resourceUrlPatternItem this link} for a description of the items
   *     allowed in this array.
   *
   *     The typical usage for the blacklist is to **block
   *     [open redirects](http://cwe.mitre.org/data/definitions/601.html)** served by your domain as
   *     these would otherwise be trusted but actually return content from the redirected domain.
   *
   *     Finally, **the blacklist overrides the whitelist** and has the final say.
   *
   * @return {Array} the currently set blacklist array.
   *
   * The **default value** when no whitelist has been explicitly set is the empty array (i.e. there
   * is no blacklist.)
   *
   * @description
   * Sets/Gets the blacklist of trusted resource URLs.
   */

  this.resourceUrlBlacklist = function(value) {
    if (arguments.length) {
      resourceUrlBlacklist = adjustMatchers(value);
    }
    return resourceUrlBlacklist;
  };

  this.$get = ['$injector', function($injector) {

    var htmlSanitizer = function htmlSanitizer(html) {
      throw $sceMinErr('unsafe', 'Attempting to use an unsafe value in a safe context.');
    };

    if ($injector.has('$sanitize')) {
      htmlSanitizer = $injector.get('$sanitize');
    }


    function matchUrl(matcher, parsedUrl) {
      if (matcher === 'self') {
        return urlIsSameOrigin(parsedUrl);
      } else {
        // definitely a regex.  See adjustMatchers()
        return !!matcher.exec(parsedUrl.href);
      }
    }

    function isResourceUrlAllowedByPolicy(url) {
      var parsedUrl = urlResolve(url.toString());
      var i, n, allowed = false;
      // Ensure that at least one item from the whitelist allows this url.
      for (i = 0, n = resourceUrlWhitelist.length; i < n; i++) {
        if (matchUrl(resourceUrlWhitelist[i], parsedUrl)) {
          allowed = true;
          break;
        }
      }
      if (allowed) {
        // Ensure that no item from the blacklist blocked this url.
        for (i = 0, n = resourceUrlBlacklist.length; i < n; i++) {
          if (matchUrl(resourceUrlBlacklist[i], parsedUrl)) {
            allowed = false;
            break;
          }
        }
      }
      return allowed;
    }

    function generateHolderType(Base) {
      var holderType = function TrustedValueHolderType(trustedValue) {
        this.$$unwrapTrustedValue = function() {
          return trustedValue;
        };
      };
      if (Base) {
        holderType.prototype = new Base();
      }
      holderType.prototype.valueOf = function sceValueOf() {
        return this.$$unwrapTrustedValue();
      };
      holderType.prototype.toString = function sceToString() {
        return this.$$unwrapTrustedValue().toString();
      };
      return holderType;
    }

    var trustedValueHolderBase = generateHolderType(),
        byType = {};

    byType[SCE_CONTEXTS.HTML] = generateHolderType(trustedValueHolderBase);
    byType[SCE_CONTEXTS.CSS] = generateHolderType(trustedValueHolderBase);
    byType[SCE_CONTEXTS.URL] = generateHolderType(trustedValueHolderBase);
    byType[SCE_CONTEXTS.JS] = generateHolderType(trustedValueHolderBase);
    byType[SCE_CONTEXTS.RESOURCE_URL] = generateHolderType(byType[SCE_CONTEXTS.URL]);

    /**
     * @ngdoc method
     * @name $sceDelegate#trustAs
     *
     * @description
     * Returns an object that is trusted by angular for use in specified strict
     * contextual escaping contexts (such as ng-bind-html, ng-include, any src
     * attribute interpolation, any dom event binding attribute interpolation
     * such as for onclick,  etc.) that uses the provided value.
     * See {@link ng.$sce $sce} for enabling strict contextual escaping.
     *
     * @param {string} type The kind of context in which this value is safe for use.  e.g. url,
     *   resourceUrl, html, js and css.
     * @param {*} value The value that that should be considered trusted/safe.
     * @returns {*} A value that can be used to stand in for the provided `value` in places
     * where Angular expects a $sce.trustAs() return value.
     */
    function trustAs(type, trustedValue) {
      var Constructor = (byType.hasOwnProperty(type) ? byType[type] : null);
      if (!Constructor) {
        throw $sceMinErr('icontext',
            'Attempted to trust a value in invalid context. Context: {0}; Value: {1}',
            type, trustedValue);
      }
      if (trustedValue === null || trustedValue === undefined || trustedValue === '') {
        return trustedValue;
      }
      // All the current contexts in SCE_CONTEXTS happen to be strings.  In order to avoid trusting
      // mutable objects, we ensure here that the value passed in is actually a string.
      if (typeof trustedValue !== 'string') {
        throw $sceMinErr('itype',
            'Attempted to trust a non-string value in a content requiring a string: Context: {0}',
            type);
      }
      return new Constructor(trustedValue);
    }

    /**
     * @ngdoc method
     * @name $sceDelegate#valueOf
     *
     * @description
     * If the passed parameter had been returned by a prior call to {@link ng.$sceDelegate#trustAs
     * `$sceDelegate.trustAs`}, returns the value that had been passed to {@link
     * ng.$sceDelegate#trustAs `$sceDelegate.trustAs`}.
     *
     * If the passed parameter is not a value that had been returned by {@link
     * ng.$sceDelegate#trustAs `$sceDelegate.trustAs`}, returns it as-is.
     *
     * @param {*} value The result of a prior {@link ng.$sceDelegate#trustAs `$sceDelegate.trustAs`}
     *      call or anything else.
     * @returns {*} The `value` that was originally provided to {@link ng.$sceDelegate#trustAs
     *     `$sceDelegate.trustAs`} if `value` is the result of such a call.  Otherwise, returns
     *     `value` unchanged.
     */
    function valueOf(maybeTrusted) {
      if (maybeTrusted instanceof trustedValueHolderBase) {
        return maybeTrusted.$$unwrapTrustedValue();
      } else {
        return maybeTrusted;
      }
    }

    /**
     * @ngdoc method
     * @name $sceDelegate#getTrusted
     *
     * @description
     * Takes the result of a {@link ng.$sceDelegate#trustAs `$sceDelegate.trustAs`} call and
     * returns the originally supplied value if the queried context type is a supertype of the
     * created type.  If this condition isn't satisfied, throws an exception.
     *
     * @param {string} type The kind of context in which this value is to be used.
     * @param {*} maybeTrusted The result of a prior {@link ng.$sceDelegate#trustAs
     *     `$sceDelegate.trustAs`} call.
     * @returns {*} The value the was originally provided to {@link ng.$sceDelegate#trustAs
     *     `$sceDelegate.trustAs`} if valid in this context.  Otherwise, throws an exception.
     */
    function getTrusted(type, maybeTrusted) {
      if (maybeTrusted === null || maybeTrusted === undefined || maybeTrusted === '') {
        return maybeTrusted;
      }
      var constructor = (byType.hasOwnProperty(type) ? byType[type] : null);
      if (constructor && maybeTrusted instanceof constructor) {
        return maybeTrusted.$$unwrapTrustedValue();
      }
      // If we get here, then we may only take one of two actions.
      // 1. sanitize the value for the requested type, or
      // 2. throw an exception.
      if (type === SCE_CONTEXTS.RESOURCE_URL) {
        if (isResourceUrlAllowedByPolicy(maybeTrusted)) {
          return maybeTrusted;
        } else {
          throw $sceMinErr('insecurl',
              'Blocked loading resource from url not allowed by $sceDelegate policy.  URL: {0}',
              maybeTrusted.toString());
        }
      } else if (type === SCE_CONTEXTS.HTML) {
        return htmlSanitizer(maybeTrusted);
      }
      throw $sceMinErr('unsafe', 'Attempting to use an unsafe value in a safe context.');
    }

    return { trustAs: trustAs,
             getTrusted: getTrusted,
             valueOf: valueOf };
  }];
}


/**
 * @ngdoc provider
 * @name $sceProvider
 * @description
 *
 * The $sceProvider provider allows developers to configure the {@link ng.$sce $sce} service.
 * -   enable/disable Strict Contextual Escaping (SCE) in a module
 * -   override the default implementation with a custom delegate
 *
 * Read more about {@link ng.$sce Strict Contextual Escaping (SCE)}.
 */

/* jshint maxlen: false*/

/**
 * @ngdoc service
 * @name $sce
 * @kind function
 *
 * @description
 *
 * `$sce` is a service that provides Strict Contextual Escaping services to AngularJS.
 *
 * # Strict Contextual Escaping
 *
 * Strict Contextual Escaping (SCE) is a mode in which AngularJS requires bindings in certain
 * contexts to result in a value that is marked as safe to use for that context.  One example of
 * such a context is binding arbitrary html controlled by the user via `ng-bind-html`.  We refer
 * to these contexts as privileged or SCE contexts.
 *
 * As of version 1.2, Angular ships with SCE enabled by default.
 *
 * Note:  When enabled (the default), IE<11 in quirks mode is not supported.  In this mode, IE<11 allow
 * one to execute arbitrary javascript by the use of the expression() syntax.  Refer
 * <http://blogs.msdn.com/b/ie/archive/2008/10/16/ending-expressions.aspx> to learn more about them.
 * You can ensure your document is in standards mode and not quirks mode by adding `<!doctype html>`
 * to the top of your HTML document.
 *
 * SCE assists in writing code in way that (a) is secure by default and (b) makes auditing for
 * security vulnerabilities such as XSS, clickjacking, etc. a lot easier.
 *
 * Here's an example of a binding in a privileged context:
 *
 * ```
 * <input ng-model="userHtml">
 * <div ng-bind-html="userHtml"></div>
 * ```
 *
 * Notice that `ng-bind-html` is bound to `userHtml` controlled by the user.  With SCE
 * disabled, this application allows the user to render arbitrary HTML into the DIV.
 * In a more realistic example, one may be rendering user comments, blog articles, etc. via
 * bindings.  (HTML is just one example of a context where rendering user controlled input creates
 * security vulnerabilities.)
 *
 * For the case of HTML, you might use a library, either on the client side, or on the server side,
 * to sanitize unsafe HTML before binding to the value and rendering it in the document.
 *
 * How would you ensure that every place that used these types of bindings was bound to a value that
 * was sanitized by your library (or returned as safe for rendering by your server?)  How can you
 * ensure that you didn't accidentally delete the line that sanitized the value, or renamed some
 * properties/fields and forgot to update the binding to the sanitized value?
 *
 * To be secure by default, you want to ensure that any such bindings are disallowed unless you can
 * determine that something explicitly says it's safe to use a value for binding in that
 * context.  You can then audit your code (a simple grep would do) to ensure that this is only done
 * for those values that you can easily tell are safe - because they were received from your server,
 * sanitized by your library, etc.  You can organize your codebase to help with this - perhaps
 * allowing only the files in a specific directory to do this.  Ensuring that the internal API
 * exposed by that code doesn't markup arbitrary values as safe then becomes a more manageable task.
 *
 * In the case of AngularJS' SCE service, one uses {@link ng.$sce#trustAs $sce.trustAs}
 * (and shorthand methods such as {@link ng.$sce#trustAsHtml $sce.trustAsHtml}, etc.) to
 * obtain values that will be accepted by SCE / privileged contexts.
 *
 *
 * ## How does it work?
 *
 * In privileged contexts, directives and code will bind to the result of {@link ng.$sce#getTrusted
 * $sce.getTrusted(context, value)} rather than to the value directly.  Directives use {@link
 * ng.$sce#parseAs $sce.parseAs} rather than `$parse` to watch attribute bindings, which performs the
 * {@link ng.$sce#getTrusted $sce.getTrusted} behind the scenes on non-constant literals.
 *
 * As an example, {@link ng.directive:ngBindHtml ngBindHtml} uses {@link
 * ng.$sce#parseAsHtml $sce.parseAsHtml(binding expression)}.  Here's the actual code (slightly
 * simplified):
 *
 * ```
 * var ngBindHtmlDirective = ['$sce', function($sce) {
 *   return function(scope, element, attr) {
 *     scope.$watch($sce.parseAsHtml(attr.ngBindHtml), function(value) {
 *       element.html(value || '');
 *     });
 *   };
 * }];
 * ```
 *
 * ## Impact on loading templates
 *
 * This applies both to the {@link ng.directive:ngInclude `ng-include`} directive as well as
 * `templateUrl`'s specified by {@link guide/directive directives}.
 *
 * By default, Angular only loads templates from the same domain and protocol as the application
 * document.  This is done by calling {@link ng.$sce#getTrustedResourceUrl
 * $sce.getTrustedResourceUrl} on the template URL.  To load templates from other domains and/or
 * protocols, you may either either {@link ng.$sceDelegateProvider#resourceUrlWhitelist whitelist
 * them} or {@link ng.$sce#trustAsResourceUrl wrap it} into a trusted value.
 *
 * *Please note*:
 * The browser's
 * [Same Origin Policy](https://code.google.com/p/browsersec/wiki/Part2#Same-origin_policy_for_XMLHttpRequest)
 * and [Cross-Origin Resource Sharing (CORS)](http://www.w3.org/TR/cors/)
 * policy apply in addition to this and may further restrict whether the template is successfully
 * loaded.  This means that without the right CORS policy, loading templates from a different domain
 * won't work on all browsers.  Also, loading templates from `file://` URL does not work on some
 * browsers.
 *
 * ## This feels like too much overhead
 *
 * It's important to remember that SCE only applies to interpolation expressions.
 *
 * If your expressions are constant literals, they're automatically trusted and you don't need to
 * call `$sce.trustAs` on them (remember to include the `ngSanitize` module) (e.g.
 * `<div ng-bind-html="'<b>implicitly trusted</b>'"></div>`) just works.
 *
 * Additionally, `a[href]` and `img[src]` automatically sanitize their URLs and do not pass them
 * through {@link ng.$sce#getTrusted $sce.getTrusted}.  SCE doesn't play a role here.
 *
 * The included {@link ng.$sceDelegate $sceDelegate} comes with sane defaults to allow you to load
 * templates in `ng-include` from your application's domain without having to even know about SCE.
 * It blocks loading templates from other domains or loading templates over http from an https
 * served document.  You can change these by setting your own custom {@link
 * ng.$sceDelegateProvider#resourceUrlWhitelist whitelists} and {@link
 * ng.$sceDelegateProvider#resourceUrlBlacklist blacklists} for matching such URLs.
 *
 * This significantly reduces the overhead.  It is far easier to pay the small overhead and have an
 * application that's secure and can be audited to verify that with much more ease than bolting
 * security onto an application later.
 *
 * <a name="contexts"></a>
 * ## What trusted context types are supported?
 *
 * | Context             | Notes          |
 * |---------------------|----------------|
 * | `$sce.HTML`         | For HTML that's safe to source into the application.  The {@link ng.directive:ngBindHtml ngBindHtml} directive uses this context for bindings. If an unsafe value is encountered and the {@link ngSanitize $sanitize} module is present this will sanitize the value instead of throwing an error. |
 * | `$sce.CSS`          | For CSS that's safe to source into the application.  Currently unused.  Feel free to use it in your own directives. |
 * | `$sce.URL`          | For URLs that are safe to follow as links.  Currently unused (`<a href=` and `<img src=` sanitize their urls and don't constitute an SCE context. |
 * | `$sce.RESOURCE_URL` | For URLs that are not only safe to follow as links, but whose contents are also safe to include in your application.  Examples include `ng-include`, `src` / `ngSrc` bindings for tags other than `IMG` (e.g. `IFRAME`, `OBJECT`, etc.)  <br><br>Note that `$sce.RESOURCE_URL` makes a stronger statement about the URL than `$sce.URL` does and therefore contexts requiring values trusted for `$sce.RESOURCE_URL` can be used anywhere that values trusted for `$sce.URL` are required. |
 * | `$sce.JS`           | For JavaScript that is safe to execute in your application's context.  Currently unused.  Feel free to use it in your own directives. |
 *
 * ## Format of items in {@link ng.$sceDelegateProvider#resourceUrlWhitelist resourceUrlWhitelist}/{@link ng.$sceDelegateProvider#resourceUrlBlacklist Blacklist} <a name="resourceUrlPatternItem"></a>
 *
 *  Each element in these arrays must be one of the following:
 *
 *  - **'self'**
 *    - The special **string**, `'self'`, can be used to match against all URLs of the **same
 *      domain** as the application document using the **same protocol**.
 *  - **String** (except the special value `'self'`)
 *    - The string is matched against the full *normalized / absolute URL* of the resource
 *      being tested (substring matches are not good enough.)
 *    - There are exactly **two wildcard sequences** - `*` and `**`.  All other characters
 *      match themselves.
 *    - `*`: matches zero or more occurrences of any character other than one of the following 6
 *      characters: '`:`', '`/`', '`.`', '`?`', '`&`' and ';'.  It's a useful wildcard for use
 *      in a whitelist.
 *    - `**`: matches zero or more occurrences of *any* character.  As such, it's not
 *      appropriate for use in a scheme, domain, etc. as it would match too much.  (e.g.
 *      http://**.example.com/ would match http://evil.com/?ignore=.example.com/ and that might
 *      not have been the intention.)  Its usage at the very end of the path is ok.  (e.g.
 *      http://foo.example.com/templates/**).
 *  - **RegExp** (*see caveat below*)
 *    - *Caveat*:  While regular expressions are powerful and offer great flexibility,  their syntax
 *      (and all the inevitable escaping) makes them *harder to maintain*.  It's easy to
 *      accidentally introduce a bug when one updates a complex expression (imho, all regexes should
 *      have good test coverage).  For instance, the use of `.` in the regex is correct only in a
 *      small number of cases.  A `.` character in the regex used when matching the scheme or a
 *      subdomain could be matched against a `:` or literal `.` that was likely not intended.   It
 *      is highly recommended to use the string patterns and only fall back to regular expressions
 *      as a last resort.
 *    - The regular expression must be an instance of RegExp (i.e. not a string.)  It is
 *      matched against the **entire** *normalized / absolute URL* of the resource being tested
 *      (even when the RegExp did not have the `^` and `$` codes.)  In addition, any flags
 *      present on the RegExp (such as multiline, global, ignoreCase) are ignored.
 *    - If you are generating your JavaScript from some other templating engine (not
 *      recommended, e.g. in issue [#4006](https://github.com/angular/angular.js/issues/4006)),
 *      remember to escape your regular expression (and be aware that you might need more than
 *      one level of escaping depending on your templating engine and the way you interpolated
 *      the value.)  Do make use of your platform's escaping mechanism as it might be good
 *      enough before coding your own.  E.g. Ruby has
 *      [Regexp.escape(str)](http://www.ruby-doc.org/core-2.0.0/Regexp.html#method-c-escape)
 *      and Python has [re.escape](http://docs.python.org/library/re.html#re.escape).
 *      Javascript lacks a similar built in function for escaping.  Take a look at Google
 *      Closure library's [goog.string.regExpEscape(s)](
 *      http://docs.closure-library.googlecode.com/git/closure_goog_string_string.js.source.html#line962).
 *
 * Refer {@link ng.$sceDelegateProvider $sceDelegateProvider} for an example.
 *
 * ## Show me an example using SCE.
 *
 * <example module="mySceApp" deps="angular-sanitize.js">
 * <file name="index.html">
 *   <div ng-controller="AppController as myCtrl">
 *     <i ng-bind-html="myCtrl.explicitlyTrustedHtml" id="explicitlyTrustedHtml"></i><br><br>
 *     <b>User comments</b><br>
 *     By default, HTML that isn't explicitly trusted (e.g. Alice's comment) is sanitized when
 *     $sanitize is available.  If $sanitize isn't available, this results in an error instead of an
 *     exploit.
 *     <div class="well">
 *       <div ng-repeat="userComment in myCtrl.userComments">
 *         <b>{{userComment.name}}</b>:
 *         <span ng-bind-html="userComment.htmlComment" class="htmlComment"></span>
 *         <br>
 *       </div>
 *     </div>
 *   </div>
 * </file>
 *
 * <file name="script.js">
 *   angular.module('mySceApp', ['ngSanitize'])
 *     .controller('AppController', ['$http', '$templateCache', '$sce',
 *       function($http, $templateCache, $sce) {
 *         var self = this;
 *         $http.get("test_data.json", {cache: $templateCache}).success(function(userComments) {
 *           self.userComments = userComments;
 *         });
 *         self.explicitlyTrustedHtml = $sce.trustAsHtml(
 *             '<span onmouseover="this.textContent=&quot;Explicitly trusted HTML bypasses ' +
 *             'sanitization.&quot;">Hover over this text.</span>');
 *       }]);
 * </file>
 *
 * <file name="test_data.json">
 * [
 *   { "name": "Alice",
 *     "htmlComment":
 *         "<span onmouseover='this.textContent=\"PWN3D!\"'>Is <i>anyone</i> reading this?</span>"
 *   },
 *   { "name": "Bob",
 *     "htmlComment": "<i>Yes!</i>  Am I the only other one?"
 *   }
 * ]
 * </file>
 *
 * <file name="protractor.js" type="protractor">
 *   describe('SCE doc demo', function() {
 *     it('should sanitize untrusted values', function() {
 *       expect(element.all(by.css('.htmlComment')).first().getInnerHtml())
 *           .toBe('<span>Is <i>anyone</i> reading this?</span>');
 *     });
 *
 *     it('should NOT sanitize explicitly trusted values', function() {
 *       expect(element(by.id('explicitlyTrustedHtml')).getInnerHtml()).toBe(
 *           '<span onmouseover="this.textContent=&quot;Explicitly trusted HTML bypasses ' +
 *           'sanitization.&quot;">Hover over this text.</span>');
 *     });
 *   });
 * </file>
 * </example>
 *
 *
 *
 * ## Can I disable SCE completely?
 *
 * Yes, you can.  However, this is strongly discouraged.  SCE gives you a lot of security benefits
 * for little coding overhead.  It will be much harder to take an SCE disabled application and
 * either secure it on your own or enable SCE at a later stage.  It might make sense to disable SCE
 * for cases where you have a lot of existing code that was written before SCE was introduced and
 * you're migrating them a module at a time.
 *
 * That said, here's how you can completely disable SCE:
 *
 * ```
 * angular.module('myAppWithSceDisabledmyApp', []).config(function($sceProvider) {
 *   // Completely disable SCE.  For demonstration purposes only!
 *   // Do not use in new projects.
 *   $sceProvider.enabled(false);
 * });
 * ```
 *
 */
/* jshint maxlen: 100 */

function $SceProvider() {
  var enabled = true;

  /**
   * @ngdoc method
   * @name $sceProvider#enabled
   * @kind function
   *
   * @param {boolean=} value If provided, then enables/disables SCE.
   * @return {boolean} true if SCE is enabled, false otherwise.
   *
   * @description
   * Enables/disables SCE and returns the current value.
   */
  this.enabled = function(value) {
    if (arguments.length) {
      enabled = !!value;
    }
    return enabled;
  };


  /* Design notes on the default implementation for SCE.
   *
   * The API contract for the SCE delegate
   * -------------------------------------
   * The SCE delegate object must provide the following 3 methods:
   *
   * - trustAs(contextEnum, value)
   *     This method is used to tell the SCE service that the provided value is OK to use in the
   *     contexts specified by contextEnum.  It must return an object that will be accepted by
   *     getTrusted() for a compatible contextEnum and return this value.
   *
   * - valueOf(value)
   *     For values that were not produced by trustAs(), return them as is.  For values that were
   *     produced by trustAs(), return the corresponding input value to trustAs.  Basically, if
   *     trustAs is wrapping the given values into some type, this operation unwraps it when given
   *     such a value.
   *
   * - getTrusted(contextEnum, value)
   *     This function should return the a value that is safe to use in the context specified by
   *     contextEnum or throw and exception otherwise.
   *
   * NOTE: This contract deliberately does NOT state that values returned by trustAs() must be
   * opaque or wrapped in some holder object.  That happens to be an implementation detail.  For
   * instance, an implementation could maintain a registry of all trusted objects by context.  In
   * such a case, trustAs() would return the same object that was passed in.  getTrusted() would
   * return the same object passed in if it was found in the registry under a compatible context or
   * throw an exception otherwise.  An implementation might only wrap values some of the time based
   * on some criteria.  getTrusted() might return a value and not throw an exception for special
   * constants or objects even if not wrapped.  All such implementations fulfill this contract.
   *
   *
   * A note on the inheritance model for SCE contexts
   * ------------------------------------------------
   * I've used inheritance and made RESOURCE_URL wrapped types a subtype of URL wrapped types.  This
   * is purely an implementation details.
   *
   * The contract is simply this:
   *
   *     getTrusted($sce.RESOURCE_URL, value) succeeding implies that getTrusted($sce.URL, value)
   *     will also succeed.
   *
   * Inheritance happens to capture this in a natural way.  In some future, we
   * may not use inheritance anymore.  That is OK because no code outside of
   * sce.js and sceSpecs.js would need to be aware of this detail.
   */

  this.$get = ['$parse', '$sceDelegate', function(
                $parse,   $sceDelegate) {
    // Prereq: Ensure that we're not running in IE<11 quirks mode.  In that mode, IE < 11 allow
    // the "expression(javascript expression)" syntax which is insecure.
    if (enabled && msie < 8) {
      throw $sceMinErr('iequirks',
        'Strict Contextual Escaping does not support Internet Explorer version < 11 in quirks ' +
        'mode.  You can fix this by adding the text <!doctype html> to the top of your HTML ' +
        'document.  See http://docs.angularjs.org/api/ng.$sce for more information.');
    }

    var sce = shallowCopy(SCE_CONTEXTS);

    /**
     * @ngdoc method
     * @name $sce#isEnabled
     * @kind function
     *
     * @return {Boolean} true if SCE is enabled, false otherwise.  If you want to set the value, you
     * have to do it at module config time on {@link ng.$sceProvider $sceProvider}.
     *
     * @description
     * Returns a boolean indicating if SCE is enabled.
     */
    sce.isEnabled = function() {
      return enabled;
    };
    sce.trustAs = $sceDelegate.trustAs;
    sce.getTrusted = $sceDelegate.getTrusted;
    sce.valueOf = $sceDelegate.valueOf;

    if (!enabled) {
      sce.trustAs = sce.getTrusted = function(type, value) { return value; };
      sce.valueOf = identity;
    }

    /**
     * @ngdoc method
     * @name $sce#parseAs
     *
     * @description
     * Converts Angular {@link guide/expression expression} into a function.  This is like {@link
     * ng.$parse $parse} and is identical when the expression is a literal constant.  Otherwise, it
     * wraps the expression in a call to {@link ng.$sce#getTrusted $sce.getTrusted(*type*,
     * *result*)}
     *
     * @param {string} type The kind of SCE context in which this result will be used.
     * @param {string} expression String expression to compile.
     * @returns {function(context, locals)} a function which represents the compiled expression:
     *
     *    * `context` – `{object}` – an object against which any expressions embedded in the strings
     *      are evaluated against (typically a scope object).
     *    * `locals` – `{object=}` – local variables context object, useful for overriding values in
     *      `context`.
     */
    sce.parseAs = function sceParseAs(type, expr) {
      var parsed = $parse(expr);
      if (parsed.literal && parsed.constant) {
        return parsed;
      } else {
        return $parse(expr, function(value) {
          return sce.getTrusted(type, value);
        });
      }
    };

    /**
     * @ngdoc method
     * @name $sce#trustAs
     *
     * @description
     * Delegates to {@link ng.$sceDelegate#trustAs `$sceDelegate.trustAs`}.  As such,
     * returns an object that is trusted by angular for use in specified strict contextual
     * escaping contexts (such as ng-bind-html, ng-include, any src attribute
     * interpolation, any dom event binding attribute interpolation such as for onclick,  etc.)
     * that uses the provided value.  See * {@link ng.$sce $sce} for enabling strict contextual
     * escaping.
     *
     * @param {string} type The kind of context in which this value is safe for use.  e.g. url,
     *   resource_url, html, js and css.
     * @param {*} value The value that that should be considered trusted/safe.
     * @returns {*} A value that can be used to stand in for the provided `value` in places
     * where Angular expects a $sce.trustAs() return value.
     */

    /**
     * @ngdoc method
     * @name $sce#trustAsHtml
     *
     * @description
     * Shorthand method.  `$sce.trustAsHtml(value)` →
     *     {@link ng.$sceDelegate#trustAs `$sceDelegate.trustAs($sce.HTML, value)`}
     *
     * @param {*} value The value to trustAs.
     * @returns {*} An object that can be passed to {@link ng.$sce#getTrustedHtml
     *     $sce.getTrustedHtml(value)} to obtain the original value.  (privileged directives
     *     only accept expressions that are either literal constants or are the
     *     return value of {@link ng.$sce#trustAs $sce.trustAs}.)
     */

    /**
     * @ngdoc method
     * @name $sce#trustAsUrl
     *
     * @description
     * Shorthand method.  `$sce.trustAsUrl(value)` →
     *     {@link ng.$sceDelegate#trustAs `$sceDelegate.trustAs($sce.URL, value)`}
     *
     * @param {*} value The value to trustAs.
     * @returns {*} An object that can be passed to {@link ng.$sce#getTrustedUrl
     *     $sce.getTrustedUrl(value)} to obtain the original value.  (privileged directives
     *     only accept expressions that are either literal constants or are the
     *     return value of {@link ng.$sce#trustAs $sce.trustAs}.)
     */

    /**
     * @ngdoc method
     * @name $sce#trustAsResourceUrl
     *
     * @description
     * Shorthand method.  `$sce.trustAsResourceUrl(value)` →
     *     {@link ng.$sceDelegate#trustAs `$sceDelegate.trustAs($sce.RESOURCE_URL, value)`}
     *
     * @param {*} value The value to trustAs.
     * @returns {*} An object that can be passed to {@link ng.$sce#getTrustedResourceUrl
     *     $sce.getTrustedResourceUrl(value)} to obtain the original value.  (privileged directives
     *     only accept expressions that are either literal constants or are the return
     *     value of {@link ng.$sce#trustAs $sce.trustAs}.)
     */

    /**
     * @ngdoc method
     * @name $sce#trustAsJs
     *
     * @description
     * Shorthand method.  `$sce.trustAsJs(value)` →
     *     {@link ng.$sceDelegate#trustAs `$sceDelegate.trustAs($sce.JS, value)`}
     *
     * @param {*} value The value to trustAs.
     * @returns {*} An object that can be passed to {@link ng.$sce#getTrustedJs
     *     $sce.getTrustedJs(value)} to obtain the original value.  (privileged directives
     *     only accept expressions that are either literal constants or are the
     *     return value of {@link ng.$sce#trustAs $sce.trustAs}.)
     */

    /**
     * @ngdoc method
     * @name $sce#getTrusted
     *
     * @description
     * Delegates to {@link ng.$sceDelegate#getTrusted `$sceDelegate.getTrusted`}.  As such,
     * takes the result of a {@link ng.$sce#trustAs `$sce.trustAs`}() call and returns the
     * originally supplied value if the queried context type is a supertype of the created type.
     * If this condition isn't satisfied, throws an exception.
     *
     * @param {string} type The kind of context in which this value is to be used.
     * @param {*} maybeTrusted The result of a prior {@link ng.$sce#trustAs `$sce.trustAs`}
     *                         call.
     * @returns {*} The value the was originally provided to
     *              {@link ng.$sce#trustAs `$sce.trustAs`} if valid in this context.
     *              Otherwise, throws an exception.
     */

    /**
     * @ngdoc method
     * @name $sce#getTrustedHtml
     *
     * @description
     * Shorthand method.  `$sce.getTrustedHtml(value)` →
     *     {@link ng.$sceDelegate#getTrusted `$sceDelegate.getTrusted($sce.HTML, value)`}
     *
     * @param {*} value The value to pass to `$sce.getTrusted`.
     * @returns {*} The return value of `$sce.getTrusted($sce.HTML, value)`
     */

    /**
     * @ngdoc method
     * @name $sce#getTrustedCss
     *
     * @description
     * Shorthand method.  `$sce.getTrustedCss(value)` →
     *     {@link ng.$sceDelegate#getTrusted `$sceDelegate.getTrusted($sce.CSS, value)`}
     *
     * @param {*} value The value to pass to `$sce.getTrusted`.
     * @returns {*} The return value of `$sce.getTrusted($sce.CSS, value)`
     */

    /**
     * @ngdoc method
     * @name $sce#getTrustedUrl
     *
     * @description
     * Shorthand method.  `$sce.getTrustedUrl(value)` →
     *     {@link ng.$sceDelegate#getTrusted `$sceDelegate.getTrusted($sce.URL, value)`}
     *
     * @param {*} value The value to pass to `$sce.getTrusted`.
     * @returns {*} The return value of `$sce.getTrusted($sce.URL, value)`
     */

    /**
     * @ngdoc method
     * @name $sce#getTrustedResourceUrl
     *
     * @description
     * Shorthand method.  `$sce.getTrustedResourceUrl(value)` →
     *     {@link ng.$sceDelegate#getTrusted `$sceDelegate.getTrusted($sce.RESOURCE_URL, value)`}
     *
     * @param {*} value The value to pass to `$sceDelegate.getTrusted`.
     * @returns {*} The return value of `$sce.getTrusted($sce.RESOURCE_URL, value)`
     */

    /**
     * @ngdoc method
     * @name $sce#getTrustedJs
     *
     * @description
     * Shorthand method.  `$sce.getTrustedJs(value)` →
     *     {@link ng.$sceDelegate#getTrusted `$sceDelegate.getTrusted($sce.JS, value)`}
     *
     * @param {*} value The value to pass to `$sce.getTrusted`.
     * @returns {*} The return value of `$sce.getTrusted($sce.JS, value)`
     */

    /**
     * @ngdoc method
     * @name $sce#parseAsHtml
     *
     * @description
     * Shorthand method.  `$sce.parseAsHtml(expression string)` →
     *     {@link ng.$sce#parseAs `$sce.parseAs($sce.HTML, value)`}
     *
     * @param {string} expression String expression to compile.
     * @returns {function(context, locals)} a function which represents the compiled expression:
     *
     *    * `context` – `{object}` – an object against which any expressions embedded in the strings
     *      are evaluated against (typically a scope object).
     *    * `locals` – `{object=}` – local variables context object, useful for overriding values in
     *      `context`.
     */

    /**
     * @ngdoc method
     * @name $sce#parseAsCss
     *
     * @description
     * Shorthand method.  `$sce.parseAsCss(value)` →
     *     {@link ng.$sce#parseAs `$sce.parseAs($sce.CSS, value)`}
     *
     * @param {string} expression String expression to compile.
     * @returns {function(context, locals)} a function which represents the compiled expression:
     *
     *    * `context` – `{object}` – an object against which any expressions embedded in the strings
     *      are evaluated against (typically a scope object).
     *    * `locals` – `{object=}` – local variables context object, useful for overriding values in
     *      `context`.
     */

    /**
     * @ngdoc method
     * @name $sce#parseAsUrl
     *
     * @description
     * Shorthand method.  `$sce.parseAsUrl(value)` →
     *     {@link ng.$sce#parseAs `$sce.parseAs($sce.URL, value)`}
     *
     * @param {string} expression String expression to compile.
     * @returns {function(context, locals)} a function which represents the compiled expression:
     *
     *    * `context` – `{object}` – an object against which any expressions embedded in the strings
     *      are evaluated against (typically a scope object).
     *    * `locals` – `{object=}` – local variables context object, useful for overriding values in
     *      `context`.
     */

    /**
     * @ngdoc method
     * @name $sce#parseAsResourceUrl
     *
     * @description
     * Shorthand method.  `$sce.parseAsResourceUrl(value)` →
     *     {@link ng.$sce#parseAs `$sce.parseAs($sce.RESOURCE_URL, value)`}
     *
     * @param {string} expression String expression to compile.
     * @returns {function(context, locals)} a function which represents the compiled expression:
     *
     *    * `context` – `{object}` – an object against which any expressions embedded in the strings
     *      are evaluated against (typically a scope object).
     *    * `locals` – `{object=}` – local variables context object, useful for overriding values in
     *      `context`.
     */

    /**
     * @ngdoc method
     * @name $sce#parseAsJs
     *
     * @description
     * Shorthand method.  `$sce.parseAsJs(value)` →
     *     {@link ng.$sce#parseAs `$sce.parseAs($sce.JS, value)`}
     *
     * @param {string} expression String expression to compile.
     * @returns {function(context, locals)} a function which represents the compiled expression:
     *
     *    * `context` – `{object}` – an object against which any expressions embedded in the strings
     *      are evaluated against (typically a scope object).
     *    * `locals` – `{object=}` – local variables context object, useful for overriding values in
     *      `context`.
     */

    // Shorthand delegations.
    var parse = sce.parseAs,
        getTrusted = sce.getTrusted,
        trustAs = sce.trustAs;

    forEach(SCE_CONTEXTS, function(enumValue, name) {
      var lName = lowercase(name);
      sce[camelCase("parse_as_" + lName)] = function(expr) {
        return parse(enumValue, expr);
      };
      sce[camelCase("get_trusted_" + lName)] = function(value) {
        return getTrusted(enumValue, value);
      };
      sce[camelCase("trust_as_" + lName)] = function(value) {
        return trustAs(enumValue, value);
      };
    });

    return sce;
  }];
}

/**
 * !!! This is an undocumented "private" service !!!
 *
 * @name $sniffer
 * @requires $window
 * @requires $document
 *
 * @property {boolean} history Does the browser support html5 history api ?
 * @property {boolean} transitions Does the browser support CSS transition events ?
 * @property {boolean} animations Does the browser support CSS animation events ?
 *
 * @description
 * This is very simple implementation of testing browser's features.
 */
function $SnifferProvider() {
  this.$get = ['$window', '$document', function($window, $document) {
    var eventSupport = {},
        android =
          int((/android (\d+)/.exec(lowercase(($window.navigator || {}).userAgent)) || [])[1]),
        boxee = /Boxee/i.test(($window.navigator || {}).userAgent),
        document = $document[0] || {},
        vendorPrefix,
        vendorRegex = /^(Moz|webkit|ms)(?=[A-Z])/,
        bodyStyle = document.body && document.body.style,
        transitions = false,
        animations = false,
        match;

    if (bodyStyle) {
      for (var prop in bodyStyle) {
        if (match = vendorRegex.exec(prop)) {
          vendorPrefix = match[0];
          vendorPrefix = vendorPrefix.substr(0, 1).toUpperCase() + vendorPrefix.substr(1);
          break;
        }
      }

      if (!vendorPrefix) {
        vendorPrefix = ('WebkitOpacity' in bodyStyle) && 'webkit';
      }

      transitions = !!(('transition' in bodyStyle) || (vendorPrefix + 'Transition' in bodyStyle));
      animations  = !!(('animation' in bodyStyle) || (vendorPrefix + 'Animation' in bodyStyle));

      if (android && (!transitions ||  !animations)) {
        transitions = isString(document.body.style.webkitTransition);
        animations = isString(document.body.style.webkitAnimation);
      }
    }


    return {
      // Android has history.pushState, but it does not update location correctly
      // so let's not use the history API at all.
      // http://code.google.com/p/android/issues/detail?id=17471
      // https://github.com/angular/angular.js/issues/904

      // older webkit browser (533.9) on Boxee box has exactly the same problem as Android has
      // so let's not use the history API also
      // We are purposefully using `!(android < 4)` to cover the case when `android` is undefined
      // jshint -W018
      history: !!($window.history && $window.history.pushState && !(android < 4) && !boxee),
      // jshint +W018
      hasEvent: function(event) {
        // IE9 implements 'input' event it's so fubared that we rather pretend that it doesn't have
        // it. In particular the event is not fired when backspace or delete key are pressed or
        // when cut operation is performed.
        // IE10+ implements 'input' event but it erroneously fires under various situations,
        // e.g. when placeholder changes, or a form is focused.
        if (event === 'input' && msie <= 11) return false;

        if (isUndefined(eventSupport[event])) {
          var divElm = document.createElement('div');
          eventSupport[event] = 'on' + event in divElm;
        }

        return eventSupport[event];
      },
      csp: csp(),
      vendorPrefix: vendorPrefix,
      transitions: transitions,
      animations: animations,
      android: android
    };
  }];
}

var $compileMinErr = minErr('$compile');

/**
 * @ngdoc service
 * @name $templateRequest
 *
 * @description
 * The `$templateRequest` service runs security checks then downloads the provided template using
 * `$http` and, upon success, stores the contents inside of `$templateCache`. If the HTTP request
 * fails or the response data of the HTTP request is empty, a `$compile` error will be thrown (the
 * exception can be thwarted by setting the 2nd parameter of the function to true). Note that the
 * contents of `$templateCache` are trusted, so the call to `$sce.getTrustedUrl(tpl)` is omitted
 * when `tpl` is of type string and `$templateCache` has the matching entry.
 *
 * @param {string|TrustedResourceUrl} tpl The HTTP request template URL
 * @param {boolean=} ignoreRequestError Whether or not to ignore the exception when the request fails or the template is empty
 *
 * @return {Promise} the HTTP Promise for the given.
 *
 * @property {number} totalPendingRequests total amount of pending template requests being downloaded.
 */
function $TemplateRequestProvider() {
  this.$get = ['$templateCache', '$http', '$q', '$sce', function($templateCache, $http, $q, $sce) {
    function handleRequestFn(tpl, ignoreRequestError) {
      handleRequestFn.totalPendingRequests++;

      // We consider the template cache holds only trusted templates, so
      // there's no need to go through whitelisting again for keys that already
      // are included in there. This also makes Angular accept any script
      // directive, no matter its name. However, we still need to unwrap trusted
      // types.
      if (!isString(tpl) || !$templateCache.get(tpl)) {
        tpl = $sce.getTrustedResourceUrl(tpl);
      }

      var transformResponse = $http.defaults && $http.defaults.transformResponse;

      if (isArray(transformResponse)) {
        transformResponse = transformResponse.filter(function(transformer) {
          return transformer !== defaultHttpResponseTransform;
        });
      } else if (transformResponse === defaultHttpResponseTransform) {
        transformResponse = null;
      }

      var httpOptions = {
        cache: $templateCache,
        transformResponse: transformResponse
      };

      return $http.get(tpl, httpOptions)
        ['finally'](function() {
          handleRequestFn.totalPendingRequests--;
        })
        .then(function(response) {
          return response.data;
        }, handleError);

      function handleError(resp) {
        if (!ignoreRequestError) {
          throw $compileMinErr('tpload', 'Failed to load template: {0}', tpl);
        }
        return $q.reject(resp);
      }
    }

    handleRequestFn.totalPendingRequests = 0;

    return handleRequestFn;
  }];
}

function $$TestabilityProvider() {
  this.$get = ['$rootScope', '$browser', '$location',
       function($rootScope,   $browser,   $location) {

    /**
     * @name $testability
     *
     * @description
     * The private $$testability service provides a collection of methods for use when debugging
     * or by automated test and debugging tools.
     */
    var testability = {};

    /**
     * @name $$testability#findBindings
     *
     * @description
     * Returns an array of elements that are bound (via ng-bind or {{}})
     * to expressions matching the input.
     *
     * @param {Element} element The element root to search from.
     * @param {string} expression The binding expression to match.
     * @param {boolean} opt_exactMatch If true, only returns exact matches
     *     for the expression. Filters and whitespace are ignored.
     */
    testability.findBindings = function(element, expression, opt_exactMatch) {
      var bindings = element.getElementsByClassName('ng-binding');
      var matches = [];
      forEach(bindings, function(binding) {
        var dataBinding = angular.element(binding).data('$binding');
        if (dataBinding) {
          forEach(dataBinding, function(bindingName) {
            if (opt_exactMatch) {
              var matcher = new RegExp('(^|\\s)' + escapeForRegexp(expression) + '(\\s|\\||$)');
              if (matcher.test(bindingName)) {
                matches.push(binding);
              }
            } else {
              if (bindingName.indexOf(expression) != -1) {
                matches.push(binding);
              }
            }
          });
        }
      });
      return matches;
    };

    /**
     * @name $$testability#findModels
     *
     * @description
     * Returns an array of elements that are two-way found via ng-model to
     * expressions matching the input.
     *
     * @param {Element} element The element root to search from.
     * @param {string} expression The model expression to match.
     * @param {boolean} opt_exactMatch If true, only returns exact matches
     *     for the expression.
     */
    testability.findModels = function(element, expression, opt_exactMatch) {
      var prefixes = ['ng-', 'data-ng-', 'ng\\:'];
      for (var p = 0; p < prefixes.length; ++p) {
        var attributeEquals = opt_exactMatch ? '=' : '*=';
        var selector = '[' + prefixes[p] + 'model' + attributeEquals + '"' + expression + '"]';
        var elements = element.querySelectorAll(selector);
        if (elements.length) {
          return elements;
        }
      }
    };

    /**
     * @name $$testability#getLocation
     *
     * @description
     * Shortcut for getting the location in a browser agnostic way. Returns
     *     the path, search, and hash. (e.g. /path?a=b#hash)
     */
    testability.getLocation = function() {
      return $location.url();
    };

    /**
     * @name $$testability#setLocation
     *
     * @description
     * Shortcut for navigating to a location without doing a full page reload.
     *
     * @param {string} url The location url (path, search and hash,
     *     e.g. /path?a=b#hash) to go to.
     */
    testability.setLocation = function(url) {
      if (url !== $location.url()) {
        $location.url(url);
        $rootScope.$digest();
      }
    };

    /**
     * @name $$testability#whenStable
     *
     * @description
     * Calls the callback when $timeout and $http requests are completed.
     *
     * @param {function} callback
     */
    testability.whenStable = function(callback) {
      $browser.notifyWhenNoOutstandingRequests(callback);
    };

    return testability;
  }];
}

function $TimeoutProvider() {
  this.$get = ['$rootScope', '$browser', '$q', '$$q', '$exceptionHandler',
       function($rootScope,   $browser,   $q,   $$q,   $exceptionHandler) {
    var deferreds = {};


     /**
      * @ngdoc service
      * @name $timeout
      *
      * @description
      * Angular's wrapper for `window.setTimeout`. The `fn` function is wrapped into a try/catch
      * block and delegates any exceptions to
      * {@link ng.$exceptionHandler $exceptionHandler} service.
      *
      * The return value of registering a timeout function is a promise, which will be resolved when
      * the timeout is reached and the timeout function is executed.
      *
      * To cancel a timeout request, call `$timeout.cancel(promise)`.
      *
      * In tests you can use {@link ngMock.$timeout `$timeout.flush()`} to
      * synchronously flush the queue of deferred functions.
      *
      * @param {function()} fn A function, whose execution should be delayed.
      * @param {number=} [delay=0] Delay in milliseconds.
      * @param {boolean=} [invokeApply=true] If set to `false` skips model dirty checking, otherwise
      *   will invoke `fn` within the {@link ng.$rootScope.Scope#$apply $apply} block.
      * @returns {Promise} Promise that will be resolved when the timeout is reached. The value this
      *   promise will be resolved with is the return value of the `fn` function.
      *
      */
    function timeout(fn, delay, invokeApply) {
      var skipApply = (isDefined(invokeApply) && !invokeApply),
          deferred = (skipApply ? $$q : $q).defer(),
          promise = deferred.promise,
          timeoutId;

      timeoutId = $browser.defer(function() {
        try {
          deferred.resolve(fn());
        } catch (e) {
          deferred.reject(e);
          $exceptionHandler(e);
        }
        finally {
          delete deferreds[promise.$$timeoutId];
        }

        if (!skipApply) $rootScope.$apply();
      }, delay);

      promise.$$timeoutId = timeoutId;
      deferreds[timeoutId] = deferred;

      return promise;
    }


     /**
      * @ngdoc method
      * @name $timeout#cancel
      *
      * @description
      * Cancels a task associated with the `promise`. As a result of this, the promise will be
      * resolved with a rejection.
      *
      * @param {Promise=} promise Promise returned by the `$timeout` function.
      * @returns {boolean} Returns `true` if the task hasn't executed yet and was successfully
      *   canceled.
      */
    timeout.cancel = function(promise) {
      if (promise && promise.$$timeoutId in deferreds) {
        deferreds[promise.$$timeoutId].reject('canceled');
        delete deferreds[promise.$$timeoutId];
        return $browser.defer.cancel(promise.$$timeoutId);
      }
      return false;
    };

    return timeout;
  }];
}

// NOTE:  The usage of window and document instead of $window and $document here is
// deliberate.  This service depends on the specific behavior of anchor nodes created by the
// browser (resolving and parsing URLs) that is unlikely to be provided by mock objects and
// cause us to break tests.  In addition, when the browser resolves a URL for XHR, it
// doesn't know about mocked locations and resolves URLs to the real document - which is
// exactly the behavior needed here.  There is little value is mocking these out for this
// service.
var urlParsingNode = document.createElement("a");
var originUrl = urlResolve(window.location.href);


/**
 *
 * Implementation Notes for non-IE browsers
 * ----------------------------------------
 * Assigning a URL to the href property of an anchor DOM node, even one attached to the DOM,
 * results both in the normalizing and parsing of the URL.  Normalizing means that a relative
 * URL will be resolved into an absolute URL in the context of the application document.
 * Parsing means that the anchor node's host, hostname, protocol, port, pathname and related
 * properties are all populated to reflect the normalized URL.  This approach has wide
 * compatibility - Safari 1+, Mozilla 1+, Opera 7+,e etc.  See
 * http://www.aptana.com/reference/html/api/HTMLAnchorElement.html
 *
 * Implementation Notes for IE
 * ---------------------------
 * IE <= 10 normalizes the URL when assigned to the anchor node similar to the other
 * browsers.  However, the parsed components will not be set if the URL assigned did not specify
 * them.  (e.g. if you assign a.href = "foo", then a.protocol, a.host, etc. will be empty.)  We
 * work around that by performing the parsing in a 2nd step by taking a previously normalized
 * URL (e.g. by assigning to a.href) and assigning it a.href again.  This correctly populates the
 * properties such as protocol, hostname, port, etc.
 *
 * References:
 *   http://developer.mozilla.org/en-US/docs/Web/API/HTMLAnchorElement
 *   http://www.aptana.com/reference/html/api/HTMLAnchorElement.html
 *   http://url.spec.whatwg.org/#urlutils
 *   https://github.com/angular/angular.js/pull/2902
 *   http://james.padolsey.com/javascript/parsing-urls-with-the-dom/
 *
 * @kind function
 * @param {string} url The URL to be parsed.
 * @description Normalizes and parses a URL.
 * @returns {object} Returns the normalized URL as a dictionary.
 *
 *   | member name   | Description    |
 *   |---------------|----------------|
 *   | href          | A normalized version of the provided URL if it was not an absolute URL |
 *   | protocol      | The protocol including the trailing colon                              |
 *   | host          | The host and port (if the port is non-default) of the normalizedUrl    |
 *   | search        | The search params, minus the question mark                             |
 *   | hash          | The hash string, minus the hash symbol
 *   | hostname      | The hostname
 *   | port          | The port, without ":"
 *   | pathname      | The pathname, beginning with "/"
 *
 */
function urlResolve(url) {
  var href = url;

  if (msie) {
    // Normalize before parse.  Refer Implementation Notes on why this is
    // done in two steps on IE.
    urlParsingNode.setAttribute("href", href);
    href = urlParsingNode.href;
  }

  urlParsingNode.setAttribute('href', href);

  // urlParsingNode provides the UrlUtils interface - http://url.spec.whatwg.org/#urlutils
  return {
    href: urlParsingNode.href,
    protocol: urlParsingNode.protocol ? urlParsingNode.protocol.replace(/:$/, '') : '',
    host: urlParsingNode.host,
    search: urlParsingNode.search ? urlParsingNode.search.replace(/^\?/, '') : '',
    hash: urlParsingNode.hash ? urlParsingNode.hash.replace(/^#/, '') : '',
    hostname: urlParsingNode.hostname,
    port: urlParsingNode.port,
    pathname: (urlParsingNode.pathname.charAt(0) === '/')
      ? urlParsingNode.pathname
      : '/' + urlParsingNode.pathname
  };
}

/**
 * Parse a request URL and determine whether this is a same-origin request as the application document.
 *
 * @param {string|object} requestUrl The url of the request as a string that will be resolved
 * or a parsed URL object.
 * @returns {boolean} Whether the request is for the same origin as the application document.
 */
function urlIsSameOrigin(requestUrl) {
  var parsed = (isString(requestUrl)) ? urlResolve(requestUrl) : requestUrl;
  return (parsed.protocol === originUrl.protocol &&
          parsed.host === originUrl.host);
}

/**
 * @ngdoc service
 * @name $window
 *
 * @description
 * A reference to the browser's `window` object. While `window`
 * is globally available in JavaScript, it causes testability problems, because
 * it is a global variable. In angular we always refer to it through the
 * `$window` service, so it may be overridden, removed or mocked for testing.
 *
 * Expressions, like the one defined for the `ngClick` directive in the example
 * below, are evaluated with respect to the current scope.  Therefore, there is
 * no risk of inadvertently coding in a dependency on a global value in such an
 * expression.
 *
 * @example
   <example module="windowExample">
     <file name="index.html">
       <script>
         angular.module('windowExample', [])
           .controller('ExampleController', ['$scope', '$window', function($scope, $window) {
             $scope.greeting = 'Hello, World!';
             $scope.doGreeting = function(greeting) {
               $window.alert(greeting);
             };
           }]);
       </script>
       <div ng-controller="ExampleController">
         <input type="text" ng-model="greeting" />
         <button ng-click="doGreeting(greeting)">ALERT</button>
       </div>
     </file>
     <file name="protractor.js" type="protractor">
      it('should display the greeting in the input box', function() {
       element(by.model('greeting')).sendKeys('Hello, E2E Tests');
       // If we click the button it will block the test runner
       // element(':button').click();
      });
     </file>
   </example>
 */
function $WindowProvider() {
  this.$get = valueFn(window);
}

/* global currencyFilter: true,
 dateFilter: true,
 filterFilter: true,
 jsonFilter: true,
 limitToFilter: true,
 lowercaseFilter: true,
 numberFilter: true,
 orderByFilter: true,
 uppercaseFilter: true,
 */

/**
 * @ngdoc provider
 * @name $filterProvider
 * @description
 *
 * Filters are just functions which transform input to an output. However filters need to be
 * Dependency Injected. To achieve this a filter definition consists of a factory function which is
 * annotated with dependencies and is responsible for creating a filter function.
 *
 * <div class="alert alert-warning">
 * **Note:** Filter names must be valid angular {@link expression} identifiers, such as `uppercase` or `orderBy`.
 * Names with special characters, such as hyphens and dots, are not allowed. If you wish to namespace
 * your filters, then you can use capitalization (`myappSubsectionFilterx`) or underscores
 * (`myapp_subsection_filterx`).
 * </div>
 *
 * ```js
 *   // Filter registration
 *   function MyModule($provide, $filterProvider) {
 *     // create a service to demonstrate injection (not always needed)
 *     $provide.value('greet', function(name){
 *       return 'Hello ' + name + '!';
 *     });
 *
 *     // register a filter factory which uses the
 *     // greet service to demonstrate DI.
 *     $filterProvider.register('greet', function(greet){
 *       // return the filter function which uses the greet service
 *       // to generate salutation
 *       return function(text) {
 *         // filters need to be forgiving so check input validity
 *         return text && greet(text) || text;
 *       };
 *     });
 *   }
 * ```
 *
 * The filter function is registered with the `$injector` under the filter name suffix with
 * `Filter`.
 *
 * ```js
 *   it('should be the same instance', inject(
 *     function($filterProvider) {
 *       $filterProvider.register('reverse', function(){
 *         return ...;
 *       });
 *     },
 *     function($filter, reverseFilter) {
 *       expect($filter('reverse')).toBe(reverseFilter);
 *     });
 * ```
 *
 *
 * For more information about how angular filters work, and how to create your own filters, see
 * {@link guide/filter Filters} in the Angular Developer Guide.
 */

/**
 * @ngdoc service
 * @name $filter
 * @kind function
 * @description
 * Filters are used for formatting data displayed to the user.
 *
 * The general syntax in templates is as follows:
 *
 *         {{ expression [| filter_name[:parameter_value] ... ] }}
 *
 * @param {String} name Name of the filter function to retrieve
 * @return {Function} the filter function
 * @example
   <example name="$filter" module="filterExample">
     <file name="index.html">
       <div ng-controller="MainCtrl">
        <h3>{{ originalText }}</h3>
        <h3>{{ filteredText }}</h3>
       </div>
     </file>

     <file name="script.js">
      angular.module('filterExample', [])
      .controller('MainCtrl', function($scope, $filter) {
        $scope.originalText = 'hello';
        $scope.filteredText = $filter('uppercase')($scope.originalText);
      });
     </file>
   </example>
  */
$FilterProvider.$inject = ['$provide'];
function $FilterProvider($provide) {
  var suffix = 'Filter';

  /**
   * @ngdoc method
   * @name $filterProvider#register
   * @param {string|Object} name Name of the filter function, or an object map of filters where
   *    the keys are the filter names and the values are the filter factories.
   *
   *    <div class="alert alert-warning">
   *    **Note:** Filter names must be valid angular {@link expression} identifiers, such as `uppercase` or `orderBy`.
   *    Names with special characters, such as hyphens and dots, are not allowed. If you wish to namespace
   *    your filters, then you can use capitalization (`myappSubsectionFilterx`) or underscores
   *    (`myapp_subsection_filterx`).
   *    </div>
   * @returns {Object} Registered filter instance, or if a map of filters was provided then a map
   *    of the registered filter instances.
   */
  function register(name, factory) {
    if (isObject(name)) {
      var filters = {};
      forEach(name, function(filter, key) {
        filters[key] = register(key, filter);
      });
      return filters;
    } else {
      return $provide.factory(name + suffix, factory);
    }
  }
  this.register = register;

  this.$get = ['$injector', function($injector) {
    return function(name) {
      return $injector.get(name + suffix);
    };
  }];

  ////////////////////////////////////////

  /* global
    currencyFilter: false,
    dateFilter: false,
    filterFilter: false,
    jsonFilter: false,
    limitToFilter: false,
    lowercaseFilter: false,
    numberFilter: false,
    orderByFilter: false,
    uppercaseFilter: false,
  */

  register('currency', currencyFilter);
  register('date', dateFilter);
  register('filter', filterFilter);
  register('json', jsonFilter);
  register('limitTo', limitToFilter);
  register('lowercase', lowercaseFilter);
  register('number', numberFilter);
  register('orderBy', orderByFilter);
  register('uppercase', uppercaseFilter);
}

/**
 * @ngdoc filter
 * @name filter
 * @kind function
 *
 * @description
 * Selects a subset of items from `array` and returns it as a new array.
 *
 * @param {Array} array The source array.
 * @param {string|Object|function()} expression The predicate to be used for selecting items from
 *   `array`.
 *
 *   Can be one of:
 *
 *   - `string`: The string is used for matching against the contents of the `array`. All strings or
 *     objects with string properties in `array` that match this string will be returned. This also
 *     applies to nested object properties.
 *     The predicate can be negated by prefixing the string with `!`.
 *
 *   - `Object`: A pattern object can be used to filter specific properties on objects contained
 *     by `array`. For example `{name:"M", phone:"1"}` predicate will return an array of items
 *     which have property `name` containing "M" and property `phone` containing "1". A special
 *     property name `$` can be used (as in `{$:"text"}`) to accept a match against any
 *     property of the object or its nested object properties. That's equivalent to the simple
 *     substring match with a `string` as described above. The predicate can be negated by prefixing
 *     the string with `!`.
 *     For example `{name: "!M"}` predicate will return an array of items which have property `name`
 *     not containing "M".
 *
 *     Note that a named property will match properties on the same level only, while the special
 *     `$` property will match properties on the same level or deeper. E.g. an array item like
 *     `{name: {first: 'John', last: 'Doe'}}` will **not** be matched by `{name: 'John'}`, but
 *     **will** be matched by `{$: 'John'}`.
 *
 *   - `function(value, index)`: A predicate function can be used to write arbitrary filters. The
 *     function is called for each element of `array`. The final result is an array of those
 *     elements that the predicate returned true for.
 *
 * @param {function(actual, expected)|true|undefined} comparator Comparator which is used in
 *     determining if the expected value (from the filter expression) and actual value (from
 *     the object in the array) should be considered a match.
 *
 *   Can be one of:
 *
 *   - `function(actual, expected)`:
 *     The function will be given the object value and the predicate value to compare and
 *     should return true if both values should be considered equal.
 *
 *   - `true`: A shorthand for `function(actual, expected) { return angular.equals(actual, expected)}`.
 *     This is essentially strict comparison of expected and actual.
 *
 *   - `false|undefined`: A short hand for a function which will look for a substring match in case
 *     insensitive way.
 *
 * @example
   <example>
     <file name="index.html">
       <div ng-init="friends = [{name:'John', phone:'555-1276'},
                                {name:'Mary', phone:'800-BIG-MARY'},
                                {name:'Mike', phone:'555-4321'},
                                {name:'Adam', phone:'555-5678'},
                                {name:'Julie', phone:'555-8765'},
                                {name:'Juliette', phone:'555-5678'}]"></div>

       Search: <input ng-model="searchText">
       <table id="searchTextResults">
         <tr><th>Name</th><th>Phone</th></tr>
         <tr ng-repeat="friend in friends | filter:searchText">
           <td>{{friend.name}}</td>
           <td>{{friend.phone}}</td>
         </tr>
       </table>
       <hr>
       Any: <input ng-model="search.$"> <br>
       Name only <input ng-model="search.name"><br>
       Phone only <input ng-model="search.phone"><br>
       Equality <input type="checkbox" ng-model="strict"><br>
       <table id="searchObjResults">
         <tr><th>Name</th><th>Phone</th></tr>
         <tr ng-repeat="friendObj in friends | filter:search:strict">
           <td>{{friendObj.name}}</td>
           <td>{{friendObj.phone}}</td>
         </tr>
       </table>
     </file>
     <file name="protractor.js" type="protractor">
       var expectFriendNames = function(expectedNames, key) {
         element.all(by.repeater(key + ' in friends').column(key + '.name')).then(function(arr) {
           arr.forEach(function(wd, i) {
             expect(wd.getText()).toMatch(expectedNames[i]);
           });
         });
       };

       it('should search across all fields when filtering with a string', function() {
         var searchText = element(by.model('searchText'));
         searchText.clear();
         searchText.sendKeys('m');
         expectFriendNames(['Mary', 'Mike', 'Adam'], 'friend');

         searchText.clear();
         searchText.sendKeys('76');
         expectFriendNames(['John', 'Julie'], 'friend');
       });

       it('should search in specific fields when filtering with a predicate object', function() {
         var searchAny = element(by.model('search.$'));
         searchAny.clear();
         searchAny.sendKeys('i');
         expectFriendNames(['Mary', 'Mike', 'Julie', 'Juliette'], 'friendObj');
       });
       it('should use a equal comparison when comparator is true', function() {
         var searchName = element(by.model('search.name'));
         var strict = element(by.model('strict'));
         searchName.clear();
         searchName.sendKeys('Julie');
         strict.click();
         expectFriendNames(['Julie'], 'friendObj');
       });
     </file>
   </example>
 */
function filterFilter() {
  return function(array, expression, comparator) {
    if (!isArray(array)) return array;

    var expressionType = (expression !== null) ? typeof expression : 'null';
    var predicateFn;
    var matchAgainstAnyProp;

    switch (expressionType) {
      case 'function':
        predicateFn = expression;
        break;
      case 'boolean':
      case 'null':
      case 'number':
      case 'string':
        matchAgainstAnyProp = true;
        //jshint -W086
      case 'object':
        //jshint +W086
        predicateFn = createPredicateFn(expression, comparator, matchAgainstAnyProp);
        break;
      default:
        return array;
    }

    return array.filter(predicateFn);
  };
}

// Helper functions for `filterFilter`
function createPredicateFn(expression, comparator, matchAgainstAnyProp) {
  var shouldMatchPrimitives = isObject(expression) && ('$' in expression);
  var predicateFn;

  if (comparator === true) {
    comparator = equals;
  } else if (!isFunction(comparator)) {
    comparator = function(actual, expected) {
      if (isUndefined(actual)) {
        // No substring matching against `undefined`
        return false;
      }
      if ((actual === null) || (expected === null)) {
        // No substring matching against `null`; only match against `null`
        return actual === expected;
      }
      if (isObject(actual) || isObject(expected)) {
        // Prevent an object to be considered equal to a string like `'[object'`
        return false;
      }

      actual = lowercase('' + actual);
      expected = lowercase('' + expected);
      return actual.indexOf(expected) !== -1;
    };
  }

  predicateFn = function(item) {
    if (shouldMatchPrimitives && !isObject(item)) {
      return deepCompare(item, expression.$, comparator, false);
    }
    return deepCompare(item, expression, comparator, matchAgainstAnyProp);
  };

  return predicateFn;
}

function deepCompare(actual, expected, comparator, matchAgainstAnyProp, dontMatchWholeObject) {
  var actualType = (actual !== null) ? typeof actual : 'null';
  var expectedType = (expected !== null) ? typeof expected : 'null';

  if ((expectedType === 'string') && (expected.charAt(0) === '!')) {
    return !deepCompare(actual, expected.substring(1), comparator, matchAgainstAnyProp);
  } else if (isArray(actual)) {
    // In case `actual` is an array, consider it a match
    // if ANY of it's items matches `expected`
    return actual.some(function(item) {
      return deepCompare(item, expected, comparator, matchAgainstAnyProp);
    });
  }

  switch (actualType) {
    case 'object':
      var key;
      if (matchAgainstAnyProp) {
        for (key in actual) {
          if ((key.charAt(0) !== '$') && deepCompare(actual[key], expected, comparator, true)) {
            return true;
          }
        }
        return dontMatchWholeObject ? false : deepCompare(actual, expected, comparator, false);
      } else if (expectedType === 'object') {
        for (key in expected) {
          var expectedVal = expected[key];
          if (isFunction(expectedVal) || isUndefined(expectedVal)) {
            continue;
          }

          var matchAnyProperty = key === '$';
          var actualVal = matchAnyProperty ? actual : actual[key];
          if (!deepCompare(actualVal, expectedVal, comparator, matchAnyProperty, matchAnyProperty)) {
            return false;
          }
        }
        return true;
      } else {
        return comparator(actual, expected);
      }
      break;
    case 'function':
      return false;
    default:
      return comparator(actual, expected);
  }
}

/**
 * @ngdoc filter
 * @name currency
 * @kind function
 *
 * @description
 * Formats a number as a currency (ie $1,234.56). When no currency symbol is provided, default
 * symbol for current locale is used.
 *
 * @param {number} amount Input to filter.
 * @param {string=} symbol Currency symbol or identifier to be displayed.
 * @param {number=} fractionSize Number of decimal places to round the amount to, defaults to default max fraction size for current locale
 * @returns {string} Formatted number.
 *
 *
 * @example
   <example module="currencyExample">
     <file name="index.html">
       <script>
         angular.module('currencyExample', [])
           .controller('ExampleController', ['$scope', function($scope) {
             $scope.amount = 1234.56;
           }]);
       </script>
       <div ng-controller="ExampleController">
         <input type="number" ng-model="amount"> <br>
         default currency symbol ($): <span id="currency-default">{{amount | currency}}</span><br>
         custom currency identifier (USD$): <span id="currency-custom">{{amount | currency:"USD$"}}</span>
         no fractions (0): <span id="currency-no-fractions">{{amount | currency:"USD$":0}}</span>
       </div>
     </file>
     <file name="protractor.js" type="protractor">
       it('should init with 1234.56', function() {
         expect(element(by.id('currency-default')).getText()).toBe('$1,234.56');
         expect(element(by.id('currency-custom')).getText()).toBe('USD$1,234.56');
         expect(element(by.id('currency-no-fractions')).getText()).toBe('USD$1,235');
       });
       it('should update', function() {
         if (browser.params.browser == 'safari') {
           // Safari does not understand the minus key. See
           // https://github.com/angular/protractor/issues/481
           return;
         }
         element(by.model('amount')).clear();
         element(by.model('amount')).sendKeys('-1234');
         expect(element(by.id('currency-default')).getText()).toBe('($1,234.00)');
         expect(element(by.id('currency-custom')).getText()).toBe('(USD$1,234.00)');
         expect(element(by.id('currency-no-fractions')).getText()).toBe('(USD$1,234)');
       });
     </file>
   </example>
 */
currencyFilter.$inject = ['$locale'];
function currencyFilter($locale) {
  var formats = $locale.NUMBER_FORMATS;
  return function(amount, currencySymbol, fractionSize) {
    if (isUndefined(currencySymbol)) {
      currencySymbol = formats.CURRENCY_SYM;
    }

    if (isUndefined(fractionSize)) {
      fractionSize = formats.PATTERNS[1].maxFrac;
    }

    // if null or undefined pass it through
    return (amount == null)
        ? amount
        : formatNumber(amount, formats.PATTERNS[1], formats.GROUP_SEP, formats.DECIMAL_SEP, fractionSize).
            replace(/\u00A4/g, currencySymbol);
  };
}

/**
 * @ngdoc filter
 * @name number
 * @kind function
 *
 * @description
 * Formats a number as text.
 *
 * If the input is null or undefined, it will just be returned.
 * If the input is infinite (Infinity/-Infinity) the Infinity symbol '∞' is returned.
 * If the input is not a number an empty string is returned.
 *
 * @param {number|string} number Number to format.
 * @param {(number|string)=} fractionSize Number of decimal places to round the number to.
 * If this is not provided then the fraction size is computed from the current locale's number
 * formatting pattern. In the case of the default locale, it will be 3.
 * @returns {string} Number rounded to decimalPlaces and places a “,” after each third digit.
 *
 * @example
   <example module="numberFilterExample">
     <file name="index.html">
       <script>
         angular.module('numberFilterExample', [])
           .controller('ExampleController', ['$scope', function($scope) {
             $scope.val = 1234.56789;
           }]);
       </script>
       <div ng-controller="ExampleController">
         Enter number: <input ng-model='val'><br>
         Default formatting: <span id='number-default'>{{val | number}}</span><br>
         No fractions: <span>{{val | number:0}}</span><br>
         Negative number: <span>{{-val | number:4}}</span>
       </div>
     </file>
     <file name="protractor.js" type="protractor">
       it('should format numbers', function() {
         expect(element(by.id('number-default')).getText()).toBe('1,234.568');
         expect(element(by.binding('val | number:0')).getText()).toBe('1,235');
         expect(element(by.binding('-val | number:4')).getText()).toBe('-1,234.5679');
       });

       it('should update', function() {
         element(by.model('val')).clear();
         element(by.model('val')).sendKeys('3374.333');
         expect(element(by.id('number-default')).getText()).toBe('3,374.333');
         expect(element(by.binding('val | number:0')).getText()).toBe('3,374');
         expect(element(by.binding('-val | number:4')).getText()).toBe('-3,374.3330');
      });
     </file>
   </example>
 */


numberFilter.$inject = ['$locale'];
function numberFilter($locale) {
  var formats = $locale.NUMBER_FORMATS;
  return function(number, fractionSize) {

    // if null or undefined pass it through
    return (number == null)
        ? number
        : formatNumber(number, formats.PATTERNS[0], formats.GROUP_SEP, formats.DECIMAL_SEP,
                       fractionSize);
  };
}

var DECIMAL_SEP = '.';
function formatNumber(number, pattern, groupSep, decimalSep, fractionSize) {
  if (!isFinite(number) || isObject(number)) return '';

  var isNegative = number < 0;
  number = Math.abs(number);
  var numStr = number + '',
      formatedText = '',
      parts = [];

  var hasExponent = false;
  if (numStr.indexOf('e') !== -1) {
    var match = numStr.match(/([\d\.]+)e(-?)(\d+)/);
    if (match && match[2] == '-' && match[3] > fractionSize + 1) {
      number = 0;
    } else {
      formatedText = numStr;
      hasExponent = true;
    }
  }

  if (!hasExponent) {
    var fractionLen = (numStr.split(DECIMAL_SEP)[1] || '').length;

    // determine fractionSize if it is not specified
    if (isUndefined(fractionSize)) {
      fractionSize = Math.min(Math.max(pattern.minFrac, fractionLen), pattern.maxFrac);
    }

    // safely round numbers in JS without hitting imprecisions of floating-point arithmetics
    // inspired by:
    // https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Math/round
    number = +(Math.round(+(number.toString() + 'e' + fractionSize)).toString() + 'e' + -fractionSize);

    var fraction = ('' + number).split(DECIMAL_SEP);
    var whole = fraction[0];
    fraction = fraction[1] || '';

    var i, pos = 0,
        lgroup = pattern.lgSize,
        group = pattern.gSize;

    if (whole.length >= (lgroup + group)) {
      pos = whole.length - lgroup;
      for (i = 0; i < pos; i++) {
        if ((pos - i) % group === 0 && i !== 0) {
          formatedText += groupSep;
        }
        formatedText += whole.charAt(i);
      }
    }

    for (i = pos; i < whole.length; i++) {
      if ((whole.length - i) % lgroup === 0 && i !== 0) {
        formatedText += groupSep;
      }
      formatedText += whole.charAt(i);
    }

    // format fraction part.
    while (fraction.length < fractionSize) {
      fraction += '0';
    }

    if (fractionSize && fractionSize !== "0") formatedText += decimalSep + fraction.substr(0, fractionSize);
  } else {
    if (fractionSize > 0 && number < 1) {
      formatedText = number.toFixed(fractionSize);
      number = parseFloat(formatedText);
    }
  }

  if (number === 0) {
    isNegative = false;
  }

  parts.push(isNegative ? pattern.negPre : pattern.posPre,
             formatedText,
             isNegative ? pattern.negSuf : pattern.posSuf);
  return parts.join('');
}

function padNumber(num, digits, trim) {
  var neg = '';
  if (num < 0) {
    neg =  '-';
    num = -num;
  }
  num = '' + num;
  while (num.length < digits) num = '0' + num;
  if (trim)
    num = num.substr(num.length - digits);
  return neg + num;
}


function dateGetter(name, size, offset, trim) {
  offset = offset || 0;
  return function(date) {
    var value = date['get' + name]();
    if (offset > 0 || value > -offset)
      value += offset;
    if (value === 0 && offset == -12) value = 12;
    return padNumber(value, size, trim);
  };
}

function dateStrGetter(name, shortForm) {
  return function(date, formats) {
    var value = date['get' + name]();
    var get = uppercase(shortForm ? ('SHORT' + name) : name);

    return formats[get][value];
  };
}

function timeZoneGetter(date) {
  var zone = -1 * date.getTimezoneOffset();
  var paddedZone = (zone >= 0) ? "+" : "";

  paddedZone += padNumber(Math[zone > 0 ? 'floor' : 'ceil'](zone / 60), 2) +
                padNumber(Math.abs(zone % 60), 2);

  return paddedZone;
}

function getFirstThursdayOfYear(year) {
    // 0 = index of January
    var dayOfWeekOnFirst = (new Date(year, 0, 1)).getDay();
    // 4 = index of Thursday (+1 to account for 1st = 5)
    // 11 = index of *next* Thursday (+1 account for 1st = 12)
    return new Date(year, 0, ((dayOfWeekOnFirst <= 4) ? 5 : 12) - dayOfWeekOnFirst);
}

function getThursdayThisWeek(datetime) {
    return new Date(datetime.getFullYear(), datetime.getMonth(),
      // 4 = index of Thursday
      datetime.getDate() + (4 - datetime.getDay()));
}

function weekGetter(size) {
   return function(date) {
      var firstThurs = getFirstThursdayOfYear(date.getFullYear()),
         thisThurs = getThursdayThisWeek(date);

      var diff = +thisThurs - +firstThurs,
         result = 1 + Math.round(diff / 6.048e8); // 6.048e8 ms per week

      return padNumber(result, size);
   };
}

function ampmGetter(date, formats) {
  return date.getHours() < 12 ? formats.AMPMS[0] : formats.AMPMS[1];
}

function eraGetter(date, formats) {
  return date.getFullYear() <= 0 ? formats.ERAS[0] : formats.ERAS[1];
}

function longEraGetter(date, formats) {
  return date.getFullYear() <= 0 ? formats.ERANAMES[0] : formats.ERANAMES[1];
}

var DATE_FORMATS = {
  yyyy: dateGetter('FullYear', 4),
    yy: dateGetter('FullYear', 2, 0, true),
     y: dateGetter('FullYear', 1),
  MMMM: dateStrGetter('Month'),
   MMM: dateStrGetter('Month', true),
    MM: dateGetter('Month', 2, 1),
     M: dateGetter('Month', 1, 1),
    dd: dateGetter('Date', 2),
     d: dateGetter('Date', 1),
    HH: dateGetter('Hours', 2),
     H: dateGetter('Hours', 1),
    hh: dateGetter('Hours', 2, -12),
     h: dateGetter('Hours', 1, -12),
    mm: dateGetter('Minutes', 2),
     m: dateGetter('Minutes', 1),
    ss: dateGetter('Seconds', 2),
     s: dateGetter('Seconds', 1),
     // while ISO 8601 requires fractions to be prefixed with `.` or `,`
     // we can be just safely rely on using `sss` since we currently don't support single or two digit fractions
   sss: dateGetter('Milliseconds', 3),
  EEEE: dateStrGetter('Day'),
   EEE: dateStrGetter('Day', true),
     a: ampmGetter,
     Z: timeZoneGetter,
    ww: weekGetter(2),
     w: weekGetter(1),
     G: eraGetter,
     GG: eraGetter,
     GGG: eraGetter,
     GGGG: longEraGetter
};

var DATE_FORMATS_SPLIT = /((?:[^yMdHhmsaZEwG']+)|(?:'(?:[^']|'')*')|(?:E+|y+|M+|d+|H+|h+|m+|s+|a|Z|G+|w+))(.*)/,
    NUMBER_STRING = /^\-?\d+$/;

/**
 * @ngdoc filter
 * @name date
 * @kind function
 *
 * @description
 *   Formats `date` to a string based on the requested `format`.
 *
 *   `format` string can be composed of the following elements:
 *
 *   * `'yyyy'`: 4 digit representation of year (e.g. AD 1 => 0001, AD 2010 => 2010)
 *   * `'yy'`: 2 digit representation of year, padded (00-99). (e.g. AD 2001 => 01, AD 2010 => 10)
 *   * `'y'`: 1 digit representation of year, e.g. (AD 1 => 1, AD 199 => 199)
 *   * `'MMMM'`: Month in year (January-December)
 *   * `'MMM'`: Month in year (Jan-Dec)
 *   * `'MM'`: Month in year, padded (01-12)
 *   * `'M'`: Month in year (1-12)
 *   * `'dd'`: Day in month, padded (01-31)
 *   * `'d'`: Day in month (1-31)
 *   * `'EEEE'`: Day in Week,(Sunday-Saturday)
 *   * `'EEE'`: Day in Week, (Sun-Sat)
 *   * `'HH'`: Hour in day, padded (00-23)
 *   * `'H'`: Hour in day (0-23)
 *   * `'hh'`: Hour in AM/PM, padded (01-12)
 *   * `'h'`: Hour in AM/PM, (1-12)
 *   * `'mm'`: Minute in hour, padded (00-59)
 *   * `'m'`: Minute in hour (0-59)
 *   * `'ss'`: Second in minute, padded (00-59)
 *   * `'s'`: Second in minute (0-59)
 *   * `'sss'`: Millisecond in second, padded (000-999)
 *   * `'a'`: AM/PM marker
 *   * `'Z'`: 4 digit (+sign) representation of the timezone offset (-1200-+1200)
 *   * `'ww'`: Week of year, padded (00-53). Week 01 is the week with the first Thursday of the year
 *   * `'w'`: Week of year (0-53). Week 1 is the week with the first Thursday of the year
 *   * `'G'`, `'GG'`, `'GGG'`: The abbreviated form of the era string (e.g. 'AD')
 *   * `'GGGG'`: The long form of the era string (e.g. 'Anno Domini')
 *
 *   `format` string can also be one of the following predefined
 *   {@link guide/i18n localizable formats}:
 *
 *   * `'medium'`: equivalent to `'MMM d, y h:mm:ss a'` for en_US locale
 *     (e.g. Sep 3, 2010 12:05:08 PM)
 *   * `'short'`: equivalent to `'M/d/yy h:mm a'` for en_US  locale (e.g. 9/3/10 12:05 PM)
 *   * `'fullDate'`: equivalent to `'EEEE, MMMM d, y'` for en_US  locale
 *     (e.g. Friday, September 3, 2010)
 *   * `'longDate'`: equivalent to `'MMMM d, y'` for en_US  locale (e.g. September 3, 2010)
 *   * `'mediumDate'`: equivalent to `'MMM d, y'` for en_US  locale (e.g. Sep 3, 2010)
 *   * `'shortDate'`: equivalent to `'M/d/yy'` for en_US locale (e.g. 9/3/10)
 *   * `'mediumTime'`: equivalent to `'h:mm:ss a'` for en_US locale (e.g. 12:05:08 PM)
 *   * `'shortTime'`: equivalent to `'h:mm a'` for en_US locale (e.g. 12:05 PM)
 *
 *   `format` string can contain literal values. These need to be escaped by surrounding with single quotes (e.g.
 *   `"h 'in the morning'"`). In order to output a single quote, escape it - i.e., two single quotes in a sequence
 *   (e.g. `"h 'o''clock'"`).
 *
 * @param {(Date|number|string)} date Date to format either as Date object, milliseconds (string or
 *    number) or various ISO 8601 datetime string formats (e.g. yyyy-MM-ddTHH:mm:ss.sssZ and its
 *    shorter versions like yyyy-MM-ddTHH:mmZ, yyyy-MM-dd or yyyyMMddTHHmmssZ). If no timezone is
 *    specified in the string input, the time is considered to be in the local timezone.
 * @param {string=} format Formatting rules (see Description). If not specified,
 *    `mediumDate` is used.
 * @param {string=} timezone Timezone to be used for formatting. Right now, only `'UTC'` is supported.
 *    If not specified, the timezone of the browser will be used.
 * @returns {string} Formatted string or the input if input is not recognized as date/millis.
 *
 * @example
   <example>
     <file name="index.html">
       <span ng-non-bindable>{{1288323623006 | date:'medium'}}</span>:
           <span>{{1288323623006 | date:'medium'}}</span><br>
       <span ng-non-bindable>{{1288323623006 | date:'yyyy-MM-dd HH:mm:ss Z'}}</span>:
          <span>{{1288323623006 | date:'yyyy-MM-dd HH:mm:ss Z'}}</span><br>
       <span ng-non-bindable>{{1288323623006 | date:'MM/dd/yyyy @ h:mma'}}</span>:
          <span>{{'1288323623006' | date:'MM/dd/yyyy @ h:mma'}}</span><br>
       <span ng-non-bindable>{{1288323623006 | date:"MM/dd/yyyy 'at' h:mma"}}</span>:
          <span>{{'1288323623006' | date:"MM/dd/yyyy 'at' h:mma"}}</span><br>
     </file>
     <file name="protractor.js" type="protractor">
       it('should format date', function() {
         expect(element(by.binding("1288323623006 | date:'medium'")).getText()).
            toMatch(/Oct 2\d, 2010 \d{1,2}:\d{2}:\d{2} (AM|PM)/);
         expect(element(by.binding("1288323623006 | date:'yyyy-MM-dd HH:mm:ss Z'")).getText()).
            toMatch(/2010\-10\-2\d \d{2}:\d{2}:\d{2} (\-|\+)?\d{4}/);
         expect(element(by.binding("'1288323623006' | date:'MM/dd/yyyy @ h:mma'")).getText()).
            toMatch(/10\/2\d\/2010 @ \d{1,2}:\d{2}(AM|PM)/);
         expect(element(by.binding("'1288323623006' | date:\"MM/dd/yyyy 'at' h:mma\"")).getText()).
            toMatch(/10\/2\d\/2010 at \d{1,2}:\d{2}(AM|PM)/);
       });
     </file>
   </example>
 */
dateFilter.$inject = ['$locale'];
function dateFilter($locale) {


  var R_ISO8601_STR = /^(\d{4})-?(\d\d)-?(\d\d)(?:T(\d\d)(?::?(\d\d)(?::?(\d\d)(?:\.(\d+))?)?)?(Z|([+-])(\d\d):?(\d\d))?)?$/;
                     // 1        2       3         4          5          6          7          8  9     10      11
  function jsonStringToDate(string) {
    var match;
    if (match = string.match(R_ISO8601_STR)) {
      var date = new Date(0),
          tzHour = 0,
          tzMin  = 0,
          dateSetter = match[8] ? date.setUTCFullYear : date.setFullYear,
          timeSetter = match[8] ? date.setUTCHours : date.setHours;

      if (match[9]) {
        tzHour = int(match[9] + match[10]);
        tzMin = int(match[9] + match[11]);
      }
      dateSetter.call(date, int(match[1]), int(match[2]) - 1, int(match[3]));
      var h = int(match[4] || 0) - tzHour;
      var m = int(match[5] || 0) - tzMin;
      var s = int(match[6] || 0);
      var ms = Math.round(parseFloat('0.' + (match[7] || 0)) * 1000);
      timeSetter.call(date, h, m, s, ms);
      return date;
    }
    return string;
  }


  return function(date, format, timezone) {
    var text = '',
        parts = [],
        fn, match;

    format = format || 'mediumDate';
    format = $locale.DATETIME_FORMATS[format] || format;
    if (isString(date)) {
      date = NUMBER_STRING.test(date) ? int(date) : jsonStringToDate(date);
    }

    if (isNumber(date)) {
      date = new Date(date);
    }

    if (!isDate(date)) {
      return date;
    }

    while (format) {
      match = DATE_FORMATS_SPLIT.exec(format);
      if (match) {
        parts = concat(parts, match, 1);
        format = parts.pop();
      } else {
        parts.push(format);
        format = null;
      }
    }

    if (timezone && timezone === 'UTC') {
      date = new Date(date.getTime());
      date.setMinutes(date.getMinutes() + date.getTimezoneOffset());
    }
    forEach(parts, function(value) {
      fn = DATE_FORMATS[value];
      text += fn ? fn(date, $locale.DATETIME_FORMATS)
                 : value.replace(/(^'|'$)/g, '').replace(/''/g, "'");
    });

    return text;
  };
}


/**
 * @ngdoc filter
 * @name json
 * @kind function
 *
 * @description
 *   Allows you to convert a JavaScript object into JSON string.
 *
 *   This filter is mostly useful for debugging. When using the double curly {{value}} notation
 *   the binding is automatically converted to JSON.
 *
 * @param {*} object Any JavaScript object (including arrays and primitive types) to filter.
 * @param {number=} spacing The number of spaces to use per indentation, defaults to 2.
 * @returns {string} JSON string.
 *
 *
 * @example
   <example>
     <file name="index.html">
       <pre id="default-spacing">{{ {'name':'value'} | json }}</pre>
       <pre id="custom-spacing">{{ {'name':'value'} | json:4 }}</pre>
     </file>
     <file name="protractor.js" type="protractor">
       it('should jsonify filtered objects', function() {
         expect(element(by.id('default-spacing')).getText()).toMatch(/\{\n  "name": ?"value"\n}/);
         expect(element(by.id('custom-spacing')).getText()).toMatch(/\{\n    "name": ?"value"\n}/);
       });
     </file>
   </example>
 *
 */
function jsonFilter() {
  return function(object, spacing) {
    if (isUndefined(spacing)) {
        spacing = 2;
    }
    return toJson(object, spacing);
  };
}


/**
 * @ngdoc filter
 * @name lowercase
 * @kind function
 * @description
 * Converts string to lowercase.
 * @see angular.lowercase
 */
var lowercaseFilter = valueFn(lowercase);


/**
 * @ngdoc filter
 * @name uppercase
 * @kind function
 * @description
 * Converts string to uppercase.
 * @see angular.uppercase
 */
var uppercaseFilter = valueFn(uppercase);

/**
 * @ngdoc filter
 * @name limitTo
 * @kind function
 *
 * @description
 * Creates a new array or string containing only a specified number of elements. The elements
 * are taken from either the beginning or the end of the source array, string or number, as specified by
 * the value and sign (positive or negative) of `limit`. If a number is used as input, it is
 * converted to a string.
 *
 * @param {Array|string|number} input Source array, string or number to be limited.
 * @param {string|number} limit The length of the returned array or string. If the `limit` number
 *     is positive, `limit` number of items from the beginning of the source array/string are copied.
 *     If the number is negative, `limit` number  of items from the end of the source array/string
 *     are copied. The `limit` will be trimmed if it exceeds `array.length`
 * @returns {Array|string} A new sub-array or substring of length `limit` or less if input array
 *     had less than `limit` elements.
 *
 * @example
   <example module="limitToExample">
     <file name="index.html">
       <script>
         angular.module('limitToExample', [])
           .controller('ExampleController', ['$scope', function($scope) {
             $scope.numbers = [1,2,3,4,5,6,7,8,9];
             $scope.letters = "abcdefghi";
             $scope.longNumber = 2345432342;
             $scope.numLimit = 3;
             $scope.letterLimit = 3;
             $scope.longNumberLimit = 3;
           }]);
       </script>
       <div ng-controller="ExampleController">
         Limit {{numbers}} to: <input type="number" step="1" ng-model="numLimit">
         <p>Output numbers: {{ numbers | limitTo:numLimit }}</p>
         Limit {{letters}} to: <input type="number" step="1" ng-model="letterLimit">
         <p>Output letters: {{ letters | limitTo:letterLimit }}</p>
         Limit {{longNumber}} to: <input type="number" step="1" ng-model="longNumberLimit">
         <p>Output long number: {{ longNumber | limitTo:longNumberLimit }}</p>
       </div>
     </file>
     <file name="protractor.js" type="protractor">
       var numLimitInput = element(by.model('numLimit'));
       var letterLimitInput = element(by.model('letterLimit'));
       var longNumberLimitInput = element(by.model('longNumberLimit'));
       var limitedNumbers = element(by.binding('numbers | limitTo:numLimit'));
       var limitedLetters = element(by.binding('letters | limitTo:letterLimit'));
       var limitedLongNumber = element(by.binding('longNumber | limitTo:longNumberLimit'));

       it('should limit the number array to first three items', function() {
         expect(numLimitInput.getAttribute('value')).toBe('3');
         expect(letterLimitInput.getAttribute('value')).toBe('3');
         expect(longNumberLimitInput.getAttribute('value')).toBe('3');
         expect(limitedNumbers.getText()).toEqual('Output numbers: [1,2,3]');
         expect(limitedLetters.getText()).toEqual('Output letters: abc');
         expect(limitedLongNumber.getText()).toEqual('Output long number: 234');
       });

       // There is a bug in safari and protractor that doesn't like the minus key
       // it('should update the output when -3 is entered', function() {
       //   numLimitInput.clear();
       //   numLimitInput.sendKeys('-3');
       //   letterLimitInput.clear();
       //   letterLimitInput.sendKeys('-3');
       //   longNumberLimitInput.clear();
       //   longNumberLimitInput.sendKeys('-3');
       //   expect(limitedNumbers.getText()).toEqual('Output numbers: [7,8,9]');
       //   expect(limitedLetters.getText()).toEqual('Output letters: ghi');
       //   expect(limitedLongNumber.getText()).toEqual('Output long number: 342');
       // });

       it('should not exceed the maximum size of input array', function() {
         numLimitInput.clear();
         numLimitInput.sendKeys('100');
         letterLimitInput.clear();
         letterLimitInput.sendKeys('100');
         longNumberLimitInput.clear();
         longNumberLimitInput.sendKeys('100');
         expect(limitedNumbers.getText()).toEqual('Output numbers: [1,2,3,4,5,6,7,8,9]');
         expect(limitedLetters.getText()).toEqual('Output letters: abcdefghi');
         expect(limitedLongNumber.getText()).toEqual('Output long number: 2345432342');
       });
     </file>
   </example>
*/
function limitToFilter() {
  return function(input, limit) {
    if (isNumber(input)) input = input.toString();
    if (!isArray(input) && !isString(input)) return input;

    if (Math.abs(Number(limit)) === Infinity) {
      limit = Number(limit);
    } else {
      limit = int(limit);
    }

    //NaN check on limit
    if (limit) {
      return limit > 0 ? input.slice(0, limit) : input.slice(limit);
    } else {
      return isString(input) ? "" : [];
    }
  };
}

/**
 * @ngdoc filter
 * @name orderBy
 * @kind function
 *
 * @description
 * Orders a specified `array` by the `expression` predicate. It is ordered alphabetically
 * for strings and numerically for numbers. Note: if you notice numbers are not being sorted
 * correctly, make sure they are actually being saved as numbers and not strings.
 *
 * @param {Array} array The array to sort.
 * @param {function(*)|string|Array.<(function(*)|string)>=} expression A predicate to be
 *    used by the comparator to determine the order of elements.
 *
 *    Can be one of:
 *
 *    - `function`: Getter function. The result of this function will be sorted using the
 *      `<`, `===`, `>` operator.
 *    - `string`: An Angular expression. The result of this expression is used to compare elements
 *      (for example `name` to sort by a property called `name` or `name.substr(0, 3)` to sort by
 *      3 first characters of a property called `name`). The result of a constant expression
 *      is interpreted as a property name to be used in comparisons (for example `"special name"`
 *      to sort object by the value of their `special name` property). An expression can be
 *      optionally prefixed with `+` or `-` to control ascending or descending sort order
 *      (for example, `+name` or `-name`). If no property is provided, (e.g. `'+'`) then the array
 *      element itself is used to compare where sorting.
 *    - `Array`: An array of function or string predicates. The first predicate in the array
 *      is used for sorting, but when two items are equivalent, the next predicate is used.
 *
 *    If the predicate is missing or empty then it defaults to `'+'`.
 *
 * @param {boolean=} reverse Reverse the order of the array.
 * @returns {Array} Sorted copy of the source array.
 *
 *
 * @example
 * The example below demonstrates a simple ngRepeat, where the data is sorted
 * by age in descending order (predicate is set to `'-age'`).
 * `reverse` is not set, which means it defaults to `false`.
   <example module="orderByExample">
     <file name="index.html">
       <script>
         angular.module('orderByExample', [])
           .controller('ExampleController', ['$scope', function($scope) {
             $scope.friends =
                 [{name:'John', phone:'555-1212', age:10},
                  {name:'Mary', phone:'555-9876', age:19},
                  {name:'Mike', phone:'555-4321', age:21},
                  {name:'Adam', phone:'555-5678', age:35},
                  {name:'Julie', phone:'555-8765', age:29}];
           }]);
       </script>
       <div ng-controller="ExampleController">
         <table class="friend">
           <tr>
             <th>Name</th>
             <th>Phone Number</th>
             <th>Age</th>
           </tr>
           <tr ng-repeat="friend in friends | orderBy:'-age'">
             <td>{{friend.name}}</td>
             <td>{{friend.phone}}</td>
             <td>{{friend.age}}</td>
           </tr>
         </table>
       </div>
     </file>
   </example>
 *
 * The predicate and reverse parameters can be controlled dynamically through scope properties,
 * as shown in the next example.
 * @example
   <example module="orderByExample">
     <file name="index.html">
       <script>
         angular.module('orderByExample', [])
           .controller('ExampleController', ['$scope', function($scope) {
             $scope.friends =
                 [{name:'John', phone:'555-1212', age:10},
                  {name:'Mary', phone:'555-9876', age:19},
                  {name:'Mike', phone:'555-4321', age:21},
                  {name:'Adam', phone:'555-5678', age:35},
                  {name:'Julie', phone:'555-8765', age:29}];
             $scope.predicate = '-age';
           }]);
       </script>
       <div ng-controller="ExampleController">
         <pre>Sorting predicate = {{predicate}}; reverse = {{reverse}}</pre>
         <hr/>
         [ <a href="" ng-click="predicate=''">unsorted</a> ]
         <table class="friend">
           <tr>
             <th><a href="" ng-click="predicate = 'name'; reverse=false">Name</a>
                 (<a href="" ng-click="predicate = '-name'; reverse=false">^</a>)</th>
             <th><a href="" ng-click="predicate = 'phone'; reverse=!reverse">Phone Number</a></th>
             <th><a href="" ng-click="predicate = 'age'; reverse=!reverse">Age</a></th>
           </tr>
           <tr ng-repeat="friend in friends | orderBy:predicate:reverse">
             <td>{{friend.name}}</td>
             <td>{{friend.phone}}</td>
             <td>{{friend.age}}</td>
           </tr>
         </table>
       </div>
     </file>
   </example>
 *
 * It's also possible to call the orderBy filter manually, by injecting `$filter`, retrieving the
 * filter routine with `$filter('orderBy')`, and calling the returned filter routine with the
 * desired parameters.
 *
 * Example:
 *
 * @example
  <example module="orderByExample">
    <file name="index.html">
      <div ng-controller="ExampleController">
        <table class="friend">
          <tr>
            <th><a href="" ng-click="reverse=false;order('name', false)">Name</a>
              (<a href="" ng-click="order('-name',false)">^</a>)</th>
            <th><a href="" ng-click="reverse=!reverse;order('phone', reverse)">Phone Number</a></th>
            <th><a href="" ng-click="reverse=!reverse;order('age',reverse)">Age</a></th>
          </tr>
          <tr ng-repeat="friend in friends">
            <td>{{friend.name}}</td>
            <td>{{friend.phone}}</td>
            <td>{{friend.age}}</td>
          </tr>
        </table>
      </div>
    </file>

    <file name="script.js">
      angular.module('orderByExample', [])
        .controller('ExampleController', ['$scope', '$filter', function($scope, $filter) {
          var orderBy = $filter('orderBy');
          $scope.friends = [
            { name: 'John',    phone: '555-1212',    age: 10 },
            { name: 'Mary',    phone: '555-9876',    age: 19 },
            { name: 'Mike',    phone: '555-4321',    age: 21 },
            { name: 'Adam',    phone: '555-5678',    age: 35 },
            { name: 'Julie',   phone: '555-8765',    age: 29 }
          ];
          $scope.order = function(predicate, reverse) {
            $scope.friends = orderBy($scope.friends, predicate, reverse);
          };
          $scope.order('-age',false);
        }]);
    </file>
</example>
 */
orderByFilter.$inject = ['$parse'];
function orderByFilter($parse) {
  return function(array, sortPredicate, reverseOrder) {
    if (!(isArrayLike(array))) return array;
    sortPredicate = isArray(sortPredicate) ? sortPredicate : [sortPredicate];
    if (sortPredicate.length === 0) { sortPredicate = ['+']; }
    sortPredicate = sortPredicate.map(function(predicate) {
      var descending = false, get = predicate || identity;
      if (isString(predicate)) {
        if ((predicate.charAt(0) == '+' || predicate.charAt(0) == '-')) {
          descending = predicate.charAt(0) == '-';
          predicate = predicate.substring(1);
        }
        if (predicate === '') {
          // Effectively no predicate was passed so we compare identity
          return reverseComparator(compare, descending);
        }
        get = $parse(predicate);
        if (get.constant) {
          var key = get();
          return reverseComparator(function(a, b) {
            return compare(a[key], b[key]);
          }, descending);
        }
      }
      return reverseComparator(function(a, b) {
        return compare(get(a),get(b));
      }, descending);
    });
    return slice.call(array).sort(reverseComparator(comparator, reverseOrder));

    function comparator(o1, o2) {
      for (var i = 0; i < sortPredicate.length; i++) {
        var comp = sortPredicate[i](o1, o2);
        if (comp !== 0) return comp;
      }
      return 0;
    }
    function reverseComparator(comp, descending) {
      return descending
          ? function(a, b) {return comp(b,a);}
          : comp;
    }

    function isPrimitive(value) {
      switch (typeof value) {
        case 'number': /* falls through */
        case 'boolean': /* falls through */
        case 'string':
          return true;
        default:
          return false;
      }
    }

    function objectToString(value) {
      if (value === null) return 'null';
      if (typeof value.valueOf === 'function') {
        value = value.valueOf();
        if (isPrimitive(value)) return value;
      }
      if (typeof value.toString === 'function') {
        value = value.toString();
        if (isPrimitive(value)) return value;
      }
      return '';
    }

    function compare(v1, v2) {
      var t1 = typeof v1;
      var t2 = typeof v2;
      if (t1 === t2 && t1 === "object") {
        v1 = objectToString(v1);
        v2 = objectToString(v2);
      }
      if (t1 === t2) {
        if (t1 === "string") {
           v1 = v1.toLowerCase();
           v2 = v2.toLowerCase();
        }
        if (v1 === v2) return 0;
        return v1 < v2 ? -1 : 1;
      } else {
        return t1 < t2 ? -1 : 1;
      }
    }
  };
}

function ngDirective(directive) {
  if (isFunction(directive)) {
    directive = {
      link: directive
    };
  }
  directive.restrict = directive.restrict || 'AC';
  return valueFn(directive);
}

/**
 * @ngdoc directive
 * @name a
 * @restrict E
 *
 * @description
 * Modifies the default behavior of the html A tag so that the default action is prevented when
 * the href attribute is empty.
 *
 * This change permits the easy creation of action links with the `ngClick` directive
 * without changing the location or causing page reloads, e.g.:
 * `<a href="" ng-click="list.addItem()">Add Item</a>`
 */
var htmlAnchorDirective = valueFn({
  restrict: 'E',
  compile: function(element, attr) {
    if (!attr.href && !attr.xlinkHref && !attr.name) {
      return function(scope, element) {
        // If the linked element is not an anchor tag anymore, do nothing
        if (element[0].nodeName.toLowerCase() !== 'a') return;

        // SVGAElement does not use the href attribute, but rather the 'xlinkHref' attribute.
        var href = toString.call(element.prop('href')) === '[object SVGAnimatedString]' ?
                   'xlink:href' : 'href';
        element.on('click', function(event) {
          // if we have no href url, then don't navigate anywhere.
          if (!element.attr(href)) {
            event.preventDefault();
          }
        });
      };
    }
  }
});

/**
 * @ngdoc directive
 * @name ngHref
 * @restrict A
 * @priority 99
 *
 * @description
 * Using Angular markup like `{{hash}}` in an href attribute will
 * make the link go to the wrong URL if the user clicks it before
 * Angular has a chance to replace the `{{hash}}` markup with its
 * value. Until Angular replaces the markup the link will be broken
 * and will most likely return a 404 error. The `ngHref` directive
 * solves this problem.
 *
 * The wrong way to write it:
 * ```html
 * <a href="http://www.gravatar.com/avatar/{{hash}}">link1</a>
 * ```
 *
 * The correct way to write it:
 * ```html
 * <a ng-href="http://www.gravatar.com/avatar/{{hash}}">link1</a>
 * ```
 *
 * @element A
 * @param {template} ngHref any string which can contain `{{}}` markup.
 *
 * @example
 * This example shows various combinations of `href`, `ng-href` and `ng-click` attributes
 * in links and their different behaviors:
    <example>
      <file name="index.html">
        <input ng-model="value" /><br />
        <a id="link-1" href ng-click="value = 1">link 1</a> (link, don't reload)<br />
        <a id="link-2" href="" ng-click="value = 2">link 2</a> (link, don't reload)<br />
        <a id="link-3" ng-href="/{{'123'}}">link 3</a> (link, reload!)<br />
        <a id="link-4" href="" name="xx" ng-click="value = 4">anchor</a> (link, don't reload)<br />
        <a id="link-5" name="xxx" ng-click="value = 5">anchor</a> (no link)<br />
        <a id="link-6" ng-href="{{value}}">link</a> (link, change location)
      </file>
      <file name="protractor.js" type="protractor">
        it('should execute ng-click but not reload when href without value', function() {
          element(by.id('link-1')).click();
          expect(element(by.model('value')).getAttribute('value')).toEqual('1');
          expect(element(by.id('link-1')).getAttribute('href')).toBe('');
        });

        it('should execute ng-click but not reload when href empty string', function() {
          element(by.id('link-2')).click();
          expect(element(by.model('value')).getAttribute('value')).toEqual('2');
          expect(element(by.id('link-2')).getAttribute('href')).toBe('');
        });

        it('should execute ng-click and change url when ng-href specified', function() {
          expect(element(by.id('link-3')).getAttribute('href')).toMatch(/\/123$/);

          element(by.id('link-3')).click();

          // At this point, we navigate away from an Angular page, so we need
          // to use browser.driver to get the base webdriver.

          browser.wait(function() {
            return browser.driver.getCurrentUrl().then(function(url) {
              return url.match(/\/123$/);
            });
          }, 5000, 'page should navigate to /123');
        });

        xit('should execute ng-click but not reload when href empty string and name specified', function() {
          element(by.id('link-4')).click();
          expect(element(by.model('value')).getAttribute('value')).toEqual('4');
          expect(element(by.id('link-4')).getAttribute('href')).toBe('');
        });

        it('should execute ng-click but not reload when no href but name specified', function() {
          element(by.id('link-5')).click();
          expect(element(by.model('value')).getAttribute('value')).toEqual('5');
          expect(element(by.id('link-5')).getAttribute('href')).toBe(null);
        });

        it('should only change url when only ng-href', function() {
          element(by.model('value')).clear();
          element(by.model('value')).sendKeys('6');
          expect(element(by.id('link-6')).getAttribute('href')).toMatch(/\/6$/);

          element(by.id('link-6')).click();

          // At this point, we navigate away from an Angular page, so we need
          // to use browser.driver to get the base webdriver.
          browser.wait(function() {
            return browser.driver.getCurrentUrl().then(function(url) {
              return url.match(/\/6$/);
            });
          }, 5000, 'page should navigate to /6');
        });
      </file>
    </example>
 */

/**
 * @ngdoc directive
 * @name ngSrc
 * @restrict A
 * @priority 99
 *
 * @description
 * Using Angular markup like `{{hash}}` in a `src` attribute doesn't
 * work right: The browser will fetch from the URL with the literal
 * text `{{hash}}` until Angular replaces the expression inside
 * `{{hash}}`. The `ngSrc` directive solves this problem.
 *
 * The buggy way to write it:
 * ```html
 * <img src="http://www.gravatar.com/avatar/{{hash}}"/>
 * ```
 *
 * The correct way to write it:
 * ```html
 * <img ng-src="http://www.gravatar.com/avatar/{{hash}}"/>
 * ```
 *
 * @element IMG
 * @param {template} ngSrc any string which can contain `{{}}` markup.
 */

/**
 * @ngdoc directive
 * @name ngSrcset
 * @restrict A
 * @priority 99
 *
 * @description
 * Using Angular markup like `{{hash}}` in a `srcset` attribute doesn't
 * work right: The browser will fetch from the URL with the literal
 * text `{{hash}}` until Angular replaces the expression inside
 * `{{hash}}`. The `ngSrcset` directive solves this problem.
 *
 * The buggy way to write it:
 * ```html
 * <img srcset="http://www.gravatar.com/avatar/{{hash}} 2x"/>
 * ```
 *
 * The correct way to write it:
 * ```html
 * <img ng-srcset="http://www.gravatar.com/avatar/{{hash}} 2x"/>
 * ```
 *
 * @element IMG
 * @param {template} ngSrcset any string which can contain `{{}}` markup.
 */

/**
 * @ngdoc directive
 * @name ngDisabled
 * @restrict A
 * @priority 100
 *
 * @description
 *
 * This directive sets the `disabled` attribute on the element if the
 * {@link guide/expression expression} inside `ngDisabled` evaluates to truthy.
 *
 * A special directive is necessary because we cannot use interpolation inside the `disabled`
 * attribute.  The following example would make the button enabled on Chrome/Firefox
 * but not on older IEs:
 *
 * ```html
 * <!-- See below for an example of ng-disabled being used correctly -->
 * <div ng-init="isDisabled = false">
 *  <button disabled="{{isDisabled}}">Disabled</button>
 * </div>
 * ```
 *
 * This is because the HTML specification does not require browsers to preserve the values of
 * boolean attributes such as `disabled` (Their presence means true and their absence means false.)
 * If we put an Angular interpolation expression into such an attribute then the
 * binding information would be lost when the browser removes the attribute.
 *
 * @example
    <example>
      <file name="index.html">
        Click me to toggle: <input type="checkbox" ng-model="checked"><br/>
        <button ng-model="button" ng-disabled="checked">Button</button>
      </file>
      <file name="protractor.js" type="protractor">
        it('should toggle button', function() {
          expect(element(by.css('button')).getAttribute('disabled')).toBeFalsy();
          element(by.model('checked')).click();
          expect(element(by.css('button')).getAttribute('disabled')).toBeTruthy();
        });
      </file>
    </example>
 *
 * @element INPUT
 * @param {expression} ngDisabled If the {@link guide/expression expression} is truthy,
 *     then the `disabled` attribute will be set on the element
 */


/**
 * @ngdoc directive
 * @name ngChecked
 * @restrict A
 * @priority 100
 *
 * @description
 * The HTML specification does not require browsers to preserve the values of boolean attributes
 * such as checked. (Their presence means true and their absence means false.)
 * If we put an Angular interpolation expression into such an attribute then the
 * binding information would be lost when the browser removes the attribute.
 * The `ngChecked` directive solves this problem for the `checked` attribute.
 * This complementary directive is not removed by the browser and so provides
 * a permanent reliable place to store the binding information.
 * @example
    <example>
      <file name="index.html">
        Check me to check both: <input type="checkbox" ng-model="master"><br/>
        <input id="checkSlave" type="checkbox" ng-checked="master">
      </file>
      <file name="protractor.js" type="protractor">
        it('should check both checkBoxes', function() {
          expect(element(by.id('checkSlave')).getAttribute('checked')).toBeFalsy();
          element(by.model('master')).click();
          expect(element(by.id('checkSlave')).getAttribute('checked')).toBeTruthy();
        });
      </file>
    </example>
 *
 * @element INPUT
 * @param {expression} ngChecked If the {@link guide/expression expression} is truthy,
 *     then special attribute "checked" will be set on the element
 */


/**
 * @ngdoc directive
 * @name ngReadonly
 * @restrict A
 * @priority 100
 *
 * @description
 * The HTML specification does not require browsers to preserve the values of boolean attributes
 * such as readonly. (Their presence means true and their absence means false.)
 * If we put an Angular interpolation expression into such an attribute then the
 * binding information would be lost when the browser removes the attribute.
 * The `ngReadonly` directive solves this problem for the `readonly` attribute.
 * This complementary directive is not removed by the browser and so provides
 * a permanent reliable place to store the binding information.
 * @example
    <example>
      <file name="index.html">
        Check me to make text readonly: <input type="checkbox" ng-model="checked"><br/>
        <input type="text" ng-readonly="checked" value="I'm Angular"/>
      </file>
      <file name="protractor.js" type="protractor">
        it('should toggle readonly attr', function() {
          expect(element(by.css('[type="text"]')).getAttribute('readonly')).toBeFalsy();
          element(by.model('checked')).click();
          expect(element(by.css('[type="text"]')).getAttribute('readonly')).toBeTruthy();
        });
      </file>
    </example>
 *
 * @element INPUT
 * @param {expression} ngReadonly If the {@link guide/expression expression} is truthy,
 *     then special attribute "readonly" will be set on the element
 */


/**
 * @ngdoc directive
 * @name ngSelected
 * @restrict A
 * @priority 100
 *
 * @description
 * The HTML specification does not require browsers to preserve the values of boolean attributes
 * such as selected. (Their presence means true and their absence means false.)
 * If we put an Angular interpolation expression into such an attribute then the
 * binding information would be lost when the browser removes the attribute.
 * The `ngSelected` directive solves this problem for the `selected` attribute.
 * This complementary directive is not removed by the browser and so provides
 * a permanent reliable place to store the binding information.
 *
 * @example
    <example>
      <file name="index.html">
        Check me to select: <input type="checkbox" ng-model="selected"><br/>
        <select>
          <option>Hello!</option>
          <option id="greet" ng-selected="selected">Greetings!</option>
        </select>
      </file>
      <file name="protractor.js" type="protractor">
        it('should select Greetings!', function() {
          expect(element(by.id('greet')).getAttribute('selected')).toBeFalsy();
          element(by.model('selected')).click();
          expect(element(by.id('greet')).getAttribute('selected')).toBeTruthy();
        });
      </file>
    </example>
 *
 * @element OPTION
 * @param {expression} ngSelected If the {@link guide/expression expression} is truthy,
 *     then special attribute "selected" will be set on the element
 */

/**
 * @ngdoc directive
 * @name ngOpen
 * @restrict A
 * @priority 100
 *
 * @description
 * The HTML specification does not require browsers to preserve the values of boolean attributes
 * such as open. (Their presence means true and their absence means false.)
 * If we put an Angular interpolation expression into such an attribute then the
 * binding information would be lost when the browser removes the attribute.
 * The `ngOpen` directive solves this problem for the `open` attribute.
 * This complementary directive is not removed by the browser and so provides
 * a permanent reliable place to store the binding information.
 * @example
     <example>
       <file name="index.html">
         Check me check multiple: <input type="checkbox" ng-model="open"><br/>
         <details id="details" ng-open="open">
            <summary>Show/Hide me</summary>
         </details>
       </file>
       <file name="protractor.js" type="protractor">
         it('should toggle open', function() {
           expect(element(by.id('details')).getAttribute('open')).toBeFalsy();
           element(by.model('open')).click();
           expect(element(by.id('details')).getAttribute('open')).toBeTruthy();
         });
       </file>
     </example>
 *
 * @element DETAILS
 * @param {expression} ngOpen If the {@link guide/expression expression} is truthy,
 *     then special attribute "open" will be set on the element
 */

var ngAttributeAliasDirectives = {};


// boolean attrs are evaluated
forEach(BOOLEAN_ATTR, function(propName, attrName) {
  // binding to multiple is not supported
  if (propName == "multiple") return;

  var normalized = directiveNormalize('ng-' + attrName);
  ngAttributeAliasDirectives[normalized] = function() {
    return {
      restrict: 'A',
      priority: 100,
      link: function(scope, element, attr) {
        scope.$watch(attr[normalized], function ngBooleanAttrWatchAction(value) {
          attr.$set(attrName, !!value);
        });
      }
    };
  };
});

// aliased input attrs are evaluated
forEach(ALIASED_ATTR, function(htmlAttr, ngAttr) {
  ngAttributeAliasDirectives[ngAttr] = function() {
    return {
      priority: 100,
      link: function(scope, element, attr) {
        //special case ngPattern when a literal regular expression value
        //is used as the expression (this way we don't have to watch anything).
        if (ngAttr === "ngPattern" && attr.ngPattern.charAt(0) == "/") {
          var match = attr.ngPattern.match(REGEX_STRING_REGEXP);
          if (match) {
            attr.$set("ngPattern", new RegExp(match[1], match[2]));
            return;
          }
        }

        scope.$watch(attr[ngAttr], function ngAttrAliasWatchAction(value) {
          attr.$set(ngAttr, value);
        });
      }
    };
  };
});

// ng-src, ng-srcset, ng-href are interpolated
forEach(['src', 'srcset', 'href'], function(attrName) {
  var normalized = directiveNormalize('ng-' + attrName);
  ngAttributeAliasDirectives[normalized] = function() {
    return {
      priority: 99, // it needs to run after the attributes are interpolated
      link: function(scope, element, attr) {
        var propName = attrName,
            name = attrName;

        if (attrName === 'href' &&
            toString.call(element.prop('href')) === '[object SVGAnimatedString]') {
          name = 'xlinkHref';
          attr.$attr[name] = 'xlink:href';
          propName = null;
        }

        attr.$observe(normalized, function(value) {
          if (!value) {
            if (attrName === 'href') {
              attr.$set(name, null);
            }
            return;
          }

          attr.$set(name, value);

          // on IE, if "ng:src" directive declaration is used and "src" attribute doesn't exist
          // then calling element.setAttribute('src', 'foo') doesn't do anything, so we need
          // to set the property as well to achieve the desired effect.
          // we use attr[attrName] value since $set can sanitize the url.
          if (msie && propName) element.prop(propName, attr[name]);
        });
      }
    };
  };
});

/* global -nullFormCtrl, -SUBMITTED_CLASS, addSetValidityMethod: true
 */
var nullFormCtrl = {
  $addControl: noop,
  $$renameControl: nullFormRenameControl,
  $removeControl: noop,
  $setValidity: noop,
  $setDirty: noop,
  $setPristine: noop,
  $setSubmitted: noop
},
SUBMITTED_CLASS = 'ng-submitted';

function nullFormRenameControl(control, name) {
  control.$name = name;
}

/**
 * @ngdoc type
 * @name form.FormController
 *
 * @property {boolean} $pristine True if user has not interacted with the form yet.
 * @property {boolean} $dirty True if user has already interacted with the form.
 * @property {boolean} $valid True if all of the containing forms and controls are valid.
 * @property {boolean} $invalid True if at least one containing control or form is invalid.
 * @property {boolean} $submitted True if user has submitted the form even if its invalid.
 *
 * @property {Object} $error Is an object hash, containing references to controls or
 *  forms with failing validators, where:
 *
 *  - keys are validation tokens (error names),
 *  - values are arrays of controls or forms that have a failing validator for given error name.
 *
 *  Built-in validation tokens:
 *
 *  - `email`
 *  - `max`
 *  - `maxlength`
 *  - `min`
 *  - `minlength`
 *  - `number`
 *  - `pattern`
 *  - `required`
 *  - `url`
 *  - `date`
 *  - `datetimelocal`
 *  - `time`
 *  - `week`
 *  - `month`
 *
 * @description
 * `FormController` keeps track of all its controls and nested forms as well as the state of them,
 * such as being valid/invalid or dirty/pristine.
 *
 * Each {@link ng.directive:form form} directive creates an instance
 * of `FormController`.
 *
 */
//asks for $scope to fool the BC controller module
FormController.$inject = ['$element', '$attrs', '$scope', '$animate', '$interpolate'];
function FormController(element, attrs, $scope, $animate, $interpolate) {
  var form = this,
      controls = [];

  var parentForm = form.$$parentForm = element.parent().controller('form') || nullFormCtrl;

  // init state
  form.$error = {};
  form.$$success = {};
  form.$pending = undefined;
  form.$name = $interpolate(attrs.name || attrs.ngForm || '')($scope);
  form.$dirty = false;
  form.$pristine = true;
  form.$valid = true;
  form.$invalid = false;
  form.$submitted = false;

  parentForm.$addControl(form);

  /**
   * @ngdoc method
   * @name form.FormController#$rollbackViewValue
   *
   * @description
   * Rollback all form controls pending updates to the `$modelValue`.
   *
   * Updates may be pending by a debounced event or because the input is waiting for a some future
   * event defined in `ng-model-options`. This method is typically needed by the reset button of
   * a form that uses `ng-model-options` to pend updates.
   */
  form.$rollbackViewValue = function() {
    forEach(controls, function(control) {
      control.$rollbackViewValue();
    });
  };

  /**
   * @ngdoc method
   * @name form.FormController#$commitViewValue
   *
   * @description
   * Commit all form controls pending updates to the `$modelValue`.
   *
   * Updates may be pending by a debounced event or because the input is waiting for a some future
   * event defined in `ng-model-options`. This method is rarely needed as `NgModelController`
   * usually handles calling this in response to input events.
   */
  form.$commitViewValue = function() {
    forEach(controls, function(control) {
      control.$commitViewValue();
    });
  };

  /**
   * @ngdoc method
   * @name form.FormController#$addControl
   *
   * @description
   * Register a control with the form.
   *
   * Input elements using ngModelController do this automatically when they are linked.
   */
  form.$addControl = function(control) {
    // Breaking change - before, inputs whose name was "hasOwnProperty" were quietly ignored
    // and not added to the scope.  Now we throw an error.
    assertNotHasOwnProperty(control.$name, 'input');
    controls.push(control);

    if (control.$name) {
      form[control.$name] = control;
    }
  };

  // Private API: rename a form control
  form.$$renameControl = function(control, newName) {
    var oldName = control.$name;

    if (form[oldName] === control) {
      delete form[oldName];
    }
    form[newName] = control;
    control.$name = newName;
  };

  /**
   * @ngdoc method
   * @name form.FormController#$removeControl
   *
   * @description
   * Deregister a control from the form.
   *
   * Input elements using ngModelController do this automatically when they are destroyed.
   */
  form.$removeControl = function(control) {
    if (control.$name && form[control.$name] === control) {
      delete form[control.$name];
    }
    forEach(form.$pending, function(value, name) {
      form.$setValidity(name, null, control);
    });
    forEach(form.$error, function(value, name) {
      form.$setValidity(name, null, control);
    });
    forEach(form.$$success, function(value, name) {
      form.$setValidity(name, null, control);
    });

    arrayRemove(controls, control);
  };


  /**
   * @ngdoc method
   * @name form.FormController#$setValidity
   *
   * @description
   * Sets the validity of a form control.
   *
   * This method will also propagate to parent forms.
   */
  addSetValidityMethod({
    ctrl: this,
    $element: element,
    set: function(object, property, controller) {
      var list = object[property];
      if (!list) {
        object[property] = [controller];
      } else {
        var index = list.indexOf(controller);
        if (index === -1) {
          list.push(controller);
        }
      }
    },
    unset: function(object, property, controller) {
      var list = object[property];
      if (!list) {
        return;
      }
      arrayRemove(list, controller);
      if (list.length === 0) {
        delete object[property];
      }
    },
    parentForm: parentForm,
    $animate: $animate
  });

  /**
   * @ngdoc method
   * @name form.FormController#$setDirty
   *
   * @description
   * Sets the form to a dirty state.
   *
   * This method can be called to add the 'ng-dirty' class and set the form to a dirty
   * state (ng-dirty class). This method will also propagate to parent forms.
   */
  form.$setDirty = function() {
    $animate.removeClass(element, PRISTINE_CLASS);
    $animate.addClass(element, DIRTY_CLASS);
    form.$dirty = true;
    form.$pristine = false;
    parentForm.$setDirty();
  };

  /**
   * @ngdoc method
   * @name form.FormController#$setPristine
   *
   * @description
   * Sets the form to its pristine state.
   *
   * This method can be called to remove the 'ng-dirty' class and set the form to its pristine
   * state (ng-pristine class). This method will also propagate to all the controls contained
   * in this form.
   *
   * Setting a form back to a pristine state is often useful when we want to 'reuse' a form after
   * saving or resetting it.
   */
  form.$setPristine = function() {
    $animate.setClass(element, PRISTINE_CLASS, DIRTY_CLASS + ' ' + SUBMITTED_CLASS);
    form.$dirty = false;
    form.$pristine = true;
    form.$submitted = false;
    forEach(controls, function(control) {
      control.$setPristine();
    });
  };

  /**
   * @ngdoc method
   * @name form.FormController#$setUntouched
   *
   * @description
   * Sets the form to its untouched state.
   *
   * This method can be called to remove the 'ng-touched' class and set the form controls to their
   * untouched state (ng-untouched class).
   *
   * Setting a form controls back to their untouched state is often useful when setting the form
   * back to its pristine state.
   */
  form.$setUntouched = function() {
    forEach(controls, function(control) {
      control.$setUntouched();
    });
  };

  /**
   * @ngdoc method
   * @name form.FormController#$setSubmitted
   *
   * @description
   * Sets the form to its submitted state.
   */
  form.$setSubmitted = function() {
    $animate.addClass(element, SUBMITTED_CLASS);
    form.$submitted = true;
    parentForm.$setSubmitted();
  };
}

/**
 * @ngdoc directive
 * @name ngForm
 * @restrict EAC
 *
 * @description
 * Nestable alias of {@link ng.directive:form `form`} directive. HTML
 * does not allow nesting of form elements. It is useful to nest forms, for example if the validity of a
 * sub-group of controls needs to be determined.
 *
 * Note: the purpose of `ngForm` is to group controls,
 * but not to be a replacement for the `<form>` tag with all of its capabilities
 * (e.g. posting to the server, ...).
 *
 * @param {string=} ngForm|name Name of the form. If specified, the form controller will be published into
 *                       related scope, under this name.
 *
 */

 /**
 * @ngdoc directive
 * @name form
 * @restrict E
 *
 * @description
 * Directive that instantiates
 * {@link form.FormController FormController}.
 *
 * If the `name` attribute is specified, the form controller is published onto the current scope under
 * this name.
 *
 * # Alias: {@link ng.directive:ngForm `ngForm`}
 *
 * In Angular, forms can be nested. This means that the outer form is valid when all of the child
 * forms are valid as well. However, browsers do not allow nesting of `<form>` elements, so
 * Angular provides the {@link ng.directive:ngForm `ngForm`} directive which behaves identically to
 * `<form>` but can be nested.  This allows you to have nested forms, which is very useful when
 * using Angular validation directives in forms that are dynamically generated using the
 * {@link ng.directive:ngRepeat `ngRepeat`} directive. Since you cannot dynamically generate the `name`
 * attribute of input elements using interpolation, you have to wrap each set of repeated inputs in an
 * `ngForm` directive and nest these in an outer `form` element.
 *
 *
 * # CSS classes
 *  - `ng-valid` is set if the form is valid.
 *  - `ng-invalid` is set if the form is invalid.
 *  - `ng-pristine` is set if the form is pristine.
 *  - `ng-dirty` is set if the form is dirty.
 *  - `ng-submitted` is set if the form was submitted.
 *
 * Keep in mind that ngAnimate can detect each of these classes when added and removed.
 *
 *
 * # Submitting a form and preventing the default action
 *
 * Since the role of forms in client-side Angular applications is different than in classical
 * roundtrip apps, it is desirable for the browser not to translate the form submission into a full
 * page reload that sends the data to the server. Instead some javascript logic should be triggered
 * to handle the form submission in an application-specific way.
 *
 * For this reason, Angular prevents the default action (form submission to the server) unless the
 * `<form>` element has an `action` attribute specified.
 *
 * You can use one of the following two ways to specify what javascript method should be called when
 * a form is submitted:
 *
 * - {@link ng.directive:ngSubmit ngSubmit} directive on the form element
 * - {@link ng.directive:ngClick ngClick} directive on the first
  *  button or input field of type submit (input[type=submit])
 *
 * To prevent double execution of the handler, use only one of the {@link ng.directive:ngSubmit ngSubmit}
 * or {@link ng.directive:ngClick ngClick} directives.
 * This is because of the following form submission rules in the HTML specification:
 *
 * - If a form has only one input field then hitting enter in this field triggers form submit
 * (`ngSubmit`)
 * - if a form has 2+ input fields and no buttons or input[type=submit] then hitting enter
 * doesn't trigger submit
 * - if a form has one or more input fields and one or more buttons or input[type=submit] then
 * hitting enter in any of the input fields will trigger the click handler on the *first* button or
 * input[type=submit] (`ngClick`) *and* a submit handler on the enclosing form (`ngSubmit`)
 *
 * Any pending `ngModelOptions` changes will take place immediately when an enclosing form is
 * submitted. Note that `ngClick` events will occur before the model is updated. Use `ngSubmit`
 * to have access to the updated model.
 *
 * ## Animation Hooks
 *
 * Animations in ngForm are triggered when any of the associated CSS classes are added and removed.
 * These classes are: `.ng-pristine`, `.ng-dirty`, `.ng-invalid` and `.ng-valid` as well as any
 * other validations that are performed within the form. Animations in ngForm are similar to how
 * they work in ngClass and animations can be hooked into using CSS transitions, keyframes as well
 * as JS animations.
 *
 * The following example shows a simple way to utilize CSS transitions to style a form element
 * that has been rendered as invalid after it has been validated:
 *
 * <pre>
 * //be sure to include ngAnimate as a module to hook into more
 * //advanced animations
 * .my-form {
 *   transition:0.5s linear all;
 *   background: white;
 * }
 * .my-form.ng-invalid {
 *   background: red;
 *   color:white;
 * }
 * </pre>
 *
 * @example
    <example deps="angular-animate.js" animations="true" fixBase="true" module="formExample">
      <file name="index.html">
       <script>
         angular.module('formExample', [])
           .controller('FormController', ['$scope', function($scope) {
             $scope.userType = 'guest';
           }]);
       </script>
       <style>
        .my-form {
          -webkit-transition:all linear 0.5s;
          transition:all linear 0.5s;
          background: transparent;
        }
        .my-form.ng-invalid {
          background: red;
        }
       </style>
       <form name="myForm" ng-controller="FormController" class="my-form">
         userType: <input name="input" ng-model="userType" required>
         <span class="error" ng-show="myForm.input.$error.required">Required!</span><br>
         <code>userType = {{userType}}</code><br>
         <code>myForm.input.$valid = {{myForm.input.$valid}}</code><br>
         <code>myForm.input.$error = {{myForm.input.$error}}</code><br>
         <code>myForm.$valid = {{myForm.$valid}}</code><br>
         <code>myForm.$error.required = {{!!myForm.$error.required}}</code><br>
        </form>
      </file>
      <file name="protractor.js" type="protractor">
        it('should initialize to model', function() {
          var userType = element(by.binding('userType'));
          var valid = element(by.binding('myForm.input.$valid'));

          expect(userType.getText()).toContain('guest');
          expect(valid.getText()).toContain('true');
        });

        it('should be invalid if empty', function() {
          var userType = element(by.binding('userType'));
          var valid = element(by.binding('myForm.input.$valid'));
          var userInput = element(by.model('userType'));

          userInput.clear();
          userInput.sendKeys('');

          expect(userType.getText()).toEqual('userType =');
          expect(valid.getText()).toContain('false');
        });
      </file>
    </example>
 *
 * @param {string=} name Name of the form. If specified, the form controller will be published into
 *                       related scope, under this name.
 */
var formDirectiveFactory = function(isNgForm) {
  return ['$timeout', function($timeout) {
    var formDirective = {
      name: 'form',
      restrict: isNgForm ? 'EAC' : 'E',
      controller: FormController,
      compile: function ngFormCompile(formElement, attr) {
        // Setup initial state of the control
        formElement.addClass(PRISTINE_CLASS).addClass(VALID_CLASS);

        var nameAttr = attr.name ? 'name' : (isNgForm && attr.ngForm ? 'ngForm' : false);

        return {
          pre: function ngFormPreLink(scope, formElement, attr, controller) {
            // if `action` attr is not present on the form, prevent the default action (submission)
            if (!('action' in attr)) {
              // we can't use jq events because if a form is destroyed during submission the default
              // action is not prevented. see #1238
              //
              // IE 9 is not affected because it doesn't fire a submit event and try to do a full
              // page reload if the form was destroyed by submission of the form via a click handler
              // on a button in the form. Looks like an IE9 specific bug.
              var handleFormSubmission = function(event) {
                scope.$apply(function() {
                  controller.$commitViewValue();
                  controller.$setSubmitted();
                });

                event.preventDefault();
              };

              addEventListenerFn(formElement[0], 'submit', handleFormSubmission);

              // unregister the preventDefault listener so that we don't not leak memory but in a
              // way that will achieve the prevention of the default action.
              formElement.on('$destroy', function() {
                $timeout(function() {
                  removeEventListenerFn(formElement[0], 'submit', handleFormSubmission);
                }, 0, false);
              });
            }

            var parentFormCtrl = controller.$$parentForm;

            if (nameAttr) {
              setter(scope, null, controller.$name, controller, controller.$name);
              attr.$observe(nameAttr, function(newValue) {
                if (controller.$name === newValue) return;
                setter(scope, null, controller.$name, undefined, controller.$name);
                parentFormCtrl.$$renameControl(controller, newValue);
                setter(scope, null, controller.$name, controller, controller.$name);
              });
            }
            formElement.on('$destroy', function() {
              parentFormCtrl.$removeControl(controller);
              if (nameAttr) {
                setter(scope, null, attr[nameAttr], undefined, controller.$name);
              }
              extend(controller, nullFormCtrl); //stop propagating child destruction handlers upwards
            });
          }
        };
      }
    };

    return formDirective;
  }];
};

var formDirective = formDirectiveFactory();
var ngFormDirective = formDirectiveFactory(true);

/* global VALID_CLASS: false,
  INVALID_CLASS: false,
  PRISTINE_CLASS: false,
  DIRTY_CLASS: false,
  UNTOUCHED_CLASS: false,
  TOUCHED_CLASS: false,
  ngModelMinErr: false,
*/

// Regex code is obtained from SO: https://stackoverflow.com/questions/3143070/javascript-regex-iso-datetime#answer-3143231
var ISO_DATE_REGEXP = /\d{4}-[01]\d-[0-3]\dT[0-2]\d:[0-5]\d:[0-5]\d\.\d+([+-][0-2]\d:[0-5]\d|Z)/;
var URL_REGEXP = /^(ftp|http|https):\/\/(\w+:{0,1}\w*@)?(\S+)(:[0-9]+)?(\/|\/([\w#!:.?+=&%@!\-\/]))?$/;
var EMAIL_REGEXP = /^[a-z0-9!#$%&'*+\/=?^_`{|}~.-]+@[a-z0-9]([a-z0-9-]*[a-z0-9])?(\.[a-z0-9]([a-z0-9-]*[a-z0-9])?)*$/i;
var NUMBER_REGEXP = /^\s*(\-|\+)?(\d+|(\d*(\.\d*)))\s*$/;
var DATE_REGEXP = /^(\d{4})-(\d{2})-(\d{2})$/;
var DATETIMELOCAL_REGEXP = /^(\d{4})-(\d\d)-(\d\d)T(\d\d):(\d\d)(?::(\d\d)(\.\d{1,3})?)?$/;
var WEEK_REGEXP = /^(\d{4})-W(\d\d)$/;
var MONTH_REGEXP = /^(\d{4})-(\d\d)$/;
var TIME_REGEXP = /^(\d\d):(\d\d)(?::(\d\d)(\.\d{1,3})?)?$/;

var inputType = {

  /**
   * @ngdoc input
   * @name input[text]
   *
   * @description
   * Standard HTML text input with angular data binding, inherited by most of the `input` elements.
   *
   *
   * @param {string} ngModel Assignable angular expression to data-bind to.
   * @param {string=} name Property name of the form under which the control is published.
   * @param {string=} required Adds `required` validation error key if the value is not entered.
   * @param {string=} ngRequired Adds `required` attribute and `required` validation constraint to
   *    the element when the ngRequired expression evaluates to true. Use `ngRequired` instead of
   *    `required` when you want to data-bind to the `required` attribute.
   * @param {number=} ngMinlength Sets `minlength` validation error key if the value is shorter than
   *    minlength.
   * @param {number=} ngMaxlength Sets `maxlength` validation error key if the value is longer than
   *    maxlength. Setting the attribute to a negative or non-numeric value, allows view values of
   *    any length.
   * @param {string=} pattern Similar to `ngPattern` except that the attribute value is the actual string
   *    that contains the regular expression body that will be converted to a regular expression
   *    as in the ngPattern directive.
   * @param {string=} ngPattern Sets `pattern` validation error key if the ngModel value does not match
   *    a RegExp found by evaluating the Angular expression given in the attribute value.
   *    If the expression evaluates to a RegExp object then this is used directly.
   *    If the expression is a string then it will be converted to a RegExp after wrapping it in `^` and `$`
   *    characters. For instance, `"abc"` will be converted to `new RegExp('^abc$')`.
   * @param {string=} ngChange Angular expression to be executed when input changes due to user
   *    interaction with the input element.
   * @param {boolean=} [ngTrim=true] If set to false Angular will not automatically trim the input.
   *    This parameter is ignored for input[type=password] controls, which will never trim the
   *    input.
   *
   * @example
      <example name="text-input-directive" module="textInputExample">
        <file name="index.html">
         <script>
           angular.module('textInputExample', [])
             .controller('ExampleController', ['$scope', function($scope) {
               $scope.example = {
                 text: 'guest',
                 word: /^\s*\w*\s*$/
               };
             }]);
         </script>
         <form name="myForm" ng-controller="ExampleController">
           Single word: <input type="text" name="input" ng-model="example.text"
                               ng-pattern="example.word" required ng-trim="false">
           <span class="error" ng-show="myForm.input.$error.required">
             Required!</span>
           <span class="error" ng-show="myForm.input.$error.pattern">
             Single word only!</span>

           <tt>text = {{example.text}}</tt><br/>
           <tt>myForm.input.$valid = {{myForm.input.$valid}}</tt><br/>
           <tt>myForm.input.$error = {{myForm.input.$error}}</tt><br/>
           <tt>myForm.$valid = {{myForm.$valid}}</tt><br/>
           <tt>myForm.$error.required = {{!!myForm.$error.required}}</tt><br/>
          </form>
        </file>
        <file name="protractor.js" type="protractor">
          var text = element(by.binding('example.text'));
          var valid = element(by.binding('myForm.input.$valid'));
          var input = element(by.model('example.text'));

          it('should initialize to model', function() {
            expect(text.getText()).toContain('guest');
            expect(valid.getText()).toContain('true');
          });

          it('should be invalid if empty', function() {
            input.clear();
            input.sendKeys('');

            expect(text.getText()).toEqual('text =');
            expect(valid.getText()).toContain('false');
          });

          it('should be invalid if multi word', function() {
            input.clear();
            input.sendKeys('hello world');

            expect(valid.getText()).toContain('false');
          });
        </file>
      </example>
   */
  'text': textInputType,

    /**
     * @ngdoc input
     * @name input[date]
     *
     * @description
     * Input with date validation and transformation. In browsers that do not yet support
     * the HTML5 date input, a text element will be used. In that case, text must be entered in a valid ISO-8601
     * date format (yyyy-MM-dd), for example: `2009-01-06`. Since many
     * modern browsers do not yet support this input type, it is important to provide cues to users on the
     * expected input format via a placeholder or label.
     *
     * The model must always be a Date object, otherwise Angular will throw an error.
     * Invalid `Date` objects (dates whose `getTime()` is `NaN`) will be rendered as an empty string.
     *
     * The timezone to be used to read/write the `Date` instance in the model can be defined using
     * {@link ng.directive:ngModelOptions ngModelOptions}. By default, this is the timezone of the browser.
     *
     * @param {string} ngModel Assignable angular expression to data-bind to.
     * @param {string=} name Property name of the form under which the control is published.
     * @param {string=} min Sets the `min` validation error key if the value entered is less than `min`. This must be a
     * valid ISO date string (yyyy-MM-dd).
     * @param {string=} max Sets the `max` validation error key if the value entered is greater than `max`. This must be
     * a valid ISO date string (yyyy-MM-dd).
     * @param {string=} required Sets `required` validation error key if the value is not entered.
     * @param {string=} ngRequired Adds `required` attribute and `required` validation constraint to
     *    the element when the ngRequired expression evaluates to true. Use `ngRequired` instead of
     *    `required` when you want to data-bind to the `required` attribute.
     * @param {string=} ngChange Angular expression to be executed when input changes due to user
     *    interaction with the input element.
     *
     * @example
     <example name="date-input-directive" module="dateInputExample">
     <file name="index.html">
       <script>
          angular.module('dateInputExample', [])
            .controller('DateController', ['$scope', function($scope) {
              $scope.example = {
                value: new Date(2013, 9, 22)
              };
            }]);
       </script>
       <form name="myForm" ng-controller="DateController as dateCtrl">
          Pick a date in 2013:
          <input type="date" id="exampleInput" name="input" ng-model="example.value"
              placeholder="yyyy-MM-dd" min="2013-01-01" max="2013-12-31" required />
          <span class="error" ng-show="myForm.input.$error.required">
              Required!</span>
          <span class="error" ng-show="myForm.input.$error.date">
              Not a valid date!</span>
           <tt>value = {{example.value | date: "yyyy-MM-dd"}}</tt><br/>
           <tt>myForm.input.$valid = {{myForm.input.$valid}}</tt><br/>
           <tt>myForm.input.$error = {{myForm.input.$error}}</tt><br/>
           <tt>myForm.$valid = {{myForm.$valid}}</tt><br/>
           <tt>myForm.$error.required = {{!!myForm.$error.required}}</tt><br/>
       </form>
     </file>
     <file name="protractor.js" type="protractor">
        var value = element(by.binding('example.value | date: "yyyy-MM-dd"'));
        var valid = element(by.binding('myForm.input.$valid'));
        var input = element(by.model('example.value'));

        // currently protractor/webdriver does not support
        // sending keys to all known HTML5 input controls
        // for various browsers (see https://github.com/angular/protractor/issues/562).
        function setInput(val) {
          // set the value of the element and force validation.
          var scr = "var ipt = document.getElementById('exampleInput'); " +
          "ipt.value = '" + val + "';" +
          "angular.element(ipt).scope().$apply(function(s) { s.myForm[ipt.name].$setViewValue('" + val + "'); });";
          browser.executeScript(scr);
        }

        it('should initialize to model', function() {
          expect(value.getText()).toContain('2013-10-22');
          expect(valid.getText()).toContain('myForm.input.$valid = true');
        });

        it('should be invalid if empty', function() {
          setInput('');
          expect(value.getText()).toEqual('value =');
          expect(valid.getText()).toContain('myForm.input.$valid = false');
        });

        it('should be invalid if over max', function() {
          setInput('2015-01-01');
          expect(value.getText()).toContain('');
          expect(valid.getText()).toContain('myForm.input.$valid = false');
        });
     </file>
     </example>
     */
  'date': createDateInputType('date', DATE_REGEXP,
         createDateParser(DATE_REGEXP, ['yyyy', 'MM', 'dd']),
         'yyyy-MM-dd'),

   /**
    * @ngdoc input
    * @name input[datetime-local]
    *
    * @description
    * Input with datetime validation and transformation. In browsers that do not yet support
    * the HTML5 date input, a text element will be used. In that case, the text must be entered in a valid ISO-8601
    * local datetime format (yyyy-MM-ddTHH:mm:ss), for example: `2010-12-28T14:57:00`.
    *
    * The model must always be a Date object, otherwise Angular will throw an error.
    * Invalid `Date` objects (dates whose `getTime()` is `NaN`) will be rendered as an empty string.
    *
    * The timezone to be used to read/write the `Date` instance in the model can be defined using
    * {@link ng.directive:ngModelOptions ngModelOptions}. By default, this is the timezone of the browser.
    *
    * @param {string} ngModel Assignable angular expression to data-bind to.
    * @param {string=} name Property name of the form under which the control is published.
    * @param {string=} min Sets the `min` validation error key if the value entered is less than `min`. This must be a
    * valid ISO datetime format (yyyy-MM-ddTHH:mm:ss).
    * @param {string=} max Sets the `max` validation error key if the value entered is greater than `max`. This must be
    * a valid ISO datetime format (yyyy-MM-ddTHH:mm:ss).
    * @param {string=} required Sets `required` validation error key if the value is not entered.
    * @param {string=} ngRequired Adds `required` attribute and `required` validation constraint to
    *    the element when the ngRequired expression evaluates to true. Use `ngRequired` instead of
    *    `required` when you want to data-bind to the `required` attribute.
    * @param {string=} ngChange Angular expression to be executed when input changes due to user
    *    interaction with the input element.
    *
    * @example
    <example name="datetimelocal-input-directive" module="dateExample">
    <file name="index.html">
      <script>
        angular.module('dateExample', [])
          .controller('DateController', ['$scope', function($scope) {
            $scope.example = {
              value: new Date(2010, 11, 28, 14, 57)
            };
          }]);
      </script>
      <form name="myForm" ng-controller="DateController as dateCtrl">
        Pick a date between in 2013:
        <input type="datetime-local" id="exampleInput" name="input" ng-model="example.value"
            placeholder="yyyy-MM-ddTHH:mm:ss" min="2001-01-01T00:00:00" max="2013-12-31T00:00:00" required />
        <span class="error" ng-show="myForm.input.$error.required">
            Required!</span>
        <span class="error" ng-show="myForm.input.$error.datetimelocal">
            Not a valid date!</span>
        <tt>value = {{example.value | date: "yyyy-MM-ddTHH:mm:ss"}}</tt><br/>
        <tt>myForm.input.$valid = {{myForm.input.$valid}}</tt><br/>
        <tt>myForm.input.$error = {{myForm.input.$error}}</tt><br/>
        <tt>myForm.$valid = {{myForm.$valid}}</tt><br/>
        <tt>myForm.$error.required = {{!!myForm.$error.required}}</tt><br/>
      </form>
    </file>
    <file name="protractor.js" type="protractor">
      var value = element(by.binding('example.value | date: "yyyy-MM-ddTHH:mm:ss"'));
      var valid = element(by.binding('myForm.input.$valid'));
      var input = element(by.model('example.value'));

      // currently protractor/webdriver does not support
      // sending keys to all known HTML5 input controls
      // for various browsers (https://github.com/angular/protractor/issues/562).
      function setInput(val) {
        // set the value of the element and force validation.
        var scr = "var ipt = document.getElementById('exampleInput'); " +
        "ipt.value = '" + val + "';" +
        "angular.element(ipt).scope().$apply(function(s) { s.myForm[ipt.name].$setViewValue('" + val + "'); });";
        browser.executeScript(scr);
      }

      it('should initialize to model', function() {
        expect(value.getText()).toContain('2010-12-28T14:57:00');
        expect(valid.getText()).toContain('myForm.input.$valid = true');
      });

      it('should be invalid if empty', function() {
        setInput('');
        expect(value.getText()).toEqual('value =');
        expect(valid.getText()).toContain('myForm.input.$valid = false');
      });

      it('should be invalid if over max', function() {
        setInput('2015-01-01T23:59:00');
        expect(value.getText()).toContain('');
        expect(valid.getText()).toContain('myForm.input.$valid = false');
      });
    </file>
    </example>
    */
  'datetime-local': createDateInputType('datetimelocal', DATETIMELOCAL_REGEXP,
      createDateParser(DATETIMELOCAL_REGEXP, ['yyyy', 'MM', 'dd', 'HH', 'mm', 'ss', 'sss']),
      'yyyy-MM-ddTHH:mm:ss.sss'),

  /**
   * @ngdoc input
   * @name input[time]
   *
   * @description
   * Input with time validation and transformation. In browsers that do not yet support
   * the HTML5 date input, a text element will be used. In that case, the text must be entered in a valid ISO-8601
   * local time format (HH:mm:ss), for example: `14:57:00`. Model must be a Date object. This binding will always output a
   * Date object to the model of January 1, 1970, or local date `new Date(1970, 0, 1, HH, mm, ss)`.
   *
   * The model must always be a Date object, otherwise Angular will throw an error.
   * Invalid `Date` objects (dates whose `getTime()` is `NaN`) will be rendered as an empty string.
   *
   * The timezone to be used to read/write the `Date` instance in the model can be defined using
   * {@link ng.directive:ngModelOptions ngModelOptions}. By default, this is the timezone of the browser.
   *
   * @param {string} ngModel Assignable angular expression to data-bind to.
   * @param {string=} name Property name of the form under which the control is published.
   * @param {string=} min Sets the `min` validation error key if the value entered is less than `min`. This must be a
   * valid ISO time format (HH:mm:ss).
   * @param {string=} max Sets the `max` validation error key if the value entered is greater than `max`. This must be a
   * valid ISO time format (HH:mm:ss).
   * @param {string=} required Sets `required` validation error key if the value is not entered.
   * @param {string=} ngRequired Adds `required` attribute and `required` validation constraint to
   *    the element when the ngRequired expression evaluates to true. Use `ngRequired` instead of
   *    `required` when you want to data-bind to the `required` attribute.
   * @param {string=} ngChange Angular expression to be executed when input changes due to user
   *    interaction with the input element.
   *
   * @example
   <example name="time-input-directive" module="timeExample">
   <file name="index.html">
     <script>
      angular.module('timeExample', [])
        .controller('DateController', ['$scope', function($scope) {
          $scope.example = {
            value: new Date(1970, 0, 1, 14, 57, 0)
          };
        }]);
     </script>
     <form name="myForm" ng-controller="DateController as dateCtrl">
        Pick a between 8am and 5pm:
        <input type="time" id="exampleInput" name="input" ng-model="example.value"
            placeholder="HH:mm:ss" min="08:00:00" max="17:00:00" required />
        <span class="error" ng-show="myForm.input.$error.required">
            Required!</span>
        <span class="error" ng-show="myForm.input.$error.time">
            Not a valid date!</span>
        <tt>value = {{example.value | date: "HH:mm:ss"}}</tt><br/>
        <tt>myForm.input.$valid = {{myForm.input.$valid}}</tt><br/>
        <tt>myForm.input.$error = {{myForm.input.$error}}</tt><br/>
        <tt>myForm.$valid = {{myForm.$valid}}</tt><br/>
        <tt>myForm.$error.required = {{!!myForm.$error.required}}</tt><br/>
     </form>
   </file>
   <file name="protractor.js" type="protractor">
      var value = element(by.binding('example.value | date: "HH:mm:ss"'));
      var valid = element(by.binding('myForm.input.$valid'));
      var input = element(by.model('example.value'));

      // currently protractor/webdriver does not support
      // sending keys to all known HTML5 input controls
      // for various browsers (https://github.com/angular/protractor/issues/562).
      function setInput(val) {
        // set the value of the element and force validation.
        var scr = "var ipt = document.getElementById('exampleInput'); " +
        "ipt.value = '" + val + "';" +
        "angular.element(ipt).scope().$apply(function(s) { s.myForm[ipt.name].$setViewValue('" + val + "'); });";
        browser.executeScript(scr);
      }

      it('should initialize to model', function() {
        expect(value.getText()).toContain('14:57:00');
        expect(valid.getText()).toContain('myForm.input.$valid = true');
      });

      it('should be invalid if empty', function() {
        setInput('');
        expect(value.getText()).toEqual('value =');
        expect(valid.getText()).toContain('myForm.input.$valid = false');
      });

      it('should be invalid if over max', function() {
        setInput('23:59:00');
        expect(value.getText()).toContain('');
        expect(valid.getText()).toContain('myForm.input.$valid = false');
      });
   </file>
   </example>
   */
  'time': createDateInputType('time', TIME_REGEXP,
      createDateParser(TIME_REGEXP, ['HH', 'mm', 'ss', 'sss']),
     'HH:mm:ss.sss'),

   /**
    * @ngdoc input
    * @name input[week]
    *
    * @description
    * Input with week-of-the-year validation and transformation to Date. In browsers that do not yet support
    * the HTML5 week input, a text element will be used. In that case, the text must be entered in a valid ISO-8601
    * week format (yyyy-W##), for example: `2013-W02`.
    *
    * The model must always be a Date object, otherwise Angular will throw an error.
    * Invalid `Date` objects (dates whose `getTime()` is `NaN`) will be rendered as an empty string.
    *
    * The timezone to be used to read/write the `Date` instance in the model can be defined using
    * {@link ng.directive:ngModelOptions ngModelOptions}. By default, this is the timezone of the browser.
    *
    * @param {string} ngModel Assignable angular expression to data-bind to.
    * @param {string=} name Property name of the form under which the control is published.
    * @param {string=} min Sets the `min` validation error key if the value entered is less than `min`. This must be a
    * valid ISO week format (yyyy-W##).
    * @param {string=} max Sets the `max` validation error key if the value entered is greater than `max`. This must be
    * a valid ISO week format (yyyy-W##).
    * @param {string=} required Sets `required` validation error key if the value is not entered.
    * @param {string=} ngRequired Adds `required` attribute and `required` validation constraint to
    *    the element when the ngRequired expression evaluates to true. Use `ngRequired` instead of
    *    `required` when you want to data-bind to the `required` attribute.
    * @param {string=} ngChange Angular expression to be executed when input changes due to user
    *    interaction with the input element.
    *
    * @example
    <example name="week-input-directive" module="weekExample">
    <file name="index.html">
      <script>
      angular.module('weekExample', [])
        .controller('DateController', ['$scope', function($scope) {
          $scope.example = {
            value: new Date(2013, 0, 3)
          };
        }]);
      </script>
      <form name="myForm" ng-controller="DateController as dateCtrl">
        Pick a date between in 2013:
        <input id="exampleInput" type="week" name="input" ng-model="example.value"
            placeholder="YYYY-W##" min="2012-W32" max="2013-W52" required />
        <span class="error" ng-show="myForm.input.$error.required">
            Required!</span>
        <span class="error" ng-show="myForm.input.$error.week">
            Not a valid date!</span>
        <tt>value = {{example.value | date: "yyyy-Www"}}</tt><br/>
        <tt>myForm.input.$valid = {{myForm.input.$valid}}</tt><br/>
        <tt>myForm.input.$error = {{myForm.input.$error}}</tt><br/>
        <tt>myForm.$valid = {{myForm.$valid}}</tt><br/>
        <tt>myForm.$error.required = {{!!myForm.$error.required}}</tt><br/>
      </form>
    </file>
    <file name="protractor.js" type="protractor">
      var value = element(by.binding('example.value | date: "yyyy-Www"'));
      var valid = element(by.binding('myForm.input.$valid'));
      var input = element(by.model('example.value'));

      // currently protractor/webdriver does not support
      // sending keys to all known HTML5 input controls
      // for various browsers (https://github.com/angular/protractor/issues/562).
      function setInput(val) {
        // set the value of the element and force validation.
        var scr = "var ipt = document.getElementById('exampleInput'); " +
        "ipt.value = '" + val + "';" +
        "angular.element(ipt).scope().$apply(function(s) { s.myForm[ipt.name].$setViewValue('" + val + "'); });";
        browser.executeScript(scr);
      }

      it('should initialize to model', function() {
        expect(value.getText()).toContain('2013-W01');
        expect(valid.getText()).toContain('myForm.input.$valid = true');
      });

      it('should be invalid if empty', function() {
        setInput('');
        expect(value.getText()).toEqual('value =');
        expect(valid.getText()).toContain('myForm.input.$valid = false');
      });

      it('should be invalid if over max', function() {
        setInput('2015-W01');
        expect(value.getText()).toContain('');
        expect(valid.getText()).toContain('myForm.input.$valid = false');
      });
    </file>
    </example>
    */
  'week': createDateInputType('week', WEEK_REGEXP, weekParser, 'yyyy-Www'),

  /**
   * @ngdoc input
   * @name input[month]
   *
   * @description
   * Input with month validation and transformation. In browsers that do not yet support
   * the HTML5 month input, a text element will be used. In that case, the text must be entered in a valid ISO-8601
   * month format (yyyy-MM), for example: `2009-01`.
   *
   * The model must always be a Date object, otherwise Angular will throw an error.
   * Invalid `Date` objects (dates whose `getTime()` is `NaN`) will be rendered as an empty string.
   * If the model is not set to the first of the month, the next view to model update will set it
   * to the first of the month.
   *
   * The timezone to be used to read/write the `Date` instance in the model can be defined using
   * {@link ng.directive:ngModelOptions ngModelOptions}. By default, this is the timezone of the browser.
   *
   * @param {string} ngModel Assignable angular expression to data-bind to.
   * @param {string=} name Property name of the form under which the control is published.
   * @param {string=} min Sets the `min` validation error key if the value entered is less than `min`. This must be
   * a valid ISO month format (yyyy-MM).
   * @param {string=} max Sets the `max` validation error key if the value entered is greater than `max`. This must
   * be a valid ISO month format (yyyy-MM).
   * @param {string=} required Sets `required` validation error key if the value is not entered.
   * @param {string=} ngRequired Adds `required` attribute and `required` validation constraint to
   *    the element when the ngRequired expression evaluates to true. Use `ngRequired` instead of
   *    `required` when you want to data-bind to the `required` attribute.
   * @param {string=} ngChange Angular expression to be executed when input changes due to user
   *    interaction with the input element.
   *
   * @example
   <example name="month-input-directive" module="monthExample">
   <file name="index.html">
     <script>
      angular.module('monthExample', [])
        .controller('DateController', ['$scope', function($scope) {
          $scope.example = {
            value: new Date(2013, 9, 1)
          };
        }]);
     </script>
     <form name="myForm" ng-controller="DateController as dateCtrl">
       Pick a month in 2013:
       <input id="exampleInput" type="month" name="input" ng-model="example.value"
          placeholder="yyyy-MM" min="2013-01" max="2013-12" required />
       <span class="error" ng-show="myForm.input.$error.required">
          Required!</span>
       <span class="error" ng-show="myForm.input.$error.month">
          Not a valid month!</span>
       <tt>value = {{example.value | date: "yyyy-MM"}}</tt><br/>
       <tt>myForm.input.$valid = {{myForm.input.$valid}}</tt><br/>
       <tt>myForm.input.$error = {{myForm.input.$error}}</tt><br/>
       <tt>myForm.$valid = {{myForm.$valid}}</tt><br/>
       <tt>myForm.$error.required = {{!!myForm.$error.required}}</tt><br/>
     </form>
   </file>
   <file name="protractor.js" type="protractor">
      var value = element(by.binding('example.value | date: "yyyy-MM"'));
      var valid = element(by.binding('myForm.input.$valid'));
      var input = element(by.model('example.value'));

      // currently protractor/webdriver does not support
      // sending keys to all known HTML5 input controls
      // for various browsers (https://github.com/angular/protractor/issues/562).
      function setInput(val) {
        // set the value of the element and force validation.
        var scr = "var ipt = document.getElementById('exampleInput'); " +
        "ipt.value = '" + val + "';" +
        "angular.element(ipt).scope().$apply(function(s) { s.myForm[ipt.name].$setViewValue('" + val + "'); });";
        browser.executeScript(scr);
      }

      it('should initialize to model', function() {
        expect(value.getText()).toContain('2013-10');
        expect(valid.getText()).toContain('myForm.input.$valid = true');
      });

      it('should be invalid if empty', function() {
        setInput('');
        expect(value.getText()).toEqual('value =');
        expect(valid.getText()).toContain('myForm.input.$valid = false');
      });

      it('should be invalid if over max', function() {
        setInput('2015-01');
        expect(value.getText()).toContain('');
        expect(valid.getText()).toContain('myForm.input.$valid = false');
      });
   </file>
   </example>
   */
  'month': createDateInputType('month', MONTH_REGEXP,
     createDateParser(MONTH_REGEXP, ['yyyy', 'MM']),
     'yyyy-MM'),

  /**
   * @ngdoc input
   * @name input[number]
   *
   * @description
   * Text input with number validation and transformation. Sets the `number` validation
   * error if not a valid number.
   *
   * <div class="alert alert-warning">
   * The model must always be of type `number` otherwise Angular will throw an error.
   * Be aware that a string containing a number is not enough. See the {@link ngModel:numfmt}
   * error docs for more information and an example of how to convert your model if necessary.
   * </div>
   *
   * @param {string} ngModel Assignable angular expression to data-bind to.
   * @param {string=} name Property name of the form under which the control is published.
   * @param {string=} min Sets the `min` validation error key if the value entered is less than `min`.
   * @param {string=} max Sets the `max` validation error key if the value entered is greater than `max`.
   * @param {string=} required Sets `required` validation error key if the value is not entered.
   * @param {string=} ngRequired Adds `required` attribute and `required` validation constraint to
   *    the element when the ngRequired expression evaluates to true. Use `ngRequired` instead of
   *    `required` when you want to data-bind to the `required` attribute.
   * @param {number=} ngMinlength Sets `minlength` validation error key if the value is shorter than
   *    minlength.
   * @param {number=} ngMaxlength Sets `maxlength` validation error key if the value is longer than
   *    maxlength. Setting the attribute to a negative or non-numeric value, allows view values of
   *    any length.
   * @param {string=} pattern Similar to `ngPattern` except that the attribute value is the actual string
   *    that contains the regular expression body that will be converted to a regular expression
   *    as in the ngPattern directive.
   * @param {string=} ngPattern Sets `pattern` validation error key if the ngModel value does not match
   *    a RegExp found by evaluating the Angular expression given in the attribute value.
   *    If the expression evaluates to a RegExp object then this is used directly.
   *    If the expression is a string then it will be converted to a RegExp after wrapping it in `^` and `$`
   *    characters. For instance, `"abc"` will be converted to `new RegExp('^abc$')`.
   * @param {string=} ngChange Angular expression to be executed when input changes due to user
   *    interaction with the input element.
   *
   * @example
      <example name="number-input-directive" module="numberExample">
        <file name="index.html">
         <script>
           angular.module('numberExample', [])
             .controller('ExampleController', ['$scope', function($scope) {
               $scope.example = {
                 value: 12
               };
             }]);
         </script>
         <form name="myForm" ng-controller="ExampleController">
           Number: <input type="number" name="input" ng-model="example.value"
                          min="0" max="99" required>
           <span class="error" ng-show="myForm.input.$error.required">
             Required!</span>
           <span class="error" ng-show="myForm.input.$error.number">
             Not valid number!</span>
           <tt>value = {{example.value}}</tt><br/>
           <tt>myForm.input.$valid = {{myForm.input.$valid}}</tt><br/>
           <tt>myForm.input.$error = {{myForm.input.$error}}</tt><br/>
           <tt>myForm.$valid = {{myForm.$valid}}</tt><br/>
           <tt>myForm.$error.required = {{!!myForm.$error.required}}</tt><br/>
          </form>
        </file>
        <file name="protractor.js" type="protractor">
          var value = element(by.binding('example.value'));
          var valid = element(by.binding('myForm.input.$valid'));
          var input = element(by.model('example.value'));

          it('should initialize to model', function() {
            expect(value.getText()).toContain('12');
            expect(valid.getText()).toContain('true');
          });

          it('should be invalid if empty', function() {
            input.clear();
            input.sendKeys('');
            expect(value.getText()).toEqual('value =');
            expect(valid.getText()).toContain('false');
          });

          it('should be invalid if over max', function() {
            input.clear();
            input.sendKeys('123');
            expect(value.getText()).toEqual('value =');
            expect(valid.getText()).toContain('false');
          });
        </file>
      </example>
   */
  'number': numberInputType,


  /**
   * @ngdoc input
   * @name input[url]
   *
   * @description
   * Text input with URL validation. Sets the `url` validation error key if the content is not a
   * valid URL.
   *
   * <div class="alert alert-warning">
   * **Note:** `input[url]` uses a regex to validate urls that is derived from the regex
   * used in Chromium. If you need stricter validation, you can use `ng-pattern` or modify
   * the built-in validators (see the {@link guide/forms Forms guide})
   * </div>
   *
   * @param {string} ngModel Assignable angular expression to data-bind to.
   * @param {string=} name Property name of the form under which the control is published.
   * @param {string=} required Sets `required` validation error key if the value is not entered.
   * @param {string=} ngRequired Adds `required` attribute and `required` validation constraint to
   *    the element when the ngRequired expression evaluates to true. Use `ngRequired` instead of
   *    `required` when you want to data-bind to the `required` attribute.
   * @param {number=} ngMinlength Sets `minlength` validation error key if the value is shorter than
   *    minlength.
   * @param {number=} ngMaxlength Sets `maxlength` validation error key if the value is longer than
   *    maxlength. Setting the attribute to a negative or non-numeric value, allows view values of
   *    any length.
   * @param {string=} pattern Similar to `ngPattern` except that the attribute value is the actual string
   *    that contains the regular expression body that will be converted to a regular expression
   *    as in the ngPattern directive.
   * @param {string=} ngPattern Sets `pattern` validation error key if the ngModel value does not match
   *    a RegExp found by evaluating the Angular expression given in the attribute value.
   *    If the expression evaluates to a RegExp object then this is used directly.
   *    If the expression is a string then it will be converted to a RegExp after wrapping it in `^` and `$`
   *    characters. For instance, `"abc"` will be converted to `new RegExp('^abc$')`.
   * @param {string=} ngChange Angular expression to be executed when input changes due to user
   *    interaction with the input element.
   *
   * @example
      <example name="url-input-directive" module="urlExample">
        <file name="index.html">
         <script>
           angular.module('urlExample', [])
             .controller('ExampleController', ['$scope', function($scope) {
               $scope.url = {
                 text: 'http://google.com'
               };
             }]);
         </script>
         <form name="myForm" ng-controller="ExampleController">
           URL: <input type="url" name="input" ng-model="url.text" required>
           <span class="error" ng-show="myForm.input.$error.required">
             Required!</span>
           <span class="error" ng-show="myForm.input.$error.url">
             Not valid url!</span>
           <tt>text = {{url.text}}</tt><br/>
           <tt>myForm.input.$valid = {{myForm.input.$valid}}</tt><br/>
           <tt>myForm.input.$error = {{myForm.input.$error}}</tt><br/>
           <tt>myForm.$valid = {{myForm.$valid}}</tt><br/>
           <tt>myForm.$error.required = {{!!myForm.$error.required}}</tt><br/>
           <tt>myForm.$error.url = {{!!myForm.$error.url}}</tt><br/>
          </form>
        </file>
        <file name="protractor.js" type="protractor">
          var text = element(by.binding('url.text'));
          var valid = element(by.binding('myForm.input.$valid'));
          var input = element(by.model('url.text'));

          it('should initialize to model', function() {
            expect(text.getText()).toContain('http://google.com');
            expect(valid.getText()).toContain('true');
          });

          it('should be invalid if empty', function() {
            input.clear();
            input.sendKeys('');

            expect(text.getText()).toEqual('text =');
            expect(valid.getText()).toContain('false');
          });

          it('should be invalid if not url', function() {
            input.clear();
            input.sendKeys('box');

            expect(valid.getText()).toContain('false');
          });
        </file>
      </example>
   */
  'url': urlInputType,


  /**
   * @ngdoc input
   * @name input[email]
   *
   * @description
   * Text input with email validation. Sets the `email` validation error key if not a valid email
   * address.
   *
   * <div class="alert alert-warning">
   * **Note:** `input[email]` uses a regex to validate email addresses that is derived from the regex
   * used in Chromium. If you need stricter validation (e.g. requiring a top-level domain), you can
   * use `ng-pattern` or modify the built-in validators (see the {@link guide/forms Forms guide})
   * </div>
   *
   * @param {string} ngModel Assignable angular expression to data-bind to.
   * @param {string=} name Property name of the form under which the control is published.
   * @param {string=} required Sets `required` validation error key if the value is not entered.
   * @param {string=} ngRequired Adds `required` attribute and `required` validation constraint to
   *    the element when the ngRequired expression evaluates to true. Use `ngRequired` instead of
   *    `required` when you want to data-bind to the `required` attribute.
   * @param {number=} ngMinlength Sets `minlength` validation error key if the value is shorter than
   *    minlength.
   * @param {number=} ngMaxlength Sets `maxlength` validation error key if the value is longer than
   *    maxlength. Setting the attribute to a negative or non-numeric value, allows view values of
   *    any length.
   * @param {string=} pattern Similar to `ngPattern` except that the attribute value is the actual string
   *    that contains the regular expression body that will be converted to a regular expression
   *    as in the ngPattern directive.
   * @param {string=} ngPattern Sets `pattern` validation error key if the ngModel value does not match
   *    a RegExp found by evaluating the Angular expression given in the attribute value.
   *    If the expression evaluates to a RegExp object then this is used directly.
   *    If the expression is a string then it will be converted to a RegExp after wrapping it in `^` and `$`
   *    characters. For instance, `"abc"` will be converted to `new RegExp('^abc$')`.
   * @param {string=} ngChange Angular expression to be executed when input changes due to user
   *    interaction with the input element.
   *
   * @example
      <example name="email-input-directive" module="emailExample">
        <file name="index.html">
         <script>
           angular.module('emailExample', [])
             .controller('ExampleController', ['$scope', function($scope) {
               $scope.email = {
                 text: 'me@example.com'
               };
             }]);
         </script>
           <form name="myForm" ng-controller="ExampleController">
             Email: <input type="email" name="input" ng-model="email.text" required>
             <span class="error" ng-show="myForm.input.$error.required">
               Required!</span>
             <span class="error" ng-show="myForm.input.$error.email">
               Not valid email!</span>
             <tt>text = {{email.text}}</tt><br/>
             <tt>myForm.input.$valid = {{myForm.input.$valid}}</tt><br/>
             <tt>myForm.input.$error = {{myForm.input.$error}}</tt><br/>
             <tt>myForm.$valid = {{myForm.$valid}}</tt><br/>
             <tt>myForm.$error.required = {{!!myForm.$error.required}}</tt><br/>
             <tt>myForm.$error.email = {{!!myForm.$error.email}}</tt><br/>
           </form>
         </file>
        <file name="protractor.js" type="protractor">
          var text = element(by.binding('email.text'));
          var valid = element(by.binding('myForm.input.$valid'));
          var input = element(by.model('email.text'));

          it('should initialize to model', function() {
            expect(text.getText()).toContain('me@example.com');
            expect(valid.getText()).toContain('true');
          });

          it('should be invalid if empty', function() {
            input.clear();
            input.sendKeys('');
            expect(text.getText()).toEqual('text =');
            expect(valid.getText()).toContain('false');
          });

          it('should be invalid if not email', function() {
            input.clear();
            input.sendKeys('xxx');

            expect(valid.getText()).toContain('false');
          });
        </file>
      </example>
   */
  'email': emailInputType,


  /**
   * @ngdoc input
   * @name input[radio]
   *
   * @description
   * HTML radio button.
   *
   * @param {string} ngModel Assignable angular expression to data-bind to.
   * @param {string} value The value to which the expression should be set when selected.
   * @param {string=} name Property name of the form under which the control is published.
   * @param {string=} ngChange Angular expression to be executed when input changes due to user
   *    interaction with the input element.
   * @param {string} ngValue Angular expression which sets the value to which the expression should
   *    be set when selected.
   *
   * @example
      <example name="radio-input-directive" module="radioExample">
        <file name="index.html">
         <script>
           angular.module('radioExample', [])
             .controller('ExampleController', ['$scope', function($scope) {
               $scope.color = {
                 name: 'blue'
               };
               $scope.specialValue = {
                 "id": "12345",
                 "value": "green"
               };
             }]);
         </script>
         <form name="myForm" ng-controller="ExampleController">
           <input type="radio" ng-model="color.name" value="red">  Red <br/>
           <input type="radio" ng-model="color.name" ng-value="specialValue"> Green <br/>
           <input type="radio" ng-model="color.name" value="blue"> Blue <br/>
           <tt>color = {{color.name | json}}</tt><br/>
          </form>
          Note that `ng-value="specialValue"` sets radio item's value to be the value of `$scope.specialValue`.
        </file>
        <file name="protractor.js" type="protractor">
          it('should change state', function() {
            var color = element(by.binding('color.name'));

            expect(color.getText()).toContain('blue');

            element.all(by.model('color.name')).get(0).click();

            expect(color.getText()).toContain('red');
          });
        </file>
      </example>
   */
  'radio': radioInputType,


  /**
   * @ngdoc input
   * @name input[checkbox]
   *
   * @description
   * HTML checkbox.
   *
   * @param {string} ngModel Assignable angular expression to data-bind to.
   * @param {string=} name Property name of the form under which the control is published.
   * @param {expression=} ngTrueValue The value to which the expression should be set when selected.
   * @param {expression=} ngFalseValue The value to which the expression should be set when not selected.
   * @param {string=} ngChange Angular expression to be executed when input changes due to user
   *    interaction with the input element.
   *
   * @example
      <example name="checkbox-input-directive" module="checkboxExample">
        <file name="index.html">
         <script>
           angular.module('checkboxExample', [])
             .controller('ExampleController', ['$scope', function($scope) {
               $scope.checkboxModel = {
                value1 : true,
                value2 : 'YES'
              };
             }]);
         </script>
         <form name="myForm" ng-controller="ExampleController">
           Value1: <input type="checkbox" ng-model="checkboxModel.value1"> <br/>
           Value2: <input type="checkbox" ng-model="checkboxModel.value2"
                          ng-true-value="'YES'" ng-false-value="'NO'"> <br/>
           <tt>value1 = {{checkboxModel.value1}}</tt><br/>
           <tt>value2 = {{checkboxModel.value2}}</tt><br/>
          </form>
        </file>
        <file name="protractor.js" type="protractor">
          it('should change state', function() {
            var value1 = element(by.binding('checkboxModel.value1'));
            var value2 = element(by.binding('checkboxModel.value2'));

            expect(value1.getText()).toContain('true');
            expect(value2.getText()).toContain('YES');

            element(by.model('checkboxModel.value1')).click();
            element(by.model('checkboxModel.value2')).click();

            expect(value1.getText()).toContain('false');
            expect(value2.getText()).toContain('NO');
          });
        </file>
      </example>
   */
  'checkbox': checkboxInputType,

  'hidden': noop,
  'button': noop,
  'submit': noop,
  'reset': noop,
  'file': noop
};

function stringBasedInputType(ctrl) {
  ctrl.$formatters.push(function(value) {
    return ctrl.$isEmpty(value) ? value : value.toString();
  });
}

function textInputType(scope, element, attr, ctrl, $sniffer, $browser) {
  baseInputType(scope, element, attr, ctrl, $sniffer, $browser);
  stringBasedInputType(ctrl);
}

function baseInputType(scope, element, attr, ctrl, $sniffer, $browser) {
  var type = lowercase(element[0].type);

  // In composition mode, users are still inputing intermediate text buffer,
  // hold the listener until composition is done.
  // More about composition events: https://developer.mozilla.org/en-US/docs/Web/API/CompositionEvent
  if (!$sniffer.android) {
    var composing = false;

    element.on('compositionstart', function(data) {
      composing = true;
    });

    element.on('compositionend', function() {
      composing = false;
      listener();
    });
  }

  var listener = function(ev) {
    if (timeout) {
      $browser.defer.cancel(timeout);
      timeout = null;
    }
    if (composing) return;
    var value = element.val(),
        event = ev && ev.type;

    // By default we will trim the value
    // If the attribute ng-trim exists we will avoid trimming
    // If input type is 'password', the value is never trimmed
    if (type !== 'password' && (!attr.ngTrim || attr.ngTrim !== 'false')) {
      value = trim(value);
    }

    // If a control is suffering from bad input (due to native validators), browsers discard its
    // value, so it may be necessary to revalidate (by calling $setViewValue again) even if the
    // control's value is the same empty value twice in a row.
    if (ctrl.$viewValue !== value || (value === '' && ctrl.$$hasNativeValidators)) {
      ctrl.$setViewValue(value, event);
    }
  };

  // if the browser does support "input" event, we are fine - except on IE9 which doesn't fire the
  // input event on backspace, delete or cut
  if ($sniffer.hasEvent('input')) {
    element.on('input', listener);
  } else {
    var timeout;

    var deferListener = function(ev, input, origValue) {
      if (!timeout) {
        timeout = $browser.defer(function() {
          timeout = null;
          if (!input || input.value !== origValue) {
            listener(ev);
          }
        });
      }
    };

    element.on('keydown', function(event) {
      var key = event.keyCode;

      // ignore
      //    command            modifiers                   arrows
      if (key === 91 || (15 < key && key < 19) || (37 <= key && key <= 40)) return;

      deferListener(event, this, this.value);
    });

    // if user modifies input value using context menu in IE, we need "paste" and "cut" events to catch it
    if ($sniffer.hasEvent('paste')) {
      element.on('paste cut', deferListener);
    }
  }

  // if user paste into input using mouse on older browser
  // or form autocomplete on newer browser, we need "change" event to catch it
  element.on('change', listener);

  ctrl.$render = function() {
    element.val(ctrl.$isEmpty(ctrl.$viewValue) ? '' : ctrl.$viewValue);
  };
}

function weekParser(isoWeek, existingDate) {
  if (isDate(isoWeek)) {
    return isoWeek;
  }

  if (isString(isoWeek)) {
    WEEK_REGEXP.lastIndex = 0;
    var parts = WEEK_REGEXP.exec(isoWeek);
    if (parts) {
      var year = +parts[1],
          week = +parts[2],
          hours = 0,
          minutes = 0,
          seconds = 0,
          milliseconds = 0,
          firstThurs = getFirstThursdayOfYear(year),
          addDays = (week - 1) * 7;

      if (existingDate) {
        hours = existingDate.getHours();
        minutes = existingDate.getMinutes();
        seconds = existingDate.getSeconds();
        milliseconds = existingDate.getMilliseconds();
      }

      return new Date(year, 0, firstThurs.getDate() + addDays, hours, minutes, seconds, milliseconds);
    }
  }

  return NaN;
}

function createDateParser(regexp, mapping) {
  return function(iso, date) {
    var parts, map;

    if (isDate(iso)) {
      return iso;
    }

    if (isString(iso)) {
      // When a date is JSON'ified to wraps itself inside of an extra
      // set of double quotes. This makes the date parsing code unable
      // to match the date string and parse it as a date.
      if (iso.charAt(0) == '"' && iso.charAt(iso.length - 1) == '"') {
        iso = iso.substring(1, iso.length - 1);
      }
      if (ISO_DATE_REGEXP.test(iso)) {
        return new Date(iso);
      }
      regexp.lastIndex = 0;
      parts = regexp.exec(iso);

      if (parts) {
        parts.shift();
        if (date) {
          map = {
            yyyy: date.getFullYear(),
            MM: date.getMonth() + 1,
            dd: date.getDate(),
            HH: date.getHours(),
            mm: date.getMinutes(),
            ss: date.getSeconds(),
            sss: date.getMilliseconds() / 1000
          };
        } else {
          map = { yyyy: 1970, MM: 1, dd: 1, HH: 0, mm: 0, ss: 0, sss: 0 };
        }

        forEach(parts, function(part, index) {
          if (index < mapping.length) {
            map[mapping[index]] = +part;
          }
        });
        return new Date(map.yyyy, map.MM - 1, map.dd, map.HH, map.mm, map.ss || 0, map.sss * 1000 || 0);
      }
    }

    return NaN;
  };
}

function createDateInputType(type, regexp, parseDate, format) {
  return function dynamicDateInputType(scope, element, attr, ctrl, $sniffer, $browser, $filter) {
    badInputChecker(scope, element, attr, ctrl);
    baseInputType(scope, element, attr, ctrl, $sniffer, $browser);
    var timezone = ctrl && ctrl.$options && ctrl.$options.timezone;
    var previousDate;

    ctrl.$$parserName = type;
    ctrl.$parsers.push(function(value) {
      if (ctrl.$isEmpty(value)) return null;
      if (regexp.test(value)) {
        // Note: We cannot read ctrl.$modelValue, as there might be a different
        // parser/formatter in the processing chain so that the model
        // contains some different data format!
        var parsedDate = parseDate(value, previousDate);
        if (timezone === 'UTC') {
          parsedDate.setMinutes(parsedDate.getMinutes() - parsedDate.getTimezoneOffset());
        }
        return parsedDate;
      }
      return undefined;
    });

    ctrl.$formatters.push(function(value) {
      if (value && !isDate(value)) {
        throw ngModelMinErr('datefmt', 'Expected `{0}` to be a date', value);
      }
      if (isValidDate(value)) {
        previousDate = value;
        if (previousDate && timezone === 'UTC') {
          var timezoneOffset = 60000 * previousDate.getTimezoneOffset();
          previousDate = new Date(previousDate.getTime() + timezoneOffset);
        }
        return $filter('date')(value, format, timezone);
      } else {
        previousDate = null;
        return '';
      }
    });

    if (isDefined(attr.min) || attr.ngMin) {
      var minVal;
      ctrl.$validators.min = function(value) {
        return !isValidDate(value) || isUndefined(minVal) || parseDate(value) >= minVal;
      };
      attr.$observe('min', function(val) {
        minVal = parseObservedDateValue(val);
        ctrl.$validate();
      });
    }

    if (isDefined(attr.max) || attr.ngMax) {
      var maxVal;
      ctrl.$validators.max = function(value) {
        return !isValidDate(value) || isUndefined(maxVal) || parseDate(value) <= maxVal;
      };
      attr.$observe('max', function(val) {
        maxVal = parseObservedDateValue(val);
        ctrl.$validate();
      });
    }

    function isValidDate(value) {
      // Invalid Date: getTime() returns NaN
      return value && !(value.getTime && value.getTime() !== value.getTime());
    }

    function parseObservedDateValue(val) {
      return isDefined(val) ? (isDate(val) ? val : parseDate(val)) : undefined;
    }
  };
}

function badInputChecker(scope, element, attr, ctrl) {
  var node = element[0];
  var nativeValidation = ctrl.$$hasNativeValidators = isObject(node.validity);
  if (nativeValidation) {
    ctrl.$parsers.push(function(value) {
      var validity = element.prop(VALIDITY_STATE_PROPERTY) || {};
      // Detect bug in FF35 for input[email] (https://bugzilla.mozilla.org/show_bug.cgi?id=1064430):
      // - also sets validity.badInput (should only be validity.typeMismatch).
      // - see http://www.whatwg.org/specs/web-apps/current-work/multipage/forms.html#e-mail-state-(type=email)
      // - can ignore this case as we can still read out the erroneous email...
      return validity.badInput && !validity.typeMismatch ? undefined : value;
    });
  }
}

function numberInputType(scope, element, attr, ctrl, $sniffer, $browser) {
  badInputChecker(scope, element, attr, ctrl);
  baseInputType(scope, element, attr, ctrl, $sniffer, $browser);

  ctrl.$$parserName = 'number';
  ctrl.$parsers.push(function(value) {
    if (ctrl.$isEmpty(value))      return null;
    if (NUMBER_REGEXP.test(value)) return parseFloat(value);
    return undefined;
  });

  ctrl.$formatters.push(function(value) {
    if (!ctrl.$isEmpty(value)) {
      if (!isNumber(value)) {
        throw ngModelMinErr('numfmt', 'Expected `{0}` to be a number', value);
      }
      value = value.toString();
    }
    return value;
  });

  if (isDefined(attr.min) || attr.ngMin) {
    var minVal;
    ctrl.$validators.min = function(value) {
      return ctrl.$isEmpty(value) || isUndefined(minVal) || value >= minVal;
    };

    attr.$observe('min', function(val) {
      if (isDefined(val) && !isNumber(val)) {
        val = parseFloat(val, 10);
      }
      minVal = isNumber(val) && !isNaN(val) ? val : undefined;
      // TODO(matsko): implement validateLater to reduce number of validations
      ctrl.$validate();
    });
  }

  if (isDefined(attr.max) || attr.ngMax) {
    var maxVal;
    ctrl.$validators.max = function(value) {
      return ctrl.$isEmpty(value) || isUndefined(maxVal) || value <= maxVal;
    };

    attr.$observe('max', function(val) {
      if (isDefined(val) && !isNumber(val)) {
        val = parseFloat(val, 10);
      }
      maxVal = isNumber(val) && !isNaN(val) ? val : undefined;
      // TODO(matsko): implement validateLater to reduce number of validations
      ctrl.$validate();
    });
  }
}

function urlInputType(scope, element, attr, ctrl, $sniffer, $browser) {
  // Note: no badInputChecker here by purpose as `url` is only a validation
  // in browsers, i.e. we can always read out input.value even if it is not valid!
  baseInputType(scope, element, attr, ctrl, $sniffer, $browser);
  stringBasedInputType(ctrl);

  ctrl.$$parserName = 'url';
  ctrl.$validators.url = function(modelValue, viewValue) {
    var value = modelValue || viewValue;
    return ctrl.$isEmpty(value) || URL_REGEXP.test(value);
  };
}

function emailInputType(scope, element, attr, ctrl, $sniffer, $browser) {
  // Note: no badInputChecker here by purpose as `url` is only a validation
  // in browsers, i.e. we can always read out input.value even if it is not valid!
  baseInputType(scope, element, attr, ctrl, $sniffer, $browser);
  stringBasedInputType(ctrl);

  ctrl.$$parserName = 'email';
  ctrl.$validators.email = function(modelValue, viewValue) {
    var value = modelValue || viewValue;
    return ctrl.$isEmpty(value) || EMAIL_REGEXP.test(value);
  };
}

function radioInputType(scope, element, attr, ctrl) {
  // make the name unique, if not defined
  if (isUndefined(attr.name)) {
    element.attr('name', nextUid());
  }

  var listener = function(ev) {
    if (element[0].checked) {
      ctrl.$setViewValue(attr.value, ev && ev.type);
    }
  };

  element.on('click', listener);

  ctrl.$render = function() {
    var value = attr.value;
    element[0].checked = (value == ctrl.$viewValue);
  };

  attr.$observe('value', ctrl.$render);
}

function parseConstantExpr($parse, context, name, expression, fallback) {
  var parseFn;
  if (isDefined(expression)) {
    parseFn = $parse(expression);
    if (!parseFn.constant) {
      throw ngModelMinErr('constexpr', 'Expected constant expression for `{0}`, but saw ' +
                                   '`{1}`.', name, expression);
    }
    return parseFn(context);
  }
  return fallback;
}

function checkboxInputType(scope, element, attr, ctrl, $sniffer, $browser, $filter, $parse) {
  var trueValue = parseConstantExpr($parse, scope, 'ngTrueValue', attr.ngTrueValue, true);
  var falseValue = parseConstantExpr($parse, scope, 'ngFalseValue', attr.ngFalseValue, false);

  var listener = function(ev) {
    ctrl.$setViewValue(element[0].checked, ev && ev.type);
  };

  element.on('click', listener);

  ctrl.$render = function() {
    element[0].checked = ctrl.$viewValue;
  };

  // Override the standard `$isEmpty` because the $viewValue of an empty checkbox is always set to `false`
  // This is because of the parser below, which compares the `$modelValue` with `trueValue` to convert
  // it to a boolean.
  ctrl.$isEmpty = function(value) {
    return value === false;
  };

  ctrl.$formatters.push(function(value) {
    return equals(value, trueValue);
  });

  ctrl.$parsers.push(function(value) {
    return value ? trueValue : falseValue;
  });
}


/**
 * @ngdoc directive
 * @name textarea
 * @restrict E
 *
 * @description
 * HTML textarea element control with angular data-binding. The data-binding and validation
 * properties of this element are exactly the same as those of the
 * {@link ng.directive:input input element}.
 *
 * @param {string} ngModel Assignable angular expression to data-bind to.
 * @param {string=} name Property name of the form under which the control is published.
 * @param {string=} required Sets `required` validation error key if the value is not entered.
 * @param {string=} ngRequired Adds `required` attribute and `required` validation constraint to
 *    the element when the ngRequired expression evaluates to true. Use `ngRequired` instead of
 *    `required` when you want to data-bind to the `required` attribute.
 * @param {number=} ngMinlength Sets `minlength` validation error key if the value is shorter than
 *    minlength.
 * @param {number=} ngMaxlength Sets `maxlength` validation error key if the value is longer than
 *    maxlength. Setting the attribute to a negative or non-numeric value, allows view values of any
 *    length.
 * @param {string=} ngPattern Sets `pattern` validation error key if the value does not match the
 *    RegExp pattern expression. Expected value is `/regexp/` for inline patterns or `regexp` for
 *    patterns defined as scope expressions.
 * @param {string=} ngChange Angular expression to be executed when input changes due to user
 *    interaction with the input element.
 * @param {boolean=} [ngTrim=true] If set to false Angular will not automatically trim the input.
 */


/**
 * @ngdoc directive
 * @name input
 * @restrict E
 *
 * @description
 * HTML input element control. When used together with {@link ngModel `ngModel`}, it provides data-binding,
 * input state control, and validation.
 * Input control follows HTML5 input types and polyfills the HTML5 validation behavior for older browsers.
 *
 * <div class="alert alert-warning">
 * **Note:** Not every feature offered is available for all input types.
 * Specifically, data binding and event handling via `ng-model` is unsupported for `input[file]`.
 * </div>
 *
 * @param {string} ngModel Assignable angular expression to data-bind to.
 * @param {string=} name Property name of the form under which the control is published.
 * @param {string=} required Sets `required` validation error key if the value is not entered.
 * @param {boolean=} ngRequired Sets `required` attribute if set to true
 * @param {number=} ngMinlength Sets `minlength` validation error key if the value is shorter than
 *    minlength.
 * @param {number=} ngMaxlength Sets `maxlength` validation error key if the value is longer than
 *    maxlength. Setting the attribute to a negative or non-numeric value, allows view values of any
 *    length.
 * @param {string=} ngPattern Sets `pattern` validation error key if the value does not match the
 *    RegExp pattern expression. Expected value is `/regexp/` for inline patterns or `regexp` for
 *    patterns defined as scope expressions.
 * @param {string=} ngChange Angular expression to be executed when input changes due to user
 *    interaction with the input element.
 * @param {boolean=} [ngTrim=true] If set to false Angular will not automatically trim the input.
 *    This parameter is ignored for input[type=password] controls, which will never trim the
 *    input.
 *
 * @example
    <example name="input-directive" module="inputExample">
      <file name="index.html">
       <script>
          angular.module('inputExample', [])
            .controller('ExampleController', ['$scope', function($scope) {
              $scope.user = {name: 'guest', last: 'visitor'};
            }]);
       </script>
       <div ng-controller="ExampleController">
         <form name="myForm">
           User name: <input type="text" name="userName" ng-model="user.name" required>
           <span class="error" ng-show="myForm.userName.$error.required">
             Required!</span><br>
           Last name: <input type="text" name="lastName" ng-model="user.last"
             ng-minlength="3" ng-maxlength="10">
           <span class="error" ng-show="myForm.lastName.$error.minlength">
             Too short!</span>
           <span class="error" ng-show="myForm.lastName.$error.maxlength">
             Too long!</span><br>
         </form>
         <hr>
         <tt>user = {{user}}</tt><br/>
         <tt>myForm.userName.$valid = {{myForm.userName.$valid}}</tt><br>
         <tt>myForm.userName.$error = {{myForm.userName.$error}}</tt><br>
         <tt>myForm.lastName.$valid = {{myForm.lastName.$valid}}</tt><br>
         <tt>myForm.lastName.$error = {{myForm.lastName.$error}}</tt><br>
         <tt>myForm.$valid = {{myForm.$valid}}</tt><br>
         <tt>myForm.$error.required = {{!!myForm.$error.required}}</tt><br>
         <tt>myForm.$error.minlength = {{!!myForm.$error.minlength}}</tt><br>
         <tt>myForm.$error.maxlength = {{!!myForm.$error.maxlength}}</tt><br>
       </div>
      </file>
      <file name="protractor.js" type="protractor">
        var user = element(by.exactBinding('user'));
        var userNameValid = element(by.binding('myForm.userName.$valid'));
        var lastNameValid = element(by.binding('myForm.lastName.$valid'));
        var lastNameError = element(by.binding('myForm.lastName.$error'));
        var formValid = element(by.binding('myForm.$valid'));
        var userNameInput = element(by.model('user.name'));
        var userLastInput = element(by.model('user.last'));

        it('should initialize to model', function() {
          expect(user.getText()).toContain('{"name":"guest","last":"visitor"}');
          expect(userNameValid.getText()).toContain('true');
          expect(formValid.getText()).toContain('true');
        });

        it('should be invalid if empty when required', function() {
          userNameInput.clear();
          userNameInput.sendKeys('');

          expect(user.getText()).toContain('{"last":"visitor"}');
          expect(userNameValid.getText()).toContain('false');
          expect(formValid.getText()).toContain('false');
        });

        it('should be valid if empty when min length is set', function() {
          userLastInput.clear();
          userLastInput.sendKeys('');

          expect(user.getText()).toContain('{"name":"guest","last":""}');
          expect(lastNameValid.getText()).toContain('true');
          expect(formValid.getText()).toContain('true');
        });

        it('should be invalid if less than required min length', function() {
          userLastInput.clear();
          userLastInput.sendKeys('xx');

          expect(user.getText()).toContain('{"name":"guest"}');
          expect(lastNameValid.getText()).toContain('false');
          expect(lastNameError.getText()).toContain('minlength');
          expect(formValid.getText()).toContain('false');
        });

        it('should be invalid if longer than max length', function() {
          userLastInput.clear();
          userLastInput.sendKeys('some ridiculously long name');

          expect(user.getText()).toContain('{"name":"guest"}');
          expect(lastNameValid.getText()).toContain('false');
          expect(lastNameError.getText()).toContain('maxlength');
          expect(formValid.getText()).toContain('false');
        });
      </file>
    </example>
 */
var inputDirective = ['$browser', '$sniffer', '$filter', '$parse',
    function($browser, $sniffer, $filter, $parse) {
  return {
    restrict: 'E',
    require: ['?ngModel'],
    link: {
      pre: function(scope, element, attr, ctrls) {
        if (ctrls[0]) {
          (inputType[lowercase(attr.type)] || inputType.text)(scope, element, attr, ctrls[0], $sniffer,
                                                              $browser, $filter, $parse);
        }
      }
    }
  };
}];



var CONSTANT_VALUE_REGEXP = /^(true|false|\d+)$/;
/**
 * @ngdoc directive
 * @name ngValue
 *
 * @description
 * Binds the given expression to the value of `<option>` or {@link input[radio] `input[radio]`},
 * so that when the element is selected, the {@link ngModel `ngModel`} of that element is set to
 * the bound value.
 *
 * `ngValue` is useful when dynamically generating lists of radio buttons using
 * {@link ngRepeat `ngRepeat`}, as shown below.
 *
 * Likewise, `ngValue` can be used to generate `<option>` elements for
 * the {@link select `select`} element. In that case however, only strings are supported
 * for the `value `attribute, so the resulting `ngModel` will always be a string.
 * Support for `select` models with non-string values is available via `ngOptions`.
 *
 * @element input
 * @param {string=} ngValue angular expression, whose value will be bound to the `value` attribute
 *   of the `input` element
 *
 * @example
    <example name="ngValue-directive" module="valueExample">
      <file name="index.html">
       <script>
          angular.module('valueExample', [])
            .controller('ExampleController', ['$scope', function($scope) {
              $scope.names = ['pizza', 'unicorns', 'robots'];
              $scope.my = { favorite: 'unicorns' };
            }]);
       </script>
        <form ng-controller="ExampleController">
          <h2>Which is your favorite?</h2>
            <label ng-repeat="name in names" for="{{name}}">
              {{name}}
              <input type="radio"
                     ng-model="my.favorite"
                     ng-value="name"
                     id="{{name}}"
                     name="favorite">
            </label>
          <div>You chose {{my.favorite}}</div>
        </form>
      </file>
      <file name="protractor.js" type="protractor">
        var favorite = element(by.binding('my.favorite'));

        it('should initialize to model', function() {
          expect(favorite.getText()).toContain('unicorns');
        });
        it('should bind the values to the inputs', function() {
          element.all(by.model('my.favorite')).get(0).click();
          expect(favorite.getText()).toContain('pizza');
        });
      </file>
    </example>
 */
var ngValueDirective = function() {
  return {
    restrict: 'A',
    priority: 100,
    compile: function(tpl, tplAttr) {
      if (CONSTANT_VALUE_REGEXP.test(tplAttr.ngValue)) {
        return function ngValueConstantLink(scope, elm, attr) {
          attr.$set('value', scope.$eval(attr.ngValue));
        };
      } else {
        return function ngValueLink(scope, elm, attr) {
          scope.$watch(attr.ngValue, function valueWatchAction(value) {
            attr.$set('value', value);
          });
        };
      }
    }
  };
};

/**
 * @ngdoc directive
 * @name ngBind
 * @restrict AC
 *
 * @description
 * The `ngBind` attribute tells Angular to replace the text content of the specified HTML element
 * with the value of a given expression, and to update the text content when the value of that
 * expression changes.
 *
 * Typically, you don't use `ngBind` directly, but instead you use the double curly markup like
 * `{{ expression }}` which is similar but less verbose.
 *
 * It is preferable to use `ngBind` instead of `{{ expression }}` if a template is momentarily
 * displayed by the browser in its raw state before Angular compiles it. Since `ngBind` is an
 * element attribute, it makes the bindings invisible to the user while the page is loading.
 *
 * An alternative solution to this problem would be using the
 * {@link ng.directive:ngCloak ngCloak} directive.
 *
 *
 * @element ANY
 * @param {expression} ngBind {@link guide/expression Expression} to evaluate.
 *
 * @example
 * Enter a name in the Live Preview text box; the greeting below the text box changes instantly.
   <example module="bindExample">
     <file name="index.html">
       <script>
         angular.module('bindExample', [])
           .controller('ExampleController', ['$scope', function($scope) {
             $scope.name = 'Whirled';
           }]);
       </script>
       <div ng-controller="ExampleController">
         Enter name: <input type="text" ng-model="name"><br>
         Hello <span ng-bind="name"></span>!
       </div>
     </file>
     <file name="protractor.js" type="protractor">
       it('should check ng-bind', function() {
         var nameInput = element(by.model('name'));

         expect(element(by.binding('name')).getText()).toBe('Whirled');
         nameInput.clear();
         nameInput.sendKeys('world');
         expect(element(by.binding('name')).getText()).toBe('world');
       });
     </file>
   </example>
 */
var ngBindDirective = ['$compile', function($compile) {
  return {
    restrict: 'AC',
    compile: function ngBindCompile(templateElement) {
      $compile.$$addBindingClass(templateElement);
      return function ngBindLink(scope, element, attr) {
        $compile.$$addBindingInfo(element, attr.ngBind);
        element = element[0];
        scope.$watch(attr.ngBind, function ngBindWatchAction(value) {
          element.textContent = value === undefined ? '' : value;
        });
      };
    }
  };
}];


/**
 * @ngdoc directive
 * @name ngBindTemplate
 *
 * @description
 * The `ngBindTemplate` directive specifies that the element
 * text content should be replaced with the interpolation of the template
 * in the `ngBindTemplate` attribute.
 * Unlike `ngBind`, the `ngBindTemplate` can contain multiple `{{` `}}`
 * expressions. This directive is needed since some HTML elements
 * (such as TITLE and OPTION) cannot contain SPAN elements.
 *
 * @element ANY
 * @param {string} ngBindTemplate template of form
 *   <tt>{{</tt> <tt>expression</tt> <tt>}}</tt> to eval.
 *
 * @example
 * Try it here: enter text in text box and watch the greeting change.
   <example module="bindExample">
     <file name="index.html">
       <script>
         angular.module('bindExample', [])
           .controller('ExampleController', ['$scope', function($scope) {
             $scope.salutation = 'Hello';
             $scope.name = 'World';
           }]);
       </script>
       <div ng-controller="ExampleController">
        Salutation: <input type="text" ng-model="salutation"><br>
        Name: <input type="text" ng-model="name"><br>
        <pre ng-bind-template="{{salutation}} {{name}}!"></pre>
       </div>
     </file>
     <file name="protractor.js" type="protractor">
       it('should check ng-bind', function() {
         var salutationElem = element(by.binding('salutation'));
         var salutationInput = element(by.model('salutation'));
         var nameInput = element(by.model('name'));

         expect(salutationElem.getText()).toBe('Hello World!');

         salutationInput.clear();
         salutationInput.sendKeys('Greetings');
         nameInput.clear();
         nameInput.sendKeys('user');

         expect(salutationElem.getText()).toBe('Greetings user!');
       });
     </file>
   </example>
 */
var ngBindTemplateDirective = ['$interpolate', '$compile', function($interpolate, $compile) {
  return {
    compile: function ngBindTemplateCompile(templateElement) {
      $compile.$$addBindingClass(templateElement);
      return function ngBindTemplateLink(scope, element, attr) {
        var interpolateFn = $interpolate(element.attr(attr.$attr.ngBindTemplate));
        $compile.$$addBindingInfo(element, interpolateFn.expressions);
        element = element[0];
        attr.$observe('ngBindTemplate', function(value) {
          element.textContent = value === undefined ? '' : value;
        });
      };
    }
  };
}];


/**
 * @ngdoc directive
 * @name ngBindHtml
 *
 * @description
 * Evaluates the expression and inserts the resulting HTML into the element in a secure way. By default,
 * the resulting HTML content will be sanitized using the {@link ngSanitize.$sanitize $sanitize} service.
 * To utilize this functionality, ensure that `$sanitize` is available, for example, by including {@link
 * ngSanitize} in your module's dependencies (not in core Angular). In order to use {@link ngSanitize}
 * in your module's dependencies, you need to include "angular-sanitize.js" in your application.
 *
 * You may also bypass sanitization for values you know are safe. To do so, bind to
 * an explicitly trusted value via {@link ng.$sce#trustAsHtml $sce.trustAsHtml}.  See the example
 * under {@link ng.$sce#show-me-an-example-using-sce- Strict Contextual Escaping (SCE)}.
 *
 * Note: If a `$sanitize` service is unavailable and the bound value isn't explicitly trusted, you
 * will have an exception (instead of an exploit.)
 *
 * @element ANY
 * @param {expression} ngBindHtml {@link guide/expression Expression} to evaluate.
 *
 * @example

   <example module="bindHtmlExample" deps="angular-sanitize.js">
     <file name="index.html">
       <div ng-controller="ExampleController">
        <p ng-bind-html="myHTML"></p>
       </div>
     </file>

     <file name="script.js">
       angular.module('bindHtmlExample', ['ngSanitize'])
         .controller('ExampleController', ['$scope', function($scope) {
           $scope.myHTML =
              'I am an <code>HTML</code>string with ' +
              '<a href="#">links!</a> and other <em>stuff</em>';
         }]);
     </file>

     <file name="protractor.js" type="protractor">
       it('should check ng-bind-html', function() {
         expect(element(by.binding('myHTML')).getText()).toBe(
             'I am an HTMLstring with links! and other stuff');
       });
     </file>
   </example>
 */
var ngBindHtmlDirective = ['$sce', '$parse', '$compile', function($sce, $parse, $compile) {
  return {
    restrict: 'A',
    compile: function ngBindHtmlCompile(tElement, tAttrs) {
      var ngBindHtmlGetter = $parse(tAttrs.ngBindHtml);
      var ngBindHtmlWatch = $parse(tAttrs.ngBindHtml, function getStringValue(value) {
        return (value || '').toString();
      });
      $compile.$$addBindingClass(tElement);

      return function ngBindHtmlLink(scope, element, attr) {
        $compile.$$addBindingInfo(element, attr.ngBindHtml);

        scope.$watch(ngBindHtmlWatch, function ngBindHtmlWatchAction() {
          // we re-evaluate the expr because we want a TrustedValueHolderType
          // for $sce, not a string
          element.html($sce.getTrustedHtml(ngBindHtmlGetter(scope)) || '');
        });
      };
    }
  };
}];

/**
 * @ngdoc directive
 * @name ngChange
 *
 * @description
 * Evaluate the given expression when the user changes the input.
 * The expression is evaluated immediately, unlike the JavaScript onchange event
 * which only triggers at the end of a change (usually, when the user leaves the
 * form element or presses the return key).
 *
 * The `ngChange` expression is only evaluated when a change in the input value causes
 * a new value to be committed to the model.
 *
 * It will not be evaluated:
 * * if the value returned from the `$parsers` transformation pipeline has not changed
 * * if the input has continued to be invalid since the model will stay `null`
 * * if the model is changed programmatically and not by a change to the input value
 *
 *
 * Note, this directive requires `ngModel` to be present.
 *
 * @element input
 * @param {expression} ngChange {@link guide/expression Expression} to evaluate upon change
 * in input value.
 *
 * @example
 * <example name="ngChange-directive" module="changeExample">
 *   <file name="index.html">
 *     <script>
 *       angular.module('changeExample', [])
 *         .controller('ExampleController', ['$scope', function($scope) {
 *           $scope.counter = 0;
 *           $scope.change = function() {
 *             $scope.counter++;
 *           };
 *         }]);
 *     </script>
 *     <div ng-controller="ExampleController">
 *       <input type="checkbox" ng-model="confirmed" ng-change="change()" id="ng-change-example1" />
 *       <input type="checkbox" ng-model="confirmed" id="ng-change-example2" />
 *       <label for="ng-change-example2">Confirmed</label><br />
 *       <tt>debug = {{confirmed}}</tt><br/>
 *       <tt>counter = {{counter}}</tt><br/>
 *     </div>
 *   </file>
 *   <file name="protractor.js" type="protractor">
 *     var counter = element(by.binding('counter'));
 *     var debug = element(by.binding('confirmed'));
 *
 *     it('should evaluate the expression if changing from view', function() {
 *       expect(counter.getText()).toContain('0');
 *
 *       element(by.id('ng-change-example1')).click();
 *
 *       expect(counter.getText()).toContain('1');
 *       expect(debug.getText()).toContain('true');
 *     });
 *
 *     it('should not evaluate the expression if changing from model', function() {
 *       element(by.id('ng-change-example2')).click();

 *       expect(counter.getText()).toContain('0');
 *       expect(debug.getText()).toContain('true');
 *     });
 *   </file>
 * </example>
 */
var ngChangeDirective = valueFn({
  restrict: 'A',
  require: 'ngModel',
  link: function(scope, element, attr, ctrl) {
    ctrl.$viewChangeListeners.push(function() {
      scope.$eval(attr.ngChange);
    });
  }
});

function classDirective(name, selector) {
  name = 'ngClass' + name;
  return ['$animate', function($animate) {
    return {
      restrict: 'AC',
      link: function(scope, element, attr) {
        var oldVal;

        scope.$watch(attr[name], ngClassWatchAction, true);

        attr.$observe('class', function(value) {
          ngClassWatchAction(scope.$eval(attr[name]));
        });


        if (name !== 'ngClass') {
          scope.$watch('$index', function($index, old$index) {
            // jshint bitwise: false
            var mod = $index & 1;
            if (mod !== (old$index & 1)) {
              var classes = arrayClasses(scope.$eval(attr[name]));
              mod === selector ?
                addClasses(classes) :
                removeClasses(classes);
            }
          });
        }

        function addClasses(classes) {
          var newClasses = digestClassCounts(classes, 1);
          attr.$addClass(newClasses);
        }

        function removeClasses(classes) {
          var newClasses = digestClassCounts(classes, -1);
          attr.$removeClass(newClasses);
        }

        function digestClassCounts(classes, count) {
          var classCounts = element.data('$classCounts') || {};
          var classesToUpdate = [];
          forEach(classes, function(className) {
            if (count > 0 || classCounts[className]) {
              classCounts[className] = (classCounts[className] || 0) + count;
              if (classCounts[className] === +(count > 0)) {
                classesToUpdate.push(className);
              }
            }
          });
          element.data('$classCounts', classCounts);
          return classesToUpdate.join(' ');
        }

        function updateClasses(oldClasses, newClasses) {
          var toAdd = arrayDifference(newClasses, oldClasses);
          var toRemove = arrayDifference(oldClasses, newClasses);
          toAdd = digestClassCounts(toAdd, 1);
          toRemove = digestClassCounts(toRemove, -1);
          if (toAdd && toAdd.length) {
            $animate.addClass(element, toAdd);
          }
          if (toRemove && toRemove.length) {
            $animate.removeClass(element, toRemove);
          }
        }

        function ngClassWatchAction(newVal) {
          if (selector === true || scope.$index % 2 === selector) {
            var newClasses = arrayClasses(newVal || []);
            if (!oldVal) {
              addClasses(newClasses);
            } else if (!equals(newVal,oldVal)) {
              var oldClasses = arrayClasses(oldVal);
              updateClasses(oldClasses, newClasses);
            }
          }
          oldVal = shallowCopy(newVal);
        }
      }
    };

    function arrayDifference(tokens1, tokens2) {
      var values = [];

      outer:
      for (var i = 0; i < tokens1.length; i++) {
        var token = tokens1[i];
        for (var j = 0; j < tokens2.length; j++) {
          if (token == tokens2[j]) continue outer;
        }
        values.push(token);
      }
      return values;
    }

    function arrayClasses(classVal) {
      if (isArray(classVal)) {
        return classVal;
      } else if (isString(classVal)) {
        return classVal.split(' ');
      } else if (isObject(classVal)) {
        var classes = [];
        forEach(classVal, function(v, k) {
          if (v) {
            classes = classes.concat(k.split(' '));
          }
        });
        return classes;
      }
      return classVal;
    }
  }];
}

/**
 * @ngdoc directive
 * @name ngClass
 * @restrict AC
 *
 * @description
 * The `ngClass` directive allows you to dynamically set CSS classes on an HTML element by databinding
 * an expression that represents all classes to be added.
 *
 * The directive operates in three different ways, depending on which of three types the expression
 * evaluates to:
 *
 * 1. If the expression evaluates to a string, the string should be one or more space-delimited class
 * names.
 *
 * 2. If the expression evaluates to an array, each element of the array should be a string that is
 * one or more space-delimited class names.
 *
 * 3. If the expression evaluates to an object, then for each key-value pair of the
 * object with a truthy value the corresponding key is used as a class name.
 *
 * The directive won't add duplicate classes if a particular class was already set.
 *
 * When the expression changes, the previously added classes are removed and only then the
 * new classes are added.
 *
 * @animations
 * **add** - happens just before the class is applied to the elements
 *
 * **remove** - happens just before the class is removed from the element
 *
 * @element ANY
 * @param {expression} ngClass {@link guide/expression Expression} to eval. The result
 *   of the evaluation can be a string representing space delimited class
 *   names, an array, or a map of class names to boolean values. In the case of a map, the
 *   names of the properties whose values are truthy will be added as css classes to the
 *   element.
 *
 * @example Example that demonstrates basic bindings via ngClass directive.
   <example>
     <file name="index.html">
       <p ng-class="{strike: deleted, bold: important, red: error}">Map Syntax Example</p>
       <input type="checkbox" ng-model="deleted"> deleted (apply "strike" class)<br>
       <input type="checkbox" ng-model="important"> important (apply "bold" class)<br>
       <input type="checkbox" ng-model="error"> error (apply "red" class)
       <hr>
       <p ng-class="style">Using String Syntax</p>
       <input type="text" ng-model="style" placeholder="Type: bold strike red">
       <hr>
       <p ng-class="[style1, style2, style3]">Using Array Syntax</p>
       <input ng-model="style1" placeholder="Type: bold, strike or red"><br>
       <input ng-model="style2" placeholder="Type: bold, strike or red"><br>
       <input ng-model="style3" placeholder="Type: bold, strike or red"><br>
     </file>
     <file name="style.css">
       .strike {
         text-decoration: line-through;
       }
       .bold {
           font-weight: bold;
       }
       .red {
           color: red;
       }
     </file>
     <file name="protractor.js" type="protractor">
       var ps = element.all(by.css('p'));

       it('should let you toggle the class', function() {

         expect(ps.first().getAttribute('class')).not.toMatch(/bold/);
         expect(ps.first().getAttribute('class')).not.toMatch(/red/);

         element(by.model('important')).click();
         expect(ps.first().getAttribute('class')).toMatch(/bold/);

         element(by.model('error')).click();
         expect(ps.first().getAttribute('class')).toMatch(/red/);
       });

       it('should let you toggle string example', function() {
         expect(ps.get(1).getAttribute('class')).toBe('');
         element(by.model('style')).clear();
         element(by.model('style')).sendKeys('red');
         expect(ps.get(1).getAttribute('class')).toBe('red');
       });

       it('array example should have 3 classes', function() {
         expect(ps.last().getAttribute('class')).toBe('');
         element(by.model('style1')).sendKeys('bold');
         element(by.model('style2')).sendKeys('strike');
         element(by.model('style3')).sendKeys('red');
         expect(ps.last().getAttribute('class')).toBe('bold strike red');
       });
     </file>
   </example>

   ## Animations

   The example below demonstrates how to perform animations using ngClass.

   <example module="ngAnimate" deps="angular-animate.js" animations="true">
     <file name="index.html">
      <input id="setbtn" type="button" value="set" ng-click="myVar='my-class'">
      <input id="clearbtn" type="button" value="clear" ng-click="myVar=''">
      <br>
      <span class="base-class" ng-class="myVar">Sample Text</span>
     </file>
     <file name="style.css">
       .base-class {
         -webkit-transition:all cubic-bezier(0.250, 0.460, 0.450, 0.940) 0.5s;
         transition:all cubic-bezier(0.250, 0.460, 0.450, 0.940) 0.5s;
       }

       .base-class.my-class {
         color: red;
         font-size:3em;
       }
     </file>
     <file name="protractor.js" type="protractor">
       it('should check ng-class', function() {
         expect(element(by.css('.base-class')).getAttribute('class')).not.
           toMatch(/my-class/);

         element(by.id('setbtn')).click();

         expect(element(by.css('.base-class')).getAttribute('class')).
           toMatch(/my-class/);

         element(by.id('clearbtn')).click();

         expect(element(by.css('.base-class')).getAttribute('class')).not.
           toMatch(/my-class/);
       });
     </file>
   </example>


   ## ngClass and pre-existing CSS3 Transitions/Animations
   The ngClass directive still supports CSS3 Transitions/Animations even if they do not follow the ngAnimate CSS naming structure.
   Upon animation ngAnimate will apply supplementary CSS classes to track the start and end of an animation, but this will not hinder
   any pre-existing CSS transitions already on the element. To get an idea of what happens during a class-based animation, be sure
   to view the step by step details of {@link ng.$animate#addClass $animate.addClass} and
   {@link ng.$animate#removeClass $animate.removeClass}.
 */
var ngClassDirective = classDirective('', true);

/**
 * @ngdoc directive
 * @name ngClassOdd
 * @restrict AC
 *
 * @description
 * The `ngClassOdd` and `ngClassEven` directives work exactly as
 * {@link ng.directive:ngClass ngClass}, except they work in
 * conjunction with `ngRepeat` and take effect only on odd (even) rows.
 *
 * This directive can be applied only within the scope of an
 * {@link ng.directive:ngRepeat ngRepeat}.
 *
 * @element ANY
 * @param {expression} ngClassOdd {@link guide/expression Expression} to eval. The result
 *   of the evaluation can be a string representing space delimited class names or an array.
 *
 * @example
   <example>
     <file name="index.html">
        <ol ng-init="names=['John', 'Mary', 'Cate', 'Suz']">
          <li ng-repeat="name in names">
           <span ng-class-odd="'odd'" ng-class-even="'even'">
             {{name}}
           </span>
          </li>
        </ol>
     </file>
     <file name="style.css">
       .odd {
         color: red;
       }
       .even {
         color: blue;
       }
     </file>
     <file name="protractor.js" type="protractor">
       it('should check ng-class-odd and ng-class-even', function() {
         expect(element(by.repeater('name in names').row(0).column('name')).getAttribute('class')).
           toMatch(/odd/);
         expect(element(by.repeater('name in names').row(1).column('name')).getAttribute('class')).
           toMatch(/even/);
       });
     </file>
   </example>
 */
var ngClassOddDirective = classDirective('Odd', 0);

/**
 * @ngdoc directive
 * @name ngClassEven
 * @restrict AC
 *
 * @description
 * The `ngClassOdd` and `ngClassEven` directives work exactly as
 * {@link ng.directive:ngClass ngClass}, except they work in
 * conjunction with `ngRepeat` and take effect only on odd (even) rows.
 *
 * This directive can be applied only within the scope of an
 * {@link ng.directive:ngRepeat ngRepeat}.
 *
 * @element ANY
 * @param {expression} ngClassEven {@link guide/expression Expression} to eval. The
 *   result of the evaluation can be a string representing space delimited class names or an array.
 *
 * @example
   <example>
     <file name="index.html">
        <ol ng-init="names=['John', 'Mary', 'Cate', 'Suz']">
          <li ng-repeat="name in names">
           <span ng-class-odd="'odd'" ng-class-even="'even'">
             {{name}} &nbsp; &nbsp; &nbsp;
           </span>
          </li>
        </ol>
     </file>
     <file name="style.css">
       .odd {
         color: red;
       }
       .even {
         color: blue;
       }
     </file>
     <file name="protractor.js" type="protractor">
       it('should check ng-class-odd and ng-class-even', function() {
         expect(element(by.repeater('name in names').row(0).column('name')).getAttribute('class')).
           toMatch(/odd/);
         expect(element(by.repeater('name in names').row(1).column('name')).getAttribute('class')).
           toMatch(/even/);
       });
     </file>
   </example>
 */
var ngClassEvenDirective = classDirective('Even', 1);

/**
 * @ngdoc directive
 * @name ngCloak
 * @restrict AC
 *
 * @description
 * The `ngCloak` directive is used to prevent the Angular html template from being briefly
 * displayed by the browser in its raw (uncompiled) form while your application is loading. Use this
 * directive to avoid the undesirable flicker effect caused by the html template display.
 *
 * The directive can be applied to the `<body>` element, but the preferred usage is to apply
 * multiple `ngCloak` directives to small portions of the page to permit progressive rendering
 * of the browser view.
 *
 * `ngCloak` works in cooperation with the following css rule embedded within `angular.js` and
 * `angular.min.js`.
 * For CSP mode please add `angular-csp.css` to your html file (see {@link ng.directive:ngCsp ngCsp}).
 *
 * ```css
 * [ng\:cloak], [ng-cloak], [data-ng-cloak], [x-ng-cloak], .ng-cloak, .x-ng-cloak {
 *   display: none !important;
 * }
 * ```
 *
 * When this css rule is loaded by the browser, all html elements (including their children) that
 * are tagged with the `ngCloak` directive are hidden. When Angular encounters this directive
 * during the compilation of the template it deletes the `ngCloak` element attribute, making
 * the compiled element visible.
 *
 * For the best result, the `angular.js` script must be loaded in the head section of the html
 * document; alternatively, the css rule above must be included in the external stylesheet of the
 * application.
 *
 * @element ANY
 *
 * @example
   <example>
     <file name="index.html">
        <div id="template1" ng-cloak>{{ 'hello' }}</div>
        <div id="template2" class="ng-cloak">{{ 'world' }}</div>
     </file>
     <file name="protractor.js" type="protractor">
       it('should remove the template directive and css class', function() {
         expect($('#template1').getAttribute('ng-cloak')).
           toBeNull();
         expect($('#template2').getAttribute('ng-cloak')).
           toBeNull();
       });
     </file>
   </example>
 *
 */
var ngCloakDirective = ngDirective({
  compile: function(element, attr) {
    attr.$set('ngCloak', undefined);
    element.removeClass('ng-cloak');
  }
});

/**
 * @ngdoc directive
 * @name ngController
 *
 * @description
 * The `ngController` directive attaches a controller class to the view. This is a key aspect of how angular
 * supports the principles behind the Model-View-Controller design pattern.
 *
 * MVC components in angular:
 *
 * * Model — Models are the properties of a scope; scopes are attached to the DOM where scope properties
 *   are accessed through bindings.
 * * View — The template (HTML with data bindings) that is rendered into the View.
 * * Controller — The `ngController` directive specifies a Controller class; the class contains business
 *   logic behind the application to decorate the scope with functions and values
 *
 * Note that you can also attach controllers to the DOM by declaring it in a route definition
 * via the {@link ngRoute.$route $route} service. A common mistake is to declare the controller
 * again using `ng-controller` in the template itself.  This will cause the controller to be attached
 * and executed twice.
 *
 * @element ANY
 * @scope
 * @priority 500
 * @param {expression} ngController Name of a constructor function registered with the current
 * {@link ng.$controllerProvider $controllerProvider} or an {@link guide/expression expression}
 * that on the current scope evaluates to a constructor function.
 *
 * The controller instance can be published into a scope property by specifying
 * `ng-controller="as propertyName"`.
 *
 * If the current `$controllerProvider` is configured to use globals (via
 * {@link ng.$controllerProvider#allowGlobals `$controllerProvider.allowGlobals()` }), this may
 * also be the name of a globally accessible constructor function (not recommended).
 *
 * @example
 * Here is a simple form for editing user contact information. Adding, removing, clearing, and
 * greeting are methods declared on the controller (see source tab). These methods can
 * easily be called from the angular markup. Any changes to the data are automatically reflected
 * in the View without the need for a manual update.
 *
 * Two different declaration styles are included below:
 *
 * * one binds methods and properties directly onto the controller using `this`:
 * `ng-controller="SettingsController1 as settings"`
 * * one injects `$scope` into the controller:
 * `ng-controller="SettingsController2"`
 *
 * The second option is more common in the Angular community, and is generally used in boilerplates
 * and in this guide. However, there are advantages to binding properties directly to the controller
 * and avoiding scope.
 *
 * * Using `controller as` makes it obvious which controller you are accessing in the template when
 * multiple controllers apply to an element.
 * * If you are writing your controllers as classes you have easier access to the properties and
 * methods, which will appear on the scope, from inside the controller code.
 * * Since there is always a `.` in the bindings, you don't have to worry about prototypal
 * inheritance masking primitives.
 *
 * This example demonstrates the `controller as` syntax.
 *
 * <example name="ngControllerAs" module="controllerAsExample">
 *   <file name="index.html">
 *    <div id="ctrl-as-exmpl" ng-controller="SettingsController1 as settings">
 *      Name: <input type="text" ng-model="settings.name"/>
 *      [ <a href="" ng-click="settings.greet()">greet</a> ]<br/>
 *      Contact:
 *      <ul>
 *        <li ng-repeat="contact in settings.contacts">
 *          <select ng-model="contact.type">
 *             <option>phone</option>
 *             <option>email</option>
 *          </select>
 *          <input type="text" ng-model="contact.value"/>
 *          [ <a href="" ng-click="settings.clearContact(contact)">clear</a>
 *          | <a href="" ng-click="settings.removeContact(contact)">X</a> ]
 *        </li>
 *        <li>[ <a href="" ng-click="settings.addContact()">add</a> ]</li>
 *     </ul>
 *    </div>
 *   </file>
 *   <file name="app.js">
 *    angular.module('controllerAsExample', [])
 *      .controller('SettingsController1', SettingsController1);
 *
 *    function SettingsController1() {
 *      this.name = "John Smith";
 *      this.contacts = [
 *        {type: 'phone', value: '408 555 1212'},
 *        {type: 'email', value: 'john.smith@example.org'} ];
 *    }
 *
 *    SettingsController1.prototype.greet = function() {
 *      alert(this.name);
 *    };
 *
 *    SettingsController1.prototype.addContact = function() {
 *      this.contacts.push({type: 'email', value: 'yourname@example.org'});
 *    };
 *
 *    SettingsController1.prototype.removeContact = function(contactToRemove) {
 *     var index = this.contacts.indexOf(contactToRemove);
 *      this.contacts.splice(index, 1);
 *    };
 *
 *    SettingsController1.prototype.clearContact = function(contact) {
 *      contact.type = 'phone';
 *      contact.value = '';
 *    };
 *   </file>
 *   <file name="protractor.js" type="protractor">
 *     it('should check controller as', function() {
 *       var container = element(by.id('ctrl-as-exmpl'));
 *         expect(container.element(by.model('settings.name'))
 *           .getAttribute('value')).toBe('John Smith');
 *
 *       var firstRepeat =
 *           container.element(by.repeater('contact in settings.contacts').row(0));
 *       var secondRepeat =
 *           container.element(by.repeater('contact in settings.contacts').row(1));
 *
 *       expect(firstRepeat.element(by.model('contact.value')).getAttribute('value'))
 *           .toBe('408 555 1212');
 *
 *       expect(secondRepeat.element(by.model('contact.value')).getAttribute('value'))
 *           .toBe('john.smith@example.org');
 *
 *       firstRepeat.element(by.linkText('clear')).click();
 *
 *       expect(firstRepeat.element(by.model('contact.value')).getAttribute('value'))
 *           .toBe('');
 *
 *       container.element(by.linkText('add')).click();
 *
 *       expect(container.element(by.repeater('contact in settings.contacts').row(2))
 *           .element(by.model('contact.value'))
 *           .getAttribute('value'))
 *           .toBe('yourname@example.org');
 *     });
 *   </file>
 * </example>
 *
 * This example demonstrates the "attach to `$scope`" style of controller.
 *
 * <example name="ngController" module="controllerExample">
 *  <file name="index.html">
 *   <div id="ctrl-exmpl" ng-controller="SettingsController2">
 *     Name: <input type="text" ng-model="name"/>
 *     [ <a href="" ng-click="greet()">greet</a> ]<br/>
 *     Contact:
 *     <ul>
 *       <li ng-repeat="contact in contacts">
 *         <select ng-model="contact.type">
 *            <option>phone</option>
 *            <option>email</option>
 *         </select>
 *         <input type="text" ng-model="contact.value"/>
 *         [ <a href="" ng-click="clearContact(contact)">clear</a>
 *         | <a href="" ng-click="removeContact(contact)">X</a> ]
 *       </li>
 *       <li>[ <a href="" ng-click="addContact()">add</a> ]</li>
 *    </ul>
 *   </div>
 *  </file>
 *  <file name="app.js">
 *   angular.module('controllerExample', [])
 *     .controller('SettingsController2', ['$scope', SettingsController2]);
 *
 *   function SettingsController2($scope) {
 *     $scope.name = "John Smith";
 *     $scope.contacts = [
 *       {type:'phone', value:'408 555 1212'},
 *       {type:'email', value:'john.smith@example.org'} ];
 *
 *     $scope.greet = function() {
 *       alert($scope.name);
 *     };
 *
 *     $scope.addContact = function() {
 *       $scope.contacts.push({type:'email', value:'yourname@example.org'});
 *     };
 *
 *     $scope.removeContact = function(contactToRemove) {
 *       var index = $scope.contacts.indexOf(contactToRemove);
 *       $scope.contacts.splice(index, 1);
 *     };
 *
 *     $scope.clearContact = function(contact) {
 *       contact.type = 'phone';
 *       contact.value = '';
 *     };
 *   }
 *  </file>
 *  <file name="protractor.js" type="protractor">
 *    it('should check controller', function() {
 *      var container = element(by.id('ctrl-exmpl'));
 *
 *      expect(container.element(by.model('name'))
 *          .getAttribute('value')).toBe('John Smith');
 *
 *      var firstRepeat =
 *          container.element(by.repeater('contact in contacts').row(0));
 *      var secondRepeat =
 *          container.element(by.repeater('contact in contacts').row(1));
 *
 *      expect(firstRepeat.element(by.model('contact.value')).getAttribute('value'))
 *          .toBe('408 555 1212');
 *      expect(secondRepeat.element(by.model('contact.value')).getAttribute('value'))
 *          .toBe('john.smith@example.org');
 *
 *      firstRepeat.element(by.linkText('clear')).click();
 *
 *      expect(firstRepeat.element(by.model('contact.value')).getAttribute('value'))
 *          .toBe('');
 *
 *      container.element(by.linkText('add')).click();
 *
 *      expect(container.element(by.repeater('contact in contacts').row(2))
 *          .element(by.model('contact.value'))
 *          .getAttribute('value'))
 *          .toBe('yourname@example.org');
 *    });
 *  </file>
 *</example>

 */
var ngControllerDirective = [function() {
  return {
    restrict: 'A',
    scope: true,
    controller: '@',
    priority: 500
  };
}];

/**
 * @ngdoc directive
 * @name ngCsp
 *
 * @element html
 * @description
 * Enables [CSP (Content Security Policy)](https://developer.mozilla.org/en/Security/CSP) support.
 *
 * This is necessary when developing things like Google Chrome Extensions or Universal Windows Apps.
 *
 * CSP forbids apps to use `eval` or `Function(string)` generated functions (among other things).
 * For Angular to be CSP compatible there are only two things that we need to do differently:
 *
 * - don't use `Function` constructor to generate optimized value getters
 * - don't inject custom stylesheet into the document
 *
 * AngularJS uses `Function(string)` generated functions as a speed optimization. Applying the `ngCsp`
 * directive will cause Angular to use CSP compatibility mode. When this mode is on AngularJS will
 * evaluate all expressions up to 30% slower than in non-CSP mode, but no security violations will
 * be raised.
 *
 * CSP forbids JavaScript to inline stylesheet rules. In non CSP mode Angular automatically
 * includes some CSS rules (e.g. {@link ng.directive:ngCloak ngCloak}).
 * To make those directives work in CSP mode, include the `angular-csp.css` manually.
 *
 * Angular tries to autodetect if CSP is active and automatically turn on the CSP-safe mode. This
 * autodetection however triggers a CSP error to be logged in the console:
 *
 * ```
 * Refused to evaluate a string as JavaScript because 'unsafe-eval' is not an allowed source of
 * script in the following Content Security Policy directive: "default-src 'self'". Note that
 * 'script-src' was not explicitly set, so 'default-src' is used as a fallback.
 * ```
 *
 * This error is harmless but annoying. To prevent the error from showing up, put the `ngCsp`
 * directive on the root element of the application or on the `angular.js` script tag, whichever
 * appears first in the html document.
 *
 * *Note: This directive is only available in the `ng-csp` and `data-ng-csp` attribute form.*
 *
 * @example
 * This example shows how to apply the `ngCsp` directive to the `html` tag.
   ```html
     <!doctype html>
     <html ng-app ng-csp>
     ...
     ...
     </html>
   ```
  * @example
      // Note: the suffix `.csp` in the example name triggers
      // csp mode in our http server!
      <example name="example.csp" module="cspExample" ng-csp="true">
        <file name="index.html">
          <div ng-controller="MainController as ctrl">
            <div>
              <button ng-click="ctrl.inc()" id="inc">Increment</button>
              <span id="counter">
                {{ctrl.counter}}
              </span>
            </div>

            <div>
              <button ng-click="ctrl.evil()" id="evil">Evil</button>
              <span id="evilError">
                {{ctrl.evilError}}
              </span>
            </div>
          </div>
        </file>
        <file name="script.js">
           angular.module('cspExample', [])
             .controller('MainController', function() {
                this.counter = 0;
                this.inc = function() {
                  this.counter++;
                };
                this.evil = function() {
                  // jshint evil:true
                  try {
                    eval('1+2');
                  } catch (e) {
                    this.evilError = e.message;
                  }
                };
              });
        </file>
        <file name="protractor.js" type="protractor">
          var util, webdriver;

          var incBtn = element(by.id('inc'));
          var counter = element(by.id('counter'));
          var evilBtn = element(by.id('evil'));
          var evilError = element(by.id('evilError'));

          function getAndClearSevereErrors() {
            return browser.manage().logs().get('browser').then(function(browserLog) {
              return browserLog.filter(function(logEntry) {
                return logEntry.level.value > webdriver.logging.Level.WARNING.value;
              });
            });
          }

          function clearErrors() {
            getAndClearSevereErrors();
          }

          function expectNoErrors() {
            getAndClearSevereErrors().then(function(filteredLog) {
              expect(filteredLog.length).toEqual(0);
              if (filteredLog.length) {
                console.log('browser console errors: ' + util.inspect(filteredLog));
              }
            });
          }

          function expectError(regex) {
            getAndClearSevereErrors().then(function(filteredLog) {
              var found = false;
              filteredLog.forEach(function(log) {
                if (log.message.match(regex)) {
                  found = true;
                }
              });
              if (!found) {
                throw new Error('expected an error that matches ' + regex);
              }
            });
          }

          beforeEach(function() {
            util = require('util');
            webdriver = require('protractor/node_modules/selenium-webdriver');
          });

          // For now, we only test on Chrome,
          // as Safari does not load the page with Protractor's injected scripts,
          // and Firefox webdriver always disables content security policy (#6358)
          if (browser.params.browser !== 'chrome') {
            return;
          }

          it('should not report errors when the page is loaded', function() {
            // clear errors so we are not dependent on previous tests
            clearErrors();
            // Need to reload the page as the page is already loaded when
            // we come here
            browser.driver.getCurrentUrl().then(function(url) {
              browser.get(url);
            });
            expectNoErrors();
          });

          it('should evaluate expressions', function() {
            expect(counter.getText()).toEqual('0');
            incBtn.click();
            expect(counter.getText()).toEqual('1');
            expectNoErrors();
          });

          it('should throw and report an error when using "eval"', function() {
            evilBtn.click();
            expect(evilError.getText()).toMatch(/Content Security Policy/);
            expectError(/Content Security Policy/);
          });
        </file>
      </example>
  */

// ngCsp is not implemented as a proper directive any more, because we need it be processed while we
// bootstrap the system (before $parse is instantiated), for this reason we just have
// the csp.isActive() fn that looks for ng-csp attribute anywhere in the current doc

/**
 * @ngdoc directive
 * @name ngClick
 *
 * @description
 * The ngClick directive allows you to specify custom behavior when
 * an element is clicked.
 *
 * @element ANY
 * @priority 0
 * @param {expression} ngClick {@link guide/expression Expression} to evaluate upon
 * click. ({@link guide/expression#-event- Event object is available as `$event`})
 *
 * @example
   <example>
     <file name="index.html">
      <button ng-click="count = count + 1" ng-init="count=0">
        Increment
      </button>
      <span>
        count: {{count}}
      </span>
     </file>
     <file name="protractor.js" type="protractor">
       it('should check ng-click', function() {
         expect(element(by.binding('count')).getText()).toMatch('0');
         element(by.css('button')).click();
         expect(element(by.binding('count')).getText()).toMatch('1');
       });
     </file>
   </example>
 */
/*
 * A collection of directives that allows creation of custom event handlers that are defined as
 * angular expressions and are compiled and executed within the current scope.
 */
var ngEventDirectives = {};

// For events that might fire synchronously during DOM manipulation
// we need to execute their event handlers asynchronously using $evalAsync,
// so that they are not executed in an inconsistent state.
var forceAsyncEvents = {
  'blur': true,
  'focus': true
};
forEach(
  'click dblclick mousedown mouseup mouseover mouseout mousemove mouseenter mouseleave keydown keyup keypress submit focus blur copy cut paste'.split(' '),
  function(eventName) {
    var directiveName = directiveNormalize('ng-' + eventName);
    ngEventDirectives[directiveName] = ['$parse', '$rootScope', function($parse, $rootScope) {
      return {
        restrict: 'A',
        compile: function($element, attr) {
          // We expose the powerful $event object on the scope that provides access to the Window,
          // etc. that isn't protected by the fast paths in $parse.  We explicitly request better
          // checks at the cost of speed since event handler expressions are not executed as
          // frequently as regular change detection.
          var fn = $parse(attr[directiveName], /* interceptorFn */ null, /* expensiveChecks */ true);
          return function ngEventHandler(scope, element) {
            element.on(eventName, function(event) {
              var callback = function() {
                fn(scope, {$event:event});
              };
              if (forceAsyncEvents[eventName] && $rootScope.$$phase) {
                scope.$evalAsync(callback);
              } else {
                scope.$apply(callback);
              }
            });
          };
        }
      };
    }];
  }
);

/**
 * @ngdoc directive
 * @name ngDblclick
 *
 * @description
 * The `ngDblclick` directive allows you to specify custom behavior on a dblclick event.
 *
 * @element ANY
 * @priority 0
 * @param {expression} ngDblclick {@link guide/expression Expression} to evaluate upon
 * a dblclick. (The Event object is available as `$event`)
 *
 * @example
   <example>
     <file name="index.html">
      <button ng-dblclick="count = count + 1" ng-init="count=0">
        Increment (on double click)
      </button>
      count: {{count}}
     </file>
   </example>
 */


/**
 * @ngdoc directive
 * @name ngMousedown
 *
 * @description
 * The ngMousedown directive allows you to specify custom behavior on mousedown event.
 *
 * @element ANY
 * @priority 0
 * @param {expression} ngMousedown {@link guide/expression Expression} to evaluate upon
 * mousedown. ({@link guide/expression#-event- Event object is available as `$event`})
 *
 * @example
   <example>
     <file name="index.html">
      <button ng-mousedown="count = count + 1" ng-init="count=0">
        Increment (on mouse down)
      </button>
      count: {{count}}
     </file>
   </example>
 */


/**
 * @ngdoc directive
 * @name ngMouseup
 *
 * @description
 * Specify custom behavior on mouseup event.
 *
 * @element ANY
 * @priority 0
 * @param {expression} ngMouseup {@link guide/expression Expression} to evaluate upon
 * mouseup. ({@link guide/expression#-event- Event object is available as `$event`})
 *
 * @example
   <example>
     <file name="index.html">
      <button ng-mouseup="count = count + 1" ng-init="count=0">
        Increment (on mouse up)
      </button>
      count: {{count}}
     </file>
   </example>
 */

/**
 * @ngdoc directive
 * @name ngMouseover
 *
 * @description
 * Specify custom behavior on mouseover event.
 *
 * @element ANY
 * @priority 0
 * @param {expression} ngMouseover {@link guide/expression Expression} to evaluate upon
 * mouseover. ({@link guide/expression#-event- Event object is available as `$event`})
 *
 * @example
   <example>
     <file name="index.html">
      <button ng-mouseover="count = count + 1" ng-init="count=0">
        Increment (when mouse is over)
      </button>
      count: {{count}}
     </file>
   </example>
 */


/**
 * @ngdoc directive
 * @name ngMouseenter
 *
 * @description
 * Specify custom behavior on mouseenter event.
 *
 * @element ANY
 * @priority 0
 * @param {expression} ngMouseenter {@link guide/expression Expression} to evaluate upon
 * mouseenter. ({@link guide/expression#-event- Event object is available as `$event`})
 *
 * @example
   <example>
     <file name="index.html">
      <button ng-mouseenter="count = count + 1" ng-init="count=0">
        Increment (when mouse enters)
      </button>
      count: {{count}}
     </file>
   </example>
 */


/**
 * @ngdoc directive
 * @name ngMouseleave
 *
 * @description
 * Specify custom behavior on mouseleave event.
 *
 * @element ANY
 * @priority 0
 * @param {expression} ngMouseleave {@link guide/expression Expression} to evaluate upon
 * mouseleave. ({@link guide/expression#-event- Event object is available as `$event`})
 *
 * @example
   <example>
     <file name="index.html">
      <button ng-mouseleave="count = count + 1" ng-init="count=0">
        Increment (when mouse leaves)
      </button>
      count: {{count}}
     </file>
   </example>
 */


/**
 * @ngdoc directive
 * @name ngMousemove
 *
 * @description
 * Specify custom behavior on mousemove event.
 *
 * @element ANY
 * @priority 0
 * @param {expression} ngMousemove {@link guide/expression Expression} to evaluate upon
 * mousemove. ({@link guide/expression#-event- Event object is available as `$event`})
 *
 * @example
   <example>
     <file name="index.html">
      <button ng-mousemove="count = count + 1" ng-init="count=0">
        Increment (when mouse moves)
      </button>
      count: {{count}}
     </file>
   </example>
 */


/**
 * @ngdoc directive
 * @name ngKeydown
 *
 * @description
 * Specify custom behavior on keydown event.
 *
 * @element ANY
 * @priority 0
 * @param {expression} ngKeydown {@link guide/expression Expression} to evaluate upon
 * keydown. (Event object is available as `$event` and can be interrogated for keyCode, altKey, etc.)
 *
 * @example
   <example>
     <file name="index.html">
      <input ng-keydown="count = count + 1" ng-init="count=0">
      key down count: {{count}}
     </file>
   </example>
 */


/**
 * @ngdoc directive
 * @name ngKeyup
 *
 * @description
 * Specify custom behavior on keyup event.
 *
 * @element ANY
 * @priority 0
 * @param {expression} ngKeyup {@link guide/expression Expression} to evaluate upon
 * keyup. (Event object is available as `$event` and can be interrogated for keyCode, altKey, etc.)
 *
 * @example
   <example>
     <file name="index.html">
       <p>Typing in the input box below updates the key count</p>
       <input ng-keyup="count = count + 1" ng-init="count=0"> key up count: {{count}}

       <p>Typing in the input box below updates the keycode</p>
       <input ng-keyup="event=$event">
       <p>event keyCode: {{ event.keyCode }}</p>
       <p>event altKey: {{ event.altKey }}</p>
     </file>
   </example>
 */


/**
 * @ngdoc directive
 * @name ngKeypress
 *
 * @description
 * Specify custom behavior on keypress event.
 *
 * @element ANY
 * @param {expression} ngKeypress {@link guide/expression Expression} to evaluate upon
 * keypress. ({@link guide/expression#-event- Event object is available as `$event`}
 * and can be interrogated for keyCode, altKey, etc.)
 *
 * @example
   <example>
     <file name="index.html">
      <input ng-keypress="count = count + 1" ng-init="count=0">
      key press count: {{count}}
     </file>
   </example>
 */


/**
 * @ngdoc directive
 * @name ngSubmit
 *
 * @description
 * Enables binding angular expressions to onsubmit events.
 *
 * Additionally it prevents the default action (which for form means sending the request to the
 * server and reloading the current page), but only if the form does not contain `action`,
 * `data-action`, or `x-action` attributes.
 *
 * <div class="alert alert-warning">
 * **Warning:** Be careful not to cause "double-submission" by using both the `ngClick` and
 * `ngSubmit` handlers together. See the
 * {@link form#submitting-a-form-and-preventing-the-default-action `form` directive documentation}
 * for a detailed discussion of when `ngSubmit` may be triggered.
 * </div>
 *
 * @element form
 * @priority 0
 * @param {expression} ngSubmit {@link guide/expression Expression} to eval.
 * ({@link guide/expression#-event- Event object is available as `$event`})
 *
 * @example
   <example module="submitExample">
     <file name="index.html">
      <script>
        angular.module('submitExample', [])
          .controller('ExampleController', ['$scope', function($scope) {
            $scope.list = [];
            $scope.text = 'hello';
            $scope.submit = function() {
              if ($scope.text) {
                $scope.list.push(this.text);
                $scope.text = '';
              }
            };
          }]);
      </script>
      <form ng-submit="submit()" ng-controller="ExampleController">
        Enter text and hit enter:
        <input type="text" ng-model="text" name="text" />
        <input type="submit" id="submit" value="Submit" />
        <pre>list={{list}}</pre>
      </form>
     </file>
     <file name="protractor.js" type="protractor">
       it('should check ng-submit', function() {
         expect(element(by.binding('list')).getText()).toBe('list=[]');
         element(by.css('#submit')).click();
         expect(element(by.binding('list')).getText()).toContain('hello');
         expect(element(by.model('text')).getAttribute('value')).toBe('');
       });
       it('should ignore empty strings', function() {
         expect(element(by.binding('list')).getText()).toBe('list=[]');
         element(by.css('#submit')).click();
         element(by.css('#submit')).click();
         expect(element(by.binding('list')).getText()).toContain('hello');
        });
     </file>
   </example>
 */

/**
 * @ngdoc directive
 * @name ngFocus
 *
 * @description
 * Specify custom behavior on focus event.
 *
 * Note: As the `focus` event is executed synchronously when calling `input.focus()`
 * AngularJS executes the expression using `scope.$evalAsync` if the event is fired
 * during an `$apply` to ensure a consistent state.
 *
 * @element window, input, select, textarea, a
 * @priority 0
 * @param {expression} ngFocus {@link guide/expression Expression} to evaluate upon
 * focus. ({@link guide/expression#-event- Event object is available as `$event`})
 *
 * @example
 * See {@link ng.directive:ngClick ngClick}
 */

/**
 * @ngdoc directive
 * @name ngBlur
 *
 * @description
 * Specify custom behavior on blur event.
 *
 * A [blur event](https://developer.mozilla.org/en-US/docs/Web/Events/blur) fires when
 * an element has lost focus.
 *
 * Note: As the `blur` event is executed synchronously also during DOM manipulations
 * (e.g. removing a focussed input),
 * AngularJS executes the expression using `scope.$evalAsync` if the event is fired
 * during an `$apply` to ensure a consistent state.
 *
 * @element window, input, select, textarea, a
 * @priority 0
 * @param {expression} ngBlur {@link guide/expression Expression} to evaluate upon
 * blur. ({@link guide/expression#-event- Event object is available as `$event`})
 *
 * @example
 * See {@link ng.directive:ngClick ngClick}
 */

/**
 * @ngdoc directive
 * @name ngCopy
 *
 * @description
 * Specify custom behavior on copy event.
 *
 * @element window, input, select, textarea, a
 * @priority 0
 * @param {expression} ngCopy {@link guide/expression Expression} to evaluate upon
 * copy. ({@link guide/expression#-event- Event object is available as `$event`})
 *
 * @example
   <example>
     <file name="index.html">
      <input ng-copy="copied=true" ng-init="copied=false; value='copy me'" ng-model="value">
      copied: {{copied}}
     </file>
   </example>
 */

/**
 * @ngdoc directive
 * @name ngCut
 *
 * @description
 * Specify custom behavior on cut event.
 *
 * @element window, input, select, textarea, a
 * @priority 0
 * @param {expression} ngCut {@link guide/expression Expression} to evaluate upon
 * cut. ({@link guide/expression#-event- Event object is available as `$event`})
 *
 * @example
   <example>
     <file name="index.html">
      <input ng-cut="cut=true" ng-init="cut=false; value='cut me'" ng-model="value">
      cut: {{cut}}
     </file>
   </example>
 */

/**
 * @ngdoc directive
 * @name ngPaste
 *
 * @description
 * Specify custom behavior on paste event.
 *
 * @element window, input, select, textarea, a
 * @priority 0
 * @param {expression} ngPaste {@link guide/expression Expression} to evaluate upon
 * paste. ({@link guide/expression#-event- Event object is available as `$event`})
 *
 * @example
   <example>
     <file name="index.html">
      <input ng-paste="paste=true" ng-init="paste=false" placeholder='paste here'>
      pasted: {{paste}}
     </file>
   </example>
 */

/**
 * @ngdoc directive
 * @name ngIf
 * @restrict A
 *
 * @description
 * The `ngIf` directive removes or recreates a portion of the DOM tree based on an
 * {expression}. If the expression assigned to `ngIf` evaluates to a false
 * value then the element is removed from the DOM, otherwise a clone of the
 * element is reinserted into the DOM.
 *
 * `ngIf` differs from `ngShow` and `ngHide` in that `ngIf` completely removes and recreates the
 * element in the DOM rather than changing its visibility via the `display` css property.  A common
 * case when this difference is significant is when using css selectors that rely on an element's
 * position within the DOM, such as the `:first-child` or `:last-child` pseudo-classes.
 *
 * Note that when an element is removed using `ngIf` its scope is destroyed and a new scope
 * is created when the element is restored.  The scope created within `ngIf` inherits from
 * its parent scope using
 * [prototypal inheritance](https://github.com/angular/angular.js/wiki/Understanding-Scopes#javascript-prototypal-inheritance).
 * An important implication of this is if `ngModel` is used within `ngIf` to bind to
 * a javascript primitive defined in the parent scope. In this case any modifications made to the
 * variable within the child scope will override (hide) the value in the parent scope.
 *
 * Also, `ngIf` recreates elements using their compiled state. An example of this behavior
 * is if an element's class attribute is directly modified after it's compiled, using something like
 * jQuery's `.addClass()` method, and the element is later removed. When `ngIf` recreates the element
 * the added class will be lost because the original compiled state is used to regenerate the element.
 *
 * Additionally, you can provide animations via the `ngAnimate` module to animate the `enter`
 * and `leave` effects.
 *
 * @animations
 * enter - happens just after the `ngIf` contents change and a new DOM element is created and injected into the `ngIf` container
 * leave - happens just before the `ngIf` contents are removed from the DOM
 *
 * @element ANY
 * @scope
 * @priority 600
 * @param {expression} ngIf If the {@link guide/expression expression} is falsy then
 *     the element is removed from the DOM tree. If it is truthy a copy of the compiled
 *     element is added to the DOM tree.
 *
 * @example
  <example module="ngAnimate" deps="angular-animate.js" animations="true">
    <file name="index.html">
      Click me: <input type="checkbox" ng-model="checked" ng-init="checked=true" /><br/>
      Show when checked:
      <span ng-if="checked" class="animate-if">
        This is removed when the checkbox is unchecked.
      </span>
    </file>
    <file name="animations.css">
      .animate-if {
        background:white;
        border:1px solid black;
        padding:10px;
      }

      .animate-if.ng-enter, .animate-if.ng-leave {
        -webkit-transition:all cubic-bezier(0.250, 0.460, 0.450, 0.940) 0.5s;
        transition:all cubic-bezier(0.250, 0.460, 0.450, 0.940) 0.5s;
      }

      .animate-if.ng-enter,
      .animate-if.ng-leave.ng-leave-active {
        opacity:0;
      }

      .animate-if.ng-leave,
      .animate-if.ng-enter.ng-enter-active {
        opacity:1;
      }
    </file>
  </example>
 */
var ngIfDirective = ['$animate', function($animate) {
  return {
    multiElement: true,
    transclude: 'element',
    priority: 600,
    terminal: true,
    restrict: 'A',
    $$tlb: true,
    link: function($scope, $element, $attr, ctrl, $transclude) {
        var block, childScope, previousElements;
        $scope.$watch($attr.ngIf, function ngIfWatchAction(value) {

          if (value) {
            if (!childScope) {
              $transclude(function(clone, newScope) {
                childScope = newScope;
                clone[clone.length++] = document.createComment(' end ngIf: ' + $attr.ngIf + ' ');
                // Note: We only need the first/last node of the cloned nodes.
                // However, we need to keep the reference to the jqlite wrapper as it might be changed later
                // by a directive with templateUrl when its template arrives.
                block = {
                  clone: clone
                };
                $animate.enter(clone, $element.parent(), $element);
              });
            }
          } else {
            if (previousElements) {
              previousElements.remove();
              previousElements = null;
            }
            if (childScope) {
              childScope.$destroy();
              childScope = null;
            }
            if (block) {
              previousElements = getBlockNodes(block.clone);
              $animate.leave(previousElements).then(function() {
                previousElements = null;
              });
              block = null;
            }
          }
        });
    }
  };
}];

/**
 * @ngdoc directive
 * @name ngInclude
 * @restrict ECA
 *
 * @description
 * Fetches, compiles and includes an external HTML fragment.
 *
 * By default, the template URL is restricted to the same domain and protocol as the
 * application document. This is done by calling {@link $sce#getTrustedResourceUrl
 * $sce.getTrustedResourceUrl} on it. To load templates from other domains or protocols
 * you may either {@link ng.$sceDelegateProvider#resourceUrlWhitelist whitelist them} or
 * {@link $sce#trustAsResourceUrl wrap them} as trusted values. Refer to Angular's {@link
 * ng.$sce Strict Contextual Escaping}.
 *
 * In addition, the browser's
 * [Same Origin Policy](https://code.google.com/p/browsersec/wiki/Part2#Same-origin_policy_for_XMLHttpRequest)
 * and [Cross-Origin Resource Sharing (CORS)](http://www.w3.org/TR/cors/)
 * policy may further restrict whether the template is successfully loaded.
 * For example, `ngInclude` won't work for cross-domain requests on all browsers and for `file://`
 * access on some browsers.
 *
 * @animations
 * enter - animation is used to bring new content into the browser.
 * leave - animation is used to animate existing content away.
 *
 * The enter and leave animation occur concurrently.
 *
 * @scope
 * @priority 400
 *
 * @param {string} ngInclude|src angular expression evaluating to URL. If the source is a string constant,
 *                 make sure you wrap it in **single** quotes, e.g. `src="'myPartialTemplate.html'"`.
 * @param {string=} onload Expression to evaluate when a new partial is loaded.
 *
 * @param {string=} autoscroll Whether `ngInclude` should call {@link ng.$anchorScroll
 *                  $anchorScroll} to scroll the viewport after the content is loaded.
 *
 *                  - If the attribute is not set, disable scrolling.
 *                  - If the attribute is set without value, enable scrolling.
 *                  - Otherwise enable scrolling only if the expression evaluates to truthy value.
 *
 * @example
  <example module="includeExample" deps="angular-animate.js" animations="true">
    <file name="index.html">
     <div ng-controller="ExampleController">
       <select ng-model="template" ng-options="t.name for t in templates">
        <option value="">(blank)</option>
       </select>
       url of the template: <code>{{template.url}}</code>
       <hr/>
       <div class="slide-animate-container">
         <div class="slide-animate" ng-include="template.url"></div>
       </div>
     </div>
    </file>
    <file name="script.js">
      angular.module('includeExample', ['ngAnimate'])
        .controller('ExampleController', ['$scope', function($scope) {
          $scope.templates =
            [ { name: 'template1.html', url: 'template1.html'},
              { name: 'template2.html', url: 'template2.html'} ];
          $scope.template = $scope.templates[0];
        }]);
     </file>
    <file name="template1.html">
      Content of template1.html
    </file>
    <file name="template2.html">
      Content of template2.html
    </file>
    <file name="animations.css">
      .slide-animate-container {
        position:relative;
        background:white;
        border:1px solid black;
        height:40px;
        overflow:hidden;
      }

      .slide-animate {
        padding:10px;
      }

      .slide-animate.ng-enter, .slide-animate.ng-leave {
        -webkit-transition:all cubic-bezier(0.250, 0.460, 0.450, 0.940) 0.5s;
        transition:all cubic-bezier(0.250, 0.460, 0.450, 0.940) 0.5s;

        position:absolute;
        top:0;
        left:0;
        right:0;
        bottom:0;
        display:block;
        padding:10px;
      }

      .slide-animate.ng-enter {
        top:-50px;
      }
      .slide-animate.ng-enter.ng-enter-active {
        top:0;
      }

      .slide-animate.ng-leave {
        top:0;
      }
      .slide-animate.ng-leave.ng-leave-active {
        top:50px;
      }
    </file>
    <file name="protractor.js" type="protractor">
      var templateSelect = element(by.model('template'));
      var includeElem = element(by.css('[ng-include]'));

      it('should load template1.html', function() {
        expect(includeElem.getText()).toMatch(/Content of template1.html/);
      });

      it('should load template2.html', function() {
        if (browser.params.browser == 'firefox') {
          // Firefox can't handle using selects
          // See https://github.com/angular/protractor/issues/480
          return;
        }
        templateSelect.click();
        templateSelect.all(by.css('option')).get(2).click();
        expect(includeElem.getText()).toMatch(/Content of template2.html/);
      });

      it('should change to blank', function() {
        if (browser.params.browser == 'firefox') {
          // Firefox can't handle using selects
          return;
        }
        templateSelect.click();
        templateSelect.all(by.css('option')).get(0).click();
        expect(includeElem.isPresent()).toBe(false);
      });
    </file>
  </example>
 */


/**
 * @ngdoc event
 * @name ngInclude#$includeContentRequested
 * @eventType emit on the scope ngInclude was declared in
 * @description
 * Emitted every time the ngInclude content is requested.
 *
 * @param {Object} angularEvent Synthetic event object.
 * @param {String} src URL of content to load.
 */


/**
 * @ngdoc event
 * @name ngInclude#$includeContentLoaded
 * @eventType emit on the current ngInclude scope
 * @description
 * Emitted every time the ngInclude content is reloaded.
 *
 * @param {Object} angularEvent Synthetic event object.
 * @param {String} src URL of content to load.
 */


/**
 * @ngdoc event
 * @name ngInclude#$includeContentError
 * @eventType emit on the scope ngInclude was declared in
 * @description
 * Emitted when a template HTTP request yields an erroneous response (status < 200 || status > 299)
 *
 * @param {Object} angularEvent Synthetic event object.
 * @param {String} src URL of content to load.
 */
var ngIncludeDirective = ['$templateRequest', '$anchorScroll', '$animate',
                  function($templateRequest,   $anchorScroll,   $animate) {
  return {
    restrict: 'ECA',
    priority: 400,
    terminal: true,
    transclude: 'element',
    controller: angular.noop,
    compile: function(element, attr) {
      var srcExp = attr.ngInclude || attr.src,
          onloadExp = attr.onload || '',
          autoScrollExp = attr.autoscroll;

      return function(scope, $element, $attr, ctrl, $transclude) {
        var changeCounter = 0,
            currentScope,
            previousElement,
            currentElement;

        var cleanupLastIncludeContent = function() {
          if (previousElement) {
            previousElement.remove();
            previousElement = null;
          }
          if (currentScope) {
            currentScope.$destroy();
            currentScope = null;
          }
          if (currentElement) {
            $animate.leave(currentElement).then(function() {
              previousElement = null;
            });
            previousElement = currentElement;
            currentElement = null;
          }
        };

        scope.$watch(srcExp, function ngIncludeWatchAction(src) {
          var afterAnimation = function() {
            if (isDefined(autoScrollExp) && (!autoScrollExp || scope.$eval(autoScrollExp))) {
              $anchorScroll();
            }
          };
          var thisChangeId = ++changeCounter;

          if (src) {
            //set the 2nd param to true to ignore the template request error so that the inner
            //contents and scope can be cleaned up.
            $templateRequest(src, true).then(function(response) {
              if (thisChangeId !== changeCounter) return;
              var newScope = scope.$new();
              ctrl.template = response;

              // Note: This will also link all children of ng-include that were contained in the original
              // html. If that content contains controllers, ... they could pollute/change the scope.
              // However, using ng-include on an element with additional content does not make sense...
              // Note: We can't remove them in the cloneAttchFn of $transclude as that
              // function is called before linking the content, which would apply child
              // directives to non existing elements.
              var clone = $transclude(newScope, function(clone) {
                cleanupLastIncludeContent();
                $animate.enter(clone, null, $element).then(afterAnimation);
              });

              currentScope = newScope;
              currentElement = clone;

              currentScope.$emit('$includeContentLoaded', src);
              scope.$eval(onloadExp);
            }, function() {
              if (thisChangeId === changeCounter) {
                cleanupLastIncludeContent();
                scope.$emit('$includeContentError', src);
              }
            });
            scope.$emit('$includeContentRequested', src);
          } else {
            cleanupLastIncludeContent();
            ctrl.template = null;
          }
        });
      };
    }
  };
}];

// This directive is called during the $transclude call of the first `ngInclude` directive.
// It will replace and compile the content of the element with the loaded template.
// We need this directive so that the element content is already filled when
// the link function of another directive on the same element as ngInclude
// is called.
var ngIncludeFillContentDirective = ['$compile',
  function($compile) {
    return {
      restrict: 'ECA',
      priority: -400,
      require: 'ngInclude',
      link: function(scope, $element, $attr, ctrl) {
        if (/SVG/.test($element[0].toString())) {
          // WebKit: https://bugs.webkit.org/show_bug.cgi?id=135698 --- SVG elements do not
          // support innerHTML, so detect this here and try to generate the contents
          // specially.
          $element.empty();
          $compile(jqLiteBuildFragment(ctrl.template, document).childNodes)(scope,
              function namespaceAdaptedClone(clone) {
            $element.append(clone);
          }, {futureParentElement: $element});
          return;
        }

        $element.html(ctrl.template);
        $compile($element.contents())(scope);
      }
    };
  }];

/**
 * @ngdoc directive
 * @name ngInit
 * @restrict AC
 *
 * @description
 * The `ngInit` directive allows you to evaluate an expression in the
 * current scope.
 *
 * <div class="alert alert-error">
 * The only appropriate use of `ngInit` is for aliasing special properties of
 * {@link ng.directive:ngRepeat `ngRepeat`}, as seen in the demo below. Besides this case, you
 * should use {@link guide/controller controllers} rather than `ngInit`
 * to initialize values on a scope.
 * </div>
 * <div class="alert alert-warning">
 * **Note**: If you have assignment in `ngInit` along with {@link ng.$filter `$filter`}, make
 * sure you have parenthesis for correct precedence:
 * <pre class="prettyprint">
 * `<div ng-init="test1 = (data | orderBy:'name')"></div>`
 * </pre>
 * </div>
 *
 * @priority 450
 *
 * @element ANY
 * @param {expression} ngInit {@link guide/expression Expression} to eval.
 *
 * @example
   <example module="initExample">
     <file name="index.html">
   <script>
     angular.module('initExample', [])
       .controller('ExampleController', ['$scope', function($scope) {
         $scope.list = [['a', 'b'], ['c', 'd']];
       }]);
   </script>
   <div ng-controller="ExampleController">
     <div ng-repeat="innerList in list" ng-init="outerIndex = $index">
       <div ng-repeat="value in innerList" ng-init="innerIndex = $index">
          <span class="example-init">list[ {{outerIndex}} ][ {{innerIndex}} ] = {{value}};</span>
       </div>
     </div>
   </div>
     </file>
     <file name="protractor.js" type="protractor">
       it('should alias index positions', function() {
         var elements = element.all(by.css('.example-init'));
         expect(elements.get(0).getText()).toBe('list[ 0 ][ 0 ] = a;');
         expect(elements.get(1).getText()).toBe('list[ 0 ][ 1 ] = b;');
         expect(elements.get(2).getText()).toBe('list[ 1 ][ 0 ] = c;');
         expect(elements.get(3).getText()).toBe('list[ 1 ][ 1 ] = d;');
       });
     </file>
   </example>
 */
var ngInitDirective = ngDirective({
  priority: 450,
  compile: function() {
    return {
      pre: function(scope, element, attrs) {
        scope.$eval(attrs.ngInit);
      }
    };
  }
});

/**
 * @ngdoc directive
 * @name ngList
 *
 * @description
 * Text input that converts between a delimited string and an array of strings. The default
 * delimiter is a comma followed by a space - equivalent to `ng-list=", "`. You can specify a custom
 * delimiter as the value of the `ngList` attribute - for example, `ng-list=" | "`.
 *
 * The behaviour of the directive is affected by the use of the `ngTrim` attribute.
 * * If `ngTrim` is set to `"false"` then whitespace around both the separator and each
 *   list item is respected. This implies that the user of the directive is responsible for
 *   dealing with whitespace but also allows you to use whitespace as a delimiter, such as a
 *   tab or newline character.
 * * Otherwise whitespace around the delimiter is ignored when splitting (although it is respected
 *   when joining the list items back together) and whitespace around each list item is stripped
 *   before it is added to the model.
 *
 * ### Example with Validation
 *
 * <example name="ngList-directive" module="listExample">
 *   <file name="app.js">
 *      angular.module('listExample', [])
 *        .controller('ExampleController', ['$scope', function($scope) {
 *          $scope.names = ['morpheus', 'neo', 'trinity'];
 *        }]);
 *   </file>
 *   <file name="index.html">
 *    <form name="myForm" ng-controller="ExampleController">
 *      List: <input name="namesInput" ng-model="names" ng-list required>
 *      <span class="error" ng-show="myForm.namesInput.$error.required">
 *        Required!</span>
 *      <br>
 *      <tt>names = {{names}}</tt><br/>
 *      <tt>myForm.namesInput.$valid = {{myForm.namesInput.$valid}}</tt><br/>
 *      <tt>myForm.namesInput.$error = {{myForm.namesInput.$error}}</tt><br/>
 *      <tt>myForm.$valid = {{myForm.$valid}}</tt><br/>
 *      <tt>myForm.$error.required = {{!!myForm.$error.required}}</tt><br/>
 *     </form>
 *   </file>
 *   <file name="protractor.js" type="protractor">
 *     var listInput = element(by.model('names'));
 *     var names = element(by.exactBinding('names'));
 *     var valid = element(by.binding('myForm.namesInput.$valid'));
 *     var error = element(by.css('span.error'));
 *
 *     it('should initialize to model', function() {
 *       expect(names.getText()).toContain('["morpheus","neo","trinity"]');
 *       expect(valid.getText()).toContain('true');
 *       expect(error.getCssValue('display')).toBe('none');
 *     });
 *
 *     it('should be invalid if empty', function() {
 *       listInput.clear();
 *       listInput.sendKeys('');
 *
 *       expect(names.getText()).toContain('');
 *       expect(valid.getText()).toContain('false');
 *       expect(error.getCssValue('display')).not.toBe('none');
 *     });
 *   </file>
 * </example>
 *
 * ### Example - splitting on whitespace
 * <example name="ngList-directive-newlines">
 *   <file name="index.html">
 *    <textarea ng-model="list" ng-list="&#10;" ng-trim="false"></textarea>
 *    <pre>{{ list | json }}</pre>
 *   </file>
 *   <file name="protractor.js" type="protractor">
 *     it("should split the text by newlines", function() {
 *       var listInput = element(by.model('list'));
 *       var output = element(by.binding('list | json'));
 *       listInput.sendKeys('abc\ndef\nghi');
 *       expect(output.getText()).toContain('[\n  "abc",\n  "def",\n  "ghi"\n]');
 *     });
 *   </file>
 * </example>
 *
 * @element input
 * @param {string=} ngList optional delimiter that should be used to split the value.
 */
var ngListDirective = function() {
  return {
    restrict: 'A',
    priority: 100,
    require: 'ngModel',
    link: function(scope, element, attr, ctrl) {
      // We want to control whitespace trimming so we use this convoluted approach
      // to access the ngList attribute, which doesn't pre-trim the attribute
      var ngList = element.attr(attr.$attr.ngList) || ', ';
      var trimValues = attr.ngTrim !== 'false';
      var separator = trimValues ? trim(ngList) : ngList;

      var parse = function(viewValue) {
        // If the viewValue is invalid (say required but empty) it will be `undefined`
        if (isUndefined(viewValue)) return;

        var list = [];

        if (viewValue) {
          forEach(viewValue.split(separator), function(value) {
            if (value) list.push(trimValues ? trim(value) : value);
          });
        }

        return list;
      };

      ctrl.$parsers.push(parse);
      ctrl.$formatters.push(function(value) {
        if (isArray(value)) {
          return value.join(ngList);
        }

        return undefined;
      });

      // Override the standard $isEmpty because an empty array means the input is empty.
      ctrl.$isEmpty = function(value) {
        return !value || !value.length;
      };
    }
  };
};

/* global VALID_CLASS: true,
  INVALID_CLASS: true,
  PRISTINE_CLASS: true,
  DIRTY_CLASS: true,
  UNTOUCHED_CLASS: true,
  TOUCHED_CLASS: true,
*/

var VALID_CLASS = 'ng-valid',
    INVALID_CLASS = 'ng-invalid',
    PRISTINE_CLASS = 'ng-pristine',
    DIRTY_CLASS = 'ng-dirty',
    UNTOUCHED_CLASS = 'ng-untouched',
    TOUCHED_CLASS = 'ng-touched',
    PENDING_CLASS = 'ng-pending';

var ngModelMinErr = minErr('ngModel');

/**
 * @ngdoc type
 * @name ngModel.NgModelController
 *
 * @property {string} $viewValue Actual string value in the view.
 * @property {*} $modelValue The value in the model that the control is bound to.
 * @property {Array.<Function>} $parsers Array of functions to execute, as a pipeline, whenever
       the control reads value from the DOM. The functions are called in array order, each passing
       its return value through to the next. The last return value is forwarded to the
       {@link ngModel.NgModelController#$validators `$validators`} collection.

Parsers are used to sanitize / convert the {@link ngModel.NgModelController#$viewValue
`$viewValue`}.

Returning `undefined` from a parser means a parse error occurred. In that case,
no {@link ngModel.NgModelController#$validators `$validators`} will run and the `ngModel`
will be set to `undefined` unless {@link ngModelOptions `ngModelOptions.allowInvalid`}
is set to `true`. The parse error is stored in `ngModel.$error.parse`.

 *
 * @property {Array.<Function>} $formatters Array of functions to execute, as a pipeline, whenever
       the model value changes. The functions are called in reverse array order, each passing the value through to the
       next. The last return value is used as the actual DOM value.
       Used to format / convert values for display in the control.
 * ```js
 * function formatter(value) {
 *   if (value) {
 *     return value.toUpperCase();
 *   }
 * }
 * ngModel.$formatters.push(formatter);
 * ```
 *
 * @property {Object.<string, function>} $validators A collection of validators that are applied
 *      whenever the model value changes. The key value within the object refers to the name of the
 *      validator while the function refers to the validation operation. The validation operation is
 *      provided with the model value as an argument and must return a true or false value depending
 *      on the response of that validation.
 *
 * ```js
 * ngModel.$validators.validCharacters = function(modelValue, viewValue) {
 *   var value = modelValue || viewValue;
 *   return /[0-9]+/.test(value) &&
 *          /[a-z]+/.test(value) &&
 *          /[A-Z]+/.test(value) &&
 *          /\W+/.test(value);
 * };
 * ```
 *
 * @property {Object.<string, function>} $asyncValidators A collection of validations that are expected to
 *      perform an asynchronous validation (e.g. a HTTP request). The validation function that is provided
 *      is expected to return a promise when it is run during the model validation process. Once the promise
 *      is delivered then the validation status will be set to true when fulfilled and false when rejected.
 *      When the asynchronous validators are triggered, each of the validators will run in parallel and the model
 *      value will only be updated once all validators have been fulfilled. As long as an asynchronous validator
 *      is unfulfilled, its key will be added to the controllers `$pending` property. Also, all asynchronous validators
 *      will only run once all synchronous validators have passed.
 *
 * Please note that if $http is used then it is important that the server returns a success HTTP response code
 * in order to fulfill the validation and a status level of `4xx` in order to reject the validation.
 *
 * ```js
 * ngModel.$asyncValidators.uniqueUsername = function(modelValue, viewValue) {
 *   var value = modelValue || viewValue;
 *
 *   // Lookup user by username
 *   return $http.get('/api/users/' + value).
 *      then(function resolved() {
 *        //username exists, this means validation fails
 *        return $q.reject('exists');
 *      }, function rejected() {
 *        //username does not exist, therefore this validation passes
 *        return true;
 *      });
 * };
 * ```
 *
 * @property {Array.<Function>} $viewChangeListeners Array of functions to execute whenever the
 *     view value has changed. It is called with no arguments, and its return value is ignored.
 *     This can be used in place of additional $watches against the model value.
 *
 * @property {Object} $error An object hash with all failing validator ids as keys.
 * @property {Object} $pending An object hash with all pending validator ids as keys.
 *
 * @property {boolean} $untouched True if control has not lost focus yet.
 * @property {boolean} $touched True if control has lost focus.
 * @property {boolean} $pristine True if user has not interacted with the control yet.
 * @property {boolean} $dirty True if user has already interacted with the control.
 * @property {boolean} $valid True if there is no error.
 * @property {boolean} $invalid True if at least one error on the control.
 * @property {string} $name The name attribute of the control.
 *
 * @description
 *
 * `NgModelController` provides API for the {@link ngModel `ngModel`} directive.
 * The controller contains services for data-binding, validation, CSS updates, and value formatting
 * and parsing. It purposefully does not contain any logic which deals with DOM rendering or
 * listening to DOM events.
 * Such DOM related logic should be provided by other directives which make use of
 * `NgModelController` for data-binding to control elements.
 * Angular provides this DOM logic for most {@link input `input`} elements.
 * At the end of this page you can find a {@link ngModel.NgModelController#custom-control-example
 * custom control example} that uses `ngModelController` to bind to `contenteditable` elements.
 *
 * @example
 * ### Custom Control Example
 * This example shows how to use `NgModelController` with a custom control to achieve
 * data-binding. Notice how different directives (`contenteditable`, `ng-model`, and `required`)
 * collaborate together to achieve the desired result.
 *
 * `contenteditable` is an HTML5 attribute, which tells the browser to let the element
 * contents be edited in place by the user.
 *
 * We are using the {@link ng.service:$sce $sce} service here and include the {@link ngSanitize $sanitize}
 * module to automatically remove "bad" content like inline event listener (e.g. `<span onclick="...">`).
 * However, as we are using `$sce` the model can still decide to provide unsafe content if it marks
 * that content using the `$sce` service.
 *
 * <example name="NgModelController" module="customControl" deps="angular-sanitize.js">
    <file name="style.css">
      [contenteditable] {
        border: 1px solid black;
        background-color: white;
        min-height: 20px;
      }

      .ng-invalid {
        border: 1px solid red;
      }

    </file>
    <file name="script.js">
      angular.module('customControl', ['ngSanitize']).
        directive('contenteditable', ['$sce', function($sce) {
          return {
            restrict: 'A', // only activate on element attribute
            require: '?ngModel', // get a hold of NgModelController
            link: function(scope, element, attrs, ngModel) {
              if (!ngModel) return; // do nothing if no ng-model

              // Specify how UI should be updated
              ngModel.$render = function() {
                element.html($sce.getTrustedHtml(ngModel.$viewValue || ''));
              };

              // Listen for change events to enable binding
              element.on('blur keyup change', function() {
                scope.$evalAsync(read);
              });
              read(); // initialize

              // Write data to the model
              function read() {
                var html = element.html();
                // When we clear the content editable the browser leaves a <br> behind
                // If strip-br attribute is provided then we strip this out
                if ( attrs.stripBr && html == '<br>' ) {
                  html = '';
                }
                ngModel.$setViewValue(html);
              }
            }
          };
        }]);
    </file>
    <file name="index.html">
      <form name="myForm">
       <div contenteditable
            name="myWidget" ng-model="userContent"
            strip-br="true"
            required>Change me!</div>
        <span ng-show="myForm.myWidget.$error.required">Required!</span>
       <hr>
       <textarea ng-model="userContent"></textarea>
      </form>
    </file>
    <file name="protractor.js" type="protractor">
    it('should data-bind and become invalid', function() {
      if (browser.params.browser == 'safari' || browser.params.browser == 'firefox') {
        // SafariDriver can't handle contenteditable
        // and Firefox driver can't clear contenteditables very well
        return;
      }
      var contentEditable = element(by.css('[contenteditable]'));
      var content = 'Change me!';

      expect(contentEditable.getText()).toEqual(content);

      contentEditable.clear();
      contentEditable.sendKeys(protractor.Key.BACK_SPACE);
      expect(contentEditable.getText()).toEqual('');
      expect(contentEditable.getAttribute('class')).toMatch(/ng-invalid-required/);
    });
    </file>
 * </example>
 *
 *
 */
var NgModelController = ['$scope', '$exceptionHandler', '$attrs', '$element', '$parse', '$animate', '$timeout', '$rootScope', '$q', '$interpolate',
    function($scope, $exceptionHandler, $attr, $element, $parse, $animate, $timeout, $rootScope, $q, $interpolate) {
  this.$viewValue = Number.NaN;
  this.$modelValue = Number.NaN;
  this.$$rawModelValue = undefined; // stores the parsed modelValue / model set from scope regardless of validity.
  this.$validators = {};
  this.$asyncValidators = {};
  this.$parsers = [];
  this.$formatters = [];
  this.$viewChangeListeners = [];
  this.$untouched = true;
  this.$touched = false;
  this.$pristine = true;
  this.$dirty = false;
  this.$valid = true;
  this.$invalid = false;
  this.$error = {}; // keep invalid keys here
  this.$$success = {}; // keep valid keys here
  this.$pending = undefined; // keep pending keys here
  this.$name = $interpolate($attr.name || '', false)($scope);


  var parsedNgModel = $parse($attr.ngModel),
      parsedNgModelAssign = parsedNgModel.assign,
      ngModelGet = parsedNgModel,
      ngModelSet = parsedNgModelAssign,
      pendingDebounce = null,
      parserValid,
      ctrl = this;

  this.$$setOptions = function(options) {
    ctrl.$options = options;
    if (options && options.getterSetter) {
      var invokeModelGetter = $parse($attr.ngModel + '()'),
          invokeModelSetter = $parse($attr.ngModel + '($$$p)');

      ngModelGet = function($scope) {
        var modelValue = parsedNgModel($scope);
        if (isFunction(modelValue)) {
          modelValue = invokeModelGetter($scope);
        }
        return modelValue;
      };
      ngModelSet = function($scope, newValue) {
        if (isFunction(parsedNgModel($scope))) {
          invokeModelSetter($scope, {$$$p: ctrl.$modelValue});
        } else {
          parsedNgModelAssign($scope, ctrl.$modelValue);
        }
      };
    } else if (!parsedNgModel.assign) {
      throw ngModelMinErr('nonassign', "Expression '{0}' is non-assignable. Element: {1}",
          $attr.ngModel, startingTag($element));
    }
  };

  /**
   * @ngdoc method
   * @name ngModel.NgModelController#$render
   *
   * @description
   * Called when the view needs to be updated. It is expected that the user of the ng-model
   * directive will implement this method.
   *
   * The `$render()` method is invoked in the following situations:
   *
   * * `$rollbackViewValue()` is called.  If we are rolling back the view value to the last
   *   committed value then `$render()` is called to update the input control.
   * * The value referenced by `ng-model` is changed programmatically and both the `$modelValue` and
   *   the `$viewValue` are different to last time.
   *
   * Since `ng-model` does not do a deep watch, `$render()` is only invoked if the values of
   * `$modelValue` and `$viewValue` are actually different to their previous value. If `$modelValue`
   * or `$viewValue` are objects (rather than a string or number) then `$render()` will not be
   * invoked if you only change a property on the objects.
   */
  this.$render = noop;

  /**
   * @ngdoc method
   * @name ngModel.NgModelController#$isEmpty
   *
   * @description
   * This is called when we need to determine if the value of an input is empty.
   *
   * For instance, the required directive does this to work out if the input has data or not.
   *
   * The default `$isEmpty` function checks whether the value is `undefined`, `''`, `null` or `NaN`.
   *
   * You can override this for input directives whose concept of being empty is different to the
   * default. The `checkboxInputType` directive does this because in its case a value of `false`
   * implies empty.
   *
   * @param {*} value The value of the input to check for emptiness.
   * @returns {boolean} True if `value` is "empty".
   */
  this.$isEmpty = function(value) {
    return isUndefined(value) || value === '' || value === null || value !== value;
  };

  var parentForm = $element.inheritedData('$formController') || nullFormCtrl,
      currentValidationRunId = 0;

  /**
   * @ngdoc method
   * @name ngModel.NgModelController#$setValidity
   *
   * @description
   * Change the validity state, and notify the form.
   *
   * This method can be called within $parsers/$formatters or a custom validation implementation.
   * However, in most cases it should be sufficient to use the `ngModel.$validators` and
   * `ngModel.$asyncValidators` collections which will call `$setValidity` automatically.
   *
   * @param {string} validationErrorKey Name of the validator. The `validationErrorKey` will be assigned
   *        to either `$error[validationErrorKey]` or `$pending[validationErrorKey]`
   *        (for unfulfilled `$asyncValidators`), so that it is available for data-binding.
   *        The `validationErrorKey` should be in camelCase and will get converted into dash-case
   *        for class name. Example: `myError` will result in `ng-valid-my-error` and `ng-invalid-my-error`
   *        class and can be bound to as  `{{someForm.someControl.$error.myError}}` .
   * @param {boolean} isValid Whether the current state is valid (true), invalid (false), pending (undefined),
   *                          or skipped (null). Pending is used for unfulfilled `$asyncValidators`.
   *                          Skipped is used by Angular when validators do not run because of parse errors and
   *                          when `$asyncValidators` do not run because any of the `$validators` failed.
   */
  addSetValidityMethod({
    ctrl: this,
    $element: $element,
    set: function(object, property) {
      object[property] = true;
    },
    unset: function(object, property) {
      delete object[property];
    },
    parentForm: parentForm,
    $animate: $animate
  });

  /**
   * @ngdoc method
   * @name ngModel.NgModelController#$setPristine
   *
   * @description
   * Sets the control to its pristine state.
   *
   * This method can be called to remove the `ng-dirty` class and set the control to its pristine
   * state (`ng-pristine` class). A model is considered to be pristine when the control
   * has not been changed from when first compiled.
   */
  this.$setPristine = function() {
    ctrl.$dirty = false;
    ctrl.$pristine = true;
    $animate.removeClass($element, DIRTY_CLASS);
    $animate.addClass($element, PRISTINE_CLASS);
  };

  /**
   * @ngdoc method
   * @name ngModel.NgModelController#$setDirty
   *
   * @description
   * Sets the control to its dirty state.
   *
   * This method can be called to remove the `ng-pristine` class and set the control to its dirty
   * state (`ng-dirty` class). A model is considered to be dirty when the control has been changed
   * from when first compiled.
   */
  this.$setDirty = function() {
    ctrl.$dirty = true;
    ctrl.$pristine = false;
    $animate.removeClass($element, PRISTINE_CLASS);
    $animate.addClass($element, DIRTY_CLASS);
    parentForm.$setDirty();
  };

  /**
   * @ngdoc method
   * @name ngModel.NgModelController#$setUntouched
   *
   * @description
   * Sets the control to its untouched state.
   *
   * This method can be called to remove the `ng-touched` class and set the control to its
   * untouched state (`ng-untouched` class). Upon compilation, a model is set as untouched
   * by default, however this function can be used to restore that state if the model has
   * already been touched by the user.
   */
  this.$setUntouched = function() {
    ctrl.$touched = false;
    ctrl.$untouched = true;
    $animate.setClass($element, UNTOUCHED_CLASS, TOUCHED_CLASS);
  };

  /**
   * @ngdoc method
   * @name ngModel.NgModelController#$setTouched
   *
   * @description
   * Sets the control to its touched state.
   *
   * This method can be called to remove the `ng-untouched` class and set the control to its
   * touched state (`ng-touched` class). A model is considered to be touched when the user has
   * first focused the control element and then shifted focus away from the control (blur event).
   */
  this.$setTouched = function() {
    ctrl.$touched = true;
    ctrl.$untouched = false;
    $animate.setClass($element, TOUCHED_CLASS, UNTOUCHED_CLASS);
  };

  /**
   * @ngdoc method
   * @name ngModel.NgModelController#$rollbackViewValue
   *
   * @description
   * Cancel an update and reset the input element's value to prevent an update to the `$modelValue`,
   * which may be caused by a pending debounced event or because the input is waiting for a some
   * future event.
   *
   * If you have an input that uses `ng-model-options` to set up debounced events or events such
   * as blur you can have a situation where there is a period when the `$viewValue`
   * is out of synch with the ngModel's `$modelValue`.
   *
   * In this case, you can run into difficulties if you try to update the ngModel's `$modelValue`
   * programmatically before these debounced/future events have resolved/occurred, because Angular's
   * dirty checking mechanism is not able to tell whether the model has actually changed or not.
   *
   * The `$rollbackViewValue()` method should be called before programmatically changing the model of an
   * input which may have such events pending. This is important in order to make sure that the
   * input field will be updated with the new model value and any pending operations are cancelled.
   *
   * <example name="ng-model-cancel-update" module="cancel-update-example">
   *   <file name="app.js">
   *     angular.module('cancel-update-example', [])
   *
   *     .controller('CancelUpdateController', ['$scope', function($scope) {
   *       $scope.resetWithCancel = function(e) {
   *         if (e.keyCode == 27) {
   *           $scope.myForm.myInput1.$rollbackViewValue();
   *           $scope.myValue = '';
   *         }
   *       };
   *       $scope.resetWithoutCancel = function(e) {
   *         if (e.keyCode == 27) {
   *           $scope.myValue = '';
   *         }
   *       };
   *     }]);
   *   </file>
   *   <file name="index.html">
   *     <div ng-controller="CancelUpdateController">
   *       <p>Try typing something in each input.  See that the model only updates when you
   *          blur off the input.
   *        </p>
   *        <p>Now see what happens if you start typing then press the Escape key</p>
   *
   *       <form name="myForm" ng-model-options="{ updateOn: 'blur' }">
   *         <p>With $rollbackViewValue()</p>
   *         <input name="myInput1" ng-model="myValue" ng-keydown="resetWithCancel($event)"><br/>
   *         myValue: "{{ myValue }}"
   *
   *         <p>Without $rollbackViewValue()</p>
   *         <input name="myInput2" ng-model="myValue" ng-keydown="resetWithoutCancel($event)"><br/>
   *         myValue: "{{ myValue }}"
   *       </form>
   *     </div>
   *   </file>
   * </example>
   */
  this.$rollbackViewValue = function() {
    $timeout.cancel(pendingDebounce);
    ctrl.$viewValue = ctrl.$$lastCommittedViewValue;
    ctrl.$render();
  };

  /**
   * @ngdoc method
   * @name ngModel.NgModelController#$validate
   *
   * @description
   * Runs each of the registered validators (first synchronous validators and then
   * asynchronous validators).
   * If the validity changes to invalid, the model will be set to `undefined`,
   * unless {@link ngModelOptions `ngModelOptions.allowInvalid`} is `true`.
   * If the validity changes to valid, it will set the model to the last available valid
   * `$modelValue`, i.e. either the last parsed value or the last value set from the scope.
   */
  this.$validate = function() {
    // ignore $validate before model is initialized
    if (isNumber(ctrl.$modelValue) && isNaN(ctrl.$modelValue)) {
      return;
    }

    var viewValue = ctrl.$$lastCommittedViewValue;
    // Note: we use the $$rawModelValue as $modelValue might have been
    // set to undefined during a view -> model update that found validation
    // errors. We can't parse the view here, since that could change
    // the model although neither viewValue nor the model on the scope changed
    var modelValue = ctrl.$$rawModelValue;

    var prevValid = ctrl.$valid;
    var prevModelValue = ctrl.$modelValue;

    var allowInvalid = ctrl.$options && ctrl.$options.allowInvalid;

    ctrl.$$runValidators(modelValue, viewValue, function(allValid) {
      // If there was no change in validity, don't update the model
      // This prevents changing an invalid modelValue to undefined
      if (!allowInvalid && prevValid !== allValid) {
        // Note: Don't check ctrl.$valid here, as we could have
        // external validators (e.g. calculated on the server),
        // that just call $setValidity and need the model value
        // to calculate their validity.
        ctrl.$modelValue = allValid ? modelValue : undefined;

        if (ctrl.$modelValue !== prevModelValue) {
          ctrl.$$writeModelToScope();
        }
      }
    });

  };

  this.$$runValidators = function(modelValue, viewValue, doneCallback) {
    currentValidationRunId++;
    var localValidationRunId = currentValidationRunId;

    // check parser error
    if (!processParseErrors()) {
      validationDone(false);
      return;
    }
    if (!processSyncValidators()) {
      validationDone(false);
      return;
    }
    processAsyncValidators();

    function processParseErrors() {
      var errorKey = ctrl.$$parserName || 'parse';
      if (parserValid === undefined) {
        setValidity(errorKey, null);
      } else {
        if (!parserValid) {
          forEach(ctrl.$validators, function(v, name) {
            setValidity(name, null);
          });
          forEach(ctrl.$asyncValidators, function(v, name) {
            setValidity(name, null);
          });
        }
        // Set the parse error last, to prevent unsetting it, should a $validators key == parserName
        setValidity(errorKey, parserValid);
        return parserValid;
      }
      return true;
    }

    function processSyncValidators() {
      var syncValidatorsValid = true;
      forEach(ctrl.$validators, function(validator, name) {
        var result = validator(modelValue, viewValue);
        syncValidatorsValid = syncValidatorsValid && result;
        setValidity(name, result);
      });
      if (!syncValidatorsValid) {
        forEach(ctrl.$asyncValidators, function(v, name) {
          setValidity(name, null);
        });
        return false;
      }
      return true;
    }

    function processAsyncValidators() {
      var validatorPromises = [];
      var allValid = true;
      forEach(ctrl.$asyncValidators, function(validator, name) {
        var promise = validator(modelValue, viewValue);
        if (!isPromiseLike(promise)) {
          throw ngModelMinErr("$asyncValidators",
            "Expected asynchronous validator to return a promise but got '{0}' instead.", promise);
        }
        setValidity(name, undefined);
        validatorPromises.push(promise.then(function() {
          setValidity(name, true);
        }, function(error) {
          allValid = false;
          setValidity(name, false);
        }));
      });
      if (!validatorPromises.length) {
        validationDone(true);
      } else {
        $q.all(validatorPromises).then(function() {
          validationDone(allValid);
        }, noop);
      }
    }

    function setValidity(name, isValid) {
      if (localValidationRunId === currentValidationRunId) {
        ctrl.$setValidity(name, isValid);
      }
    }

    function validationDone(allValid) {
      if (localValidationRunId === currentValidationRunId) {

        doneCallback(allValid);
      }
    }
  };

  /**
   * @ngdoc method
   * @name ngModel.NgModelController#$commitViewValue
   *
   * @description
   * Commit a pending update to the `$modelValue`.
   *
   * Updates may be pending by a debounced event or because the input is waiting for a some future
   * event defined in `ng-model-options`. this method is rarely needed as `NgModelController`
   * usually handles calling this in response to input events.
   */
  this.$commitViewValue = function() {
    var viewValue = ctrl.$viewValue;

    $timeout.cancel(pendingDebounce);

    // If the view value has not changed then we should just exit, except in the case where there is
    // a native validator on the element. In this case the validation state may have changed even though
    // the viewValue has stayed empty.
    if (ctrl.$$lastCommittedViewValue === viewValue && (viewValue !== '' || !ctrl.$$hasNativeValidators)) {
      return;
    }
    ctrl.$$lastCommittedViewValue = viewValue;

    // change to dirty
    if (ctrl.$pristine) {
      this.$setDirty();
    }
    this.$$parseAndValidate();
  };

  this.$$parseAndValidate = function() {
    var viewValue = ctrl.$$lastCommittedViewValue;
    var modelValue = viewValue;
    parserValid = isUndefined(modelValue) ? undefined : true;

    if (parserValid) {
      for (var i = 0; i < ctrl.$parsers.length; i++) {
        modelValue = ctrl.$parsers[i](modelValue);
        if (isUndefined(modelValue)) {
          parserValid = false;
          break;
        }
      }
    }
    if (isNumber(ctrl.$modelValue) && isNaN(ctrl.$modelValue)) {
      // ctrl.$modelValue has not been touched yet...
      ctrl.$modelValue = ngModelGet($scope);
    }
    var prevModelValue = ctrl.$modelValue;
    var allowInvalid = ctrl.$options && ctrl.$options.allowInvalid;
    ctrl.$$rawModelValue = modelValue;

    if (allowInvalid) {
      ctrl.$modelValue = modelValue;
      writeToModelIfNeeded();
    }

    // Pass the $$lastCommittedViewValue here, because the cached viewValue might be out of date.
    // This can happen if e.g. $setViewValue is called from inside a parser
    ctrl.$$runValidators(modelValue, ctrl.$$lastCommittedViewValue, function(allValid) {
      if (!allowInvalid) {
        // Note: Don't check ctrl.$valid here, as we could have
        // external validators (e.g. calculated on the server),
        // that just call $setValidity and need the model value
        // to calculate their validity.
        ctrl.$modelValue = allValid ? modelValue : undefined;
        writeToModelIfNeeded();
      }
    });

    function writeToModelIfNeeded() {
      if (ctrl.$modelValue !== prevModelValue) {
        ctrl.$$writeModelToScope();
      }
    }
  };

  this.$$writeModelToScope = function() {
    ngModelSet($scope, ctrl.$modelValue);
    forEach(ctrl.$viewChangeListeners, function(listener) {
      try {
        listener();
      } catch (e) {
        $exceptionHandler(e);
      }
    });
  };

  /**
   * @ngdoc method
   * @name ngModel.NgModelController#$setViewValue
   *
   * @description
   * Update the view value.
   *
   * This method should be called when an input directive want to change the view value; typically,
   * this is done from within a DOM event handler.
   *
   * For example {@link ng.directive:input input} calls it when the value of the input changes and
   * {@link ng.directive:select select} calls it when an option is selected.
   *
   * If the new `value` is an object (rather than a string or a number), we should make a copy of the
   * object before passing it to `$setViewValue`.  This is because `ngModel` does not perform a deep
   * watch of objects, it only looks for a change of identity. If you only change the property of
   * the object then ngModel will not realise that the object has changed and will not invoke the
   * `$parsers` and `$validators` pipelines.
   *
   * For this reason, you should not change properties of the copy once it has been passed to
   * `$setViewValue`. Otherwise you may cause the model value on the scope to change incorrectly.
   *
   * When this method is called, the new `value` will be staged for committing through the `$parsers`
   * and `$validators` pipelines. If there are no special {@link ngModelOptions} specified then the staged
   * value sent directly for processing, finally to be applied to `$modelValue` and then the
   * **expression** specified in the `ng-model` attribute.
   *
   * Lastly, all the registered change listeners, in the `$viewChangeListeners` list, are called.
   *
   * In case the {@link ng.directive:ngModelOptions ngModelOptions} directive is used with `updateOn`
   * and the `default` trigger is not listed, all those actions will remain pending until one of the
   * `updateOn` events is triggered on the DOM element.
   * All these actions will be debounced if the {@link ng.directive:ngModelOptions ngModelOptions}
   * directive is used with a custom debounce for this particular event.
   *
   * Note that calling this function does not trigger a `$digest`.
   *
   * @param {string} value Value from the view.
   * @param {string} trigger Event that triggered the update.
   */
  this.$setViewValue = function(value, trigger) {
    ctrl.$viewValue = value;
    if (!ctrl.$options || ctrl.$options.updateOnDefault) {
      ctrl.$$debounceViewValueCommit(trigger);
    }
  };

  this.$$debounceViewValueCommit = function(trigger) {
    var debounceDelay = 0,
        options = ctrl.$options,
        debounce;

    if (options && isDefined(options.debounce)) {
      debounce = options.debounce;
      if (isNumber(debounce)) {
        debounceDelay = debounce;
      } else if (isNumber(debounce[trigger])) {
        debounceDelay = debounce[trigger];
      } else if (isNumber(debounce['default'])) {
        debounceDelay = debounce['default'];
      }
    }

    $timeout.cancel(pendingDebounce);
    if (debounceDelay) {
      pendingDebounce = $timeout(function() {
        ctrl.$commitViewValue();
      }, debounceDelay);
    } else if ($rootScope.$$phase) {
      ctrl.$commitViewValue();
    } else {
      $scope.$apply(function() {
        ctrl.$commitViewValue();
      });
    }
  };

  // model -> value
  // Note: we cannot use a normal scope.$watch as we want to detect the following:
  // 1. scope value is 'a'
  // 2. user enters 'b'
  // 3. ng-change kicks in and reverts scope value to 'a'
  //    -> scope value did not change since the last digest as
  //       ng-change executes in apply phase
  // 4. view should be changed back to 'a'
  $scope.$watch(function ngModelWatch() {
    var modelValue = ngModelGet($scope);

    // if scope model value and ngModel value are out of sync
    // TODO(perf): why not move this to the action fn?
    if (modelValue !== ctrl.$modelValue &&
       // checks for NaN is needed to allow setting the model to NaN when there's an asyncValidator
       (ctrl.$modelValue === ctrl.$modelValue || modelValue === modelValue)
    ) {
      ctrl.$modelValue = ctrl.$$rawModelValue = modelValue;
      parserValid = undefined;

      var formatters = ctrl.$formatters,
          idx = formatters.length;

      var viewValue = modelValue;
      while (idx--) {
        viewValue = formatters[idx](viewValue);
      }
      if (ctrl.$viewValue !== viewValue) {
        ctrl.$viewValue = ctrl.$$lastCommittedViewValue = viewValue;
        ctrl.$render();

        ctrl.$$runValidators(modelValue, viewValue, noop);
      }
    }

    return modelValue;
  });
}];


/**
 * @ngdoc directive
 * @name ngModel
 *
 * @element input
 * @priority 1
 *
 * @description
 * The `ngModel` directive binds an `input`,`select`, `textarea` (or custom form control) to a
 * property on the scope using {@link ngModel.NgModelController NgModelController},
 * which is created and exposed by this directive.
 *
 * `ngModel` is responsible for:
 *
 * - Binding the view into the model, which other directives such as `input`, `textarea` or `select`
 *   require.
 * - Providing validation behavior (i.e. required, number, email, url).
 * - Keeping the state of the control (valid/invalid, dirty/pristine, touched/untouched, validation errors).
 * - Setting related css classes on the element (`ng-valid`, `ng-invalid`, `ng-dirty`, `ng-pristine`, `ng-touched`, `ng-untouched`) including animations.
 * - Registering the control with its parent {@link ng.directive:form form}.
 *
 * Note: `ngModel` will try to bind to the property given by evaluating the expression on the
 * current scope. If the property doesn't already exist on this scope, it will be created
 * implicitly and added to the scope.
 *
 * For best practices on using `ngModel`, see:
 *
 *  - [Understanding Scopes](https://github.com/angular/angular.js/wiki/Understanding-Scopes)
 *
 * For basic examples, how to use `ngModel`, see:
 *
 *  - {@link ng.directive:input input}
 *    - {@link input[text] text}
 *    - {@link input[checkbox] checkbox}
 *    - {@link input[radio] radio}
 *    - {@link input[number] number}
 *    - {@link input[email] email}
 *    - {@link input[url] url}
 *    - {@link input[date] date}
 *    - {@link input[datetime-local] datetime-local}
 *    - {@link input[time] time}
 *    - {@link input[month] month}
 *    - {@link input[week] week}
 *  - {@link ng.directive:select select}
 *  - {@link ng.directive:textarea textarea}
 *
 * # CSS classes
 * The following CSS classes are added and removed on the associated input/select/textarea element
 * depending on the validity of the model.
 *
 *  - `ng-valid`: the model is valid
 *  - `ng-invalid`: the model is invalid
 *  - `ng-valid-[key]`: for each valid key added by `$setValidity`
 *  - `ng-invalid-[key]`: for each invalid key added by `$setValidity`
 *  - `ng-pristine`: the control hasn't been interacted with yet
 *  - `ng-dirty`: the control has been interacted with
 *  - `ng-touched`: the control has been blurred
 *  - `ng-untouched`: the control hasn't been blurred
 *  - `ng-pending`: any `$asyncValidators` are unfulfilled
 *
 * Keep in mind that ngAnimate can detect each of these classes when added and removed.
 *
 * ## Animation Hooks
 *
 * Animations within models are triggered when any of the associated CSS classes are added and removed
 * on the input element which is attached to the model. These classes are: `.ng-pristine`, `.ng-dirty`,
 * `.ng-invalid` and `.ng-valid` as well as any other validations that are performed on the model itself.
 * The animations that are triggered within ngModel are similar to how they work in ngClass and
 * animations can be hooked into using CSS transitions, keyframes as well as JS animations.
 *
 * The following example shows a simple way to utilize CSS transitions to style an input element
 * that has been rendered as invalid after it has been validated:
 *
 * <pre>
 * //be sure to include ngAnimate as a module to hook into more
 * //advanced animations
 * .my-input {
 *   transition:0.5s linear all;
 *   background: white;
 * }
 * .my-input.ng-invalid {
 *   background: red;
 *   color:white;
 * }
 * </pre>
 *
 * @example
 * <example deps="angular-animate.js" animations="true" fixBase="true" module="inputExample">
     <file name="index.html">
       <script>
        angular.module('inputExample', [])
          .controller('ExampleController', ['$scope', function($scope) {
            $scope.val = '1';
          }]);
       </script>
       <style>
         .my-input {
           -webkit-transition:all linear 0.5s;
           transition:all linear 0.5s;
           background: transparent;
         }
         .my-input.ng-invalid {
           color:white;
           background: red;
         }
       </style>
       Update input to see transitions when valid/invalid.
       Integer is a valid value.
       <form name="testForm" ng-controller="ExampleController">
         <input ng-model="val" ng-pattern="/^\d+$/" name="anim" class="my-input" />
       </form>
     </file>
 * </example>
 *
 * ## Binding to a getter/setter
 *
 * Sometimes it's helpful to bind `ngModel` to a getter/setter function.  A getter/setter is a
 * function that returns a representation of the model when called with zero arguments, and sets
 * the internal state of a model when called with an argument. It's sometimes useful to use this
 * for models that have an internal representation that's different than what the model exposes
 * to the view.
 *
 * <div class="alert alert-success">
 * **Best Practice:** It's best to keep getters fast because Angular is likely to call them more
 * frequently than other parts of your code.
 * </div>
 *
 * You use this behavior by adding `ng-model-options="{ getterSetter: true }"` to an element that
 * has `ng-model` attached to it. You can also add `ng-model-options="{ getterSetter: true }"` to
 * a `<form>`, which will enable this behavior for all `<input>`s within it. See
 * {@link ng.directive:ngModelOptions `ngModelOptions`} for more.
 *
 * The following example shows how to use `ngModel` with a getter/setter:
 *
 * @example
 * <example name="ngModel-getter-setter" module="getterSetterExample">
     <file name="index.html">
       <div ng-controller="ExampleController">
         <form name="userForm">
           Name:
           <input type="text" name="userName"
                  ng-model="user.name"
                  ng-model-options="{ getterSetter: true }" />
         </form>
         <pre>user.name = <span ng-bind="user.name()"></span></pre>
       </div>
     </file>
     <file name="app.js">
       angular.module('getterSetterExample', [])
         .controller('ExampleController', ['$scope', function($scope) {
           var _name = 'Brian';
           $scope.user = {
             name: function(newName) {
              // Note that newName can be undefined for two reasons:
              // 1. Because it is called as a getter and thus called with no arguments
              // 2. Because the property should actually be set to undefined. This happens e.g. if the
              //    input is invalid
              return arguments.length ? (_name = newName) : _name;
             }
           };
         }]);
     </file>
 * </example>
 */
var ngModelDirective = ['$rootScope', function($rootScope) {
  return {
    restrict: 'A',
    require: ['ngModel', '^?form', '^?ngModelOptions'],
    controller: NgModelController,
    // Prelink needs to run before any input directive
    // so that we can set the NgModelOptions in NgModelController
    // before anyone else uses it.
    priority: 1,
    compile: function ngModelCompile(element) {
      // Setup initial state of the control
      element.addClass(PRISTINE_CLASS).addClass(UNTOUCHED_CLASS).addClass(VALID_CLASS);

      return {
        pre: function ngModelPreLink(scope, element, attr, ctrls) {
          var modelCtrl = ctrls[0],
              formCtrl = ctrls[1] || nullFormCtrl;

          modelCtrl.$$setOptions(ctrls[2] && ctrls[2].$options);

          // notify others, especially parent forms
          formCtrl.$addControl(modelCtrl);

          attr.$observe('name', function(newValue) {
            if (modelCtrl.$name !== newValue) {
              formCtrl.$$renameControl(modelCtrl, newValue);
            }
          });

          scope.$on('$destroy', function() {
            formCtrl.$removeControl(modelCtrl);
          });
        },
        post: function ngModelPostLink(scope, element, attr, ctrls) {
          var modelCtrl = ctrls[0];
          if (modelCtrl.$options && modelCtrl.$options.updateOn) {
            element.on(modelCtrl.$options.updateOn, function(ev) {
              modelCtrl.$$debounceViewValueCommit(ev && ev.type);
            });
          }

          element.on('blur', function(ev) {
            if (modelCtrl.$touched) return;

            if ($rootScope.$$phase) {
              scope.$evalAsync(modelCtrl.$setTouched);
            } else {
              scope.$apply(modelCtrl.$setTouched);
            }
          });
        }
      };
    }
  };
}];

var DEFAULT_REGEXP = /(\s+|^)default(\s+|$)/;

/**
 * @ngdoc directive
 * @name ngModelOptions
 *
 * @description
 * Allows tuning how model updates are done. Using `ngModelOptions` you can specify a custom list of
 * events that will trigger a model update and/or a debouncing delay so that the actual update only
 * takes place when a timer expires; this timer will be reset after another change takes place.
 *
 * Given the nature of `ngModelOptions`, the value displayed inside input fields in the view might
 * be different than the value in the actual model. This means that if you update the model you
 * should also invoke {@link ngModel.NgModelController `$rollbackViewValue`} on the relevant input field in
 * order to make sure it is synchronized with the model and that any debounced action is canceled.
 *
 * The easiest way to reference the control's {@link ngModel.NgModelController `$rollbackViewValue`}
 * method is by making sure the input is placed inside a form that has a `name` attribute. This is
 * important because `form` controllers are published to the related scope under the name in their
 * `name` attribute.
 *
 * Any pending changes will take place immediately when an enclosing form is submitted via the
 * `submit` event. Note that `ngClick` events will occur before the model is updated. Use `ngSubmit`
 * to have access to the updated model.
 *
 * `ngModelOptions` has an effect on the element it's declared on and its descendants.
 *
 * @param {Object} ngModelOptions options to apply to the current model. Valid keys are:
 *   - `updateOn`: string specifying which event should the input be bound to. You can set several
 *     events using an space delimited list. There is a special event called `default` that
 *     matches the default events belonging of the control.
 *   - `debounce`: integer value which contains the debounce model update value in milliseconds. A
 *     value of 0 triggers an immediate update. If an object is supplied instead, you can specify a
 *     custom value for each event. For example:
 *     `ng-model-options="{ updateOn: 'default blur', debounce: {'default': 500, 'blur': 0} }"`
 *   - `allowInvalid`: boolean value which indicates that the model can be set with values that did
 *     not validate correctly instead of the default behavior of setting the model to undefined.
 *   - `getterSetter`: boolean value which determines whether or not to treat functions bound to
       `ngModel` as getters/setters.
 *   - `timezone`: Defines the timezone to be used to read/write the `Date` instance in the model for
 *     `<input type="date">`, `<input type="time">`, ... . Right now, the only supported value is `'UTC'`,
 *     otherwise the default timezone of the browser will be used.
 *
 * @example

  The following example shows how to override immediate updates. Changes on the inputs within the
  form will update the model only when the control loses focus (blur event). If `escape` key is
  pressed while the input field is focused, the value is reset to the value in the current model.

  <example name="ngModelOptions-directive-blur" module="optionsExample">
    <file name="index.html">
      <div ng-controller="ExampleController">
        <form name="userForm">
          Name:
          <input type="text" name="userName"
                 ng-model="user.name"
                 ng-model-options="{ updateOn: 'blur' }"
                 ng-keyup="cancel($event)" /><br />

          Other data:
          <input type="text" ng-model="user.data" /><br />
        </form>
        <pre>user.name = <span ng-bind="user.name"></span></pre>
      </div>
    </file>
    <file name="app.js">
      angular.module('optionsExample', [])
        .controller('ExampleController', ['$scope', function($scope) {
          $scope.user = { name: 'say', data: '' };

          $scope.cancel = function(e) {
            if (e.keyCode == 27) {
              $scope.userForm.userName.$rollbackViewValue();
            }
          };
        }]);
    </file>
    <file name="protractor.js" type="protractor">
      var model = element(by.binding('user.name'));
      var input = element(by.model('user.name'));
      var other = element(by.model('user.data'));

      it('should allow custom events', function() {
        input.sendKeys(' hello');
        input.click();
        expect(model.getText()).toEqual('say');
        other.click();
        expect(model.getText()).toEqual('say hello');
      });

      it('should $rollbackViewValue when model changes', function() {
        input.sendKeys(' hello');
        expect(input.getAttribute('value')).toEqual('say hello');
        input.sendKeys(protractor.Key.ESCAPE);
        expect(input.getAttribute('value')).toEqual('say');
        other.click();
        expect(model.getText()).toEqual('say');
      });
    </file>
  </example>

  This one shows how to debounce model changes. Model will be updated only 1 sec after last change.
  If the `Clear` button is pressed, any debounced action is canceled and the value becomes empty.

  <example name="ngModelOptions-directive-debounce" module="optionsExample">
    <file name="index.html">
      <div ng-controller="ExampleController">
        <form name="userForm">
          Name:
          <input type="text" name="userName"
                 ng-model="user.name"
                 ng-model-options="{ debounce: 1000 }" />
          <button ng-click="userForm.userName.$rollbackViewValue(); user.name=''">Clear</button><br />
        </form>
        <pre>user.name = <span ng-bind="user.name"></span></pre>
      </div>
    </file>
    <file name="app.js">
      angular.module('optionsExample', [])
        .controller('ExampleController', ['$scope', function($scope) {
          $scope.user = { name: 'say' };
        }]);
    </file>
  </example>

  This one shows how to bind to getter/setters:

  <example name="ngModelOptions-directive-getter-setter" module="getterSetterExample">
    <file name="index.html">
      <div ng-controller="ExampleController">
        <form name="userForm">
          Name:
          <input type="text" name="userName"
                 ng-model="user.name"
                 ng-model-options="{ getterSetter: true }" />
        </form>
        <pre>user.name = <span ng-bind="user.name()"></span></pre>
      </div>
    </file>
    <file name="app.js">
      angular.module('getterSetterExample', [])
        .controller('ExampleController', ['$scope', function($scope) {
          var _name = 'Brian';
          $scope.user = {
            name: function(newName) {
              // Note that newName can be undefined for two reasons:
              // 1. Because it is called as a getter and thus called with no arguments
              // 2. Because the property should actually be set to undefined. This happens e.g. if the
              //    input is invalid
              return arguments.length ? (_name = newName) : _name;
            }
          };
        }]);
    </file>
  </example>
 */
var ngModelOptionsDirective = function() {
  return {
    restrict: 'A',
    controller: ['$scope', '$attrs', function($scope, $attrs) {
      var that = this;
      this.$options = $scope.$eval($attrs.ngModelOptions);
      // Allow adding/overriding bound events
      if (this.$options.updateOn !== undefined) {
        this.$options.updateOnDefault = false;
        // extract "default" pseudo-event from list of events that can trigger a model update
        this.$options.updateOn = trim(this.$options.updateOn.replace(DEFAULT_REGEXP, function() {
          that.$options.updateOnDefault = true;
          return ' ';
        }));
      } else {
        this.$options.updateOnDefault = true;
      }
    }]
  };
};



// helper methods
function addSetValidityMethod(context) {
  var ctrl = context.ctrl,
      $element = context.$element,
      classCache = {},
      set = context.set,
      unset = context.unset,
      parentForm = context.parentForm,
      $animate = context.$animate;

  classCache[INVALID_CLASS] = !(classCache[VALID_CLASS] = $element.hasClass(VALID_CLASS));

  ctrl.$setValidity = setValidity;

  function setValidity(validationErrorKey, state, controller) {
    if (state === undefined) {
      createAndSet('$pending', validationErrorKey, controller);
    } else {
      unsetAndCleanup('$pending', validationErrorKey, controller);
    }
    if (!isBoolean(state)) {
      unset(ctrl.$error, validationErrorKey, controller);
      unset(ctrl.$$success, validationErrorKey, controller);
    } else {
      if (state) {
        unset(ctrl.$error, validationErrorKey, controller);
        set(ctrl.$$success, validationErrorKey, controller);
      } else {
        set(ctrl.$error, validationErrorKey, controller);
        unset(ctrl.$$success, validationErrorKey, controller);
      }
    }
    if (ctrl.$pending) {
      cachedToggleClass(PENDING_CLASS, true);
      ctrl.$valid = ctrl.$invalid = undefined;
      toggleValidationCss('', null);
    } else {
      cachedToggleClass(PENDING_CLASS, false);
      ctrl.$valid = isObjectEmpty(ctrl.$error);
      ctrl.$invalid = !ctrl.$valid;
      toggleValidationCss('', ctrl.$valid);
    }

    // re-read the state as the set/unset methods could have
    // combined state in ctrl.$error[validationError] (used for forms),
    // where setting/unsetting only increments/decrements the value,
    // and does not replace it.
    var combinedState;
    if (ctrl.$pending && ctrl.$pending[validationErrorKey]) {
      combinedState = undefined;
    } else if (ctrl.$error[validationErrorKey]) {
      combinedState = false;
    } else if (ctrl.$$success[validationErrorKey]) {
      combinedState = true;
    } else {
      combinedState = null;
    }

    toggleValidationCss(validationErrorKey, combinedState);
    parentForm.$setValidity(validationErrorKey, combinedState, ctrl);
  }

  function createAndSet(name, value, controller) {
    if (!ctrl[name]) {
      ctrl[name] = {};
    }
    set(ctrl[name], value, controller);
  }

  function unsetAndCleanup(name, value, controller) {
    if (ctrl[name]) {
      unset(ctrl[name], value, controller);
    }
    if (isObjectEmpty(ctrl[name])) {
      ctrl[name] = undefined;
    }
  }

  function cachedToggleClass(className, switchValue) {
    if (switchValue && !classCache[className]) {
      $animate.addClass($element, className);
      classCache[className] = true;
    } else if (!switchValue && classCache[className]) {
      $animate.removeClass($element, className);
      classCache[className] = false;
    }
  }

  function toggleValidationCss(validationErrorKey, isValid) {
    validationErrorKey = validationErrorKey ? '-' + snake_case(validationErrorKey, '-') : '';

    cachedToggleClass(VALID_CLASS + validationErrorKey, isValid === true);
    cachedToggleClass(INVALID_CLASS + validationErrorKey, isValid === false);
  }
}

function isObjectEmpty(obj) {
  if (obj) {
    for (var prop in obj) {
      return false;
    }
  }
  return true;
}

/**
 * @ngdoc directive
 * @name ngNonBindable
 * @restrict AC
 * @priority 1000
 *
 * @description
 * The `ngNonBindable` directive tells Angular not to compile or bind the contents of the current
 * DOM element. This is useful if the element contains what appears to be Angular directives and
 * bindings but which should be ignored by Angular. This could be the case if you have a site that
 * displays snippets of code, for instance.
 *
 * @element ANY
 *
 * @example
 * In this example there are two locations where a simple interpolation binding (`{{}}`) is present,
 * but the one wrapped in `ngNonBindable` is left alone.
 *
 * @example
    <example>
      <file name="index.html">
        <div>Normal: {{1 + 2}}</div>
        <div ng-non-bindable>Ignored: {{1 + 2}}</div>
      </file>
      <file name="protractor.js" type="protractor">
       it('should check ng-non-bindable', function() {
         expect(element(by.binding('1 + 2')).getText()).toContain('3');
         expect(element.all(by.css('div')).last().getText()).toMatch(/1 \+ 2/);
       });
      </file>
    </example>
 */
var ngNonBindableDirective = ngDirective({ terminal: true, priority: 1000 });

/**
 * @ngdoc directive
 * @name ngPluralize
 * @restrict EA
 *
 * @description
 * `ngPluralize` is a directive that displays messages according to en-US localization rules.
 * These rules are bundled with angular.js, but can be overridden
 * (see {@link guide/i18n Angular i18n} dev guide). You configure ngPluralize directive
 * by specifying the mappings between
 * [plural categories](http://unicode.org/repos/cldr-tmp/trunk/diff/supplemental/language_plural_rules.html)
 * and the strings to be displayed.
 *
 * # Plural categories and explicit number rules
 * There are two
 * [plural categories](http://unicode.org/repos/cldr-tmp/trunk/diff/supplemental/language_plural_rules.html)
 * in Angular's default en-US locale: "one" and "other".
 *
 * While a plural category may match many numbers (for example, in en-US locale, "other" can match
 * any number that is not 1), an explicit number rule can only match one number. For example, the
 * explicit number rule for "3" matches the number 3. There are examples of plural categories
 * and explicit number rules throughout the rest of this documentation.
 *
 * # Configuring ngPluralize
 * You configure ngPluralize by providing 2 attributes: `count` and `when`.
 * You can also provide an optional attribute, `offset`.
 *
 * The value of the `count` attribute can be either a string or an {@link guide/expression
 * Angular expression}; these are evaluated on the current scope for its bound value.
 *
 * The `when` attribute specifies the mappings between plural categories and the actual
 * string to be displayed. The value of the attribute should be a JSON object.
 *
 * The following example shows how to configure ngPluralize:
 *
 * ```html
 * <ng-pluralize count="personCount"
                 when="{'0': 'Nobody is viewing.',
 *                      'one': '1 person is viewing.',
 *                      'other': '{} people are viewing.'}">
 * </ng-pluralize>
 *```
 *
 * In the example, `"0: Nobody is viewing."` is an explicit number rule. If you did not
 * specify this rule, 0 would be matched to the "other" category and "0 people are viewing"
 * would be shown instead of "Nobody is viewing". You can specify an explicit number rule for
 * other numbers, for example 12, so that instead of showing "12 people are viewing", you can
 * show "a dozen people are viewing".
 *
 * You can use a set of closed braces (`{}`) as a placeholder for the number that you want substituted
 * into pluralized strings. In the previous example, Angular will replace `{}` with
 * <span ng-non-bindable>`{{personCount}}`</span>. The closed braces `{}` is a placeholder
 * for <span ng-non-bindable>{{numberExpression}}</span>.
 *
 * # Configuring ngPluralize with offset
 * The `offset` attribute allows further customization of pluralized text, which can result in
 * a better user experience. For example, instead of the message "4 people are viewing this document",
 * you might display "John, Kate and 2 others are viewing this document".
 * The offset attribute allows you to offset a number by any desired value.
 * Let's take a look at an example:
 *
 * ```html
 * <ng-pluralize count="personCount" offset=2
 *               when="{'0': 'Nobody is viewing.',
 *                      '1': '{{person1}} is viewing.',
 *                      '2': '{{person1}} and {{person2}} are viewing.',
 *                      'one': '{{person1}}, {{person2}} and one other person are viewing.',
 *                      'other': '{{person1}}, {{person2}} and {} other people are viewing.'}">
 * </ng-pluralize>
 * ```
 *
 * Notice that we are still using two plural categories(one, other), but we added
 * three explicit number rules 0, 1 and 2.
 * When one person, perhaps John, views the document, "John is viewing" will be shown.
 * When three people view the document, no explicit number rule is found, so
 * an offset of 2 is taken off 3, and Angular uses 1 to decide the plural category.
 * In this case, plural category 'one' is matched and "John, Mary and one other person are viewing"
 * is shown.
 *
 * Note that when you specify offsets, you must provide explicit number rules for
 * numbers from 0 up to and including the offset. If you use an offset of 3, for example,
 * you must provide explicit number rules for 0, 1, 2 and 3. You must also provide plural strings for
 * plural categories "one" and "other".
 *
 * @param {string|expression} count The variable to be bound to.
 * @param {string} when The mapping between plural category to its corresponding strings.
 * @param {number=} offset Offset to deduct from the total number.
 *
 * @example
    <example module="pluralizeExample">
      <file name="index.html">
        <script>
          angular.module('pluralizeExample', [])
            .controller('ExampleController', ['$scope', function($scope) {
              $scope.person1 = 'Igor';
              $scope.person2 = 'Misko';
              $scope.personCount = 1;
            }]);
        </script>
        <div ng-controller="ExampleController">
          Person 1:<input type="text" ng-model="person1" value="Igor" /><br/>
          Person 2:<input type="text" ng-model="person2" value="Misko" /><br/>
          Number of People:<input type="text" ng-model="personCount" value="1" /><br/>

          <!--- Example with simple pluralization rules for en locale --->
          Without Offset:
          <ng-pluralize count="personCount"
                        when="{'0': 'Nobody is viewing.',
                               'one': '1 person is viewing.',
                               'other': '{} people are viewing.'}">
          </ng-pluralize><br>

          <!--- Example with offset --->
          With Offset(2):
          <ng-pluralize count="personCount" offset=2
                        when="{'0': 'Nobody is viewing.',
                               '1': '{{person1}} is viewing.',
                               '2': '{{person1}} and {{person2}} are viewing.',
                               'one': '{{person1}}, {{person2}} and one other person are viewing.',
                               'other': '{{person1}}, {{person2}} and {} other people are viewing.'}">
          </ng-pluralize>
        </div>
      </file>
      <file name="protractor.js" type="protractor">
        it('should show correct pluralized string', function() {
          var withoutOffset = element.all(by.css('ng-pluralize')).get(0);
          var withOffset = element.all(by.css('ng-pluralize')).get(1);
          var countInput = element(by.model('personCount'));

          expect(withoutOffset.getText()).toEqual('1 person is viewing.');
          expect(withOffset.getText()).toEqual('Igor is viewing.');

          countInput.clear();
          countInput.sendKeys('0');

          expect(withoutOffset.getText()).toEqual('Nobody is viewing.');
          expect(withOffset.getText()).toEqual('Nobody is viewing.');

          countInput.clear();
          countInput.sendKeys('2');

          expect(withoutOffset.getText()).toEqual('2 people are viewing.');
          expect(withOffset.getText()).toEqual('Igor and Misko are viewing.');

          countInput.clear();
          countInput.sendKeys('3');

          expect(withoutOffset.getText()).toEqual('3 people are viewing.');
          expect(withOffset.getText()).toEqual('Igor, Misko and one other person are viewing.');

          countInput.clear();
          countInput.sendKeys('4');

          expect(withoutOffset.getText()).toEqual('4 people are viewing.');
          expect(withOffset.getText()).toEqual('Igor, Misko and 2 other people are viewing.');
        });
        it('should show data-bound names', function() {
          var withOffset = element.all(by.css('ng-pluralize')).get(1);
          var personCount = element(by.model('personCount'));
          var person1 = element(by.model('person1'));
          var person2 = element(by.model('person2'));
          personCount.clear();
          personCount.sendKeys('4');
          person1.clear();
          person1.sendKeys('Di');
          person2.clear();
          person2.sendKeys('Vojta');
          expect(withOffset.getText()).toEqual('Di, Vojta and 2 other people are viewing.');
        });
      </file>
    </example>
 */
var ngPluralizeDirective = ['$locale', '$interpolate', function($locale, $interpolate) {
  var BRACE = /{}/g,
      IS_WHEN = /^when(Minus)?(.+)$/;

  return {
    restrict: 'EA',
    link: function(scope, element, attr) {
      var numberExp = attr.count,
          whenExp = attr.$attr.when && element.attr(attr.$attr.when), // we have {{}} in attrs
          offset = attr.offset || 0,
          whens = scope.$eval(whenExp) || {},
          whensExpFns = {},
          startSymbol = $interpolate.startSymbol(),
          endSymbol = $interpolate.endSymbol(),
          braceReplacement = startSymbol + numberExp + '-' + offset + endSymbol,
          watchRemover = angular.noop,
          lastCount;

      forEach(attr, function(expression, attributeName) {
        var tmpMatch = IS_WHEN.exec(attributeName);
        if (tmpMatch) {
          var whenKey = (tmpMatch[1] ? '-' : '') + lowercase(tmpMatch[2]);
          whens[whenKey] = element.attr(attr.$attr[attributeName]);
        }
      });
      forEach(whens, function(expression, key) {
        whensExpFns[key] = $interpolate(expression.replace(BRACE, braceReplacement));

      });

      scope.$watch(numberExp, function ngPluralizeWatchAction(newVal) {
        var count = parseFloat(newVal);
        var countIsNaN = isNaN(count);

        if (!countIsNaN && !(count in whens)) {
          // If an explicit number rule such as 1, 2, 3... is defined, just use it.
          // Otherwise, check it against pluralization rules in $locale service.
          count = $locale.pluralCat(count - offset);
        }

        // If both `count` and `lastCount` are NaN, we don't need to re-register a watch.
        // In JS `NaN !== NaN`, so we have to exlicitly check.
        if ((count !== lastCount) && !(countIsNaN && isNaN(lastCount))) {
          watchRemover();
          watchRemover = scope.$watch(whensExpFns[count], updateElementText);
          lastCount = count;
        }
      });

      function updateElementText(newText) {
        element.text(newText || '');
      }
    }
  };
}];

/**
 * @ngdoc directive
 * @name ngRepeat
 *
 * @description
 * The `ngRepeat` directive instantiates a template once per item from a collection. Each template
 * instance gets its own scope, where the given loop variable is set to the current collection item,
 * and `$index` is set to the item index or key.
 *
 * Special properties are exposed on the local scope of each template instance, including:
 *
 * | Variable  | Type            | Details                                                                     |
 * |-----------|-----------------|-----------------------------------------------------------------------------|
 * | `$index`  | {@type number}  | iterator offset of the repeated element (0..length-1)                       |
 * | `$first`  | {@type boolean} | true if the repeated element is first in the iterator.                      |
 * | `$middle` | {@type boolean} | true if the repeated element is between the first and last in the iterator. |
 * | `$last`   | {@type boolean} | true if the repeated element is last in the iterator.                       |
 * | `$even`   | {@type boolean} | true if the iterator position `$index` is even (otherwise false).           |
 * | `$odd`    | {@type boolean} | true if the iterator position `$index` is odd (otherwise false).            |
 *
 * Creating aliases for these properties is possible with {@link ng.directive:ngInit `ngInit`}.
 * This may be useful when, for instance, nesting ngRepeats.
 *
 * # Iterating over object properties
 *
 * It is possible to get `ngRepeat` to iterate over the properties of an object using the following
 * syntax:
 *
 * ```js
 * <div ng-repeat="(key, value) in myObj"> ... </div>
 * ```
 *
 * You need to be aware that the JavaScript specification does not define what order
 * it will return the keys for an object. In order to have a guaranteed deterministic order
 * for the keys, Angular versions up to and including 1.3 **sort the keys alphabetically**.
 *
 * If this is not desired, the recommended workaround is to convert your object into an array
 * that is sorted into the order that you prefer before providing it to `ngRepeat`.  You could
 * do this with a filter such as [toArrayFilter](http://ngmodules.org/modules/angular-toArrayFilter)
 * or implement a `$watch` on the object yourself.
 *
 * In version 1.4 we will remove the sorting, since it seems that browsers generally follow the
 * strategy of providing keys in the order in which they were defined, although there are exceptions
 * when keys are deleted and reinstated.
 *
 *
 * # Tracking and Duplicates
 *
 * When the contents of the collection change, `ngRepeat` makes the corresponding changes to the DOM:
 *
 * * When an item is added, a new instance of the template is added to the DOM.
 * * When an item is removed, its template instance is removed from the DOM.
 * * When items are reordered, their respective templates are reordered in the DOM.
 *
 * By default, `ngRepeat` does not allow duplicate items in arrays. This is because when
 * there are duplicates, it is not possible to maintain a one-to-one mapping between collection
 * items and DOM elements.
 *
 * If you do need to repeat duplicate items, you can substitute the default tracking behavior
 * with your own using the `track by` expression.
 *
 * For example, you may track items by the index of each item in the collection, using the
 * special scope property `$index`:
 * ```html
 *    <div ng-repeat="n in [42, 42, 43, 43] track by $index">
 *      {{n}}
 *    </div>
 * ```
 *
 * You may use arbitrary expressions in `track by`, including references to custom functions
 * on the scope:
 * ```html
 *    <div ng-repeat="n in [42, 42, 43, 43] track by myTrackingFunction(n)">
 *      {{n}}
 *    </div>
 * ```
 *
 * If you are working with objects that have an identifier property, you can track
 * by the identifier instead of the whole object. Should you reload your data later, `ngRepeat`
 * will not have to rebuild the DOM elements for items it has already rendered, even if the
 * JavaScript objects in the collection have been substituted for new ones:
 * ```html
 *    <div ng-repeat="model in collection track by model.id">
 *      {{model.name}}
 *    </div>
 * ```
 *
 * When no `track by` expression is provided, it is equivalent to tracking by the built-in
 * `$id` function, which tracks items by their identity:
 * ```html
 *    <div ng-repeat="obj in collection track by $id(obj)">
 *      {{obj.prop}}
 *    </div>
 * ```
 *
 * # Special repeat start and end points
 * To repeat a series of elements instead of just one parent element, ngRepeat (as well as other ng directives) supports extending
 * the range of the repeater by defining explicit start and end points by using **ng-repeat-start** and **ng-repeat-end** respectively.
 * The **ng-repeat-start** directive works the same as **ng-repeat**, but will repeat all the HTML code (including the tag it's defined on)
 * up to and including the ending HTML tag where **ng-repeat-end** is placed.
 *
 * The example below makes use of this feature:
 * ```html
 *   <header ng-repeat-start="item in items">
 *     Header {{ item }}
 *   </header>
 *   <div class="body">
 *     Body {{ item }}
 *   </div>
 *   <footer ng-repeat-end>
 *     Footer {{ item }}
 *   </footer>
 * ```
 *
 * And with an input of {@type ['A','B']} for the items variable in the example above, the output will evaluate to:
 * ```html
 *   <header>
 *     Header A
 *   </header>
 *   <div class="body">
 *     Body A
 *   </div>
 *   <footer>
 *     Footer A
 *   </footer>
 *   <header>
 *     Header B
 *   </header>
 *   <div class="body">
 *     Body B
 *   </div>
 *   <footer>
 *     Footer B
 *   </footer>
 * ```
 *
 * The custom start and end points for ngRepeat also support all other HTML directive syntax flavors provided in AngularJS (such
 * as **data-ng-repeat-start**, **x-ng-repeat-start** and **ng:repeat-start**).
 *
 * @animations
 * **.enter** - when a new item is added to the list or when an item is revealed after a filter
 *
 * **.leave** - when an item is removed from the list or when an item is filtered out
 *
 * **.move** - when an adjacent item is filtered out causing a reorder or when the item contents are reordered
 *
 * @element ANY
 * @scope
 * @priority 1000
 * @param {repeat_expression} ngRepeat The expression indicating how to enumerate a collection. These
 *   formats are currently supported:
 *
 *   * `variable in expression` – where variable is the user defined loop variable and `expression`
 *     is a scope expression giving the collection to enumerate.
 *
 *     For example: `album in artist.albums`.
 *
 *   * `(key, value) in expression` – where `key` and `value` can be any user defined identifiers,
 *     and `expression` is the scope expression giving the collection to enumerate.
 *
 *     For example: `(name, age) in {'adam':10, 'amalie':12}`.
 *
 *   * `variable in expression track by tracking_expression` – You can also provide an optional tracking expression
 *     which can be used to associate the objects in the collection with the DOM elements. If no tracking expression
 *     is specified, ng-repeat associates elements by identity. It is an error to have
 *     more than one tracking expression value resolve to the same key. (This would mean that two distinct objects are
 *     mapped to the same DOM element, which is not possible.)  If filters are used in the expression, they should be
 *     applied before the tracking expression.
 *
 *     For example: `item in items` is equivalent to `item in items track by $id(item)`. This implies that the DOM elements
 *     will be associated by item identity in the array.
 *
 *     For example: `item in items track by $id(item)`. A built in `$id()` function can be used to assign a unique
 *     `$$hashKey` property to each item in the array. This property is then used as a key to associated DOM elements
 *     with the corresponding item in the array by identity. Moving the same object in array would move the DOM
 *     element in the same way in the DOM.
 *
 *     For example: `item in items track by item.id` is a typical pattern when the items come from the database. In this
 *     case the object identity does not matter. Two objects are considered equivalent as long as their `id`
 *     property is same.
 *
 *     For example: `item in items | filter:searchText track by item.id` is a pattern that might be used to apply a filter
 *     to items in conjunction with a tracking expression.
 *
 *   * `variable in expression as alias_expression` – You can also provide an optional alias expression which will then store the
 *     intermediate results of the repeater after the filters have been applied. Typically this is used to render a special message
 *     when a filter is active on the repeater, but the filtered result set is empty.
 *
 *     For example: `item in items | filter:x as results` will store the fragment of the repeated items as `results`, but only after
 *     the items have been processed through the filter.
 *
 * @example
 * This example initializes the scope to a list of names and
 * then uses `ngRepeat` to display every person:
  <example module="ngAnimate" deps="angular-animate.js" animations="true">
    <file name="index.html">
      <div ng-init="friends = [
        {name:'John', age:25, gender:'boy'},
        {name:'Jessie', age:30, gender:'girl'},
        {name:'Johanna', age:28, gender:'girl'},
        {name:'Joy', age:15, gender:'girl'},
        {name:'Mary', age:28, gender:'girl'},
        {name:'Peter', age:95, gender:'boy'},
        {name:'Sebastian', age:50, gender:'boy'},
        {name:'Erika', age:27, gender:'girl'},
        {name:'Patrick', age:40, gender:'boy'},
        {name:'Samantha', age:60, gender:'girl'}
      ]">
        I have {{friends.length}} friends. They are:
        <input type="search" ng-model="q" placeholder="filter friends..." />
        <ul class="example-animate-container">
          <li class="animate-repeat" ng-repeat="friend in friends | filter:q as results">
            [{{$index + 1}}] {{friend.name}} who is {{friend.age}} years old.
          </li>
          <li class="animate-repeat" ng-if="results.length == 0">
            <strong>No results found...</strong>
          </li>
        </ul>
      </div>
    </file>
    <file name="animations.css">
      .example-animate-container {
        background:white;
        border:1px solid black;
        list-style:none;
        margin:0;
        padding:0 10px;
      }

      .animate-repeat {
        line-height:40px;
        list-style:none;
        box-sizing:border-box;
      }

      .animate-repeat.ng-move,
      .animate-repeat.ng-enter,
      .animate-repeat.ng-leave {
        -webkit-transition:all linear 0.5s;
        transition:all linear 0.5s;
      }

      .animate-repeat.ng-leave.ng-leave-active,
      .animate-repeat.ng-move,
      .animate-repeat.ng-enter {
        opacity:0;
        max-height:0;
      }

      .animate-repeat.ng-leave,
      .animate-repeat.ng-move.ng-move-active,
      .animate-repeat.ng-enter.ng-enter-active {
        opacity:1;
        max-height:40px;
      }
    </file>
    <file name="protractor.js" type="protractor">
      var friends = element.all(by.repeater('friend in friends'));

      it('should render initial data set', function() {
        expect(friends.count()).toBe(10);
        expect(friends.get(0).getText()).toEqual('[1] John who is 25 years old.');
        expect(friends.get(1).getText()).toEqual('[2] Jessie who is 30 years old.');
        expect(friends.last().getText()).toEqual('[10] Samantha who is 60 years old.');
        expect(element(by.binding('friends.length')).getText())
            .toMatch("I have 10 friends. They are:");
      });

       it('should update repeater when filter predicate changes', function() {
         expect(friends.count()).toBe(10);

         element(by.model('q')).sendKeys('ma');

         expect(friends.count()).toBe(2);
         expect(friends.get(0).getText()).toEqual('[1] Mary who is 28 years old.');
         expect(friends.last().getText()).toEqual('[2] Samantha who is 60 years old.');
       });
      </file>
    </example>
 */
var ngRepeatDirective = ['$parse', '$animate', function($parse, $animate) {
  var NG_REMOVED = '$$NG_REMOVED';
  var ngRepeatMinErr = minErr('ngRepeat');

  var updateScope = function(scope, index, valueIdentifier, value, keyIdentifier, key, arrayLength) {
    // TODO(perf): generate setters to shave off ~40ms or 1-1.5%
    scope[valueIdentifier] = value;
    if (keyIdentifier) scope[keyIdentifier] = key;
    scope.$index = index;
    scope.$first = (index === 0);
    scope.$last = (index === (arrayLength - 1));
    scope.$middle = !(scope.$first || scope.$last);
    // jshint bitwise: false
    scope.$odd = !(scope.$even = (index&1) === 0);
    // jshint bitwise: true
  };

  var getBlockStart = function(block) {
    return block.clone[0];
  };

  var getBlockEnd = function(block) {
    return block.clone[block.clone.length - 1];
  };


  return {
    restrict: 'A',
    multiElement: true,
    transclude: 'element',
    priority: 1000,
    terminal: true,
    $$tlb: true,
    compile: function ngRepeatCompile($element, $attr) {
      var expression = $attr.ngRepeat;
      var ngRepeatEndComment = document.createComment(' end ngRepeat: ' + expression + ' ');

      var match = expression.match(/^\s*([\s\S]+?)\s+in\s+([\s\S]+?)(?:\s+as\s+([\s\S]+?))?(?:\s+track\s+by\s+([\s\S]+?))?\s*$/);

      if (!match) {
        throw ngRepeatMinErr('iexp', "Expected expression in form of '_item_ in _collection_[ track by _id_]' but got '{0}'.",
            expression);
      }

      var lhs = match[1];
      var rhs = match[2];
      var aliasAs = match[3];
      var trackByExp = match[4];

      match = lhs.match(/^(?:(\s*[\$\w]+)|\(\s*([\$\w]+)\s*,\s*([\$\w]+)\s*\))$/);

      if (!match) {
        throw ngRepeatMinErr('iidexp', "'_item_' in '_item_ in _collection_' should be an identifier or '(_key_, _value_)' expression, but got '{0}'.",
            lhs);
      }
      var valueIdentifier = match[3] || match[1];
      var keyIdentifier = match[2];

      if (aliasAs && (!/^[$a-zA-Z_][$a-zA-Z0-9_]*$/.test(aliasAs) ||
          /^(null|undefined|this|\$index|\$first|\$middle|\$last|\$even|\$odd|\$parent|\$root|\$id)$/.test(aliasAs))) {
        throw ngRepeatMinErr('badident', "alias '{0}' is invalid --- must be a valid JS identifier which is not a reserved name.",
          aliasAs);
      }

      var trackByExpGetter, trackByIdExpFn, trackByIdArrayFn, trackByIdObjFn;
      var hashFnLocals = {$id: hashKey};

      if (trackByExp) {
        trackByExpGetter = $parse(trackByExp);
      } else {
        trackByIdArrayFn = function(key, value) {
          return hashKey(value);
        };
        trackByIdObjFn = function(key) {
          return key;
        };
      }

      return function ngRepeatLink($scope, $element, $attr, ctrl, $transclude) {

        if (trackByExpGetter) {
          trackByIdExpFn = function(key, value, index) {
            // assign key, value, and $index to the locals so that they can be used in hash functions
            if (keyIdentifier) hashFnLocals[keyIdentifier] = key;
            hashFnLocals[valueIdentifier] = value;
            hashFnLocals.$index = index;
            return trackByExpGetter($scope, hashFnLocals);
          };
        }

        // Store a list of elements from previous run. This is a hash where key is the item from the
        // iterator, and the value is objects with following properties.
        //   - scope: bound scope
        //   - element: previous element.
        //   - index: position
        //
        // We are using no-proto object so that we don't need to guard against inherited props via
        // hasOwnProperty.
        var lastBlockMap = createMap();

        //watch props
        $scope.$watchCollection(rhs, function ngRepeatAction(collection) {
          var index, length,
              previousNode = $element[0],     // node that cloned nodes should be inserted after
                                              // initialized to the comment node anchor
              nextNode,
              // Same as lastBlockMap but it has the current state. It will become the
              // lastBlockMap on the next iteration.
              nextBlockMap = createMap(),
              collectionLength,
              key, value, // key/value of iteration
              trackById,
              trackByIdFn,
              collectionKeys,
              block,       // last object information {scope, element, id}
              nextBlockOrder,
              elementsToRemove;

          if (aliasAs) {
            $scope[aliasAs] = collection;
          }

          if (isArrayLike(collection)) {
            collectionKeys = collection;
            trackByIdFn = trackByIdExpFn || trackByIdArrayFn;
          } else {
            trackByIdFn = trackByIdExpFn || trackByIdObjFn;
            // if object, extract keys, sort them and use to determine order of iteration over obj props
            collectionKeys = [];
            for (var itemKey in collection) {
              if (collection.hasOwnProperty(itemKey) && itemKey.charAt(0) != '$') {
                collectionKeys.push(itemKey);
              }
            }
            collectionKeys.sort();
          }

          collectionLength = collectionKeys.length;
          nextBlockOrder = new Array(collectionLength);

          // locate existing items
          for (index = 0; index < collectionLength; index++) {
            key = (collection === collectionKeys) ? index : collectionKeys[index];
            value = collection[key];
            trackById = trackByIdFn(key, value, index);
            if (lastBlockMap[trackById]) {
              // found previously seen block
              block = lastBlockMap[trackById];
              delete lastBlockMap[trackById];
              nextBlockMap[trackById] = block;
              nextBlockOrder[index] = block;
            } else if (nextBlockMap[trackById]) {
              // if collision detected. restore lastBlockMap and throw an error
              forEach(nextBlockOrder, function(block) {
                if (block && block.scope) lastBlockMap[block.id] = block;
              });
              throw ngRepeatMinErr('dupes',
                  "Duplicates in a repeater are not allowed. Use 'track by' expression to specify unique keys. Repeater: {0}, Duplicate key: {1}, Duplicate value: {2}",
                  expression, trackById, value);
            } else {
              // new never before seen block
              nextBlockOrder[index] = {id: trackById, scope: undefined, clone: undefined};
              nextBlockMap[trackById] = true;
            }
          }

          // remove leftover items
          for (var blockKey in lastBlockMap) {
            block = lastBlockMap[blockKey];
            elementsToRemove = getBlockNodes(block.clone);
            $animate.leave(elementsToRemove);
            if (elementsToRemove[0].parentNode) {
              // if the element was not removed yet because of pending animation, mark it as deleted
              // so that we can ignore it later
              for (index = 0, length = elementsToRemove.length; index < length; index++) {
                elementsToRemove[index][NG_REMOVED] = true;
              }
            }
            block.scope.$destroy();
          }

          // we are not using forEach for perf reasons (trying to avoid #call)
          for (index = 0; index < collectionLength; index++) {
            key = (collection === collectionKeys) ? index : collectionKeys[index];
            value = collection[key];
            block = nextBlockOrder[index];

            if (block.scope) {
              // if we have already seen this object, then we need to reuse the
              // associated scope/element

              nextNode = previousNode;

              // skip nodes that are already pending removal via leave animation
              do {
                nextNode = nextNode.nextSibling;
              } while (nextNode && nextNode[NG_REMOVED]);

              if (getBlockStart(block) != nextNode) {
                // existing item which got moved
                $animate.move(getBlockNodes(block.clone), null, jqLite(previousNode));
              }
              previousNode = getBlockEnd(block);
              updateScope(block.scope, index, valueIdentifier, value, keyIdentifier, key, collectionLength);
            } else {
              // new item which we don't know about
              $transclude(function ngRepeatTransclude(clone, scope) {
                block.scope = scope;
                // http://jsperf.com/clone-vs-createcomment
                var endNode = ngRepeatEndComment.cloneNode(false);
                clone[clone.length++] = endNode;

                // TODO(perf): support naked previousNode in `enter` to avoid creation of jqLite wrapper?
                $animate.enter(clone, null, jqLite(previousNode));
                previousNode = endNode;
                // Note: We only need the first/last node of the cloned nodes.
                // However, we need to keep the reference to the jqlite wrapper as it might be changed later
                // by a directive with templateUrl when its template arrives.
                block.clone = clone;
                nextBlockMap[block.id] = block;
                updateScope(block.scope, index, valueIdentifier, value, keyIdentifier, key, collectionLength);
              });
            }
          }
          lastBlockMap = nextBlockMap;
        });
      };
    }
  };
}];

var NG_HIDE_CLASS = 'ng-hide';
var NG_HIDE_IN_PROGRESS_CLASS = 'ng-hide-animate';
/**
 * @ngdoc directive
 * @name ngShow
 *
 * @description
 * The `ngShow` directive shows or hides the given HTML element based on the expression
 * provided to the `ngShow` attribute. The element is shown or hidden by removing or adding
 * the `.ng-hide` CSS class onto the element. The `.ng-hide` CSS class is predefined
 * in AngularJS and sets the display style to none (using an !important flag).
 * For CSP mode please add `angular-csp.css` to your html file (see {@link ng.directive:ngCsp ngCsp}).
 *
 * ```html
 * <!-- when $scope.myValue is truthy (element is visible) -->
 * <div ng-show="myValue"></div>
 *
 * <!-- when $scope.myValue is falsy (element is hidden) -->
 * <div ng-show="myValue" class="ng-hide"></div>
 * ```
 *
 * When the `ngShow` expression evaluates to a falsy value then the `.ng-hide` CSS class is added to the class
 * attribute on the element causing it to become hidden. When truthy, the `.ng-hide` CSS class is removed
 * from the element causing the element not to appear hidden.
 *
 * ## Why is !important used?
 *
 * You may be wondering why !important is used for the `.ng-hide` CSS class. This is because the `.ng-hide` selector
 * can be easily overridden by heavier selectors. For example, something as simple
 * as changing the display style on a HTML list item would make hidden elements appear visible.
 * This also becomes a bigger issue when dealing with CSS frameworks.
 *
 * By using !important, the show and hide behavior will work as expected despite any clash between CSS selector
 * specificity (when !important isn't used with any conflicting styles). If a developer chooses to override the
 * styling to change how to hide an element then it is just a matter of using !important in their own CSS code.
 *
 * ### Overriding `.ng-hide`
 *
 * By default, the `.ng-hide` class will style the element with `display: none!important`. If you wish to change
 * the hide behavior with ngShow/ngHide then this can be achieved by restating the styles for the `.ng-hide`
 * class CSS. Note that the selector that needs to be used is actually `.ng-hide:not(.ng-hide-animate)` to cope
 * with extra animation classes that can be added.
 *
 * ```css
 * .ng-hide:not(.ng-hide-animate) {
 *   /&#42; this is just another form of hiding an element &#42;/
 *   display: block!important;
 *   position: absolute;
 *   top: -9999px;
 *   left: -9999px;
 * }
 * ```
 *
 * By default you don't need to override in CSS anything and the animations will work around the display style.
 *
 * ## A note about animations with `ngShow`
 *
 * Animations in ngShow/ngHide work with the show and hide events that are triggered when the directive expression
 * is true and false. This system works like the animation system present with ngClass except that
 * you must also include the !important flag to override the display property
 * so that you can perform an animation when the element is hidden during the time of the animation.
 *
 * ```css
 * //
 * //a working example can be found at the bottom of this page
 * //
 * .my-element.ng-hide-add, .my-element.ng-hide-remove {
 *   /&#42; this is required as of 1.3x to properly
 *      apply all styling in a show/hide animation &#42;/
 *   transition: 0s linear all;
 * }
 *
 * .my-element.ng-hide-add-active,
 * .my-element.ng-hide-remove-active {
 *   /&#42; the transition is defined in the active class &#42;/
 *   transition: 1s linear all;
 * }
 *
 * .my-element.ng-hide-add { ... }
 * .my-element.ng-hide-add.ng-hide-add-active { ... }
 * .my-element.ng-hide-remove { ... }
 * .my-element.ng-hide-remove.ng-hide-remove-active { ... }
 * ```
 *
 * Keep in mind that, as of AngularJS version 1.3.0-beta.11, there is no need to change the display
 * property to block during animation states--ngAnimate will handle the style toggling automatically for you.
 *
 * @animations
 * addClass: `.ng-hide` - happens after the `ngShow` expression evaluates to a truthy value and the just before contents are set to visible
 * removeClass: `.ng-hide` - happens after the `ngShow` expression evaluates to a non truthy value and just before the contents are set to hidden
 *
 * @element ANY
 * @param {expression} ngShow If the {@link guide/expression expression} is truthy
 *     then the element is shown or hidden respectively.
 *
 * @example
  <example module="ngAnimate" deps="angular-animate.js" animations="true">
    <file name="index.html">
      Click me: <input type="checkbox" ng-model="checked"><br/>
      <div>
        Show:
        <div class="check-element animate-show" ng-show="checked">
          <span class="glyphicon glyphicon-thumbs-up"></span> I show up when your checkbox is checked.
        </div>
      </div>
      <div>
        Hide:
        <div class="check-element animate-show" ng-hide="checked">
          <span class="glyphicon glyphicon-thumbs-down"></span> I hide when your checkbox is checked.
        </div>
      </div>
    </file>
    <file name="glyphicons.css">
      @import url(../../components/bootstrap-3.1.1/css/bootstrap.css);
    </file>
    <file name="animations.css">
      .animate-show {
        line-height: 20px;
        opacity: 1;
        padding: 10px;
        border: 1px solid black;
        background: white;
      }

      .animate-show.ng-hide-add.ng-hide-add-active,
      .animate-show.ng-hide-remove.ng-hide-remove-active {
        -webkit-transition: all linear 0.5s;
        transition: all linear 0.5s;
      }

      .animate-show.ng-hide {
        line-height: 0;
        opacity: 0;
        padding: 0 10px;
      }

      .check-element {
        padding: 10px;
        border: 1px solid black;
        background: white;
      }
    </file>
    <file name="protractor.js" type="protractor">
      var thumbsUp = element(by.css('span.glyphicon-thumbs-up'));
      var thumbsDown = element(by.css('span.glyphicon-thumbs-down'));

      it('should check ng-show / ng-hide', function() {
        expect(thumbsUp.isDisplayed()).toBeFalsy();
        expect(thumbsDown.isDisplayed()).toBeTruthy();

        element(by.model('checked')).click();

        expect(thumbsUp.isDisplayed()).toBeTruthy();
        expect(thumbsDown.isDisplayed()).toBeFalsy();
      });
    </file>
  </example>
 */
var ngShowDirective = ['$animate', function($animate) {
  return {
    restrict: 'A',
    multiElement: true,
    link: function(scope, element, attr) {
      scope.$watch(attr.ngShow, function ngShowWatchAction(value) {
        // we're adding a temporary, animation-specific class for ng-hide since this way
        // we can control when the element is actually displayed on screen without having
        // to have a global/greedy CSS selector that breaks when other animations are run.
        // Read: https://github.com/angular/angular.js/issues/9103#issuecomment-58335845
        $animate[value ? 'removeClass' : 'addClass'](element, NG_HIDE_CLASS, {
          tempClasses: NG_HIDE_IN_PROGRESS_CLASS
        });
      });
    }
  };
}];


/**
 * @ngdoc directive
 * @name ngHide
 *
 * @description
 * The `ngHide` directive shows or hides the given HTML element based on the expression
 * provided to the `ngHide` attribute. The element is shown or hidden by removing or adding
 * the `ng-hide` CSS class onto the element. The `.ng-hide` CSS class is predefined
 * in AngularJS and sets the display style to none (using an !important flag).
 * For CSP mode please add `angular-csp.css` to your html file (see {@link ng.directive:ngCsp ngCsp}).
 *
 * ```html
 * <!-- when $scope.myValue is truthy (element is hidden) -->
 * <div ng-hide="myValue" class="ng-hide"></div>
 *
 * <!-- when $scope.myValue is falsy (element is visible) -->
 * <div ng-hide="myValue"></div>
 * ```
 *
 * When the `ngHide` expression evaluates to a truthy value then the `.ng-hide` CSS class is added to the class
 * attribute on the element causing it to become hidden. When falsy, the `.ng-hide` CSS class is removed
 * from the element causing the element not to appear hidden.
 *
 * ## Why is !important used?
 *
 * You may be wondering why !important is used for the `.ng-hide` CSS class. This is because the `.ng-hide` selector
 * can be easily overridden by heavier selectors. For example, something as simple
 * as changing the display style on a HTML list item would make hidden elements appear visible.
 * This also becomes a bigger issue when dealing with CSS frameworks.
 *
 * By using !important, the show and hide behavior will work as expected despite any clash between CSS selector
 * specificity (when !important isn't used with any conflicting styles). If a developer chooses to override the
 * styling to change how to hide an element then it is just a matter of using !important in their own CSS code.
 *
 * ### Overriding `.ng-hide`
 *
 * By default, the `.ng-hide` class will style the element with `display: none!important`. If you wish to change
 * the hide behavior with ngShow/ngHide then this can be achieved by restating the styles for the `.ng-hide`
 * class in CSS:
 *
 * ```css
 * .ng-hide {
 *   /&#42; this is just another form of hiding an element &#42;/
 *   display: block!important;
 *   position: absolute;
 *   top: -9999px;
 *   left: -9999px;
 * }
 * ```
 *
 * By default you don't need to override in CSS anything and the animations will work around the display style.
 *
 * ## A note about animations with `ngHide`
 *
 * Animations in ngShow/ngHide work with the show and hide events that are triggered when the directive expression
 * is true and false. This system works like the animation system present with ngClass, except that the `.ng-hide`
 * CSS class is added and removed for you instead of your own CSS class.
 *
 * ```css
 * //
 * //a working example can be found at the bottom of this page
 * //
 * .my-element.ng-hide-add, .my-element.ng-hide-remove {
 *   transition: 0.5s linear all;
 * }
 *
 * .my-element.ng-hide-add { ... }
 * .my-element.ng-hide-add.ng-hide-add-active { ... }
 * .my-element.ng-hide-remove { ... }
 * .my-element.ng-hide-remove.ng-hide-remove-active { ... }
 * ```
 *
 * Keep in mind that, as of AngularJS version 1.3.0-beta.11, there is no need to change the display
 * property to block during animation states--ngAnimate will handle the style toggling automatically for you.
 *
 * @animations
 * removeClass: `.ng-hide` - happens after the `ngHide` expression evaluates to a truthy value and just before the contents are set to hidden
 * addClass: `.ng-hide` - happens after the `ngHide` expression evaluates to a non truthy value and just before the contents are set to visible
 *
 * @element ANY
 * @param {expression} ngHide If the {@link guide/expression expression} is truthy then
 *     the element is shown or hidden respectively.
 *
 * @example
  <example module="ngAnimate" deps="angular-animate.js" animations="true">
    <file name="index.html">
      Click me: <input type="checkbox" ng-model="checked"><br/>
      <div>
        Show:
        <div class="check-element animate-hide" ng-show="checked">
          <span class="glyphicon glyphicon-thumbs-up"></span> I show up when your checkbox is checked.
        </div>
      </div>
      <div>
        Hide:
        <div class="check-element animate-hide" ng-hide="checked">
          <span class="glyphicon glyphicon-thumbs-down"></span> I hide when your checkbox is checked.
        </div>
      </div>
    </file>
    <file name="glyphicons.css">
      @import url(../../components/bootstrap-3.1.1/css/bootstrap.css);
    </file>
    <file name="animations.css">
      .animate-hide {
        -webkit-transition: all linear 0.5s;
        transition: all linear 0.5s;
        line-height: 20px;
        opacity: 1;
        padding: 10px;
        border: 1px solid black;
        background: white;
      }

      .animate-hide.ng-hide {
        line-height: 0;
        opacity: 0;
        padding: 0 10px;
      }

      .check-element {
        padding: 10px;
        border: 1px solid black;
        background: white;
      }
    </file>
    <file name="protractor.js" type="protractor">
      var thumbsUp = element(by.css('span.glyphicon-thumbs-up'));
      var thumbsDown = element(by.css('span.glyphicon-thumbs-down'));

      it('should check ng-show / ng-hide', function() {
        expect(thumbsUp.isDisplayed()).toBeFalsy();
        expect(thumbsDown.isDisplayed()).toBeTruthy();

        element(by.model('checked')).click();

        expect(thumbsUp.isDisplayed()).toBeTruthy();
        expect(thumbsDown.isDisplayed()).toBeFalsy();
      });
    </file>
  </example>
 */
var ngHideDirective = ['$animate', function($animate) {
  return {
    restrict: 'A',
    multiElement: true,
    link: function(scope, element, attr) {
      scope.$watch(attr.ngHide, function ngHideWatchAction(value) {
        // The comment inside of the ngShowDirective explains why we add and
        // remove a temporary class for the show/hide animation
        $animate[value ? 'addClass' : 'removeClass'](element,NG_HIDE_CLASS, {
          tempClasses: NG_HIDE_IN_PROGRESS_CLASS
        });
      });
    }
  };
}];

/**
 * @ngdoc directive
 * @name ngStyle
 * @restrict AC
 *
 * @description
 * The `ngStyle` directive allows you to set CSS style on an HTML element conditionally.
 *
 * @element ANY
 * @param {expression} ngStyle
 *
 * {@link guide/expression Expression} which evals to an
 * object whose keys are CSS style names and values are corresponding values for those CSS
 * keys.
 *
 * Since some CSS style names are not valid keys for an object, they must be quoted.
 * See the 'background-color' style in the example below.
 *
 * @example
   <example>
     <file name="index.html">
        <input type="button" value="set color" ng-click="myStyle={color:'red'}">
        <input type="button" value="set background" ng-click="myStyle={'background-color':'blue'}">
        <input type="button" value="clear" ng-click="myStyle={}">
        <br/>
        <span ng-style="myStyle">Sample Text</span>
        <pre>myStyle={{myStyle}}</pre>
     </file>
     <file name="style.css">
       span {
         color: black;
       }
     </file>
     <file name="protractor.js" type="protractor">
       var colorSpan = element(by.css('span'));

       it('should check ng-style', function() {
         expect(colorSpan.getCssValue('color')).toBe('rgba(0, 0, 0, 1)');
         element(by.css('input[value=\'set color\']')).click();
         expect(colorSpan.getCssValue('color')).toBe('rgba(255, 0, 0, 1)');
         element(by.css('input[value=clear]')).click();
         expect(colorSpan.getCssValue('color')).toBe('rgba(0, 0, 0, 1)');
       });
     </file>
   </example>
 */
var ngStyleDirective = ngDirective(function(scope, element, attr) {
  scope.$watch(attr.ngStyle, function ngStyleWatchAction(newStyles, oldStyles) {
    if (oldStyles && (newStyles !== oldStyles)) {
      forEach(oldStyles, function(val, style) { element.css(style, '');});
    }
    if (newStyles) element.css(newStyles);
  }, true);
});

/**
 * @ngdoc directive
 * @name ngSwitch
 * @restrict EA
 *
 * @description
 * The `ngSwitch` directive is used to conditionally swap DOM structure on your template based on a scope expression.
 * Elements within `ngSwitch` but without `ngSwitchWhen` or `ngSwitchDefault` directives will be preserved at the location
 * as specified in the template.
 *
 * The directive itself works similar to ngInclude, however, instead of downloading template code (or loading it
 * from the template cache), `ngSwitch` simply chooses one of the nested elements and makes it visible based on which element
 * matches the value obtained from the evaluated expression. In other words, you define a container element
 * (where you place the directive), place an expression on the **`on="..."` attribute**
 * (or the **`ng-switch="..."` attribute**), define any inner elements inside of the directive and place
 * a when attribute per element. The when attribute is used to inform ngSwitch which element to display when the on
 * expression is evaluated. If a matching expression is not found via a when attribute then an element with the default
 * attribute is displayed.
 *
 * <div class="alert alert-info">
 * Be aware that the attribute values to match against cannot be expressions. They are interpreted
 * as literal string values to match against.
 * For example, **`ng-switch-when="someVal"`** will match against the string `"someVal"` not against the
 * value of the expression `$scope.someVal`.
 * </div>

 * @animations
 * enter - happens after the ngSwitch contents change and the matched child element is placed inside the container
 * leave - happens just after the ngSwitch contents change and just before the former contents are removed from the DOM
 *
 * @usage
 *
 * ```
 * <ANY ng-switch="expression">
 *   <ANY ng-switch-when="matchValue1">...</ANY>
 *   <ANY ng-switch-when="matchValue2">...</ANY>
 *   <ANY ng-switch-default>...</ANY>
 * </ANY>
 * ```
 *
 *
 * @scope
 * @priority 1200
 * @param {*} ngSwitch|on expression to match against <code>ng-switch-when</code>.
 * On child elements add:
 *
 * * `ngSwitchWhen`: the case statement to match against. If match then this
 *   case will be displayed. If the same match appears multiple times, all the
 *   elements will be displayed.
 * * `ngSwitchDefault`: the default case when no other case match. If there
 *   are multiple default cases, all of them will be displayed when no other
 *   case match.
 *
 *
 * @example
  <example module="switchExample" deps="angular-animate.js" animations="true">
    <file name="index.html">
      <div ng-controller="ExampleController">
        <select ng-model="selection" ng-options="item for item in items">
        </select>
        <code>selection={{selection}}</code>
        <hr/>
        <div class="animate-switch-container"
          ng-switch on="selection">
            <div class="animate-switch" ng-switch-when="settings">Settings Div</div>
            <div class="animate-switch" ng-switch-when="home">Home Span</div>
            <div class="animate-switch" ng-switch-default>default</div>
        </div>
      </div>
    </file>
    <file name="script.js">
      angular.module('switchExample', ['ngAnimate'])
        .controller('ExampleController', ['$scope', function($scope) {
          $scope.items = ['settings', 'home', 'other'];
          $scope.selection = $scope.items[0];
        }]);
    </file>
    <file name="animations.css">
      .animate-switch-container {
        position:relative;
        background:white;
        border:1px solid black;
        height:40px;
        overflow:hidden;
      }

      .animate-switch {
        padding:10px;
      }

      .animate-switch.ng-animate {
        -webkit-transition:all cubic-bezier(0.250, 0.460, 0.450, 0.940) 0.5s;
        transition:all cubic-bezier(0.250, 0.460, 0.450, 0.940) 0.5s;

        position:absolute;
        top:0;
        left:0;
        right:0;
        bottom:0;
      }

      .animate-switch.ng-leave.ng-leave-active,
      .animate-switch.ng-enter {
        top:-50px;
      }
      .animate-switch.ng-leave,
      .animate-switch.ng-enter.ng-enter-active {
        top:0;
      }
    </file>
    <file name="protractor.js" type="protractor">
      var switchElem = element(by.css('[ng-switch]'));
      var select = element(by.model('selection'));

      it('should start in settings', function() {
        expect(switchElem.getText()).toMatch(/Settings Div/);
      });
      it('should change to home', function() {
        select.all(by.css('option')).get(1).click();
        expect(switchElem.getText()).toMatch(/Home Span/);
      });
      it('should select default', function() {
        select.all(by.css('option')).get(2).click();
        expect(switchElem.getText()).toMatch(/default/);
      });
    </file>
  </example>
 */
var ngSwitchDirective = ['$animate', function($animate) {
  return {
    restrict: 'EA',
    require: 'ngSwitch',

    // asks for $scope to fool the BC controller module
    controller: ['$scope', function ngSwitchController() {
     this.cases = {};
    }],
    link: function(scope, element, attr, ngSwitchController) {
      var watchExpr = attr.ngSwitch || attr.on,
          selectedTranscludes = [],
          selectedElements = [],
          previousLeaveAnimations = [],
          selectedScopes = [];

      var spliceFactory = function(array, index) {
          return function() { array.splice(index, 1); };
      };

      scope.$watch(watchExpr, function ngSwitchWatchAction(value) {
        var i, ii;
        for (i = 0, ii = previousLeaveAnimations.length; i < ii; ++i) {
          $animate.cancel(previousLeaveAnimations[i]);
        }
        previousLeaveAnimations.length = 0;

        for (i = 0, ii = selectedScopes.length; i < ii; ++i) {
          var selected = getBlockNodes(selectedElements[i].clone);
          selectedScopes[i].$destroy();
          var promise = previousLeaveAnimations[i] = $animate.leave(selected);
          promise.then(spliceFactory(previousLeaveAnimations, i));
        }

        selectedElements.length = 0;
        selectedScopes.length = 0;

        if ((selectedTranscludes = ngSwitchController.cases['!' + value] || ngSwitchController.cases['?'])) {
          forEach(selectedTranscludes, function(selectedTransclude) {
            selectedTransclude.transclude(function(caseElement, selectedScope) {
              selectedScopes.push(selectedScope);
              var anchor = selectedTransclude.element;
              caseElement[caseElement.length++] = document.createComment(' end ngSwitchWhen: ');
              var block = { clone: caseElement };

              selectedElements.push(block);
              $animate.enter(caseElement, anchor.parent(), anchor);
            });
          });
        }
      });
    }
  };
}];

var ngSwitchWhenDirective = ngDirective({
  transclude: 'element',
  priority: 1200,
  require: '^ngSwitch',
  multiElement: true,
  link: function(scope, element, attrs, ctrl, $transclude) {
    ctrl.cases['!' + attrs.ngSwitchWhen] = (ctrl.cases['!' + attrs.ngSwitchWhen] || []);
    ctrl.cases['!' + attrs.ngSwitchWhen].push({ transclude: $transclude, element: element });
  }
});

var ngSwitchDefaultDirective = ngDirective({
  transclude: 'element',
  priority: 1200,
  require: '^ngSwitch',
  multiElement: true,
  link: function(scope, element, attr, ctrl, $transclude) {
    ctrl.cases['?'] = (ctrl.cases['?'] || []);
    ctrl.cases['?'].push({ transclude: $transclude, element: element });
   }
});

/**
 * @ngdoc directive
 * @name ngTransclude
 * @restrict EAC
 *
 * @description
 * Directive that marks the insertion point for the transcluded DOM of the nearest parent directive that uses transclusion.
 *
 * Any existing content of the element that this directive is placed on will be removed before the transcluded content is inserted.
 *
 * @element ANY
 *
 * @example
   <example module="transcludeExample">
     <file name="index.html">
       <script>
         angular.module('transcludeExample', [])
          .directive('pane', function(){
             return {
               restrict: 'E',
               transclude: true,
               scope: { title:'@' },
               template: '<div style="border: 1px solid black;">' +
                           '<div style="background-color: gray">{{title}}</div>' +
                           '<ng-transclude></ng-transclude>' +
                         '</div>'
             };
         })
         .controller('ExampleController', ['$scope', function($scope) {
           $scope.title = 'Lorem Ipsum';
           $scope.text = 'Neque porro quisquam est qui dolorem ipsum quia dolor...';
         }]);
       </script>
       <div ng-controller="ExampleController">
         <input ng-model="title"> <br/>
         <textarea ng-model="text"></textarea> <br/>
         <pane title="{{title}}">{{text}}</pane>
       </div>
     </file>
     <file name="protractor.js" type="protractor">
        it('should have transcluded', function() {
          var titleElement = element(by.model('title'));
          titleElement.clear();
          titleElement.sendKeys('TITLE');
          var textElement = element(by.model('text'));
          textElement.clear();
          textElement.sendKeys('TEXT');
          expect(element(by.binding('title')).getText()).toEqual('TITLE');
          expect(element(by.binding('text')).getText()).toEqual('TEXT');
        });
     </file>
   </example>
 *
 */
var ngTranscludeDirective = ngDirective({
  restrict: 'EAC',
  link: function($scope, $element, $attrs, controller, $transclude) {
    if (!$transclude) {
      throw minErr('ngTransclude')('orphan',
       'Illegal use of ngTransclude directive in the template! ' +
       'No parent directive that requires a transclusion found. ' +
       'Element: {0}',
       startingTag($element));
    }

    $transclude(function(clone) {
      $element.empty();
      $element.append(clone);
    });
  }
});

/**
 * @ngdoc directive
 * @name script
 * @restrict E
 *
 * @description
 * Load the content of a `<script>` element into {@link ng.$templateCache `$templateCache`}, so that the
 * template can be used by {@link ng.directive:ngInclude `ngInclude`},
 * {@link ngRoute.directive:ngView `ngView`}, or {@link guide/directive directives}. The type of the
 * `<script>` element must be specified as `text/ng-template`, and a cache name for the template must be
 * assigned through the element's `id`, which can then be used as a directive's `templateUrl`.
 *
 * @param {string} type Must be set to `'text/ng-template'`.
 * @param {string} id Cache name of the template.
 *
 * @example
  <example>
    <file name="index.html">
      <script type="text/ng-template" id="/tpl.html">
        Content of the template.
      </script>

      <a ng-click="currentTpl='/tpl.html'" id="tpl-link">Load inlined template</a>
      <div id="tpl-content" ng-include src="currentTpl"></div>
    </file>
    <file name="protractor.js" type="protractor">
      it('should load template defined inside script tag', function() {
        element(by.css('#tpl-link')).click();
        expect(element(by.css('#tpl-content')).getText()).toMatch(/Content of the template/);
      });
    </file>
  </example>
 */
var scriptDirective = ['$templateCache', function($templateCache) {
  return {
    restrict: 'E',
    terminal: true,
    compile: function(element, attr) {
      if (attr.type == 'text/ng-template') {
        var templateUrl = attr.id,
            text = element[0].text;

        $templateCache.put(templateUrl, text);
      }
    }
  };
}];

var ngOptionsMinErr = minErr('ngOptions');
/**
 * @ngdoc directive
 * @name select
 * @restrict E
 *
 * @description
 * HTML `SELECT` element with angular data-binding.
 *
 * # `ngOptions`
 *
 * The `ngOptions` attribute can be used to dynamically generate a list of `<option>`
 * elements for the `<select>` element using the array or object obtained by evaluating the
 * `ngOptions` comprehension expression.
 *
 * In many cases, `ngRepeat` can be used on `<option>` elements instead of `ngOptions` to achieve a
 * similar result. However, `ngOptions` provides some benefits such as reducing memory and
 * increasing speed by not creating a new scope for each repeated instance, as well as providing
 * more flexibility in how the `<select>`'s model is assigned via the `select` **`as`** part of the
 * comprehension expression. `ngOptions` should be used when the `<select>` model needs to be bound
 *  to a non-string value. This is because an option element can only be bound to string values at
 * present.
 *
 * When an item in the `<select>` menu is selected, the array element or object property
 * represented by the selected option will be bound to the model identified by the `ngModel`
 * directive.
 *
 * Optionally, a single hard-coded `<option>` element, with the value set to an empty string, can
 * be nested into the `<select>` element. This element will then represent the `null` or "not selected"
 * option. See example below for demonstration.
 *
 * <div class="alert alert-warning">
 * **Note:** `ngModel` compares by reference, not value. This is important when binding to an
 * array of objects. See an example [in this jsfiddle](http://jsfiddle.net/qWzTb/).
 * </div>
 *
 * ## `select` **`as`**
 *
 * Using `select` **`as`** will bind the result of the `select` expression to the model, but
 * the value of the `<select>` and `<option>` html elements will be either the index (for array data sources)
 * or property name (for object data sources) of the value within the collection. If a **`track by`** expression
 * is used, the result of that expression will be set as the value of the `option` and `select` elements.
 *
 *
 * ### `select` **`as`** and **`track by`**
 *
 * <div class="alert alert-warning">
 * Do not use `select` **`as`** and **`track by`** in the same expression. They are not designed to work together.
 * </div>
 *
 * Consider the following example:
 *
 * ```html
 * <select ng-options="item.subItem as item.label for item in values track by item.id" ng-model="selected">
 * ```
 *
 * ```js
 * $scope.values = [{
 *   id: 1,
 *   label: 'aLabel',
 *   subItem: { name: 'aSubItem' }
 * }, {
 *   id: 2,
 *   label: 'bLabel',
 *   subItem: { name: 'bSubItem' }
 * }];
 *
 * $scope.selected = { name: 'aSubItem' };
 * ```
 *
 * With the purpose of preserving the selection, the **`track by`** expression is always applied to the element
 * of the data source (to `item` in this example). To calculate whether an element is selected, we do the
 * following:
 *
 * 1. Apply **`track by`** to the elements in the array. In the example: `[1, 2]`
 * 2. Apply **`track by`** to the already selected value in `ngModel`.
 *    In the example: this is not possible as **`track by`** refers to `item.id`, but the selected
 *    value from `ngModel` is `{name: 'aSubItem'}`, so the **`track by`** expression is applied to
 *    a wrong object, the selected element can't be found, `<select>` is always reset to the "not
 *    selected" option.
 *
 *
 * @param {string} ngModel Assignable angular expression to data-bind to.
 * @param {string=} name Property name of the form under which the control is published.
 * @param {string=} required The control is considered valid only if value is entered.
 * @param {string=} ngRequired Adds `required` attribute and `required` validation constraint to
 *    the element when the ngRequired expression evaluates to true. Use `ngRequired` instead of
 *    `required` when you want to data-bind to the `required` attribute.
 * @param {comprehension_expression=} ngOptions in one of the following forms:
 *
 *   * for array data sources:
 *     * `label` **`for`** `value` **`in`** `array`
 *     * `select` **`as`** `label` **`for`** `value` **`in`** `array`
 *     * `label` **`group by`** `group` **`for`** `value` **`in`** `array`
 *     * `label` **`group by`** `group` **`for`** `value` **`in`** `array` **`track by`** `trackexpr`
 *     * `label` **`for`** `value` **`in`** `array` | orderBy:`orderexpr` **`track by`** `trackexpr`
 *        (for including a filter with `track by`)
 *   * for object data sources:
 *     * `label` **`for (`**`key` **`,`** `value`**`) in`** `object`
 *     * `select` **`as`** `label` **`for (`**`key` **`,`** `value`**`) in`** `object`
 *     * `label` **`group by`** `group` **`for (`**`key`**`,`** `value`**`) in`** `object`
 *     * `select` **`as`** `label` **`group by`** `group`
 *         **`for` `(`**`key`**`,`** `value`**`) in`** `object`
 *
 * Where:
 *
 *   * `array` / `object`: an expression which evaluates to an array / object to iterate over.
 *   * `value`: local variable which will refer to each item in the `array` or each property value
 *      of `object` during iteration.
 *   * `key`: local variable which will refer to a property name in `object` during iteration.
 *   * `label`: The result of this expression will be the label for `<option>` element. The
 *     `expression` will most likely refer to the `value` variable (e.g. `value.propertyName`).
 *   * `select`: The result of this expression will be bound to the model of the parent `<select>`
 *      element. If not specified, `select` expression will default to `value`.
 *   * `group`: The result of this expression will be used to group options using the `<optgroup>`
 *      DOM element.
 *   * `trackexpr`: Used when working with an array of objects. The result of this expression will be
 *      used to identify the objects in the array. The `trackexpr` will most likely refer to the
 *     `value` variable (e.g. `value.propertyName`). With this the selection is preserved
 *      even when the options are recreated (e.g. reloaded from the server).
 *
 * @example
    <example module="selectExample">
      <file name="index.html">
        <script>
        angular.module('selectExample', [])
          .controller('ExampleController', ['$scope', function($scope) {
            $scope.colors = [
              {name:'black', shade:'dark'},
              {name:'white', shade:'light'},
              {name:'red', shade:'dark'},
              {name:'blue', shade:'dark'},
              {name:'yellow', shade:'light'}
            ];
            $scope.myColor = $scope.colors[2]; // red
          }]);
        </script>
        <div ng-controller="ExampleController">
          <ul>
            <li ng-repeat="color in colors">
              Name: <input ng-model="color.name">
              [<a href ng-click="colors.splice($index, 1)">X</a>]
            </li>
            <li>
              [<a href ng-click="colors.push({})">add</a>]
            </li>
          </ul>
          <hr/>
          Color (null not allowed):
          <select ng-model="myColor" ng-options="color.name for color in colors"></select><br>

          Color (null allowed):
          <span  class="nullable">
            <select ng-model="myColor" ng-options="color.name for color in colors">
              <option value="">-- choose color --</option>
            </select>
          </span><br/>

          Color grouped by shade:
          <select ng-model="myColor" ng-options="color.name group by color.shade for color in colors">
          </select><br/>


          Select <a href ng-click="myColor = { name:'not in list', shade: 'other' }">bogus</a>.<br>
          <hr/>
          Currently selected: {{ {selected_color:myColor} }}
          <div style="border:solid 1px black; height:20px"
               ng-style="{'background-color':myColor.name}">
          </div>
        </div>
      </file>
      <file name="protractor.js" type="protractor">
         it('should check ng-options', function() {
           expect(element(by.binding('{selected_color:myColor}')).getText()).toMatch('red');
           element.all(by.model('myColor')).first().click();
           element.all(by.css('select[ng-model="myColor"] option')).first().click();
           expect(element(by.binding('{selected_color:myColor}')).getText()).toMatch('black');
           element(by.css('.nullable select[ng-model="myColor"]')).click();
           element.all(by.css('.nullable select[ng-model="myColor"] option')).first().click();
           expect(element(by.binding('{selected_color:myColor}')).getText()).toMatch('null');
         });
      </file>
    </example>
 */

var ngOptionsDirective = valueFn({
  restrict: 'A',
  terminal: true
});

// jshint maxlen: false
var selectDirective = ['$compile', '$parse', function($compile,   $parse) {
                         //000011111111110000000000022222222220000000000000000000003333333333000000000000004444444444444440000000005555555555555550000000666666666666666000000000000000777777777700000000000000000008888888888
  var NG_OPTIONS_REGEXP = /^\s*([\s\S]+?)(?:\s+as\s+([\s\S]+?))?(?:\s+group\s+by\s+([\s\S]+?))?\s+for\s+(?:([\$\w][\$\w]*)|(?:\(\s*([\$\w][\$\w]*)\s*,\s*([\$\w][\$\w]*)\s*\)))\s+in\s+([\s\S]+?)(?:\s+track\s+by\s+([\s\S]+?))?$/,
      nullModelCtrl = {$setViewValue: noop};
// jshint maxlen: 100

  return {
    restrict: 'E',
    require: ['select', '?ngModel'],
    controller: ['$element', '$scope', '$attrs', function($element, $scope, $attrs) {
      var self = this,
          optionsMap = {},
          ngModelCtrl = nullModelCtrl,
          nullOption,
          unknownOption;


      self.databound = $attrs.ngModel;


      self.init = function(ngModelCtrl_, nullOption_, unknownOption_) {
        ngModelCtrl = ngModelCtrl_;
        nullOption = nullOption_;
        unknownOption = unknownOption_;
      };


      self.addOption = function(value, element) {
        assertNotHasOwnProperty(value, '"option value"');
        optionsMap[value] = true;

        if (ngModelCtrl.$viewValue == value) {
          $element.val(value);
          if (unknownOption.parent()) unknownOption.remove();
        }
        // Workaround for https://code.google.com/p/chromium/issues/detail?id=381459
        // Adding an <option selected="selected"> element to a <select required="required"> should
        // automatically select the new element
        if (element && element[0].hasAttribute('selected')) {
          element[0].selected = true;
        }
      };


      self.removeOption = function(value) {
        if (this.hasOption(value)) {
          delete optionsMap[value];
          if (ngModelCtrl.$viewValue === value) {
            this.renderUnknownOption(value);
          }
        }
      };


      self.renderUnknownOption = function(val) {
        var unknownVal = '? ' + hashKey(val) + ' ?';
        unknownOption.val(unknownVal);
        $element.prepend(unknownOption);
        $element.val(unknownVal);
        unknownOption.prop('selected', true); // needed for IE
      };


      self.hasOption = function(value) {
        return optionsMap.hasOwnProperty(value);
      };

      $scope.$on('$destroy', function() {
        // disable unknown option so that we don't do work when the whole select is being destroyed
        self.renderUnknownOption = noop;
      });
    }],

    link: function(scope, element, attr, ctrls) {
      // if ngModel is not defined, we don't need to do anything
      if (!ctrls[1]) return;

      var selectCtrl = ctrls[0],
          ngModelCtrl = ctrls[1],
          multiple = attr.multiple,
          optionsExp = attr.ngOptions,
          nullOption = false, // if false, user will not be able to select it (used by ngOptions)
          emptyOption,
          renderScheduled = false,
          // we can't just jqLite('<option>') since jqLite is not smart enough
          // to create it in <select> and IE barfs otherwise.
          optionTemplate = jqLite(document.createElement('option')),
          optGroupTemplate =jqLite(document.createElement('optgroup')),
          unknownOption = optionTemplate.clone();

      // find "null" option
      for (var i = 0, children = element.children(), ii = children.length; i < ii; i++) {
        if (children[i].value === '') {
          emptyOption = nullOption = children.eq(i);
          break;
        }
      }

      selectCtrl.init(ngModelCtrl, nullOption, unknownOption);

      // required validator
      if (multiple) {
        ngModelCtrl.$isEmpty = function(value) {
          return !value || value.length === 0;
        };
      }

      if (optionsExp) setupAsOptions(scope, element, ngModelCtrl);
      else if (multiple) setupAsMultiple(scope, element, ngModelCtrl);
      else setupAsSingle(scope, element, ngModelCtrl, selectCtrl);


      ////////////////////////////



      function setupAsSingle(scope, selectElement, ngModelCtrl, selectCtrl) {
        ngModelCtrl.$render = function() {
          var viewValue = ngModelCtrl.$viewValue;

          if (selectCtrl.hasOption(viewValue)) {
            if (unknownOption.parent()) unknownOption.remove();
            selectElement.val(viewValue);
            if (viewValue === '') emptyOption.prop('selected', true); // to make IE9 happy
          } else {
            if (viewValue == null && emptyOption) {
              selectElement.val('');
            } else {
              selectCtrl.renderUnknownOption(viewValue);
            }
          }
        };

        selectElement.on('change', function() {
          scope.$apply(function() {
            if (unknownOption.parent()) unknownOption.remove();
            ngModelCtrl.$setViewValue(selectElement.val());
          });
        });
      }

      function setupAsMultiple(scope, selectElement, ctrl) {
        var lastView;
        ctrl.$render = function() {
          var items = new HashMap(ctrl.$viewValue);
          forEach(selectElement.find('option'), function(option) {
            option.selected = isDefined(items.get(option.value));
          });
        };

        // we have to do it on each watch since ngModel watches reference, but
        // we need to work of an array, so we need to see if anything was inserted/removed
        scope.$watch(function selectMultipleWatch() {
          if (!equals(lastView, ctrl.$viewValue)) {
            lastView = shallowCopy(ctrl.$viewValue);
            ctrl.$render();
          }
        });

        selectElement.on('change', function() {
          scope.$apply(function() {
            var array = [];
            forEach(selectElement.find('option'), function(option) {
              if (option.selected) {
                array.push(option.value);
              }
            });
            ctrl.$setViewValue(array);
          });
        });
      }

      function setupAsOptions(scope, selectElement, ctrl) {
        var match;

        if (!(match = optionsExp.match(NG_OPTIONS_REGEXP))) {
          throw ngOptionsMinErr('iexp',
            "Expected expression in form of " +
            "'_select_ (as _label_)? for (_key_,)?_value_ in _collection_'" +
            " but got '{0}'. Element: {1}",
            optionsExp, startingTag(selectElement));
        }

        var displayFn = $parse(match[2] || match[1]),
            valueName = match[4] || match[6],
            selectAs = / as /.test(match[0]) && match[1],
            selectAsFn = selectAs ? $parse(selectAs) : null,
            keyName = match[5],
            groupByFn = $parse(match[3] || ''),
            valueFn = $parse(match[2] ? match[1] : valueName),
            valuesFn = $parse(match[7]),
            track = match[8],
            trackFn = track ? $parse(match[8]) : null,
            trackKeysCache = {},
            // This is an array of array of existing option groups in DOM.
            // We try to reuse these if possible
            // - optionGroupsCache[0] is the options with no option group
            // - optionGroupsCache[?][0] is the parent: either the SELECT or OPTGROUP element
            optionGroupsCache = [[{element: selectElement, label:''}]],
            //re-usable object to represent option's locals
            locals = {};

        if (nullOption) {
          // compile the element since there might be bindings in it
          $compile(nullOption)(scope);

          // remove the class, which is added automatically because we recompile the element and it
          // becomes the compilation root
          nullOption.removeClass('ng-scope');

          // we need to remove it before calling selectElement.empty() because otherwise IE will
          // remove the label from the element. wtf?
          nullOption.remove();
        }

        // clear contents, we'll add what's needed based on the model
        selectElement.empty();

        selectElement.on('change', selectionChanged);

        ctrl.$render = render;

        scope.$watchCollection(valuesFn, scheduleRendering);
        scope.$watchCollection(getLabels, scheduleRendering);

        if (multiple) {
          scope.$watchCollection(function() { return ctrl.$modelValue; }, scheduleRendering);
        }

        // ------------------------------------------------------------------ //

        function callExpression(exprFn, key, value) {
          locals[valueName] = value;
          if (keyName) locals[keyName] = key;
          return exprFn(scope, locals);
        }

        function selectionChanged() {
          scope.$apply(function() {
            var collection = valuesFn(scope) || [];
            var viewValue;
            if (multiple) {
              viewValue = [];
              forEach(selectElement.val(), function(selectedKey) {
                  selectedKey = trackFn ? trackKeysCache[selectedKey] : selectedKey;
                viewValue.push(getViewValue(selectedKey, collection[selectedKey]));
              });
            } else {
              var selectedKey = trackFn ? trackKeysCache[selectElement.val()] : selectElement.val();
              viewValue = getViewValue(selectedKey, collection[selectedKey]);
            }
            ctrl.$setViewValue(viewValue);
            render();
          });
        }

        function getViewValue(key, value) {
          if (key === '?') {
            return undefined;
          } else if (key === '') {
            return null;
          } else {
            var viewValueFn = selectAsFn ? selectAsFn : valueFn;
            return callExpression(viewValueFn, key, value);
          }
        }

        function getLabels() {
          var values = valuesFn(scope);
          var toDisplay;
          if (values && isArray(values)) {
            toDisplay = new Array(values.length);
            for (var i = 0, ii = values.length; i < ii; i++) {
              toDisplay[i] = callExpression(displayFn, i, values[i]);
            }
            return toDisplay;
          } else if (values) {
            // TODO: Add a test for this case
            toDisplay = {};
            for (var prop in values) {
              if (values.hasOwnProperty(prop)) {
                toDisplay[prop] = callExpression(displayFn, prop, values[prop]);
              }
            }
          }
          return toDisplay;
        }

        function createIsSelectedFn(viewValue) {
          var selectedSet;
          if (multiple) {
            if (trackFn && isArray(viewValue)) {

              selectedSet = new HashMap([]);
              for (var trackIndex = 0; trackIndex < viewValue.length; trackIndex++) {
                // tracking by key
                selectedSet.put(callExpression(trackFn, null, viewValue[trackIndex]), true);
              }
            } else {
              selectedSet = new HashMap(viewValue);
            }
          } else if (trackFn) {
            viewValue = callExpression(trackFn, null, viewValue);
          }

          return function isSelected(key, value) {
            var compareValueFn;
            if (trackFn) {
              compareValueFn = trackFn;
            } else if (selectAsFn) {
              compareValueFn = selectAsFn;
            } else {
              compareValueFn = valueFn;
            }

            if (multiple) {
              return isDefined(selectedSet.remove(callExpression(compareValueFn, key, value)));
            } else {
              return viewValue === callExpression(compareValueFn, key, value);
            }
          };
        }

        function scheduleRendering() {
          if (!renderScheduled) {
            scope.$$postDigest(render);
            renderScheduled = true;
          }
        }

        /**
         * A new labelMap is created with each render.
         * This function is called for each existing option with added=false,
         * and each new option with added=true.
         * - Labels that are passed to this method twice,
         * (once with added=true and once with added=false) will end up with a value of 0, and
         * will cause no change to happen to the corresponding option.
         * - Labels that are passed to this method only once with added=false will end up with a
         * value of -1 and will eventually be passed to selectCtrl.removeOption()
         * - Labels that are passed to this method only once with added=true will end up with a
         * value of 1 and will eventually be passed to selectCtrl.addOption()
        */
        function updateLabelMap(labelMap, label, added) {
          labelMap[label] = labelMap[label] || 0;
          labelMap[label] += (added ? 1 : -1);
        }

        function render() {
          renderScheduled = false;

          // Temporary location for the option groups before we render them
          var optionGroups = {'':[]},
              optionGroupNames = [''],
              optionGroupName,
              optionGroup,
              option,
              existingParent, existingOptions, existingOption,
              viewValue = ctrl.$viewValue,
              values = valuesFn(scope) || [],
              keys = keyName ? sortedKeys(values) : values,
              key,
              value,
              groupLength, length,
              groupIndex, index,
              labelMap = {},
              selected,
              isSelected = createIsSelectedFn(viewValue),
              anySelected = false,
              lastElement,
              element,
              label,
              optionId;

          trackKeysCache = {};

          // We now build up the list of options we need (we merge later)
          for (index = 0; length = keys.length, index < length; index++) {
            key = index;
            if (keyName) {
              key = keys[index];
              if (key.charAt(0) === '$') continue;
            }
            value = values[key];

            optionGroupName = callExpression(groupByFn, key, value) || '';
            if (!(optionGroup = optionGroups[optionGroupName])) {
              optionGroup = optionGroups[optionGroupName] = [];
              optionGroupNames.push(optionGroupName);
            }

            selected = isSelected(key, value);
            anySelected = anySelected || selected;

            label = callExpression(displayFn, key, value); // what will be seen by the user

            // doing displayFn(scope, locals) || '' overwrites zero values
            label = isDefined(label) ? label : '';
            optionId = trackFn ? trackFn(scope, locals) : (keyName ? keys[index] : index);
            if (trackFn) {
              trackKeysCache[optionId] = key;
            }

            optionGroup.push({
              // either the index into array or key from object
              id: optionId,
              label: label,
              selected: selected                   // determine if we should be selected
            });
          }
          if (!multiple) {
            if (nullOption || viewValue === null) {
              // insert null option if we have a placeholder, or the model is null
              optionGroups[''].unshift({id:'', label:'', selected:!anySelected});
            } else if (!anySelected) {
              // option could not be found, we have to insert the undefined item
              optionGroups[''].unshift({id:'?', label:'', selected:true});
            }
          }

          // Now we need to update the list of DOM nodes to match the optionGroups we computed above
          for (groupIndex = 0, groupLength = optionGroupNames.length;
               groupIndex < groupLength;
               groupIndex++) {
            // current option group name or '' if no group
            optionGroupName = optionGroupNames[groupIndex];

            // list of options for that group. (first item has the parent)
            optionGroup = optionGroups[optionGroupName];

            if (optionGroupsCache.length <= groupIndex) {
              // we need to grow the optionGroups
              existingParent = {
                element: optGroupTemplate.clone().attr('label', optionGroupName),
                label: optionGroup.label
              };
              existingOptions = [existingParent];
              optionGroupsCache.push(existingOptions);
              selectElement.append(existingParent.element);
            } else {
              existingOptions = optionGroupsCache[groupIndex];
              existingParent = existingOptions[0];  // either SELECT (no group) or OPTGROUP element

              // update the OPTGROUP label if not the same.
              if (existingParent.label != optionGroupName) {
                existingParent.element.attr('label', existingParent.label = optionGroupName);
              }
            }

            lastElement = null;  // start at the beginning
            for (index = 0, length = optionGroup.length; index < length; index++) {
              option = optionGroup[index];
              if ((existingOption = existingOptions[index + 1])) {
                // reuse elements
                lastElement = existingOption.element;
                if (existingOption.label !== option.label) {
                  updateLabelMap(labelMap, existingOption.label, false);
                  updateLabelMap(labelMap, option.label, true);
                  lastElement.text(existingOption.label = option.label);
                  lastElement.prop('label', existingOption.label);
                }
                if (existingOption.id !== option.id) {
                  lastElement.val(existingOption.id = option.id);
                }
                // lastElement.prop('selected') provided by jQuery has side-effects
                if (lastElement[0].selected !== option.selected) {
                  lastElement.prop('selected', (existingOption.selected = option.selected));
                  if (msie) {
                    // See #7692
                    // The selected item wouldn't visually update on IE without this.
                    // Tested on Win7: IE9, IE10 and IE11. Future IEs should be tested as well
                    lastElement.prop('selected', existingOption.selected);
                  }
                }
              } else {
                // grow elements

                // if it's a null option
                if (option.id === '' && nullOption) {
                  // put back the pre-compiled element
                  element = nullOption;
                } else {
                  // jQuery(v1.4.2) Bug: We should be able to chain the method calls, but
                  // in this version of jQuery on some browser the .text() returns a string
                  // rather then the element.
                  (element = optionTemplate.clone())
                      .val(option.id)
                      .prop('selected', option.selected)
                      .attr('selected', option.selected)
                      .prop('label', option.label)
                      .text(option.label);
                }

                existingOptions.push(existingOption = {
                    element: element,
                    label: option.label,
                    id: option.id,
                    selected: option.selected
                });
                updateLabelMap(labelMap, option.label, true);
                if (lastElement) {
                  lastElement.after(element);
                } else {
                  existingParent.element.append(element);
                }
                lastElement = element;
              }
            }
            // remove any excessive OPTIONs in a group
            index++; // increment since the existingOptions[0] is parent element not OPTION
            while (existingOptions.length > index) {
              option = existingOptions.pop();
              updateLabelMap(labelMap, option.label, false);
              option.element.remove();
            }
          }
          // remove any excessive OPTGROUPs from select
          while (optionGroupsCache.length > groupIndex) {
            // remove all the labels in the option group
            optionGroup = optionGroupsCache.pop();
            for (index = 1; index < optionGroup.length; ++index) {
              updateLabelMap(labelMap, optionGroup[index].label, false);
            }
            optionGroup[0].element.remove();
          }
          forEach(labelMap, function(count, label) {
            if (count > 0) {
              selectCtrl.addOption(label);
            } else if (count < 0) {
              selectCtrl.removeOption(label);
            }
          });
        }
      }
    }
  };
}];

var optionDirective = ['$interpolate', function($interpolate) {
  var nullSelectCtrl = {
    addOption: noop,
    removeOption: noop
  };

  return {
    restrict: 'E',
    priority: 100,
    compile: function(element, attr) {
      if (isUndefined(attr.value)) {
        var interpolateFn = $interpolate(element.text(), true);
        if (!interpolateFn) {
          attr.$set('value', element.text());
        }
      }

      return function(scope, element, attr) {
        var selectCtrlName = '$selectController',
            parent = element.parent(),
            selectCtrl = parent.data(selectCtrlName) ||
              parent.parent().data(selectCtrlName); // in case we are in optgroup

        if (!selectCtrl || !selectCtrl.databound) {
          selectCtrl = nullSelectCtrl;
        }

        if (interpolateFn) {
          scope.$watch(interpolateFn, function interpolateWatchAction(newVal, oldVal) {
            attr.$set('value', newVal);
            if (oldVal !== newVal) {
              selectCtrl.removeOption(oldVal);
            }
            selectCtrl.addOption(newVal, element);
          });
        } else {
          selectCtrl.addOption(attr.value, element);
        }

        element.on('$destroy', function() {
          selectCtrl.removeOption(attr.value);
        });
      };
    }
  };
}];

var styleDirective = valueFn({
  restrict: 'E',
  terminal: false
});

var requiredDirective = function() {
  return {
    restrict: 'A',
    require: '?ngModel',
    link: function(scope, elm, attr, ctrl) {
      if (!ctrl) return;
      attr.required = true; // force truthy in case we are on non input element

      ctrl.$validators.required = function(modelValue, viewValue) {
        return !attr.required || !ctrl.$isEmpty(viewValue);
      };

      attr.$observe('required', function() {
        ctrl.$validate();
      });
    }
  };
};


var patternDirective = function() {
  return {
    restrict: 'A',
    require: '?ngModel',
    link: function(scope, elm, attr, ctrl) {
      if (!ctrl) return;

      var regexp, patternExp = attr.ngPattern || attr.pattern;
      attr.$observe('pattern', function(regex) {
        if (isString(regex) && regex.length > 0) {
          regex = new RegExp('^' + regex + '$');
        }

        if (regex && !regex.test) {
          throw minErr('ngPattern')('noregexp',
            'Expected {0} to be a RegExp but was {1}. Element: {2}', patternExp,
            regex, startingTag(elm));
        }

        regexp = regex || undefined;
        ctrl.$validate();
      });

      ctrl.$validators.pattern = function(modelValue, viewValue) {
        // HTML5 pattern constraint validates the input value, so we validate the viewValue
        return ctrl.$isEmpty(viewValue) || isUndefined(regexp) || regexp.test(viewValue);
      };
    }
  };
};


var maxlengthDirective = function() {
  return {
    restrict: 'A',
    require: '?ngModel',
    link: function(scope, elm, attr, ctrl) {
      if (!ctrl) return;

      var maxlength = -1;
      attr.$observe('maxlength', function(value) {
        var intVal = int(value);
        maxlength = isNaN(intVal) ? -1 : intVal;
        ctrl.$validate();
      });
      ctrl.$validators.maxlength = function(modelValue, viewValue) {
        return (maxlength < 0) || ctrl.$isEmpty(viewValue) || (viewValue.length <= maxlength);
      };
    }
  };
};

var minlengthDirective = function() {
  return {
    restrict: 'A',
    require: '?ngModel',
    link: function(scope, elm, attr, ctrl) {
      if (!ctrl) return;

      var minlength = 0;
      attr.$observe('minlength', function(value) {
        minlength = int(value) || 0;
        ctrl.$validate();
      });
      ctrl.$validators.minlength = function(modelValue, viewValue) {
        return ctrl.$isEmpty(viewValue) || viewValue.length >= minlength;
      };
    }
  };
};

  if (window.angular.bootstrap) {
    //AngularJS is already loaded, so we can return here...
    console.log('WARNING: Tried to load angular more than once.');
    return;
  }

  //try to bind to jquery now so that one can write jqLite(document).ready()
  //but we will rebind on bootstrap again.
  bindJQuery();

  publishExternalAPI(angular);

  jqLite(document).ready(function() {
    angularInit(document, bootstrap);
  });

})(window, document);

!window.angular.$$csp() && window.angular.element(document.head).prepend('<style type="text/css">@charset "UTF-8";[ng\\:cloak],[ng-cloak],[data-ng-cloak],[x-ng-cloak],.ng-cloak,.x-ng-cloak,.ng-hide:not(.ng-hide-animate){display:none !important;}ng\\:form{display:block;}</style>');
/*
 * angular-ui-bootstrap
 * http://angular-ui.github.io/bootstrap/

 * Version: 0.13.4 - 2015-09-03
 * License: MIT
 */
angular.module("ui.bootstrap", ["ui.bootstrap.tpls", "ui.bootstrap.collapse","ui.bootstrap.accordion","ui.bootstrap.alert","ui.bootstrap.bindHtml","ui.bootstrap.buttons","ui.bootstrap.carousel","ui.bootstrap.dateparser","ui.bootstrap.position","ui.bootstrap.datepicker","ui.bootstrap.dropdown","ui.bootstrap.modal","ui.bootstrap.pagination","ui.bootstrap.tooltip","ui.bootstrap.popover","ui.bootstrap.progressbar","ui.bootstrap.rating","ui.bootstrap.tabs","ui.bootstrap.timepicker","ui.bootstrap.transition","ui.bootstrap.typeahead"]);
angular.module("ui.bootstrap.tpls", ["template/accordion/accordion-group.html","template/accordion/accordion.html","template/alert/alert.html","template/carousel/carousel.html","template/carousel/slide.html","template/datepicker/datepicker.html","template/datepicker/day.html","template/datepicker/month.html","template/datepicker/popup.html","template/datepicker/year.html","template/modal/backdrop.html","template/modal/window.html","template/pagination/pager.html","template/pagination/pagination.html","template/tooltip/tooltip-html-popup.html","template/tooltip/tooltip-html-unsafe-popup.html","template/tooltip/tooltip-popup.html","template/tooltip/tooltip-template-popup.html","template/popover/popover-html.html","template/popover/popover-template.html","template/popover/popover.html","template/progressbar/bar.html","template/progressbar/progress.html","template/progressbar/progressbar.html","template/rating/rating.html","template/tabs/tab.html","template/tabs/tabset.html","template/timepicker/timepicker.html","template/typeahead/typeahead-match.html","template/typeahead/typeahead-popup.html"]);
angular.module('ui.bootstrap.collapse', [])

  .directive('collapse', ['$animate', function($animate) {
    return {
      link: function(scope, element, attrs) {
        function expand() {
          element.removeClass('collapse')
            .addClass('collapsing')
            .attr('aria-expanded', true)
            .attr('aria-hidden', false);

          $animate.addClass(element, 'in', {
            to: { height: element[0].scrollHeight + 'px' }
          }).then(expandDone);
        }

        function expandDone() {
          element.removeClass('collapsing');
          element.css({height: 'auto'});
        }

        function collapse() {
          if (!element.hasClass('collapse') && !element.hasClass('in')) {
            return collapseDone();
          }

          element
            // IMPORTANT: The height must be set before adding "collapsing" class.
            // Otherwise, the browser attempts to animate from height 0 (in
            // collapsing class) to the given height here.
            .css({height: element[0].scrollHeight + 'px'})
            // initially all panel collapse have the collapse class, this removal
            // prevents the animation from jumping to collapsed state
            .removeClass('collapse')
            .addClass('collapsing')
            .attr('aria-expanded', false)
            .attr('aria-hidden', true);

          $animate.removeClass(element, 'in', {
            to: {height: '0'}
          }).then(collapseDone);
        }

        function collapseDone() {
          element.css({height: '0'}); // Required so that collapse works when animation is disabled
          element.removeClass('collapsing');
          element.addClass('collapse');
        }

        scope.$watch(attrs.collapse, function(shouldCollapse) {
          if (shouldCollapse) {
            collapse();
          } else {
            expand();
          }
        });
      }
    };
  }]);

angular.module('ui.bootstrap.accordion', ['ui.bootstrap.collapse'])

.constant('accordionConfig', {
  closeOthers: true
})

.controller('AccordionController', ['$scope', '$attrs', 'accordionConfig', function($scope, $attrs, accordionConfig) {
  // This array keeps track of the accordion groups
  this.groups = [];

  // Ensure that all the groups in this accordion are closed, unless close-others explicitly says not to
  this.closeOthers = function(openGroup) {
    var closeOthers = angular.isDefined($attrs.closeOthers) ?
      $scope.$eval($attrs.closeOthers) : accordionConfig.closeOthers;
    if (closeOthers) {
      angular.forEach(this.groups, function(group) {
        if (group !== openGroup) {
          group.isOpen = false;
        }
      });
    }
  };

  // This is called from the accordion-group directive to add itself to the accordion
  this.addGroup = function(groupScope) {
    var that = this;
    this.groups.push(groupScope);

    groupScope.$on('$destroy', function(event) {
      that.removeGroup(groupScope);
    });
  };

  // This is called from the accordion-group directive when to remove itself
  this.removeGroup = function(group) {
    var index = this.groups.indexOf(group);
    if (index !== -1) {
      this.groups.splice(index, 1);
    }
  };

}])

// The accordion directive simply sets up the directive controller
// and adds an accordion CSS class to itself element.
.directive('accordion', function() {
  return {
    restrict: 'EA',
    controller: 'AccordionController',
    controllerAs: 'accordion',
    transclude: true,
    replace: false,
    templateUrl: function(element, attrs) {
      return attrs.templateUrl || 'template/accordion/accordion.html';
    }
  };
})

// The accordion-group directive indicates a block of html that will expand and collapse in an accordion
.directive('accordionGroup', function() {
  return {
    require: '^accordion',         // We need this directive to be inside an accordion
    restrict: 'EA',
    transclude: true,              // It transcludes the contents of the directive into the template
    replace: true,                // The element containing the directive will be replaced with the template
    templateUrl: function(element, attrs) {
      return attrs.templateUrl || 'template/accordion/accordion-group.html';
    },
    scope: {
      heading: '@',               // Interpolate the heading attribute onto this scope
      isOpen: '=?',
      isDisabled: '=?'
    },
    controller: function() {
      this.setHeading = function(element) {
        this.heading = element;
      };
    },
    link: function(scope, element, attrs, accordionCtrl) {
      accordionCtrl.addGroup(scope);

      scope.openClass = attrs.openClass || 'panel-open';
      scope.panelClass = attrs.panelClass;
      scope.$watch('isOpen', function(value) {
        element.toggleClass(scope.openClass, value);
        if (value) {
          accordionCtrl.closeOthers(scope);
        }
      });

      scope.toggleOpen = function($event) {
        if (!scope.isDisabled) {
          if (!$event || $event.which === 32) {
            scope.isOpen = !scope.isOpen;
          }
        }
      };
    }
  };
})

// Use accordion-heading below an accordion-group to provide a heading containing HTML
// <accordion-group>
//   <accordion-heading>Heading containing HTML - <img src="..."></accordion-heading>
// </accordion-group>
.directive('accordionHeading', function() {
  return {
    restrict: 'EA',
    transclude: true,   // Grab the contents to be used as the heading
    template: '',       // In effect remove this element!
    replace: true,
    require: '^accordionGroup',
    link: function(scope, element, attr, accordionGroupCtrl, transclude) {
      // Pass the heading to the accordion-group controller
      // so that it can be transcluded into the right place in the template
      // [The second parameter to transclude causes the elements to be cloned so that they work in ng-repeat]
      accordionGroupCtrl.setHeading(transclude(scope, angular.noop));
    }
  };
})

// Use in the accordion-group template to indicate where you want the heading to be transcluded
// You must provide the property on the accordion-group controller that will hold the transcluded element
// <div class="accordion-group">
//   <div class="accordion-heading" ><a ... accordion-transclude="heading">...</a></div>
//   ...
// </div>
.directive('accordionTransclude', function() {
  return {
    require: '^accordionGroup',
    link: function(scope, element, attr, controller) {
      scope.$watch(function() { return controller[attr.accordionTransclude]; }, function(heading) {
        if (heading) {
          element.find('span').html('');
          element.find('span').append(heading);
        }
      });
    }
  };
})

;

angular.module('ui.bootstrap.alert', [])

.controller('AlertController', ['$scope', '$attrs', function($scope, $attrs) {
  $scope.closeable = !!$attrs.close;
  this.close = $scope.close;
}])

.directive('alert', function() {
  return {
    controller: 'AlertController',
    controllerAs: 'alert',
    templateUrl: function(element, attrs) {
      return attrs.templateUrl || 'template/alert/alert.html';
    },
    transclude: true,
    replace: true,
    scope: {
      type: '@',
      close: '&'
    }
  };
})

.directive('dismissOnTimeout', ['$timeout', function($timeout) {
  return {
    require: 'alert',
    link: function(scope, element, attrs, alertCtrl) {
      $timeout(function() {
        alertCtrl.close();
      }, parseInt(attrs.dismissOnTimeout, 10));
    }
  };
}]);

angular.module('ui.bootstrap.bindHtml', [])

  .value('$bindHtmlUnsafeSuppressDeprecated', false)

  .directive('bindHtmlUnsafe', ['$log', '$bindHtmlUnsafeSuppressDeprecated', function ($log, $bindHtmlUnsafeSuppressDeprecated) {
    return function (scope, element, attr) {
      if (!$bindHtmlUnsafeSuppressDeprecated) {
        $log.warn('bindHtmlUnsafe is now deprecated. Use ngBindHtml instead');
      }
      element.addClass('ng-binding').data('$binding', attr.bindHtmlUnsafe);
      scope.$watch(attr.bindHtmlUnsafe, function bindHtmlUnsafeWatchAction(value) {
        element.html(value || '');
      });
    };
  }]);
angular.module('ui.bootstrap.buttons', [])

.constant('buttonConfig', {
  activeClass: 'active',
  toggleEvent: 'click'
})

.controller('ButtonsController', ['buttonConfig', function(buttonConfig) {
  this.activeClass = buttonConfig.activeClass || 'active';
  this.toggleEvent = buttonConfig.toggleEvent || 'click';
}])

.directive('btnRadio', function() {
  return {
    require: ['btnRadio', 'ngModel'],
    controller: 'ButtonsController',
    controllerAs: 'buttons',
    link: function(scope, element, attrs, ctrls) {
      var buttonsCtrl = ctrls[0], ngModelCtrl = ctrls[1];

      element.find('input').css({display: 'none'});

      //model -> UI
      ngModelCtrl.$render = function() {
        element.toggleClass(buttonsCtrl.activeClass, angular.equals(ngModelCtrl.$modelValue, scope.$eval(attrs.btnRadio)));
      };

      //ui->model
      element.bind(buttonsCtrl.toggleEvent, function() {
        if (attrs.disabled) {
          return;
        }

        var isActive = element.hasClass(buttonsCtrl.activeClass);

        if (!isActive || angular.isDefined(attrs.uncheckable)) {
          scope.$apply(function() {
            ngModelCtrl.$setViewValue(isActive ? null : scope.$eval(attrs.btnRadio));
            ngModelCtrl.$render();
          });
        }
      });
    }
  };
})

.directive('btnCheckbox', ['$document', function($document) {
  return {
    require: ['btnCheckbox', 'ngModel'],
    controller: 'ButtonsController',
    controllerAs: 'button',
    link: function(scope, element, attrs, ctrls) {
      var buttonsCtrl = ctrls[0], ngModelCtrl = ctrls[1];

      element.find('input').css({display: 'none'});

      function getTrueValue() {
        return getCheckboxValue(attrs.btnCheckboxTrue, true);
      }

      function getFalseValue() {
        return getCheckboxValue(attrs.btnCheckboxFalse, false);
      }

      function getCheckboxValue(attributeValue, defaultValue) {
        var val = scope.$eval(attributeValue);
        return angular.isDefined(val) ? val : defaultValue;
      }

      //model -> UI
      ngModelCtrl.$render = function() {
        element.toggleClass(buttonsCtrl.activeClass, angular.equals(ngModelCtrl.$modelValue, getTrueValue()));
      };

      //ui->model
      element.bind(buttonsCtrl.toggleEvent, function() {
        if (attrs.disabled) {
          return;
        }

        scope.$apply(function() {
          ngModelCtrl.$setViewValue(element.hasClass(buttonsCtrl.activeClass) ? getFalseValue() : getTrueValue());
          ngModelCtrl.$render();
        });
      });

      //accessibility
      element.on('keypress', function(e) {
        if (attrs.disabled || e.which !== 32 || $document[0].activeElement !== element[0]) {
          return;
        }

        scope.$apply(function() {
          ngModelCtrl.$setViewValue(element.hasClass(buttonsCtrl.activeClass) ? getFalseValue() : getTrueValue());
          ngModelCtrl.$render();
        });
      });
    }
  };
}]);

/**
* @ngdoc overview
* @name ui.bootstrap.carousel
*
* @description
* AngularJS version of an image carousel.
*
*/
angular.module('ui.bootstrap.carousel', [])
.controller('CarouselController', ['$scope', '$element', '$interval', '$animate', function ($scope, $element, $interval, $animate) {
  var self = this,
    slides = self.slides = $scope.slides = [],
    NEW_ANIMATE = angular.version.minor >= 4,
    NO_TRANSITION = 'uib-noTransition',
    SLIDE_DIRECTION = 'uib-slideDirection',
    currentIndex = -1,
    currentInterval, isPlaying;
  self.currentSlide = null;

  var destroyed = false;
  /* direction: "prev" or "next" */
  self.select = $scope.select = function(nextSlide, direction) {
    var nextIndex = $scope.indexOfSlide(nextSlide);
    //Decide direction if it's not given
    if (direction === undefined) {
      direction = nextIndex > self.getCurrentIndex() ? 'next' : 'prev';
    }
    //Prevent this user-triggered transition from occurring if there is already one in progress
    if (nextSlide && nextSlide !== self.currentSlide && !$scope.$currentTransition) {
      goNext(nextSlide, nextIndex, direction);
    }
  };

  function goNext(slide, index, direction) {
    // Scope has been destroyed, stop here.
    if (destroyed) { return; }

    angular.extend(slide, {direction: direction, active: true});
    angular.extend(self.currentSlide || {}, {direction: direction, active: false});
    if ($animate.enabled() && !$scope.noTransition && !$scope.$currentTransition &&
      slide.$element && self.slides.length > 1) {
      slide.$element.data(SLIDE_DIRECTION, slide.direction);
      if (self.currentSlide && self.currentSlide.$element) {
        self.currentSlide.$element.data(SLIDE_DIRECTION, slide.direction);
      }

      $scope.$currentTransition = true;
      if (NEW_ANIMATE) {
        $animate.on('addClass', slide.$element, function (element, phase) {
          if (phase === 'close') {
            $scope.$currentTransition = null;
            $animate.off('addClass', element);
          }
        });
      } else {
        slide.$element.one('$animate:close', function closeFn() {
          $scope.$currentTransition = null;
        });
      }
    }

    self.currentSlide = slide;
    currentIndex = index;

    //every time you change slides, reset the timer
    restartTimer();
  }

  $scope.$on('$destroy', function () {
    destroyed = true;
  });

  function getSlideByIndex(index) {
    if (angular.isUndefined(slides[index].index)) {
      return slides[index];
    }
    var i, len = slides.length;
    for (i = 0; i < slides.length; ++i) {
      if (slides[i].index == index) {
        return slides[i];
      }
    }
  }

  self.getCurrentIndex = function() {
    if (self.currentSlide && angular.isDefined(self.currentSlide.index)) {
      return +self.currentSlide.index;
    }
    return currentIndex;
  };

  /* Allow outside people to call indexOf on slides array */
  $scope.indexOfSlide = function(slide) {
    return angular.isDefined(slide.index) ? +slide.index : slides.indexOf(slide);
  };

  $scope.next = function() {
    var newIndex = (self.getCurrentIndex() + 1) % slides.length;

    if (newIndex === 0 && $scope.noWrap()) {
      $scope.pause();
      return;
    }

    return self.select(getSlideByIndex(newIndex), 'next');
  };

  $scope.prev = function() {
    var newIndex = self.getCurrentIndex() - 1 < 0 ? slides.length - 1 : self.getCurrentIndex() - 1;

    if ($scope.noWrap() && newIndex === slides.length - 1){
      $scope.pause();
      return;
    }

    return self.select(getSlideByIndex(newIndex), 'prev');
  };

  $scope.isActive = function(slide) {
     return self.currentSlide === slide;
  };

  $scope.$watch('interval', restartTimer);
  $scope.$on('$destroy', resetTimer);

  function restartTimer() {
    resetTimer();
    var interval = +$scope.interval;
    if (!isNaN(interval) && interval > 0) {
      currentInterval = $interval(timerFn, interval);
    }
  }

  function resetTimer() {
    if (currentInterval) {
      $interval.cancel(currentInterval);
      currentInterval = null;
    }
  }

  function timerFn() {
    var interval = +$scope.interval;
    if (isPlaying && !isNaN(interval) && interval > 0 && slides.length) {
      $scope.next();
    } else {
      $scope.pause();
    }
  }

  $scope.play = function() {
    if (!isPlaying) {
      isPlaying = true;
      restartTimer();
    }
  };
  $scope.pause = function() {
    if (!$scope.noPause) {
      isPlaying = false;
      resetTimer();
    }
  };

  self.addSlide = function(slide, element) {
    slide.$element = element;
    slides.push(slide);
    //if this is the first slide or the slide is set to active, select it
    if(slides.length === 1 || slide.active) {
      self.select(slides[slides.length-1]);
      if (slides.length == 1) {
        $scope.play();
      }
    } else {
      slide.active = false;
    }
  };

  self.removeSlide = function(slide) {
    if (angular.isDefined(slide.index)) {
      slides.sort(function(a, b) {
        return +a.index > +b.index;
      });
    }
    //get the index of the slide inside the carousel
    var index = slides.indexOf(slide);
    slides.splice(index, 1);
    if (slides.length > 0 && slide.active) {
      if (index >= slides.length) {
        self.select(slides[index-1]);
      } else {
        self.select(slides[index]);
      }
    } else if (currentIndex > index) {
      currentIndex--;
    }
    
    //clean the currentSlide when no more slide
    if (slides.length === 0) {
      self.currentSlide = null;
    }
  };

  $scope.$watch('noTransition', function(noTransition) {
    $element.data(NO_TRANSITION, noTransition);
  });

}])

/**
 * @ngdoc directive
 * @name ui.bootstrap.carousel.directive:carousel
 * @restrict EA
 *
 * @description
 * Carousel is the outer container for a set of image 'slides' to showcase.
 *
 * @param {number=} interval The time, in milliseconds, that it will take the carousel to go to the next slide.
 * @param {boolean=} noTransition Whether to disable transitions on the carousel.
 * @param {boolean=} noPause Whether to disable pausing on the carousel (by default, the carousel interval pauses on hover).
 *
 * @example
<example module="ui.bootstrap">
  <file name="index.html">
    <carousel>
      <slide>
        <img src="http://placekitten.com/150/150" style="margin:auto;">
        <div class="carousel-caption">
          <p>Beautiful!</p>
        </div>
      </slide>
      <slide>
        <img src="http://placekitten.com/100/150" style="margin:auto;">
        <div class="carousel-caption">
          <p>D'aww!</p>
        </div>
      </slide>
    </carousel>
  </file>
  <file name="demo.css">
    .carousel-indicators {
      top: auto;
      bottom: 15px;
    }
  </file>
</example>
 */
.directive('carousel', [function() {
  return {
    restrict: 'EA',
    transclude: true,
    replace: true,
    controller: 'CarouselController',
    controllerAs: 'carousel',
    require: 'carousel',
    templateUrl: function(element, attrs) {
      return attrs.templateUrl || 'template/carousel/carousel.html';
    },
    scope: {
      interval: '=',
      noTransition: '=',
      noPause: '=',
      noWrap: '&'
    }
  };
}])

/**
 * @ngdoc directive
 * @name ui.bootstrap.carousel.directive:slide
 * @restrict EA
 *
 * @description
 * Creates a slide inside a {@link ui.bootstrap.carousel.directive:carousel carousel}.  Must be placed as a child of a carousel element.
 *
 * @param {boolean=} active Model binding, whether or not this slide is currently active.
 * @param {number=} index The index of the slide. The slides will be sorted by this parameter.
 *
 * @example
<example module="ui.bootstrap">
  <file name="index.html">
<div ng-controller="CarouselDemoCtrl">
  <carousel>
    <slide ng-repeat="slide in slides" active="slide.active" index="$index">
      <img ng-src="{{slide.image}}" style="margin:auto;">
      <div class="carousel-caption">
        <h4>Slide {{$index}}</h4>
        <p>{{slide.text}}</p>
      </div>
    </slide>
  </carousel>
  Interval, in milliseconds: <input type="number" ng-model="myInterval">
  <br />Enter a negative number to stop the interval.
</div>
  </file>
  <file name="script.js">
function CarouselDemoCtrl($scope) {
  $scope.myInterval = 5000;
}
  </file>
  <file name="demo.css">
    .carousel-indicators {
      top: auto;
      bottom: 15px;
    }
  </file>
</example>
*/

.directive('slide', function() {
  return {
    require: '^carousel',
    restrict: 'EA',
    transclude: true,
    replace: true,
    templateUrl: function(element, attrs) {
      return attrs.templateUrl || 'template/carousel/slide.html';
    },
    scope: {
      active: '=?',
      actual: '=?',
      index: '=?'
    },
    link: function (scope, element, attrs, carouselCtrl) {
      carouselCtrl.addSlide(scope, element);
      //when the scope is destroyed then remove the slide from the current slides array
      scope.$on('$destroy', function() {
        carouselCtrl.removeSlide(scope);
      });

      scope.$watch('active', function(active) {
        if (active) {
          carouselCtrl.select(scope);
        }
      });
    }
  };
})

.animation('.item', [
         '$injector', '$animate',
function ($injector, $animate) {
  var NO_TRANSITION = 'uib-noTransition',
    SLIDE_DIRECTION = 'uib-slideDirection',
    $animateCss = null;

  if ($injector.has('$animateCss')) {
    $animateCss = $injector.get('$animateCss');
  }

  function removeClass(element, className, callback) {
    element.removeClass(className);
    if (callback) {
      callback();
    }
  }

  return {
    beforeAddClass: function (element, className, done) {
      // Due to transclusion, noTransition property is on parent's scope
      if (className == 'active' && element.parent() &&
          !element.parent().data(NO_TRANSITION)) {
        var stopped = false;
        var direction = element.data(SLIDE_DIRECTION);
        var directionClass = direction == 'next' ? 'left' : 'right';
        var removeClassFn = removeClass.bind(this, element,
          directionClass + ' ' + direction, done);
        element.addClass(direction);

        if ($animateCss) {
          $animateCss(element, {addClass: directionClass})
            .start()
            .done(removeClassFn);
        } else {
          $animate.addClass(element, directionClass).then(function () {
            if (!stopped) {
              removeClassFn();
            }
            done();
          });
        }

        return function () {
          stopped = true;
        };
      }
      done();
    },
    beforeRemoveClass: function (element, className, done) {
      // Due to transclusion, noTransition property is on parent's scope
      if (className === 'active' && element.parent() &&
          !element.parent().data(NO_TRANSITION)) {
        var stopped = false;
        var direction = element.data(SLIDE_DIRECTION);
        var directionClass = direction == 'next' ? 'left' : 'right';
        var removeClassFn = removeClass.bind(this, element, directionClass, done);

        if ($animateCss) {
          $animateCss(element, {addClass: directionClass})
            .start()
            .done(removeClassFn);
        } else {
          $animate.addClass(element, directionClass).then(function () {
            if (!stopped) {
              removeClassFn();
            }
            done();
          });
        }
        return function () {
          stopped = true;
        };
      }
      done();
    }
  };

}])


;

angular.module('ui.bootstrap.dateparser', [])

.service('dateParser', ['$log', '$locale', 'orderByFilter', function($log, $locale, orderByFilter) {
  // Pulled from https://github.com/mbostock/d3/blob/master/src/format/requote.js
  var SPECIAL_CHARACTERS_REGEXP = /[\\\^\$\*\+\?\|\[\]\(\)\.\{\}]/g;

  this.parsers = {};

  var formatCodeToRegex = {
    'yyyy': {
      regex: '\\d{4}',
      apply: function(value) { this.year = +value; }
    },
    'yy': {
      regex: '\\d{2}',
      apply: function(value) { this.year = +value + 2000; }
    },
    'y': {
      regex: '\\d{1,4}',
      apply: function(value) { this.year = +value; }
    },
    'MMMM': {
      regex: $locale.DATETIME_FORMATS.MONTH.join('|'),
      apply: function(value) { this.month = $locale.DATETIME_FORMATS.MONTH.indexOf(value); }
    },
    'MMM': {
      regex: $locale.DATETIME_FORMATS.SHORTMONTH.join('|'),
      apply: function(value) { this.month = $locale.DATETIME_FORMATS.SHORTMONTH.indexOf(value); }
    },
    'MM': {
      regex: '0[1-9]|1[0-2]',
      apply: function(value) { this.month = value - 1; }
    },
    'M': {
      regex: '[1-9]|1[0-2]',
      apply: function(value) { this.month = value - 1; }
    },
    'dd': {
      regex: '[0-2][0-9]{1}|3[0-1]{1}',
      apply: function(value) { this.date = +value; }
    },
    'd': {
      regex: '[1-2]?[0-9]{1}|3[0-1]{1}',
      apply: function(value) { this.date = +value; }
    },
    'EEEE': {
      regex: $locale.DATETIME_FORMATS.DAY.join('|')
    },
    'EEE': {
      regex: $locale.DATETIME_FORMATS.SHORTDAY.join('|')
    },
    'HH': {
      regex: '(?:0|1)[0-9]|2[0-3]',
      apply: function(value) { this.hours = +value; }
    },
    'hh': {
      regex: '0[0-9]|1[0-2]',
      apply: function(value) { this.hours = +value; }
    },
    'H': {
      regex: '1?[0-9]|2[0-3]',
      apply: function(value) { this.hours = +value; }
    },
    'h': {
      regex: '[0-9]|1[0-2]',
      apply: function(value) { this.hours = +value; }
    },
    'mm': {
      regex: '[0-5][0-9]',
      apply: function(value) { this.minutes = +value; }
    },
    'm': {
      regex: '[0-9]|[1-5][0-9]',
      apply: function(value) { this.minutes = +value; }
    },
    'sss': {
      regex: '[0-9][0-9][0-9]',
      apply: function(value) { this.milliseconds = +value; }
    },
    'ss': {
      regex: '[0-5][0-9]',
      apply: function(value) { this.seconds = +value; }
    },
    's': {
      regex: '[0-9]|[1-5][0-9]',
      apply: function(value) { this.seconds = +value; }
    },
    'a': {
      regex: $locale.DATETIME_FORMATS.AMPMS.join('|'),
      apply: function(value) {
        if (this.hours === 12) {
          this.hours = 0;
        }

        if (value === 'PM') {
          this.hours += 12;
        }
      }
    }
  };

  function createParser(format) {
    var map = [], regex = format.split('');

    angular.forEach(formatCodeToRegex, function(data, code) {
      var index = format.indexOf(code);

      if (index > -1) {
        format = format.split('');

        regex[index] = '(' + data.regex + ')';
        format[index] = '$'; // Custom symbol to define consumed part of format
        for (var i = index + 1, n = index + code.length; i < n; i++) {
          regex[i] = '';
          format[i] = '$';
        }
        format = format.join('');

        map.push({ index: index, apply: data.apply });
      }
    });

    return {
      regex: new RegExp('^' + regex.join('') + '$'),
      map: orderByFilter(map, 'index')
    };
  }

  this.parse = function(input, format, baseDate) {
    if (!angular.isString(input) || !format) {
      return input;
    }

    format = $locale.DATETIME_FORMATS[format] || format;
    format = format.replace(SPECIAL_CHARACTERS_REGEXP, '\\$&');

    if (!this.parsers[format]) {
      this.parsers[format] = createParser(format);
    }

    var parser = this.parsers[format],
        regex = parser.regex,
        map = parser.map,
        results = input.match(regex);

    if (results && results.length) {
      var fields, dt;
      if (angular.isDate(baseDate) && !isNaN(baseDate.getTime())) {
        fields = {
          year: baseDate.getFullYear(),
          month: baseDate.getMonth(),
          date: baseDate.getDate(),
          hours: baseDate.getHours(),
          minutes: baseDate.getMinutes(),
          seconds: baseDate.getSeconds(),
          milliseconds: baseDate.getMilliseconds()
        };
      } else {
        if (baseDate) {
          $log.warn('dateparser:', 'baseDate is not a valid date');
        }
        fields = { year: 1900, month: 0, date: 1, hours: 0, minutes: 0, seconds: 0, milliseconds: 0 };
      }

      for (var i = 1, n = results.length; i < n; i++) {
        var mapper = map[i-1];
        if (mapper.apply) {
          mapper.apply.call(fields, results[i]);
        }
      }

      if (isValid(fields.year, fields.month, fields.date)) {
        dt = new Date(fields.year, fields.month, fields.date,
          fields.hours, fields.minutes, fields.seconds,
          fields.milliseconds || 0);
      }

      return dt;
    }
  };

  // Check if date is valid for specific month (and year for February).
  // Month: 0 = Jan, 1 = Feb, etc
  function isValid(year, month, date) {
    if (date < 1) {
      return false;
    }

    if (month === 1 && date > 28) {
      return date === 29 && ((year % 4 === 0 && year % 100 !== 0) || year % 400 === 0);
    }

    if (month === 3 || month === 5 || month === 8 || month === 10) {
      return date < 31;
    }

    return true;
  }
}]);

angular.module('ui.bootstrap.position', [])

/**
 * A set of utility methods that can be use to retrieve position of DOM elements.
 * It is meant to be used where we need to absolute-position DOM elements in
 * relation to other, existing elements (this is the case for tooltips, popovers,
 * typeahead suggestions etc.).
 */
  .factory('$position', ['$document', '$window', function($document, $window) {
    function getStyle(el, cssprop) {
      if (el.currentStyle) { //IE
        return el.currentStyle[cssprop];
      } else if ($window.getComputedStyle) {
        return $window.getComputedStyle(el)[cssprop];
      }
      // finally try and get inline style
      return el.style[cssprop];
    }

    /**
     * Checks if a given element is statically positioned
     * @param element - raw DOM element
     */
    function isStaticPositioned(element) {
      return (getStyle(element, 'position') || 'static' ) === 'static';
    }

    /**
     * returns the closest, non-statically positioned parentOffset of a given element
     * @param element
     */
    var parentOffsetEl = function(element) {
      var docDomEl = $document[0];
      var offsetParent = element.offsetParent || docDomEl;
      while (offsetParent && offsetParent !== docDomEl && isStaticPositioned(offsetParent) ) {
        offsetParent = offsetParent.offsetParent;
      }
      return offsetParent || docDomEl;
    };

    return {
      /**
       * Provides read-only equivalent of jQuery's position function:
       * http://api.jquery.com/position/
       */
      position: function(element) {
        var elBCR = this.offset(element);
        var offsetParentBCR = { top: 0, left: 0 };
        var offsetParentEl = parentOffsetEl(element[0]);
        if (offsetParentEl != $document[0]) {
          offsetParentBCR = this.offset(angular.element(offsetParentEl));
          offsetParentBCR.top += offsetParentEl.clientTop - offsetParentEl.scrollTop;
          offsetParentBCR.left += offsetParentEl.clientLeft - offsetParentEl.scrollLeft;
        }

        var boundingClientRect = element[0].getBoundingClientRect();
        return {
          width: boundingClientRect.width || element.prop('offsetWidth'),
          height: boundingClientRect.height || element.prop('offsetHeight'),
          top: elBCR.top - offsetParentBCR.top,
          left: elBCR.left - offsetParentBCR.left
        };
      },

      /**
       * Provides read-only equivalent of jQuery's offset function:
       * http://api.jquery.com/offset/
       */
      offset: function(element) {
        var boundingClientRect = element[0].getBoundingClientRect();
        return {
          width: boundingClientRect.width || element.prop('offsetWidth'),
          height: boundingClientRect.height || element.prop('offsetHeight'),
          top: boundingClientRect.top + ($window.pageYOffset || $document[0].documentElement.scrollTop),
          left: boundingClientRect.left + ($window.pageXOffset || $document[0].documentElement.scrollLeft)
        };
      },

      /**
       * Provides coordinates for the targetEl in relation to hostEl
       */
      positionElements: function(hostEl, targetEl, positionStr, appendToBody) {
        var positionStrParts = positionStr.split('-');
        var pos0 = positionStrParts[0], pos1 = positionStrParts[1] || 'center';

        var hostElPos,
          targetElWidth,
          targetElHeight,
          targetElPos;

        hostElPos = appendToBody ? this.offset(hostEl) : this.position(hostEl);

        targetElWidth = targetEl.prop('offsetWidth');
        targetElHeight = targetEl.prop('offsetHeight');

        var shiftWidth = {
          center: function() {
            return hostElPos.left + hostElPos.width / 2 - targetElWidth / 2;
          },
          left: function() {
            return hostElPos.left;
          },
          right: function() {
            return hostElPos.left + hostElPos.width;
          }
        };

        var shiftHeight = {
          center: function() {
            return hostElPos.top + hostElPos.height / 2 - targetElHeight / 2;
          },
          top: function() {
            return hostElPos.top;
          },
          bottom: function() {
            return hostElPos.top + hostElPos.height;
          }
        };

        switch (pos0) {
          case 'right':
            targetElPos = {
              top: shiftHeight[pos1](),
              left: shiftWidth[pos0]()
            };
            break;
          case 'left':
            targetElPos = {
              top: shiftHeight[pos1](),
              left: hostElPos.left - targetElWidth
            };
            break;
          case 'bottom':
            targetElPos = {
              top: shiftHeight[pos0](),
              left: shiftWidth[pos1]()
            };
            break;
          default:
            targetElPos = {
              top: hostElPos.top - targetElHeight,
              left: shiftWidth[pos1]()
            };
            break;
        }

        return targetElPos;
      }
    };
  }]);

angular.module('ui.bootstrap.datepicker', ['ui.bootstrap.dateparser', 'ui.bootstrap.position'])

.value('$datepickerSuppressError', false)

.constant('datepickerConfig', {
  formatDay: 'dd',
  formatMonth: 'MMMM',
  formatYear: 'yyyy',
  formatDayHeader: 'EEE',
  formatDayTitle: 'MMMM yyyy',
  formatMonthTitle: 'yyyy',
  datepickerMode: 'day',
  minMode: 'day',
  maxMode: 'year',
  showWeeks: true,
  startingDay: 0,
  yearRange: 20,
  minDate: null,
  maxDate: null,
  shortcutPropagation: false
})

.controller('DatepickerController', ['$scope', '$attrs', '$parse', '$interpolate', '$log', 'dateFilter', 'datepickerConfig', '$datepickerSuppressError', function($scope, $attrs, $parse, $interpolate, $log, dateFilter, datepickerConfig, $datepickerSuppressError) {
  var self = this,
      ngModelCtrl = { $setViewValue: angular.noop }; // nullModelCtrl;

  // Modes chain
  this.modes = ['day', 'month', 'year'];

  // Configuration attributes
  angular.forEach(['formatDay', 'formatMonth', 'formatYear', 'formatDayHeader', 'formatDayTitle', 'formatMonthTitle',
                   'showWeeks', 'startingDay', 'yearRange', 'shortcutPropagation'], function(key, index) {
    self[key] = angular.isDefined($attrs[key]) ? (index < 6 ? $interpolate($attrs[key])($scope.$parent) : $scope.$parent.$eval($attrs[key])) : datepickerConfig[key];
  });

  // Watchable date attributes
  angular.forEach(['minDate', 'maxDate'], function(key) {
    if ($attrs[key]) {
      $scope.$parent.$watch($parse($attrs[key]), function(value) {
        self[key] = value ? new Date(value) : null;
        self.refreshView();
      });
    } else {
      self[key] = datepickerConfig[key] ? new Date(datepickerConfig[key]) : null;
    }
  });

  angular.forEach(['minMode', 'maxMode'], function(key) {
    if ($attrs[key]) {
      $scope.$parent.$watch($parse($attrs[key]), function(value) {
        self[key] = angular.isDefined(value) ? value : $attrs[key];
        $scope[key] = self[key];
        if ((key == 'minMode' && self.modes.indexOf($scope.datepickerMode) < self.modes.indexOf(self[key])) || (key == 'maxMode' && self.modes.indexOf($scope.datepickerMode) > self.modes.indexOf(self[key]))) {
          $scope.datepickerMode = self[key];
        }
      });
    } else {
      self[key] = datepickerConfig[key] || null;
      $scope[key] = self[key];
    }
  });

  $scope.datepickerMode = $scope.datepickerMode || datepickerConfig.datepickerMode;
  $scope.uniqueId = 'datepicker-' + $scope.$id + '-' + Math.floor(Math.random() * 10000);

  if (angular.isDefined($attrs.initDate)) {
    this.activeDate = $scope.$parent.$eval($attrs.initDate) || new Date();
    $scope.$parent.$watch($attrs.initDate, function(initDate) {
      if (initDate && (ngModelCtrl.$isEmpty(ngModelCtrl.$modelValue) || ngModelCtrl.$invalid)) {
        self.activeDate = initDate;
        self.refreshView();
      }
    });
  } else {
    this.activeDate = new Date();
  }

  $scope.isActive = function(dateObject) {
    if (self.compare(dateObject.date, self.activeDate) === 0) {
      $scope.activeDateId = dateObject.uid;
      return true;
    }
    return false;
  };

  this.init = function(ngModelCtrl_) {
    ngModelCtrl = ngModelCtrl_;

    ngModelCtrl.$render = function() {
      self.render();
    };
  };

  this.render = function() {
    if (ngModelCtrl.$viewValue) {
      var date = new Date(ngModelCtrl.$viewValue),
          isValid = !isNaN(date);

      if (isValid) {
        this.activeDate = date;
      } else if (!$datepickerSuppressError) {
        $log.error('Datepicker directive: "ng-model" value must be a Date object, a number of milliseconds since 01.01.1970 or a string representing an RFC2822 or ISO 8601 date.');
      }
    }
    this.refreshView();
  };

  this.refreshView = function() {
    if (this.element) {
      this._refreshView();

      var date = ngModelCtrl.$viewValue ? new Date(ngModelCtrl.$viewValue) : null;
      ngModelCtrl.$setValidity('dateDisabled', !date || (this.element && !this.isDisabled(date)));
    }
  };

  this.createDateObject = function(date, format) {
    var model = ngModelCtrl.$viewValue ? new Date(ngModelCtrl.$viewValue) : null;
    return {
      date: date,
      label: dateFilter(date, format),
      selected: model && this.compare(date, model) === 0,
      disabled: this.isDisabled(date),
      current: this.compare(date, new Date()) === 0,
      customClass: this.customClass(date)
    };
  };

  this.isDisabled = function(date) {
    return ((this.minDate && this.compare(date, this.minDate) < 0) || (this.maxDate && this.compare(date, this.maxDate) > 0) || ($attrs.dateDisabled && $scope.dateDisabled({date: date, mode: $scope.datepickerMode})));
  };

  this.customClass = function(date) {
    return $scope.customClass({date: date, mode: $scope.datepickerMode});
  };

  // Split array into smaller arrays
  this.split = function(arr, size) {
    var arrays = [];
    while (arr.length > 0) {
      arrays.push(arr.splice(0, size));
    }
    return arrays;
  };

  // Fix a hard-reprodusible bug with timezones
  // The bug depends on OS, browser, current timezone and current date
  // i.e.
  // var date = new Date(2014, 0, 1);
  // console.log(date.getFullYear(), date.getMonth(), date.getDate(), date.getHours());
  // can result in "2013 11 31 23" because of the bug.
  this.fixTimeZone = function(date) {
    var hours = date.getHours();
    date.setHours(hours === 23 ? hours + 2 : 0);
  };

  $scope.select = function(date) {
    if ($scope.datepickerMode === self.minMode) {
      var dt = ngModelCtrl.$viewValue ? new Date(ngModelCtrl.$viewValue) : new Date(0, 0, 0, 0, 0, 0, 0);
      dt.setFullYear(date.getFullYear(), date.getMonth(), date.getDate());
      ngModelCtrl.$setViewValue(dt);
      ngModelCtrl.$render();
    } else {
      self.activeDate = date;
      $scope.datepickerMode = self.modes[self.modes.indexOf($scope.datepickerMode) - 1];
    }
  };

  $scope.move = function(direction) {
    var year = self.activeDate.getFullYear() + direction * (self.step.years || 0),
        month = self.activeDate.getMonth() + direction * (self.step.months || 0);
    self.activeDate.setFullYear(year, month, 1);
    self.refreshView();
  };

  $scope.toggleMode = function(direction) {
    direction = direction || 1;

    if (($scope.datepickerMode === self.maxMode && direction === 1) || ($scope.datepickerMode === self.minMode && direction === -1)) {
      return;
    }

    $scope.datepickerMode = self.modes[self.modes.indexOf($scope.datepickerMode) + direction];
  };

  // Key event mapper
  $scope.keys = { 13: 'enter', 32: 'space', 33: 'pageup', 34: 'pagedown', 35: 'end', 36: 'home', 37: 'left', 38: 'up', 39: 'right', 40: 'down' };

  var focusElement = function() {
    self.element[0].focus();
  };

  // Listen for focus requests from popup directive
  $scope.$on('datepicker.focus', focusElement);

  $scope.keydown = function(evt) {
    var key = $scope.keys[evt.which];

    if (!key || evt.shiftKey || evt.altKey) {
      return;
    }

    evt.preventDefault();
    if (!self.shortcutPropagation) {
      evt.stopPropagation();
    }

    if (key === 'enter' || key === 'space') {
      if (self.isDisabled(self.activeDate)) {
        return; // do nothing
      }
      $scope.select(self.activeDate);
      focusElement();
    } else if (evt.ctrlKey && (key === 'up' || key === 'down')) {
      $scope.toggleMode(key === 'up' ? 1 : -1);
      focusElement();
    } else {
      self.handleKeyDown(key, evt);
      self.refreshView();
    }
  };
}])

.directive('datepicker', function() {
  return {
    restrict: 'EA',
    replace: true,
    templateUrl: function(element, attrs) {
      return attrs.templateUrl || 'template/datepicker/datepicker.html';
    },
    scope: {
      datepickerMode: '=?',
      dateDisabled: '&',
      customClass: '&',
      shortcutPropagation: '&?'
    },
    require: ['datepicker', '^ngModel'],
    controller: 'DatepickerController',
    controllerAs: 'datepicker',
    link: function(scope, element, attrs, ctrls) {
      var datepickerCtrl = ctrls[0], ngModelCtrl = ctrls[1];

      datepickerCtrl.init(ngModelCtrl);
    }
  };
})

.directive('daypicker', ['dateFilter', function(dateFilter) {
  return {
    restrict: 'EA',
    replace: true,
    templateUrl: 'template/datepicker/day.html',
    require: '^datepicker',
    link: function(scope, element, attrs, ctrl) {
      scope.showWeeks = ctrl.showWeeks;

      ctrl.step = { months: 1 };
      ctrl.element = element;

      var DAYS_IN_MONTH = [31, 28, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31];
      function getDaysInMonth(year, month) {
        return ((month === 1) && (year % 4 === 0) && ((year % 100 !== 0) || (year % 400 === 0))) ? 29 : DAYS_IN_MONTH[month];
      }

      function getDates(startDate, n) {
        var dates = new Array(n), current = new Date(startDate), i = 0, date;
        while (i < n) {
          date = new Date(current);
          ctrl.fixTimeZone(date);
          dates[i++] = date;
          current.setDate(current.getDate() + 1);
        }
        return dates;
      }

      ctrl._refreshView = function() {
        var year = ctrl.activeDate.getFullYear(),
          month = ctrl.activeDate.getMonth(),
          firstDayOfMonth = new Date(year, month, 1),
          difference = ctrl.startingDay - firstDayOfMonth.getDay(),
          numDisplayedFromPreviousMonth = (difference > 0) ? 7 - difference : - difference,
          firstDate = new Date(firstDayOfMonth);

        if (numDisplayedFromPreviousMonth > 0) {
          firstDate.setDate(-numDisplayedFromPreviousMonth + 1);
        }

        // 42 is the number of days on a six-month calendar
        var days = getDates(firstDate, 42);
        for (var i = 0; i < 42; i ++) {
          days[i] = angular.extend(ctrl.createDateObject(days[i], ctrl.formatDay), {
            secondary: days[i].getMonth() !== month,
            uid: scope.uniqueId + '-' + i
          });
        }

        scope.labels = new Array(7);
        for (var j = 0; j < 7; j++) {
          scope.labels[j] = {
            abbr: dateFilter(days[j].date, ctrl.formatDayHeader),
            full: dateFilter(days[j].date, 'EEEE')
          };
        }

        scope.title = dateFilter(ctrl.activeDate, ctrl.formatDayTitle);
        scope.rows = ctrl.split(days, 7);

        if (scope.showWeeks) {
          scope.weekNumbers = [];
          var thursdayIndex = (4 + 7 - ctrl.startingDay) % 7,
              numWeeks = scope.rows.length;
          for (var curWeek = 0; curWeek < numWeeks; curWeek++) {
            scope.weekNumbers.push(
              getISO8601WeekNumber(scope.rows[curWeek][thursdayIndex].date));
          }
        }
      };

      ctrl.compare = function(date1, date2) {
        return (new Date(date1.getFullYear(), date1.getMonth(), date1.getDate()) - new Date(date2.getFullYear(), date2.getMonth(), date2.getDate()));
      };

      function getISO8601WeekNumber(date) {
        var checkDate = new Date(date);
        checkDate.setDate(checkDate.getDate() + 4 - (checkDate.getDay() || 7)); // Thursday
        var time = checkDate.getTime();
        checkDate.setMonth(0); // Compare with Jan 1
        checkDate.setDate(1);
        return Math.floor(Math.round((time - checkDate) / 86400000) / 7) + 1;
      }

      ctrl.handleKeyDown = function(key, evt) {
        var date = ctrl.activeDate.getDate();

        if (key === 'left') {
          date = date - 1;   // up
        } else if (key === 'up') {
          date = date - 7;   // down
        } else if (key === 'right') {
          date = date + 1;   // down
        } else if (key === 'down') {
          date = date + 7;
        } else if (key === 'pageup' || key === 'pagedown') {
          var month = ctrl.activeDate.getMonth() + (key === 'pageup' ? - 1 : 1);
          ctrl.activeDate.setMonth(month, 1);
          date = Math.min(getDaysInMonth(ctrl.activeDate.getFullYear(), ctrl.activeDate.getMonth()), date);
        } else if (key === 'home') {
          date = 1;
        } else if (key === 'end') {
          date = getDaysInMonth(ctrl.activeDate.getFullYear(), ctrl.activeDate.getMonth());
        }
        ctrl.activeDate.setDate(date);
      };

      ctrl.refreshView();
    }
  };
}])

.directive('monthpicker', ['dateFilter', function(dateFilter) {
  return {
    restrict: 'EA',
    replace: true,
    templateUrl: 'template/datepicker/month.html',
    require: '^datepicker',
    link: function(scope, element, attrs, ctrl) {
      ctrl.step = { years: 1 };
      ctrl.element = element;

      ctrl._refreshView = function() {
        var months = new Array(12),
            year = ctrl.activeDate.getFullYear(),
            date;

        for (var i = 0; i < 12; i++) {
          date = new Date(year, i, 1);
          ctrl.fixTimeZone(date);
          months[i] = angular.extend(ctrl.createDateObject(date, ctrl.formatMonth), {
            uid: scope.uniqueId + '-' + i
          });
        }

        scope.title = dateFilter(ctrl.activeDate, ctrl.formatMonthTitle);
        scope.rows = ctrl.split(months, 3);
      };

      ctrl.compare = function(date1, date2) {
        return new Date(date1.getFullYear(), date1.getMonth()) - new Date(date2.getFullYear(), date2.getMonth());
      };

      ctrl.handleKeyDown = function(key, evt) {
        var date = ctrl.activeDate.getMonth();

        if (key === 'left') {
          date = date - 1;   // up
        } else if (key === 'up') {
          date = date - 3;   // down
        } else if (key === 'right') {
          date = date + 1;   // down
        } else if (key === 'down') {
          date = date + 3;
        } else if (key === 'pageup' || key === 'pagedown') {
          var year = ctrl.activeDate.getFullYear() + (key === 'pageup' ? - 1 : 1);
          ctrl.activeDate.setFullYear(year);
        } else if (key === 'home') {
          date = 0;
        } else if (key === 'end') {
          date = 11;
        }
        ctrl.activeDate.setMonth(date);
      };

      ctrl.refreshView();
    }
  };
}])

.directive('yearpicker', ['dateFilter', function(dateFilter) {
  return {
    restrict: 'EA',
    replace: true,
    templateUrl: 'template/datepicker/year.html',
    require: '^datepicker',
    link: function(scope, element, attrs, ctrl) {
      var range = ctrl.yearRange;

      ctrl.step = { years: range };
      ctrl.element = element;

      function getStartingYear( year ) {
        return parseInt((year - 1) / range, 10) * range + 1;
      }

      ctrl._refreshView = function() {
        var years = new Array(range), date;

        for (var i = 0, start = getStartingYear(ctrl.activeDate.getFullYear()); i < range; i++) {
          date = new Date(start + i, 0, 1);
          ctrl.fixTimeZone(date);
          years[i] = angular.extend(ctrl.createDateObject(date, ctrl.formatYear), {
            uid: scope.uniqueId + '-' + i
          });
        }

        scope.title = [years[0].label, years[range - 1].label].join(' - ');
        scope.rows = ctrl.split(years, 5);
      };

      ctrl.compare = function(date1, date2) {
        return date1.getFullYear() - date2.getFullYear();
      };

      ctrl.handleKeyDown = function(key, evt) {
        var date = ctrl.activeDate.getFullYear();

        if (key === 'left') {
          date = date - 1;   // up
        } else if (key === 'up') {
          date = date - 5;   // down
        } else if (key === 'right') {
          date = date + 1;   // down
        } else if (key === 'down') {
          date = date + 5;
        } else if (key === 'pageup' || key === 'pagedown') {
          date += (key === 'pageup' ? - 1 : 1) * ctrl.step.years;
        } else if (key === 'home') {
          date = getStartingYear(ctrl.activeDate.getFullYear());
        } else if (key === 'end') {
          date = getStartingYear(ctrl.activeDate.getFullYear()) + range - 1;
        }
        ctrl.activeDate.setFullYear(date);
      };

      ctrl.refreshView();
    }
  };
}])

.constant('datepickerPopupConfig', {
  datepickerPopup: 'yyyy-MM-dd',
  datepickerPopupTemplateUrl: 'template/datepicker/popup.html',
  datepickerTemplateUrl: 'template/datepicker/datepicker.html',
  html5Types: {
    date: 'yyyy-MM-dd',
    'datetime-local': 'yyyy-MM-ddTHH:mm:ss.sss',
    'month': 'yyyy-MM'
  },
  currentText: 'Today',
  clearText: 'Clear',
  closeText: 'Done',
  closeOnDateSelection: true,
  appendToBody: false,
  showButtonBar: true,
  onOpenFocus: true
})

.directive('datepickerPopup', ['$compile', '$parse', '$document', '$rootScope', '$position', 'dateFilter', 'dateParser', 'datepickerPopupConfig', '$timeout',
function($compile, $parse, $document, $rootScope, $position, dateFilter, dateParser, datepickerPopupConfig, $timeout) {
  return {
    restrict: 'EA',
    require: 'ngModel',
    scope: {
      isOpen: '=?',
      currentText: '@',
      clearText: '@',
      closeText: '@',
      dateDisabled: '&',
      customClass: '&'
    },
    link: function(scope, element, attrs, ngModel) {
      var dateFormat,
          closeOnDateSelection = angular.isDefined(attrs.closeOnDateSelection) ? scope.$parent.$eval(attrs.closeOnDateSelection) : datepickerPopupConfig.closeOnDateSelection,
          appendToBody = angular.isDefined(attrs.datepickerAppendToBody) ? scope.$parent.$eval(attrs.datepickerAppendToBody) : datepickerPopupConfig.appendToBody,
          onOpenFocus = angular.isDefined(attrs.onOpenFocus) ? scope.$parent.$eval(attrs.onOpenFocus) : datepickerPopupConfig.onOpenFocus,
          datepickerPopupTemplateUrl = angular.isDefined(attrs.datepickerPopupTemplateUrl) ? attrs.datepickerPopupTemplateUrl : datepickerPopupConfig.datepickerPopupTemplateUrl,
          datepickerTemplateUrl = angular.isDefined(attrs.datepickerTemplateUrl) ? attrs.datepickerTemplateUrl : datepickerPopupConfig.datepickerTemplateUrl,
          cache = {};

      scope.showButtonBar = angular.isDefined(attrs.showButtonBar) ? scope.$parent.$eval(attrs.showButtonBar) : datepickerPopupConfig.showButtonBar;

      scope.getText = function(key) {
        return scope[key + 'Text'] || datepickerPopupConfig[key + 'Text'];
      };

      scope.isDisabled = function(date) {
        if (date === 'today') {
          date = new Date();
        }

        return ((scope.watchData.minDate && scope.compare(date, cache.minDate) < 0) ||
          (scope.watchData.maxDate && scope.compare(date, cache.maxDate) > 0));
      };

      scope.compare = function(date1, date2) {
        return (new Date(date1.getFullYear(), date1.getMonth(), date1.getDate()) - new Date(date2.getFullYear(), date2.getMonth(), date2.getDate()));
      };

      var isHtml5DateInput = false;
      if (datepickerPopupConfig.html5Types[attrs.type]) {
        dateFormat = datepickerPopupConfig.html5Types[attrs.type];
        isHtml5DateInput = true;
      } else {
        dateFormat = attrs.datepickerPopup || datepickerPopupConfig.datepickerPopup;
        attrs.$observe('datepickerPopup', function(value, oldValue) {
            var newDateFormat = value || datepickerPopupConfig.datepickerPopup;
            // Invalidate the $modelValue to ensure that formatters re-run
            // FIXME: Refactor when PR is merged: https://github.com/angular/angular.js/pull/10764
            if (newDateFormat !== dateFormat) {
              dateFormat = newDateFormat;
              ngModel.$modelValue = null;

              if (!dateFormat) {
                throw new Error('datepickerPopup must have a date format specified.');
              }
            }
        });
      }

      if (!dateFormat) {
        throw new Error('datepickerPopup must have a date format specified.');
      }

      if (isHtml5DateInput && attrs.datepickerPopup) {
        throw new Error('HTML5 date input types do not support custom formats.');
      }

      // popup element used to display calendar
      var popupEl = angular.element('<div datepicker-popup-wrap><div datepicker></div></div>');
      popupEl.attr({
        'ng-model': 'date',
        'ng-change': 'dateSelection(date)',
        'template-url': datepickerPopupTemplateUrl
      });

      function cameltoDash(string) {
        return string.replace(/([A-Z])/g, function($1) { return '-' + $1.toLowerCase(); });
      }

      // datepicker element
      var datepickerEl = angular.element(popupEl.children()[0]);
      datepickerEl.attr('template-url', datepickerTemplateUrl);

      if (isHtml5DateInput) {
        if (attrs.type === 'month') {
          datepickerEl.attr('datepicker-mode', '"month"');
          datepickerEl.attr('min-mode', 'month');
        }
      }

      if (attrs.datepickerOptions) {
        var options = scope.$parent.$eval(attrs.datepickerOptions);
        if (options && options.initDate) {
          scope.initDate = options.initDate;
          datepickerEl.attr('init-date', 'initDate');
          delete options.initDate;
        }
        angular.forEach(options, function(value, option) {
          datepickerEl.attr( cameltoDash(option), value );
        });
      }

      scope.watchData = {};
      angular.forEach(['minMode', 'maxMode', 'minDate', 'maxDate', 'datepickerMode', 'initDate', 'shortcutPropagation'], function(key) {
        if (attrs[key]) {
          var getAttribute = $parse(attrs[key]);
          scope.$parent.$watch(getAttribute, function(value) {
            scope.watchData[key] = value;
            if (key === 'minDate' || key === 'maxDate') {
              cache[key] = new Date(value);
            }
          });
          datepickerEl.attr(cameltoDash(key), 'watchData.' + key);

          // Propagate changes from datepicker to outside
          if (key === 'datepickerMode') {
            var setAttribute = getAttribute.assign;
            scope.$watch('watchData.' + key, function(value, oldvalue) {
              if (angular.isFunction(setAttribute) && value !== oldvalue) {
                setAttribute(scope.$parent, value);
              }
            });
          }
        }
      });
      if (attrs.dateDisabled) {
        datepickerEl.attr('date-disabled', 'dateDisabled({ date: date, mode: mode })');
      }

      if (attrs.showWeeks) {
        datepickerEl.attr('show-weeks', attrs.showWeeks);
      }

      if (attrs.customClass) {
        datepickerEl.attr('custom-class', 'customClass({ date: date, mode: mode })');
      }

      function parseDate(viewValue) {
        if (angular.isNumber(viewValue)) {
          // presumably timestamp to date object
          viewValue = new Date(viewValue);
        }

        if (!viewValue) {
          return null;
        } else if (angular.isDate(viewValue) && !isNaN(viewValue)) {
          return viewValue;
        } else if (angular.isString(viewValue)) {
          var date = dateParser.parse(viewValue, dateFormat, scope.date);
          if (isNaN(date)) {
            return undefined;
          } else {
            return date;
          }
        } else {
          return undefined;
        }
      }

      function validator(modelValue, viewValue) {
        var value = modelValue || viewValue;

        if (!attrs.ngRequired && !value) {
          return true;
        }

        if (angular.isNumber(value)) {
          value = new Date(value);
        }
        if (!value) {
          return true;
        } else if (angular.isDate(value) && !isNaN(value)) {
          return true;
        } else if (angular.isString(value)) {
          var date = dateParser.parse(value, dateFormat);
          return !isNaN(date);
        } else {
          return false;
        }
      }

      if (!isHtml5DateInput) {
        // Internal API to maintain the correct ng-invalid-[key] class
        ngModel.$$parserName = 'date';
        ngModel.$validators.date = validator;
        ngModel.$parsers.unshift(parseDate);
        ngModel.$formatters.push(function(value) {
          scope.date = value;
          return ngModel.$isEmpty(value) ? value : dateFilter(value, dateFormat);
        });
      } else {
        ngModel.$formatters.push(function(value) {
          scope.date = value;
          return value;
        });
      }

      // Inner change
      scope.dateSelection = function(dt) {
        if (angular.isDefined(dt)) {
          scope.date = dt;
        }
        var date = scope.date ? dateFilter(scope.date, dateFormat) : null; // Setting to NULL is necessary for form validators to function
        element.val(date);
        ngModel.$setViewValue(date);

        if (closeOnDateSelection) {
          scope.isOpen = false;
          element[0].focus();
        }
      };

      // Detect changes in the view from the text box
      ngModel.$viewChangeListeners.push(function() {
        scope.date = dateParser.parse(ngModel.$viewValue, dateFormat, scope.date);
      });

      var documentClickBind = function(event) {
        if (scope.isOpen && !(element[0].contains(event.target) || popupEl[0].contains(event.target))) {
          scope.$apply(function() {
            scope.isOpen = false;
          });
        }
      };

      var inputKeydownBind = function(evt) {
        if (evt.which === 27 && scope.isOpen) {
          evt.preventDefault();
          evt.stopPropagation();
          scope.$apply(function() {
            scope.isOpen = false;
          });
          element[0].focus();
        } else if (evt.which === 40 && !scope.isOpen) {
          evt.preventDefault();
          evt.stopPropagation();
          scope.$apply(function() {
            scope.isOpen = true;
          });
        }
      };
      element.bind('keydown', inputKeydownBind);

      scope.keydown = function(evt) {
        if (evt.which === 27) {
          scope.isOpen = false;
          element[0].focus();
        }
      };

      scope.$watch('isOpen', function(value) {
        if (value) {
          scope.position = appendToBody ? $position.offset(element) : $position.position(element);
          scope.position.top = scope.position.top + element.prop('offsetHeight');

          $timeout(function() {
            if (onOpenFocus) {
              scope.$broadcast('datepicker.focus');
            }
            $document.bind('click', documentClickBind);
          }, 0, false);
        } else {
          $document.unbind('click', documentClickBind);
        }
      });

      scope.select = function(date) {
        if (date === 'today') {
          var today = new Date();
          if (angular.isDate(scope.date)) {
            date = new Date(scope.date);
            date.setFullYear(today.getFullYear(), today.getMonth(), today.getDate());
          } else {
            date = new Date(today.setHours(0, 0, 0, 0));
          }
        }
        scope.dateSelection(date);
      };

      scope.close = function() {
        scope.isOpen = false;
        element[0].focus();
      };

      var $popup = $compile(popupEl)(scope);
      // Prevent jQuery cache memory leak (template is now redundant after linking)
      popupEl.remove();

      if (appendToBody) {
        $document.find('body').append($popup);
      } else {
        element.after($popup);
      }

      scope.$on('$destroy', function() {
        if (scope.isOpen === true) {
          if (!$rootScope.$$phase) {
            scope.$apply(function() {
              scope.isOpen = false;
            });
          }
        }

        $popup.remove();
        element.unbind('keydown', inputKeydownBind);
        $document.unbind('click', documentClickBind);
      });
    }
  };
}])

.directive('datepickerPopupWrap', function() {
  return {
    restrict:'EA',
    replace: true,
    transclude: true,
    templateUrl: function(element, attrs) {
      return attrs.templateUrl || 'template/datepicker/popup.html';
    }
  };
});

angular.module('ui.bootstrap.dropdown', ['ui.bootstrap.position'])

.constant('dropdownConfig', {
  openClass: 'open'
})

.service('dropdownService', ['$document', '$rootScope', function($document, $rootScope) {
  var openScope = null;

  this.open = function(dropdownScope) {
    if (!openScope) {
      $document.bind('click', closeDropdown);
      $document.bind('keydown', keybindFilter);
    }

    if (openScope && openScope !== dropdownScope) {
      openScope.isOpen = false;
    }

    openScope = dropdownScope;
  };

  this.close = function(dropdownScope) {
    if (openScope === dropdownScope) {
      openScope = null;
      $document.unbind('click', closeDropdown);
      $document.unbind('keydown', keybindFilter);
    }
  };

  var closeDropdown = function(evt) {
    // This method may still be called during the same mouse event that
    // unbound this event handler. So check openScope before proceeding.
    if (!openScope) { return; }

    if (evt && openScope.getAutoClose() === 'disabled')  { return ; }

    var toggleElement = openScope.getToggleElement();
    if (evt && toggleElement && toggleElement[0].contains(evt.target)) {
      return;
    }

    var dropdownElement = openScope.getDropdownElement();
    if (evt && openScope.getAutoClose() === 'outsideClick' &&
      dropdownElement && dropdownElement[0].contains(evt.target)) {
      return;
    }

    openScope.isOpen = false;

    if (!$rootScope.$$phase) {
      openScope.$apply();
    }
  };

  var keybindFilter = function(evt) {
    if (evt.which === 27) {
      openScope.focusToggleElement();
      closeDropdown();
    } else if (openScope.isKeynavEnabled() && /(38|40)/.test(evt.which) && openScope.isOpen) {
      evt.preventDefault();
      evt.stopPropagation();
      openScope.focusDropdownEntry(evt.which);
    }
  };
}])

.controller('DropdownController', ['$scope', '$attrs', '$parse', 'dropdownConfig', 'dropdownService', '$animate', '$position', '$document', '$compile', '$templateRequest', function($scope, $attrs, $parse, dropdownConfig, dropdownService, $animate, $position, $document, $compile, $templateRequest) {
  var self = this,
    scope = $scope.$new(), // create a child scope so we are not polluting original one
    templateScope,
    openClass = dropdownConfig.openClass,
    getIsOpen,
    setIsOpen = angular.noop,
    toggleInvoker = $attrs.onToggle ? $parse($attrs.onToggle) : angular.noop,
    appendToBody = false,
    keynavEnabled = false,
    selectedOption = null,
    body = $document.find('body');

  this.init = function(element) {
    self.$element = element;

    if ($attrs.isOpen) {
      getIsOpen = $parse($attrs.isOpen);
      setIsOpen = getIsOpen.assign;

      $scope.$watch(getIsOpen, function(value) {
        scope.isOpen = !!value;
      });
    }

    appendToBody = angular.isDefined($attrs.dropdownAppendToBody);
    keynavEnabled = angular.isDefined($attrs.keyboardNav);

    if (appendToBody && self.dropdownMenu) {
      body.append(self.dropdownMenu);
      body.addClass('dropdown');
      element.on('$destroy', function handleDestroyEvent() {
        self.dropdownMenu.remove();
      });
    }
  };

  this.toggle = function(open) {
    return scope.isOpen = arguments.length ? !!open : !scope.isOpen;
  };

  // Allow other directives to watch status
  this.isOpen = function() {
    return scope.isOpen;
  };

  scope.getToggleElement = function() {
    return self.toggleElement;
  };

  scope.getAutoClose = function() {
    return $attrs.autoClose || 'always'; //or 'outsideClick' or 'disabled'
  };

  scope.getElement = function() {
    return self.$element;
  };

  scope.isKeynavEnabled = function() {
    return keynavEnabled;
  };

  scope.focusDropdownEntry = function(keyCode) {
    var elems = self.dropdownMenu ? //If append to body is used.
      (angular.element(self.dropdownMenu).find('a')) :
      (angular.element(self.$element).find('ul').eq(0).find('a'));

    switch (keyCode) {
      case (40): {
        if (!angular.isNumber(self.selectedOption)) {
          self.selectedOption = 0;
        } else {
          self.selectedOption = (self.selectedOption === elems.length -1 ?
            self.selectedOption :
            self.selectedOption + 1);
        }
        break;
      }
      case (38): {
        if (!angular.isNumber(self.selectedOption)) {
          self.selectedOption = elems.length - 1;
        } else {
          self.selectedOption = self.selectedOption === 0 ?
            0 : self.selectedOption - 1;
        }
        break;
      }
    }
    elems[self.selectedOption].focus();
  };

  scope.getDropdownElement = function() {
    return self.dropdownMenu;
  };

  scope.focusToggleElement = function() {
    if (self.toggleElement) {
      self.toggleElement[0].focus();
    }
  };

  scope.$watch('isOpen', function(isOpen, wasOpen) {
    if (appendToBody && self.dropdownMenu) {
      var pos = $position.positionElements(self.$element, self.dropdownMenu, 'bottom-left', true);
      var css = {
        top: pos.top + 'px',
        display: isOpen ? 'block' : 'none'
      };

      var rightalign = self.dropdownMenu.hasClass('dropdown-menu-right');
      if (!rightalign) {
        css.left = pos.left + 'px';
        css.right = 'auto';
      } else {
        css.left = 'auto';
        css.right = (window.innerWidth - (pos.left + self.$element.prop('offsetWidth'))) + 'px';
      }

      self.dropdownMenu.css(css);
    }

    var openContainer = appendToBody ? body : self.$element;

    $animate[isOpen ? 'addClass' : 'removeClass'](openContainer, openClass).then(function() {
      if (angular.isDefined(isOpen) && isOpen !== wasOpen) {
        toggleInvoker($scope, { open: !!isOpen });
      }
    });

    if (isOpen) {
      if (self.dropdownMenuTemplateUrl) {
        $templateRequest(self.dropdownMenuTemplateUrl).then(function(tplContent) {
          templateScope = scope.$new();
          $compile(tplContent.trim())(templateScope, function(dropdownElement) {
            var newEl = dropdownElement;
            self.dropdownMenu.replaceWith(newEl);
            self.dropdownMenu = newEl;
          });
        });
      }

      scope.focusToggleElement();
      dropdownService.open(scope);
    } else {
      if (self.dropdownMenuTemplateUrl) {
        if (templateScope) {
          templateScope.$destroy();
        }
        var newEl = angular.element('<ul class="dropdown-menu"></ul>');
        self.dropdownMenu.replaceWith(newEl);
        self.dropdownMenu = newEl;
      }

      dropdownService.close(scope);
      self.selectedOption = null;
    }

    if (angular.isFunction(setIsOpen)) {
      setIsOpen($scope, isOpen);
    }
  });

  $scope.$on('$locationChangeSuccess', function() {
    if (scope.getAutoClose() !== 'disabled') {
      scope.isOpen = false;
    }
  });

  var offDestroy = $scope.$on('$destroy', function() {
    scope.$destroy();
  });
  scope.$on('$destroy', offDestroy);
}])

.directive('dropdown', function() {
  return {
    controller: 'DropdownController',
    link: function(scope, element, attrs, dropdownCtrl) {
      dropdownCtrl.init( element );
      element.addClass('dropdown');
    }
  };
})

.directive('dropdownMenu', function() {
  return {
    restrict: 'AC',
    require: '?^dropdown',
    link: function(scope, element, attrs, dropdownCtrl) {
      if (!dropdownCtrl) {
        return;
      }
      var tplUrl = attrs.templateUrl;
      if (tplUrl) {
        dropdownCtrl.dropdownMenuTemplateUrl = tplUrl;
      }
      if (!dropdownCtrl.dropdownMenu) {
        dropdownCtrl.dropdownMenu = element;
      }
    }
  };
})

.directive('keyboardNav', function() {
  return {
    restrict: 'A',
    require: '?^dropdown',
    link: function (scope, element, attrs, dropdownCtrl) {

      element.bind('keydown', function(e) {
        if ([38, 40].indexOf(e.which) !== -1) {
          e.preventDefault();
          e.stopPropagation();

          var elems = dropdownCtrl.dropdownMenu.find('a');

          switch (e.which) {
            case (40): { // Down
              if (!angular.isNumber(dropdownCtrl.selectedOption)) {
                dropdownCtrl.selectedOption = 0;
              } else {
                dropdownCtrl.selectedOption = dropdownCtrl.selectedOption === elems.length -1 ?
                  dropdownCtrl.selectedOption : dropdownCtrl.selectedOption + 1;
              }
              break;
            }
            case (38): { // Up
              if (!angular.isNumber(dropdownCtrl.selectedOption)) {
                dropdownCtrl.selectedOption = elems.length - 1;
              } else {
                dropdownCtrl.selectedOption = dropdownCtrl.selectedOption === 0 ?
                  0 : dropdownCtrl.selectedOption - 1;
              }
              break;
            }
          }
          elems[dropdownCtrl.selectedOption].focus();
        }
      });
    }
  };
})

.directive('dropdownToggle', function() {
  return {
    require: '?^dropdown',
    link: function(scope, element, attrs, dropdownCtrl) {
      if (!dropdownCtrl) {
        return;
      }

      element.addClass('dropdown-toggle');

      dropdownCtrl.toggleElement = element;

      var toggleDropdown = function(event) {
        event.preventDefault();

        if (!element.hasClass('disabled') && !attrs.disabled) {
          scope.$apply(function() {
            dropdownCtrl.toggle();
          });
        }
      };

      element.bind('click', toggleDropdown);

      // WAI-ARIA
      element.attr({ 'aria-haspopup': true, 'aria-expanded': false });
      scope.$watch(dropdownCtrl.isOpen, function( isOpen ) {
        element.attr('aria-expanded', !!isOpen);
      });

      scope.$on('$destroy', function() {
        element.unbind('click', toggleDropdown);
      });
    }
  };
});

angular.module('ui.bootstrap.modal', [])

/**
 * A helper, internal data structure that acts as a map but also allows getting / removing
 * elements in the LIFO order
 */
  .factory('$$stackedMap', function() {
    return {
      createNew: function() {
        var stack = [];

        return {
          add: function(key, value) {
            stack.push({
              key: key,
              value: value
            });
          },
          get: function(key) {
            for (var i = 0; i < stack.length; i++) {
              if (key == stack[i].key) {
                return stack[i];
              }
            }
          },
          keys: function() {
            var keys = [];
            for (var i = 0; i < stack.length; i++) {
              keys.push(stack[i].key);
            }
            return keys;
          },
          top: function() {
            return stack[stack.length - 1];
          },
          remove: function(key) {
            var idx = -1;
            for (var i = 0; i < stack.length; i++) {
              if (key == stack[i].key) {
                idx = i;
                break;
              }
            }
            return stack.splice(idx, 1)[0];
          },
          removeTop: function() {
            return stack.splice(stack.length - 1, 1)[0];
          },
          length: function() {
            return stack.length;
          }
        };
      }
    };
  })

/**
 * A helper, internal data structure that stores all references attached to key
 */
  .factory('$$multiMap', function() {
    return {
      createNew: function() {
        var map = {};

        return {
          entries: function() {
            return Object.keys(map).map(function(key) {
              return {
                key: key,
                value: map[key]
              };
            });
          },
          get: function(key) {
            return map[key];
          },
          hasKey: function(key) {
            return !!map[key];
          },
          keys: function() {
            return Object.keys(map);
          },
          put: function(key, value) {
            if (!map[key]) {
              map[key] = [];
            }

            map[key].push(value);
          },
          remove: function(key, value) {
            var values = map[key];

            if (!values) {
              return;
            }

            var idx = values.indexOf(value);

            if (idx !== -1) {
              values.splice(idx, 1);
            }

            if (!values.length) {
              delete map[key];
            }
          }
        };
      }
    };
  })

/**
 * A helper directive for the $modal service. It creates a backdrop element.
 */
  .directive('modalBackdrop', [
           '$animate', '$injector', '$modalStack',
  function($animate ,  $injector,   $modalStack) {
    var $animateCss = null;

    if ($injector.has('$animateCss')) {
      $animateCss = $injector.get('$animateCss');
    }

    return {
      restrict: 'EA',
      replace: true,
      templateUrl: 'template/modal/backdrop.html',
      compile: function(tElement, tAttrs) {
        tElement.addClass(tAttrs.backdropClass);
        return linkFn;
      }
    };

    function linkFn(scope, element, attrs) {
      if (attrs.modalInClass) {
        if ($animateCss) {
          $animateCss(element, {
            addClass: attrs.modalInClass
          }).start();
        } else {
          $animate.addClass(element, attrs.modalInClass);
        }

        scope.$on($modalStack.NOW_CLOSING_EVENT, function(e, setIsAsync) {
          var done = setIsAsync();
          if ($animateCss) {
            $animateCss(element, {
              removeClass: attrs.modalInClass
            }).start().then(done);
          } else {
            $animate.removeClass(element, attrs.modalInClass).then(done);
          }
        });
      }
    }
  }])

  .directive('modalWindow', [
           '$modalStack', '$q', '$animate', '$injector',
  function($modalStack ,  $q ,  $animate,   $injector) {
    var $animateCss = null;

    if ($injector.has('$animateCss')) {
      $animateCss = $injector.get('$animateCss');
    }

    return {
      restrict: 'EA',
      scope: {
        index: '@'
      },
      replace: true,
      transclude: true,
      templateUrl: function(tElement, tAttrs) {
        return tAttrs.templateUrl || 'template/modal/window.html';
      },
      link: function(scope, element, attrs) {
        element.addClass(attrs.windowClass || '');
        scope.size = attrs.size;

        scope.close = function(evt) {
          var modal = $modalStack.getTop();
          if (modal && modal.value.backdrop && modal.value.backdrop !== 'static' && (evt.target === evt.currentTarget)) {
            evt.preventDefault();
            evt.stopPropagation();
            $modalStack.dismiss(modal.key, 'backdrop click');
          }
        };

        // This property is only added to the scope for the purpose of detecting when this directive is rendered.
        // We can detect that by using this property in the template associated with this directive and then use
        // {@link Attribute#$observe} on it. For more details please see {@link TableColumnResize}.
        scope.$isRendered = true;

        // Deferred object that will be resolved when this modal is render.
        var modalRenderDeferObj = $q.defer();
        // Observe function will be called on next digest cycle after compilation, ensuring that the DOM is ready.
        // In order to use this way of finding whether DOM is ready, we need to observe a scope property used in modal's template.
        attrs.$observe('modalRender', function(value) {
          if (value == 'true') {
            modalRenderDeferObj.resolve();
          }
        });

        modalRenderDeferObj.promise.then(function() {
          var animationPromise = null;

          if (attrs.modalInClass) {
            if ($animateCss) {
              animationPromise = $animateCss(element, {
                addClass: attrs.modalInClass
              }).start();
            } else {
              animationPromise = $animate.addClass(element, attrs.modalInClass);
            }

            scope.$on($modalStack.NOW_CLOSING_EVENT, function(e, setIsAsync) {
              var done = setIsAsync();
              if ($animateCss) {
                $animateCss(element, {
                  removeClass: attrs.modalInClass
                }).start().then(done);
              } else {
                $animate.removeClass(element, attrs.modalInClass).then(done);
              }
            });
          }


          $q.when(animationPromise).then(function() {
            var inputsWithAutofocus = element[0].querySelectorAll('[autofocus]');
            /**
             * Auto-focusing of a freshly-opened modal element causes any child elements
             * with the autofocus attribute to lose focus. This is an issue on touch
             * based devices which will show and then hide the onscreen keyboard.
             * Attempts to refocus the autofocus element via JavaScript will not reopen
             * the onscreen keyboard. Fixed by updated the focusing logic to only autofocus
             * the modal element if the modal does not contain an autofocus element.
             */
            if (inputsWithAutofocus.length) {
              inputsWithAutofocus[0].focus();
            } else {
              element[0].focus();
            }
          });

          // Notify {@link $modalStack} that modal is rendered.
          var modal = $modalStack.getTop();
          if (modal) {
            $modalStack.modalRendered(modal.key);
          }
        });
      }
    };
  }])

  .directive('modalAnimationClass', [
    function () {
      return {
        compile: function(tElement, tAttrs) {
          if (tAttrs.modalAnimation) {
            tElement.addClass(tAttrs.modalAnimationClass);
          }
        }
      };
    }])

  .directive('modalTransclude', function() {
    return {
      link: function($scope, $element, $attrs, controller, $transclude) {
        $transclude($scope.$parent, function(clone) {
          $element.empty();
          $element.append(clone);
        });
      }
    };
  })

  .factory('$modalStack', [
             '$animate', '$timeout', '$document', '$compile', '$rootScope',
             '$q',
             '$injector',
             '$$multiMap',
             '$$stackedMap',
    function($animate ,  $timeout ,  $document ,  $compile ,  $rootScope ,
              $q,
              $injector,
              $$multiMap,
              $$stackedMap) {
      var $animateCss = null;

      if ($injector.has('$animateCss')) {
        $animateCss = $injector.get('$animateCss');
      }

      var OPENED_MODAL_CLASS = 'modal-open';

      var backdropDomEl, backdropScope;
      var openedWindows = $$stackedMap.createNew();
      var openedClasses = $$multiMap.createNew();
      var $modalStack = {
        NOW_CLOSING_EVENT: 'modal.stack.now-closing'
      };

      //Modal focus behavior
      var focusableElementList;
      var focusIndex = 0;
      var tababbleSelector = 'a[href], area[href], input:not([disabled]), ' +
        'button:not([disabled]),select:not([disabled]), textarea:not([disabled]), ' +
        'iframe, object, embed, *[tabindex], *[contenteditable=true]';

      function backdropIndex() {
        var topBackdropIndex = -1;
        var opened = openedWindows.keys();
        for (var i = 0; i < opened.length; i++) {
          if (openedWindows.get(opened[i]).value.backdrop) {
            topBackdropIndex = i;
          }
        }
        return topBackdropIndex;
      }

      $rootScope.$watch(backdropIndex, function(newBackdropIndex) {
        if (backdropScope) {
          backdropScope.index = newBackdropIndex;
        }
      });

      function removeModalWindow(modalInstance, elementToReceiveFocus) {
        var body = $document.find('body').eq(0);
        var modalWindow = openedWindows.get(modalInstance).value;

        //clean up the stack
        openedWindows.remove(modalInstance);

        removeAfterAnimate(modalWindow.modalDomEl, modalWindow.modalScope, function() {
          var modalBodyClass = modalWindow.openedClass || OPENED_MODAL_CLASS;
          openedClasses.remove(modalBodyClass, modalInstance);
          body.toggleClass(modalBodyClass, openedClasses.hasKey(modalBodyClass));
        });
        checkRemoveBackdrop();

        //move focus to specified element if available, or else to body
        if (elementToReceiveFocus && elementToReceiveFocus.focus) {
          elementToReceiveFocus.focus();
        } else {
          body.focus();
        }
      }

      function checkRemoveBackdrop() {
          //remove backdrop if no longer needed
          if (backdropDomEl && backdropIndex() == -1) {
            var backdropScopeRef = backdropScope;
            removeAfterAnimate(backdropDomEl, backdropScope, function() {
              backdropScopeRef = null;
            });
            backdropDomEl = undefined;
            backdropScope = undefined;
          }
      }

      function removeAfterAnimate(domEl, scope, done) {
        var asyncDeferred;
        var asyncPromise = null;
        var setIsAsync = function() {
          if (!asyncDeferred) {
            asyncDeferred = $q.defer();
            asyncPromise = asyncDeferred.promise;
          }

          return function asyncDone() {
            asyncDeferred.resolve();
          };
        };
        scope.$broadcast($modalStack.NOW_CLOSING_EVENT, setIsAsync);

        // Note that it's intentional that asyncPromise might be null.
        // That's when setIsAsync has not been called during the
        // NOW_CLOSING_EVENT broadcast.
        return $q.when(asyncPromise).then(afterAnimating);

        function afterAnimating() {
          if (afterAnimating.done) {
            return;
          }
          afterAnimating.done = true;

          if ($animateCss) {
            $animateCss(domEl, {
              event: 'leave'
            }).start().then(function() {
              domEl.remove();
            });
          } else {
            $animate.leave(domEl);
          }
          scope.$destroy();
          if (done) {
            done();
          }
        }
      }

      $document.bind('keydown', function(evt) {
        if (evt.isDefaultPrevented()) {
          return evt;
        }

        var modal = openedWindows.top();
        if (modal && modal.value.keyboard) {
          switch (evt.which){
            case 27: {
              evt.preventDefault();
              $rootScope.$apply(function() {
                $modalStack.dismiss(modal.key, 'escape key press');
              });
              break;
            }
            case 9: {
              $modalStack.loadFocusElementList(modal);
              var focusChanged = false;
              if (evt.shiftKey) {
                if ($modalStack.isFocusInFirstItem(evt)) {
                  focusChanged = $modalStack.focusLastFocusableElement();
                }
              } else {
                if ($modalStack.isFocusInLastItem(evt)) {
                  focusChanged = $modalStack.focusFirstFocusableElement();
                }
              }

              if (focusChanged) {
                evt.preventDefault();
                evt.stopPropagation();
              }
              break;
            }
          }
        }
      });

      $modalStack.open = function(modalInstance, modal) {
        var modalOpener = $document[0].activeElement,
          modalBodyClass = modal.openedClass || OPENED_MODAL_CLASS;

        openedWindows.add(modalInstance, {
          deferred: modal.deferred,
          renderDeferred: modal.renderDeferred,
          modalScope: modal.scope,
          backdrop: modal.backdrop,
          keyboard: modal.keyboard,
          openedClass: modal.openedClass
        });

        openedClasses.put(modalBodyClass, modalInstance);

        var body = $document.find('body').eq(0),
            currBackdropIndex = backdropIndex();

        if (currBackdropIndex >= 0 && !backdropDomEl) {
          backdropScope = $rootScope.$new(true);
          backdropScope.index = currBackdropIndex;
          var angularBackgroundDomEl = angular.element('<div modal-backdrop="modal-backdrop"></div>');
          angularBackgroundDomEl.attr('backdrop-class', modal.backdropClass);
          if (modal.animation) {
            angularBackgroundDomEl.attr('modal-animation', 'true');
          }
          backdropDomEl = $compile(angularBackgroundDomEl)(backdropScope);
          body.append(backdropDomEl);
        }

        var angularDomEl = angular.element('<div modal-window="modal-window"></div>');
        angularDomEl.attr({
          'template-url': modal.windowTemplateUrl,
          'window-class': modal.windowClass,
          'size': modal.size,
          'index': openedWindows.length() - 1,
          'animate': 'animate'
        }).html(modal.content);
        if (modal.animation) {
          angularDomEl.attr('modal-animation', 'true');
        }

        var modalDomEl = $compile(angularDomEl)(modal.scope);
        openedWindows.top().value.modalDomEl = modalDomEl;
        openedWindows.top().value.modalOpener = modalOpener;
        body.append(modalDomEl);
        body.addClass(modalBodyClass);

        $modalStack.clearFocusListCache();
      };

      function broadcastClosing(modalWindow, resultOrReason, closing) {
          return !modalWindow.value.modalScope.$broadcast('modal.closing', resultOrReason, closing).defaultPrevented;
      }

      $modalStack.close = function(modalInstance, result) {
        var modalWindow = openedWindows.get(modalInstance);
        if (modalWindow && broadcastClosing(modalWindow, result, true)) {
          modalWindow.value.modalScope.$$uibDestructionScheduled = true;
          modalWindow.value.deferred.resolve(result);
          removeModalWindow(modalInstance, modalWindow.value.modalOpener);
          return true;
        }
        return !modalWindow;
      };

      $modalStack.dismiss = function(modalInstance, reason) {
        var modalWindow = openedWindows.get(modalInstance);
        if (modalWindow && broadcastClosing(modalWindow, reason, false)) {
          modalWindow.value.modalScope.$$uibDestructionScheduled = true;
          modalWindow.value.deferred.reject(reason);
          removeModalWindow(modalInstance, modalWindow.value.modalOpener);
          return true;
        }
        return !modalWindow;
      };

      $modalStack.dismissAll = function(reason) {
        var topModal = this.getTop();
        while (topModal && this.dismiss(topModal.key, reason)) {
          topModal = this.getTop();
        }
      };

      $modalStack.getTop = function() {
        return openedWindows.top();
      };

      $modalStack.modalRendered = function(modalInstance) {
        var modalWindow = openedWindows.get(modalInstance);
        if (modalWindow) {
          modalWindow.value.renderDeferred.resolve();
        }
      };

      $modalStack.focusFirstFocusableElement = function() {
        if (focusableElementList.length > 0) {
          focusableElementList[0].focus();
          return true;
        }
        return false;
      };
      $modalStack.focusLastFocusableElement = function() {
        if (focusableElementList.length > 0) {
          focusableElementList[focusableElementList.length - 1].focus();
          return true;
        }
        return false;
      };

      $modalStack.isFocusInFirstItem = function(evt) {
        if (focusableElementList.length > 0) {
          return (evt.target || evt.srcElement) == focusableElementList[0];
        }
        return false;
      };

      $modalStack.isFocusInLastItem = function(evt) {
        if (focusableElementList.length > 0) {
          return (evt.target || evt.srcElement) == focusableElementList[focusableElementList.length - 1];
        }
        return false;
      };

      $modalStack.clearFocusListCache = function() {
        focusableElementList = [];
        focusIndex = 0;
      };

      $modalStack.loadFocusElementList = function(modalWindow) {
        if (focusableElementList === undefined || !focusableElementList.length0) {
          if (modalWindow) {
            var modalDomE1 = modalWindow.value.modalDomEl;
            if (modalDomE1 && modalDomE1.length) {
              focusableElementList = modalDomE1[0].querySelectorAll(tababbleSelector);
            }
          }
        }
      };

      return $modalStack;
    }])

  .provider('$modal', function() {
    var $modalProvider = {
      options: {
        animation: true,
        backdrop: true, //can also be false or 'static'
        keyboard: true
      },
      $get: ['$injector', '$rootScope', '$q', '$templateRequest', '$controller', '$modalStack',
        function ($injector, $rootScope, $q, $templateRequest, $controller, $modalStack) {
          var $modal = {};

          function getTemplatePromise(options) {
            return options.template ? $q.when(options.template) :
              $templateRequest(angular.isFunction(options.templateUrl) ? (options.templateUrl)() : options.templateUrl);
          }

          function getResolvePromises(resolves) {
            var promisesArr = [];
            angular.forEach(resolves, function(value) {
              if (angular.isFunction(value) || angular.isArray(value)) {
                promisesArr.push($q.when($injector.invoke(value)));
              } else if (angular.isString(value)) {
                promisesArr.push($q.when($injector.get(value)));
              } else {
                promisesArr.push($q.when(value));
              }
            });
            return promisesArr;
          }

          var promiseChain = null;
          $modal.getPromiseChain = function() {
            return promiseChain;
          };

          $modal.open = function (modalOptions) {

            var modalResultDeferred = $q.defer();
            var modalOpenedDeferred = $q.defer();
            var modalRenderDeferred = $q.defer();

            //prepare an instance of a modal to be injected into controllers and returned to a caller
            var modalInstance = {
              result: modalResultDeferred.promise,
              opened: modalOpenedDeferred.promise,
              rendered: modalRenderDeferred.promise,
              close: function (result) {
                return $modalStack.close(modalInstance, result);
              },
              dismiss: function (reason) {
                return $modalStack.dismiss(modalInstance, reason);
              }
            };

            //merge and clean up options
            modalOptions = angular.extend({}, $modalProvider.options, modalOptions);
            modalOptions.resolve = modalOptions.resolve || {};

            //verify options
            if (!modalOptions.template && !modalOptions.templateUrl) {
              throw new Error('One of template or templateUrl options is required.');
            }

            var templateAndResolvePromise =
              $q.all([getTemplatePromise(modalOptions)].concat(getResolvePromises(modalOptions.resolve)));

            // Wait for the resolution of the existing promise chain.
            // Then switch to our own combined promise dependency (regardless of how the previous modal fared).
            // Then add to $modalStack and resolve opened.
            // Finally clean up the chain variable if no subsequent modal has overwritten it.
            var samePromise;
            samePromise = promiseChain = $q.all([promiseChain])
              .then(function() { return templateAndResolvePromise; }, function() { return templateAndResolvePromise; })
              .then(function resolveSuccess(tplAndVars) {

                var modalScope = (modalOptions.scope || $rootScope).$new();
                modalScope.$close = modalInstance.close;
                modalScope.$dismiss = modalInstance.dismiss;

                modalScope.$on('$destroy', function() {
                  if (!modalScope.$$uibDestructionScheduled) {
                    modalScope.$dismiss('$uibUnscheduledDestruction');
                  }
                });

                var ctrlInstance, ctrlLocals = {};
                var resolveIter = 1;

                //controllers
                if (modalOptions.controller) {
                  ctrlLocals.$scope = modalScope;
                  ctrlLocals.$modalInstance = modalInstance;
                  angular.forEach(modalOptions.resolve, function(value, key) {
                    ctrlLocals[key] = tplAndVars[resolveIter++];
                  });

                  ctrlInstance = $controller(modalOptions.controller, ctrlLocals);
                  if (modalOptions.controllerAs) {
                    if (modalOptions.bindToController) {
                      angular.extend(ctrlInstance, modalScope);
                    }

                    modalScope[modalOptions.controllerAs] = ctrlInstance;
                  }
                }

                $modalStack.open(modalInstance, {
                  scope: modalScope,
                  deferred: modalResultDeferred,
                  renderDeferred: modalRenderDeferred,
                  content: tplAndVars[0],
                  animation: modalOptions.animation,
                  backdrop: modalOptions.backdrop,
                  keyboard: modalOptions.keyboard,
                  backdropClass: modalOptions.backdropClass,
                  windowClass: modalOptions.windowClass,
                  windowTemplateUrl: modalOptions.windowTemplateUrl,
                  size: modalOptions.size,
                  openedClass: modalOptions.openedClass
                });
                modalOpenedDeferred.resolve(true);

            }, function resolveError(reason) {
              modalOpenedDeferred.reject(reason);
              modalResultDeferred.reject(reason);
            })
            .finally(function() {
              if (promiseChain === samePromise) {
                promiseChain = null;
              }
            });

            return modalInstance;
          };

          return $modal;
        }]
    };

    return $modalProvider;
  });

angular.module('ui.bootstrap.pagination', [])
.controller('PaginationController', ['$scope', '$attrs', '$parse', function($scope, $attrs, $parse) {
  var self = this,
      ngModelCtrl = { $setViewValue: angular.noop }, // nullModelCtrl
      setNumPages = $attrs.numPages ? $parse($attrs.numPages).assign : angular.noop;

  this.init = function(ngModelCtrl_, config) {
    ngModelCtrl = ngModelCtrl_;
    this.config = config;

    ngModelCtrl.$render = function() {
      self.render();
    };

    if ($attrs.itemsPerPage) {
      $scope.$parent.$watch($parse($attrs.itemsPerPage), function(value) {
        self.itemsPerPage = parseInt(value, 10);
        $scope.totalPages = self.calculateTotalPages();
      });
    } else {
      this.itemsPerPage = config.itemsPerPage;
    }

    $scope.$watch('totalItems', function() {
      $scope.totalPages = self.calculateTotalPages();
    });

    $scope.$watch('totalPages', function(value) {
      setNumPages($scope.$parent, value); // Readonly variable

      if ( $scope.page > value ) {
        $scope.selectPage(value);
      } else {
        ngModelCtrl.$render();
      }
    });
  };

  this.calculateTotalPages = function() {
    var totalPages = this.itemsPerPage < 1 ? 1 : Math.ceil($scope.totalItems / this.itemsPerPage);
    return Math.max(totalPages || 0, 1);
  };

  this.render = function() {
    $scope.page = parseInt(ngModelCtrl.$viewValue, 10) || 1;
  };

  $scope.selectPage = function(page, evt) {
    if (evt) {
      evt.preventDefault();
    }

    var clickAllowed = !$scope.ngDisabled || !evt;
    if (clickAllowed && $scope.page !== page && page > 0 && page <= $scope.totalPages) {
      if (evt && evt.target) {
        evt.target.blur();
      }
      ngModelCtrl.$setViewValue(page);
      ngModelCtrl.$render();
    }
  };

  $scope.getText = function(key) {
    return $scope[key + 'Text'] || self.config[key + 'Text'];
  };

  $scope.noPrevious = function() {
    return $scope.page === 1;
  };

  $scope.noNext = function() {
    return $scope.page === $scope.totalPages;
  };
}])

.constant('paginationConfig', {
  itemsPerPage: 10,
  boundaryLinks: false,
  directionLinks: true,
  firstText: 'First',
  previousText: 'Previous',
  nextText: 'Next',
  lastText: 'Last',
  rotate: true
})

.directive('pagination', ['$parse', 'paginationConfig', function($parse, paginationConfig) {
  return {
    restrict: 'EA',
    scope: {
      totalItems: '=',
      firstText: '@',
      previousText: '@',
      nextText: '@',
      lastText: '@',
      ngDisabled:'='
    },
    require: ['pagination', '?ngModel'],
    controller: 'PaginationController',
    controllerAs: 'pagination',
    templateUrl: function(element, attrs) {
      return attrs.templateUrl || 'template/pagination/pagination.html';
    },
    replace: true,
    link: function(scope, element, attrs, ctrls) {
      var paginationCtrl = ctrls[0], ngModelCtrl = ctrls[1];

      if (!ngModelCtrl) {
         return; // do nothing if no ng-model
      }

      // Setup configuration parameters
      var maxSize = angular.isDefined(attrs.maxSize) ? scope.$parent.$eval(attrs.maxSize) : paginationConfig.maxSize,
          rotate = angular.isDefined(attrs.rotate) ? scope.$parent.$eval(attrs.rotate) : paginationConfig.rotate;
      scope.boundaryLinks = angular.isDefined(attrs.boundaryLinks) ? scope.$parent.$eval(attrs.boundaryLinks) : paginationConfig.boundaryLinks;
      scope.directionLinks = angular.isDefined(attrs.directionLinks) ? scope.$parent.$eval(attrs.directionLinks) : paginationConfig.directionLinks;

      paginationCtrl.init(ngModelCtrl, paginationConfig);

      if (attrs.maxSize) {
        scope.$parent.$watch($parse(attrs.maxSize), function(value) {
          maxSize = parseInt(value, 10);
          paginationCtrl.render();
        });
      }

      // Create page object used in template
      function makePage(number, text, isActive) {
        return {
          number: number,
          text: text,
          active: isActive
        };
      }

      function getPages(currentPage, totalPages) {
        var pages = [];

        // Default page limits
        var startPage = 1, endPage = totalPages;
        var isMaxSized = angular.isDefined(maxSize) && maxSize < totalPages;

        // recompute if maxSize
        if (isMaxSized) {
          if (rotate) {
            // Current page is displayed in the middle of the visible ones
            startPage = Math.max(currentPage - Math.floor(maxSize/2), 1);
            endPage   = startPage + maxSize - 1;

            // Adjust if limit is exceeded
            if (endPage > totalPages) {
              endPage   = totalPages;
              startPage = endPage - maxSize + 1;
            }
          } else {
            // Visible pages are paginated with maxSize
            startPage = ((Math.ceil(currentPage / maxSize) - 1) * maxSize) + 1;

            // Adjust last page if limit is exceeded
            endPage = Math.min(startPage + maxSize - 1, totalPages);
          }
        }

        // Add page number links
        for (var number = startPage; number <= endPage; number++) {
          var page = makePage(number, number, number === currentPage);
          pages.push(page);
        }

        // Add links to move between page sets
        if (isMaxSized && ! rotate) {
          if (startPage > 1) {
            var previousPageSet = makePage(startPage - 1, '...', false);
            pages.unshift(previousPageSet);
          }

          if (endPage < totalPages) {
            var nextPageSet = makePage(endPage + 1, '...', false);
            pages.push(nextPageSet);
          }
        }

        return pages;
      }

      var originalRender = paginationCtrl.render;
      paginationCtrl.render = function() {
        originalRender();
        if (scope.page > 0 && scope.page <= scope.totalPages) {
          scope.pages = getPages(scope.page, scope.totalPages);
        }
      };
    }
  };
}])

.constant('pagerConfig', {
  itemsPerPage: 10,
  previousText: '« Previous',
  nextText: 'Next »',
  align: true
})

.directive('pager', ['pagerConfig', function(pagerConfig) {
  return {
    restrict: 'EA',
    scope: {
      totalItems: '=',
      previousText: '@',
      nextText: '@',
      ngDisabled: '='
    },
    require: ['pager', '?ngModel'],
    controller: 'PaginationController',
    controllerAs: 'pagination',
    templateUrl: function(element, attrs) {
      return attrs.templateUrl || 'template/pagination/pager.html';
    },
    replace: true,
    link: function(scope, element, attrs, ctrls) {
      var paginationCtrl = ctrls[0], ngModelCtrl = ctrls[1];

      if (!ngModelCtrl) {
         return; // do nothing if no ng-model
      }

      scope.align = angular.isDefined(attrs.align) ? scope.$parent.$eval(attrs.align) : pagerConfig.align;
      paginationCtrl.init(ngModelCtrl, pagerConfig);
    }
  };
}]);

/**
 * The following features are still outstanding: animation as a
 * function, placement as a function, inside, support for more triggers than
 * just mouse enter/leave, html tooltips, and selector delegation.
 */
angular.module('ui.bootstrap.tooltip', ['ui.bootstrap.position', 'ui.bootstrap.bindHtml'])

/**
 * The $tooltip service creates tooltip- and popover-like directives as well as
 * houses global options for them.
 */
.provider('$tooltip', function() {
  // The default options tooltip and popover.
  var defaultOptions = {
    placement: 'top',
    animation: true,
    popupDelay: 0,
    useContentExp: false
  };

  // Default hide triggers for each show trigger
  var triggerMap = {
    'mouseenter': 'mouseleave',
    'click': 'click',
    'focus': 'blur',
    'none': ''
  };

  // The options specified to the provider globally.
  var globalOptions = {};

  /**
   * `options({})` allows global configuration of all tooltips in the
   * application.
   *
   *   var app = angular.module( 'App', ['ui.bootstrap.tooltip'], function( $tooltipProvider ) {
   *     // place tooltips left instead of top by default
   *     $tooltipProvider.options( { placement: 'left' } );
   *   });
   */
	this.options = function(value) {
		angular.extend(globalOptions, value);
	};

  /**
   * This allows you to extend the set of trigger mappings available. E.g.:
   *
   *   $tooltipProvider.setTriggers( 'openTrigger': 'closeTrigger' );
   */
  this.setTriggers = function setTriggers(triggers) {
    angular.extend(triggerMap, triggers);
  };

  /**
   * This is a helper function for translating camel-case to snake-case.
   */
  function snake_case(name) {
    var regexp = /[A-Z]/g;
    var separator = '-';
    return name.replace(regexp, function(letter, pos) {
      return (pos ? separator : '') + letter.toLowerCase();
    });
  }

  /**
   * Returns the actual instance of the $tooltip service.
   * TODO support multiple triggers
   */
  this.$get = ['$window', '$compile', '$timeout', '$document', '$position', '$interpolate', '$rootScope', '$parse', function($window, $compile, $timeout, $document, $position, $interpolate, $rootScope, $parse) {
    return function $tooltip(type, prefix, defaultTriggerShow, options) {
      options = angular.extend({}, defaultOptions, globalOptions, options);

      /**
       * Returns an object of show and hide triggers.
       *
       * If a trigger is supplied,
       * it is used to show the tooltip; otherwise, it will use the `trigger`
       * option passed to the `$tooltipProvider.options` method; else it will
       * default to the trigger supplied to this directive factory.
       *
       * The hide trigger is based on the show trigger. If the `trigger` option
       * was passed to the `$tooltipProvider.options` method, it will use the
       * mapped trigger from `triggerMap` or the passed trigger if the map is
       * undefined; otherwise, it uses the `triggerMap` value of the show
       * trigger; else it will just use the show trigger.
       */
      function getTriggers(trigger) {
        var show = (trigger || options.trigger || defaultTriggerShow).split(' ');
        var hide = show.map(function(trigger) {
          return triggerMap[trigger] || trigger;
        });
        return {
          show: show,
          hide: hide
        };
      }

      var directiveName = snake_case(type);

      var startSym = $interpolate.startSymbol();
      var endSym = $interpolate.endSymbol();
      var template =
        '<div '+ directiveName +'-popup '+
          'title="'+startSym+'title'+endSym+'" '+
          (options.useContentExp ?
            'content-exp="contentExp()" ' :
            'content="'+startSym+'content'+endSym+'" ') +
          'placement="'+startSym+'placement'+endSym+'" '+
          'popup-class="'+startSym+'popupClass'+endSym+'" '+
          'animation="animation" '+
          'is-open="isOpen"'+
          'origin-scope="origScope" '+
          '>'+
        '</div>';

      return {
        restrict: 'EA',
        compile: function(tElem, tAttrs) {
          var tooltipLinker = $compile( template );

          return function link(scope, element, attrs, tooltipCtrl) {
            var tooltip;
            var tooltipLinkedScope;
            var transitionTimeout;
            var popupTimeout;
            var positionTimeout;
            var appendToBody = angular.isDefined(options.appendToBody) ? options.appendToBody : false;
            var triggers = getTriggers(undefined);
            var hasEnableExp = angular.isDefined(attrs[prefix + 'Enable']);
            var ttScope = scope.$new(true);
            var repositionScheduled = false;
            var isOpenExp = angular.isDefined(attrs[prefix + 'IsOpen']) ? $parse(attrs[prefix + 'IsOpen']) : false;

            var positionTooltip = function() {
              if (!tooltip) { return; }

              if (!positionTimeout) {
                positionTimeout = $timeout(function() {
                  // Reset the positioning and box size for correct width and height values.
                  tooltip.css({ top: 0, left: 0, width: 'auto', height: 'auto' });

                  var ttBox = $position.position(tooltip);
                  var ttCss = $position.positionElements(element, tooltip, ttScope.placement, appendToBody);
                  ttCss.top += 'px';
                  ttCss.left += 'px';

                  ttCss.width = ttBox.width + 'px';
                  ttCss.height = ttBox.height + 'px';

                  // Now set the calculated positioning and size.
                  tooltip.css(ttCss);

                  positionTimeout = null;

                }, 0, false);
              }
            };

            // Set up the correct scope to allow transclusion later
            ttScope.origScope = scope;

            // By default, the tooltip is not open.
            // TODO add ability to start tooltip opened
            ttScope.isOpen = false;

            function toggleTooltipBind() {
              if (!ttScope.isOpen) {
                showTooltipBind();
              } else {
                hideTooltipBind();
              }
            }

            // Show the tooltip with delay if specified, otherwise show it immediately
            function showTooltipBind() {
              if (hasEnableExp && !scope.$eval(attrs[prefix + 'Enable'])) {
                return;
              }

              prepareTooltip();

              if (ttScope.popupDelay) {
                // Do nothing if the tooltip was already scheduled to pop-up.
                // This happens if show is triggered multiple times before any hide is triggered.
                if (!popupTimeout) {
                  popupTimeout = $timeout(show, ttScope.popupDelay, false);
                }
              } else {
                show();
              }
            }

            function hideTooltipBind () {
              hide();
              if (!$rootScope.$$phase) {
                $rootScope.$digest();
              }
            }

            // Show the tooltip popup element.
            function show() {
              popupTimeout = null;

              // If there is a pending remove transition, we must cancel it, lest the
              // tooltip be mysteriously removed.
              if (transitionTimeout) {
                $timeout.cancel(transitionTimeout);
                transitionTimeout = null;
              }

              // Don't show empty tooltips.
              if (!(options.useContentExp ? ttScope.contentExp() : ttScope.content)) {
                return angular.noop;
              }

              createTooltip();

              // And show the tooltip.
              ttScope.isOpen = true;
              if (isOpenExp) {
                isOpenExp.assign(ttScope.origScope, ttScope.isOpen);
              }

              if (!$rootScope.$$phase) {
                ttScope.$apply(); // digest required as $apply is not called
              }

              tooltip.css({ display: 'block' });

              positionTooltip();
            }

            // Hide the tooltip popup element.
            function hide() {
              // First things first: we don't show it anymore.
              ttScope.isOpen = false;
              if (isOpenExp) {
                isOpenExp.assign(ttScope.origScope, ttScope.isOpen);
              }

              //if tooltip is going to be shown after delay, we must cancel this
              $timeout.cancel(popupTimeout);
              popupTimeout = null;

              $timeout.cancel(positionTimeout);
              positionTimeout = null;

              // And now we remove it from the DOM. However, if we have animation, we
              // need to wait for it to expire beforehand.
              // FIXME: this is a placeholder for a port of the transitions library.
              if (ttScope.animation) {
                if (!transitionTimeout) {
                  transitionTimeout = $timeout(removeTooltip, 500);
                }
              } else {
                removeTooltip();
              }
            }

            function createTooltip() {
              // There can only be one tooltip element per directive shown at once.
              if (tooltip) {
                removeTooltip();
              }
              tooltipLinkedScope = ttScope.$new();
              tooltip = tooltipLinker(tooltipLinkedScope, function(tooltip) {
                if (appendToBody) {
                  $document.find('body').append(tooltip);
                } else {
                  element.after(tooltip);
                }
              });

              if (options.useContentExp) {
                tooltipLinkedScope.$watch('contentExp()', function(val) {
                  if (!val && ttScope.isOpen) {
                    hide();
                  }
                });

                tooltipLinkedScope.$watch(function() {
                  if (!repositionScheduled) {
                    repositionScheduled = true;
                    tooltipLinkedScope.$$postDigest(function() {
                      repositionScheduled = false;
                      if (ttScope.isOpen) {
                        positionTooltip();
                      }
                    });
                  }
                });

              }
            }

            function removeTooltip() {
              transitionTimeout = null;
              if (tooltip) {
                tooltip.remove();
                tooltip = null;
              }
              if (tooltipLinkedScope) {
                tooltipLinkedScope.$destroy();
                tooltipLinkedScope = null;
              }
            }

            function prepareTooltip() {
              prepPopupClass();
              prepPlacement();
              prepPopupDelay();
            }

            ttScope.contentExp = function() {
              return scope.$eval(attrs[type]);
            };

            /**
             * Observe the relevant attributes.
             */
            if (!options.useContentExp) {
              attrs.$observe(type, function(val) {
                ttScope.content = val;

                if (!val && ttScope.isOpen) {
                  hide();
                } else {
                  positionTooltip();
                }
              });
            }

            attrs.$observe('disabled', function(val) {
              if (popupTimeout && val) {
                $timeout.cancel(popupTimeout);
                popupTimeout = null;
              }

              if (val && ttScope.isOpen) {
                hide();
              }
            });

            attrs.$observe(prefix + 'Title', function(val) {
              ttScope.title = val;
              positionTooltip();
            });

            attrs.$observe(prefix + 'Placement', function() {
              if (ttScope.isOpen) {
                prepPlacement();
                positionTooltip();
              }
            });

            if (isOpenExp) {
              scope.$watch(isOpenExp, function(val) {
                if (val !== ttScope.isOpen) {
                  toggleTooltipBind();
                }
              });
            }

            function prepPopupClass() {
              ttScope.popupClass = attrs[prefix + 'Class'];
            }

            function prepPlacement() {
              var val = attrs[prefix + 'Placement'];
              ttScope.placement = angular.isDefined(val) ? val : options.placement;
            }

            function prepPopupDelay() {
              var val = attrs[prefix + 'PopupDelay'];
              var delay = parseInt(val, 10);
              ttScope.popupDelay = !isNaN(delay) ? delay : options.popupDelay;
            }

            var unregisterTriggers = function() {
              triggers.show.forEach(function(trigger) {
                element.unbind(trigger, showTooltipBind);
              });
              triggers.hide.forEach(function(trigger) {
                element.unbind(trigger, hideTooltipBind);
              });
            };

            function prepTriggers() {
              var val = attrs[prefix + 'Trigger'];
              unregisterTriggers();

              triggers = getTriggers(val);

              if (triggers.show !== 'none') {
                triggers.show.forEach(function(trigger, idx) {
                  // Using raw addEventListener due to jqLite/jQuery bug - #4060
                  if (trigger === triggers.hide[idx]) {
                    element[0].addEventListener(trigger, toggleTooltipBind);
                  } else if (trigger) {
                    element[0].addEventListener(trigger, showTooltipBind);
                    element[0].addEventListener(triggers.hide[idx], hideTooltipBind);
                  }
                });
              }
            }
            prepTriggers();

            var animation = scope.$eval(attrs[prefix + 'Animation']);
            ttScope.animation = angular.isDefined(animation) ? !!animation : options.animation;

            var appendToBodyVal = scope.$eval(attrs[prefix + 'AppendToBody']);
            appendToBody = angular.isDefined(appendToBodyVal) ? appendToBodyVal : appendToBody;

            // if a tooltip is attached to <body> we need to remove it on
            // location change as its parent scope will probably not be destroyed
            // by the change.
            if (appendToBody) {
              scope.$on('$locationChangeSuccess', function closeTooltipOnLocationChangeSuccess() {
                if (ttScope.isOpen) {
                  hide();
                }
              });
            }

            // Make sure tooltip is destroyed and removed.
            scope.$on('$destroy', function onDestroyTooltip() {
              $timeout.cancel(transitionTimeout);
              $timeout.cancel(popupTimeout);
              $timeout.cancel(positionTimeout);
              unregisterTriggers();
              removeTooltip();
              ttScope = null;
            });
          };
        }
      };
    };
  }];
})

// This is mostly ngInclude code but with a custom scope
.directive('tooltipTemplateTransclude', [
         '$animate', '$sce', '$compile', '$templateRequest',
function ($animate ,  $sce ,  $compile ,  $templateRequest) {
  return {
    link: function(scope, elem, attrs) {
      var origScope = scope.$eval(attrs.tooltipTemplateTranscludeScope);

      var changeCounter = 0,
        currentScope,
        previousElement,
        currentElement;

      var cleanupLastIncludeContent = function() {
        if (previousElement) {
          previousElement.remove();
          previousElement = null;
        }
        if (currentScope) {
          currentScope.$destroy();
          currentScope = null;
        }
        if (currentElement) {
          $animate.leave(currentElement).then(function() {
            previousElement = null;
          });
          previousElement = currentElement;
          currentElement = null;
        }
      };

      scope.$watch($sce.parseAsResourceUrl(attrs.tooltipTemplateTransclude), function(src) {
        var thisChangeId = ++changeCounter;

        if (src) {
          //set the 2nd param to true to ignore the template request error so that the inner
          //contents and scope can be cleaned up.
          $templateRequest(src, true).then(function(response) {
            if (thisChangeId !== changeCounter) { return; }
            var newScope = origScope.$new();
            var template = response;

            var clone = $compile(template)(newScope, function(clone) {
              cleanupLastIncludeContent();
              $animate.enter(clone, elem);
            });

            currentScope = newScope;
            currentElement = clone;

            currentScope.$emit('$includeContentLoaded', src);
          }, function() {
            if (thisChangeId === changeCounter) {
              cleanupLastIncludeContent();
              scope.$emit('$includeContentError', src);
            }
          });
          scope.$emit('$includeContentRequested', src);
        } else {
          cleanupLastIncludeContent();
        }
      });

      scope.$on('$destroy', cleanupLastIncludeContent);
    }
  };
}])

/**
 * Note that it's intentional that these classes are *not* applied through $animate.
 * They must not be animated as they're expected to be present on the tooltip on
 * initialization.
 */
.directive('tooltipClasses', function() {
  return {
    restrict: 'A',
    link: function(scope, element, attrs) {
      if (scope.placement) {
        element.addClass(scope.placement);
      }
      if (scope.popupClass) {
        element.addClass(scope.popupClass);
      }
      if (scope.animation()) {
        element.addClass(attrs.tooltipAnimationClass);
      }
    }
  };
})

.directive('tooltipPopup', function() {
  return {
    restrict: 'EA',
    replace: true,
    scope: { content: '@', placement: '@', popupClass: '@', animation: '&', isOpen: '&' },
    templateUrl: 'template/tooltip/tooltip-popup.html'
  };
})

.directive('tooltip', [ '$tooltip', function($tooltip) {
  return $tooltip('tooltip', 'tooltip', 'mouseenter');
}])

.directive('tooltipTemplatePopup', function() {
  return {
    restrict: 'EA',
    replace: true,
    scope: { contentExp: '&', placement: '@', popupClass: '@', animation: '&', isOpen: '&',
      originScope: '&' },
    templateUrl: 'template/tooltip/tooltip-template-popup.html'
  };
})

.directive('tooltipTemplate', ['$tooltip', function($tooltip) {
  return $tooltip('tooltipTemplate', 'tooltip', 'mouseenter', {
    useContentExp: true
  });
}])

.directive('tooltipHtmlPopup', function() {
  return {
    restrict: 'EA',
    replace: true,
    scope: { contentExp: '&', placement: '@', popupClass: '@', animation: '&', isOpen: '&' },
    templateUrl: 'template/tooltip/tooltip-html-popup.html'
  };
})

.directive('tooltipHtml', ['$tooltip', function($tooltip) {
  return $tooltip('tooltipHtml', 'tooltip', 'mouseenter', {
    useContentExp: true
  });
}])

/*
Deprecated
*/
.directive('tooltipHtmlUnsafePopup', function() {
  return {
    restrict: 'EA',
    replace: true,
    scope: { content: '@', placement: '@', popupClass: '@', animation: '&', isOpen: '&' },
    templateUrl: 'template/tooltip/tooltip-html-unsafe-popup.html'
  };
})

.value('tooltipHtmlUnsafeSuppressDeprecated', false)
.directive('tooltipHtmlUnsafe', [
          '$tooltip', 'tooltipHtmlUnsafeSuppressDeprecated', '$log',
function($tooltip ,  tooltipHtmlUnsafeSuppressDeprecated ,  $log) {
  if (!tooltipHtmlUnsafeSuppressDeprecated) {
    $log.warn('tooltip-html-unsafe is now deprecated. Use tooltip-html or tooltip-template instead.');
  }
  return $tooltip('tooltipHtmlUnsafe', 'tooltip', 'mouseenter');
}]);

/**
 * The following features are still outstanding: popup delay, animation as a
 * function, placement as a function, inside, support for more triggers than
 * just mouse enter/leave, and selector delegatation.
 */
angular.module( 'ui.bootstrap.popover', ['ui.bootstrap.tooltip'])

.directive('popoverTemplatePopup', function() {
  return {
    restrict: 'EA',
    replace: true,
    scope: { title: '@', contentExp: '&', placement: '@', popupClass: '@', animation: '&', isOpen: '&',
      originScope: '&' },
    templateUrl: 'template/popover/popover-template.html'
  };
})

.directive('popoverTemplate', ['$tooltip', function($tooltip) {
  return $tooltip('popoverTemplate', 'popover', 'click', {
    useContentExp: true
  });
}])

.directive('popoverHtmlPopup', function() {
  return {
    restrict: 'EA',
    replace: true,
    scope: { contentExp: '&', title: '@', placement: '@', popupClass: '@', animation: '&', isOpen: '&' },
    templateUrl: 'template/popover/popover-html.html'
  };
})

.directive('popoverHtml', ['$tooltip', function($tooltip) {
  return $tooltip( 'popoverHtml', 'popover', 'click', {
    useContentExp: true
  });
}])

.directive('popoverPopup', function() {
  return {
    restrict: 'EA',
    replace: true,
    scope: { title: '@', content: '@', placement: '@', popupClass: '@', animation: '&', isOpen: '&' },
    templateUrl: 'template/popover/popover.html'
  };
})

.directive('popover', ['$tooltip', function($tooltip) {
  return $tooltip( 'popover', 'popover', 'click' );
}]);

angular.module('ui.bootstrap.progressbar', [])

.constant('progressConfig', {
  animate: true,
  max: 100
})

.value('$progressSuppressWarning', false)

.controller('ProgressController', ['$scope', '$attrs', 'progressConfig', function($scope, $attrs, progressConfig) {
  var self = this,
      animate = angular.isDefined($attrs.animate) ? $scope.$parent.$eval($attrs.animate) : progressConfig.animate;

  this.bars = [];
  $scope.max = angular.isDefined($scope.max) ? $scope.max : progressConfig.max;

  this.addBar = function(bar, element) {
    if (!animate) {
      element.css({'transition': 'none'});
    }

    this.bars.push(bar);

    bar.max = $scope.max;

    bar.$watch('value', function(value) {
      bar.recalculatePercentage();
    });

    bar.recalculatePercentage = function() {
      bar.percent = +(100 * bar.value / bar.max).toFixed(2);

      var totalPercentage = self.bars.reduce(function(total, bar) {
        return total + bar.percent;
      }, 0);

      if (totalPercentage > 100) {
        bar.percent -= totalPercentage - 100;
      }
    };

    bar.$on('$destroy', function() {
      element = null;
      self.removeBar(bar);
    });
  };

  this.removeBar = function(bar) {
      this.bars.splice(this.bars.indexOf(bar), 1);
  };

  $scope.$watch('max', function(max) {
    self.bars.forEach(function(bar) {
      bar.max = $scope.max;
      bar.recalculatePercentage();
    });
  });
}])

.directive('uibProgress', function() {
  return {
    restrict: 'EA',
    replace: true,
    transclude: true,
    controller: 'ProgressController',
    require: 'uibProgress',
    scope: {
      max: '=?'
    },
    templateUrl: 'template/progressbar/progress.html'
  };
})

.directive('progress', ['$log', '$progressSuppressWarning', function($log, $progressSuppressWarning) {
  return {
    restrict: 'EA',
    replace: true,
    transclude: true,
    controller: 'ProgressController',
    require: 'progress',
    scope: {
      max: '=?'
    },
    templateUrl: 'template/progressbar/progress.html',
    link: function() {
      if ($progressSuppressWarning) {
        $log.warn('progress is now deprecated. Use uib-progress instead');
      }
    }
  };
}])

.directive('uibBar', function() {
  return {
    restrict: 'EA',
    replace: true,
    transclude: true,
    require: '^uibProgress',
    scope: {
      value: '=',
      type: '@'
    },
    templateUrl: 'template/progressbar/bar.html',
    link: function(scope, element, attrs, progressCtrl) {
      progressCtrl.addBar(scope, element);
    }
  };
})

.directive('bar', ['$log', '$progressSuppressWarning', function($log, $progressSuppressWarning) {
  return {
    restrict: 'EA',
    replace: true,
    transclude: true,
    require: '^progress',
    scope: {
      value: '=',
      type: '@'
    },
    templateUrl: 'template/progressbar/bar.html',
    link: function(scope, element, attrs, progressCtrl) {
      if ($progressSuppressWarning) {
        $log.warn('bar is now deprecated. Use uib-bar instead');
      }
      progressCtrl.addBar(scope, element);
    }
  };
}])

.directive('progressbar', function() {
  return {
    restrict: 'EA',
    replace: true,
    transclude: true,
    controller: 'ProgressController',
    scope: {
      value: '=',
      max: '=?',
      type: '@'
    },
    templateUrl: 'template/progressbar/progressbar.html',
    link: function(scope, element, attrs, progressCtrl) {
      progressCtrl.addBar(scope, angular.element(element.children()[0]));
    }
  };
});

angular.module('ui.bootstrap.rating', [])

.constant('ratingConfig', {
  max: 5,
  stateOn: null,
  stateOff: null,
  titles : ['one', 'two', 'three', 'four', 'five']
})

.controller('RatingController', ['$scope', '$attrs', 'ratingConfig', function($scope, $attrs, ratingConfig) {
  var ngModelCtrl  = { $setViewValue: angular.noop };

  this.init = function(ngModelCtrl_) {
    ngModelCtrl = ngModelCtrl_;
    ngModelCtrl.$render = this.render;

    ngModelCtrl.$formatters.push(function(value) {
      if (angular.isNumber(value) && value << 0 !== value) {
        value = Math.round(value);
      }
      return value;
    });

    this.stateOn = angular.isDefined($attrs.stateOn) ? $scope.$parent.$eval($attrs.stateOn) : ratingConfig.stateOn;
    this.stateOff = angular.isDefined($attrs.stateOff) ? $scope.$parent.$eval($attrs.stateOff) : ratingConfig.stateOff;
    var tmpTitles = angular.isDefined($attrs.titles)  ? $scope.$parent.$eval($attrs.titles) : ratingConfig.titles ;    
    this.titles = angular.isArray(tmpTitles) && tmpTitles.length > 0 ?
      tmpTitles : ratingConfig.titles;
    
    var ratingStates = angular.isDefined($attrs.ratingStates) ?
      $scope.$parent.$eval($attrs.ratingStates) :
      new Array(angular.isDefined($attrs.max) ? $scope.$parent.$eval($attrs.max) : ratingConfig.max);
    $scope.range = this.buildTemplateObjects(ratingStates);
  };

  this.buildTemplateObjects = function(states) {
    for (var i = 0, n = states.length; i < n; i++) {
      states[i] = angular.extend({ index: i }, { stateOn: this.stateOn, stateOff: this.stateOff, title: this.getTitle(i) }, states[i]);
    }
    return states;
  };
  
  this.getTitle = function(index) {
    if (index >= this.titles.length) {
      return index + 1;
    } else {
      return this.titles[index];
    }
  };
  
  $scope.rate = function(value) {
    if (!$scope.readonly && value >= 0 && value <= $scope.range.length) {
      ngModelCtrl.$setViewValue(ngModelCtrl.$viewValue === value ? 0 : value);
      ngModelCtrl.$render();
    }
  };

  $scope.enter = function(value) {
    if (!$scope.readonly) {
      $scope.value = value;
    }
    $scope.onHover({value: value});
  };

  $scope.reset = function() {
    $scope.value = ngModelCtrl.$viewValue;
    $scope.onLeave();
  };

  $scope.onKeydown = function(evt) {
    if (/(37|38|39|40)/.test(evt.which)) {
      evt.preventDefault();
      evt.stopPropagation();
      $scope.rate($scope.value + (evt.which === 38 || evt.which === 39 ? 1 : -1));
    }
  };

  this.render = function() {
    $scope.value = ngModelCtrl.$viewValue;
  };
}])

.directive('rating', function() {
  return {
    restrict: 'EA',
    require: ['rating', 'ngModel'],
    scope: {
      readonly: '=?',
      onHover: '&',
      onLeave: '&'
    },
    controller: 'RatingController',
    templateUrl: 'template/rating/rating.html',
    replace: true,
    link: function(scope, element, attrs, ctrls) {
      var ratingCtrl = ctrls[0], ngModelCtrl = ctrls[1];
      ratingCtrl.init( ngModelCtrl );
    }
  };
});


/**
 * @ngdoc overview
 * @name ui.bootstrap.tabs
 *
 * @description
 * AngularJS version of the tabs directive.
 */

angular.module('ui.bootstrap.tabs', [])

.controller('TabsetController', ['$scope', function TabsetCtrl($scope) {
  var ctrl = this,
      tabs = ctrl.tabs = $scope.tabs = [];

  ctrl.select = function(selectedTab) {
    angular.forEach(tabs, function(tab) {
      if (tab.active && tab !== selectedTab) {
        tab.active = false;
        tab.onDeselect();
        selectedTab.selectCalled = false;
      }
    });
    selectedTab.active = true;
    // only call select if it has not already been called
    if (!selectedTab.selectCalled) {
      selectedTab.onSelect();
      selectedTab.selectCalled = true;
    }
  };

  ctrl.addTab = function addTab(tab) {
    tabs.push(tab);
    // we can't run the select function on the first tab
    // since that would select it twice
    if (tabs.length === 1 && tab.active !== false) {
      tab.active = true;
    } else if (tab.active) {
      ctrl.select(tab);
    } else {
      tab.active = false;
    }
  };

  ctrl.removeTab = function removeTab(tab) {
    var index = tabs.indexOf(tab);
    //Select a new tab if the tab to be removed is selected and not destroyed
    if (tab.active && tabs.length > 1 && !destroyed) {
      //If this is the last tab, select the previous tab. else, the next tab.
      var newActiveIndex = index == tabs.length - 1 ? index - 1 : index + 1;
      ctrl.select(tabs[newActiveIndex]);
    }
    tabs.splice(index, 1);
  };

  var destroyed;
  $scope.$on('$destroy', function() {
    destroyed = true;
  });
}])

/**
 * @ngdoc directive
 * @name ui.bootstrap.tabs.directive:tabset
 * @restrict EA
 *
 * @description
 * Tabset is the outer container for the tabs directive
 *
 * @param {boolean=} vertical Whether or not to use vertical styling for the tabs.
 * @param {boolean=} justified Whether or not to use justified styling for the tabs.
 *
 * @example
<example module="ui.bootstrap">
  <file name="index.html">
    <tabset>
      <tab heading="Tab 1"><b>First</b> Content!</tab>
      <tab heading="Tab 2"><i>Second</i> Content!</tab>
    </tabset>
    <hr />
    <tabset vertical="true">
      <tab heading="Vertical Tab 1"><b>First</b> Vertical Content!</tab>
      <tab heading="Vertical Tab 2"><i>Second</i> Vertical Content!</tab>
    </tabset>
    <tabset justified="true">
      <tab heading="Justified Tab 1"><b>First</b> Justified Content!</tab>
      <tab heading="Justified Tab 2"><i>Second</i> Justified Content!</tab>
    </tabset>
  </file>
</example>
 */
.directive('tabset', function() {
  return {
    restrict: 'EA',
    transclude: true,
    replace: true,
    scope: {
      type: '@'
    },
    controller: 'TabsetController',
    templateUrl: 'template/tabs/tabset.html',
    link: function(scope, element, attrs) {
      scope.vertical = angular.isDefined(attrs.vertical) ? scope.$parent.$eval(attrs.vertical) : false;
      scope.justified = angular.isDefined(attrs.justified) ? scope.$parent.$eval(attrs.justified) : false;
    }
  };
})

/**
 * @ngdoc directive
 * @name ui.bootstrap.tabs.directive:tab
 * @restrict EA
 *
 * @param {string=} heading The visible heading, or title, of the tab. Set HTML headings with {@link ui.bootstrap.tabs.directive:tabHeading tabHeading}.
 * @param {string=} select An expression to evaluate when the tab is selected.
 * @param {boolean=} active A binding, telling whether or not this tab is selected.
 * @param {boolean=} disabled A binding, telling whether or not this tab is disabled.
 *
 * @description
 * Creates a tab with a heading and content. Must be placed within a {@link ui.bootstrap.tabs.directive:tabset tabset}.
 *
 * @example
<example module="ui.bootstrap">
  <file name="index.html">
    <div ng-controller="TabsDemoCtrl">
      <button class="btn btn-small" ng-click="items[0].active = true">
        Select item 1, using active binding
      </button>
      <button class="btn btn-small" ng-click="items[1].disabled = !items[1].disabled">
        Enable/disable item 2, using disabled binding
      </button>
      <br />
      <tabset>
        <tab heading="Tab 1">First Tab</tab>
        <tab select="alertMe()">
          <tab-heading><i class="icon-bell"></i> Alert me!</tab-heading>
          Second Tab, with alert callback and html heading!
        </tab>
        <tab ng-repeat="item in items"
          heading="{{item.title}}"
          disabled="item.disabled"
          active="item.active">
          {{item.content}}
        </tab>
      </tabset>
    </div>
  </file>
  <file name="script.js">
    function TabsDemoCtrl($scope) {
      $scope.items = [
        { title:"Dynamic Title 1", content:"Dynamic Item 0" },
        { title:"Dynamic Title 2", content:"Dynamic Item 1", disabled: true }
      ];

      $scope.alertMe = function() {
        setTimeout(function() {
          alert("You've selected the alert tab!");
        });
      };
    };
  </file>
</example>
 */

/**
 * @ngdoc directive
 * @name ui.bootstrap.tabs.directive:tabHeading
 * @restrict EA
 *
 * @description
 * Creates an HTML heading for a {@link ui.bootstrap.tabs.directive:tab tab}. Must be placed as a child of a tab element.
 *
 * @example
<example module="ui.bootstrap">
  <file name="index.html">
    <tabset>
      <tab>
        <tab-heading><b>HTML</b> in my titles?!</tab-heading>
        And some content, too!
      </tab>
      <tab>
        <tab-heading><i class="icon-heart"></i> Icon heading?!?</tab-heading>
        That's right.
      </tab>
    </tabset>
  </file>
</example>
 */
.directive('tab', ['$parse', '$log', function($parse, $log) {
  return {
    require: '^tabset',
    restrict: 'EA',
    replace: true,
    templateUrl: 'template/tabs/tab.html',
    transclude: true,
    scope: {
      active: '=?',
      heading: '@',
      onSelect: '&select', //This callback is called in contentHeadingTransclude
                          //once it inserts the tab's content into the dom
      onDeselect: '&deselect'
    },
    controller: function() {
      //Empty controller so other directives can require being 'under' a tab
    },
    link: function(scope, elm, attrs, tabsetCtrl, transclude) {
      scope.$watch('active', function(active) {
        if (active) {
          tabsetCtrl.select(scope);
        }
      });

      scope.disabled = false;
      if (attrs.disable) {
        scope.$parent.$watch($parse(attrs.disable), function(value) {
          scope.disabled = !! value;
        });
      }

      // Deprecation support of "disabled" parameter
      // fix(tab): IE9 disabled attr renders grey text on enabled tab #2677
      // This code is duplicated from the lines above to make it easy to remove once
      // the feature has been completely deprecated
      if (attrs.disabled) {
        $log.warn('Use of "disabled" attribute has been deprecated, please use "disable"');
        scope.$parent.$watch($parse(attrs.disabled), function(value) {
          scope.disabled = !! value;
        });
      }

      scope.select = function() {
        if (!scope.disabled) {
          scope.active = true;
        }
      };

      tabsetCtrl.addTab(scope);
      scope.$on('$destroy', function() {
        tabsetCtrl.removeTab(scope);
      });

      //We need to transclude later, once the content container is ready.
      //when this link happens, we're inside a tab heading.
      scope.$transcludeFn = transclude;
    }
  };
}])

.directive('tabHeadingTransclude', function() {
  return {
    restrict: 'A',
    require: '^tab',
    link: function(scope, elm, attrs, tabCtrl) {
      scope.$watch('headingElement', function updateHeadingElement(heading) {
        if (heading) {
          elm.html('');
          elm.append(heading);
        }
      });
    }
  };
})

.directive('tabContentTransclude', function() {
  return {
    restrict: 'A',
    require: '^tabset',
    link: function(scope, elm, attrs) {
      var tab = scope.$eval(attrs.tabContentTransclude);

      //Now our tab is ready to be transcluded: both the tab heading area
      //and the tab content area are loaded.  Transclude 'em both.
      tab.$transcludeFn(tab.$parent, function(contents) {
        angular.forEach(contents, function(node) {
          if (isTabHeading(node)) {
            //Let tabHeadingTransclude know.
            tab.headingElement = node;
          } else {
            elm.append(node);
          }
        });
      });
    }
  };

  function isTabHeading(node) {
    return node.tagName && (
      node.hasAttribute('tab-heading') ||
      node.hasAttribute('data-tab-heading') ||
      node.hasAttribute('x-tab-heading') ||
      node.tagName.toLowerCase() === 'tab-heading' ||
      node.tagName.toLowerCase() === 'data-tab-heading' ||
      node.tagName.toLowerCase() === 'x-tab-heading'
    );
  }
});

angular.module('ui.bootstrap.timepicker', [])

.constant('timepickerConfig', {
  hourStep: 1,
  minuteStep: 1,
  showMeridian: true,
  meridians: null,
  readonlyInput: false,
  mousewheel: true,
  arrowkeys: true,
  showSpinners: true
})

.controller('TimepickerController', ['$scope', '$attrs', '$parse', '$log', '$locale', 'timepickerConfig', function($scope, $attrs, $parse, $log, $locale, timepickerConfig) {
  var selected = new Date(),
      ngModelCtrl = { $setViewValue: angular.noop }, // nullModelCtrl
      meridians = angular.isDefined($attrs.meridians) ? $scope.$parent.$eval($attrs.meridians) : timepickerConfig.meridians || $locale.DATETIME_FORMATS.AMPMS;

  this.init = function(ngModelCtrl_, inputs) {
    ngModelCtrl = ngModelCtrl_;
    ngModelCtrl.$render = this.render;

    ngModelCtrl.$formatters.unshift(function(modelValue) {
      return modelValue ? new Date(modelValue) : null;
    });

    var hoursInputEl = inputs.eq(0),
        minutesInputEl = inputs.eq(1);

    var mousewheel = angular.isDefined($attrs.mousewheel) ? $scope.$parent.$eval($attrs.mousewheel) : timepickerConfig.mousewheel;
    if (mousewheel) {
      this.setupMousewheelEvents(hoursInputEl, minutesInputEl);
    }

    var arrowkeys = angular.isDefined($attrs.arrowkeys) ? $scope.$parent.$eval($attrs.arrowkeys) : timepickerConfig.arrowkeys;
    if (arrowkeys) {
      this.setupArrowkeyEvents(hoursInputEl, minutesInputEl);
    }

    $scope.readonlyInput = angular.isDefined($attrs.readonlyInput) ? $scope.$parent.$eval($attrs.readonlyInput) : timepickerConfig.readonlyInput;
    this.setupInputEvents(hoursInputEl, minutesInputEl);
  };

  var hourStep = timepickerConfig.hourStep;
  if ($attrs.hourStep) {
    $scope.$parent.$watch($parse($attrs.hourStep), function(value) {
      hourStep = parseInt(value, 10);
    });
  }

  var minuteStep = timepickerConfig.minuteStep;
  if ($attrs.minuteStep) {
    $scope.$parent.$watch($parse($attrs.minuteStep), function(value) {
      minuteStep = parseInt(value, 10);
    });
  }

  var min;
  $scope.$parent.$watch($parse($attrs.min), function(value) {
    var dt = new Date(value);
    min = isNaN(dt) ? undefined : dt;
  });

  var max;
  $scope.$parent.$watch($parse($attrs.max), function(value) {
    var dt = new Date(value);
    max = isNaN(dt) ? undefined : dt;
  });

  $scope.noIncrementHours = function() {
    var incrementedSelected = addMinutes(selected, hourStep * 60);
    return incrementedSelected > max ||
      (incrementedSelected < selected && incrementedSelected < min);
  };

  $scope.noDecrementHours = function() {
    var decrementedSelected = addMinutes(selected, -hourStep * 60);
    return decrementedSelected < min ||
      (decrementedSelected > selected && decrementedSelected > max);
  };

  $scope.noIncrementMinutes = function() {
    var incrementedSelected = addMinutes(selected, minuteStep);
    return incrementedSelected > max ||
      (incrementedSelected < selected && incrementedSelected < min);
  };

  $scope.noDecrementMinutes = function() {
    var decrementedSelected = addMinutes(selected, -minuteStep);
    return decrementedSelected < min ||
      (decrementedSelected > selected && decrementedSelected > max);
  };

  $scope.noToggleMeridian = function() {
    if (selected.getHours() < 13) {
      return addMinutes(selected, 12 * 60) > max;
    } else {
      return addMinutes(selected, -12 * 60) < min;
    }
  };

  // 12H / 24H mode
  $scope.showMeridian = timepickerConfig.showMeridian;
  if ($attrs.showMeridian) {
    $scope.$parent.$watch($parse($attrs.showMeridian), function(value) {
      $scope.showMeridian = !!value;

      if (ngModelCtrl.$error.time) {
        // Evaluate from template
        var hours = getHoursFromTemplate(), minutes = getMinutesFromTemplate();
        if (angular.isDefined(hours) && angular.isDefined(minutes)) {
          selected.setHours(hours);
          refresh();
        }
      } else {
        updateTemplate();
      }
    });
  }

  // Get $scope.hours in 24H mode if valid
  function getHoursFromTemplate() {
    var hours = parseInt($scope.hours, 10);
    var valid = $scope.showMeridian ? (hours > 0 && hours < 13) : (hours >= 0 && hours < 24);
    if (!valid) {
      return undefined;
    }

    if ($scope.showMeridian) {
      if (hours === 12) {
        hours = 0;
      }
      if ($scope.meridian === meridians[1]) {
        hours = hours + 12;
      }
    }
    return hours;
  }

  function getMinutesFromTemplate() {
    var minutes = parseInt($scope.minutes, 10);
    return (minutes >= 0 && minutes < 60) ? minutes : undefined;
  }

  function pad(value) {
    return (angular.isDefined(value) && value.toString().length < 2) ? '0' + value : value.toString();
  }

  // Respond on mousewheel spin
  this.setupMousewheelEvents = function(hoursInputEl, minutesInputEl) {
    var isScrollingUp = function(e) {
      if (e.originalEvent) {
        e = e.originalEvent;
      }
      //pick correct delta variable depending on event
      var delta = (e.wheelDelta) ? e.wheelDelta : -e.deltaY;
      return (e.detail || delta > 0);
    };

    hoursInputEl.bind('mousewheel wheel', function(e) {
      $scope.$apply(isScrollingUp(e) ? $scope.incrementHours() : $scope.decrementHours());
      e.preventDefault();
    });

    minutesInputEl.bind('mousewheel wheel', function(e) {
      $scope.$apply(isScrollingUp(e) ? $scope.incrementMinutes() : $scope.decrementMinutes());
      e.preventDefault();
    });

  };

  // Respond on up/down arrowkeys
  this.setupArrowkeyEvents = function(hoursInputEl, minutesInputEl) {
    hoursInputEl.bind('keydown', function(e) {
      if (e.which === 38) { // up
        e.preventDefault();
        $scope.incrementHours();
        $scope.$apply();
      } else if (e.which === 40) { // down
        e.preventDefault();
        $scope.decrementHours();
        $scope.$apply();
      }
    });

    minutesInputEl.bind('keydown', function(e) {
      if (e.which === 38) { // up
        e.preventDefault();
        $scope.incrementMinutes();
        $scope.$apply();
      } else if (e.which === 40) { // down
        e.preventDefault();
        $scope.decrementMinutes();
        $scope.$apply();
      }
    });
  };

  this.setupInputEvents = function(hoursInputEl, minutesInputEl) {
    if ($scope.readonlyInput) {
      $scope.updateHours = angular.noop;
      $scope.updateMinutes = angular.noop;
      return;
    }

    var invalidate = function(invalidHours, invalidMinutes) {
      ngModelCtrl.$setViewValue(null);
      ngModelCtrl.$setValidity('time', false);
      if (angular.isDefined(invalidHours)) {
        $scope.invalidHours = invalidHours;
      }
      if (angular.isDefined(invalidMinutes)) {
        $scope.invalidMinutes = invalidMinutes;
      }
    };

    $scope.updateHours = function() {
      var hours = getHoursFromTemplate(),
        minutes = getMinutesFromTemplate();

      if (angular.isDefined(hours) && angular.isDefined(minutes)) {
        selected.setHours(hours);
        if (selected < min || selected > max) {
          invalidate(true);
        } else {
          refresh('h');
        }
      } else {
        invalidate(true);
      }
    };

    hoursInputEl.bind('blur', function(e) {
      if (!$scope.invalidHours && $scope.hours < 10) {
        $scope.$apply(function() {
          $scope.hours = pad($scope.hours);
        });
      }
    });

    $scope.updateMinutes = function() {
      var minutes = getMinutesFromTemplate(),
        hours = getHoursFromTemplate();

      if (angular.isDefined(minutes) && angular.isDefined(hours)) {
        selected.setMinutes(minutes);
        if (selected < min || selected > max) {
          invalidate(undefined, true);
        } else {
          refresh('m');
        }
      } else {
        invalidate(undefined, true);
      }
    };

    minutesInputEl.bind('blur', function(e) {
      if (!$scope.invalidMinutes && $scope.minutes < 10) {
        $scope.$apply(function() {
          $scope.minutes = pad($scope.minutes);
        });
      }
    });

  };

  this.render = function() {
    var date = ngModelCtrl.$viewValue;

    if (isNaN(date)) {
      ngModelCtrl.$setValidity('time', false);
      $log.error('Timepicker directive: "ng-model" value must be a Date object, a number of milliseconds since 01.01.1970 or a string representing an RFC2822 or ISO 8601 date.');
    } else {
      if (date) {
        selected = date;
      }

      if (selected < min || selected > max) {
        ngModelCtrl.$setValidity('time', false);
        $scope.invalidHours = true;
        $scope.invalidMinutes = true;
      } else {
        makeValid();
      }
      updateTemplate();
    }
  };

  // Call internally when we know that model is valid.
  function refresh(keyboardChange) {
    makeValid();
    ngModelCtrl.$setViewValue(new Date(selected));
    updateTemplate(keyboardChange);
  }

  function makeValid() {
    ngModelCtrl.$setValidity('time', true);
    $scope.invalidHours = false;
    $scope.invalidMinutes = false;
  }

  function updateTemplate(keyboardChange) {
    var hours = selected.getHours(), minutes = selected.getMinutes();

    if ($scope.showMeridian) {
      hours = (hours === 0 || hours === 12) ? 12 : hours % 12; // Convert 24 to 12 hour system
    }

    $scope.hours = keyboardChange === 'h' ? hours : pad(hours);
    if (keyboardChange !== 'm') {
      $scope.minutes = pad(minutes);
    }
    $scope.meridian = selected.getHours() < 12 ? meridians[0] : meridians[1];
  }

  function addMinutes(date, minutes) {
    var dt = new Date(date.getTime() + minutes * 60000);
    var newDate = new Date(date);
    newDate.setHours(dt.getHours(), dt.getMinutes());
    return newDate;
  }

  function addMinutesToSelected(minutes) {
    selected = addMinutes(selected, minutes);
    refresh();
  }

  $scope.showSpinners = angular.isDefined($attrs.showSpinners) ?
    $scope.$parent.$eval($attrs.showSpinners) : timepickerConfig.showSpinners;

  $scope.incrementHours = function() {
    if (!$scope.noIncrementHours()) {
      addMinutesToSelected(hourStep * 60);
    }
  };

  $scope.decrementHours = function() {
    if (!$scope.noDecrementHours()) {
      addMinutesToSelected(-hourStep * 60);
    }
  };

  $scope.incrementMinutes = function() {
    if (!$scope.noIncrementMinutes()) {
      addMinutesToSelected(minuteStep);
    }
  };

  $scope.decrementMinutes = function() {
    if (!$scope.noDecrementMinutes()) {
      addMinutesToSelected(-minuteStep);
    }
  };

  $scope.toggleMeridian = function() {
    if (!$scope.noToggleMeridian()) {
      addMinutesToSelected(12 * 60 * (selected.getHours() < 12 ? 1 : -1));
    }
  };
}])

.directive('timepicker', function() {
  return {
    restrict: 'EA',
    require: ['timepicker', '?^ngModel'],
    controller:'TimepickerController',
    controllerAs: 'timepicker',
    replace: true,
    scope: {},
    templateUrl: function(element, attrs) {
      return attrs.templateUrl || 'template/timepicker/timepicker.html';
    },
    link: function(scope, element, attrs, ctrls) {
      var timepickerCtrl = ctrls[0], ngModelCtrl = ctrls[1];

      if (ngModelCtrl) {
        timepickerCtrl.init(ngModelCtrl, element.find('input'));
      }
    }
  };
});

angular.module('ui.bootstrap.transition', [])

.value('$transitionSuppressDeprecated', false)
/**
 * $transition service provides a consistent interface to trigger CSS 3 transitions and to be informed when they complete.
 * @param  {DOMElement} element  The DOMElement that will be animated.
 * @param  {string|object|function} trigger  The thing that will cause the transition to start:
 *   - As a string, it represents the css class to be added to the element.
 *   - As an object, it represents a hash of style attributes to be applied to the element.
 *   - As a function, it represents a function to be called that will cause the transition to occur.
 * @return {Promise}  A promise that is resolved when the transition finishes.
 */
.factory('$transition', [
        '$q', '$timeout', '$rootScope', '$log', '$transitionSuppressDeprecated',
function($q ,  $timeout ,  $rootScope ,  $log ,  $transitionSuppressDeprecated) {

  if (!$transitionSuppressDeprecated) {
    $log.warn('$transition is now deprecated. Use $animate from ngAnimate instead.');
  }

  var $transition = function(element, trigger, options) {
    options = options || {};
    var deferred = $q.defer();
    var endEventName = $transition[options.animation ? 'animationEndEventName' : 'transitionEndEventName'];

    var transitionEndHandler = function(event) {
      $rootScope.$apply(function() {
        element.unbind(endEventName, transitionEndHandler);
        deferred.resolve(element);
      });
    };

    if (endEventName) {
      element.bind(endEventName, transitionEndHandler);
    }

    // Wrap in a timeout to allow the browser time to update the DOM before the transition is to occur
    $timeout(function() {
      if ( angular.isString(trigger) ) {
        element.addClass(trigger);
      } else if ( angular.isFunction(trigger) ) {
        trigger(element);
      } else if ( angular.isObject(trigger) ) {
        element.css(trigger);
      }
      //If browser does not support transitions, instantly resolve
      if ( !endEventName ) {
        deferred.resolve(element);
      }
    });

    // Add our custom cancel function to the promise that is returned
    // We can call this if we are about to run a new transition, which we know will prevent this transition from ending,
    // i.e. it will therefore never raise a transitionEnd event for that transition
    deferred.promise.cancel = function() {
      if ( endEventName ) {
        element.unbind(endEventName, transitionEndHandler);
      }
      deferred.reject('Transition cancelled');
    };

    return deferred.promise;
  };

  // Work out the name of the transitionEnd event
  var transElement = document.createElement('trans');
  var transitionEndEventNames = {
    'WebkitTransition': 'webkitTransitionEnd',
    'MozTransition': 'transitionend',
    'OTransition': 'oTransitionEnd',
    'transition': 'transitionend'
  };
  var animationEndEventNames = {
    'WebkitTransition': 'webkitAnimationEnd',
    'MozTransition': 'animationend',
    'OTransition': 'oAnimationEnd',
    'transition': 'animationend'
  };
  function findEndEventName(endEventNames) {
    for (var name in endEventNames){
      if (transElement.style[name] !== undefined) {
        return endEventNames[name];
      }
    }
  }
  $transition.transitionEndEventName = findEndEventName(transitionEndEventNames);
  $transition.animationEndEventName = findEndEventName(animationEndEventNames);
  return $transition;
}]);

angular.module('ui.bootstrap.typeahead', ['ui.bootstrap.position'])

/**
 * A helper service that can parse typeahead's syntax (string provided by users)
 * Extracted to a separate service for ease of unit testing
 */
  .factory('typeaheadParser', ['$parse', function($parse) {

  //                      00000111000000000000022200000000000000003333333333333330000000000044000
  var TYPEAHEAD_REGEXP = /^\s*([\s\S]+?)(?:\s+as\s+([\s\S]+?))?\s+for\s+(?:([\$\w][\$\w\d]*))\s+in\s+([\s\S]+?)$/;

  return {
    parse: function(input) {
      var match = input.match(TYPEAHEAD_REGEXP);
      if (!match) {
        throw new Error(
          'Expected typeahead specification in form of "_modelValue_ (as _label_)? for _item_ in _collection_"' +
            ' but got "' + input + '".');
      }

      return {
        itemName:match[3],
        source:$parse(match[4]),
        viewMapper:$parse(match[2] || match[1]),
        modelMapper:$parse(match[1])
      };
    }
  };
}])

  .directive('typeahead', ['$compile', '$parse', '$q', '$timeout', '$document', '$window', '$rootScope', '$position', 'typeaheadParser',
    function($compile, $parse, $q, $timeout, $document, $window, $rootScope, $position, typeaheadParser) {
    var HOT_KEYS = [9, 13, 27, 38, 40];
    var eventDebounceTime = 200;

    return {
      require: ['ngModel', '^?ngModelOptions'],
      link: function(originalScope, element, attrs, ctrls) {
        var modelCtrl = ctrls[0];
        var ngModelOptions = ctrls[1];
        //SUPPORTED ATTRIBUTES (OPTIONS)

        //minimal no of characters that needs to be entered before typeahead kicks-in
        var minLength = originalScope.$eval(attrs.typeaheadMinLength);
        if (!minLength && minLength !== 0) {
          minLength = 1;
        }

        //minimal wait time after last character typed before typeahead kicks-in
        var waitTime = originalScope.$eval(attrs.typeaheadWaitMs) || 0;

        //should it restrict model values to the ones selected from the popup only?
        var isEditable = originalScope.$eval(attrs.typeaheadEditable) !== false;

        //binding to a variable that indicates if matches are being retrieved asynchronously
        var isLoadingSetter = $parse(attrs.typeaheadLoading).assign || angular.noop;

        //a callback executed when a match is selected
        var onSelectCallback = $parse(attrs.typeaheadOnSelect);

        //should it select highlighted popup value when losing focus?
        var isSelectOnBlur = angular.isDefined(attrs.typeaheadSelectOnBlur) ? originalScope.$eval(attrs.typeaheadSelectOnBlur) : false;

        //binding to a variable that indicates if there were no results after the query is completed
        var isNoResultsSetter = $parse(attrs.typeaheadNoResults).assign || angular.noop;

        var inputFormatter = attrs.typeaheadInputFormatter ? $parse(attrs.typeaheadInputFormatter) : undefined;

        var appendToBody =  attrs.typeaheadAppendToBody ? originalScope.$eval(attrs.typeaheadAppendToBody) : false;

        var focusFirst = originalScope.$eval(attrs.typeaheadFocusFirst) !== false;

        //If input matches an item of the list exactly, select it automatically
        var selectOnExact = attrs.typeaheadSelectOnExact ? originalScope.$eval(attrs.typeaheadSelectOnExact) : false;

        //INTERNAL VARIABLES

        //model setter executed upon match selection
        var parsedModel = $parse(attrs.ngModel);
        var invokeModelSetter = $parse(attrs.ngModel + '($$$p)');
        var $setModelValue = function(scope, newValue) {
          if (angular.isFunction(parsedModel(originalScope)) &&
            ngModelOptions && ngModelOptions.$options && ngModelOptions.$options.getterSetter) {
            return invokeModelSetter(scope, {$$$p: newValue});
          } else {
            return parsedModel.assign(scope, newValue);
          }
        };

        //expressions used by typeahead
        var parserResult = typeaheadParser.parse(attrs.typeahead);

        var hasFocus;

        //Used to avoid bug in iOS webview where iOS keyboard does not fire
        //mousedown & mouseup events
        //Issue #3699
        var selected;

        //create a child scope for the typeahead directive so we are not polluting original scope
        //with typeahead-specific data (matches, query etc.)
        var scope = originalScope.$new();
        var offDestroy = originalScope.$on('$destroy', function() {
			    scope.$destroy();
        });
        scope.$on('$destroy', offDestroy);

        // WAI-ARIA
        var popupId = 'typeahead-' + scope.$id + '-' + Math.floor(Math.random() * 10000);
        element.attr({
          'aria-autocomplete': 'list',
          'aria-expanded': false,
          'aria-owns': popupId
        });

        //pop-up element used to display matches
        var popUpEl = angular.element('<div typeahead-popup></div>');
        popUpEl.attr({
          id: popupId,
          matches: 'matches',
          active: 'activeIdx',
          select: 'select(activeIdx)',
          'move-in-progress': 'moveInProgress',
          query: 'query',
          position: 'position'
        });
        //custom item template
        if (angular.isDefined(attrs.typeaheadTemplateUrl)) {
          popUpEl.attr('template-url', attrs.typeaheadTemplateUrl);
        }

        if (angular.isDefined(attrs.typeaheadPopupTemplateUrl)) {
          popUpEl.attr('popup-template-url', attrs.typeaheadPopupTemplateUrl);
        }

        var resetMatches = function() {
          scope.matches = [];
          scope.activeIdx = -1;
          element.attr('aria-expanded', false);
        };

        var getMatchId = function(index) {
          return popupId + '-option-' + index;
        };

        // Indicate that the specified match is the active (pre-selected) item in the list owned by this typeahead.
        // This attribute is added or removed automatically when the `activeIdx` changes.
        scope.$watch('activeIdx', function(index) {
          if (index < 0) {
            element.removeAttr('aria-activedescendant');
          } else {
            element.attr('aria-activedescendant', getMatchId(index));
          }
        });

        var inputIsExactMatch = function(inputValue, index) {
          if (scope.matches.length > index && inputValue) {
            return inputValue.toUpperCase() === scope.matches[index].label.toUpperCase();
          }

          return false;
        };

        var getMatchesAsync = function(inputValue) {
          var locals = {$viewValue: inputValue};
          isLoadingSetter(originalScope, true);
          isNoResultsSetter(originalScope, false);
          $q.when(parserResult.source(originalScope, locals)).then(function(matches) {
            //it might happen that several async queries were in progress if a user were typing fast
            //but we are interested only in responses that correspond to the current view value
            var onCurrentRequest = (inputValue === modelCtrl.$viewValue);
            if (onCurrentRequest && hasFocus) {
              if (matches && matches.length > 0) {

                scope.activeIdx = focusFirst ? 0 : -1;
                isNoResultsSetter(originalScope, false);
                scope.matches.length = 0;

                //transform labels
                for (var i = 0; i < matches.length; i++) {
                  locals[parserResult.itemName] = matches[i];
                  scope.matches.push({
                    id: getMatchId(i),
                    label: parserResult.viewMapper(scope, locals),
                    model: matches[i]
                  });
                }

                scope.query = inputValue;
                //position pop-up with matches - we need to re-calculate its position each time we are opening a window
                //with matches as a pop-up might be absolute-positioned and position of an input might have changed on a page
                //due to other elements being rendered
                recalculatePosition();

                element.attr('aria-expanded', true);

                //Select the single remaining option if user input matches
                if (selectOnExact && scope.matches.length === 1 && inputIsExactMatch(inputValue, 0)) {
                  scope.select(0);
                }
              } else {
                resetMatches();
                isNoResultsSetter(originalScope, true);
              }
            }
            if (onCurrentRequest) {
              isLoadingSetter(originalScope, false);
            }
          }, function() {
            resetMatches();
            isLoadingSetter(originalScope, false);
            isNoResultsSetter(originalScope, true);
          });
        };

        // bind events only if appendToBody params exist - performance feature
        if (appendToBody) {
          angular.element($window).bind('resize', fireRecalculating);
          $document.find('body').bind('scroll', fireRecalculating);
        }

        // Declare the timeout promise var outside the function scope so that stacked calls can be cancelled later
        var timeoutEventPromise;

        // Default progress type
        scope.moveInProgress = false;

        function fireRecalculating() {
          if (!scope.moveInProgress) {
            scope.moveInProgress = true;
            scope.$digest();
          }

          // Cancel previous timeout
          if (timeoutEventPromise) {
            $timeout.cancel(timeoutEventPromise);
          }

          // Debounced executing recalculate after events fired
          timeoutEventPromise = $timeout(function() {
            // if popup is visible
            if (scope.matches.length) {
              recalculatePosition();
            }

            scope.moveInProgress = false;
            scope.$digest();
          }, eventDebounceTime);
        }

        // recalculate actual position and set new values to scope
        // after digest loop is popup in right position
        function recalculatePosition() {
          scope.position = appendToBody ? $position.offset(element) : $position.position(element);
          scope.position.top += element.prop('offsetHeight');
        }

        resetMatches();

        //we need to propagate user's query so we can higlight matches
        scope.query = undefined;

        //Declare the timeout promise var outside the function scope so that stacked calls can be cancelled later
        var timeoutPromise;

        var scheduleSearchWithTimeout = function(inputValue) {
          timeoutPromise = $timeout(function() {
            getMatchesAsync(inputValue);
          }, waitTime);
        };

        var cancelPreviousTimeout = function() {
          if (timeoutPromise) {
            $timeout.cancel(timeoutPromise);
          }
        };

        //plug into $parsers pipeline to open a typeahead on view changes initiated from DOM
        //$parsers kick-in on all the changes coming from the view as well as manually triggered by $setViewValue
        modelCtrl.$parsers.unshift(function(inputValue) {
          hasFocus = true;

          if (minLength === 0 || inputValue && inputValue.length >= minLength) {
            if (waitTime > 0) {
              cancelPreviousTimeout();
              scheduleSearchWithTimeout(inputValue);
            } else {
              getMatchesAsync(inputValue);
            }
          } else {
            isLoadingSetter(originalScope, false);
            cancelPreviousTimeout();
            resetMatches();
          }

          if (isEditable) {
            return inputValue;
          } else {
            if (!inputValue) {
              // Reset in case user had typed something previously.
              modelCtrl.$setValidity('editable', true);
              return null;
            } else {
              modelCtrl.$setValidity('editable', false);
              return undefined;
            }
          }
        });

        modelCtrl.$formatters.push(function(modelValue) {
          var candidateViewValue, emptyViewValue;
          var locals = {};

          // The validity may be set to false via $parsers (see above) if
          // the model is restricted to selected values. If the model
          // is set manually it is considered to be valid.
          if (!isEditable) {
            modelCtrl.$setValidity('editable', true);
          }

          if (inputFormatter) {
            locals.$model = modelValue;
            return inputFormatter(originalScope, locals);
          } else {
            //it might happen that we don't have enough info to properly render input value
            //we need to check for this situation and simply return model value if we can't apply custom formatting
            locals[parserResult.itemName] = modelValue;
            candidateViewValue = parserResult.viewMapper(originalScope, locals);
            locals[parserResult.itemName] = undefined;
            emptyViewValue = parserResult.viewMapper(originalScope, locals);

            return candidateViewValue!== emptyViewValue ? candidateViewValue : modelValue;
          }
        });

        scope.select = function(activeIdx) {
          //called from within the $digest() cycle
          var locals = {};
          var model, item;

          selected = true;
          locals[parserResult.itemName] = item = scope.matches[activeIdx].model;
          model = parserResult.modelMapper(originalScope, locals);
          $setModelValue(originalScope, model);
          modelCtrl.$setValidity('editable', true);
          modelCtrl.$setValidity('parse', true);

          onSelectCallback(originalScope, {
            $item: item,
            $model: model,
            $label: parserResult.viewMapper(originalScope, locals)
          });

          resetMatches();

          //return focus to the input element if a match was selected via a mouse click event
          // use timeout to avoid $rootScope:inprog error
          if (scope.$eval(attrs.typeaheadFocusOnSelect) !== false) {
            $timeout(function() { element[0].focus(); }, 0, false);
          }
        };

        //bind keyboard events: arrows up(38) / down(40), enter(13) and tab(9), esc(27)
        element.bind('keydown', function(evt) {
          //typeahead is open and an "interesting" key was pressed
          if (scope.matches.length === 0 || HOT_KEYS.indexOf(evt.which) === -1) {
            return;
          }

          // if there's nothing selected (i.e. focusFirst) and enter or tab is hit, clear the results
          if (scope.activeIdx === -1 && (evt.which === 9 || evt.which === 13)) {
            resetMatches();
            scope.$digest();
            return;
          }

          evt.preventDefault();

          if (evt.which === 40) {
            scope.activeIdx = (scope.activeIdx + 1) % scope.matches.length;
            scope.$digest();

          } else if (evt.which === 38) {
            scope.activeIdx = (scope.activeIdx > 0 ? scope.activeIdx : scope.matches.length) - 1;
            scope.$digest();

          } else if (evt.which === 13 || evt.which === 9) {
            scope.$apply(function () {
              scope.select(scope.activeIdx);
            });

          } else if (evt.which === 27) {
            evt.stopPropagation();

            resetMatches();
            scope.$digest();
          }
        });

        element.bind('blur', function() {
          if (isSelectOnBlur && scope.matches.length && scope.activeIdx !== -1 && !selected) {
            selected = true;
            scope.$apply(function() {
              scope.select(scope.activeIdx);
            });
          }
          hasFocus = false;
          selected = false;
        });

        // Keep reference to click handler to unbind it.
        var dismissClickHandler = function(evt) {
          // Issue #3973
          // Firefox treats right click as a click on document
          if (element[0] !== evt.target && evt.which !== 3 && scope.matches.length !== 0) {
            resetMatches();
            if (!$rootScope.$$phase) {
              scope.$digest();
            }
          }
        };

        $document.bind('click', dismissClickHandler);

        originalScope.$on('$destroy', function() {
          $document.unbind('click', dismissClickHandler);
          if (appendToBody) {
            $popup.remove();
          }
          // Prevent jQuery cache memory leak
          popUpEl.remove();
        });

        var $popup = $compile(popUpEl)(scope);

        if (appendToBody) {
          $document.find('body').append($popup);
        } else {
          element.after($popup);
        }
      }
    };

  }])

  .directive('typeaheadPopup', function() {
    return {
      restrict: 'EA',
      scope: {
        matches: '=',
        query: '=',
        active: '=',
        position: '&',
        moveInProgress: '=',
        select: '&'
      },
      replace: true,
      templateUrl: function(element, attrs) {
        return attrs.popupTemplateUrl || 'template/typeahead/typeahead-popup.html';
      },
      link: function(scope, element, attrs) {
        scope.templateUrl = attrs.templateUrl;

        scope.isOpen = function() {
          return scope.matches.length > 0;
        };

        scope.isActive = function(matchIdx) {
          return scope.active == matchIdx;
        };

        scope.selectActive = function(matchIdx) {
          scope.active = matchIdx;
        };

        scope.selectMatch = function(activeIdx) {
          scope.select({activeIdx:activeIdx});
        };
      }
    };
  })

  .directive('typeaheadMatch', ['$templateRequest', '$compile', '$parse', function($templateRequest, $compile, $parse) {
    return {
      restrict: 'EA',
      scope: {
        index: '=',
        match: '=',
        query: '='
      },
      link:function(scope, element, attrs) {
        var tplUrl = $parse(attrs.templateUrl)(scope.$parent) || 'template/typeahead/typeahead-match.html';
        $templateRequest(tplUrl).then(function(tplContent) {
          $compile(tplContent.trim())(scope, function(clonedElement) {
            element.replaceWith(clonedElement);
          });
        });
      }
    };
  }])

  .filter('typeaheadHighlight', ['$sce', '$injector', '$log', function($sce, $injector, $log) {
    var isSanitizePresent;
    isSanitizePresent = $injector.has('$sanitize');

    function escapeRegexp(queryToEscape) {
      // Regex: capture the whole query string and replace it with the string that will be used to match
      // the results, for example if the capture is "a" the result will be \a
      return queryToEscape.replace(/([.?*+^$[\]\\(){}|-])/g, '\\$1');
    }

    function containsHtml(matchItem) {
      return /<.*>/g.test(matchItem);
    }

    return function(matchItem, query) {
      if (!isSanitizePresent && containsHtml(matchItem)) {
        $log.warn('Unsafe use of typeahead please use ngSanitize'); // Warn the user about the danger
      }
      matchItem = query? ('' + matchItem).replace(new RegExp(escapeRegexp(query), 'gi'), '<strong>$&</strong>') : matchItem; // Replaces the capture string with a the same string inside of a "strong" tag
      if (!isSanitizePresent) {
        matchItem = $sce.trustAsHtml(matchItem); // If $sanitize is not present we pack the string in a $sce object for the ng-bind-html directive
      }
      return matchItem;
    };
  }]);

angular.module("template/accordion/accordion-group.html", []).run(["$templateCache", function($templateCache) {
  $templateCache.put("template/accordion/accordion-group.html",
    "<div class=\"panel {{panelClass || 'panel-default'}}\">\n" +
    "  <div class=\"panel-heading\" ng-keypress=\"toggleOpen($event)\">\n" +
    "    <h4 class=\"panel-title\">\n" +
    "      <a href tabindex=\"0\" class=\"accordion-toggle\" ng-click=\"toggleOpen()\" accordion-transclude=\"heading\"><span ng-class=\"{'text-muted': isDisabled}\">{{heading}}</span></a>\n" +
    "    </h4>\n" +
    "  </div>\n" +
    "  <div class=\"panel-collapse collapse\" collapse=\"!isOpen\">\n" +
    "	  <div class=\"panel-body\" ng-transclude></div>\n" +
    "  </div>\n" +
    "</div>\n" +
    "");
}]);

angular.module("template/accordion/accordion.html", []).run(["$templateCache", function($templateCache) {
  $templateCache.put("template/accordion/accordion.html",
    "<div class=\"panel-group\" ng-transclude></div>");
}]);

angular.module("template/alert/alert.html", []).run(["$templateCache", function($templateCache) {
  $templateCache.put("template/alert/alert.html",
    "<div class=\"alert\" ng-class=\"['alert-' + (type || 'warning'), closeable ? 'alert-dismissible' : null]\" role=\"alert\">\n" +
    "    <button ng-show=\"closeable\" type=\"button\" class=\"close\" ng-click=\"close($event)\">\n" +
    "        <span aria-hidden=\"true\">&times;</span>\n" +
    "        <span class=\"sr-only\">Close</span>\n" +
    "    </button>\n" +
    "    <div ng-transclude></div>\n" +
    "</div>\n" +
    "");
}]);

angular.module("template/carousel/carousel.html", []).run(["$templateCache", function($templateCache) {
  $templateCache.put("template/carousel/carousel.html",
    "<div ng-mouseenter=\"pause()\" ng-mouseleave=\"play()\" class=\"carousel\" ng-swipe-right=\"prev()\" ng-swipe-left=\"next()\">\n" +
    "    <ol class=\"carousel-indicators\" ng-show=\"slides.length > 1\">\n" +
    "        <li ng-repeat=\"slide in slides | orderBy:indexOfSlide track by $index\" ng-class=\"{active: isActive(slide)}\" ng-click=\"select(slide)\"></li>\n" +
    "    </ol>\n" +
    "    <div class=\"carousel-inner\" ng-transclude></div>\n" +
    "    <a class=\"left carousel-control\" ng-click=\"prev()\" ng-show=\"slides.length > 1\"><span class=\"glyphicon glyphicon-chevron-left\"></span></a>\n" +
    "    <a class=\"right carousel-control\" ng-click=\"next()\" ng-show=\"slides.length > 1\"><span class=\"glyphicon glyphicon-chevron-right\"></span></a>\n" +
    "</div>\n" +
    "");
}]);

angular.module("template/carousel/slide.html", []).run(["$templateCache", function($templateCache) {
  $templateCache.put("template/carousel/slide.html",
    "<div ng-class=\"{\n" +
    "    'active': active\n" +
    "  }\" class=\"item text-center\" ng-transclude></div>\n" +
    "");
}]);

angular.module("template/datepicker/datepicker.html", []).run(["$templateCache", function($templateCache) {
  $templateCache.put("template/datepicker/datepicker.html",
    "<div ng-switch=\"datepickerMode\" role=\"application\" ng-keydown=\"keydown($event)\">\n" +
    "  <daypicker ng-switch-when=\"day\" tabindex=\"0\"></daypicker>\n" +
    "  <monthpicker ng-switch-when=\"month\" tabindex=\"0\"></monthpicker>\n" +
    "  <yearpicker ng-switch-when=\"year\" tabindex=\"0\"></yearpicker>\n" +
    "</div>");
}]);

angular.module("template/datepicker/day.html", []).run(["$templateCache", function($templateCache) {
  $templateCache.put("template/datepicker/day.html",
    "<table role=\"grid\" aria-labelledby=\"{{::uniqueId}}-title\" aria-activedescendant=\"{{activeDateId}}\">\n" +
    "  <thead>\n" +
    "    <tr>\n" +
    "      <th><button type=\"button\" class=\"btn btn-default btn-sm pull-left\" ng-click=\"move(-1)\" tabindex=\"-1\"><i class=\"glyphicon glyphicon-chevron-left\"></i></button></th>\n" +
    "      <th colspan=\"{{::5 + showWeeks}}\"><button id=\"{{::uniqueId}}-title\" role=\"heading\" aria-live=\"assertive\" aria-atomic=\"true\" type=\"button\" class=\"btn btn-default btn-sm\" ng-click=\"toggleMode()\" ng-disabled=\"datepickerMode === maxMode\" tabindex=\"-1\" style=\"width:100%;\"><strong>{{title}}</strong></button></th>\n" +
    "      <th><button type=\"button\" class=\"btn btn-default btn-sm pull-right\" ng-click=\"move(1)\" tabindex=\"-1\"><i class=\"glyphicon glyphicon-chevron-right\"></i></button></th>\n" +
    "    </tr>\n" +
    "    <tr>\n" +
    "      <th ng-if=\"showWeeks\" class=\"text-center\"></th>\n" +
    "      <th ng-repeat=\"label in ::labels track by $index\" class=\"text-center\"><small aria-label=\"{{::label.full}}\">{{::label.abbr}}</small></th>\n" +
    "    </tr>\n" +
    "  </thead>\n" +
    "  <tbody>\n" +
    "    <tr ng-repeat=\"row in rows track by $index\">\n" +
    "      <td ng-if=\"showWeeks\" class=\"text-center h6\"><em>{{ weekNumbers[$index] }}</em></td>\n" +
    "      <td ng-repeat=\"dt in row track by dt.date\" class=\"text-center\" role=\"gridcell\" id=\"{{::dt.uid}}\" ng-class=\"::dt.customClass\">\n" +
    "        <button type=\"button\" style=\"min-width:100%;\" class=\"btn btn-default btn-sm\" ng-class=\"{'btn-info': dt.selected, active: isActive(dt)}\" ng-click=\"select(dt.date)\" ng-disabled=\"dt.disabled\" tabindex=\"-1\"><span ng-class=\"::{'text-muted': dt.secondary, 'text-info': dt.current}\">{{::dt.label}}</span></button>\n" +
    "      </td>\n" +
    "    </tr>\n" +
    "  </tbody>\n" +
    "</table>\n" +
    "");
}]);

angular.module("template/datepicker/month.html", []).run(["$templateCache", function($templateCache) {
  $templateCache.put("template/datepicker/month.html",
    "<table role=\"grid\" aria-labelledby=\"{{::uniqueId}}-title\" aria-activedescendant=\"{{activeDateId}}\">\n" +
    "  <thead>\n" +
    "    <tr>\n" +
    "      <th><button type=\"button\" class=\"btn btn-default btn-sm pull-left\" ng-click=\"move(-1)\" tabindex=\"-1\"><i class=\"glyphicon glyphicon-chevron-left\"></i></button></th>\n" +
    "      <th><button id=\"{{::uniqueId}}-title\" role=\"heading\" aria-live=\"assertive\" aria-atomic=\"true\" type=\"button\" class=\"btn btn-default btn-sm\" ng-click=\"toggleMode()\" ng-disabled=\"datepickerMode === maxMode\" tabindex=\"-1\" style=\"width:100%;\"><strong>{{title}}</strong></button></th>\n" +
    "      <th><button type=\"button\" class=\"btn btn-default btn-sm pull-right\" ng-click=\"move(1)\" tabindex=\"-1\"><i class=\"glyphicon glyphicon-chevron-right\"></i></button></th>\n" +
    "    </tr>\n" +
    "  </thead>\n" +
    "  <tbody>\n" +
    "    <tr ng-repeat=\"row in rows track by $index\">\n" +
    "      <td ng-repeat=\"dt in row track by dt.date\" class=\"text-center\" role=\"gridcell\" id=\"{{::dt.uid}}\" ng-class=\"::dt.customClass\">\n" +
    "        <button type=\"button\" style=\"min-width:100%;\" class=\"btn btn-default\" ng-class=\"{'btn-info': dt.selected, active: isActive(dt)}\" ng-click=\"select(dt.date)\" ng-disabled=\"dt.disabled\" tabindex=\"-1\"><span ng-class=\"::{'text-info': dt.current}\">{{::dt.label}}</span></button>\n" +
    "      </td>\n" +
    "    </tr>\n" +
    "  </tbody>\n" +
    "</table>\n" +
    "");
}]);

angular.module("template/datepicker/popup.html", []).run(["$templateCache", function($templateCache) {
  $templateCache.put("template/datepicker/popup.html",
    "<ul class=\"dropdown-menu\" ng-if=\"isOpen\" style=\"display: block\" ng-style=\"{top: position.top+'px', left: position.left+'px'}\" ng-keydown=\"keydown($event)\" ng-click=\"$event.stopPropagation()\">\n" +
    "	<li ng-transclude></li>\n" +
    "	<li ng-if=\"showButtonBar\" style=\"padding:10px 9px 2px\">\n" +
    "		<span class=\"btn-group pull-left\">\n" +
    "			<button type=\"button\" class=\"btn btn-sm btn-info\" ng-click=\"select('today')\" ng-disabled=\"isDisabled('today')\">{{ getText('current') }}</button>\n" +
    "			<button type=\"button\" class=\"btn btn-sm btn-danger\" ng-click=\"select(null)\">{{ getText('clear') }}</button>\n" +
    "		</span>\n" +
    "		<button type=\"button\" class=\"btn btn-sm btn-success pull-right\" ng-click=\"close()\">{{ getText('close') }}</button>\n" +
    "	</li>\n" +
    "</ul>\n" +
    "");
}]);

angular.module("template/datepicker/year.html", []).run(["$templateCache", function($templateCache) {
  $templateCache.put("template/datepicker/year.html",
    "<table role=\"grid\" aria-labelledby=\"{{::uniqueId}}-title\" aria-activedescendant=\"{{activeDateId}}\">\n" +
    "  <thead>\n" +
    "    <tr>\n" +
    "      <th><button type=\"button\" class=\"btn btn-default btn-sm pull-left\" ng-click=\"move(-1)\" tabindex=\"-1\"><i class=\"glyphicon glyphicon-chevron-left\"></i></button></th>\n" +
    "      <th colspan=\"3\"><button id=\"{{::uniqueId}}-title\" role=\"heading\" aria-live=\"assertive\" aria-atomic=\"true\" type=\"button\" class=\"btn btn-default btn-sm\" ng-click=\"toggleMode()\" ng-disabled=\"datepickerMode === maxMode\" tabindex=\"-1\" style=\"width:100%;\"><strong>{{title}}</strong></button></th>\n" +
    "      <th><button type=\"button\" class=\"btn btn-default btn-sm pull-right\" ng-click=\"move(1)\" tabindex=\"-1\"><i class=\"glyphicon glyphicon-chevron-right\"></i></button></th>\n" +
    "    </tr>\n" +
    "  </thead>\n" +
    "  <tbody>\n" +
    "    <tr ng-repeat=\"row in rows track by $index\">\n" +
    "      <td ng-repeat=\"dt in row track by dt.date\" class=\"text-center\" role=\"gridcell\" id=\"{{::dt.uid}}\">\n" +
    "        <button type=\"button\" style=\"min-width:100%;\" class=\"btn btn-default\" ng-class=\"{'btn-info': dt.selected, active: isActive(dt)}\" ng-click=\"select(dt.date)\" ng-disabled=\"dt.disabled\" tabindex=\"-1\"><span ng-class=\"::{'text-info': dt.current}\">{{::dt.label}}</span></button>\n" +
    "      </td>\n" +
    "    </tr>\n" +
    "  </tbody>\n" +
    "</table>\n" +
    "");
}]);

angular.module("template/modal/backdrop.html", []).run(["$templateCache", function($templateCache) {
  $templateCache.put("template/modal/backdrop.html",
    "<div class=\"modal-backdrop\"\n" +
    "     modal-animation-class=\"fade\"\n" +
    "     modal-in-class=\"in\"\n" +
    "     ng-style=\"{'z-index': 1040 + (index && 1 || 0) + index*10}\"\n" +
    "></div>\n" +
    "");
}]);

angular.module("template/modal/window.html", []).run(["$templateCache", function($templateCache) {
  $templateCache.put("template/modal/window.html",
    "<div modal-render=\"{{$isRendered}}\" tabindex=\"-1\" role=\"dialog\" class=\"modal\"\n" +
    "    modal-animation-class=\"fade\"\n" +
    "    modal-in-class=\"in\"\n" +
    "	ng-style=\"{'z-index': 1050 + index*10, display: 'block'}\" ng-click=\"close($event)\">\n" +
    "    <div class=\"modal-dialog\" ng-class=\"size ? 'modal-' + size : ''\"><div class=\"modal-content\" modal-transclude></div></div>\n" +
    "</div>\n" +
    "");
}]);

angular.module("template/pagination/pager.html", []).run(["$templateCache", function($templateCache) {
  $templateCache.put("template/pagination/pager.html",
    "<ul class=\"pager\">\n" +
    "  <li ng-class=\"{disabled: noPrevious()||ngDisabled, previous: align}\"><a href ng-click=\"selectPage(page - 1, $event)\">{{::getText('previous')}}</a></li>\n" +
    "  <li ng-class=\"{disabled: noNext()||ngDisabled, next: align}\"><a href ng-click=\"selectPage(page + 1, $event)\">{{::getText('next')}}</a></li>\n" +
    "</ul>\n" +
    "");
}]);

angular.module("template/pagination/pagination.html", []).run(["$templateCache", function($templateCache) {
  $templateCache.put("template/pagination/pagination.html",
    "<ul class=\"pagination\">\n" +
    "  <li ng-if=\"::boundaryLinks\" ng-class=\"{disabled: noPrevious()||ngDisabled}\" class=\"pagination-first\"><a href ng-click=\"selectPage(1, $event)\">{{::getText('first')}}</a></li>\n" +
    "  <li ng-if=\"::directionLinks\" ng-class=\"{disabled: noPrevious()||ngDisabled}\" class=\"pagination-prev\"><a href ng-click=\"selectPage(page - 1, $event)\">{{::getText('previous')}}</a></li>\n" +
    "  <li ng-repeat=\"page in pages track by $index\" ng-class=\"{active: page.active,disabled: ngDisabled&&!page.active}\" class=\"pagination-page\"><a href ng-click=\"selectPage(page.number, $event)\">{{page.text}}</a></li>\n" +
    "  <li ng-if=\"::directionLinks\" ng-class=\"{disabled: noNext()||ngDisabled}\" class=\"pagination-next\"><a href ng-click=\"selectPage(page + 1, $event)\">{{::getText('next')}}</a></li>\n" +
    "  <li ng-if=\"::boundaryLinks\" ng-class=\"{disabled: noNext()||ngDisabled}\" class=\"pagination-last\"><a href ng-click=\"selectPage(totalPages, $event)\">{{::getText('last')}}</a></li>\n" +
    "</ul>\n" +
    "");
}]);

angular.module("template/tooltip/tooltip-html-popup.html", []).run(["$templateCache", function($templateCache) {
  $templateCache.put("template/tooltip/tooltip-html-popup.html",
    "<div class=\"tooltip\"\n" +
    "  tooltip-animation-class=\"fade\"\n" +
    "  tooltip-classes\n" +
    "  ng-class=\"{ in: isOpen() }\">\n" +
    "  <div class=\"tooltip-arrow\"></div>\n" +
    "  <div class=\"tooltip-inner\" ng-bind-html=\"contentExp()\"></div>\n" +
    "</div>\n" +
    "");
}]);

angular.module("template/tooltip/tooltip-html-unsafe-popup.html", []).run(["$templateCache", function($templateCache) {
  $templateCache.put("template/tooltip/tooltip-html-unsafe-popup.html",
    "<div class=\"tooltip\"\n" +
    "  tooltip-animation-class=\"fade\"\n" +
    "  tooltip-classes\n" +
    "  ng-class=\"{ in: isOpen() }\">\n" +
    "  <div class=\"tooltip-arrow\"></div>\n" +
    "  <div class=\"tooltip-inner\" bind-html-unsafe=\"content\"></div>\n" +
    "</div>\n" +
    "");
}]);

angular.module("template/tooltip/tooltip-popup.html", []).run(["$templateCache", function($templateCache) {
  $templateCache.put("template/tooltip/tooltip-popup.html",
    "<div class=\"tooltip\"\n" +
    "  tooltip-animation-class=\"fade\"\n" +
    "  tooltip-classes\n" +
    "  ng-class=\"{ in: isOpen() }\">\n" +
    "  <div class=\"tooltip-arrow\"></div>\n" +
    "  <div class=\"tooltip-inner\" ng-bind=\"content\"></div>\n" +
    "</div>\n" +
    "");
}]);

angular.module("template/tooltip/tooltip-template-popup.html", []).run(["$templateCache", function($templateCache) {
  $templateCache.put("template/tooltip/tooltip-template-popup.html",
    "<div class=\"tooltip\"\n" +
    "  tooltip-animation-class=\"fade\"\n" +
    "  tooltip-classes\n" +
    "  ng-class=\"{ in: isOpen() }\">\n" +
    "  <div class=\"tooltip-arrow\"></div>\n" +
    "  <div class=\"tooltip-inner\"\n" +
    "    tooltip-template-transclude=\"contentExp()\"\n" +
    "    tooltip-template-transclude-scope=\"originScope()\"></div>\n" +
    "</div>\n" +
    "");
}]);

angular.module("template/popover/popover-html.html", []).run(["$templateCache", function($templateCache) {
  $templateCache.put("template/popover/popover-html.html",
    "<div class=\"popover\"\n" +
    "  tooltip-animation-class=\"fade\"\n" +
    "  tooltip-classes\n" +
    "  ng-class=\"{ in: isOpen() }\">\n" +
    "  <div class=\"arrow\"></div>\n" +
    "\n" +
    "  <div class=\"popover-inner\">\n" +
    "      <h3 class=\"popover-title\" ng-bind=\"title\" ng-if=\"title\"></h3>\n" +
    "      <div class=\"popover-content\" ng-bind-html=\"contentExp()\"></div>\n" +
    "  </div>\n" +
    "</div>\n" +
    "");
}]);

angular.module("template/popover/popover-template.html", []).run(["$templateCache", function($templateCache) {
  $templateCache.put("template/popover/popover-template.html",
    "<div class=\"popover\"\n" +
    "  tooltip-animation-class=\"fade\"\n" +
    "  tooltip-classes\n" +
    "  ng-class=\"{ in: isOpen() }\">\n" +
    "  <div class=\"arrow\"></div>\n" +
    "\n" +
    "  <div class=\"popover-inner\">\n" +
    "      <h3 class=\"popover-title\" ng-bind=\"title\" ng-if=\"title\"></h3>\n" +
    "      <div class=\"popover-content\"\n" +
    "        tooltip-template-transclude=\"contentExp()\"\n" +
    "        tooltip-template-transclude-scope=\"originScope()\"></div>\n" +
    "  </div>\n" +
    "</div>\n" +
    "");
}]);

angular.module("template/popover/popover.html", []).run(["$templateCache", function($templateCache) {
  $templateCache.put("template/popover/popover.html",
    "<div class=\"popover\"\n" +
    "  tooltip-animation-class=\"fade\"\n" +
    "  tooltip-classes\n" +
    "  ng-class=\"{ in: isOpen() }\">\n" +
    "  <div class=\"arrow\"></div>\n" +
    "\n" +
    "  <div class=\"popover-inner\">\n" +
    "      <h3 class=\"popover-title\" ng-bind=\"title\" ng-if=\"title\"></h3>\n" +
    "      <div class=\"popover-content\" ng-bind=\"content\"></div>\n" +
    "  </div>\n" +
    "</div>\n" +
    "");
}]);

angular.module("template/progressbar/bar.html", []).run(["$templateCache", function($templateCache) {
  $templateCache.put("template/progressbar/bar.html",
    "<div class=\"progress-bar\" ng-class=\"type && 'progress-bar-' + type\" role=\"progressbar\" aria-valuenow=\"{{value}}\" aria-valuemin=\"0\" aria-valuemax=\"{{max}}\" ng-style=\"{width: (percent < 100 ? percent : 100) + '%'}\" aria-valuetext=\"{{percent | number:0}}%\" style=\"min-width: 0;\" ng-transclude></div>\n" +
    "");
}]);

angular.module("template/progressbar/progress.html", []).run(["$templateCache", function($templateCache) {
  $templateCache.put("template/progressbar/progress.html",
    "<div class=\"progress\" ng-transclude></div>");
}]);

angular.module("template/progressbar/progressbar.html", []).run(["$templateCache", function($templateCache) {
  $templateCache.put("template/progressbar/progressbar.html",
    "<div class=\"progress\">\n" +
    "  <div class=\"progress-bar\" ng-class=\"type && 'progress-bar-' + type\" role=\"progressbar\" aria-valuenow=\"{{value}}\" aria-valuemin=\"0\" aria-valuemax=\"{{max}}\" ng-style=\"{width: (percent < 100 ? percent : 100) + '%'}\" aria-valuetext=\"{{percent | number:0}}%\" style=\"min-width: 0;\" ng-transclude></div>\n" +
    "</div>\n" +
    "");
}]);

angular.module("template/rating/rating.html", []).run(["$templateCache", function($templateCache) {
  $templateCache.put("template/rating/rating.html",
    "<span ng-mouseleave=\"reset()\" ng-keydown=\"onKeydown($event)\" tabindex=\"0\" role=\"slider\" aria-valuemin=\"0\" aria-valuemax=\"{{range.length}}\" aria-valuenow=\"{{value}}\">\n" +
    "    <span ng-repeat-start=\"r in range track by $index\" class=\"sr-only\">({{ $index < value ? '*' : ' ' }})</span>\n" +
    "    <i ng-repeat-end ng-mouseenter=\"enter($index + 1)\" ng-click=\"rate($index + 1)\" class=\"glyphicon\" ng-class=\"$index < value && (r.stateOn || 'glyphicon-star') || (r.stateOff || 'glyphicon-star-empty')\" ng-attr-title=\"{{r.title}}\" ></i>\n" +
    "</span>\n" +
    "");
}]);

angular.module("template/tabs/tab.html", []).run(["$templateCache", function($templateCache) {
  $templateCache.put("template/tabs/tab.html",
    "<li ng-class=\"{active: active, disabled: disabled}\">\n" +
    "  <a href ng-click=\"select()\" tab-heading-transclude>{{heading}}</a>\n" +
    "</li>\n" +
    "");
}]);

angular.module("template/tabs/tabset.html", []).run(["$templateCache", function($templateCache) {
  $templateCache.put("template/tabs/tabset.html",
    "<div>\n" +
    "  <ul class=\"nav nav-{{type || 'tabs'}}\" ng-class=\"{'nav-stacked': vertical, 'nav-justified': justified}\" ng-transclude></ul>\n" +
    "  <div class=\"tab-content\">\n" +
    "    <div class=\"tab-pane\" \n" +
    "         ng-repeat=\"tab in tabs\" \n" +
    "         ng-class=\"{active: tab.active}\"\n" +
    "         tab-content-transclude=\"tab\">\n" +
    "    </div>\n" +
    "  </div>\n" +
    "</div>\n" +
    "");
}]);

angular.module("template/timepicker/timepicker.html", []).run(["$templateCache", function($templateCache) {
  $templateCache.put("template/timepicker/timepicker.html",
    "<table>\n" +
    "  <tbody>\n" +
    "    <tr class=\"text-center\" ng-show=\"::showSpinners\">\n" +
    "      <td><a ng-click=\"incrementHours()\" ng-class=\"{disabled: noIncrementHours()}\" class=\"btn btn-link\"><span class=\"glyphicon glyphicon-chevron-up\"></span></a></td>\n" +
    "      <td>&nbsp;</td>\n" +
    "      <td><a ng-click=\"incrementMinutes()\" ng-class=\"{disabled: noIncrementMinutes()}\" class=\"btn btn-link\"><span class=\"glyphicon glyphicon-chevron-up\"></span></a></td>\n" +
    "      <td ng-show=\"showMeridian\"></td>\n" +
    "    </tr>\n" +
    "    <tr>\n" +
    "      <td class=\"form-group\" ng-class=\"{'has-error': invalidHours}\">\n" +
    "        <input style=\"width:50px;\" type=\"text\" ng-model=\"hours\" ng-change=\"updateHours()\" class=\"form-control text-center\" ng-readonly=\"::readonlyInput\" maxlength=\"2\">\n" +
    "      </td>\n" +
    "      <td>:</td>\n" +
    "      <td class=\"form-group\" ng-class=\"{'has-error': invalidMinutes}\">\n" +
    "        <input style=\"width:50px;\" type=\"text\" ng-model=\"minutes\" ng-change=\"updateMinutes()\" class=\"form-control text-center\" ng-readonly=\"::readonlyInput\" maxlength=\"2\">\n" +
    "      </td>\n" +
    "      <td ng-show=\"showMeridian\"><button type=\"button\" ng-class=\"{disabled: noToggleMeridian()}\" class=\"btn btn-default text-center\" ng-click=\"toggleMeridian()\">{{meridian}}</button></td>\n" +
    "    </tr>\n" +
    "    <tr class=\"text-center\" ng-show=\"::showSpinners\">\n" +
    "      <td><a ng-click=\"decrementHours()\" ng-class=\"{disabled: noDecrementHours()}\" class=\"btn btn-link\"><span class=\"glyphicon glyphicon-chevron-down\"></span></a></td>\n" +
    "      <td>&nbsp;</td>\n" +
    "      <td><a ng-click=\"decrementMinutes()\" ng-class=\"{disabled: noDecrementMinutes()}\" class=\"btn btn-link\"><span class=\"glyphicon glyphicon-chevron-down\"></span></a></td>\n" +
    "      <td ng-show=\"showMeridian\"></td>\n" +
    "    </tr>\n" +
    "  </tbody>\n" +
    "</table>\n" +
    "");
}]);

angular.module("template/typeahead/typeahead-match.html", []).run(["$templateCache", function($templateCache) {
  $templateCache.put("template/typeahead/typeahead-match.html",
    "<a href tabindex=\"-1\" ng-bind-html=\"match.label | typeaheadHighlight:query\"></a>\n" +
    "");
}]);

angular.module("template/typeahead/typeahead-popup.html", []).run(["$templateCache", function($templateCache) {
  $templateCache.put("template/typeahead/typeahead-popup.html",
    "<ul class=\"dropdown-menu\" ng-show=\"isOpen() && !moveInProgress\" ng-style=\"{top: position().top+'px', left: position().left+'px'}\" style=\"display: block;\" role=\"listbox\" aria-hidden=\"{{!isOpen()}}\">\n" +
    "    <li ng-repeat=\"match in matches track by $index\" ng-class=\"{active: isActive($index) }\" ng-mouseenter=\"selectActive($index)\" ng-click=\"selectMatch($index)\" role=\"option\" id=\"{{::match.id}}\">\n" +
    "        <div typeahead-match index=\"$index\" match=\"match\" query=\"query\" template-url=\"templateUrl\"></div>\n" +
    "    </li>\n" +
    "</ul>\n" +
    "");
}]);
!angular.$$csp() && angular.element(document).find('head').prepend('<style type="text/css">.ng-animate.item:not(.left):not(.right){-webkit-transition:0s ease-in-out left;transition:0s ease-in-out left}</style>');
/**
 * @license Angular UI Tree v2.1.5
 * (c) 2010-2014. https://github.com/JimLiu/angular-ui-tree
 * License: MIT
 */
(function () {
  'use strict';

  angular.module('ui.tree', [])
    .constant('treeConfig', {
      treeClass: 'angular-ui-tree',
      emptyTreeClass: 'angular-ui-tree-empty',
      hiddenClass: 'angular-ui-tree-hidden',
      nodesClass: 'angular-ui-tree-nodes',
      nodeClass: 'angular-ui-tree-node',
      handleClass: 'angular-ui-tree-handle',
      placeHolderClass: 'angular-ui-tree-placeholder',
      dragClass: 'angular-ui-tree-drag',
      dragThreshold: 3,
      levelThreshold: 30
    });

})();

(function () {
  'use strict';

  angular.module('ui.tree')

   /**
    * @ngdoc service
    * @name ui.tree.service:$helper
    * @requires ng.$document
    * @requires ng.$window
    *
    * @description
    * angular-ui-tree.
    */
    .factory('$uiTreeHelper', ['$document', '$window',
      function ($document, $window) {
        return {

          /**
           * A hashtable used to storage data of nodes
           * @type {Object}
           */
          nodesData: {
          },

          setNodeAttribute: function(scope, attrName, val) {
            var data = this.nodesData[scope.$modelValue.$$hashKey];
            if (!data) {
              data = {};
              this.nodesData[scope.$modelValue.$$hashKey] = data;
            }
            data[attrName] = val;
          },

          getNodeAttribute: function(scope, attrName) {
            var data = this.nodesData[scope.$modelValue.$$hashKey];
            if (data) {
              return data[attrName];
            }
            return null;
          },

          /**
           * @ngdoc method
           * @methodOf ui.tree.service:$nodrag
           * @param  {Object} targetElm angular element
           * @return {Bool} check if the node can be dragged.
           */
          nodrag: function (targetElm) {
            return (typeof targetElm.attr('data-nodrag')) != "undefined";
          },

          /**
           * get the event object for touchs
           * @param  {[type]} e [description]
           * @return {[type]}   [description]
           */
          eventObj: function(e) {
            var obj = e;
            if (e.targetTouches !== undefined) {
              obj = e.targetTouches.item(0);
            } else if (e.originalEvent !== undefined && e.originalEvent.targetTouches !== undefined) {
              obj = e.originalEvent.targetTouches.item(0);
            }
            return obj;
          },

          dragInfo: function(node) {
            return {
              source: node,
              sourceInfo: {
                nodeScope: node,
                index: node.index(),
                nodesScope: node.$parentNodesScope
              },
              index: node.index(),
              siblings: node.siblings().slice(0),
              parent: node.$parentNodesScope,

              moveTo: function(parent, siblings, index) { // Move the node to a new position
                this.parent = parent;
                this.siblings = siblings.slice(0);
                var i = this.siblings.indexOf(this.source); // If source node is in the target nodes
                if (i > -1) {
                  this.siblings.splice(i, 1);
                  if (this.source.index() < index) {
                    index--;
                  }
                }
                this.siblings.splice(index, 0, this.source);
                this.index = index;
              },

              parentNode: function() {
                return this.parent.$nodeScope;
              },

              prev: function() {
                if (this.index > 0) {
                  return this.siblings[this.index - 1];
                }
                return null;
              },

              next: function() {
                if (this.index < this.siblings.length - 1) {
                  return this.siblings[this.index + 1];
                }
                return null;
              },

              isDirty: function() {
                return this.source.$parentNodesScope != this.parent ||
                        this.source.index() != this.index;
              },

              eventArgs: function(elements, pos) {
                return {
                  source: this.sourceInfo,
                  dest: {
                    index: this.index,
                    nodesScope: this.parent
                  },
                  elements: elements,
                  pos: pos
                };
              },

              apply: function() {
                var nodeData = this.source.$modelValue;
                this.source.remove();
                this.parent.insertNode(this.index, nodeData);
              }
            };
          },

          /**
          * @ngdoc method
          * @name hippo.theme#height
          * @methodOf ui.tree.service:$helper
          *
          * @description
          * Get the height of an element.
          *
          * @param {Object} element Angular element.
          * @returns {String} Height
          */
          height: function (element) {
            return element.prop('scrollHeight');
          },

          /**
          * @ngdoc method
          * @name hippo.theme#width
          * @methodOf ui.tree.service:$helper
          *
          * @description
          * Get the width of an element.
          *
          * @param {Object} element Angular element.
          * @returns {String} Width
          */
          width: function (element) {
            return element.prop('scrollWidth');
          },

          /**
          * @ngdoc method
          * @name hippo.theme#offset
          * @methodOf ui.nestedSortable.service:$helper
          *
          * @description
          * Get the offset values of an element.
          *
          * @param {Object} element Angular element.
          * @returns {Object} Object with properties width, height, top and left
          */
          offset: function (element) {
            var boundingClientRect = element[0].getBoundingClientRect();

            return {
                width: element.prop('offsetWidth'),
                height: element.prop('offsetHeight'),
                top: boundingClientRect.top + ($window.pageYOffset || $document[0].body.scrollTop || $document[0].documentElement.scrollTop),
                left: boundingClientRect.left + ($window.pageXOffset || $document[0].body.scrollLeft  || $document[0].documentElement.scrollLeft)
              };
          },

          /**
          * @ngdoc method
          * @name hippo.theme#positionStarted
          * @methodOf ui.tree.service:$helper
          *
          * @description
          * Get the start position of the target element according to the provided event properties.
          *
          * @param {Object} e Event
          * @param {Object} target Target element
          * @returns {Object} Object with properties offsetX, offsetY, startX, startY, nowX and dirX.
          */
          positionStarted: function (e, target) {
            var pos = {};
            pos.offsetX = e.pageX - this.offset(target).left;
            pos.offsetY = e.pageY - this.offset(target).top;
            pos.startX = pos.lastX = e.pageX;
            pos.startY = pos.lastY = e.pageY;
            pos.nowX = pos.nowY = pos.distX = pos.distY = pos.dirAx = 0;
            pos.dirX = pos.dirY = pos.lastDirX = pos.lastDirY = pos.distAxX = pos.distAxY = 0;
            return pos;
          },

          positionMoved: function (e, pos, firstMoving) {
            // mouse position last events
            pos.lastX = pos.nowX;
            pos.lastY = pos.nowY;

            // mouse position this events
            pos.nowX  = e.pageX;
            pos.nowY  = e.pageY;

            // distance mouse moved between events
            pos.distX = pos.nowX - pos.lastX;
            pos.distY = pos.nowY - pos.lastY;

            // direction mouse was moving
            pos.lastDirX = pos.dirX;
            pos.lastDirY = pos.dirY;

            // direction mouse is now moving (on both axis)
            pos.dirX = pos.distX === 0 ? 0 : pos.distX > 0 ? 1 : -1;
            pos.dirY = pos.distY === 0 ? 0 : pos.distY > 0 ? 1 : -1;

            // axis mouse is now moving on
            var newAx   = Math.abs(pos.distX) > Math.abs(pos.distY) ? 1 : 0;

            // do nothing on first move
            if (firstMoving) {
              pos.dirAx  = newAx;
              pos.moving = true;
              return;
            }

            // calc distance moved on this axis (and direction)
            if (pos.dirAx !== newAx) {
              pos.distAxX = 0;
              pos.distAxY = 0;
            } else {
              pos.distAxX += Math.abs(pos.distX);
              if (pos.dirX !== 0 && pos.dirX !== pos.lastDirX) {
                pos.distAxX = 0;
              }

              pos.distAxY += Math.abs(pos.distY);
              if (pos.dirY !== 0 && pos.dirY !== pos.lastDirY) {
                pos.distAxY = 0;
              }
            }

            pos.dirAx = newAx;
          }
        };
      }
    ]);

})();
(function () {
  'use strict';

  angular.module('ui.tree')

    .controller('TreeController', ['$scope', '$element', '$attrs', 'treeConfig',
      function ($scope, $element, $attrs, treeConfig) {
        this.scope = $scope;

        $scope.$element = $element;
        $scope.$nodesScope = null; // root nodes
        $scope.$type = 'uiTree';
        $scope.$emptyElm = null;
        $scope.$callbacks = null;

        $scope.dragEnabled = true;
        $scope.emptyPlaceHolderEnabled = true;
        $scope.maxDepth = 0;
        $scope.dragDelay = 0;

        // Check if it's a empty tree
        $scope.isEmpty = function() {
          return ($scope.$nodesScope && $scope.$nodesScope.$modelValue
            && $scope.$nodesScope.$modelValue.length === 0);
        };

        // add placeholder to empty tree
        $scope.place = function(placeElm) {
          $scope.$nodesScope.$element.append(placeElm);
          $scope.$emptyElm.remove();
        };

        $scope.resetEmptyElement = function() {
          if ($scope.$nodesScope.$modelValue.length === 0 &&
            $scope.emptyPlaceHolderEnabled) {
            $element.append($scope.$emptyElm);
          } else {
            $scope.$emptyElm.remove();
          }
        };

        var collapseOrExpand = function(scope, collapsed) {
          var nodes = scope.childNodes();
          for (var i = 0; i < nodes.length; i++) {
            collapsed ? nodes[i].collapse() : nodes[i].expand();
            var subScope = nodes[i].$childNodesScope;
            if (subScope) {
              collapseOrExpand(subScope, collapsed);
            }
          }
        };

        $scope.collapseAll = function() {
          collapseOrExpand($scope.$nodesScope, true);
        };

        $scope.expandAll = function() {
          collapseOrExpand($scope.$nodesScope, false);
        };

      }
    ]);
})();

(function () {
  'use strict';

  angular.module('ui.tree')

    .controller('TreeNodesController', ['$scope', '$element', 'treeConfig',
      function ($scope, $element, treeConfig) {
        this.scope = $scope;

        $scope.$element = $element;
        $scope.$modelValue = null;
        $scope.$nodeScope = null; // the scope of node which the nodes belongs to
        $scope.$treeScope = null;
        $scope.$type = 'uiTreeNodes';
        $scope.$nodesMap = {};

        $scope.nodrop = false;
        $scope.maxDepth = 0;

        $scope.initSubNode = function(subNode) {
          $scope.$nodesMap[subNode.$modelValue.$$hashKey] = subNode;
        };

        $scope.destroySubNode = function(subNode) {
          $scope.$nodesMap[subNode.$modelValue.$$hashKey] = null;
        };

        $scope.accept = function(sourceNode, destIndex) {
          return $scope.$treeScope.$callbacks.accept(sourceNode, $scope, destIndex);
        };

        $scope.beforeDrag = function(sourceNode) {
          return $scope.$treeScope.$callbacks.beforeDrag(sourceNode);
        };

        $scope.isParent = function(node) {
          return node.$parentNodesScope == $scope;
        };

        $scope.hasChild = function() {
          return $scope.$modelValue.length > 0;
        };

        $scope.safeApply = function(fn) {
          var phase = this.$root.$$phase;
          if(phase == '$apply' || phase == '$digest') {
            if(fn && (typeof(fn) === 'function')) {
              fn();
            }
          } else {
            this.$apply(fn);
          }
        };

        $scope.removeNode = function(node) {
          var index = $scope.$modelValue.indexOf(node.$modelValue);
          if (index > -1) {
            $scope.safeApply(function() {
              $scope.$modelValue.splice(index, 1)[0];
            });
            return node;
          }
          return null;
        };

        $scope.insertNode = function(index, nodeData) {
          $scope.safeApply(function() {
            $scope.$modelValue.splice(index, 0, nodeData);
          });
        };

        $scope.childNodes = function() {
          var nodes = [];
          if ($scope.$modelValue) {
            for (var i = 0; i < $scope.$modelValue.length; i++) {
              nodes.push($scope.$nodesMap[$scope.$modelValue[i].$$hashKey]);
            }
          }
          return nodes;
        };

        $scope.depth = function() {
          if ($scope.$nodeScope) {
            return $scope.$nodeScope.depth();
          }
          return 0; // if it has no $nodeScope, it's root
        };

        // check if depth limit has reached
        $scope.outOfDepth = function(sourceNode) {
          var maxDepth = $scope.maxDepth || $scope.$treeScope.maxDepth;
          if (maxDepth > 0) {
            return $scope.depth() + sourceNode.maxSubDepth() + 1 > maxDepth;
          }
          return false;
        };

      }
    ]);
})();
(function () {
  'use strict';

  angular.module('ui.tree')

    .controller('TreeNodeController', ['$scope', '$element', '$attrs', 'treeConfig',
      function ($scope, $element, $attrs, treeConfig) {
        this.scope = $scope;

        $scope.$element = $element;
        $scope.$modelValue = null; // Model value for node;
        $scope.$parentNodeScope = null; // uiTreeNode Scope of parent node;
        $scope.$childNodesScope = null; // uiTreeNodes Scope of child nodes.
        $scope.$parentNodesScope = null; // uiTreeNodes Scope of parent nodes.
        $scope.$treeScope = null; // uiTree scope
        $scope.$handleScope = null; // it's handle scope
        $scope.$type = 'uiTreeNode';
        $scope.$$apply = false; //

        $scope.collapsed = false;

        $scope.init = function(controllersArr) {
          var treeNodesCtrl = controllersArr[0];
          $scope.$treeScope = controllersArr[1] ? controllersArr[1].scope : null;

          // find the scope of it's parent node
          $scope.$parentNodeScope = treeNodesCtrl.scope.$nodeScope;
          // modelValue for current node
          $scope.$modelValue = treeNodesCtrl.scope.$modelValue[$scope.$index];
          $scope.$parentNodesScope = treeNodesCtrl.scope;
          treeNodesCtrl.scope.initSubNode($scope); // init sub nodes

          $element.on('$destroy', function() {
            treeNodesCtrl.scope.destroySubNode($scope); // destroy sub nodes
          });
        };

        $scope.index = function() {
          return $scope.$parentNodesScope.$modelValue.indexOf($scope.$modelValue);
        };

        $scope.dragEnabled = function() {
          return !($scope.$treeScope && !$scope.$treeScope.dragEnabled);
        };

        $scope.isSibling = function(targetNode) {
          return $scope.$parentNodesScope == targetNode.$parentNodesScope;
        };

        $scope.isChild = function(targetNode) {
          var nodes = $scope.childNodes();
          return nodes && nodes.indexOf(targetNode) > -1;
        };

        $scope.prev = function() {
          var index = $scope.index();
          if (index > 0) {
            return $scope.siblings()[index - 1];
          }
          return null;
        };

        $scope.siblings = function() {
          return $scope.$parentNodesScope.childNodes();
        };

        $scope.childNodesCount = function() {
          return $scope.childNodes() ? $scope.childNodes().length : 0;
        };

        $scope.hasChild = function() {
          return $scope.childNodesCount() > 0;
        };

        $scope.childNodes = function() {
          return $scope.$childNodesScope && $scope.$childNodesScope.$modelValue ?
              $scope.$childNodesScope.childNodes() :
              null;
        };

        $scope.accept = function(sourceNode, destIndex) {
          return $scope.$childNodesScope &&
                  $scope.$childNodesScope.$modelValue &&
                  $scope.$childNodesScope.accept(sourceNode, destIndex);
        };

        $scope.removeNode = function(){
          var node = $scope.remove();
          $scope.$callbacks.removed(node);
          return node;
        };

        $scope.remove = function() {
          return $scope.$parentNodesScope.removeNode($scope);
        };

        $scope.toggle = function() {
          $scope.collapsed = !$scope.collapsed;
        };

        $scope.collapse = function() {
          $scope.collapsed = true;
        };

        $scope.expand = function() {
          $scope.collapsed = false;
        };

        $scope.depth = function() {
          var parentNode = $scope.$parentNodeScope;
          if (parentNode) {
            return parentNode.depth() + 1;
          }
          return 1;
        };

        var subDepth = 0;
        var countSubDepth = function(scope) {
          var count = 0;
          var nodes = scope.childNodes();
          for (var i = 0; i < nodes.length; i++) {
            var childNodes = nodes[i].$childNodesScope;
            if (childNodes) {
              count = 1;
              countSubDepth(childNodes);
            }
          }
          subDepth += count;
        };

        $scope.maxSubDepth = function() {
          subDepth = 0;
          if ($scope.$childNodesScope) {
            countSubDepth($scope.$childNodesScope);
          }
          return subDepth;
        };

      }
    ]);
})();

(function () {
  'use strict';

  angular.module('ui.tree')

    .controller('TreeHandleController', ['$scope', '$element', '$attrs', 'treeConfig',
      function ($scope, $element, $attrs, treeConfig) {
        this.scope = $scope;

        $scope.$element = $element;
        $scope.$nodeScope = null;
        $scope.$type = 'uiTreeHandle';

      }
    ]);
})();

(function () {
  'use strict';

  angular.module('ui.tree')
  .directive('uiTree', [ 'treeConfig', '$window',
    function(treeConfig, $window) {
      return {
        restrict: 'A',
        scope: true,
        controller: 'TreeController',
        link: function(scope, element, attrs) {
          var callbacks = {
            accept: null,
            beforeDrag: null
          };

          var config = {};
          angular.extend(config, treeConfig);
          if (config.treeClass) {
            element.addClass(config.treeClass);
          }

          scope.$emptyElm = angular.element($window.document.createElement('div'));
          if (config.emptyTreeClass) {
            scope.$emptyElm.addClass(config.emptyTreeClass);
          }

          scope.$watch('$nodesScope.$modelValue.length', function() {
            if (scope.$nodesScope.$modelValue) {
              scope.resetEmptyElement();
            }
          }, true);

          scope.$watch(attrs.dragEnabled, function(val) {
            if((typeof val) == "boolean") {
              scope.dragEnabled = val;
            }
          });

          scope.$watch(attrs.emptyPlaceHolderEnabled, function(val) {
            if((typeof val) == "boolean") {
              scope.emptyPlaceHolderEnabled = val;
            }
          });

          scope.$watch(attrs.maxDepth, function(val) {
            if((typeof val) == "number") {
              scope.maxDepth = val;
            }
          });

          scope.$watch(attrs.dragDelay, function(val) {
            if((typeof val) == "number") {
              scope.dragDelay = val;
            }
          });

          // check if the dest node can accept the dragging node
          // by default, we check the 'data-nodrop' attribute in `ui-tree-nodes`
          // and the 'max-depth' attribute in `ui-tree` or `ui-tree-nodes`.
          // the method can be overrided
          callbacks.accept = function(sourceNodeScope, destNodesScope, destIndex) {
            if (destNodesScope.nodrop || destNodesScope.outOfDepth(sourceNodeScope)) {
              return false;
            }
            return true;
          };

          callbacks.beforeDrag = function(sourceNodeScope) {
            return true;
          };

          callbacks.removed = function(node){
          
          };

          callbacks.dropped = function(event) {

          };

          //
          callbacks.dragStart = function(event) {

          };

          callbacks.dragMove = function(event) {

          };

          callbacks.dragStop = function(event) {

          };

          callbacks.beforeDrop = function(event) {

          };

          scope.$watch(attrs.uiTree, function(newVal, oldVal){
            angular.forEach(newVal, function(value, key){
              if (callbacks[key]) {
                if (typeof value === "function") {
                  callbacks[key] = value;
                }
              }
            });

            scope.$callbacks = callbacks;
          }, true);


        }
      };
    }
  ]);
})();

(function () {
  'use strict';

  angular.module('ui.tree')
  .directive('uiTreeNodes', [ 'treeConfig', '$window',
    function(treeConfig) {
      return {
        require: ['ngModel', '?^uiTreeNode', '^uiTree'],
        restrict: 'A',
        scope: true,
        controller: 'TreeNodesController',
        link: function(scope, element, attrs, controllersArr) {

          var config = {};
          angular.extend(config, treeConfig);
          if (config.nodesClass) {
            element.addClass(config.nodesClass);
          }

          var ngModel = controllersArr[0];
          var treeNodeCtrl = controllersArr[1];
          var treeCtrl = controllersArr[2];
          if (treeNodeCtrl) {
            treeNodeCtrl.scope.$childNodesScope = scope;
            scope.$nodeScope = treeNodeCtrl.scope;
          }
          else { // find the root nodes if there is no parent node and have a parent ui-tree
            treeCtrl.scope.$nodesScope = scope;
          }
          scope.$treeScope = treeCtrl.scope;

          if (ngModel) {
            ngModel.$render = function() {
              if (!ngModel.$modelValue || !angular.isArray(ngModel.$modelValue)) {
                scope.$modelValue = [];
              }
              scope.$modelValue = ngModel.$modelValue;
            };
          }

          scope.$watch(attrs.maxDepth, function(val) {
            if((typeof val) == "number") {
              scope.maxDepth = val;
            }
          });

          attrs.$observe('nodrop', function(val) {
            scope.nodrop = ((typeof val) != "undefined");
          });

          attrs.$observe('horizontal', function(val) {
            scope.horizontal = ((typeof val) != "undefined");
          });

        }
      };
    }
  ]);
})();

(function () {
  'use strict';

  angular.module('ui.tree')

    .directive('uiTreeNode', ['treeConfig', '$uiTreeHelper', '$window', '$document','$timeout',
      function (treeConfig, $uiTreeHelper, $window, $document, $timeout) {
        return {
          require: ['^uiTreeNodes', '^uiTree'],
          restrict: 'A',
          controller: 'TreeNodeController',
          link: function(scope, element, attrs, controllersArr) {
            var config = {};
            angular.extend(config, treeConfig);
            if (config.nodeClass) {
              element.addClass(config.nodeClass);
            }
            scope.init(controllersArr);

            scope.collapsed = !!$uiTreeHelper.getNodeAttribute(scope, 'collapsed');

            scope.$watch(attrs.collapsed, function(val) {
              if((typeof val) == "boolean") {
                scope.collapsed = val;
              }
            });

            scope.$watch('collapsed', function(val) {
              $uiTreeHelper.setNodeAttribute(scope, 'collapsed', val);
              attrs.$set('collapsed', val);
            });

            var hasTouch = 'ontouchstart' in window;
            // todo startPos is unused
            var startPos, firstMoving, dragInfo, pos;
            var placeElm, hiddenPlaceElm, dragElm;
            var treeScope = null;
            var elements; // As a parameter for callbacks
            var dragDelaying = true;
            var dragStarted = false;
            var dragTimer = null;
            var body = document.body,
                html = document.documentElement,
                document_height,
                document_width;

            var dragStart = function(e) {
              if (!hasTouch && (e.button == 2 || e.which == 3)) {
                // disable right click
                return;
              }
              if (e.uiTreeDragging || (e.originalEvent && e.originalEvent.uiTreeDragging)) { // event has already fired in other scope.
                return;
              }

              // the element which is clicked.
              var eventElm = angular.element(e.target);
              var eventScope = eventElm.scope();
              if (!eventScope || !eventScope.$type) {
                return;
              }
              if (eventScope.$type != 'uiTreeNode'
                && eventScope.$type != 'uiTreeHandle') { // Check if it is a node or a handle
                return;
              }
              if (eventScope.$type == 'uiTreeNode'
                && eventScope.$handleScope) { // If the node has a handle, then it should be clicked by the handle
                return;
              }

              var eventElmTagName = eventElm.prop('tagName').toLowerCase();
              if (eventElmTagName == 'input' ||
                eventElmTagName == 'textarea' ||
                eventElmTagName == 'button' ||
                eventElmTagName == 'select') { // if it's a input or button, ignore it
                return;
              }

              // check if it or it's parents has a 'data-nodrag' attribute
              while (eventElm && eventElm[0] && eventElm[0] != element) {
                if ($uiTreeHelper.nodrag(eventElm)) { // if the node mark as `nodrag`, DONOT drag it.
                  return;
                }
                eventElm = eventElm.parent();
              }

              if (!scope.beforeDrag(scope)){
                return;
              }

              e.uiTreeDragging = true; // stop event bubbling
              if (e.originalEvent) {
                e.originalEvent.uiTreeDragging = true;
              }
              e.preventDefault();
              var eventObj = $uiTreeHelper.eventObj(e);

              firstMoving = true;
              dragInfo = $uiTreeHelper.dragInfo(scope);

              var tagName = scope.$element.prop('tagName');
              if (tagName.toLowerCase() === 'tr') {
                placeElm = angular.element($window.document.createElement(tagName));
                var tdElm = angular.element($window.document.createElement('td'))
                              .addClass(config.placeHolderClass);
                placeElm.append(tdElm);
              } else {
                placeElm = angular.element($window.document.createElement(tagName))
                              .addClass(config.placeHolderClass);
              }
              hiddenPlaceElm = angular.element($window.document.createElement(tagName));
              if (config.hiddenClass) {
                hiddenPlaceElm.addClass(config.hiddenClass);
              }
              pos = $uiTreeHelper.positionStarted(eventObj, scope.$element);
              placeElm.css('height', $uiTreeHelper.height(scope.$element) + 'px');
              placeElm.css('width', $uiTreeHelper.width(scope.$element) + 'px');
              dragElm = angular.element($window.document.createElement(scope.$parentNodesScope.$element.prop('tagName')))
                        .addClass(scope.$parentNodesScope.$element.attr('class')).addClass(config.dragClass);
              dragElm.css('width', $uiTreeHelper.width(scope.$element) + 'px');
              dragElm.css('z-index', 9999);

              // Prevents cursor to change rapidly in Opera 12.16 and IE when dragging an element
              var hStyle = (scope.$element[0].querySelector('.angular-ui-tree-handle') || scope.$element[0]).currentStyle;
              if (hStyle) {
                document.body.setAttribute('ui-tree-cursor', $document.find('body').css('cursor') || '');
                $document.find('body').css({'cursor': hStyle.cursor + '!important'});
              }

              scope.$element.after(placeElm);
              scope.$element.after(hiddenPlaceElm);
              dragElm.append(scope.$element);
              $document.find('body').append(dragElm);
              dragElm.css({
                'left' : eventObj.pageX - pos.offsetX + 'px',
                'top'  : eventObj.pageY - pos.offsetY + 'px'
              });
              elements = {
                placeholder: placeElm,
                dragging: dragElm
              };

              angular.element($document).bind('touchend', dragEndEvent);
              angular.element($document).bind('touchcancel', dragEndEvent);
              angular.element($document).bind('touchmove', dragMoveEvent);
              angular.element($document).bind('mouseup', dragEndEvent);
              angular.element($document).bind('mousemove', dragMoveEvent);
              angular.element($document).bind('mouseleave', dragCancelEvent);

              document_height = Math.max(body.scrollHeight, body.offsetHeight, html.clientHeight, html.scrollHeight, html.offsetHeight);
              document_width = Math.max(body.scrollWidth, body.offsetWidth, html.clientWidth, html.scrollWidth, html.offsetWidth);
            };

            var dragMove = function(e) {
              if (!dragStarted) {
                if (!dragDelaying) {
                  dragStarted = true;
                  scope.$apply(function() {
                    scope.$callbacks.dragStart(dragInfo.eventArgs(elements, pos));
                  });
                }
                return;
              }

              var eventObj = $uiTreeHelper.eventObj(e);
              var prev, leftElmPos, topElmPos;

              if (dragElm) {
                e.preventDefault();

                if ($window.getSelection) {
                  $window.getSelection().removeAllRanges();
                } else if ($window.document.selection) {
                  $window.document.selection.empty();
                }

                leftElmPos = eventObj.pageX - pos.offsetX;
                topElmPos = eventObj.pageY - pos.offsetY;

                //dragElm can't leave the screen on the left
                if(leftElmPos < 0){
                  leftElmPos = 0;
                }

                //dragElm can't leave the screen on the top
                if(topElmPos < 0){
                  topElmPos = 0;
                }

                //dragElm can't leave the screen on the bottom
                if ((topElmPos + 10) > document_height){
                  topElmPos = document_height - 10;
                }

                //dragElm can't leave the screen on the right
                if((leftElmPos + 10) > document_width) {
                  leftElmPos = document_width - 10;
                }

                dragElm.css({
                  'left': leftElmPos + 'px',
                  'top': topElmPos + 'px'
                });

                var top_scroll = window.pageYOffset || $window.document.documentElement.scrollTop;
                var bottom_scroll = top_scroll + (window.innerHeight || $window.document.clientHeight || $window.document.clientHeight);

                // to scroll down if cursor y-position is greater than the bottom position the vertical scroll
                if (bottom_scroll < eventObj.pageY && bottom_scroll <= document_height) {
                  window.scrollBy(0, 10);
                }

                // to scroll top if cursor y-position is less than the top position the vertical scroll
                if (top_scroll > eventObj.pageY) {
                  window.scrollBy(0, -10);
                }

                $uiTreeHelper.positionMoved(e, pos, firstMoving);
                if (firstMoving) {
                  firstMoving = false;
                  return;
                }

                // move horizontal
                if (pos.dirAx && pos.distAxX >= config.levelThreshold) {
                  pos.distAxX = 0;

                  // increase horizontal level if previous sibling exists and is not collapsed
                  if (pos.distX > 0) {
                    prev = dragInfo.prev();
                    if (prev && !prev.collapsed
                      && prev.accept(scope, prev.childNodesCount())) {
                      prev.$childNodesScope.$element.append(placeElm);
                      dragInfo.moveTo(prev.$childNodesScope, prev.childNodes(), prev.childNodesCount());
                    }
                  }

                  // decrease horizontal level
                  if (pos.distX < 0) {
                    // we can't decrease a level if an item preceeds the current one
                    var next = dragInfo.next();
                    if (!next) {
                      var target = dragInfo.parentNode(); // As a sibling of it's parent node
                      if (target
                        && target.$parentNodesScope.accept(scope, target.index() + 1)) {
                        target.$element.after(placeElm);
                        dragInfo.moveTo(target.$parentNodesScope, target.siblings(), target.index() + 1);
                      }
                    }
                  }
                }

                // check if add it as a child node first
                // todo decrease is unused
                var decrease = ($uiTreeHelper.offset(dragElm).left - $uiTreeHelper.offset(placeElm).left) >= config.threshold;
                var targetX = eventObj.pageX - $window.document.body.scrollLeft;
                var targetY = eventObj.pageY - (window.pageYOffset || $window.document.documentElement.scrollTop);

                // Select the drag target. Because IE does not support CSS 'pointer-events: none', it will always
                // pick the drag element itself as the target. To prevent this, we hide the drag element while
                // selecting the target.
                var displayElm;
                if (angular.isFunction(dragElm.hide)) {
                  dragElm.hide();
                }else{
                  displayElm = dragElm[0].style.display;
                  dragElm[0].style.display = "none";
                }

                // when using elementFromPoint() inside an iframe, you have to call
                // elementFromPoint() twice to make sure IE8 returns the correct value
                $window.document.elementFromPoint(targetX, targetY);

                var targetElm = angular.element($window.document.elementFromPoint(targetX, targetY));
                if (angular.isFunction(dragElm.show)) {
                  dragElm.show();
                }else{
                  dragElm[0].style.display = displayElm;
                }

                // move vertical
                if (!pos.dirAx) {
                  var targetBefore, targetNode;
                  // check it's new position
                  targetNode = targetElm.scope();
                  var isEmpty = false;
                  if (!targetNode) {
                    return;
                  }
                  if (targetNode.$type == 'uiTree' && targetNode.dragEnabled) {
                    isEmpty = targetNode.isEmpty(); // Check if it's empty tree
                  }
                  if (targetNode.$type == 'uiTreeHandle') {
                    targetNode = targetNode.$nodeScope;
                  }
                  if (targetNode.$type != 'uiTreeNode'
                    && !isEmpty) { // Check if it is a uiTreeNode or it's an empty tree
                    return;
                  }

                  // if placeholder move from empty tree, reset it.
                  if (treeScope && placeElm.parent()[0] != treeScope.$element[0]) {
                    treeScope.resetEmptyElement();
                    treeScope = null;
                  }

                  if (isEmpty) { // it's an empty tree
                    treeScope = targetNode;
                    if (targetNode.$nodesScope.accept(scope, 0)) {
                      targetNode.place(placeElm);
                      dragInfo.moveTo(targetNode.$nodesScope, targetNode.$nodesScope.childNodes(), 0);
                    }
                  } else if (targetNode.dragEnabled()){ // drag enabled
                    targetElm = targetNode.$element; // Get the element of ui-tree-node
                    var targetOffset = $uiTreeHelper.offset(targetElm);
                    targetBefore = targetNode.horizontal ? eventObj.pageX < (targetOffset.left + $uiTreeHelper.width(targetElm) / 2)
                                                         : eventObj.pageY < (targetOffset.top + $uiTreeHelper.height(targetElm) / 2);

                    if (targetNode.$parentNodesScope.accept(scope, targetNode.index())) {
                      if (targetBefore) {
                        targetElm[0].parentNode.insertBefore(placeElm[0], targetElm[0]);
                        dragInfo.moveTo(targetNode.$parentNodesScope, targetNode.siblings(), targetNode.index());
                      } else {
                        targetElm.after(placeElm);
                        dragInfo.moveTo(targetNode.$parentNodesScope, targetNode.siblings(), targetNode.index() + 1);
                      }
                    }
                    else if (!targetBefore && targetNode.accept(scope, targetNode.childNodesCount())) { // we have to check if it can add the dragging node as a child
                      targetNode.$childNodesScope.$element.append(placeElm);
                      dragInfo.moveTo(targetNode.$childNodesScope, targetNode.childNodes(), targetNode.childNodesCount());
                    }
                  }

                }

                scope.$apply(function() {
                  scope.$callbacks.dragMove(dragInfo.eventArgs(elements, pos));
                });
              }
            };

            var dragEnd = function(e) {
              e.preventDefault();

              if (dragElm) {
                scope.$treeScope.$apply(function() {
                  scope.$callbacks.beforeDrop(dragInfo.eventArgs(elements, pos));
                });
                // roll back elements changed
                hiddenPlaceElm.replaceWith(scope.$element);
                placeElm.remove();

                dragElm.remove();
                dragElm = null;
                if (scope.$$apply) {
                  dragInfo.apply();
                  scope.$treeScope.$apply(function() {
                    scope.$callbacks.dropped(dragInfo.eventArgs(elements, pos));
                  });
                } else {
                  bindDrag();
                }
                scope.$treeScope.$apply(function() {
                  scope.$callbacks.dragStop(dragInfo.eventArgs(elements, pos));
                });
                scope.$$apply = false;
                dragInfo = null;

              }

              // Restore cursor in Opera 12.16 and IE
              var oldCur = document.body.getAttribute('ui-tree-cursor');
              if (oldCur !== null) {
                $document.find('body').css({'cursor': oldCur});
                document.body.removeAttribute('ui-tree-cursor');
              }

              angular.element($document).unbind('touchend', dragEndEvent); // Mobile
              angular.element($document).unbind('touchcancel', dragEndEvent); // Mobile
              angular.element($document).unbind('touchmove', dragMoveEvent); // Mobile
              angular.element($document).unbind('mouseup', dragEndEvent);
              angular.element($document).unbind('mousemove', dragMoveEvent);
              angular.element($window.document.body).unbind('mouseleave', dragCancelEvent);
            };

            var dragStartEvent = function(e) {
              if (scope.dragEnabled()) {
                dragStart(e);
              }
            };

            var dragMoveEvent = function(e) {
              dragMove(e);
            };

            var dragEndEvent = function(e) {
              scope.$$apply = true;
              dragEnd(e);
            };

            var dragCancelEvent = function(e) {
              dragEnd(e);
            };

            var bindDrag = function() {
              element.bind('touchstart mousedown', function (e) {
                dragDelaying = true;
                dragStarted = false;
                dragStartEvent(e);
                dragTimer = $timeout(function(){dragDelaying = false;}, scope.dragDelay);
              });
              element.bind('touchend touchcancel mouseup',function(){$timeout.cancel(dragTimer);});
            };
            bindDrag();

            angular.element($window.document.body).bind("keydown", function(e) {
              if (e.keyCode == 27) {
                scope.$$apply = false;
                dragEnd(e);
              }
            });
          }
        };
      }
    ]);

})();

(function () {
  'use strict';

  angular.module('ui.tree')
  .directive('uiTreeHandle', [ 'treeConfig', '$window',
    function(treeConfig) {
      return {
        require: '^uiTreeNode',
        restrict: 'A',
        scope: true,
        controller: 'TreeHandleController',
        link: function(scope, element, attrs, treeNodeCtrl) {
          var config = {};
          angular.extend(config, treeConfig);
          if (config.handleClass) {
            element.addClass(config.handleClass);
          }
          // connect with the tree node.
          if (scope != treeNodeCtrl.scope) {
            scope.$nodeScope = treeNodeCtrl.scope;
            treeNodeCtrl.scope.$handleScope = scope;
          }
        }
      };
    }
  ]);
})();

/**
 * @license AngularJS v1.3.20
 * (c) 2010-2014 Google, Inc. http://angularjs.org
 * License: MIT
 */
(function(window, angular, undefined) {'use strict';

/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
 *     Any commits to this file should be reviewed with security in mind.  *
 *   Changes to this file can potentially create security vulnerabilities. *
 *          An approval from 2 Core members with history of modifying      *
 *                         this file is required.                          *
 *                                                                         *
 *  Does the change somehow allow for arbitrary javascript to be executed? *
 *    Or allows for someone to change the prototype of built-in objects?   *
 *     Or gives undesired access to variables likes document or window?    *
 * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

var $sanitizeMinErr = angular.$$minErr('$sanitize');

/**
 * @ngdoc module
 * @name ngSanitize
 * @description
 *
 * # ngSanitize
 *
 * The `ngSanitize` module provides functionality to sanitize HTML.
 *
 *
 * <div doc-module-components="ngSanitize"></div>
 *
 * See {@link ngSanitize.$sanitize `$sanitize`} for usage.
 */

/*
 * HTML Parser By Misko Hevery (misko@hevery.com)
 * based on:  HTML Parser By John Resig (ejohn.org)
 * Original code by Erik Arvidsson, Mozilla Public License
 * http://erik.eae.net/simplehtmlparser/simplehtmlparser.js
 *
 * // Use like so:
 * htmlParser(htmlString, {
 *     start: function(tag, attrs, unary) {},
 *     end: function(tag) {},
 *     chars: function(text) {},
 *     comment: function(text) {}
 * });
 *
 */


/**
 * @ngdoc service
 * @name $sanitize
 * @kind function
 *
 * @description
 *   The input is sanitized by parsing the HTML into tokens. All safe tokens (from a whitelist) are
 *   then serialized back to properly escaped html string. This means that no unsafe input can make
 *   it into the returned string, however, since our parser is more strict than a typical browser
 *   parser, it's possible that some obscure input, which would be recognized as valid HTML by a
 *   browser, won't make it through the sanitizer. The input may also contain SVG markup.
 *   The whitelist is configured using the functions `aHrefSanitizationWhitelist` and
 *   `imgSrcSanitizationWhitelist` of {@link ng.$compileProvider `$compileProvider`}.
 *
 * @param {string} html HTML input.
 * @returns {string} Sanitized HTML.
 *
 * @example
   <example module="sanitizeExample" deps="angular-sanitize.js">
   <file name="index.html">
     <script>
         angular.module('sanitizeExample', ['ngSanitize'])
           .controller('ExampleController', ['$scope', '$sce', function($scope, $sce) {
             $scope.snippet =
               '<p style="color:blue">an html\n' +
               '<em onmouseover="this.textContent=\'PWN3D!\'">click here</em>\n' +
               'snippet</p>';
             $scope.deliberatelyTrustDangerousSnippet = function() {
               return $sce.trustAsHtml($scope.snippet);
             };
           }]);
     </script>
     <div ng-controller="ExampleController">
        Snippet: <textarea ng-model="snippet" cols="60" rows="3"></textarea>
       <table>
         <tr>
           <td>Directive</td>
           <td>How</td>
           <td>Source</td>
           <td>Rendered</td>
         </tr>
         <tr id="bind-html-with-sanitize">
           <td>ng-bind-html</td>
           <td>Automatically uses $sanitize</td>
           <td><pre>&lt;div ng-bind-html="snippet"&gt;<br/>&lt;/div&gt;</pre></td>
           <td><div ng-bind-html="snippet"></div></td>
         </tr>
         <tr id="bind-html-with-trust">
           <td>ng-bind-html</td>
           <td>Bypass $sanitize by explicitly trusting the dangerous value</td>
           <td>
           <pre>&lt;div ng-bind-html="deliberatelyTrustDangerousSnippet()"&gt;
&lt;/div&gt;</pre>
           </td>
           <td><div ng-bind-html="deliberatelyTrustDangerousSnippet()"></div></td>
         </tr>
         <tr id="bind-default">
           <td>ng-bind</td>
           <td>Automatically escapes</td>
           <td><pre>&lt;div ng-bind="snippet"&gt;<br/>&lt;/div&gt;</pre></td>
           <td><div ng-bind="snippet"></div></td>
         </tr>
       </table>
       </div>
   </file>
   <file name="protractor.js" type="protractor">
     it('should sanitize the html snippet by default', function() {
       expect(element(by.css('#bind-html-with-sanitize div')).getInnerHtml()).
         toBe('<p>an html\n<em>click here</em>\nsnippet</p>');
     });

     it('should inline raw snippet if bound to a trusted value', function() {
       expect(element(by.css('#bind-html-with-trust div')).getInnerHtml()).
         toBe("<p style=\"color:blue\">an html\n" +
              "<em onmouseover=\"this.textContent='PWN3D!'\">click here</em>\n" +
              "snippet</p>");
     });

     it('should escape snippet without any filter', function() {
       expect(element(by.css('#bind-default div')).getInnerHtml()).
         toBe("&lt;p style=\"color:blue\"&gt;an html\n" +
              "&lt;em onmouseover=\"this.textContent='PWN3D!'\"&gt;click here&lt;/em&gt;\n" +
              "snippet&lt;/p&gt;");
     });

     it('should update', function() {
       element(by.model('snippet')).clear();
       element(by.model('snippet')).sendKeys('new <b onclick="alert(1)">text</b>');
       expect(element(by.css('#bind-html-with-sanitize div')).getInnerHtml()).
         toBe('new <b>text</b>');
       expect(element(by.css('#bind-html-with-trust div')).getInnerHtml()).toBe(
         'new <b onclick="alert(1)">text</b>');
       expect(element(by.css('#bind-default div')).getInnerHtml()).toBe(
         "new &lt;b onclick=\"alert(1)\"&gt;text&lt;/b&gt;");
     });
   </file>
   </example>
 */
function $SanitizeProvider() {
  this.$get = ['$$sanitizeUri', function($$sanitizeUri) {
    return function(html) {
      var buf = [];
      htmlParser(html, htmlSanitizeWriter(buf, function(uri, isImage) {
        return !/^unsafe/.test($$sanitizeUri(uri, isImage));
      }));
      return buf.join('');
    };
  }];
}

function sanitizeText(chars) {
  var buf = [];
  var writer = htmlSanitizeWriter(buf, angular.noop);
  writer.chars(chars);
  return buf.join('');
}


// Regular Expressions for parsing tags and attributes
var START_TAG_REGEXP =
       /^<((?:[a-zA-Z])[\w:-]*)((?:\s+[\w:-]+(?:\s*=\s*(?:(?:"[^"]*")|(?:'[^']*')|[^>\s]+))?)*)\s*(\/?)\s*(>?)/,
  END_TAG_REGEXP = /^<\/\s*([\w:-]+)[^>]*>/,
  ATTR_REGEXP = /([\w:-]+)(?:\s*=\s*(?:(?:"((?:[^"])*)")|(?:'((?:[^'])*)')|([^>\s]+)))?/g,
  BEGIN_TAG_REGEXP = /^</,
  BEGING_END_TAGE_REGEXP = /^<\//,
  COMMENT_REGEXP = /<!--(.*?)-->/g,
  DOCTYPE_REGEXP = /<!DOCTYPE([^>]*?)>/i,
  CDATA_REGEXP = /<!\[CDATA\[(.*?)]]>/g,
  SURROGATE_PAIR_REGEXP = /[\uD800-\uDBFF][\uDC00-\uDFFF]/g,
  // Match everything outside of normal chars and " (quote character)
  NON_ALPHANUMERIC_REGEXP = /([^\#-~| |!])/g;


// Good source of info about elements and attributes
// http://dev.w3.org/html5/spec/Overview.html#semantics
// http://simon.html5.org/html-elements

// Safe Void Elements - HTML5
// http://dev.w3.org/html5/spec/Overview.html#void-elements
var voidElements = makeMap("area,br,col,hr,img,wbr");

// Elements that you can, intentionally, leave open (and which close themselves)
// http://dev.w3.org/html5/spec/Overview.html#optional-tags
var optionalEndTagBlockElements = makeMap("colgroup,dd,dt,li,p,tbody,td,tfoot,th,thead,tr"),
    optionalEndTagInlineElements = makeMap("rp,rt"),
    optionalEndTagElements = angular.extend({},
                                            optionalEndTagInlineElements,
                                            optionalEndTagBlockElements);

// Safe Block Elements - HTML5
var blockElements = angular.extend({}, optionalEndTagBlockElements, makeMap("address,article," +
        "aside,blockquote,caption,center,del,dir,div,dl,figure,figcaption,footer,h1,h2,h3,h4,h5," +
        "h6,header,hgroup,hr,ins,map,menu,nav,ol,pre,script,section,table,ul"));

// Inline Elements - HTML5
var inlineElements = angular.extend({}, optionalEndTagInlineElements, makeMap("a,abbr,acronym,b," +
        "bdi,bdo,big,br,cite,code,del,dfn,em,font,i,img,ins,kbd,label,map,mark,q,ruby,rp,rt,s," +
        "samp,small,span,strike,strong,sub,sup,time,tt,u,var"));

// SVG Elements
// https://wiki.whatwg.org/wiki/Sanitization_rules#svg_Elements
var svgElements = makeMap("animate,animateColor,animateMotion,animateTransform,circle,defs," +
        "desc,ellipse,font-face,font-face-name,font-face-src,g,glyph,hkern,image,linearGradient," +
        "line,marker,metadata,missing-glyph,mpath,path,polygon,polyline,radialGradient,rect,set," +
        "stop,svg,switch,text,title,tspan,use");

// Special Elements (can contain anything)
var specialElements = makeMap("script,style");

var validElements = angular.extend({},
                                   voidElements,
                                   blockElements,
                                   inlineElements,
                                   optionalEndTagElements,
                                   svgElements);

//Attributes that have href and hence need to be sanitized
var uriAttrs = makeMap("background,cite,href,longdesc,src,usemap,xlink:href");

var htmlAttrs = makeMap('abbr,align,alt,axis,bgcolor,border,cellpadding,cellspacing,class,clear,' +
    'color,cols,colspan,compact,coords,dir,face,headers,height,hreflang,hspace,' +
    'ismap,lang,language,nohref,nowrap,rel,rev,rows,rowspan,rules,' +
    'scope,scrolling,shape,size,span,start,summary,target,title,type,' +
    'valign,value,vspace,width');

// SVG attributes (without "id" and "name" attributes)
// https://wiki.whatwg.org/wiki/Sanitization_rules#svg_Attributes
var svgAttrs = makeMap('accent-height,accumulate,additive,alphabetic,arabic-form,ascent,' +
    'attributeName,attributeType,baseProfile,bbox,begin,by,calcMode,cap-height,class,color,' +
    'color-rendering,content,cx,cy,d,dx,dy,descent,display,dur,end,fill,fill-rule,font-family,' +
    'font-size,font-stretch,font-style,font-variant,font-weight,from,fx,fy,g1,g2,glyph-name,' +
    'gradientUnits,hanging,height,horiz-adv-x,horiz-origin-x,ideographic,k,keyPoints,' +
    'keySplines,keyTimes,lang,marker-end,marker-mid,marker-start,markerHeight,markerUnits,' +
    'markerWidth,mathematical,max,min,offset,opacity,orient,origin,overline-position,' +
    'overline-thickness,panose-1,path,pathLength,points,preserveAspectRatio,r,refX,refY,' +
    'repeatCount,repeatDur,requiredExtensions,requiredFeatures,restart,rotate,rx,ry,slope,stemh,' +
    'stemv,stop-color,stop-opacity,strikethrough-position,strikethrough-thickness,stroke,' +
    'stroke-dasharray,stroke-dashoffset,stroke-linecap,stroke-linejoin,stroke-miterlimit,' +
    'stroke-opacity,stroke-width,systemLanguage,target,text-anchor,to,transform,type,u1,u2,' +
    'underline-position,underline-thickness,unicode,unicode-range,units-per-em,values,version,' +
    'viewBox,visibility,width,widths,x,x-height,x1,x2,xlink:actuate,xlink:arcrole,xlink:role,' +
    'xlink:show,xlink:title,xlink:type,xml:base,xml:lang,xml:space,xmlns,xmlns:xlink,y,y1,y2,' +
    'zoomAndPan');

var validAttrs = angular.extend({},
                                uriAttrs,
                                svgAttrs,
                                htmlAttrs);

function makeMap(str) {
  var obj = {}, items = str.split(','), i;
  for (i = 0; i < items.length; i++) obj[items[i]] = true;
  return obj;
}


/**
 * @example
 * htmlParser(htmlString, {
 *     start: function(tag, attrs, unary) {},
 *     end: function(tag) {},
 *     chars: function(text) {},
 *     comment: function(text) {}
 * });
 *
 * @param {string} html string
 * @param {object} handler
 */
function htmlParser(html, handler) {
  if (typeof html !== 'string') {
    if (html === null || typeof html === 'undefined') {
      html = '';
    } else {
      html = '' + html;
    }
  }
  var index, chars, match, stack = [], last = html, text;
  stack.last = function() { return stack[stack.length - 1]; };

  while (html) {
    text = '';
    chars = true;

    // Make sure we're not in a script or style element
    if (!stack.last() || !specialElements[stack.last()]) {

      // Comment
      if (html.indexOf("<!--") === 0) {
        // comments containing -- are not allowed unless they terminate the comment
        index = html.indexOf("--", 4);

        if (index >= 0 && html.lastIndexOf("-->", index) === index) {
          if (handler.comment) handler.comment(html.substring(4, index));
          html = html.substring(index + 3);
          chars = false;
        }
      // DOCTYPE
      } else if (DOCTYPE_REGEXP.test(html)) {
        match = html.match(DOCTYPE_REGEXP);

        if (match) {
          html = html.replace(match[0], '');
          chars = false;
        }
      // end tag
      } else if (BEGING_END_TAGE_REGEXP.test(html)) {
        match = html.match(END_TAG_REGEXP);

        if (match) {
          html = html.substring(match[0].length);
          match[0].replace(END_TAG_REGEXP, parseEndTag);
          chars = false;
        }

      // start tag
      } else if (BEGIN_TAG_REGEXP.test(html)) {
        match = html.match(START_TAG_REGEXP);

        if (match) {
          // We only have a valid start-tag if there is a '>'.
          if (match[4]) {
            html = html.substring(match[0].length);
            match[0].replace(START_TAG_REGEXP, parseStartTag);
          }
          chars = false;
        } else {
          // no ending tag found --- this piece should be encoded as an entity.
          text += '<';
          html = html.substring(1);
        }
      }

      if (chars) {
        index = html.indexOf("<");

        text += index < 0 ? html : html.substring(0, index);
        html = index < 0 ? "" : html.substring(index);

        if (handler.chars) handler.chars(decodeEntities(text));
      }

    } else {
      // IE versions 9 and 10 do not understand the regex '[^]', so using a workaround with [\W\w].
      html = html.replace(new RegExp("([\\W\\w]*)<\\s*\\/\\s*" + stack.last() + "[^>]*>", 'i'),
        function(all, text) {
          text = text.replace(COMMENT_REGEXP, "$1").replace(CDATA_REGEXP, "$1");

          if (handler.chars) handler.chars(decodeEntities(text));

          return "";
      });

      parseEndTag("", stack.last());
    }

    if (html == last) {
      throw $sanitizeMinErr('badparse', "The sanitizer was unable to parse the following block " +
                                        "of html: {0}", html);
    }
    last = html;
  }

  // Clean up any remaining tags
  parseEndTag();

  function parseStartTag(tag, tagName, rest, unary) {
    tagName = angular.lowercase(tagName);
    if (blockElements[tagName]) {
      while (stack.last() && inlineElements[stack.last()]) {
        parseEndTag("", stack.last());
      }
    }

    if (optionalEndTagElements[tagName] && stack.last() == tagName) {
      parseEndTag("", tagName);
    }

    unary = voidElements[tagName] || !!unary;

    if (!unary)
      stack.push(tagName);

    var attrs = {};

    rest.replace(ATTR_REGEXP,
      function(match, name, doubleQuotedValue, singleQuotedValue, unquotedValue) {
        var value = doubleQuotedValue
          || singleQuotedValue
          || unquotedValue
          || '';

        attrs[name] = decodeEntities(value);
    });
    if (handler.start) handler.start(tagName, attrs, unary);
  }

  function parseEndTag(tag, tagName) {
    var pos = 0, i;
    tagName = angular.lowercase(tagName);
    if (tagName)
      // Find the closest opened tag of the same type
      for (pos = stack.length - 1; pos >= 0; pos--)
        if (stack[pos] == tagName)
          break;

    if (pos >= 0) {
      // Close all the open elements, up the stack
      for (i = stack.length - 1; i >= pos; i--)
        if (handler.end) handler.end(stack[i]);

      // Remove the open elements from the stack
      stack.length = pos;
    }
  }
}

var hiddenPre=document.createElement("pre");
/**
 * decodes all entities into regular string
 * @param value
 * @returns {string} A string with decoded entities.
 */
function decodeEntities(value) {
  if (!value) { return ''; }

  hiddenPre.innerHTML = value.replace(/</g,"&lt;");
  // innerText depends on styling as it doesn't display hidden elements.
  // Therefore, it's better to use textContent not to cause unnecessary reflows.
  return hiddenPre.textContent;
}

/**
 * Escapes all potentially dangerous characters, so that the
 * resulting string can be safely inserted into attribute or
 * element text.
 * @param value
 * @returns {string} escaped text
 */
function encodeEntities(value) {
  return value.
    replace(/&/g, '&amp;').
    replace(SURROGATE_PAIR_REGEXP, function(value) {
      var hi = value.charCodeAt(0);
      var low = value.charCodeAt(1);
      return '&#' + (((hi - 0xD800) * 0x400) + (low - 0xDC00) + 0x10000) + ';';
    }).
    replace(NON_ALPHANUMERIC_REGEXP, function(value) {
      return '&#' + value.charCodeAt(0) + ';';
    }).
    replace(/</g, '&lt;').
    replace(/>/g, '&gt;');
}

/**
 * create an HTML/XML writer which writes to buffer
 * @param {Array} buf use buf.jain('') to get out sanitized html string
 * @returns {object} in the form of {
 *     start: function(tag, attrs, unary) {},
 *     end: function(tag) {},
 *     chars: function(text) {},
 *     comment: function(text) {}
 * }
 */
function htmlSanitizeWriter(buf, uriValidator) {
  var ignore = false;
  var out = angular.bind(buf, buf.push);
  return {
    start: function(tag, attrs, unary) {
      tag = angular.lowercase(tag);
      if (!ignore && specialElements[tag]) {
        ignore = tag;
      }
      if (!ignore && validElements[tag] === true) {
        out('<');
        out(tag);
        angular.forEach(attrs, function(value, key) {
          var lkey=angular.lowercase(key);
          var isImage = (tag === 'img' && lkey === 'src') || (lkey === 'background');
          if (validAttrs[lkey] === true &&
            (uriAttrs[lkey] !== true || uriValidator(value, isImage))) {
            out(' ');
            out(key);
            out('="');
            out(encodeEntities(value));
            out('"');
          }
        });
        out(unary ? '/>' : '>');
      }
    },
    end: function(tag) {
        tag = angular.lowercase(tag);
        if (!ignore && validElements[tag] === true) {
          out('</');
          out(tag);
          out('>');
        }
        if (tag == ignore) {
          ignore = false;
        }
      },
    chars: function(chars) {
        if (!ignore) {
          out(encodeEntities(chars));
        }
      }
  };
}


// define ngSanitize module and register $sanitize service
angular.module('ngSanitize', []).provider('$sanitize', $SanitizeProvider);

/* global sanitizeText: false */

/**
 * @ngdoc filter
 * @name linky
 * @kind function
 *
 * @description
 * Finds links in text input and turns them into html links. Supports http/https/ftp/mailto and
 * plain email address links.
 *
 * Requires the {@link ngSanitize `ngSanitize`} module to be installed.
 *
 * @param {string} text Input text.
 * @param {string} target Window (_blank|_self|_parent|_top) or named frame to open links in.
 * @returns {string} Html-linkified text.
 *
 * @usage
   <span ng-bind-html="linky_expression | linky"></span>
 *
 * @example
   <example module="linkyExample" deps="angular-sanitize.js">
     <file name="index.html">
       <script>
         angular.module('linkyExample', ['ngSanitize'])
           .controller('ExampleController', ['$scope', function($scope) {
             $scope.snippet =
               'Pretty text with some links:\n'+
               'http://angularjs.org/,\n'+
               'mailto:us@somewhere.org,\n'+
               'another@somewhere.org,\n'+
               'and one more: ftp://127.0.0.1/.';
             $scope.snippetWithTarget = 'http://angularjs.org/';
           }]);
       </script>
       <div ng-controller="ExampleController">
       Snippet: <textarea ng-model="snippet" cols="60" rows="3"></textarea>
       <table>
         <tr>
           <td>Filter</td>
           <td>Source</td>
           <td>Rendered</td>
         </tr>
         <tr id="linky-filter">
           <td>linky filter</td>
           <td>
             <pre>&lt;div ng-bind-html="snippet | linky"&gt;<br>&lt;/div&gt;</pre>
           </td>
           <td>
             <div ng-bind-html="snippet | linky"></div>
           </td>
         </tr>
         <tr id="linky-target">
          <td>linky target</td>
          <td>
            <pre>&lt;div ng-bind-html="snippetWithTarget | linky:'_blank'"&gt;<br>&lt;/div&gt;</pre>
          </td>
          <td>
            <div ng-bind-html="snippetWithTarget | linky:'_blank'"></div>
          </td>
         </tr>
         <tr id="escaped-html">
           <td>no filter</td>
           <td><pre>&lt;div ng-bind="snippet"&gt;<br>&lt;/div&gt;</pre></td>
           <td><div ng-bind="snippet"></div></td>
         </tr>
       </table>
     </file>
     <file name="protractor.js" type="protractor">
       it('should linkify the snippet with urls', function() {
         expect(element(by.id('linky-filter')).element(by.binding('snippet | linky')).getText()).
             toBe('Pretty text with some links: http://angularjs.org/, us@somewhere.org, ' +
                  'another@somewhere.org, and one more: ftp://127.0.0.1/.');
         expect(element.all(by.css('#linky-filter a')).count()).toEqual(4);
       });

       it('should not linkify snippet without the linky filter', function() {
         expect(element(by.id('escaped-html')).element(by.binding('snippet')).getText()).
             toBe('Pretty text with some links: http://angularjs.org/, mailto:us@somewhere.org, ' +
                  'another@somewhere.org, and one more: ftp://127.0.0.1/.');
         expect(element.all(by.css('#escaped-html a')).count()).toEqual(0);
       });

       it('should update', function() {
         element(by.model('snippet')).clear();
         element(by.model('snippet')).sendKeys('new http://link.');
         expect(element(by.id('linky-filter')).element(by.binding('snippet | linky')).getText()).
             toBe('new http://link.');
         expect(element.all(by.css('#linky-filter a')).count()).toEqual(1);
         expect(element(by.id('escaped-html')).element(by.binding('snippet')).getText())
             .toBe('new http://link.');
       });

       it('should work with the target property', function() {
        expect(element(by.id('linky-target')).
            element(by.binding("snippetWithTarget | linky:'_blank'")).getText()).
            toBe('http://angularjs.org/');
        expect(element(by.css('#linky-target a')).getAttribute('target')).toEqual('_blank');
       });
     </file>
   </example>
 */
angular.module('ngSanitize').filter('linky', ['$sanitize', function($sanitize) {
  var LINKY_URL_REGEXP =
        /((ftp|https?):\/\/|(www\.)|(mailto:)?[A-Za-z0-9._%+-]+@)\S*[^\s.;,(){}<>"”’]/i,
      MAILTO_REGEXP = /^mailto:/i;

  return function(text, target) {
    if (!text) return text;
    var match;
    var raw = text;
    var html = [];
    var url;
    var i;
    while ((match = raw.match(LINKY_URL_REGEXP))) {
      // We can not end in these as they are sometimes found at the end of the sentence
      url = match[0];
      // if we did not match ftp/http/www/mailto then assume mailto
      if (!match[2] && !match[4]) {
        url = (match[3] ? 'http://' : 'mailto:') + url;
      }
      i = match.index;
      addText(raw.substr(0, i));
      addLink(url, match[0].replace(MAILTO_REGEXP, ''));
      raw = raw.substring(i + match[0].length);
    }
    addText(raw);
    return $sanitize(html.join(''));

    function addText(text) {
      if (!text) {
        return;
      }
      html.push(sanitizeText(text));
    }

    function addLink(url, text) {
      html.push('<a ');
      if (angular.isDefined(target)) {
        html.push('target="',
                  target,
                  '" ');
      }
      html.push('href="',
                url.replace(/"/g, '&quot;'),
                '">');
      addText(text);
      html.push('</a>');
    }
  };
}]);


})(window, window.angular);

// Copyright 2009-2012 by contributors, MIT License
// vim: ts=4 sts=4 sw=4 expandtab

//Add semicolon to prevent IIFE from being passed as argument to concated code.
;
// Module systems magic dance
(function (definition) {
    // RequireJS
    if (typeof define == "function") {
        define(definition);
    // YUI3
    } else if (typeof YUI == "function") {
        YUI.add("es5", definition);
    // CommonJS and <script>
    } else {
        definition();
    }
})(function () {

/**
 * Brings an environment as close to ECMAScript 5 compliance
 * as is possible with the facilities of erstwhile engines.
 *
 * Annotated ES5: http://es5.github.com/ (specific links below)
 * ES5 Spec: http://www.ecma-international.org/publications/files/ECMA-ST/Ecma-262.pdf
 * Required reading: http://javascriptweblog.wordpress.com/2011/12/05/extending-javascript-natives/
 */

// ES-5 15.1.2.2
if (parseInt('08') !== 8) {
    parseInt = (function (origParseInt) {
        var hexRegex = /^0[xX]/;
        return function parseIntES5(str, radix) {
            str = String(str).trim();
            if (!+radix) {
                radix = hexRegex.test(str) ? 16 : 10;
            }
            return origParseInt(str, radix);
        };
    }(parseInt));
}

//
// Function
// ========
//

// ES-5 15.3.4.5
// http://es5.github.com/#x15.3.4.5

function Empty() {}

if (!Function.prototype.bind) {
    Function.prototype.bind = function bind(that) { // .length is 1
        // 1. Let Target be the this value.
        var target = this;
        // 2. If IsCallable(Target) is false, throw a TypeError exception.
        if (typeof target != "function") {
            throw new TypeError("Function.prototype.bind called on incompatible " + target);
        }
        // 3. Let A be a new (possibly empty) internal list of all of the
        //   argument values provided after thisArg (arg1, arg2 etc), in order.
        // XXX slicedArgs will stand in for "A" if used
        var args = _Array_slice_.call(arguments, 1); // for normal call
        // 4. Let F be a new native ECMAScript object.
        // 11. Set the [[Prototype]] internal property of F to the standard
        //   built-in Function prototype object as specified in 15.3.3.1.
        // 12. Set the [[Call]] internal property of F as described in
        //   15.3.4.5.1.
        // 13. Set the [[Construct]] internal property of F as described in
        //   15.3.4.5.2.
        // 14. Set the [[HasInstance]] internal property of F as described in
        //   15.3.4.5.3.
        var binder = function () {

            if (this instanceof bound) {
                // 15.3.4.5.2 [[Construct]]
                // When the [[Construct]] internal method of a function object,
                // F that was created using the bind function is called with a
                // list of arguments ExtraArgs, the following steps are taken:
                // 1. Let target be the value of F's [[TargetFunction]]
                //   internal property.
                // 2. If target has no [[Construct]] internal method, a
                //   TypeError exception is thrown.
                // 3. Let boundArgs be the value of F's [[BoundArgs]] internal
                //   property.
                // 4. Let args be a new list containing the same values as the
                //   list boundArgs in the same order followed by the same
                //   values as the list ExtraArgs in the same order.
                // 5. Return the result of calling the [[Construct]] internal
                //   method of target providing args as the arguments.

                var result = target.apply(
                    this,
                    args.concat(_Array_slice_.call(arguments))
                );
                if (Object(result) === result) {
                    return result;
                }
                return this;

            } else {
                // 15.3.4.5.1 [[Call]]
                // When the [[Call]] internal method of a function object, F,
                // which was created using the bind function is called with a
                // this value and a list of arguments ExtraArgs, the following
                // steps are taken:
                // 1. Let boundArgs be the value of F's [[BoundArgs]] internal
                //   property.
                // 2. Let boundThis be the value of F's [[BoundThis]] internal
                //   property.
                // 3. Let target be the value of F's [[TargetFunction]] internal
                //   property.
                // 4. Let args be a new list containing the same values as the
                //   list boundArgs in the same order followed by the same
                //   values as the list ExtraArgs in the same order.
                // 5. Return the result of calling the [[Call]] internal method
                //   of target providing boundThis as the this value and
                //   providing args as the arguments.

                // equiv: target.call(this, ...boundArgs, ...args)
                return target.apply(
                    that,
                    args.concat(_Array_slice_.call(arguments))
                );

            }

        };

        // 15. If the [[Class]] internal property of Target is "Function", then
        //     a. Let L be the length property of Target minus the length of A.
        //     b. Set the length own property of F to either 0 or L, whichever is
        //       larger.
        // 16. Else set the length own property of F to 0.

        var boundLength = Math.max(0, target.length - args.length);

        // 17. Set the attributes of the length own property of F to the values
        //   specified in 15.3.5.1.
        var boundArgs = [];
        for (var i = 0; i < boundLength; i++) {
            boundArgs.push("$" + i);
        }

        // XXX Build a dynamic function with desired amount of arguments is the only 
        // way to set the length property of a function. 
        // In environments where Content Security Policies enabled (Chrome extensions, 
        // for ex.) all use of eval or Function costructor throws an exception. 
        // However in all of these environments Function.prototype.bind exists 
        // and so this code will never be executed.
        var bound = Function("binder", "return function(" + boundArgs.join(",") + "){return binder.apply(this,arguments)}")(binder);

        if (target.prototype) {
            Empty.prototype = target.prototype;
            bound.prototype = new Empty();
            // Clean up dangling references.
            Empty.prototype = null;
        }

        // TODO
        // 18. Set the [[Extensible]] internal property of F to true.

        // TODO
        // 19. Let thrower be the [[ThrowTypeError]] function Object (13.2.3).
        // 20. Call the [[DefineOwnProperty]] internal method of F with
        //   arguments "caller", PropertyDescriptor {[[Get]]: thrower, [[Set]]:
        //   thrower, [[Enumerable]]: false, [[Configurable]]: false}, and
        //   false.
        // 21. Call the [[DefineOwnProperty]] internal method of F with
        //   arguments "arguments", PropertyDescriptor {[[Get]]: thrower,
        //   [[Set]]: thrower, [[Enumerable]]: false, [[Configurable]]: false},
        //   and false.

        // TODO
        // NOTE Function objects created using Function.prototype.bind do not
        // have a prototype property or the [[Code]], [[FormalParameters]], and
        // [[Scope]] internal properties.
        // XXX can't delete prototype in pure-js.

        // 22. Return F.
        return bound;
    };
}

// Shortcut to an often accessed properties, in order to avoid multiple
// dereference that costs universally.
// _Please note: Shortcuts are defined after `Function.prototype.bind` as we
// us it in defining shortcuts.
var call = Function.prototype.call;
var prototypeOfArray = Array.prototype;
var prototypeOfObject = Object.prototype;
var _Array_slice_ = prototypeOfArray.slice;
// Having a toString local variable name breaks in Opera so use _toString.
var _toString = call.bind(prototypeOfObject.toString);
var owns = call.bind(prototypeOfObject.hasOwnProperty);

// If JS engine supports accessors creating shortcuts.
var defineGetter;
var defineSetter;
var lookupGetter;
var lookupSetter;
var supportsAccessors;
if ((supportsAccessors = owns(prototypeOfObject, "__defineGetter__"))) {
    defineGetter = call.bind(prototypeOfObject.__defineGetter__);
    defineSetter = call.bind(prototypeOfObject.__defineSetter__);
    lookupGetter = call.bind(prototypeOfObject.__lookupGetter__);
    lookupSetter = call.bind(prototypeOfObject.__lookupSetter__);
}

//
// Array
// =====
//

// ES5 15.4.4.12
// http://es5.github.com/#x15.4.4.12
// Default value for second param
// [bugfix, ielt9, old browsers]
// IE < 9 bug: [1,2].splice(0).join("") == "" but should be "12"
if ([1,2].splice(0).length != 2) {
    var array_splice = Array.prototype.splice;
    var array_push = Array.prototype.push;
    var array_unshift = Array.prototype.unshift;

    if (function() { // test IE < 9 to splice bug - see issue #138
        function makeArray(l) {
            var a = [];
            while (l--) {
                a.unshift(l)
            }
            return a
        }

        var array = []
            , lengthBefore
        ;

        array.splice.bind(array, 0, 0).apply(null, makeArray(20));
        array.splice.bind(array, 0, 0).apply(null, makeArray(26));

        lengthBefore = array.length; //20
        array.splice(5, 0, "XXX"); // add one element

        if (lengthBefore + 1 == array.length) {
            return true;// has right splice implementation without bugs
        }
        // else {
        //    IE8 bug
        // }
    }()) {//IE 6/7
        Array.prototype.splice = function(start, deleteCount) {
            if (!arguments.length) {
                return [];
            } else {
                return array_splice.apply(this, [
                    start === void 0 ? 0 : start,
                    deleteCount === void 0 ? (this.length - start) : deleteCount
                ].concat(_Array_slice_.call(arguments, 2)))
            }
        };
    }
    else {//IE8
        Array.prototype.splice = function(start, deleteCount) {
            var result
                , args = _Array_slice_.call(arguments, 2)
                , addElementsCount = args.length
            ;

            if (!arguments.length) {
                return [];
            }

            if (start === void 0) { // default
                start = 0;
            }
            if (deleteCount === void 0) { // default
                deleteCount = this.length - start;
            }

            if (addElementsCount > 0) {
                if (deleteCount <= 0) {
                    if (start == this.length) { // tiny optimisation #1
                        array_push.apply(this, args);
                        return [];
                    }

                    if (start == 0) { // tiny optimisation #2
                        array_unshift.apply(this, args);
                        return [];
                    }
                }

                // Array.prototype.splice implementation
                result = _Array_slice_.call(this, start, start + deleteCount);// delete part
                args.push.apply(args, _Array_slice_.call(this, start + deleteCount, this.length));// right part
                args.unshift.apply(args, _Array_slice_.call(this, 0, start));// left part

                // delete all items from this array and replace it to 'left part' + _Array_slice_.call(arguments, 2) + 'right part'
                args.unshift(0, this.length);

                array_splice.apply(this, args);

                return result;
            }

            return array_splice.call(this, start, deleteCount);
        }

    }
}

// ES5 15.4.4.12
// http://es5.github.com/#x15.4.4.13
// Return len+argCount.
// [bugfix, ielt8]
// IE < 8 bug: [].unshift(0) == undefined but should be "1"
if ([].unshift(0) != 1) {
    var array_unshift = Array.prototype.unshift;
    Array.prototype.unshift = function() {
        array_unshift.apply(this, arguments);
        return this.length;
    };
}

// ES5 15.4.3.2
// http://es5.github.com/#x15.4.3.2
// https://developer.mozilla.org/en/JavaScript/Reference/Global_Objects/Array/isArray
if (!Array.isArray) {
    Array.isArray = function isArray(obj) {
        return _toString(obj) == "[object Array]";
    };
}

// The IsCallable() check in the Array functions
// has been replaced with a strict check on the
// internal class of the object to trap cases where
// the provided function was actually a regular
// expression literal, which in V8 and
// JavaScriptCore is a typeof "function".  Only in
// V8 are regular expression literals permitted as
// reduce parameters, so it is desirable in the
// general case for the shim to match the more
// strict and common behavior of rejecting regular
// expressions.

// ES5 15.4.4.18
// http://es5.github.com/#x15.4.4.18
// https://developer.mozilla.org/en/JavaScript/Reference/Global_Objects/array/forEach

// Check failure of by-index access of string characters (IE < 9)
// and failure of `0 in boxedString` (Rhino)
var boxedString = Object("a"),
    splitString = boxedString[0] != "a" || !(0 in boxedString);
// Check node 0.6.21 bug where third parameter is not boxed
var boxedForEach = true;
if (Array.prototype.forEach) {
    Array.prototype.forEach.call("foo", function(item, i, obj) {
        if (typeof obj !== 'object') boxedForEach = false;
    });
}

if (!Array.prototype.forEach || !boxedForEach) {
    Array.prototype.forEach = function forEach(fun /*, thisp*/) {
        var object = toObject(this),
            self = splitString && _toString(this) == "[object String]" ?
                this.split("") :
                object,
            thisp = arguments[1],
            i = -1,
            length = self.length >>> 0;

        // If no callback function or if callback is not a callable function
        if (_toString(fun) != "[object Function]") {
            throw new TypeError(); // TODO message
        }

        while (++i < length) {
            if (i in self) {
                // Invoke the callback function with call, passing arguments:
                // context, property value, property key, thisArg object
                // context
                fun.call(thisp, self[i], i, object);
            }
        }
    };
}

// ES5 15.4.4.19
// http://es5.github.com/#x15.4.4.19
// https://developer.mozilla.org/en/Core_JavaScript_1.5_Reference/Objects/Array/map
if (!Array.prototype.map) {
    Array.prototype.map = function map(fun /*, thisp*/) {
        var object = toObject(this),
            self = splitString && _toString(this) == "[object String]" ?
                this.split("") :
                object,
            length = self.length >>> 0,
            result = Array(length),
            thisp = arguments[1];

        // If no callback function or if callback is not a callable function
        if (_toString(fun) != "[object Function]") {
            throw new TypeError(fun + " is not a function");
        }

        for (var i = 0; i < length; i++) {
            if (i in self)
                result[i] = fun.call(thisp, self[i], i, object);
        }
        return result;
    };
}

// ES5 15.4.4.20
// http://es5.github.com/#x15.4.4.20
// https://developer.mozilla.org/en/Core_JavaScript_1.5_Reference/Objects/Array/filter
if (!Array.prototype.filter) {
    Array.prototype.filter = function filter(fun /*, thisp */) {
        var object = toObject(this),
            self = splitString && _toString(this) == "[object String]" ?
                this.split("") :
                    object,
            length = self.length >>> 0,
            result = [],
            value,
            thisp = arguments[1];

        // If no callback function or if callback is not a callable function
        if (_toString(fun) != "[object Function]") {
            throw new TypeError(fun + " is not a function");
        }

        for (var i = 0; i < length; i++) {
            if (i in self) {
                value = self[i];
                if (fun.call(thisp, value, i, object)) {
                    result.push(value);
                }
            }
        }
        return result;
    };
}

// ES5 15.4.4.16
// http://es5.github.com/#x15.4.4.16
// https://developer.mozilla.org/en/JavaScript/Reference/Global_Objects/Array/every
if (!Array.prototype.every) {
    Array.prototype.every = function every(fun /*, thisp */) {
        var object = toObject(this),
            self = splitString && _toString(this) == "[object String]" ?
                this.split("") :
                object,
            length = self.length >>> 0,
            thisp = arguments[1];

        // If no callback function or if callback is not a callable function
        if (_toString(fun) != "[object Function]") {
            throw new TypeError(fun + " is not a function");
        }

        for (var i = 0; i < length; i++) {
            if (i in self && !fun.call(thisp, self[i], i, object)) {
                return false;
            }
        }
        return true;
    };
}

// ES5 15.4.4.17
// http://es5.github.com/#x15.4.4.17
// https://developer.mozilla.org/en/JavaScript/Reference/Global_Objects/Array/some
if (!Array.prototype.some) {
    Array.prototype.some = function some(fun /*, thisp */) {
        var object = toObject(this),
            self = splitString && _toString(this) == "[object String]" ?
                this.split("") :
                object,
            length = self.length >>> 0,
            thisp = arguments[1];

        // If no callback function or if callback is not a callable function
        if (_toString(fun) != "[object Function]") {
            throw new TypeError(fun + " is not a function");
        }

        for (var i = 0; i < length; i++) {
            if (i in self && fun.call(thisp, self[i], i, object)) {
                return true;
            }
        }
        return false;
    };
}

// ES5 15.4.4.21
// http://es5.github.com/#x15.4.4.21
// https://developer.mozilla.org/en/Core_JavaScript_1.5_Reference/Objects/Array/reduce
if (!Array.prototype.reduce) {
    Array.prototype.reduce = function reduce(fun /*, initial*/) {
        var object = toObject(this),
            self = splitString && _toString(this) == "[object String]" ?
                this.split("") :
                object,
            length = self.length >>> 0;

        // If no callback function or if callback is not a callable function
        if (_toString(fun) != "[object Function]") {
            throw new TypeError(fun + " is not a function");
        }

        // no value to return if no initial value and an empty array
        if (!length && arguments.length == 1) {
            throw new TypeError("reduce of empty array with no initial value");
        }

        var i = 0;
        var result;
        if (arguments.length >= 2) {
            result = arguments[1];
        } else {
            do {
                if (i in self) {
                    result = self[i++];
                    break;
                }

                // if array contains no values, no initial value to return
                if (++i >= length) {
                    throw new TypeError("reduce of empty array with no initial value");
                }
            } while (true);
        }

        for (; i < length; i++) {
            if (i in self) {
                result = fun.call(void 0, result, self[i], i, object);
            }
        }

        return result;
    };
}

// ES5 15.4.4.22
// http://es5.github.com/#x15.4.4.22
// https://developer.mozilla.org/en/Core_JavaScript_1.5_Reference/Objects/Array/reduceRight
if (!Array.prototype.reduceRight) {
    Array.prototype.reduceRight = function reduceRight(fun /*, initial*/) {
        var object = toObject(this),
            self = splitString && _toString(this) == "[object String]" ?
                this.split("") :
                object,
            length = self.length >>> 0;

        // If no callback function or if callback is not a callable function
        if (_toString(fun) != "[object Function]") {
            throw new TypeError(fun + " is not a function");
        }

        // no value to return if no initial value, empty array
        if (!length && arguments.length == 1) {
            throw new TypeError("reduceRight of empty array with no initial value");
        }

        var result, i = length - 1;
        if (arguments.length >= 2) {
            result = arguments[1];
        } else {
            do {
                if (i in self) {
                    result = self[i--];
                    break;
                }

                // if array contains no values, no initial value to return
                if (--i < 0) {
                    throw new TypeError("reduceRight of empty array with no initial value");
                }
            } while (true);
        }

        if (i < 0) {
            return result;
        }

        do {
            if (i in this) {
                result = fun.call(void 0, result, self[i], i, object);
            }
        } while (i--);

        return result;
    };
}

// ES5 15.4.4.14
// http://es5.github.com/#x15.4.4.14
// https://developer.mozilla.org/en/JavaScript/Reference/Global_Objects/Array/indexOf
if (!Array.prototype.indexOf || ([0, 1].indexOf(1, 2) != -1)) {
    Array.prototype.indexOf = function indexOf(sought /*, fromIndex */ ) {
        var self = splitString && _toString(this) == "[object String]" ?
                this.split("") :
                toObject(this),
            length = self.length >>> 0;

        if (!length) {
            return -1;
        }

        var i = 0;
        if (arguments.length > 1) {
            i = toInteger(arguments[1]);
        }

        // handle negative indices
        i = i >= 0 ? i : Math.max(0, length + i);
        for (; i < length; i++) {
            if (i in self && self[i] === sought) {
                return i;
            }
        }
        return -1;
    };
}

// ES5 15.4.4.15
// http://es5.github.com/#x15.4.4.15
// https://developer.mozilla.org/en/JavaScript/Reference/Global_Objects/Array/lastIndexOf
if (!Array.prototype.lastIndexOf || ([0, 1].lastIndexOf(0, -3) != -1)) {
    Array.prototype.lastIndexOf = function lastIndexOf(sought /*, fromIndex */) {
        var self = splitString && _toString(this) == "[object String]" ?
                this.split("") :
                toObject(this),
            length = self.length >>> 0;

        if (!length) {
            return -1;
        }
        var i = length - 1;
        if (arguments.length > 1) {
            i = Math.min(i, toInteger(arguments[1]));
        }
        // handle negative indices
        i = i >= 0 ? i : length - Math.abs(i);
        for (; i >= 0; i--) {
            if (i in self && sought === self[i]) {
                return i;
            }
        }
        return -1;
    };
}

//
// Object
// ======
//

// ES5 15.2.3.14
// http://es5.github.com/#x15.2.3.14
if (!Object.keys) {
    // http://whattheheadsaid.com/2010/10/a-safer-object-keys-compatibility-implementation
    var hasDontEnumBug = true,
        dontEnums = [
            "toString",
            "toLocaleString",
            "valueOf",
            "hasOwnProperty",
            "isPrototypeOf",
            "propertyIsEnumerable",
            "constructor"
        ],
        dontEnumsLength = dontEnums.length;

    for (var key in {"toString": null}) {
        hasDontEnumBug = false;
    }

    Object.keys = function keys(object) {

        if (
            (typeof object != "object" && typeof object != "function") ||
            object === null
        ) {
            throw new TypeError("Object.keys called on a non-object");
        }

        var keys = [];
        for (var name in object) {
            if (owns(object, name)) {
                keys.push(name);
            }
        }

        if (hasDontEnumBug) {
            for (var i = 0, ii = dontEnumsLength; i < ii; i++) {
                var dontEnum = dontEnums[i];
                if (owns(object, dontEnum)) {
                    keys.push(dontEnum);
                }
            }
        }
        return keys;
    };

}

//
// Date
// ====
//

// ES5 15.9.5.43
// http://es5.github.com/#x15.9.5.43
// This function returns a String value represent the instance in time
// represented by this Date object. The format of the String is the Date Time
// string format defined in 15.9.1.15. All fields are present in the String.
// The time zone is always UTC, denoted by the suffix Z. If the time value of
// this object is not a finite Number a RangeError exception is thrown.
var negativeDate = -62198755200000,
    negativeYearString = "-000001";
if (
    !Date.prototype.toISOString ||
    (new Date(negativeDate).toISOString().indexOf(negativeYearString) === -1)
) {
    Date.prototype.toISOString = function toISOString() {
        var result, length, value, year, month;
        if (!isFinite(this)) {
            throw new RangeError("Date.prototype.toISOString called on non-finite value.");
        }

        year = this.getUTCFullYear();

        month = this.getUTCMonth();
        // see https://github.com/es-shims/es5-shim/issues/111
        year += Math.floor(month / 12);
        month = (month % 12 + 12) % 12;

        // the date time string format is specified in 15.9.1.15.
        result = [month + 1, this.getUTCDate(),
            this.getUTCHours(), this.getUTCMinutes(), this.getUTCSeconds()];
        year = (
            (year < 0 ? "-" : (year > 9999 ? "+" : "")) +
            ("00000" + Math.abs(year))
            .slice(0 <= year && year <= 9999 ? -4 : -6)
        );

        length = result.length;
        while (length--) {
            value = result[length];
            // pad months, days, hours, minutes, and seconds to have two
            // digits.
            if (value < 10) {
                result[length] = "0" + value;
            }
        }
        // pad milliseconds to have three digits.
        return (
            year + "-" + result.slice(0, 2).join("-") +
            "T" + result.slice(2).join(":") + "." +
            ("000" + this.getUTCMilliseconds()).slice(-3) + "Z"
        );
    };
}


// ES5 15.9.5.44
// http://es5.github.com/#x15.9.5.44
// This function provides a String representation of a Date object for use by
// JSON.stringify (15.12.3).
var dateToJSONIsSupported = false;
try {
    dateToJSONIsSupported = (
        Date.prototype.toJSON &&
        new Date(NaN).toJSON() === null &&
        new Date(negativeDate).toJSON().indexOf(negativeYearString) !== -1 &&
        Date.prototype.toJSON.call({ // generic
            toISOString: function () {
                return true;
            }
        })
    );
} catch (e) {
}
if (!dateToJSONIsSupported) {
    Date.prototype.toJSON = function toJSON(key) {
        // When the toJSON method is called with argument key, the following
        // steps are taken:

        // 1.  Let O be the result of calling ToObject, giving it the this
        // value as its argument.
        // 2. Let tv be toPrimitive(O, hint Number).
        var o = Object(this),
            tv = toPrimitive(o),
            toISO;
        // 3. If tv is a Number and is not finite, return null.
        if (typeof tv === "number" && !isFinite(tv)) {
            return null;
        }
        // 4. Let toISO be the result of calling the [[Get]] internal method of
        // O with argument "toISOString".
        toISO = o.toISOString;
        // 5. If IsCallable(toISO) is false, throw a TypeError exception.
        if (typeof toISO != "function") {
            throw new TypeError("toISOString property is not callable");
        }
        // 6. Return the result of calling the [[Call]] internal method of
        //  toISO with O as the this value and an empty argument list.
        return toISO.call(o);

        // NOTE 1 The argument is ignored.

        // NOTE 2 The toJSON function is intentionally generic; it does not
        // require that its this value be a Date object. Therefore, it can be
        // transferred to other kinds of objects for use as a method. However,
        // it does require that any such object have a toISOString method. An
        // object is free to use the argument key to filter its
        // stringification.
    };
}

// ES5 15.9.4.2
// http://es5.github.com/#x15.9.4.2
// based on work shared by Daniel Friesen (dantman)
// http://gist.github.com/303249
if (!Date.parse || "Date.parse is buggy") {
    // XXX global assignment won't work in embeddings that use
    // an alternate object for the context.
    Date = (function(NativeDate) {

        // Date.length === 7
        function Date(Y, M, D, h, m, s, ms) {
            var length = arguments.length;
            if (this instanceof NativeDate) {
                var date = length == 1 && String(Y) === Y ? // isString(Y)
                    // We explicitly pass it through parse:
                    new NativeDate(Date.parse(Y)) :
                    // We have to manually make calls depending on argument
                    // length here
                    length >= 7 ? new NativeDate(Y, M, D, h, m, s, ms) :
                    length >= 6 ? new NativeDate(Y, M, D, h, m, s) :
                    length >= 5 ? new NativeDate(Y, M, D, h, m) :
                    length >= 4 ? new NativeDate(Y, M, D, h) :
                    length >= 3 ? new NativeDate(Y, M, D) :
                    length >= 2 ? new NativeDate(Y, M) :
                    length >= 1 ? new NativeDate(Y) :
                                  new NativeDate();
                // Prevent mixups with unfixed Date object
                date.constructor = Date;
                return date;
            }
            return NativeDate.apply(this, arguments);
        };

        // 15.9.1.15 Date Time String Format.
        var isoDateExpression = new RegExp("^" +
            "(\\d{4}|[\+\-]\\d{6})" + // four-digit year capture or sign +
                                      // 6-digit extended year
            "(?:-(\\d{2})" + // optional month capture
            "(?:-(\\d{2})" + // optional day capture
            "(?:" + // capture hours:minutes:seconds.milliseconds
                "T(\\d{2})" + // hours capture
                ":(\\d{2})" + // minutes capture
                "(?:" + // optional :seconds.milliseconds
                    ":(\\d{2})" + // seconds capture
                    "(?:(\\.\\d{1,}))?" + // milliseconds capture
                ")?" +
            "(" + // capture UTC offset component
                "Z|" + // UTC capture
                "(?:" + // offset specifier +/-hours:minutes
                    "([-+])" + // sign capture
                    "(\\d{2})" + // hours offset capture
                    ":(\\d{2})" + // minutes offset capture
                ")" +
            ")?)?)?)?" +
        "$");

        var months = [
            0, 31, 59, 90, 120, 151, 181, 212, 243, 273, 304, 334, 365
        ];

        function dayFromMonth(year, month) {
            var t = month > 1 ? 1 : 0;
            return (
                months[month] +
                Math.floor((year - 1969 + t) / 4) -
                Math.floor((year - 1901 + t) / 100) +
                Math.floor((year - 1601 + t) / 400) +
                365 * (year - 1970)
            );
        }

        function toUTC(t) {
            return Number(new NativeDate(1970, 0, 1, 0, 0, 0, t));
        }

        // Copy any custom methods a 3rd party library may have added
        for (var key in NativeDate) {
            Date[key] = NativeDate[key];
        }

        // Copy "native" methods explicitly; they may be non-enumerable
        Date.now = NativeDate.now;
        Date.UTC = NativeDate.UTC;
        Date.prototype = NativeDate.prototype;
        Date.prototype.constructor = Date;

        // Upgrade Date.parse to handle simplified ISO 8601 strings
        Date.parse = function parse(string) {
            var match = isoDateExpression.exec(string);
            if (match) {
                // parse months, days, hours, minutes, seconds, and milliseconds
                // provide default values if necessary
                // parse the UTC offset component
                var year = Number(match[1]),
                    month = Number(match[2] || 1) - 1,
                    day = Number(match[3] || 1) - 1,
                    hour = Number(match[4] || 0),
                    minute = Number(match[5] || 0),
                    second = Number(match[6] || 0),
                    millisecond = Math.floor(Number(match[7] || 0) * 1000),
                    // When time zone is missed, local offset should be used
                    // (ES 5.1 bug)
                    // see https://bugs.ecmascript.org/show_bug.cgi?id=112
                    isLocalTime = Boolean(match[4] && !match[8]),
                    signOffset = match[9] === "-" ? 1 : -1,
                    hourOffset = Number(match[10] || 0),
                    minuteOffset = Number(match[11] || 0),
                    result;
                if (
                    hour < (
                        minute > 0 || second > 0 || millisecond > 0 ?
                        24 : 25
                    ) &&
                    minute < 60 && second < 60 && millisecond < 1000 &&
                    month > -1 && month < 12 && hourOffset < 24 &&
                    minuteOffset < 60 && // detect invalid offsets
                    day > -1 &&
                    day < (
                        dayFromMonth(year, month + 1) -
                        dayFromMonth(year, month)
                    )
                ) {
                    result = (
                        (dayFromMonth(year, month) + day) * 24 +
                        hour +
                        hourOffset * signOffset
                    ) * 60;
                    result = (
                        (result + minute + minuteOffset * signOffset) * 60 +
                        second
                    ) * 1000 + millisecond;
                    if (isLocalTime) {
                        result = toUTC(result);
                    }
                    if (-8.64e15 <= result && result <= 8.64e15) {
                        return result;
                    }
                }
                return NaN;
            }
            return NativeDate.parse.apply(this, arguments);
        };

        return Date;
    })(Date);
}

// ES5 15.9.4.4
// http://es5.github.com/#x15.9.4.4
if (!Date.now) {
    Date.now = function now() {
        return new Date().getTime();
    };
}


//
// Number
// ======
//

// ES5.1 15.7.4.5
// http://es5.github.com/#x15.7.4.5
if (!Number.prototype.toFixed || (0.00008).toFixed(3) !== '0.000' || (0.9).toFixed(0) === '0' || (1.255).toFixed(2) !== '1.25' || (1000000000000000128).toFixed(0) !== "1000000000000000128") {
    // Hide these variables and functions
    (function () {
        var base, size, data, i;

        base = 1e7;
        size = 6;
        data = [0, 0, 0, 0, 0, 0];

        function multiply(n, c) {
            var i = -1;
            while (++i < size) {
                c += n * data[i];
                data[i] = c % base;
                c = Math.floor(c / base);
            }
        }

        function divide(n) {
            var i = size, c = 0;
            while (--i >= 0) {
                c += data[i];
                data[i] = Math.floor(c / n);
                c = (c % n) * base;
            }
        }

        function toString() {
            var i = size;
            var s = '';
            while (--i >= 0) {
                if (s !== '' || i === 0 || data[i] !== 0) {
                    var t = String(data[i]);
                    if (s === '') {
                        s = t;
                    } else {
                        s += '0000000'.slice(0, 7 - t.length) + t;
                    }
                }
            }
            return s;
        }

        function pow(x, n, acc) {
            return (n === 0 ? acc : (n % 2 === 1 ? pow(x, n - 1, acc * x) : pow(x * x, n / 2, acc)));
        }

        function log(x) {
            var n = 0;
            while (x >= 4096) {
                n += 12;
                x /= 4096;
            }
            while (x >= 2) {
                n += 1;
                x /= 2;
            }
            return n;
        }

        Number.prototype.toFixed = function (fractionDigits) {
            var f, x, s, m, e, z, j, k;

            // Test for NaN and round fractionDigits down
            f = Number(fractionDigits);
            f = f !== f ? 0 : Math.floor(f);

            if (f < 0 || f > 20) {
                throw new RangeError("Number.toFixed called with invalid number of decimals");
            }

            x = Number(this);

            // Test for NaN
            if (x !== x) {
                return "NaN";
            }

            // If it is too big or small, return the string value of the number
            if (x <= -1e21 || x >= 1e21) {
                return String(x);
            }

            s = "";

            if (x < 0) {
                s = "-";
                x = -x;
            }

            m = "0";

            if (x > 1e-21) {
                // 1e-21 < x < 1e21
                // -70 < log2(x) < 70
                e = log(x * pow(2, 69, 1)) - 69;
                z = (e < 0 ? x * pow(2, -e, 1) : x / pow(2, e, 1));
                z *= 0x10000000000000; // Math.pow(2, 52);
                e = 52 - e;

                // -18 < e < 122
                // x = z / 2 ^ e
                if (e > 0) {
                    multiply(0, z);
                    j = f;

                    while (j >= 7) {
                        multiply(1e7, 0);
                        j -= 7;
                    }

                    multiply(pow(10, j, 1), 0);
                    j = e - 1;

                    while (j >= 23) {
                        divide(1 << 23);
                        j -= 23;
                    }

                    divide(1 << j);
                    multiply(1, 1);
                    divide(2);
                    m = toString();
                } else {
                    multiply(0, z);
                    multiply(1 << (-e), 0);
                    m = toString() + '0.00000000000000000000'.slice(2, 2 + f);
                }
            }

            if (f > 0) {
                k = m.length;

                if (k <= f) {
                    m = s + '0.0000000000000000000'.slice(0, f - k + 2) + m;
                } else {
                    m = s + m.slice(0, k - f) + '.' + m.slice(k - f);
                }
            } else {
                m = s + m;
            }

            return m;
        }
    }());
}


//
// String
// ======
//


// ES5 15.5.4.14
// http://es5.github.com/#x15.5.4.14

// [bugfix, IE lt 9, firefox 4, Konqueror, Opera, obscure browsers]
// Many browsers do not split properly with regular expressions or they
// do not perform the split correctly under obscure conditions.
// See http://blog.stevenlevithan.com/archives/cross-browser-split
// I've tested in many browsers and this seems to cover the deviant ones:
//    'ab'.split(/(?:ab)*/) should be ["", ""], not [""]
//    '.'.split(/(.?)(.?)/) should be ["", ".", "", ""], not ["", ""]
//    'tesst'.split(/(s)*/) should be ["t", undefined, "e", "s", "t"], not
//       [undefined, "t", undefined, "e", ...]
//    ''.split(/.?/) should be [], not [""]
//    '.'.split(/()()/) should be ["."], not ["", "", "."]

var string_split = String.prototype.split;
if (
    'ab'.split(/(?:ab)*/).length !== 2 ||
    '.'.split(/(.?)(.?)/).length !== 4 ||
    'tesst'.split(/(s)*/)[1] === "t" ||
    ''.split(/.?/).length ||
    '.'.split(/()()/).length > 1
) {
    (function () {
        var compliantExecNpcg = /()??/.exec("")[1] === void 0; // NPCG: nonparticipating capturing group

        String.prototype.split = function (separator, limit) {
            var string = this;
            if (separator === void 0 && limit === 0)
                return [];

            // If `separator` is not a regex, use native split
            if (Object.prototype.toString.call(separator) !== "[object RegExp]") {
                return string_split.apply(this, arguments);
            }

            var output = [],
                flags = (separator.ignoreCase ? "i" : "") +
                        (separator.multiline  ? "m" : "") +
                        (separator.extended   ? "x" : "") + // Proposed for ES6
                        (separator.sticky     ? "y" : ""), // Firefox 3+
                lastLastIndex = 0,
                // Make `global` and avoid `lastIndex` issues by working with a copy
                separator = new RegExp(separator.source, flags + "g"),
                separator2, match, lastIndex, lastLength;
            string += ""; // Type-convert
            if (!compliantExecNpcg) {
                // Doesn't need flags gy, but they don't hurt
                separator2 = new RegExp("^" + separator.source + "$(?!\\s)", flags);
            }
            /* Values for `limit`, per the spec:
             * If undefined: 4294967295 // Math.pow(2, 32) - 1
             * If 0, Infinity, or NaN: 0
             * If positive number: limit = Math.floor(limit); if (limit > 4294967295) limit -= 4294967296;
             * If negative number: 4294967296 - Math.floor(Math.abs(limit))
             * If other: Type-convert, then use the above rules
             */
            limit = limit === void 0 ?
                -1 >>> 0 : // Math.pow(2, 32) - 1
                limit >>> 0; // ToUint32(limit)
            while (match = separator.exec(string)) {
                // `separator.lastIndex` is not reliable cross-browser
                lastIndex = match.index + match[0].length;
                if (lastIndex > lastLastIndex) {
                    output.push(string.slice(lastLastIndex, match.index));
                    // Fix browsers whose `exec` methods don't consistently return `undefined` for
                    // nonparticipating capturing groups
                    if (!compliantExecNpcg && match.length > 1) {
                        match[0].replace(separator2, function () {
                            for (var i = 1; i < arguments.length - 2; i++) {
                                if (arguments[i] === void 0) {
                                    match[i] = void 0;
                                }
                            }
                        });
                    }
                    if (match.length > 1 && match.index < string.length) {
                        Array.prototype.push.apply(output, match.slice(1));
                    }
                    lastLength = match[0].length;
                    lastLastIndex = lastIndex;
                    if (output.length >= limit) {
                        break;
                    }
                }
                if (separator.lastIndex === match.index) {
                    separator.lastIndex++; // Avoid an infinite loop
                }
            }
            if (lastLastIndex === string.length) {
                if (lastLength || !separator.test("")) {
                    output.push("");
                }
            } else {
                output.push(string.slice(lastLastIndex));
            }
            return output.length > limit ? output.slice(0, limit) : output;
        };
    }());

// [bugfix, chrome]
// If separator is undefined, then the result array contains just one String,
// which is the this value (converted to a String). If limit is not undefined,
// then the output array is truncated so that it contains no more than limit
// elements.
// "0".split(undefined, 0) -> []
} else if ("0".split(void 0, 0).length) {
    String.prototype.split = function(separator, limit) {
        if (separator === void 0 && limit === 0) return [];
        return string_split.apply(this, arguments);
    }
}


// ECMA-262, 3rd B.2.3
// Note an ECMAScript standart, although ECMAScript 3rd Edition has a
// non-normative section suggesting uniform semantics and it should be
// normalized across all browsers
// [bugfix, IE lt 9] IE < 9 substr() with negative value not working in IE
if ("".substr && "0b".substr(-1) !== "b") {
    var string_substr = String.prototype.substr;
    /**
     *  Get the substring of a string
     *  @param  {integer}  start   where to start the substring
     *  @param  {integer}  length  how many characters to return
     *  @return {string}
     */
    String.prototype.substr = function(start, length) {
        return string_substr.call(
            this,
            start < 0 ? ((start = this.length + start) < 0 ? 0 : start) : start,
            length
        );
    }
}

// ES5 15.5.4.20
// http://es5.github.com/#x15.5.4.20
var ws = "\x09\x0A\x0B\x0C\x0D\x20\xA0\u1680\u180E\u2000\u2001\u2002\u2003" +
    "\u2004\u2005\u2006\u2007\u2008\u2009\u200A\u202F\u205F\u3000\u2028" +
    "\u2029\uFEFF";
if (!String.prototype.trim || ws.trim()) {
    // http://blog.stevenlevithan.com/archives/faster-trim-javascript
    // http://perfectionkills.com/whitespace-deviations/
    ws = "[" + ws + "]";
    var trimBeginRegexp = new RegExp("^" + ws + ws + "*"),
        trimEndRegexp = new RegExp(ws + ws + "*$");
    String.prototype.trim = function trim() {
        if (this === void 0 || this === null) {
            throw new TypeError("can't convert "+this+" to object");
        }
        return String(this)
            .replace(trimBeginRegexp, "")
            .replace(trimEndRegexp, "");
    };
}

//
// Util
// ======
//

// ES5 9.4
// http://es5.github.com/#x9.4
// http://jsperf.com/to-integer

function toInteger(n) {
    n = +n;
    if (n !== n) { // isNaN
        n = 0;
    } else if (n !== 0 && n !== (1/0) && n !== -(1/0)) {
        n = (n > 0 || -1) * Math.floor(Math.abs(n));
    }
    return n;
}

function isPrimitive(input) {
    var type = typeof input;
    return (
        input === null ||
        type === "undefined" ||
        type === "boolean" ||
        type === "number" ||
        type === "string"
    );
}

function toPrimitive(input) {
    var val, valueOf, toString;
    if (isPrimitive(input)) {
        return input;
    }
    valueOf = input.valueOf;
    if (typeof valueOf === "function") {
        val = valueOf.call(input);
        if (isPrimitive(val)) {
            return val;
        }
    }
    toString = input.toString;
    if (typeof toString === "function") {
        val = toString.call(input);
        if (isPrimitive(val)) {
            return val;
        }
    }
    throw new TypeError();
}

// ES5 9.9
// http://es5.github.com/#x9.9
var toObject = function (o) {
    if (o == null) { // this matches both null and undefined
        throw new TypeError("can't convert "+o+" to object");
    }
    return Object(o);
};

});

!function(e,t){"object"==typeof exports&&"object"==typeof module?module.exports=t():"function"==typeof define&&define.amd?define(t):"object"==typeof exports?exports["RAML.JsonValidation"]=t():e["RAML.JsonValidation"]=t()}(this,function(){return function(e){function t(n){if(r[n])return r[n].exports;var i=r[n]={exports:{},id:n,loaded:!1};return e[n].call(i.exports,i,i.exports,t),i.loaded=!0,i.exports}var r={};return t.m=e,t.c=r,t.p="",t(0)}([function(e,t,r){"use strict";var n=r(1),i=function(){function e(){this.validator=new n}return e.prototype.setRemoteReference=function(e,t){this.validator.setRemoteReference(e,t)},e.prototype.validateSchema=function(e){this.validator.validateSchema(e)},e.prototype.getMissingRemoteReferences=function(){return this.validator.getMissingRemoteReferences()},e.prototype.isResourceLoaded=function(e){return null==this.validator.cache[e]?!1:!0},e.prototype.validate=function(e,t){this.validator.validate(e,t)},e.prototype.getLastErrors=function(){return this.validator.getLastErrors()},e}();t.JSONValidator=i},function(e,t,r){(function(t){"use strict";function n(e){if(this.cache={},this.referenceCache=[],this.setRemoteReference("http://json-schema.org/draft-04/schema",c),this.setRemoteReference("http://json-schema.org/draft-04/hyper-schema",p),"object"==typeof e){for(var t,r=Object.keys(e),n=r.length;n--;)if(t=r[n],void 0===h[t])throw new Error("Unexpected option passed to constructor: "+t);for(r=Object.keys(h),n=r.length;n--;)t=r[n],void 0===e[t]&&(e[t]=d.clone(h[t]));this.options=e}else this.options=d.clone(h);this.options.strictMode===!0&&(this.options.forceAdditional=!0,this.options.forceItems=!0,this.options.forceMaxLength=!0,this.options.forceProperties=!0,this.options.noExtraKeywords=!0,this.options.noTypeless=!0,this.options.noEmptyStrings=!0,this.options.noEmptyArrays=!0)}r(2);var i=r(12),o=r(3),a=r(4),s=r(5),u=r(6),l=r(7),f=r(8),d=r(9),c=r(13),p=r(14),h={asyncTimeout:2e3,forceAdditional:!1,assumeAdditional:!1,forceItems:!1,forceMinItems:!1,forceMaxItems:!1,forceMinLength:!1,forceMaxLength:!1,forceProperties:!1,ignoreUnresolvableReferences:!1,noExtraKeywords:!1,noTypeless:!1,noEmptyStrings:!1,noEmptyArrays:!1,strictUris:!1,strictMode:!1,reportPathAsArray:!1,breakOnFirstError:!0,pedanticCheck:!1,ignoreUnknownFormats:!1,customValidator:null};n.prototype.compileSchema=function(e){var t=new o(this.options);return e=u.getSchema.call(this,t,e),l.compileSchema.call(this,t,e),this.lastReport=t,t.isValid()},n.prototype.validateSchema=function(e){if(Array.isArray(e)&&0===e.length)throw new Error(".validateSchema was called with an empty array");var t=new o(this.options);e=u.getSchema.call(this,t,e);var r=l.compileSchema.call(this,t,e);return r&&f.validateSchema.call(this,t,e),this.lastReport=t,t.isValid()},n.prototype.validate=function(e,r,n,a){"function"===d.whatIs(n)&&(a=n,n={}),n||(n={});var c=d.whatIs(r);if("string"!==c&&"object"!==c){var p=new Error("Invalid .validate call - schema must be an string or object but "+c+" was passed!");if(a)return void t.nextTick(function(){a(p,!1)});throw p}var h=!1,m=new o(this.options);if("string"==typeof r){var _=r;if(r=u.getSchema.call(this,m,_),!r)throw new Error("Schema with id '"+_+"' wasn't found in the validator cache!")}else r=u.getSchema.call(this,m,r);var y=!1;h||(y=l.compileSchema.call(this,m,r)),y||(this.lastReport=m,h=!0);var E=!1;if(h||(E=f.validateSchema.call(this,m,r)),E||(this.lastReport=m,h=!0),n.schemaPath&&(m.rootSchema=r,r=i(r,n.schemaPath),!r))throw new Error("Schema path '"+n.schemaPath+"' wasn't found in the schema!");if(h||s.validate.call(this,m,r,e),a)return void m.processAsyncTasks(this.options.asyncTimeout,a);if(m.asyncTasks.length>0)throw new Error("This validation has async tasks and cannot be done in sync mode, please provide callback argument.");return this.lastReport=m,m.isValid()},n.prototype.getLastError=function(){if(0===this.lastReport.errors.length)return null;var e=new Error;return e.name="z-schema validation error",e.message=this.lastReport.commonErrorMessage,e.details=this.lastReport.errors,e},n.prototype.getLastErrors=function(){return this.lastReport&&this.lastReport.errors.length>0?this.lastReport.errors:void 0},n.prototype.getMissingReferences=function(e){e=e||this.lastReport.errors;for(var t=[],r=e.length;r--;){var n=e[r];if("UNRESOLVABLE_REFERENCE"===n.code){var i=n.params[0];-1===t.indexOf(i)&&t.push(i)}n.inner&&(t=t.concat(this.getMissingReferences(n.inner)))}return t},n.prototype.getMissingRemoteReferences=function(){for(var e=this.getMissingReferences(),t=[],r=e.length;r--;){var n=u.getRemotePath(e[r]);n&&-1===t.indexOf(n)&&t.push(n)}return t},n.prototype.setRemoteReference=function(e,t){t="string"==typeof t?JSON.parse(t):d.cloneDeep(t),u.cacheSchemaByUri.call(this,e,t)},n.prototype.getResolvedSchema=function(e){var t=new o(this.options);e=u.getSchema.call(this,t,e),e=d.cloneDeep(e);var r=[],n=function(e){var t,i=d.whatIs(e);if(("object"===i||"array"===i)&&!e.___$visited){if(e.___$visited=!0,r.push(e),e.$ref&&e.__$refResolved){var o=e.__$refResolved,a=e;delete e.$ref,delete e.__$refResolved;for(t in o)o.hasOwnProperty(t)&&(a[t]=o[t])}for(t in e)e.hasOwnProperty(t)&&(0===t.indexOf("__$")?delete e[t]:n(e[t]))}};if(n(e),r.forEach(function(e){delete e.___$visited}),this.lastReport=t,t.isValid())return e;throw this.getLastError()},n.prototype.setSchemaReader=function(e){return n.setSchemaReader(e)},n.prototype.getSchemaReader=function(){return n.schemaReader},n.setSchemaReader=function(e){n.schemaReader=e},n.registerFormat=function(e,t){a[e]=t},n.unregisterFormat=function(e){delete a[e]},n.getRegisteredFormats=function(){return Object.keys(a)},n.getDefaultOptions=function(){return d.cloneDeep(h)},e.exports=n}).call(t,r(10))},function(e,t,r){"function"!=typeof Number.isFinite&&(Number.isFinite=function(e){return"number"!=typeof e?!1:e!==e||e===1/0||e===-(1/0)?!1:!0})},function(e,t,r){(function(t){"use strict";function n(e,t){this.parentReport=e instanceof n?e:void 0,this.options=e instanceof n?e.options:e||{},this.reportOptions=t||{},this.errors=[],this.path=[],this.asyncTasks=[]}var i=r(12),o=r(11),a=r(9);n.prototype.isValid=function(){if(this.asyncTasks.length>0)throw new Error("Async tasks pending, can't answer isValid");return 0===this.errors.length},n.prototype.addAsyncTask=function(e,t,r){this.asyncTasks.push([e,t,r])},n.prototype.processAsyncTasks=function(e,r){function n(){t.nextTick(function(){var e=0===l.errors.length,t=e?void 0:l.errors;r(t,e)})}function i(e){return function(t){u||(e(t),0===--a&&n())}}var o=e||2e3,a=this.asyncTasks.length,s=a,u=!1,l=this;if(0===a||this.errors.length>0)return void n();for(;s--;){var f=this.asyncTasks[s];f[0].apply(null,f[1].concat(i(f[2])))}setTimeout(function(){a>0&&(u=!0,l.addError("ASYNC_TIMEOUT",[a,o]),r(l.errors,!1))},o)},n.prototype.getPath=function(e){var t=[];return this.parentReport&&(t=t.concat(this.parentReport.path)),t=t.concat(this.path),e!==!0&&(t="#/"+t.map(function(e){return a.isAbsoluteUri(e)?"uri("+e+")":e.replace(/\~/g,"~0").replace(/\//g,"~1")}).join("/")),t},n.prototype.getSchemaId=function(){if(!this.rootSchema)return null;var e=[];for(this.parentReport&&(e=e.concat(this.parentReport.path)),e=e.concat(this.path);e.length>0;){var t=i(this.rootSchema,e);if(t&&t.id)return t.id;e.pop()}return this.rootSchema.id},n.prototype.hasError=function(e,t){for(var r=this.errors.length;r--;)if(this.errors[r].code===e){for(var n=!0,i=this.errors[r].params.length;i--;)this.errors[r].params[i]!==t[i]&&(n=!1);if(n)return n}return!1},n.prototype.addError=function(e,t,r,n){if(!e)throw new Error("No errorCode passed into addError()");this.addCustomError(e,o[e],t,r,n)},n.prototype.addCustomError=function(e,t,r,n,i){if(!(this.errors.length>=this.reportOptions.maxErrors)){if(!t)throw new Error("No errorMessage known for code "+e);r=r||[];for(var o=r.length;o--;){var s=a.whatIs(r[o]),u="object"===s||"null"===s?JSON.stringify(r[o]):r[o];t=t.replace("{"+o+"}",u)}var l={code:e,params:r,message:t,path:this.getPath(this.options.reportPathAsArray),schemaId:this.getSchemaId()};if(i&&(l.description=i),null!=n){for(Array.isArray(n)||(n=[n]),l.inner=[],o=n.length;o--;)for(var f=n[o],d=f.errors.length;d--;)l.inner.push(f.errors[d]);0===l.inner.length&&(l.inner=void 0)}this.errors.push(l)}},e.exports=n}).call(t,r(10))},function(e,t,r){var n=r(15),i={date:function(e){if("string"!=typeof e)return!0;var t=/^([0-9]{4})-([0-9]{2})-([0-9]{2})$/.exec(e);return null===t?!1:t[2]<"01"||t[2]>"12"||t[3]<"01"||t[3]>"31"?!1:!0},"date-time":function(e){if("string"!=typeof e)return!0;var t=e.toLowerCase().split("t");if(!i.date(t[0]))return!1;var r=/^([0-9]{2}):([0-9]{2}):([0-9]{2})(.[0-9]+)?(z|([+-][0-9]{2}:[0-9]{2}))$/.exec(t[1]);return null===r?!1:r[1]>"23"||r[2]>"59"||r[3]>"59"?!1:!0},email:function(e){return"string"!=typeof e?!0:n.isEmail(e,{require_tld:!0})},hostname:function(e){if("string"!=typeof e)return!0;var t=/^[a-zA-Z](([-0-9a-zA-Z]+)?[0-9a-zA-Z])?(\.[a-zA-Z](([-0-9a-zA-Z]+)?[0-9a-zA-Z])?)*$/.test(e);if(t){if(e.length>255)return!1;for(var r=e.split("."),n=0;n<r.length;n++)if(r[n].length>63)return!1}return t},"host-name":function(e){return i.hostname.call(this,e)},ipv4:function(e){return"string"!=typeof e?!0:n.isIP(e,4)},ipv6:function(e){return"string"!=typeof e?!0:n.isIP(e,6)},regex:function(e){try{return RegExp(e),!0}catch(t){return!1}},uri:function(e){return this.options.strictUris?i["strict-uri"].apply(this,arguments):"string"!=typeof e||RegExp("^(([^:/?#]+):)?(//([^/?#]*))?([^?#]*)(\\?([^#]*))?(#(.*))?").test(e)},"strict-uri":function(e){return"string"!=typeof e||n.isURL(e)}};e.exports=i},function(e,t,r){"use strict";var n=r(4),i=r(3),o=r(9),a={multipleOf:function(e,t,r){"number"==typeof r&&"integer"!==o.whatIs(r/t.multipleOf)&&e.addError("MULTIPLE_OF",[r,t.multipleOf],null,t.description)},maximum:function(e,t,r){"number"==typeof r&&(t.exclusiveMaximum!==!0?r>t.maximum&&e.addError("MAXIMUM",[r,t.maximum],null,t.description):r>=t.maximum&&e.addError("MAXIMUM_EXCLUSIVE",[r,t.maximum],null,t.description))},exclusiveMaximum:function(){},minimum:function(e,t,r){"number"==typeof r&&(t.exclusiveMinimum!==!0?r<t.minimum&&e.addError("MINIMUM",[r,t.minimum],null,t.description):r<=t.minimum&&e.addError("MINIMUM_EXCLUSIVE",[r,t.minimum],null,t.description))},exclusiveMinimum:function(){},maxLength:function(e,t,r){"string"==typeof r&&o.ucs2decode(r).length>t.maxLength&&e.addError("MAX_LENGTH",[r.length,t.maxLength],null,t.description)},minLength:function(e,t,r){"string"==typeof r&&o.ucs2decode(r).length<t.minLength&&e.addError("MIN_LENGTH",[r.length,t.minLength],null,t.description)},pattern:function(e,t,r){"string"==typeof r&&RegExp(t.pattern).test(r)===!1&&e.addError("PATTERN",[t.pattern,r],null,t.description)},additionalItems:function(e,t,r){Array.isArray(r)&&t.additionalItems===!1&&Array.isArray(t.items)&&r.length>t.items.length&&e.addError("ARRAY_ADDITIONAL_ITEMS",null,null,t.description)},items:function(){},maxItems:function(e,t,r){Array.isArray(r)&&r.length>t.maxItems&&e.addError("ARRAY_LENGTH_LONG",[r.length,t.maxItems],null,t.description)},minItems:function(e,t,r){Array.isArray(r)&&r.length<t.minItems&&e.addError("ARRAY_LENGTH_SHORT",[r.length,t.minItems],null,t.description)},uniqueItems:function(e,t,r){if(Array.isArray(r)&&t.uniqueItems===!0){var n=[];o.isUniqueArray(r,n)===!1&&e.addError("ARRAY_UNIQUE",n,null,t.description)}},maxProperties:function(e,t,r){if("object"===o.whatIs(r)){var n=Object.keys(r).length;n>t.maxProperties&&e.addError("OBJECT_PROPERTIES_MAXIMUM",[n,t.maxProperties],null,t.description)}},minProperties:function(e,t,r){if("object"===o.whatIs(r)){var n=Object.keys(r).length;n<t.minProperties&&e.addError("OBJECT_PROPERTIES_MINIMUM",[n,t.minProperties],null,t.description)}},required:function(e,t,r){if("object"===o.whatIs(r))for(var n=t.required.length;n--;){var i=t.required[n];void 0===r[i]&&e.addError("OBJECT_MISSING_REQUIRED_PROPERTY",[i],null,t.description)}},additionalProperties:function(e,t,r){return void 0===t.properties&&void 0===t.patternProperties?a.properties.call(this,e,t,r):void 0},patternProperties:function(e,t,r){return void 0===t.properties?a.properties.call(this,e,t,r):void 0},properties:function(e,t,r){if("object"===o.whatIs(r)){var n=void 0!==t.properties?t.properties:{},i=void 0!==t.patternProperties?t.patternProperties:{};if(t.additionalProperties===!1){var a=Object.keys(r),s=Object.keys(n),u=Object.keys(i);a=o.difference(a,s);for(var l=u.length;l--;)for(var f=RegExp(u[l]),d=a.length;d--;)f.test(a[d])===!0&&a.splice(d,1);if(a.length>0){var c=this.options.assumeAdditional.length;if(c)for(;c--;){var p=a.indexOf(this.options.assumeAdditional[c]);-1!==p&&a.splice(p,1)}a.length>0&&e.addError("OBJECT_ADDITIONAL_PROPERTIES",[a],null,t.description)}}}},dependencies:function(e,r,n){if("object"===o.whatIs(n))for(var i=Object.keys(r.dependencies),a=i.length;a--;){var s=i[a];if(n[s]){var u=r.dependencies[s];if("object"===o.whatIs(u))t.validate.call(this,e,u,n);else for(var l=u.length;l--;){var f=u[l];void 0===n[f]&&e.addError("OBJECT_DEPENDENCY_KEY",[f,s],null,r.description)}}}},"enum":function(e,t,r){for(var n=!1,i=t["enum"].length;i--;)if(o.areEqual(r,t["enum"][i])){n=!0;break}n===!1&&e.addError("ENUM_MISMATCH",[r],null,t.description)},allOf:function(e,r,n){for(var i=r.allOf.length;i--;){var o=t.validate.call(this,e,r.allOf[i],n);if(this.options.breakOnFirstError&&o===!1)break}},anyOf:function(e,r,n){for(var o=[],a=!1,s=r.anyOf.length;s--&&a===!1;){var u=new i(e);o.push(u),a=t.validate.call(this,u,r.anyOf[s],n)}a===!1&&e.addError("ANY_OF_MISSING",void 0,o,r.description)},oneOf:function(e,r,n){for(var o=0,a=[],s=r.oneOf.length;s--;){var u=new i(e,{maxErrors:1});a.push(u),t.validate.call(this,u,r.oneOf[s],n)===!0&&o++}0===o?e.addError("ONE_OF_MISSING",void 0,a,r.description):o>1&&e.addError("ONE_OF_MULTIPLE",null,null,r.description)},not:function(e,r,n){var o=new i(e);t.validate.call(this,o,r.not,n)===!0&&e.addError("NOT_PASSED",null,null,r.description)},definitions:function(){},format:function(e,t,r){var i=n[t.format];"function"==typeof i?2===i.length?e.addAsyncTask(i,[r],function(n){n!==!0&&e.addError("INVALID_FORMAT",[t.format,r],null,t.description)}):i.call(this,r)!==!0&&e.addError("INVALID_FORMAT",[t.format,r],null,t.description):this.options.ignoreUnknownFormats!==!0&&e.addError("UNKNOWN_FORMAT",[t.format],null,t.description)}},s=function(e,r,n){var i=n.length;if(Array.isArray(r.items))for(;i--;)i<r.items.length?(e.path.push(i.toString()),t.validate.call(this,e,r.items[i],n[i]),e.path.pop()):"object"==typeof r.additionalItems&&(e.path.push(i.toString()),t.validate.call(this,e,r.additionalItems,n[i]),e.path.pop());else if("object"==typeof r.items)for(;i--;)e.path.push(i.toString()),t.validate.call(this,e,r.items,n[i]),e.path.pop()},u=function(e,r,n){var i=r.additionalProperties;(i===!0||void 0===i)&&(i={});for(var o=r.properties?Object.keys(r.properties):[],a=r.patternProperties?Object.keys(r.patternProperties):[],s=Object.keys(n),u=s.length;u--;){var l=s[u],f=n[l],d=[];-1!==o.indexOf(l)&&d.push(r.properties[l]);for(var c=a.length;c--;){var p=a[c];RegExp(p).test(l)===!0&&d.push(r.patternProperties[p])}for(0===d.length&&i!==!1&&d.push(i),c=d.length;c--;)e.path.push(l),t.validate.call(this,e,d[c],f),e.path.pop()}};t.validate=function(e,t,r){e.commonErrorMessage="JSON_OBJECT_VALIDATION_FAILED";var n=o.whatIs(t);if("object"!==n)return e.addError("SCHEMA_NOT_AN_OBJECT",[n],null,t.description),!1;var i=Object.keys(t);if(0===i.length)return!0;var l=!1;if(e.rootSchema||(e.rootSchema=t,l=!0),void 0!==t.$ref){for(var f=99;t.$ref&&f>0;){if(!t.__$refResolved){e.addError("REF_UNRESOLVED",[t.$ref],null,t.description);break}if(t.__$refResolved===t)break;t=t.__$refResolved,i=Object.keys(t),f--}if(0===f)throw new Error("Circular dependency by $ref references!")}var d=o.whatIs(r);if(t.type)if("string"==typeof t.type){if(d!==t.type&&("integer"!==d||"number"!==t.type)&&(e.addError("INVALID_TYPE",[t.type,d],null,t.description),this.options.breakOnFirstError))return!1}else if(-1===t.type.indexOf(d)&&("integer"!==d||-1===t.type.indexOf("number"))&&(e.addError("INVALID_TYPE",[t.type,d],null,t.description),this.options.breakOnFirstError))return!1;for(var c=i.length;c--&&!(a[i[c]]&&(a[i[c]].call(this,e,t,r),e.errors.length&&this.options.breakOnFirstError)););return(0===e.errors.length||this.options.breakOnFirstError===!1)&&("array"===d?s.call(this,e,t,r):"object"===d&&u.call(this,e,t,r)),"function"==typeof this.options.customValidator&&this.options.customValidator(e,t,r),l&&(e.rootSchema=void 0),0===e.errors.length}},function(e,t,r){"use strict";function n(e){return decodeURIComponent(e).replace(/~[0-1]/g,function(e){return"~1"===e?"/":"~"})}function i(e){var t=e.indexOf("#");return-1===t?e:e.slice(0,t)}function o(e){var t=e.indexOf("#"),r=-1===t?void 0:e.slice(t+1);return r}function a(e,t){if("object"==typeof e&&null!==e){if(!t)return e;if(e.id&&(e.id===t||"#"===e.id[0]&&e.id.substring(1)===t))return e;var r,n;if(Array.isArray(e)){for(r=e.length;r--;)if(n=a(e[r],t))return n}else{var i=Object.keys(e);for(r=i.length;r--;){var o=i[r];if(0!==o.indexOf("__$")&&(n=a(e[o],t)))return n}}}}var s=r(3),u=r(7),l=r(8),f=r(9);t.cacheSchemaByUri=function(e,t){var r=i(e);r&&(this.cache[r]=t)},t.removeFromCacheByUri=function(e){var t=i(e);t&&delete this.cache[t]},t.checkCacheForUri=function(e){var t=i(e);return t?null!=this.cache[t]:!1},t.getSchema=function(e,r){return"object"==typeof r&&(r=t.getSchemaByReference.call(this,e,r)),"string"==typeof r&&(r=t.getSchemaByUri.call(this,e,r)),r},t.getSchemaByReference=function(e,t){for(var r=this.referenceCache.length;r--;)if(this.referenceCache[r][0]===t)return this.referenceCache[r][1];var n=f.cloneDeep(t);return this.referenceCache.push([t,n]),n},t.getSchemaByUri=function(e,t,r){var f=i(t),d=o(t),c=f?this.cache[f]:r;if(c&&f){var p=c!==r;if(p){e.path.push(f);var h=new s(e);u.compileSchema.call(this,h,c)&&l.validateSchema.call(this,h,c);var m=h.isValid();if(m||e.addError("REMOTE_NOT_VALID",[t],h),e.path.pop(),!m)return void 0}}if(c&&d)for(var _=d.split("/"),y=0,E=_.length;c&&E>y;y++){var v=n(_[y]);c=0===y?a(c,v):c[v]}return c},t.getRemotePath=i},function(e,t,r){"use strict";function n(e,t){if(u.isAbsoluteUri(t))return t;var r,n=e.join(""),i=u.isAbsoluteUri(n),o=u.isRelativeUri(n),a=u.isRelativeUri(t);i&&a?(r=n.match(/\/[^\/]*$/),r&&(n=n.slice(0,r.index+1))):o&&a?n="":(r=n.match(/[^#\/]+$/),r&&(n=n.slice(0,r.index)));var s=n+t;return s=s.replace(/##/,"#")}function i(e,t,r,o){if(t=t||[],r=r||[],o=o||[],"object"!=typeof e||null===e)return t;"string"==typeof e.id&&r.push(e.id),"string"==typeof e.$ref&&"undefined"==typeof e.__$refResolved&&t.push({ref:n(r,e.$ref),key:"$ref",obj:e,path:o.slice(0)}),"string"==typeof e.$schema&&"undefined"==typeof e.__$schemaResolved&&t.push({ref:n(r,e.$schema),key:"$schema",obj:e,path:o.slice(0)});var a;if(Array.isArray(e))for(a=e.length;a--;)o.push(a.toString()),i(e[a],t,r,o),o.pop();else{var s=Object.keys(e);for(a=s.length;a--;)0!==s[a].indexOf("__$")&&(o.push(s[a]),i(e[s[a]],t,r,o),o.pop())}return"string"==typeof e.id&&r.pop(),t}function o(e,t){for(var r=e.length;r--;)if(e[r].id===t)return e[r];return null}var a=r(3),s=r(6),u=r(9),l=function(e,r){for(var n=r.length,i=0;n--;){var o=new a(e),s=t.compileSchema.call(this,o,r[n]);s&&i++,e.errors=e.errors.concat(o.errors)}return i},f=function(e,t){var r,n=0;do{for(var i=e.errors.length;i--;)"UNRESOLVABLE_REFERENCE"===e.errors[i].code&&e.errors.splice(i,1);for(r=n,n=l.call(this,e,t),i=t.length;i--;){var a=t[i];if(a.__$missingReferences){for(var s=a.__$missingReferences.length;s--;){var u=a.__$missingReferences[s],f=o(t,u.ref);f&&(u.obj["__"+u.key+"Resolved"]=f,a.__$missingReferences.splice(s,1))}0===a.__$missingReferences.length&&delete a.__$missingReferences}}}while(n!==t.length&&n!==r);return e.isValid()};t.compileSchema=function(e,r){if(e.commonErrorMessage="SCHEMA_COMPILATION_FAILED","string"==typeof r){var n=s.getSchemaByUri.call(this,e,r);if(!n)return e.addError("SCHEMA_NOT_REACHABLE",[r]),!1;r=n}if(Array.isArray(r))return f.call(this,e,r);if(r.__$compiled&&r.id&&s.checkCacheForUri.call(this,r.id)===!1&&(r.__$compiled=void 0),r.__$compiled)return!0;r.id&&"string"==typeof r.id&&s.cacheSchemaByUri.call(this,r.id,r);var o=!1;e.rootSchema||(e.rootSchema=r,o=!0);var l=e.isValid();delete r.__$missingReferences;for(var d=i.call(this,r),c=d.length;c--;){var p=d[c],h=s.getSchemaByUri.call(this,e,p.ref,r);if(!h){var m=this.getSchemaReader();if(m){var _=m(p.ref);if(_){_.id=p.ref;var y=new a(e);t.compileSchema.call(this,y,_)?h=s.getSchemaByUri.call(this,e,p.ref,r):e.errors=e.errors.concat(y.errors)}}}if(!h){var E=e.hasError("REMOTE_NOT_VALID",[p.ref]),v=u.isAbsoluteUri(p.ref),g=!1,O=this.options.ignoreUnresolvableReferences===!0;v&&(g=s.checkCacheForUri.call(this,p.ref)),E||O&&v||g||(Array.prototype.push.apply(e.path,p.path),e.addError("UNRESOLVABLE_REFERENCE",[p.ref]),e.path=e.path.slice(0,-p.path.length),l&&(r.__$missingReferences=r.__$missingReferences||[],r.__$missingReferences.push(p)))}p.obj["__"+p.key+"Resolved"]=h}var b=e.isValid();return b?r.__$compiled=!0:r.id&&"string"==typeof r.id&&s.removeFromCacheByUri.call(this,r.id),o&&(e.rootSchema=void 0),b}},function(e,t,r){"use strict";var n=r(4),i=r(5),o=r(3),a=r(9),s={$ref:function(e,t){"string"!=typeof t.$ref&&e.addError("KEYWORD_TYPE_EXPECTED",["$ref","string"])},$schema:function(e,t){"string"!=typeof t.$schema&&e.addError("KEYWORD_TYPE_EXPECTED",["$schema","string"])},multipleOf:function(e,t){"number"!=typeof t.multipleOf?e.addError("KEYWORD_TYPE_EXPECTED",["multipleOf","number"]):t.multipleOf<=0&&e.addError("KEYWORD_MUST_BE",["multipleOf","strictly greater than 0"])},maximum:function(e,t){"number"!=typeof t.maximum&&e.addError("KEYWORD_TYPE_EXPECTED",["maximum","number"])},exclusiveMaximum:function(e,t){"boolean"!=typeof t.exclusiveMaximum?e.addError("KEYWORD_TYPE_EXPECTED",["exclusiveMaximum","boolean"]):void 0===t.maximum&&e.addError("KEYWORD_DEPENDENCY",["exclusiveMaximum","maximum"])},minimum:function(e,t){"number"!=typeof t.minimum&&e.addError("KEYWORD_TYPE_EXPECTED",["minimum","number"])},exclusiveMinimum:function(e,t){"boolean"!=typeof t.exclusiveMinimum?e.addError("KEYWORD_TYPE_EXPECTED",["exclusiveMinimum","boolean"]):void 0===t.minimum&&e.addError("KEYWORD_DEPENDENCY",["exclusiveMinimum","minimum"])},maxLength:function(e,t){"integer"!==a.whatIs(t.maxLength)?e.addError("KEYWORD_TYPE_EXPECTED",["maxLength","integer"]):t.maxLength<0&&e.addError("KEYWORD_MUST_BE",["maxLength","greater than, or equal to 0"])},minLength:function(e,t){"integer"!==a.whatIs(t.minLength)?e.addError("KEYWORD_TYPE_EXPECTED",["minLength","integer"]):t.minLength<0&&e.addError("KEYWORD_MUST_BE",["minLength","greater than, or equal to 0"])},pattern:function(e,t){if("string"!=typeof t.pattern)e.addError("KEYWORD_TYPE_EXPECTED",["pattern","string"]);else try{RegExp(t.pattern)}catch(r){e.addError("KEYWORD_PATTERN",["pattern",t.pattern])}},additionalItems:function(e,r){var n=a.whatIs(r.additionalItems);"boolean"!==n&&"object"!==n?e.addError("KEYWORD_TYPE_EXPECTED",["additionalItems",["boolean","object"]]):"object"===n&&(e.path.push("additionalItems"),t.validateSchema.call(this,e,r.additionalItems),e.path.pop())},items:function(e,r){var n=a.whatIs(r.items);if("object"===n)e.path.push("items"),t.validateSchema.call(this,e,r.items),e.path.pop();else if("array"===n)for(var i=r.items.length;i--;)e.path.push("items"),e.path.push(i.toString()),t.validateSchema.call(this,e,r.items[i]),e.path.pop(),e.path.pop();else e.addError("KEYWORD_TYPE_EXPECTED",["items",["array","object"]]);this.options.forceAdditional===!0&&void 0===r.additionalItems&&Array.isArray(r.items)&&e.addError("KEYWORD_UNDEFINED_STRICT",["additionalItems"]),this.options.assumeAdditional&&void 0===r.additionalItems&&Array.isArray(r.items)&&(r.additionalItems=!1)},maxItems:function(e,t){"number"!=typeof t.maxItems?e.addError("KEYWORD_TYPE_EXPECTED",["maxItems","integer"]):t.maxItems<0&&e.addError("KEYWORD_MUST_BE",["maxItems","greater than, or equal to 0"])},minItems:function(e,t){"integer"!==a.whatIs(t.minItems)?e.addError("KEYWORD_TYPE_EXPECTED",["minItems","integer"]):t.minItems<0&&e.addError("KEYWORD_MUST_BE",["minItems","greater than, or equal to 0"])},uniqueItems:function(e,t){"boolean"!=typeof t.uniqueItems&&e.addError("KEYWORD_TYPE_EXPECTED",["uniqueItems","boolean"])},maxProperties:function(e,t){"integer"!==a.whatIs(t.maxProperties)?e.addError("KEYWORD_TYPE_EXPECTED",["maxProperties","integer"]):t.maxProperties<0&&e.addError("KEYWORD_MUST_BE",["maxProperties","greater than, or equal to 0"])},minProperties:function(e,t){"integer"!==a.whatIs(t.minProperties)?e.addError("KEYWORD_TYPE_EXPECTED",["minProperties","integer"]):t.minProperties<0&&e.addError("KEYWORD_MUST_BE",["minProperties","greater than, or equal to 0"])},required:function(e,t){if("array"!==a.whatIs(t.required))e.addError("KEYWORD_TYPE_EXPECTED",["required","array"]);else if(0===t.required.length)e.addError("KEYWORD_MUST_BE",["required","an array with at least one element"]);else{for(var r=t.required.length;r--;)"string"!=typeof t.required[r]&&e.addError("KEYWORD_VALUE_TYPE",["required","string"]);a.isUniqueArray(t.required)===!1&&e.addError("KEYWORD_MUST_BE",["required","an array with unique items"])}},additionalProperties:function(e,r){var n=a.whatIs(r.additionalProperties);"boolean"!==n&&"object"!==n?e.addError("KEYWORD_TYPE_EXPECTED",["additionalProperties",["boolean","object"]]):"object"===n&&(e.path.push("additionalProperties"),t.validateSchema.call(this,e,r.additionalProperties),e.path.pop())},properties:function(e,r){if("object"!==a.whatIs(r.properties))return void e.addError("KEYWORD_TYPE_EXPECTED",["properties","object"]);for(var n=Object.keys(r.properties),i=n.length;i--;){var o=n[i],s=r.properties[o];e.path.push("properties"),e.path.push(o),t.validateSchema.call(this,e,s),e.path.pop(),e.path.pop()}this.options.forceAdditional===!0&&void 0===r.additionalProperties&&e.addError("KEYWORD_UNDEFINED_STRICT",["additionalProperties"]),this.options.assumeAdditional&&void 0===r.additionalProperties&&(r.additionalProperties=!1),this.options.forceProperties===!0&&0===n.length&&e.addError("CUSTOM_MODE_FORCE_PROPERTIES",["properties"])},patternProperties:function(e,r){if("object"!==a.whatIs(r.patternProperties))return void e.addError("KEYWORD_TYPE_EXPECTED",["patternProperties","object"]);for(var n=Object.keys(r.patternProperties),i=n.length;i--;){var o=n[i],s=r.patternProperties[o];try{RegExp(o)}catch(u){e.addError("KEYWORD_PATTERN",["patternProperties",o])}e.path.push("patternProperties"),e.path.push(o.toString()),t.validateSchema.call(this,e,s),e.path.pop(),e.path.pop()}this.options.forceProperties===!0&&0===n.length&&e.addError("CUSTOM_MODE_FORCE_PROPERTIES",["patternProperties"])},dependencies:function(e,r){if("object"!==a.whatIs(r.dependencies))e.addError("KEYWORD_TYPE_EXPECTED",["dependencies","object"]);else for(var n=Object.keys(r.dependencies),i=n.length;i--;){var o=n[i],s=r.dependencies[o],u=a.whatIs(s);if("object"===u)e.path.push("dependencies"),e.path.push(o),t.validateSchema.call(this,e,s),e.path.pop(),e.path.pop();else if("array"===u){var l=s.length;for(0===l&&e.addError("KEYWORD_MUST_BE",["dependencies","not empty array"]);l--;)"string"!=typeof s[l]&&e.addError("KEYWORD_VALUE_TYPE",["dependensices","string"]);a.isUniqueArray(s)===!1&&e.addError("KEYWORD_MUST_BE",["dependencies","an array with unique items"])}else e.addError("KEYWORD_VALUE_TYPE",["dependencies","object or array"])}},"enum":function(e,t){Array.isArray(t["enum"])===!1?e.addError("KEYWORD_TYPE_EXPECTED",["enum","array"]):0===t["enum"].length?e.addError("KEYWORD_MUST_BE",["enum","an array with at least one element"]):a.isUniqueArray(t["enum"])===!1&&e.addError("KEYWORD_MUST_BE",["enum","an array with unique elements"])},type:function(e,t){var r=["array","boolean","integer","number","null","object","string"],n=r.join(","),i=Array.isArray(t.type);if(i){for(var o=t.type.length;o--;)-1===r.indexOf(t.type[o])&&e.addError("KEYWORD_TYPE_EXPECTED",["type",n]);a.isUniqueArray(t.type)===!1&&e.addError("KEYWORD_MUST_BE",["type","an object with unique properties"])}else"string"==typeof t.type?-1===r.indexOf(t.type)&&e.addError("KEYWORD_TYPE_EXPECTED",["type",n]):e.addError("KEYWORD_TYPE_EXPECTED",["type",["string","array"]]);this.options.noEmptyStrings===!0&&("string"===t.type||i&&-1!==t.type.indexOf("string"))&&void 0===t.minLength&&void 0===t["enum"]&&void 0===t.format&&(t.minLength=1),this.options.noEmptyArrays===!0&&("array"===t.type||i&&-1!==t.type.indexOf("array"))&&void 0===t.minItems&&(t.minItems=1),this.options.forceProperties===!0&&("object"===t.type||i&&-1!==t.type.indexOf("object"))&&void 0===t.properties&&void 0===t.patternProperties&&e.addError("KEYWORD_UNDEFINED_STRICT",["properties"]),this.options.forceItems===!0&&("array"===t.type||i&&-1!==t.type.indexOf("array"))&&void 0===t.items&&e.addError("KEYWORD_UNDEFINED_STRICT",["items"]),this.options.forceMinItems===!0&&("array"===t.type||i&&-1!==t.type.indexOf("array"))&&void 0===t.minItems&&e.addError("KEYWORD_UNDEFINED_STRICT",["minItems"]),this.options.forceMaxItems===!0&&("array"===t.type||i&&-1!==t.type.indexOf("array"))&&void 0===t.maxItems&&e.addError("KEYWORD_UNDEFINED_STRICT",["maxItems"]),this.options.forceMinLength===!0&&("string"===t.type||i&&-1!==t.type.indexOf("string"))&&void 0===t.minLength&&void 0===t.format&&void 0===t["enum"]&&void 0===t.pattern&&e.addError("KEYWORD_UNDEFINED_STRICT",["minLength"]),this.options.forceMaxLength===!0&&("string"===t.type||i&&-1!==t.type.indexOf("string"))&&void 0===t.maxLength&&void 0===t.format&&void 0===t["enum"]&&void 0===t.pattern&&e.addError("KEYWORD_UNDEFINED_STRICT",["maxLength"])},allOf:function(e,r){if(Array.isArray(r.allOf)===!1)e.addError("KEYWORD_TYPE_EXPECTED",["allOf","array"]);else if(0===r.allOf.length)e.addError("KEYWORD_MUST_BE",["allOf","an array with at least one element"]);else for(var n=r.allOf.length;n--;)e.path.push("allOf"),e.path.push(n.toString()),t.validateSchema.call(this,e,r.allOf[n]),e.path.pop(),e.path.pop()},anyOf:function(e,r){if(Array.isArray(r.anyOf)===!1)e.addError("KEYWORD_TYPE_EXPECTED",["anyOf","array"]);else if(0===r.anyOf.length)e.addError("KEYWORD_MUST_BE",["anyOf","an array with at least one element"]);else for(var n=r.anyOf.length;n--;)e.path.push("anyOf"),e.path.push(n.toString()),t.validateSchema.call(this,e,r.anyOf[n]),e.path.pop(),e.path.pop()},oneOf:function(e,r){if(Array.isArray(r.oneOf)===!1)e.addError("KEYWORD_TYPE_EXPECTED",["oneOf","array"]);else if(0===r.oneOf.length)e.addError("KEYWORD_MUST_BE",["oneOf","an array with at least one element"]);else for(var n=r.oneOf.length;n--;)e.path.push("oneOf"),e.path.push(n.toString()),t.validateSchema.call(this,e,r.oneOf[n]),e.path.pop(),e.path.pop()},not:function(e,r){"object"!==a.whatIs(r.not)?e.addError("KEYWORD_TYPE_EXPECTED",["not","object"]):(e.path.push("not"),t.validateSchema.call(this,e,r.not),e.path.pop())},definitions:function(e,r){if("object"!==a.whatIs(r.definitions))e.addError("KEYWORD_TYPE_EXPECTED",["definitions","object"]);else for(var n=Object.keys(r.definitions),i=n.length;i--;){var o=n[i],s=r.definitions[o];e.path.push("definitions"),e.path.push(o),t.validateSchema.call(this,e,s),e.path.pop(),e.path.pop()}},format:function(e,t){"string"!=typeof t.format?e.addError("KEYWORD_TYPE_EXPECTED",["format","string"]):void 0===n[t.format]&&this.options.ignoreUnknownFormats!==!0&&e.addError("UNKNOWN_FORMAT",[t.format])},id:function(e,t){"string"!=typeof t.id&&e.addError("KEYWORD_TYPE_EXPECTED",["id","string"])},title:function(e,t){"string"!=typeof t.title&&e.addError("KEYWORD_TYPE_EXPECTED",["title","string"])},description:function(e,t){"string"!=typeof t.description&&e.addError("KEYWORD_TYPE_EXPECTED",["description","string"])},"default":function(){}},u=function(e,r){for(var n=r.length;n--;)t.validateSchema.call(this,e,r[n]);return e.isValid()};t.validateSchema=function(e,t){if(e.commonErrorMessage="SCHEMA_VALIDATION_FAILED",
Array.isArray(t))return u.call(this,e,t);if(t.__$validated)return!0;var r=t.$schema&&t.id!==t.$schema;if(r)if(t.__$schemaResolved&&t.__$schemaResolved!==t){var n=new o(e),l=i.validate.call(this,n,t.__$schemaResolved,t);l===!1&&e.addError("PARENT_SCHEMA_VALIDATION_FAILED",null,n)}else this.options.ignoreUnresolvableReferences!==!0&&e.addError("REF_UNRESOLVED",[t.$schema]);if(this.options.noTypeless===!0){if(void 0!==t.type){var f=[];Array.isArray(t.anyOf)&&(f=f.concat(t.anyOf)),Array.isArray(t.oneOf)&&(f=f.concat(t.oneOf)),Array.isArray(t.allOf)&&(f=f.concat(t.allOf)),f.forEach(function(e){e.type||(e.type=t.type)})}void 0===t["enum"]&&void 0===t.type&&void 0===t.anyOf&&void 0===t.oneOf&&void 0===t.not&&void 0===t.$ref&&e.addError("KEYWORD_UNDEFINED_STRICT",["type"])}for(var d=Object.keys(t),c=d.length;c--;){var p=d[c];0!==p.indexOf("__")&&(void 0!==s[p]?s[p].call(this,e,t):r||this.options.noExtraKeywords===!0&&e.addError("KEYWORD_UNEXPECTED",[p]))}if(this.options.pedanticCheck===!0){if(t["enum"]){var h=a.clone(t);for(delete h["enum"],delete h["default"],e.path.push("enum"),c=t["enum"].length;c--;)e.path.push(c.toString()),i.validate.call(this,e,h,t["enum"][c]),e.path.pop();e.path.pop()}t["default"]&&(e.path.push("default"),i.validate.call(this,e,t,t["default"]),e.path.pop())}var m=e.isValid();return m&&(t.__$validated=!0),m}},function(e,t,r){"use strict";t.isAbsoluteUri=function(e){return/^https?:\/\//.test(e)},t.isRelativeUri=function(e){return/.+#/.test(e)},t.whatIs=function(e){var t=typeof e;return"object"===t?null===e?"null":Array.isArray(e)?"array":"object":"number"===t?Number.isFinite(e)?e%1===0?"integer":"number":Number.isNaN(e)?"not-a-number":"unknown-number":t},t.areEqual=function n(e,r){if(e===r)return!0;var i,o;if(Array.isArray(e)&&Array.isArray(r)){if(e.length!==r.length)return!1;for(o=e.length,i=0;o>i;i++)if(!n(e[i],r[i]))return!1;return!0}if("object"===t.whatIs(e)&&"object"===t.whatIs(r)){var a=Object.keys(e),s=Object.keys(r);if(!n(a,s))return!1;for(o=a.length,i=0;o>i;i++)if(!n(e[a[i]],r[a[i]]))return!1;return!0}return!1},t.isUniqueArray=function(e,r){var n,i,o=e.length;for(n=0;o>n;n++)for(i=n+1;o>i;i++)if(t.areEqual(e[n],e[i]))return r&&r.push(n,i),!1;return!0},t.difference=function(e,t){for(var r=[],n=e.length;n--;)-1===t.indexOf(e[n])&&r.push(e[n]);return r},t.clone=function(e){if("undefined"==typeof e)return void 0;if("object"!=typeof e||null===e)return e;var t,r;if(Array.isArray(e))for(t=[],r=e.length;r--;)t[r]=e[r];else{t={};var n=Object.keys(e);for(r=n.length;r--;){var i=n[r];t[i]=e[i]}}return t},t.cloneDeep=function(e){function t(e){if("object"!=typeof e||null===e)return e;var i,o,a;if(a=r.indexOf(e),-1!==a)return n[a];if(r.push(e),Array.isArray(e))for(i=[],n.push(i),o=e.length;o--;)i[o]=t(e[o]);else{i={},n.push(i);var s=Object.keys(e);for(o=s.length;o--;){var u=s[o];i[u]=t(e[u])}}return i}var r=[],n=[];return t(e)},t.ucs2decode=function(e){for(var t,r,n=[],i=0,o=e.length;o>i;)t=e.charCodeAt(i++),t>=55296&&56319>=t&&o>i?(r=e.charCodeAt(i++),56320==(64512&r)?n.push(((1023&t)<<10)+(1023&r)+65536):(n.push(t),i--)):n.push(t);return n}},function(e,t,r){function n(){if(!s){s=!0;for(var e,t=a.length;t;){e=a,a=[];for(var r=-1;++r<t;)e[r]();t=a.length}s=!1}}function i(){}var o=e.exports={},a=[],s=!1;o.nextTick=function(e){a.push(e),s||setTimeout(n,0)},o.title="browser",o.browser=!0,o.env={},o.argv=[],o.version="",o.versions={},o.on=i,o.addListener=i,o.once=i,o.off=i,o.removeListener=i,o.removeAllListeners=i,o.emit=i,o.binding=function(e){throw new Error("process.binding is not supported")},o.cwd=function(){return"/"},o.chdir=function(e){throw new Error("process.chdir is not supported")},o.umask=function(){return 0}},function(e,t,r){"use strict";e.exports={INVALID_TYPE:"Expected type {0} but found type {1}",INVALID_FORMAT:"Object didn't pass validation for format {0}: {1}",ENUM_MISMATCH:"No enum match for: {0}",ANY_OF_MISSING:"Data does not match any schemas from 'anyOf'",ONE_OF_MISSING:"Data does not match any schemas from 'oneOf'",ONE_OF_MULTIPLE:"Data is valid against more than one schema from 'oneOf'",NOT_PASSED:"Data matches schema from 'not'",ARRAY_LENGTH_SHORT:"Array is too short ({0}), minimum {1}",ARRAY_LENGTH_LONG:"Array is too long ({0}), maximum {1}",ARRAY_UNIQUE:"Array items are not unique (indexes {0} and {1})",ARRAY_ADDITIONAL_ITEMS:"Additional items not allowed",MULTIPLE_OF:"Value {0} is not a multiple of {1}",MINIMUM:"Value {0} is less than minimum {1}",MINIMUM_EXCLUSIVE:"Value {0} is equal or less than exclusive minimum {1}",MAXIMUM:"Value {0} is greater than maximum {1}",MAXIMUM_EXCLUSIVE:"Value {0} is equal or greater than exclusive maximum {1}",OBJECT_PROPERTIES_MINIMUM:"Too few properties defined ({0}), minimum {1}",OBJECT_PROPERTIES_MAXIMUM:"Too many properties defined ({0}), maximum {1}",OBJECT_MISSING_REQUIRED_PROPERTY:"Missing required property: {0}",OBJECT_ADDITIONAL_PROPERTIES:"Additional properties not allowed: {0}",OBJECT_DEPENDENCY_KEY:"Dependency failed - key must exist: {0} (due to key: {1})",MIN_LENGTH:"String is too short ({0} chars), minimum {1}",MAX_LENGTH:"String is too long ({0} chars), maximum {1}",PATTERN:"String does not match pattern {0}: {1}",KEYWORD_TYPE_EXPECTED:"Keyword '{0}' is expected to be of type '{1}'",KEYWORD_UNDEFINED_STRICT:"Keyword '{0}' must be defined in strict mode",KEYWORD_UNEXPECTED:"Keyword '{0}' is not expected to appear in the schema",KEYWORD_MUST_BE:"Keyword '{0}' must be {1}",KEYWORD_DEPENDENCY:"Keyword '{0}' requires keyword '{1}'",KEYWORD_PATTERN:"Keyword '{0}' is not a valid RegExp pattern: {1}",KEYWORD_VALUE_TYPE:"Each element of keyword '{0}' array must be a '{1}'",UNKNOWN_FORMAT:"There is no validation function for format '{0}'",CUSTOM_MODE_FORCE_PROPERTIES:"{0} must define at least one property if present",REF_UNRESOLVED:"Reference has not been resolved during compilation: {0}",UNRESOLVABLE_REFERENCE:"Reference could not be resolved: {0}",SCHEMA_NOT_REACHABLE:"Validator was not able to read schema with uri: {0}",SCHEMA_TYPE_EXPECTED:"Schema is expected to be of type 'object'",SCHEMA_NOT_AN_OBJECT:"Schema is not an object: {0}",ASYNC_TIMEOUT:"{0} asynchronous task(s) have timed out after {1} ms",PARENT_SCHEMA_VALIDATION_FAILED:"Schema failed to validate against its parent schema, see inner errors for details.",REMOTE_NOT_VALID:"Remote reference didn't compile successfully: {0}"}},function(e,t,r){(function(t){function r(e,t){return null==e?void 0:e[t]}function n(e){var t=!1;if(null!=e&&"function"!=typeof e.toString)try{t=!!(e+"")}catch(r){}return t}function i(e){var t=-1,r=e?e.length:0;for(this.clear();++t<r;){var n=e[t];this.set(n[0],n[1])}}function o(){this.__data__=_e?_e(null):{}}function a(e){return this.has(e)&&delete this.__data__[e]}function s(e){var t=this.__data__;if(_e){var r=t[e];return r===k?void 0:r}return fe.call(t,e)?t[e]:void 0}function u(e){var t=this.__data__;return _e?void 0!==t[e]:fe.call(t,e)}function l(e,t){var r=this.__data__;return r[e]=_e&&void 0===t?k:t,this}function f(e){var t=-1,r=e?e.length:0;for(this.clear();++t<r;){var n=e[t];this.set(n[0],n[1])}}function d(){this.__data__=[]}function c(e){var t=this.__data__,r=b(t,e);if(0>r)return!1;var n=t.length-1;return r==n?t.pop():he.call(t,r,1),!0}function p(e){var t=this.__data__,r=b(t,e);return 0>r?void 0:t[r][1]}function h(e){return b(this.__data__,e)>-1}function m(e,t){var r=this.__data__,n=b(r,e);return 0>n?r.push([e,t]):r[n][1]=t,this}function _(e){var t=-1,r=e?e.length:0;for(this.clear();++t<r;){var n=e[t];this.set(n[0],n[1])}}function y(){this.__data__={hash:new i,map:new(me||f),string:new i}}function E(e){return M(this,e)["delete"](e)}function v(e){return M(this,e).get(e)}function g(e){return M(this,e).has(e)}function O(e,t){return M(this,e).set(e,t),this}function b(e,t){for(var r=e.length;r--;)if(w(e[r][0],t))return r;return-1}function A(e,t){t=I(t,e)?[t]:P(t);for(var r=0,n=t.length;null!=e&&n>r;)e=e[$(t[r++])];return r&&r==n?e:void 0}function x(e){if(!C(e)||S(e))return!1;var t=N(e)||n(e)?ce:ee;return t.test(j(e))}function R(e){if("string"==typeof e)return e;if(U(e))return Ee?Ee.call(e):"";var t=e+"";return"0"==t&&1/e==-B?"-0":t}function P(e){return ge(e)?e:ve(e)}function M(e,t){var r=e.__data__;return D(t)?r["string"==typeof t?"string":"hash"]:r.map}function T(e,t){var n=r(e,t);return x(n)?n:void 0}function I(e,t){if(ge(e))return!1;var r=typeof e;return"number"==r||"symbol"==r||"boolean"==r||null==e||U(e)?!0:H.test(e)||!Z.test(e)||null!=t&&e in Object(t)}function D(e){var t=typeof e;return"string"==t||"number"==t||"symbol"==t||"boolean"==t?"__proto__"!==e:null===e}function S(e){return!!ue&&ue in e}function $(e){if("string"==typeof e||U(e))return e;var t=e+"";return"0"==t&&1/e==-B?"-0":t}function j(e){if(null!=e){try{return le.call(e)}catch(t){}try{return e+""}catch(t){}}return""}function F(e,t){if("function"!=typeof e||t&&"function"!=typeof t)throw new TypeError(W);var r=function(){var n=arguments,i=t?t.apply(this,n):n[0],o=r.cache;if(o.has(i))return o.get(i);var a=e.apply(this,n);return r.cache=o.set(i,a),a};return r.cache=new(F.Cache||_),r}function w(e,t){return e===t||e!==e&&t!==t}function N(e){var t=C(e)?de.call(e):"";return t==q||t==V}function C(e){var t=typeof e;return!!e&&("object"==t||"function"==t)}function Y(e){return!!e&&"object"==typeof e}function U(e){return"symbol"==typeof e||Y(e)&&de.call(e)==X}function L(e){return null==e?"":R(e)}function K(e,t,r){var n=null==e?void 0:A(e,t);return void 0===n?r:n}var W="Expected a function",k="__lodash_hash_undefined__",B=1/0,q="[object Function]",V="[object GeneratorFunction]",X="[object Symbol]",Z=/\.|\[(?:[^[\]]*|(["'])(?:(?!\1)[^\\]|\\.)*?\1)\]/,H=/^\w*$/,z=/^\./,J=/[^.[\]]+|\[(?:(-?\d+(?:\.\d+)?)|(["'])((?:(?!\2)[^\\]|\\.)*?)\2)\]|(?=(?:\.|\[\])(?:\.|\[\]|$))/g,G=/[\\^$.*+?()[\]{}|]/g,Q=/\\(\\)?/g,ee=/^\[object .+?Constructor\]$/,te="object"==typeof t&&t&&t.Object===Object&&t,re="object"==typeof self&&self&&self.Object===Object&&self,ne=te||re||Function("return this")(),ie=Array.prototype,oe=Function.prototype,ae=Object.prototype,se=ne["__core-js_shared__"],ue=function(){var e=/[^.]+$/.exec(se&&se.keys&&se.keys.IE_PROTO||"");return e?"Symbol(src)_1."+e:""}(),le=oe.toString,fe=ae.hasOwnProperty,de=ae.toString,ce=RegExp("^"+le.call(fe).replace(G,"\\$&").replace(/hasOwnProperty|(function).*?(?=\\\()| for .+?(?=\\\])/g,"$1.*?")+"$"),pe=ne.Symbol,he=ie.splice,me=T(ne,"Map"),_e=T(Object,"create"),ye=pe?pe.prototype:void 0,Ee=ye?ye.toString:void 0;i.prototype.clear=o,i.prototype["delete"]=a,i.prototype.get=s,i.prototype.has=u,i.prototype.set=l,f.prototype.clear=d,f.prototype["delete"]=c,f.prototype.get=p,f.prototype.has=h,f.prototype.set=m,_.prototype.clear=y,_.prototype["delete"]=E,_.prototype.get=v,_.prototype.has=g,_.prototype.set=O;var ve=F(function(e){e=L(e);var t=[];return z.test(e)&&t.push(""),e.replace(J,function(e,r,n,i){t.push(n?i.replace(Q,"$1"):r||e)}),t});F.Cache=_;var ge=Array.isArray;e.exports=K}).call(t,function(){return this}())},function(e,t,r){e.exports={id:"http://json-schema.org/draft-04/schema#",$schema:"http://json-schema.org/draft-04/schema#",description:"Core schema meta-schema",definitions:{schemaArray:{type:"array",minItems:1,items:{$ref:"#"}},positiveInteger:{type:"integer",minimum:0},positiveIntegerDefault0:{allOf:[{$ref:"#/definitions/positiveInteger"},{"default":0}]},simpleTypes:{"enum":["array","boolean","integer","null","number","object","string"]},stringArray:{type:"array",items:{type:"string"},minItems:1,uniqueItems:!0}},type:"object",properties:{id:{type:"string",format:"uri"},$schema:{type:"string",format:"uri"},title:{type:"string"},description:{type:"string"},"default":{},multipleOf:{type:"number",minimum:0,exclusiveMinimum:!0},maximum:{type:"number"},exclusiveMaximum:{type:"boolean","default":!1},minimum:{type:"number"},exclusiveMinimum:{type:"boolean","default":!1},maxLength:{$ref:"#/definitions/positiveInteger"},minLength:{$ref:"#/definitions/positiveIntegerDefault0"},pattern:{type:"string",format:"regex"},additionalItems:{anyOf:[{type:"boolean"},{$ref:"#"}],"default":{}},items:{anyOf:[{$ref:"#"},{$ref:"#/definitions/schemaArray"}],"default":{}},maxItems:{$ref:"#/definitions/positiveInteger"},minItems:{$ref:"#/definitions/positiveIntegerDefault0"},uniqueItems:{type:"boolean","default":!1},maxProperties:{$ref:"#/definitions/positiveInteger"},minProperties:{$ref:"#/definitions/positiveIntegerDefault0"},required:{$ref:"#/definitions/stringArray"},additionalProperties:{anyOf:[{type:"boolean"},{$ref:"#"}],"default":{}},definitions:{type:"object",additionalProperties:{$ref:"#"},"default":{}},properties:{type:"object",additionalProperties:{$ref:"#"},"default":{}},patternProperties:{type:"object",additionalProperties:{$ref:"#"},"default":{}},dependencies:{type:"object",additionalProperties:{anyOf:[{$ref:"#"},{$ref:"#/definitions/stringArray"}]}},"enum":{type:"array",minItems:1,uniqueItems:!0},type:{anyOf:[{$ref:"#/definitions/simpleTypes"},{type:"array",items:{$ref:"#/definitions/simpleTypes"},minItems:1,uniqueItems:!0}]},format:{type:"string"},allOf:{$ref:"#/definitions/schemaArray"},anyOf:{$ref:"#/definitions/schemaArray"},oneOf:{$ref:"#/definitions/schemaArray"},not:{$ref:"#"}},dependencies:{exclusiveMaximum:["maximum"],exclusiveMinimum:["minimum"]},"default":{}}},function(e,t,r){e.exports={$schema:"http://json-schema.org/draft-04/hyper-schema#",id:"http://json-schema.org/draft-04/hyper-schema#",title:"JSON Hyper-Schema",allOf:[{$ref:"http://json-schema.org/draft-04/schema#"}],properties:{additionalItems:{anyOf:[{type:"boolean"},{$ref:"#"}]},additionalProperties:{anyOf:[{type:"boolean"},{$ref:"#"}]},dependencies:{additionalProperties:{anyOf:[{$ref:"#"},{type:"array"}]}},items:{anyOf:[{$ref:"#"},{$ref:"#/definitions/schemaArray"}]},definitions:{additionalProperties:{$ref:"#"}},patternProperties:{additionalProperties:{$ref:"#"}},properties:{additionalProperties:{$ref:"#"}},allOf:{$ref:"#/definitions/schemaArray"},anyOf:{$ref:"#/definitions/schemaArray"},oneOf:{$ref:"#/definitions/schemaArray"},not:{$ref:"#"},links:{type:"array",items:{$ref:"#/definitions/linkDescription"}},fragmentResolution:{type:"string"},media:{type:"object",properties:{type:{description:"A media type, as described in RFC 2046",type:"string"},binaryEncoding:{description:"A content encoding scheme, as described in RFC 2045",type:"string"}}},pathStart:{description:"Instances' URIs must start with this value for this schema to apply to them",type:"string",format:"uri"}},definitions:{schemaArray:{type:"array",items:{$ref:"#"}},linkDescription:{title:"Link Description Object",type:"object",required:["href","rel"],properties:{href:{description:"a URI template, as defined by RFC 6570, with the addition of the $, ( and ) characters for pre-processing",type:"string"},rel:{description:"relation to the target resource of the link",type:"string"},title:{description:"a title for the link",type:"string"},targetSchema:{description:"JSON Schema describing the link target",$ref:"#"},mediaType:{description:"media type (as defined by RFC 2046) describing the link target",type:"string"},method:{description:'method for requesting the target of the link (e.g. for HTTP this might be "GET" or "DELETE")',type:"string"},encType:{description:"The media type in which to submit data along with the request",type:"string","default":"application/json"},schema:{description:"Schema describing the data to submit along with the request",$ref:"#"}}}}}},function(e,t,r){"use strict";function n(e){return e&&e.__esModule?e:{"default":e}}Object.defineProperty(t,"__esModule",{value:!0});var i=r(16),o=n(i),a=r(17),s=n(a),u=r(18),l=n(u),f=r(19),d=n(f),c=r(20),p=n(c),h=r(21),m=n(h),_=r(22),y=n(_),E=r(23),v=n(E),g=r(24),O=n(g),b=r(25),A=n(b),x=r(26),R=n(x),P=r(27),M=n(P),T=r(28),I=n(T),D=r(29),S=n(D),$=r(30),j=n($),F=r(31),w=n(F),N=r(32),C=n(N),Y=r(33),U=n(Y),L=r(34),K=n(L),W=r(35),k=n(W),B=r(36),q=n(B),V=r(37),X=n(V),Z=r(38),H=n(Z),z=r(39),J=n(z),G=r(40),Q=n(G),ee=r(41),te=n(ee),re=r(42),ne=n(re),ie=r(43),oe=n(ie),ae=r(44),se=n(ae),ue=r(45),le=n(ue),fe=r(46),de=n(fe),ce=r(47),pe=n(ce),he=r(48),me=n(he),_e=r(49),ye=n(_e),Ee=r(50),ve=n(Ee),ge=r(51),Oe=n(ge),be=r(52),Ae=n(be),xe=r(53),Re=n(xe),Pe=r(54),Me=n(Pe),Te=r(55),Ie=n(Te),De=r(56),Se=n(De),$e=r(57),je=n($e),Fe=r(58),we=n(Fe),Ne=r(59),Ce=n(Ne),Ye=r(60),Ue=n(Ye),Le=r(61),Ke=n(Le),We=r(62),ke=n(We),Be=r(63),qe=n(Be),Ve=r(64),Xe=n(Ve),Ze=r(65),He=n(Ze),ze=r(66),Je=n(ze),Ge=r(67),Qe=n(Ge),et=r(68),tt=n(et),rt=r(69),nt=n(rt),it=r(70),ot=n(it),at=r(71),st=n(at),ut=r(72),lt=n(ut),ft=r(73),dt=n(ft),ct=r(74),pt=n(ct),ht=r(75),mt=n(ht),_t="5.7.0",yt={version:_t,toDate:o["default"],toFloat:s["default"],toInt:l["default"],toBoolean:d["default"],equals:p["default"],contains:m["default"],matches:y["default"],isEmail:v["default"],isURL:O["default"],isMACAddress:A["default"],isIP:R["default"],isFQDN:M["default"],isBoolean:I["default"],isAlpha:S["default"],isAlphanumeric:j["default"],isNumeric:w["default"],isLowercase:C["default"],isUppercase:U["default"],isAscii:K["default"],isFullWidth:k["default"],isHalfWidth:q["default"],isVariableWidth:X["default"],isMultibyte:H["default"],isSurrogatePair:J["default"],isInt:Q["default"],isFloat:te["default"],isDecimal:ne["default"],isHexadecimal:oe["default"],isDivisibleBy:se["default"],isHexColor:le["default"],isMD5:de["default"],isJSON:pe["default"],isNull:me["default"],isLength:ye["default"],isByteLength:ve["default"],isUUID:Oe["default"],isMongoId:Ae["default"],isDate:Re["default"],isAfter:Me["default"],isBefore:Ie["default"],isIn:Se["default"],isCreditCard:je["default"],isISIN:we["default"],isISBN:Ce["default"],isMobilePhone:Ue["default"],isCurrency:Ke["default"],isISO8601:ke["default"],isBase64:qe["default"],isDataURI:Xe["default"],ltrim:He["default"],rtrim:Je["default"],trim:Qe["default"],escape:tt["default"],unescape:nt["default"],stripLow:ot["default"],whitelist:st["default"],blacklist:lt["default"],isWhitelisted:dt["default"],normalizeEmail:pt["default"],toString:mt["default"]};t["default"]=yt,e.exports=t["default"]},function(e,t,r){"use strict";function n(e){return e&&e.__esModule?e:{"default":e}}function i(e){return a["default"](e),e=Date.parse(e),isNaN(e)?null:new Date(e)}Object.defineProperty(t,"__esModule",{value:!0}),t["default"]=i;var o=r(76),a=n(o);e.exports=t["default"]},function(e,t,r){"use strict";function n(e){return e&&e.__esModule?e:{"default":e}}function i(e){return a["default"](e),parseFloat(e)}Object.defineProperty(t,"__esModule",{value:!0}),t["default"]=i;var o=r(76),a=n(o);e.exports=t["default"]},function(e,t,r){"use strict";function n(e){return e&&e.__esModule?e:{"default":e}}function i(e,t){return a["default"](e),parseInt(e,t||10)}Object.defineProperty(t,"__esModule",{value:!0}),t["default"]=i;var o=r(76),a=n(o);e.exports=t["default"]},function(e,t,r){"use strict";function n(e){return e&&e.__esModule?e:{"default":e}}function i(e,t){return a["default"](e),t?"1"===e||"true"===e:"0"!==e&&"false"!==e&&""!==e}Object.defineProperty(t,"__esModule",{value:!0}),t["default"]=i;var o=r(76),a=n(o);e.exports=t["default"]},function(e,t,r){"use strict";function n(e){return e&&e.__esModule?e:{"default":e}}function i(e,t){return a["default"](e),e===t}Object.defineProperty(t,"__esModule",{value:!0}),t["default"]=i;var o=r(76),a=n(o);e.exports=t["default"]},function(e,t,r){"use strict";function n(e){return e&&e.__esModule?e:{"default":e}}function i(e,t){return a["default"](e),e.indexOf(u["default"](t))>=0}Object.defineProperty(t,"__esModule",{value:!0}),t["default"]=i;var o=r(76),a=n(o),s=r(75),u=n(s);e.exports=t["default"]},function(e,t,r){"use strict";function n(e){return e&&e.__esModule?e:{"default":e}}function i(e,t,r){return a["default"](e),"[object RegExp]"!==Object.prototype.toString.call(t)&&(t=new RegExp(t,r)),t.test(e)}Object.defineProperty(t,"__esModule",{value:!0}),t["default"]=i;var o=r(76),a=n(o);e.exports=t["default"]},function(e,t,r){"use strict";function n(e){return e&&e.__esModule?e:{"default":e}}function i(e,t){if(a["default"](e),t=u["default"](t,p),t.allow_display_name){var r=e.match(h);r&&(e=r[1])}var n=e.split("@"),i=n.pop(),o=n.join("@"),s=i.toLowerCase();if(("gmail.com"===s||"googlemail.com"===s)&&(o=o.replace(/\./g,"").toLowerCase()),!f["default"](o,{max:64})||!f["default"](i,{max:256}))return!1;if(!c["default"](i,{require_tld:t.require_tld}))return!1;if('"'===o[0])return o=o.slice(1,o.length-1),t.allow_utf8_local_part?E.test(o):_.test(o);for(var l=t.allow_utf8_local_part?y:m,d=o.split("."),v=0;v<d.length;v++)if(!l.test(d[v]))return!1;return!0}Object.defineProperty(t,"__esModule",{value:!0}),t["default"]=i;var o=r(76),a=n(o),s=r(77),u=n(s),l=r(50),f=n(l),d=r(27),c=n(d),p={allow_display_name:!1,allow_utf8_local_part:!0,require_tld:!0},h=/^[a-z\d!#\$%&'\*\+\-\/=\?\^_`{\|}~\.\u00A0-\uD7FF\uF900-\uFDCF\uFDF0-\uFFEF]+[a-z\d!#\$%&'\*\+\-\/=\?\^_`{\|}~\.\u00A0-\uD7FF\uF900-\uFDCF\uFDF0-\uFFEF\s]*<(.+)>$/i,m=/^[a-z\d!#\$%&'\*\+\-\/=\?\^_`{\|}~]+$/i,_=/^([\s\x01-\x08\x0b\x0c\x0e-\x1f\x7f\x21\x23-\x5b\x5d-\x7e]|(\\[\x01-\x09\x0b\x0c\x0d-\x7f]))*$/i,y=/^[a-z\d!#\$%&'\*\+\-\/=\?\^_`{\|}~\u00A0-\uD7FF\uF900-\uFDCF\uFDF0-\uFFEF]+$/i,E=/^([\s\x01-\x08\x0b\x0c\x0e-\x1f\x7f\x21\x23-\x5b\x5d-\x7e\u00A0-\uD7FF\uF900-\uFDCF\uFDF0-\uFFEF]|(\\[\x01-\x09\x0b\x0c\x0d-\x7f\u00A0-\uD7FF\uF900-\uFDCF\uFDF0-\uFFEF]))*$/i;e.exports=t["default"]},function(e,t,r){"use strict";function n(e){return e&&e.__esModule?e:{"default":e}}function i(e){return"[object RegExp]"===Object.prototype.toString.call(e)}function o(e,t){for(var r=0;r<t.length;r++){var n=t[r];if(e===n||i(n)&&n.test(e))return!0}return!1}function a(e,t){if(u["default"](e),!e||e.length>=2083||/\s/.test(e))return!1;if(0===e.indexOf("mailto:"))return!1;t=h["default"](t,m);var r=void 0,n=void 0,i=void 0,a=void 0,s=void 0,l=void 0,d=void 0,p=void 0;if(d=e.split("#"),e=d.shift(),d=e.split("?"),e=d.shift(),d=e.split("://"),d.length>1){if(r=d.shift(),t.require_valid_protocol&&-1===t.protocols.indexOf(r))return!1}else{if(t.require_protocol)return!1;t.allow_protocol_relative_urls&&"//"===e.substr(0,2)&&(d[0]=e.substr(2))}if(e=d.join("://"),d=e.split("/"),e=d.shift(),""===e&&!t.require_host)return!0;if(d=e.split("@"),d.length>1&&(n=d.shift(),n.indexOf(":")>=0&&n.split(":").length>2))return!1;a=d.join("@"),l=p=null;var y=a.match(_);return y?(i="",p=y[1],l=y[2]||null):(d=a.split(":"),i=d.shift(),d.length&&(l=d.join(":"))),null!==l&&(s=parseInt(l,10),!/^[0-9]+$/.test(l)||0>=s||s>65535)?!1:c["default"](i)||f["default"](i,t)||p&&c["default"](p,6)||"localhost"===i?(i=i||p,t.host_whitelist&&!o(i,t.host_whitelist)?!1:t.host_blacklist&&o(i,t.host_blacklist)?!1:!0):!1}Object.defineProperty(t,"__esModule",{value:!0}),t["default"]=a;var s=r(76),u=n(s),l=r(27),f=n(l),d=r(26),c=n(d),p=r(77),h=n(p),m={protocols:["http","https","ftp"],require_tld:!0,require_protocol:!1,require_host:!0,require_valid_protocol:!0,allow_underscores:!1,allow_trailing_dot:!1,allow_protocol_relative_urls:!1},_=/^\[([^\]]+)\](?::([0-9]+))?$/;e.exports=t["default"]},function(e,t,r){"use strict";function n(e){return e&&e.__esModule?e:{"default":e}}function i(e){return a["default"](e),s.test(e)}Object.defineProperty(t,"__esModule",{value:!0}),t["default"]=i;var o=r(76),a=n(o),s=/^([0-9a-fA-F][0-9a-fA-F]:){5}([0-9a-fA-F][0-9a-fA-F])$/;e.exports=t["default"]},function(e,t,r){"use strict";function n(e){return e&&e.__esModule?e:{"default":e}}function i(e){var t=arguments.length<=1||void 0===arguments[1]?"":arguments[1];if(a["default"](e),t=String(t),!t)return i(e,4)||i(e,6);if("4"===t){if(!s.test(e))return!1;var r=e.split(".").sort(function(e,t){return e-t});return r[3]<=255}if("6"===t){var n=e.split(":"),o=!1,l=i(n[n.length-1],4),f=l?7:8;if(n.length>f)return!1;if("::"===e)return!0;"::"===e.substr(0,2)?(n.shift(),n.shift(),o=!0):"::"===e.substr(e.length-2)&&(n.pop(),n.pop(),o=!0);for(var d=0;d<n.length;++d)if(""===n[d]&&d>0&&d<n.length-1){if(o)return!1;o=!0}else if(l&&d===n.length-1);else if(!u.test(n[d]))return!1;return o?n.length>=1:n.length===f}return!1}Object.defineProperty(t,"__esModule",{value:!0}),t["default"]=i;var o=r(76),a=n(o),s=/^(\d{1,3})\.(\d{1,3})\.(\d{1,3})\.(\d{1,3})$/,u=/^[0-9A-F]{1,4}$/i;e.exports=t["default"]},function(e,t,r){"use strict";function n(e){return e&&e.__esModule?e:{"default":e}}function i(e,t){a["default"](e),t=u["default"](t,l),t.allow_trailing_dot&&"."===e[e.length-1]&&(e=e.substring(0,e.length-1));var r=e.split(".");if(t.require_tld){var n=r.pop();if(!r.length||!/^([a-z\u00a1-\uffff]{2,}|xn[a-z0-9-]{2,})$/i.test(n))return!1}for(var i,o=0;o<r.length;o++){if(i=r[o],t.allow_underscores&&(i=i.replace(/_/g,"")),!/^[a-z\u00a1-\uffff0-9-]+$/i.test(i))return!1;if(/[\uff01-\uff5e]/.test(i))return!1;if("-"===i[0]||"-"===i[i.length-1])return!1}return!0}Object.defineProperty(t,"__esModule",{value:!0}),t["default"]=i;var o=r(76),a=n(o),s=r(77),u=n(s),l={require_tld:!0,allow_underscores:!1,allow_trailing_dot:!1};e.exports=t["default"]},function(e,t,r){"use strict";function n(e){return e&&e.__esModule?e:{"default":e}}function i(e){return a["default"](e),["true","false","1","0"].indexOf(e)>=0}Object.defineProperty(t,"__esModule",{value:!0}),t["default"]=i;var o=r(76),a=n(o);e.exports=t["default"]},function(e,t,r){"use strict";function n(e){return e&&e.__esModule?e:{"default":e}}function i(e){var t=arguments.length<=1||void 0===arguments[1]?"en-US":arguments[1];if(a["default"](e),t in s.alpha)return s.alpha[t].test(e);throw new Error("Invalid locale '"+t+"'")}Object.defineProperty(t,"__esModule",{value:!0}),t["default"]=i;var o=r(76),a=n(o),s=r(78);e.exports=t["default"]},function(e,t,r){"use strict";function n(e){return e&&e.__esModule?e:{"default":e}}function i(e){var t=arguments.length<=1||void 0===arguments[1]?"en-US":arguments[1];if(a["default"](e),t in s.alphanumeric)return s.alphanumeric[t].test(e);throw new Error("Invalid locale '"+t+"'")}Object.defineProperty(t,"__esModule",{value:!0}),t["default"]=i;var o=r(76),a=n(o),s=r(78);e.exports=t["default"]},function(e,t,r){"use strict";function n(e){return e&&e.__esModule?e:{"default":e}}function i(e){return a["default"](e),s.test(e)}Object.defineProperty(t,"__esModule",{value:!0}),t["default"]=i;var o=r(76),a=n(o),s=/^[-+]?[0-9]+$/;e.exports=t["default"]},function(e,t,r){"use strict";function n(e){return e&&e.__esModule?e:{"default":e}}function i(e){return a["default"](e),e===e.toLowerCase()}Object.defineProperty(t,"__esModule",{value:!0}),t["default"]=i;var o=r(76),a=n(o);e.exports=t["default"]},function(e,t,r){"use strict";function n(e){return e&&e.__esModule?e:{"default":e}}function i(e){return a["default"](e),e===e.toUpperCase()}Object.defineProperty(t,"__esModule",{value:!0}),t["default"]=i;var o=r(76),a=n(o);e.exports=t["default"]},function(e,t,r){"use strict";function n(e){return e&&e.__esModule?e:{"default":e}}function i(e){return a["default"](e),s.test(e)}Object.defineProperty(t,"__esModule",{value:!0}),t["default"]=i;var o=r(76),a=n(o),s=/^[\x00-\x7F]+$/;e.exports=t["default"]},function(e,t,r){"use strict";function n(e){return e&&e.__esModule?e:{"default":e}}function i(e){return a["default"](e),s.test(e)}Object.defineProperty(t,"__esModule",{value:!0}),t.fullWidth=void 0,t["default"]=i;var o=r(76),a=n(o),s=t.fullWidth=/[^\u0020-\u007E\uFF61-\uFF9F\uFFA0-\uFFDC\uFFE8-\uFFEE0-9a-zA-Z]/},function(e,t,r){"use strict";function n(e){return e&&e.__esModule?e:{"default":e}}function i(e){return a["default"](e),s.test(e)}Object.defineProperty(t,"__esModule",{value:!0}),t.halfWidth=void 0,t["default"]=i;var o=r(76),a=n(o),s=t.halfWidth=/[\u0020-\u007E\uFF61-\uFF9F\uFFA0-\uFFDC\uFFE8-\uFFEE0-9a-zA-Z]/},function(e,t,r){"use strict";function n(e){return e&&e.__esModule?e:{"default":e}}function i(e){return a["default"](e),s.fullWidth.test(e)&&u.halfWidth.test(e)}Object.defineProperty(t,"__esModule",{value:!0}),t["default"]=i;var o=r(76),a=n(o),s=r(35),u=r(36);e.exports=t["default"]},function(e,t,r){"use strict";function n(e){return e&&e.__esModule?e:{"default":e}}function i(e){return a["default"](e),s.test(e)}Object.defineProperty(t,"__esModule",{value:!0}),t["default"]=i;var o=r(76),a=n(o),s=/[^\x00-\x7F]/;e.exports=t["default"]},function(e,t,r){"use strict";function n(e){return e&&e.__esModule?e:{"default":e}}function i(e){return a["default"](e),s.test(e)}Object.defineProperty(t,"__esModule",{value:!0}),t["default"]=i;var o=r(76),a=n(o),s=/[\uD800-\uDBFF][\uDC00-\uDFFF]/;e.exports=t["default"]},function(e,t,r){"use strict";function n(e){return e&&e.__esModule?e:{"default":e}}function i(e,t){a["default"](e),t=t||{};var r=t.hasOwnProperty("allow_leading_zeroes")&&t.allow_leading_zeroes?u:s,n=!t.hasOwnProperty("min")||e>=t.min,i=!t.hasOwnProperty("max")||e<=t.max;return r.test(e)&&n&&i}Object.defineProperty(t,"__esModule",{value:!0}),t["default"]=i;var o=r(76),a=n(o),s=/^(?:[-+]?(?:0|[1-9][0-9]*))$/,u=/^[-+]?[0-9]+$/;e.exports=t["default"]},function(e,t,r){"use strict";function n(e){return e&&e.__esModule?e:{"default":e}}function i(e,t){return a["default"](e),t=t||{},""===e||"."===e?!1:s.test(e)&&(!t.hasOwnProperty("min")||e>=t.min)&&(!t.hasOwnProperty("max")||e<=t.max)}Object.defineProperty(t,"__esModule",{value:!0}),t["default"]=i;var o=r(76),a=n(o),s=/^(?:[-+]?(?:[0-9]+))?(?:\.[0-9]*)?(?:[eE][\+\-]?(?:[0-9]+))?$/;e.exports=t["default"]},function(e,t,r){"use strict";function n(e){return e&&e.__esModule?e:{"default":e}}function i(e){return a["default"](e),""!==e&&s.test(e)}Object.defineProperty(t,"__esModule",{value:!0}),t["default"]=i;var o=r(76),a=n(o),s=/^[-+]?([0-9]+|\.[0-9]+|[0-9]+\.[0-9]+)$/;e.exports=t["default"]},function(e,t,r){"use strict";function n(e){return e&&e.__esModule?e:{"default":e}}function i(e){return a["default"](e),s.test(e)}Object.defineProperty(t,"__esModule",{value:!0}),t["default"]=i;var o=r(76),a=n(o),s=/^[0-9A-F]+$/i;e.exports=t["default"]},function(e,t,r){"use strict";function n(e){return e&&e.__esModule?e:{"default":e}}function i(e,t){return a["default"](e),u["default"](e)%parseInt(t,10)===0}Object.defineProperty(t,"__esModule",{value:!0}),t["default"]=i;var o=r(76),a=n(o),s=r(17),u=n(s);e.exports=t["default"]},function(e,t,r){"use strict";function n(e){return e&&e.__esModule?e:{"default":e}}function i(e){return a["default"](e),s.test(e)}Object.defineProperty(t,"__esModule",{value:!0}),t["default"]=i;var o=r(76),a=n(o),s=/^#?([0-9A-F]{3}|[0-9A-F]{6})$/i;e.exports=t["default"]},function(e,t,r){"use strict";function n(e){return e&&e.__esModule?e:{"default":e}}function i(e){return a["default"](e),s.test(e)}Object.defineProperty(t,"__esModule",{value:!0}),t["default"]=i;var o=r(76),a=n(o),s=/^[a-f0-9]{32}$/;e.exports=t["default"]},function(e,t,r){"use strict";function n(e){return e&&e.__esModule?e:{"default":e}}function i(e){s["default"](e);try{var t=JSON.parse(e);return!!t&&"object"===("undefined"==typeof t?"undefined":o(t))}catch(r){}return!1}Object.defineProperty(t,"__esModule",{value:!0});var o="function"==typeof Symbol&&"symbol"==typeof Symbol.iterator?function(e){return typeof e}:function(e){return e&&"function"==typeof Symbol&&e.constructor===Symbol?"symbol":typeof e};t["default"]=i;var a=r(76),s=n(a);e.exports=t["default"]},function(e,t,r){"use strict";function n(e){return e&&e.__esModule?e:{"default":e}}function i(e){return a["default"](e),0===e.length}Object.defineProperty(t,"__esModule",{value:!0}),t["default"]=i;var o=r(76),a=n(o);e.exports=t["default"]},function(e,t,r){"use strict";function n(e){return e&&e.__esModule?e:{"default":e}}function i(e,t){s["default"](e);var r=void 0,n=void 0;"object"===("undefined"==typeof t?"undefined":o(t))?(r=t.min||0,n=t.max):(r=arguments[1],n=arguments[2]);var i=e.match(/[\uD800-\uDBFF][\uDC00-\uDFFF]/g)||[],a=e.length-i.length;return a>=r&&("undefined"==typeof n||n>=a)}Object.defineProperty(t,"__esModule",{value:!0});var o="function"==typeof Symbol&&"symbol"==typeof Symbol.iterator?function(e){return typeof e}:function(e){return e&&"function"==typeof Symbol&&e.constructor===Symbol?"symbol":typeof e};t["default"]=i;var a=r(76),s=n(a);e.exports=t["default"]},function(e,t,r){"use strict";function n(e){
return e&&e.__esModule?e:{"default":e}}function i(e,t){s["default"](e);var r=void 0,n=void 0;"object"===("undefined"==typeof t?"undefined":o(t))?(r=t.min||0,n=t.max):(r=arguments[1],n=arguments[2]);var i=encodeURI(e).split(/%..|./).length-1;return i>=r&&("undefined"==typeof n||n>=i)}Object.defineProperty(t,"__esModule",{value:!0});var o="function"==typeof Symbol&&"symbol"==typeof Symbol.iterator?function(e){return typeof e}:function(e){return e&&"function"==typeof Symbol&&e.constructor===Symbol?"symbol":typeof e};t["default"]=i;var a=r(76),s=n(a);e.exports=t["default"]},function(e,t,r){"use strict";function n(e){return e&&e.__esModule?e:{"default":e}}function i(e){var t=arguments.length<=1||void 0===arguments[1]?"all":arguments[1];a["default"](e);var r=s[t];return r&&r.test(e)}Object.defineProperty(t,"__esModule",{value:!0}),t["default"]=i;var o=r(76),a=n(o),s={3:/^[0-9A-F]{8}-[0-9A-F]{4}-3[0-9A-F]{3}-[0-9A-F]{4}-[0-9A-F]{12}$/i,4:/^[0-9A-F]{8}-[0-9A-F]{4}-4[0-9A-F]{3}-[89AB][0-9A-F]{3}-[0-9A-F]{12}$/i,5:/^[0-9A-F]{8}-[0-9A-F]{4}-5[0-9A-F]{3}-[89AB][0-9A-F]{3}-[0-9A-F]{12}$/i,all:/^[0-9A-F]{8}-[0-9A-F]{4}-[0-9A-F]{4}-[0-9A-F]{4}-[0-9A-F]{12}$/i};e.exports=t["default"]},function(e,t,r){"use strict";function n(e){return e&&e.__esModule?e:{"default":e}}function i(e){return a["default"](e),u["default"](e)&&24===e.length}Object.defineProperty(t,"__esModule",{value:!0}),t["default"]=i;var o=r(76),a=n(o),s=r(43),u=n(s);e.exports=t["default"]},function(e,t,r){"use strict";function n(e){return e&&e.__esModule?e:{"default":e}}function i(e){var t=e.match(u.iso8601),r=void 0,n=void 0,i=void 0,o=void 0;if(t){if(r=t[21],!r)return t[12]?null:0;if("z"===r||"Z"===r)return 0;n=t[22],-1!==r.indexOf(":")?(i=parseInt(t[23],10),o=parseInt(t[24],10)):(i=0,o=parseInt(t[23],10))}else{if(e=e.toLowerCase(),r=e.match(/(?:\s|gmt\s*)(-|\+)(\d{1,4})(\s|$)/),!r)return-1!==e.indexOf("gmt")?0:null;n=r[1];var a=r[2];3===a.length&&(a="0"+a),a.length<=2?(i=0,o=parseInt(a,10)):(i=parseInt(a.slice(0,2),10),o=parseInt(a.slice(2,4),10))}return(60*i+o)*("-"===n?1:-1)}function o(e){s["default"](e);var t=new Date(Date.parse(e));if(isNaN(t))return!1;var r=i(e);if(null!==r){var n=t.getTimezoneOffset()-r;t=new Date(t.getTime()+6e4*n)}var o=String(t.getDate()),a=void 0,u=void 0,l=void 0;return(u=e.match(/(^|[^:\d])[23]\d([^T:\d]|$)/g))?(a=u.map(function(e){return e.match(/\d+/g)[0]}).join("/"),l=String(t.getFullYear()).slice(-2),a===o||a===l?!0:a===""+o/l||a===""+l/o?!0:!1):!0}Object.defineProperty(t,"__esModule",{value:!0}),t["default"]=o;var a=r(76),s=n(a),u=r(62);e.exports=t["default"]},function(e,t,r){"use strict";function n(e){return e&&e.__esModule?e:{"default":e}}function i(e){var t=arguments.length<=1||void 0===arguments[1]?String(new Date):arguments[1];a["default"](e);var r=u["default"](t),n=u["default"](e);return!!(n&&r&&n>r)}Object.defineProperty(t,"__esModule",{value:!0}),t["default"]=i;var o=r(76),a=n(o),s=r(16),u=n(s);e.exports=t["default"]},function(e,t,r){"use strict";function n(e){return e&&e.__esModule?e:{"default":e}}function i(e){var t=arguments.length<=1||void 0===arguments[1]?String(new Date):arguments[1];a["default"](e);var r=u["default"](t),n=u["default"](e);return!!(n&&r&&r>n)}Object.defineProperty(t,"__esModule",{value:!0}),t["default"]=i;var o=r(76),a=n(o),s=r(16),u=n(s);e.exports=t["default"]},function(e,t,r){"use strict";function n(e){return e&&e.__esModule?e:{"default":e}}function i(e,t){s["default"](e);var r=void 0;if("[object Array]"===Object.prototype.toString.call(t)){var n=[];for(r in t)({}).hasOwnProperty.call(t,r)&&(n[r]=l["default"](t[r]));return n.indexOf(e)>=0}return"object"===("undefined"==typeof t?"undefined":o(t))?t.hasOwnProperty(e):t&&"function"==typeof t.indexOf?t.indexOf(e)>=0:!1}Object.defineProperty(t,"__esModule",{value:!0});var o="function"==typeof Symbol&&"symbol"==typeof Symbol.iterator?function(e){return typeof e}:function(e){return e&&"function"==typeof Symbol&&e.constructor===Symbol?"symbol":typeof e};t["default"]=i;var a=r(76),s=n(a),u=r(75),l=n(u);e.exports=t["default"]},function(e,t,r){"use strict";function n(e){return e&&e.__esModule?e:{"default":e}}function i(e){a["default"](e);var t=e.replace(/[^0-9]+/g,"");if(!s.test(t))return!1;for(var r=0,n=void 0,i=void 0,o=void 0,u=t.length-1;u>=0;u--)n=t.substring(u,u+1),i=parseInt(n,10),o?(i*=2,r+=i>=10?i%10+1:i):r+=i,o=!o;return!!(r%10===0?t:!1)}Object.defineProperty(t,"__esModule",{value:!0}),t["default"]=i;var o=r(76),a=n(o),s=/^(?:4[0-9]{12}(?:[0-9]{3})?|5[1-5][0-9]{14}|(222[1-9]|22[3-9][0-9]|2[3-6][0-9]{2}|27[01][0-9]|2720)[0-9]{12}|6(?:011|5[0-9][0-9])[0-9]{12}|3[47][0-9]{13}|3(?:0[0-5]|[68][0-9])[0-9]{11}|(?:2131|1800|35\d{3})\d{11})|62[0-9]{14}$/;e.exports=t["default"]},function(e,t,r){"use strict";function n(e){return e&&e.__esModule?e:{"default":e}}function i(e){if(a["default"](e),!s.test(e))return!1;for(var t=e.replace(/[A-Z]/g,function(e){return parseInt(e,36)}),r=0,n=void 0,i=void 0,o=!0,u=t.length-2;u>=0;u--)n=t.substring(u,u+1),i=parseInt(n,10),o?(i*=2,r+=i>=10?i+1:i):r+=i,o=!o;return parseInt(e.substr(e.length-1),10)===(1e4-r)%10}Object.defineProperty(t,"__esModule",{value:!0}),t["default"]=i;var o=r(76),a=n(o),s=/^[A-Z]{2}[0-9A-Z]{9}[0-9]$/;e.exports=t["default"]},function(e,t,r){"use strict";function n(e){return e&&e.__esModule?e:{"default":e}}function i(e){var t=arguments.length<=1||void 0===arguments[1]?"":arguments[1];if(a["default"](e),t=String(t),!t)return i(e,10)||i(e,13);var r=e.replace(/[\s-]+/g,""),n=0,o=void 0;if("10"===t){if(!s.test(r))return!1;for(o=0;9>o;o++)n+=(o+1)*r.charAt(o);if(n+="X"===r.charAt(9)?100:10*r.charAt(9),n%11===0)return!!r}else if("13"===t){if(!u.test(r))return!1;for(o=0;12>o;o++)n+=l[o%2]*r.charAt(o);if(r.charAt(12)-(10-n%10)%10===0)return!!r}return!1}Object.defineProperty(t,"__esModule",{value:!0}),t["default"]=i;var o=r(76),a=n(o),s=/^(?:[0-9]{9}X|[0-9]{10})$/,u=/^(?:[0-9]{13})$/,l=[1,3];e.exports=t["default"]},function(e,t,r){"use strict";function n(e){return e&&e.__esModule?e:{"default":e}}function i(e,t){return a["default"](e),t in s?s[t].test(e):!1}Object.defineProperty(t,"__esModule",{value:!0}),t["default"]=i;var o=r(76),a=n(o),s={"ar-DZ":/^(\+?213|0)(5|6|7)\d{8}$/,"ar-SY":/^(!?(\+?963)|0)?9\d{8}$/,"ar-SA":/^(!?(\+?966)|0)?5\d{8}$/,"en-US":/^(\+?1)?[2-9]\d{2}[2-9](?!11)\d{6}$/,"cs-CZ":/^(\+?420)? ?[1-9][0-9]{2} ?[0-9]{3} ?[0-9]{3}$/,"de-DE":/^(\+?49[ \.\-])?([\(]{1}[0-9]{1,6}[\)])?([0-9 \.\-\/]{3,20})((x|ext|extension)[ ]?[0-9]{1,4})?$/,"da-DK":/^(\+?45)?(\d{8})$/,"el-GR":/^(\+?30)?(69\d{8})$/,"en-AU":/^(\+?61|0)4\d{8}$/,"en-GB":/^(\+?44|0)7\d{9}$/,"en-HK":/^(\+?852\-?)?[569]\d{3}\-?\d{4}$/,"en-IN":/^(\+?91|0)?[789]\d{9}$/,"en-NZ":/^(\+?64|0)2\d{7,9}$/,"en-ZA":/^(\+?27|0)\d{9}$/,"en-ZM":/^(\+?26)?09[567]\d{7}$/,"es-ES":/^(\+?34)?(6\d{1}|7[1234])\d{7}$/,"fi-FI":/^(\+?358|0)\s?(4(0|1|2|4|5)?|50)\s?(\d\s?){4,8}\d$/,"fr-FR":/^(\+?33|0)[67]\d{8}$/,"hu-HU":/^(\+?36)(20|30|70)\d{7}$/,"it-IT":/^(\+?39)?\s?3\d{2} ?\d{6,7}$/,"ja-JP":/^(\+?81|0)\d{1,4}[ \-]?\d{1,4}[ \-]?\d{4}$/,"ms-MY":/^(\+?6?01){1}(([145]{1}(\-|\s)?\d{7,8})|([236789]{1}(\s|\-)?\d{7}))$/,"nb-NO":/^(\+?47)?[49]\d{7}$/,"nl-BE":/^(\+?32|0)4?\d{8}$/,"nn-NO":/^(\+?47)?[49]\d{7}$/,"pl-PL":/^(\+?48)? ?[5-8]\d ?\d{3} ?\d{2} ?\d{2}$/,"pt-BR":/^(\+?55|0)\-?[1-9]{2}\-?[2-9]{1}\d{3,4}\-?\d{4}$/,"pt-PT":/^(\+?351)?9[1236]\d{7}$/,"ru-RU":/^(\+?7|8)?9\d{9}$/,"sr-RS":/^(\+3816|06)[- \d]{5,9}$/,"tr-TR":/^(\+?90|0)?5\d{9}$/,"vi-VN":/^(\+?84|0)?((1(2([0-9])|6([2-9])|88|99))|(9((?!5)[0-9])))([0-9]{7})$/,"zh-CN":/^(\+?0?86\-?)?1[345789]\d{9}$/,"zh-TW":/^(\+?886\-?|0)?9\d{8}$/};s["en-CA"]=s["en-US"],s["fr-BE"]=s["nl-BE"],e.exports=t["default"]},function(e,t,r){"use strict";function n(e){return e&&e.__esModule?e:{"default":e}}function i(e){var t="(\\"+e.symbol.replace(/\./g,"\\.")+")"+(e.require_symbol?"":"?"),r="-?",n="[1-9]\\d*",i="[1-9]\\d{0,2}(\\"+e.thousands_separator+"\\d{3})*",o=["0",n,i],a="("+o.join("|")+")?",s="(\\"+e.decimal_separator+"\\d{2})?",u=a+s;return e.allow_negatives&&!e.parens_for_negatives&&(e.negative_sign_after_digits?u+=r:e.negative_sign_before_digits&&(u=r+u)),e.allow_negative_sign_placeholder?u="( (?!\\-))?"+u:e.allow_space_after_symbol?u=" ?"+u:e.allow_space_after_digits&&(u+="( (?!$))?"),e.symbol_after_digits?u+=t:u=t+u,e.allow_negatives&&(e.parens_for_negatives?u="(\\("+u+"\\)|"+u+")":e.negative_sign_before_digits||e.negative_sign_after_digits||(u=r+u)),new RegExp("^(?!-? )(?=.*\\d)"+u+"$")}function o(e,t){return l["default"](e),t=s["default"](t,f),i(t).test(e)}Object.defineProperty(t,"__esModule",{value:!0}),t["default"]=o;var a=r(77),s=n(a),u=r(76),l=n(u),f={symbol:"$",require_symbol:!1,allow_space_after_symbol:!1,symbol_after_digits:!1,allow_negatives:!0,parens_for_negatives:!1,negative_sign_before_digits:!1,negative_sign_after_digits:!1,allow_negative_sign_placeholder:!1,thousands_separator:",",decimal_separator:".",allow_space_after_digits:!1};e.exports=t["default"]},function(e,t,r){"use strict";function n(e){return e&&e.__esModule?e:{"default":e}}Object.defineProperty(t,"__esModule",{value:!0}),t.iso8601=void 0,t["default"]=function(e){return o["default"](e),a.test(e)};var i=r(76),o=n(i),a=t.iso8601=/^([\+-]?\d{4}(?!\d{2}\b))((-?)((0[1-9]|1[0-2])(\3([12]\d|0[1-9]|3[01]))?|W([0-4]\d|5[0-2])(-?[1-7])?|(00[1-9]|0[1-9]\d|[12]\d{2}|3([0-5]\d|6[1-6])))([T\s]((([01]\d|2[0-3])((:?)[0-5]\d)?|24:?00)([\.,]\d+(?!:))?)?(\17[0-5]\d([\.,]\d+)?)?([zZ]|([\+-])([01]\d|2[0-3]):?([0-5]\d)?)?)?)?$/},function(e,t,r){"use strict";function n(e){return e&&e.__esModule?e:{"default":e}}function i(e){a["default"](e);var t=e.length;if(!t||t%4!==0||s.test(e))return!1;var r=e.indexOf("=");return-1===r||r===t-1||r===t-2&&"="===e[t-1]}Object.defineProperty(t,"__esModule",{value:!0}),t["default"]=i;var o=r(76),a=n(o),s=/[^A-Z0-9+\/=]/i;e.exports=t["default"]},function(e,t,r){"use strict";function n(e){return e&&e.__esModule?e:{"default":e}}function i(e){return a["default"](e),s.test(e)}Object.defineProperty(t,"__esModule",{value:!0}),t["default"]=i;var o=r(76),a=n(o),s=/^\s*data:([a-z]+\/[a-z0-9\-\+]+(;[a-z\-]+=[a-z0-9\-]+)?)?(;base64)?,[a-z0-9!\$&',\(\)\*\+,;=\-\._~:@\/\?%\s]*\s*$/i;e.exports=t["default"]},function(e,t,r){"use strict";function n(e){return e&&e.__esModule?e:{"default":e}}function i(e,t){a["default"](e);var r=t?new RegExp("^["+t+"]+","g"):/^\s+/g;return e.replace(r,"")}Object.defineProperty(t,"__esModule",{value:!0}),t["default"]=i;var o=r(76),a=n(o);e.exports=t["default"]},function(e,t,r){"use strict";function n(e){return e&&e.__esModule?e:{"default":e}}function i(e,t){a["default"](e);for(var r=t?new RegExp("["+t+"]"):/\s/,n=e.length-1;n>=0&&r.test(e[n]);)n--;return n<e.length?e.substr(0,n+1):e}Object.defineProperty(t,"__esModule",{value:!0}),t["default"]=i;var o=r(76),a=n(o);e.exports=t["default"]},function(e,t,r){"use strict";function n(e){return e&&e.__esModule?e:{"default":e}}function i(e,t){return a["default"](u["default"](e,t),t)}Object.defineProperty(t,"__esModule",{value:!0}),t["default"]=i;var o=r(66),a=n(o),s=r(65),u=n(s);e.exports=t["default"]},function(e,t,r){"use strict";function n(e){return e&&e.__esModule?e:{"default":e}}function i(e){return a["default"](e),e.replace(/&/g,"&amp;").replace(/"/g,"&quot;").replace(/'/g,"&#x27;").replace(/</g,"&lt;").replace(/>/g,"&gt;").replace(/\//g,"&#x2F;").replace(/`/g,"&#96;")}Object.defineProperty(t,"__esModule",{value:!0}),t["default"]=i;var o=r(76),a=n(o);e.exports=t["default"]},function(e,t,r){"use strict";function n(e){return e&&e.__esModule?e:{"default":e}}function i(e){return a["default"](e),e.replace(/&amp;/g,"&").replace(/&quot;/g,'"').replace(/&#x27;/g,"'").replace(/&lt;/g,"<").replace(/&gt;/g,">").replace(/&#x2F;/g,"/").replace(/&#96;/g,"`")}Object.defineProperty(t,"__esModule",{value:!0}),t["default"]=i;var o=r(76),a=n(o);e.exports=t["default"]},function(e,t,r){"use strict";function n(e){return e&&e.__esModule?e:{"default":e}}function i(e,t){a["default"](e);var r=t?"\\x00-\\x09\\x0B\\x0C\\x0E-\\x1F\\x7F":"\\x00-\\x1F\\x7F";return u["default"](e,r)}Object.defineProperty(t,"__esModule",{value:!0}),t["default"]=i;var o=r(76),a=n(o),s=r(72),u=n(s);e.exports=t["default"]},function(e,t,r){"use strict";function n(e){return e&&e.__esModule?e:{"default":e}}function i(e,t){return a["default"](e),e.replace(new RegExp("[^"+t+"]+","g"),"")}Object.defineProperty(t,"__esModule",{value:!0}),t["default"]=i;var o=r(76),a=n(o);e.exports=t["default"]},function(e,t,r){"use strict";function n(e){return e&&e.__esModule?e:{"default":e}}function i(e,t){return a["default"](e),e.replace(new RegExp("["+t+"]+","g"),"")}Object.defineProperty(t,"__esModule",{value:!0}),t["default"]=i;var o=r(76),a=n(o);e.exports=t["default"]},function(e,t,r){"use strict";function n(e){return e&&e.__esModule?e:{"default":e}}function i(e,t){a["default"](e);for(var r=e.length-1;r>=0;r--)if(-1===t.indexOf(e[r]))return!1;return!0}Object.defineProperty(t,"__esModule",{value:!0}),t["default"]=i;var o=r(76),a=n(o);e.exports=t["default"]},function(e,t,r){"use strict";function n(e){return e&&e.__esModule?e:{"default":e}}function i(e,t){if(t=u["default"](t,l),!a["default"](e))return!1;var r=e.split("@",2);if(r[1]=r[1].toLowerCase(),"gmail.com"===r[1]||"googlemail.com"===r[1]){if(t.remove_extension&&(r[0]=r[0].split("+")[0]),t.remove_dots&&(r[0]=r[0].replace(/\./g,"")),!r[0].length)return!1;r[0]=r[0].toLowerCase(),r[1]="gmail.com"}else t.lowercase&&(r[0]=r[0].toLowerCase());return r.join("@")}Object.defineProperty(t,"__esModule",{value:!0}),t["default"]=i;var o=r(23),a=n(o),s=r(77),u=n(s),l={lowercase:!0,remove_dots:!0,remove_extension:!0};e.exports=t["default"]},function(e,t,r){"use strict";function n(e){return"object"===("undefined"==typeof e?"undefined":i(e))&&null!==e?e="function"==typeof e.toString?e.toString():"[object Object]":(null===e||"undefined"==typeof e||isNaN(e)&&!e.length)&&(e=""),String(e)}Object.defineProperty(t,"__esModule",{value:!0});var i="function"==typeof Symbol&&"symbol"==typeof Symbol.iterator?function(e){return typeof e}:function(e){return e&&"function"==typeof Symbol&&e.constructor===Symbol?"symbol":typeof e};t["default"]=n,e.exports=t["default"]},function(e,t,r){"use strict";function n(e){if("string"!=typeof e)throw new TypeError("This library (validator.js) validates strings only")}Object.defineProperty(t,"__esModule",{value:!0}),t["default"]=n,e.exports=t["default"]},function(e,t,r){"use strict";function n(){var e=arguments.length<=0||void 0===arguments[0]?{}:arguments[0],t=arguments[1];for(var r in t)"undefined"==typeof e[r]&&(e[r]=t[r]);return e}Object.defineProperty(t,"__esModule",{value:!0}),t["default"]=n,e.exports=t["default"]},function(e,t,r){"use strict";Object.defineProperty(t,"__esModule",{value:!0});for(var n,i=t.alpha={"en-US":/^[A-Z]+$/i,"cs-CZ":/^[A-ZÁČĎÉĚÍŇÓŘŠŤÚŮÝŽ]+$/i,"de-DE":/^[A-ZÄÖÜß]+$/i,"es-ES":/^[A-ZÁÉÍÑÓÚÜ]+$/i,"fr-FR":/^[A-ZÀÂÆÇÉÈÊËÏÎÔŒÙÛÜŸ]+$/i,"nl-NL":/^[A-ZÉËÏÓÖÜ]+$/i,"hu-HU":/^[A-ZÁÉÍÓÖŐÚÜŰ]+$/i,"pl-PL":/^[A-ZĄĆĘŚŁŃÓŻŹ]+$/i,"pt-PT":/^[A-ZÃÁÀÂÇÉÊÍÕÓÔÚÜ]+$/i,"ru-RU":/^[А-ЯЁ]+$/i,"sr-RS@latin":/^[A-ZČĆŽŠĐ]+$/i,"sr-RS":/^[А-ЯЂЈЉЊЋЏ]+$/i,"tr-TR":/^[A-ZÇĞİıÖŞÜ]+$/i,ar:/^[ءآأؤإئابةتثجحخدذرزسشصضطظعغفقكلمنهوىيًٌٍَُِّْٰ]+$/},o=t.alphanumeric={"en-US":/^[0-9A-Z]+$/i,"cs-CZ":/^[0-9A-ZÁČĎÉĚÍŇÓŘŠŤÚŮÝŽ]+$/i,"de-DE":/^[0-9A-ZÄÖÜß]+$/i,"es-ES":/^[0-9A-ZÁÉÍÑÓÚÜ]+$/i,"fr-FR":/^[0-9A-ZÀÂÆÇÉÈÊËÏÎÔŒÙÛÜŸ]+$/i,"hu-HU":/^[0-9A-ZÁÉÍÓÖŐÚÜŰ]+$/i,"nl-NL":/^[0-9A-ZÉËÏÓÖÜ]+$/i,"pl-PL":/^[0-9A-ZĄĆĘŚŁŃÓŻŹ]+$/i,"pt-PT":/^[0-9A-ZÃÁÀÂÇÉÊÍÕÓÔÚÜ]+$/i,"ru-RU":/^[0-9А-ЯЁ]+$/i,"sr-RS@latin":/^[0-9A-ZČĆŽŠĐ]+$/i,"sr-RS":/^[0-9А-ЯЂЈЉЊЋЏ]+$/i,"tr-TR":/^[0-9A-ZÇĞİıÖŞÜ]+$/i,ar:/^[٠١٢٣٤٥٦٧٨٩0-9ءآأؤإئابةتثجحخدذرزسشصضطظعغفقكلمنهوىيًٌٍَُِّْٰ]+$/},a=t.englishLocales=["AU","GB","HK","IN","NZ","ZA","ZM"],s=0;s<a.length;s++)n="en-"+a[s],i[n]=i["en-US"],o[n]=o["en-US"];i["pt-BR"]=i["pt-PT"],o["pt-BR"]=o["pt-PT"];for(var u,l=t.arabicLocales=["AE","BH","DZ","EG","IQ","JO","KW","LB","LY","MA","QM","QA","SA","SD","SY","TN","YE"],f=0;f<l.length;f++)u="ar-"+l[f],i[u]=i.ar,o[u]=o.ar}])});
(function webpackUniversalModuleDefinition(root, factory) {
	if(typeof exports === 'object' && typeof module === 'object')
		module.exports = factory();
	else if(typeof define === 'function' && define.amd)
		define(factory);
	else if(typeof exports === 'object')
		exports["RAML.XmlValidation"] = factory();
	else
		root["RAML.XmlValidation"] = factory();
})(this, function() {
return /******/ (function(modules) { // webpackBootstrap
/******/ 	// The module cache
/******/ 	var installedModules = {};
/******/
/******/ 	// The require function
/******/ 	function __webpack_require__(moduleId) {
/******/
/******/ 		// Check if module is in cache
/******/ 		if(installedModules[moduleId])
/******/ 			return installedModules[moduleId].exports;
/******/
/******/ 		// Create a new module (and put it into the cache)
/******/ 		var module = installedModules[moduleId] = {
/******/ 			exports: {},
/******/ 			id: moduleId,
/******/ 			loaded: false
/******/ 		};
/******/
/******/ 		// Execute the module function
/******/ 		modules[moduleId].call(module.exports, module, module.exports, __webpack_require__);
/******/
/******/ 		// Flag the module as loaded
/******/ 		module.loaded = true;
/******/
/******/ 		// Return the exports of the module
/******/ 		return module.exports;
/******/ 	}
/******/
/******/
/******/ 	// expose the modules object (__webpack_modules__)
/******/ 	__webpack_require__.m = modules;
/******/
/******/ 	// expose the module cache
/******/ 	__webpack_require__.c = installedModules;
/******/
/******/ 	// __webpack_public_path__
/******/ 	__webpack_require__.p = "";
/******/
/******/ 	// Load entry module and return exports
/******/ 	return __webpack_require__(0);
/******/ })
/************************************************************************/
/******/ ([
/* 0 */
/***/ function(module, exports, __webpack_require__) {

	"use strict";
	var validator = __webpack_require__(1);
	var XMLValidator = (function () {
	    function XMLValidator(schema) {
	        this.schema = schema;
	    }
	    XMLValidator.prototype.validate = function (xml, references) {
	        if (references === void 0) { references = []; }
	        if (references.length === 0) {
	            var result = validator.validateXML({ xml: xml, schema: this.schema });
	            return (result && result.errors && result.errors.map(function (error) { return new Error(error); })) || [];
	        }
	        var schemas = this.remoteSchemas(references);
	        schemas.push(this.schema);
	        var result = validator.validateXML({ xml: xml, schema: schemas });
	        return (result && result.errors && result.errors.map(function (error) {
	            return new Error(error);
	        })) || [];
	    };
	    XMLValidator.prototype.remoteSchemas = function (refs) {
	        return refs.map(function (ref) { return ref.patchedContent; });
	    };
	    return XMLValidator;
	}());
	exports.XMLValidator = XMLValidator;
	var XMLSchemaReference = (function () {
	    function XMLSchemaReference(originalPath, virtualIndex, patchedContent) {
	        this.originalPath = originalPath;
	        this.virtualIndex = virtualIndex;
	        this.patchedContent = patchedContent;
	    }
	    return XMLSchemaReference;
	}());
	exports.XMLSchemaReference = XMLSchemaReference;
	//# sourceMappingURL=index.js.map

/***/ },
/* 1 */
/***/ function(module, exports, __webpack_require__) {

	/* WEBPACK VAR INJECTION */(function(Buffer) {var xmllint={},errrCount=0;!function(){var module=void 0,process=void 0,require=void 0;if("undefined"==typeof window)var window={};xmllint.validateXML=function(options){function globalEval(e){eval.call(null,e)}function assert(e,i){e||abort("Assertion failed: "+i)}function getCFunc(ident){var func=Module["_"+ident];if(!func)try{func=eval("_"+ident)}catch(e){}return assert(func,"Cannot call unknown function "+ident+" (perhaps LLVM optimizations or closure removed it?)"),func}function setValue(e,i,r,n){switch(r=r||"i8","*"===r.charAt(r.length-1)&&(r="i32"),r){case"i1":HEAP8[e>>0]=i;break;case"i8":HEAP8[e>>0]=i;break;case"i16":HEAP16[e>>1]=i;break;case"i32":HEAP32[e>>2]=i;break;case"i64":tempI64=[i>>>0,(tempDouble=i,+Math_abs(tempDouble)>=1?tempDouble>0?(0|Math_min(+Math_floor(tempDouble/4294967296),4294967295))>>>0:~~+Math_ceil((tempDouble-+(~~tempDouble>>>0))/4294967296)>>>0:0)],HEAP32[e>>2]=tempI64[0],HEAP32[e+4>>2]=tempI64[1];break;case"float":HEAPF32[e>>2]=i;break;case"double":HEAPF64[e>>3]=i;break;default:abort("invalid type for setValue: "+r)}}function getValue(e,i,r){switch(i=i||"i8","*"===i.charAt(i.length-1)&&(i="i32"),i){case"i1":return HEAP8[e>>0];case"i8":return HEAP8[e>>0];case"i16":return HEAP16[e>>1];case"i32":return HEAP32[e>>2];case"i64":return HEAP32[e>>2];case"float":return HEAPF32[e>>2];case"double":return HEAPF64[e>>3];default:abort("invalid type for setValue: "+i)}return null}function allocate(e,i,r,n){var f,t;"number"==typeof e?(f=!0,t=e):(f=!1,t=e.length);var u,a="string"==typeof i?i:null;if(u=r==ALLOC_NONE?n:[_malloc,Runtime.stackAlloc,Runtime.staticAlloc,Runtime.dynamicAlloc][void 0===r?ALLOC_STATIC:r](Math.max(t,a?1:i.length)),f){var o,n=u;for(assert(0==(3&u)),o=u+(t&-4);n<o;n+=4)HEAP32[n>>2]=0;for(o=u+t;n<o;)HEAP8[n++>>0]=0;return u}if("i8"===a)return e.subarray||e.slice?HEAPU8.set(e,u):HEAPU8.set(new Uint8Array(e),u),u;for(var c,l,s,b=0;b<t;){var k=e[b];"function"==typeof k&&(k=Runtime.getFunctionIndex(k)),c=a||i[b],0!==c?("i64"==c&&(c="i32"),setValue(u+b,k,c),s!==c&&(l=Runtime.getNativeTypeSize(c),s=c),b+=l):b++}return u}function Pointer_stringify(e,i){if(0===i||!e)return"";for(var r,n=!1,f=0;;){if(r=HEAPU8[e+f>>0],r>=128)n=!0;else if(0==r&&!i)break;if(f++,i&&f==i)break}i||(i=f);var t="";if(!n){for(var u,a=1024;i>0;)u=String.fromCharCode.apply(String,HEAPU8.subarray(e,e+Math.min(i,a))),t=t?t+u:u,e+=a,i-=a;return t}var o=new Runtime.UTF8Processor;for(f=0;f<i;f++)r=HEAPU8[e+f>>0],t+=o.processCChar(r);return t}function UTF16ToString(e){for(var i=0,r="";;){var n=HEAP16[e+2*i>>1];if(0==n)return r;++i,r+=String.fromCharCode(n)}}function stringToUTF16(e,i){for(var r=0;r<e.length;++r){var n=e.charCodeAt(r);HEAP16[i+2*r>>1]=n}HEAP16[i+2*e.length>>1]=0}function UTF32ToString(e){for(var i=0,r="";;){var n=HEAP32[e+4*i>>2];if(0==n)return r;if(++i,n>=65536){var f=n-65536;r+=String.fromCharCode(55296|f>>10,56320|1023&f)}else r+=String.fromCharCode(n)}}function stringToUTF32(e,i){for(var r=0,n=0;n<e.length;++n){var f=e.charCodeAt(n);if(f>=55296&&f<=57343){var t=e.charCodeAt(++n);f=65536+((1023&f)<<10)|1023&t}HEAP32[i+4*r>>2]=f,++r}HEAP32[i+4*r>>2]=0}function demangle(e){function i(){a++,"K"===e[a]&&a++;for(var i=[];"E"!==e[a];)if("S"!==e[a])if("C"!==e[a]){var r=parseInt(e.substr(a)),n=r.toString().length;if(!r||!n){a--;break}var f=e.substr(a+n,r);i.push(f),c.push(f),a+=n+r}else i.push(i[i.length-1]),a+=2;else{a++;var t=e.indexOf("_",a),u=e.substring(a,t)||0;i.push(c[u]||"?"),a=t+1}return a++,i}function r(n,f,t){function u(){return"("+b.join(", ")+")"}f=f||1/0;var c,s="",b=[];if("N"===e[a]){if(c=i().join("::"),f--,0===f)return n?[c]:c}else{("K"===e[a]||l&&"L"===e[a])&&a++;var k=parseInt(e.substr(a));if(k){var h=k.toString().length;c=e.substr(a+h,k),a+=h+k}}if(l=!1,"I"===e[a]){a++;var w=r(!0),d=r(!0,1,!0);s+=d[0]+" "+c+"<"+w.join(", ")+">"}else s=c;e:for(;a<e.length&&f-- >0;){var v=e[a++];if(v in o)b.push(o[v]);else switch(v){case"P":b.push(r(!0,1,!0)[0]+"*");break;case"R":b.push(r(!0,1,!0)[0]+"&");break;case"L":a++;var m=e.indexOf("E",a),k=m-a;b.push(e.substr(a,k)),a+=k+2;break;case"A":var k=parseInt(e.substr(a));if(a+=k.toString().length,"_"!==e[a])throw"?";a++,b.push(r(!0,1,!0)[0]+" ["+k+"]");break;case"E":break e;default:s+="?"+v;break e}}return t||1!==b.length||"void"!==b[0]||(b=[]),n?(s&&b.push(s+"?"),b):s+u()}var n=!!Module.___cxa_demangle;if(n)try{var f=_malloc(e.length);writeStringToMemory(e.substr(1),f);var t=_malloc(4),u=Module.___cxa_demangle(f,0,0,t);if(0===getValue(t,"i32")&&u)return Pointer_stringify(u)}catch(e){}finally{f&&_free(f),t&&_free(t),u&&_free(u)}var a=3,o={v:"void",b:"bool",c:"char",s:"short",i:"int",l:"long",f:"float",d:"double",w:"wchar_t",a:"signed char",h:"unsigned char",t:"unsigned short",j:"unsigned int",m:"unsigned long",x:"long long",y:"unsigned long long",z:"..."},c=[],l=!0,s=e;try{if("Object._main"==e||"_main"==e)return"main()";if("number"==typeof e&&(e=Pointer_stringify(e)),"_"!==e[0])return e;if("_"!==e[1])return e;if("Z"!==e[2])return e;switch(e[3]){case"n":return"operator new()";case"d":return"operator delete()"}s=r()}catch(e){s+="?"}return s.indexOf("?")>=0&&!n&&Runtime.warnOnce("warning: a problem occurred in builtin C++ name demangling; build with  -s DEMANGLE_SUPPORT=1  to link in libcxxabi demangling"),s}function demangleAll(e){return e.replace(/__Z[\w\d_]+/g,function(e){var i=demangle(e);return e===i?e:e+" ["+i+"]"})}function jsStackTrace(){var e=new Error;if(!e.stack){try{throw new Error(0)}catch(i){e=i}if(!e.stack)return"(no stack trace available)"}return e.stack.toString()}function stackTrace(){return demangleAll(jsStackTrace())}function alignMemoryPage(e){return e+4095&-4096}function enlargeMemory(){abort("Cannot enlarge memory arrays. Either (1) compile with -s TOTAL_MEMORY=X with X higher than the current value "+TOTAL_MEMORY+", (2) compile with ALLOW_MEMORY_GROWTH which adjusts the size at runtime but prevents some optimizations, or (3) set Module.TOTAL_MEMORY before the program runs.")}function callRuntimeCallbacks(e){for(;e.length>0;){var i=e.shift();if("function"!=typeof i){var r=i.func;"number"==typeof r?void 0===i.arg?Runtime.dynCall("v",r):Runtime.dynCall("vi",r,[i.arg]):r(void 0===i.arg?null:i.arg)}else i()}}function preRun(){if(Module.preRun)for("function"==typeof Module.preRun&&(Module.preRun=[Module.preRun]);Module.preRun.length;)addOnPreRun(Module.preRun.shift());callRuntimeCallbacks(__ATPRERUN__)}function ensureInitRuntime(){runtimeInitialized||(runtimeInitialized=!0,callRuntimeCallbacks(__ATINIT__))}function preMain(){callRuntimeCallbacks(__ATMAIN__)}function exitRuntime(){callRuntimeCallbacks(__ATEXIT__),runtimeExited=!0}function postRun(){if(Module.postRun)for("function"==typeof Module.postRun&&(Module.postRun=[Module.postRun]);Module.postRun.length;)addOnPostRun(Module.postRun.shift());callRuntimeCallbacks(__ATPOSTRUN__)}function addOnPreRun(e){__ATPRERUN__.unshift(e)}function addOnInit(e){__ATINIT__.unshift(e)}function addOnPreMain(e){__ATMAIN__.unshift(e)}function addOnExit(e){__ATEXIT__.unshift(e)}function addOnPostRun(e){__ATPOSTRUN__.unshift(e)}function intArrayFromString(e,i,r){var n=(new Runtime.UTF8Processor).processJSString(e);return r&&(n.length=r),i||n.push(0),n}function intArrayToString(e){for(var i=[],r=0;r<e.length;r++){var n=e[r];n>255&&(n&=255),i.push(String.fromCharCode(n))}return i.join("")}function writeStringToMemory(e,i,r){for(var n=intArrayFromString(e,r),f=0;f<n.length;){var t=n[f];HEAP8[i+f>>0]=t,f+=1}}function writeArrayToMemory(e,i){for(var r=0;r<e.length;r++)HEAP8[i+r>>0]=e[r]}function writeAsciiToMemory(e,i,r){for(var n=0;n<e.length;n++)HEAP8[i+n>>0]=e.charCodeAt(n);r||(HEAP8[i+e.length>>0]=0)}function unSign(e,i,r){return e>=0?e:i<=32?2*Math.abs(1<<i-1)+e:Math.pow(2,i)+e}function reSign(e,i,r){if(e<=0)return e;var n=i<=32?Math.abs(1<<i-1):Math.pow(2,i-1);return e>=n&&(i<=32||e>n)&&(e=-2*n+e),e}function addRunDependency(e){runDependencies++,Module.monitorRunDependencies&&Module.monitorRunDependencies(runDependencies)}function removeRunDependency(e){if(runDependencies--,Module.monitorRunDependencies&&Module.monitorRunDependencies(runDependencies),0==runDependencies&&(null!==runDependencyWatcher&&(clearInterval(runDependencyWatcher),runDependencyWatcher=null),dependenciesFulfilled)){var i=dependenciesFulfilled;dependenciesFulfilled=null,i()}}function copyTempFloat(e){HEAP8[tempDoublePtr]=HEAP8[e],HEAP8[tempDoublePtr+1]=HEAP8[e+1],HEAP8[tempDoublePtr+2]=HEAP8[e+2],HEAP8[tempDoublePtr+3]=HEAP8[e+3]}function copyTempDouble(e){HEAP8[tempDoublePtr]=HEAP8[e],HEAP8[tempDoublePtr+1]=HEAP8[e+1],HEAP8[tempDoublePtr+2]=HEAP8[e+2],HEAP8[tempDoublePtr+3]=HEAP8[e+3],HEAP8[tempDoublePtr+4]=HEAP8[e+4],HEAP8[tempDoublePtr+5]=HEAP8[e+5],HEAP8[tempDoublePtr+6]=HEAP8[e+6],HEAP8[tempDoublePtr+7]=HEAP8[e+7]}function ___assert_fail(e,i,r,n){throw ABORT=!0,"Assertion failed: "+Pointer_stringify(e)+", at: "+[i?Pointer_stringify(i):"unknown filename",r,n?Pointer_stringify(n):"unknown function"]+" at "+stackTrace()}function ___setErrNo(e){return HEAP32[___errno_state>>2]=e,e}function _fflush(e){}function _mkport(){throw"TODO"}function _recv(e,i,r,n){var f=SOCKFS.getSocket(e);return f?_read(e,i,r):(___setErrNo(ERRNO_CODES.EBADF),-1)}function _pread(e,i,r,n){var f=FS.getStream(e);if(!f)return ___setErrNo(ERRNO_CODES.EBADF),-1;try{var t=HEAP8;return FS.read(f,t,i,r,n)}catch(e){return FS.handleFSError(e),-1}}function _read(e,i,r){var n=FS.getStream(e);if(!n)return ___setErrNo(ERRNO_CODES.EBADF),-1;try{var f=HEAP8;return FS.read(n,f,i,r)}catch(e){return FS.handleFSError(e),-1}}function _fread(e,i,r,n){var f=r*i;if(0==f)return 0;var t=0,u=FS.getStreamFromPtr(n);if(!u)return ___setErrNo(ERRNO_CODES.EBADF),0;for(;u.ungotten.length&&f>0;)HEAP8[e++>>0]=u.ungotten.pop(),f--,t++;var a=_read(u.fd,e,f);return a==-1?(u&&(u.error=!0),0):(t+=a,t<f&&(u.eof=!0),t/i|0)}function _close(e){var i=FS.getStream(e);if(!i)return ___setErrNo(ERRNO_CODES.EBADF),-1;try{return FS.close(i),0}catch(e){return FS.handleFSError(e),-1}}function _fsync(e){var i=FS.getStream(e);return i?0:(___setErrNo(ERRNO_CODES.EBADF),-1)}function _fileno(e){return e=FS.getStreamFromPtr(e),e?e.fd:-1}function _fclose(e){var i=_fileno(e);return _fsync(i),_close(i)}function _strerror_r(e,i,r){if(e in ERRNO_MESSAGES){if(ERRNO_MESSAGES[e].length>r-1)return ___setErrNo(ERRNO_CODES.ERANGE);var n=ERRNO_MESSAGES[e];return writeAsciiToMemory(n,i),0}return ___setErrNo(ERRNO_CODES.EINVAL)}function _strerror(e){return _strerror.buffer||(_strerror.buffer=_malloc(256)),_strerror_r(e,_strerror.buffer,256),_strerror.buffer}function _send(e,i,r,n){var f=SOCKFS.getSocket(e);return f?_write(e,i,r):(___setErrNo(ERRNO_CODES.EBADF),-1)}function _pwrite(e,i,r,n){var f=FS.getStream(e);if(!f)return ___setErrNo(ERRNO_CODES.EBADF),-1;try{var t=HEAP8;return FS.write(f,t,i,r,n)}catch(e){return FS.handleFSError(e),-1}}function _write(e,i,r){var n=FS.getStream(e);if(!n)return ___setErrNo(ERRNO_CODES.EBADF),-1;try{var f=HEAP8;return FS.write(n,f,i,r)}catch(e){return FS.handleFSError(e),-1}}function _fwrite(e,i,r,n){var f=r*i;if(0==f)return 0;var t=_fileno(n),u=_write(t,e,f);if(u==-1){var a=FS.getStreamFromPtr(n);return a&&(a.error=!0),0}return u/i|0}function _abort(){Module.abort()}function __reallyNegative(e){return e<0||0===e&&1/e===-(1/0)}function __formatString(e,i){function r(e){var r;return"double"===e?(HEAP32[tempDoublePtr>>2]=HEAP32[i+a>>2],HEAP32[tempDoublePtr+4>>2]=HEAP32[i+(a+4)>>2],r=+HEAPF64[tempDoublePtr>>3]):"i64"==e?r=[HEAP32[i+a>>2],HEAP32[i+(a+4)>>2]]:(e="i32",r=HEAP32[i+a>>2]),a+=Runtime.getNativeFieldSize(e),r}for(var n,f,t,u=e,a=0,o=[];;){var c=u;if(n=HEAP8[u>>0],0===n)break;if(f=HEAP8[u+1>>0],37==n){var l=!1,s=!1,b=!1,k=!1,h=!1;e:for(;;){switch(f){case 43:l=!0;break;case 45:s=!0;break;case 35:b=!0;break;case 48:if(k)break e;k=!0;break;case 32:h=!0;break;default:break e}u++,f=HEAP8[u+1>>0]}var w=0;if(42==f)w=r("i32"),u++,f=HEAP8[u+1>>0];else for(;f>=48&&f<=57;)w=10*w+(f-48),u++,f=HEAP8[u+1>>0];var d=!1,v=-1;if(46==f){if(v=0,d=!0,u++,f=HEAP8[u+1>>0],42==f)v=r("i32"),u++;else for(;;){var m=HEAP8[u+1>>0];if(m<48||m>57)break;v=10*v+(m-48),u++}f=HEAP8[u+1>>0]}v<0&&(v=6,d=!1);var _;switch(String.fromCharCode(f)){case"h":var p=HEAP8[u+2>>0];104==p?(u++,_=1):_=2;break;case"l":var p=HEAP8[u+2>>0];108==p?(u++,_=8):_=4;break;case"L":case"q":case"j":_=8;break;case"z":case"t":case"I":_=4;break;default:_=null}switch(_&&u++,f=HEAP8[u+1>>0],String.fromCharCode(f)){case"d":case"i":case"u":case"o":case"x":case"X":case"p":var E=100==f||105==f;_=_||4;var S,t=r("i"+8*_),g=t;if(8==_&&(t=Runtime.makeBigInt(t[0],t[1],117==f)),_<=4){var y=Math.pow(256,_)-1;t=(E?reSign:unSign)(t&y,8*_)}var F=Math.abs(t),O="";if(100==f||105==f)S=8==_&&i64Math?i64Math.stringify(g[0],g[1],null):reSign(t,8*_,1).toString(10);else if(117==f)S=8==_&&i64Math?i64Math.stringify(g[0],g[1],!0):unSign(t,8*_,1).toString(10),t=Math.abs(t);else if(111==f)S=(b?"0":"")+F.toString(8);else if(120==f||88==f){if(O=b&&0!=t?"0x":"",8==_&&i64Math)if(g[1]){S=(g[1]>>>0).toString(16);for(var A=(g[0]>>>0).toString(16);A.length<8;)A="0"+A;S+=A}else S=(g[0]>>>0).toString(16);else if(t<0){t=-t,S=(F-1).toString(16);for(var M=[],R=0;R<S.length;R++)M.push((15-parseInt(S[R],16)).toString(16));for(S=M.join("");S.length<2*_;)S="f"+S}else S=F.toString(16);88==f&&(O=O.toUpperCase(),S=S.toUpperCase())}else 112==f&&(0===F?S="(nil)":(O="0x",S=F.toString(16)));if(d)for(;S.length<v;)S="0"+S;for(t>=0&&(l?O="+"+O:h&&(O=" "+O)),"-"==S.charAt(0)&&(O="-"+O,S=S.substr(1));O.length+S.length<w;)s?S+=" ":k?S="0"+S:O=" "+O;S=O+S,S.split("").forEach(function(e){o.push(e.charCodeAt(0))});break;case"f":case"F":case"e":case"E":case"g":case"G":var S,t=r("double");if(isNaN(t))S="nan",k=!1;else if(isFinite(t)){var N=!1,T=Math.min(v,20);if(103==f||71==f){N=!0,v=v||1;var L=parseInt(t.toExponential(T).split("e")[1],10);v>L&&L>=-4?(f=(103==f?"f":"F").charCodeAt(0),v-=L+1):(f=(103==f?"e":"E").charCodeAt(0),v--),T=Math.min(v,20)}101==f||69==f?(S=t.toExponential(T),/[eE][-+]\d$/.test(S)&&(S=S.slice(0,-1)+"0"+S.slice(-1))):102!=f&&70!=f||(S=t.toFixed(T),0===t&&__reallyNegative(t)&&(S="-"+S));var D=S.split("e");if(N&&!b)for(;D[0].length>1&&D[0].indexOf(".")!=-1&&("0"==D[0].slice(-1)||"."==D[0].slice(-1));)D[0]=D[0].slice(0,-1);else for(b&&S.indexOf(".")==-1&&(D[0]+=".");v>T++;)D[0]+="0";S=D[0]+(D.length>1?"e"+D[1]:""),69==f&&(S=S.toUpperCase()),t>=0&&(l?S="+"+S:h&&(S=" "+S))}else S=(t<0?"-":"")+"inf",k=!1;for(;S.length<w;)s?S+=" ":S=!k||"-"!=S[0]&&"+"!=S[0]?(k?"0":" ")+S:S[0]+"0"+S.slice(1);f<97&&(S=S.toUpperCase()),S.split("").forEach(function(e){o.push(e.charCodeAt(0))});break;case"s":var C=r("i8*"),P=C?_strlen(C):"(null)".length;if(d&&(P=Math.min(P,v)),!s)for(;P<w--;)o.push(32);if(C)for(var R=0;R<P;R++)o.push(HEAPU8[C++>>0]);else o=o.concat(intArrayFromString("(null)".substr(0,P),!0));if(s)for(;P<w--;)o.push(32);break;case"c":for(s&&o.push(r("i8"));--w>0;)o.push(32);s||o.push(r("i8"));break;case"n":var B=r("i32*");HEAP32[B>>2]=o.length;break;case"%":o.push(n);break;default:for(var R=c;R<u+2;R++)o.push(HEAP8[R>>0])}u+=2}else o.push(n),u+=1}return o}function _fprintf(e,i,r){var n=__formatString(i,r),f=Runtime.stackSave(),t=_fwrite(allocate(n,"i8",ALLOC_STACK),1,n.length,e);return Runtime.stackRestore(f),t}function _printf(e,i){var r=HEAP32[_stdout>>2];return _fprintf(r,e,i)}function _fgetc(e){var i=FS.getStreamFromPtr(e);if(!i)return-1;if(i.eof||i.error)return-1;var r=_fread(_fgetc.ret,1,1,e);return 0==r?-1:r==-1?(i.error=!0,-1):HEAPU8[_fgetc.ret>>0]}function _fgets(e,i,r){var n=FS.getStreamFromPtr(r);if(!n)return 0;if(n.error||n.eof)return 0;for(var f,t=0;t<i-1&&10!=f;t++){if(f=_fgetc(r),f==-1){if(n.error||n.eof&&0==t)return 0;if(n.eof)break}HEAP8[e+t>>0]=f}return HEAP8[e+t>>0]=0,e}function _open(e,i,r){var n=HEAP32[r>>2];e=Pointer_stringify(e);try{var f=FS.open(e,i,n);return f.fd}catch(e){return FS.handleFSError(e),-1}}function _fopen(e,i){var r;if(i=Pointer_stringify(i),"r"==i[0])r=i.indexOf("+")!=-1?2:0;else if("w"==i[0])r=i.indexOf("+")!=-1?2:1,r|=64,r|=512;else{if("a"!=i[0])return ___setErrNo(ERRNO_CODES.EINVAL),0;r=i.indexOf("+")!=-1?2:1,r|=64,r|=1024}var n=_open(e,r,allocate([511,0,0,0],"i32",ALLOC_STACK));return n===-1?0:FS.getPtrForStream(FS.getStream(n))}function _fputc(e,i){var r=unSign(255&e);HEAP8[_fputc.ret>>0]=r;var n=_fileno(i),f=_write(n,_fputc.ret,1);if(f==-1){var t=FS.getStreamFromPtr(i);return t&&(t.error=!0),-1}return r}function _mmap(e,i,r,n,f,t){var u,a=!1;if(_mmap.mappings||(_mmap.mappings={}),f==-1){if(u=_malloc(i),!u)return-1;_memset(u,0,i),a=!0}else{var o=FS.getStream(f);if(!o)return-1;try{var c=FS.mmap(o,HEAPU8,e,i,t,r,n);u=c.ptr,a=c.allocated}catch(e){return FS.handleFSError(e),-1}}return _mmap.mappings[u]={malloc:u,num:i,allocated:a},u}function __exit(e){Module.exit(e)}function _exit(e){__exit(e)}function _emscripten_set_main_loop_timing(e,i){return Browser.mainLoop.timingMode=e,Browser.mainLoop.timingValue=i,Browser.mainLoop.func?(0==e?(Browser.mainLoop.scheduler=function(){setTimeout(Browser.mainLoop.runner,i)},Browser.mainLoop.method="timeout"):1==e&&(Browser.mainLoop.scheduler=function(){Browser.requestAnimationFrame(Browser.mainLoop.runner)},Browser.mainLoop.method="rAF"),0):1}function _emscripten_set_main_loop(e,i,r,n){Module.noExitRuntime=!0,assert(!Browser.mainLoop.func,"emscripten_set_main_loop: there can only be one main loop function at once: call emscripten_cancel_main_loop to cancel the previous one before setting a new one with different parameters."),Browser.mainLoop.func=e,Browser.mainLoop.arg=n;var f=Browser.mainLoop.currentlyRunningMainloop;if(Browser.mainLoop.runner=function(){if(!ABORT){if(Browser.mainLoop.queue.length>0){var i=Date.now(),r=Browser.mainLoop.queue.shift();if(r.func(r.arg),Browser.mainLoop.remainingBlockers){var t=Browser.mainLoop.remainingBlockers,u=t%1==0?t-1:Math.floor(t);r.counted?Browser.mainLoop.remainingBlockers=u:(u+=.5,Browser.mainLoop.remainingBlockers=(8*t+u)/9)}return console.log('main loop blocker "'+r.name+'" took '+(Date.now()-i)+" ms"),Browser.mainLoop.updateStatus(),void setTimeout(Browser.mainLoop.runner,0)}if(!(f<Browser.mainLoop.currentlyRunningMainloop)){if(Browser.mainLoop.currentFrameNumber=Browser.mainLoop.currentFrameNumber+1|0,1==Browser.mainLoop.timingMode&&Browser.mainLoop.timingValue>1&&Browser.mainLoop.currentFrameNumber%Browser.mainLoop.timingValue!=0)return void Browser.mainLoop.scheduler();"timeout"===Browser.mainLoop.method&&Module.ctx&&(Module.printErr("Looks like you are rendering without using requestAnimationFrame for the main loop. You should use 0 for the frame rate in emscripten_set_main_loop in order to use requestAnimationFrame, as that can greatly improve your frame rates!"),Browser.mainLoop.method=""),Browser.mainLoop.runIter(function(){"undefined"!=typeof n?Runtime.dynCall("vi",e,[n]):Runtime.dynCall("v",e)}),f<Browser.mainLoop.currentlyRunningMainloop||("object"==typeof SDL&&SDL.audio&&SDL.audio.queueNewAudioData&&SDL.audio.queueNewAudioData(),Browser.mainLoop.scheduler())}}},i&&i>0?_emscripten_set_main_loop_timing(0,1e3/i):_emscripten_set_main_loop_timing(1,1),Browser.mainLoop.scheduler(),r)throw"SimulateInfiniteLoop"}function _munmap(e,i){_mmap.mappings||(_mmap.mappings={});var r=_mmap.mappings[e];return r?(i==r.num&&(_mmap.mappings[e]=null,r.allocated&&_free(r.malloc)),0):0}function _stat(e,i,r){e="string"!=typeof e?Pointer_stringify(e):e;try{var n=r?FS.lstat(e):FS.stat(e);return HEAP32[i>>2]=n.dev,HEAP32[i+4>>2]=0,HEAP32[i+8>>2]=n.ino,HEAP32[i+12>>2]=n.mode,HEAP32[i+16>>2]=n.nlink,HEAP32[i+20>>2]=n.uid,HEAP32[i+24>>2]=n.gid,HEAP32[i+28>>2]=n.rdev,HEAP32[i+32>>2]=0,HEAP32[i+36>>2]=n.size,HEAP32[i+40>>2]=4096,HEAP32[i+44>>2]=n.blocks,HEAP32[i+48>>2]=n.atime.getTime()/1e3|0,HEAP32[i+52>>2]=0,HEAP32[i+56>>2]=n.mtime.getTime()/1e3|0,HEAP32[i+60>>2]=0,HEAP32[i+64>>2]=n.ctime.getTime()/1e3|0,HEAP32[i+68>>2]=0,HEAP32[i+72>>2]=n.ino,0}catch(i){return i.node&&PATH.normalize(e)!==PATH.normalize(FS.getPath(i.node))&&i.setErrno(ERRNO_CODES.ENOTDIR),FS.handleFSError(i),-1}}function _sysconf(e){switch(e){case 30:return PAGE_SIZE;case 132:case 133:case 12:case 137:case 138:case 15:case 235:case 16:case 17:case 18:case 19:case 20:case 149:case 13:case 10:case 236:case 153:case 9:case 21:case 22:case 159:case 154:case 14:case 77:case 78:case 139:case 80:case 81:case 79:case 82:case 68:case 67:case 164:case 11:case 29:case 47:case 48:case 95:case 52:case 51:case 46:return 200809;case 27:case 246:case 127:case 128:case 23:case 24:case 160:case 161:case 181:case 182:case 242:case 183:case 184:case 243:case 244:case 245:case 165:case 178:case 179:case 49:case 50:case 168:case 169:case 175:case 170:case 171:case 172:case 97:case 76:case 32:case 173:case 35:return-1;case 176:case 177:case 7:case 155:case 8:case 157:case 125:case 126:case 92:case 93:case 129:case 130:case 131:case 94:case 91:return 1;case 74:case 60:case 69:case 70:case 4:return 1024;case 31:case 42:case 72:return 32;case 87:case 26:case 33:return 2147483647;case 34:case 1:return 47839;case 38:case 36:return 99;case 43:case 37:return 2048;case 0:return 2097152;case 3:return 65536;case 28:return 32768;case 44:return 32767;case 75:return 16384;case 39:return 1e3;case 89:return 700;case 71:return 256;case 40:return 255;case 2:return 100;case 180:return 64;case 25:return 20;case 5:return 16;case 6:return 6;case 73:return 4;case 84:return"object"==typeof navigator?navigator.hardwareConcurrency||1:1}return ___setErrNo(ERRNO_CODES.EINVAL),-1}function _ferror(e){return e=FS.getStreamFromPtr(e),Number(e&&e.error)}function _getcwd(e,i){if(0==i)return ___setErrNo(ERRNO_CODES.EINVAL),0;var r=FS.cwd();return i<r.length+1?(___setErrNo(ERRNO_CODES.ERANGE),0):(writeAsciiToMemory(r,e),e)}function ___buildEnvironment(e){var i,r,n=64,f=1024;___buildEnvironment.called?(r=HEAP32[_environ>>2],i=HEAP32[r>>2]):(___buildEnvironment.called=!0,ENV.USER="web_user",ENV.PATH="/",ENV.PWD="/",ENV.HOME="/home/web_user",ENV.LANG="C",ENV._=Module.thisProgram,i=allocate(f,"i8",ALLOC_STATIC),r=allocate(4*n,"i8*",ALLOC_STATIC),HEAP32[r>>2]=i,HEAP32[_environ>>2]=r);var t=[],u=0;for(var a in e)if("string"==typeof e[a]){var o=a+"="+e[a];t.push(o),u+=o.length}if(u>f)throw new Error("Environment size exceeded TOTAL_ENV_SIZE!");for(var c=4,l=0;l<t.length;l++){var o=t[l];writeAsciiToMemory(o,i),HEAP32[r+l*c>>2]=i,i+=o.length+1}HEAP32[r+t.length*c>>2]=0}function _getenv(e){return 0===e?0:(e=Pointer_stringify(e),ENV.hasOwnProperty(e)?(_getenv.ret&&_free(_getenv.ret),_getenv.ret=allocate(intArrayFromString(ENV[e]),"i8",ALLOC_NORMAL),_getenv.ret):0)}function _gettimeofday(e){var i=Date.now();return HEAP32[e>>2]=i/1e3|0,HEAP32[e+4>>2]=i%1e3*1e3|0,0}function _vfprintf(e,i,r){return _fprintf(e,i,HEAP32[r>>2])}function _emscripten_memcpy_big(e,i,r){return HEAPU8.set(HEAPU8.subarray(i,i+r),e),e}function _sbrk(e){var i=_sbrk;i.called||(DYNAMICTOP=alignMemoryPage(DYNAMICTOP),i.called=!0,assert(Runtime.dynamicAlloc),i.alloc=Runtime.dynamicAlloc,Runtime.dynamicAlloc=function(){abort("cannot dynamically allocate, sbrk now has control")});var r=DYNAMICTOP;return 0!=e&&i.alloc(e),r}function ___errno_location(){return ___errno_state}function _time(e){var i=Date.now()/1e3|0;return e&&(HEAP32[e>>2]=i),i}function _llvm_ctlz_i64(e,i){var r=_llvm_ctlz_i32(i);return 32==r&&(r+=_llvm_ctlz_i32(e)),0|(asm.setTempRet0(0),r)}function invoke_iiiiiiii(e,i,r,n,f,t,u,a){try{return Module.dynCall_iiiiiiii(e,i,r,n,f,t,u,a)}catch(e){if("number"!=typeof e&&"longjmp"!==e)throw e;asm.setThrew(1,0)}}function invoke_iiii(e,i,r,n){try{return Module.dynCall_iiii(e,i,r,n)}catch(e){if("number"!=typeof e&&"longjmp"!==e)throw e;asm.setThrew(1,0)}}function invoke_viiiiiii(e,i,r,n,f,t,u,a){try{Module.dynCall_viiiiiii(e,i,r,n,f,t,u,a)}catch(e){if("number"!=typeof e&&"longjmp"!==e)throw e;asm.setThrew(1,0)}}function invoke_viiiii(e,i,r,n,f,t){try{Module.dynCall_viiiii(e,i,r,n,f,t)}catch(e){if("number"!=typeof e&&"longjmp"!==e)throw e;asm.setThrew(1,0)}}function invoke_i(e){try{return Module.dynCall_i(e)}catch(e){if("number"!=typeof e&&"longjmp"!==e)throw e;asm.setThrew(1,0)}}function invoke_vi(e,i){try{Module.dynCall_vi(e,i)}catch(e){if("number"!=typeof e&&"longjmp"!==e)throw e;asm.setThrew(1,0)}}function invoke_vii(e,i,r){try{Module.dynCall_vii(e,i,r)}catch(e){if("number"!=typeof e&&"longjmp"!==e)throw e;asm.setThrew(1,0)}}function invoke_iiiiiii(e,i,r,n,f,t,u){try{return Module.dynCall_iiiiiii(e,i,r,n,f,t,u)}catch(e){if("number"!=typeof e&&"longjmp"!==e)throw e;asm.setThrew(1,0)}}function invoke_ii(e,i){try{return Module.dynCall_ii(e,i)}catch(e){if("number"!=typeof e&&"longjmp"!==e)throw e;asm.setThrew(1,0)}}function invoke_viii(e,i,r,n){try{Module.dynCall_viii(e,i,r,n)}catch(e){if("number"!=typeof e&&"longjmp"!==e)throw e;asm.setThrew(1,0)}}function invoke_viiiiiiiii(e,i,r,n,f,t,u,a,o,c){try{Module.dynCall_viiiiiiiii(e,i,r,n,f,t,u,a,o,c)}catch(e){if("number"!=typeof e&&"longjmp"!==e)throw e;asm.setThrew(1,0)}}function invoke_iiiii(e,i,r,n,f){try{return Module.dynCall_iiiii(e,i,r,n,f)}catch(e){if("number"!=typeof e&&"longjmp"!==e)throw e;asm.setThrew(1,0)}}function invoke_viiiiii(e,i,r,n,f,t,u){try{Module.dynCall_viiiiii(e,i,r,n,f,t,u)}catch(e){if("number"!=typeof e&&"longjmp"!==e)throw e;asm.setThrew(1,0)}}function invoke_iii(e,i,r){try{return Module.dynCall_iii(e,i,r)}catch(e){if("number"!=typeof e&&"longjmp"!==e)throw e;asm.setThrew(1,0)}}function invoke_iiiiii(e,i,r,n,f,t){try{return Module.dynCall_iiiiii(e,i,r,n,f,t)}catch(e){if("number"!=typeof e&&"longjmp"!==e)throw e;asm.setThrew(1,0)}}function invoke_viiii(e,i,r,n,f){try{Module.dynCall_viiii(e,i,r,n,f)}catch(e){if("number"!=typeof e&&"longjmp"!==e)throw e;asm.setThrew(1,0)}}function ExitStatus(e){this.name="ExitStatus",this.message="Program terminated with exit("+e+")",this.status=e}function run(e){function i(){Module.calledRun||(Module.calledRun=!0,ABORT||(ensureInitRuntime(),preMain(),null!==preloadStartTime&&Date.now()-preloadStartTime>15&&Module.printErr("pre-main prep time: "+(Date.now()-preloadStartTime)+" ms"),Module.onRuntimeInitialized&&Module.onRuntimeInitialized(),Module._main&&shouldRunNow&&Module.callMain(e),postRun()))}e=e||Module.arguments,null===preloadStartTime&&(preloadStartTime=Date.now()),runDependencies>0||(preRun(),runDependencies>0||Module.calledRun||(Module.setStatus?(Module.setStatus("Running..."),setTimeout(function(){setTimeout(function(){Module.setStatus("")},1),i()},1)):i()))}function exit(e){if(!Module.noExitRuntime)throw ABORT=!0,EXITSTATUS=e,STACKTOP=initialStackTop,exitRuntime(),new ExitStatus(e)}function abort(e){e&&(Module.print(e),Module.printErr(e)),ABORT=!0,EXITSTATUS=1;var i="\nIf this abort() is unexpected, build with -s ASSERTIONS=1 which can give more information.";throw"abort() at "+stackTrace()+i}var Module={xml:options.xml,schema:options.schema};Module.preRun=function(){var e;for(e=0;e<1;e++)FS.createDataFile("/","file_"+e+".xml",Module.intArrayFromString(Module.xml[e]),!0,!0);for(e=0;e<Module.schema.length;e++)FS.createDataFile("/","file_"+e+".xsd",Module.intArrayFromString(Module.schema[e]),!0,!0)},Module.arguments=["--noout"],function(){var e;for("[object Array]"!==Object.prototype.toString.call(Module.schema)&&(Module.schema=[Module.schema]),"[object Array]"!==Object.prototype.toString.call(Module.xml)&&(Module.xml=[Module.xml]),e=0;e<Module.schema.length;e++)Module.arguments.push("--schema"),Module.arguments.push("file_"+e+".xsd");for(e=0;e<1;e++)Module.arguments.push("file_"+e+".xml")}(),Module.return="",Module.stdout=Module.stderr=function(e){Module.return+=String.fromCharCode(e)};var Module;Module||(Module=("undefined"!=typeof Module?Module:null)||{});var moduleOverrides={};for(var key in Module)Module.hasOwnProperty(key)&&(moduleOverrides[key]=Module[key]);if(Module.read=function(e){var i=new XMLHttpRequest;return i.open("GET",e,!1),i.send(null),i.responseText},"undefined"!=typeof arguments&&(Module.arguments=arguments),"undefined"!=typeof console)Module.print||(Module.print=function(e){console.log(e)}),Module.printErr||(Module.printErr=function(e){throw new Error("!_PERF_!")});else{var TRY_USE_DUMP=!1;Module.print||(Module.print=TRY_USE_DUMP&&"undefined"!=typeof dump?function(e){dump(e)}:function(e){})}window.Module=Module,!Module.load&&Module.read&&(Module.load=function(e){globalEval(Module.read(e))}),Module.print||(Module.print=function(){}),Module.printErr||(Module.printErr=Module.print),Module.arguments||(Module.arguments=[]),Module.thisProgram||(Module.thisProgram="./this.program"),Module.print=Module.print,Module.printErr=Module.printErr,Module.preRun=[],Module.postRun=[];for(var key in moduleOverrides)moduleOverrides.hasOwnProperty(key)&&(Module[key]=moduleOverrides[key]);var Runtime={setTempRet0:function(e){tempRet0=e},getTempRet0:function(){return tempRet0},stackSave:function(){return STACKTOP},stackRestore:function(e){STACKTOP=e},getNativeTypeSize:function(e){switch(e){case"i1":case"i8":return 1;case"i16":return 2;case"i32":return 4;case"i64":return 8;case"float":return 4;case"double":return 8;default:if("*"===e[e.length-1])return Runtime.QUANTUM_SIZE;if("i"===e[0]){var i=parseInt(e.substr(1));return assert(i%8===0),i/8}return 0}},getNativeFieldSize:function(e){return Math.max(Runtime.getNativeTypeSize(e),Runtime.QUANTUM_SIZE)},STACK_ALIGN:16,getAlignSize:function(e,i,r){return r||"i64"!=e&&"double"!=e?e?Math.min(i||(e?Runtime.getNativeFieldSize(e):0),Runtime.QUANTUM_SIZE):Math.min(i,8):8},dynCall:function(e,i,r){return r&&r.length?(r.splice||(r=Array.prototype.slice.call(r)),r.splice(0,0,i),Module["dynCall_"+e].apply(null,r)):Module["dynCall_"+e].call(null,i)},functionPointers:[],addFunction:function(e){for(var i=0;i<Runtime.functionPointers.length;i++)if(!Runtime.functionPointers[i])return Runtime.functionPointers[i]=e,2*(1+i);throw"Finished up all reserved function pointers. Use a higher value for RESERVED_FUNCTION_POINTERS."},removeFunction:function(e){Runtime.functionPointers[(e-2)/2]=null},getAsmConst:function(code,numArgs){Runtime.asmConstCache||(Runtime.asmConstCache={});var func=Runtime.asmConstCache[code];if(func)return func;for(var args=[],i=0;i<numArgs;i++)args.push(String.fromCharCode(36)+i);var source=Pointer_stringify(code);'"'===source[0]&&(source.indexOf('"',1)===source.length-1?source=source.substr(1,source.length-2):abort("invalid EM_ASM input |"+source+"|. Please use EM_ASM(..code..) (no quotes) or EM_ASM({ ..code($0).. }, input) (to input values)"));try{var evalled=eval("(function(Module, FS) { return function("+args.join(",")+"){ "+source+" } })")(Module,"undefined"!=typeof FS?FS:null)}catch(e){throw Module.printErr("error in executing inline EM_ASM code: "+e+" on: \n\n"+source+"\n\nwith args |"+args+"| (make sure to use the right one out of EM_ASM, EM_ASM_ARGS, etc.)"),e}return Runtime.asmConstCache[code]=evalled},warnOnce:function(e){Runtime.warnOnce.shown||(Runtime.warnOnce.shown={}),Runtime.warnOnce.shown[e]||(Runtime.warnOnce.shown[e]=1,Module.printErr(e))},funcWrappers:{},getFuncWrapper:function(e,i){assert(i),Runtime.funcWrappers[i]||(Runtime.funcWrappers[i]={});var r=Runtime.funcWrappers[i];return r[e]||(r[e]=function(){return Runtime.dynCall(i,e,arguments)}),r[e]},UTF8Processor:function(){var e=[],i=0;this.processCChar=function(r){if(r&=255,0==e.length)return 0==(128&r)?String.fromCharCode(r):(e.push(r),i=192==(224&r)?1:224==(240&r)?2:3,"");if(i&&(e.push(r),i--,i>0))return"";var n,f=e[0],t=e[1],u=e[2],a=e[3];if(2==e.length)n=String.fromCharCode((31&f)<<6|63&t);else if(3==e.length)n=String.fromCharCode((15&f)<<12|(63&t)<<6|63&u);else{var o=(7&f)<<18|(63&t)<<12|(63&u)<<6|63&a;n=String.fromCharCode(((o-65536)/1024|0)+55296,(o-65536)%1024+56320)}return e.length=0,n},this.processJSString=function(e){e=unescape(encodeURIComponent(e));for(var i=[],r=0;r<e.length;r++)i.push(e.charCodeAt(r));return i}},getCompilerSetting:function(e){throw"You must build with -s RETAIN_COMPILER_SETTINGS=1 for Runtime.getCompilerSetting or emscripten_get_compiler_setting to work"},stackAlloc:function(e){var i=STACKTOP;return STACKTOP=STACKTOP+e|0,STACKTOP=STACKTOP+15&-16,i},staticAlloc:function(e){
	var i=STATICTOP;return STATICTOP=STATICTOP+e|0,STATICTOP=STATICTOP+15&-16,i},dynamicAlloc:function(e){var i=DYNAMICTOP;return DYNAMICTOP=DYNAMICTOP+e|0,DYNAMICTOP=DYNAMICTOP+15&-16,DYNAMICTOP>=TOTAL_MEMORY&&enlargeMemory(),i},alignMemory:function(e,i){var r=e=Math.ceil(e/(i?i:16))*(i?i:16);return r},makeBigInt:function(e,i,r){var n=r?+(e>>>0)+4294967296*+(i>>>0):+(e>>>0)+4294967296*+(0|i);return n},GLOBAL_BASE:8,QUANTUM_SIZE:4,__dummy__:0};Module.Runtime=Runtime;var __THREW__=0,ABORT=!1,EXITSTATUS=0,undef=0,tempValue,tempInt,tempBigInt,tempInt2,tempBigInt2,tempPair,tempBigIntI,tempBigIntR,tempBigIntS,tempBigIntP,tempBigIntD,tempDouble,tempFloat,tempI64,tempI64b,tempRet0,tempRet1,tempRet2,tempRet3,tempRet4,tempRet5,tempRet6,tempRet7,tempRet8,tempRet9,globalScope=this,cwrap,ccall;!function(){function parseJSFunc(e){var i=e.toString().match(sourceRegex).slice(1);return{arguments:i[0],body:i[1],returnValue:i[2]}}var JSfuncs={stackSave:function(){Runtime.stackSave()},stackRestore:function(){Runtime.stackRestore()},arrayToC:function(e){var i=Runtime.stackAlloc(e.length);return writeArrayToMemory(e,i),i},stringToC:function(e){var i=0;return null!==e&&void 0!==e&&0!==e&&(i=Runtime.stackAlloc((e.length<<2)+1),writeStringToMemory(e,i)),i}},toC={string:JSfuncs.stringToC,array:JSfuncs.arrayToC};ccall=function(e,i,r,n){var f=getCFunc(e),t=[],u=0;if(n)for(var a=0;a<n.length;a++){var o=toC[r[a]];o?(0===u&&(u=Runtime.stackSave()),t[a]=o(n[a])):t[a]=n[a]}var c=f.apply(null,t);return"string"===i&&(c=Pointer_stringify(c)),0!==u&&Runtime.stackRestore(u),c};var sourceRegex=/^function\s*\(([^)]*)\)\s*{\s*([^*]*?)[\s;]*(?:return\s*(.*?)[;\s]*)?}$/,JSsource={};for(var fun in JSfuncs)JSfuncs.hasOwnProperty(fun)&&(JSsource[fun]=parseJSFunc(JSfuncs[fun]));cwrap=function cwrap(ident,returnType,argTypes){argTypes=argTypes||[];var cfunc=getCFunc(ident),numericArgs=argTypes.every(function(e){return"number"===e}),numericRet="string"!==returnType;if(numericRet&&numericArgs)return cfunc;var argNames=argTypes.map(function(e,i){return"$"+i}),funcstr="(function("+argNames.join(",")+") {",nargs=argTypes.length;if(!numericArgs){funcstr+="var stack = "+JSsource.stackSave.body+";";for(var i=0;i<nargs;i++){var arg=argNames[i],type=argTypes[i];if("number"!==type){var convertCode=JSsource[type+"ToC"];funcstr+="var "+convertCode.arguments+" = "+arg+";",funcstr+=convertCode.body+";",funcstr+=arg+"="+convertCode.returnValue+";"}}}var cfuncname=parseJSFunc(function(){return cfunc}).returnValue;if(funcstr+="var ret = "+cfuncname+"("+argNames.join(",")+");",!numericRet){var strgfy=parseJSFunc(function(){return Pointer_stringify}).returnValue;funcstr+="ret = "+strgfy+"(ret);"}return numericArgs||(funcstr+=JSsource.stackRestore.body.replace("()","(stack)")+";"),funcstr+="return ret})",eval(funcstr)}}(),Module.cwrap=cwrap,Module.ccall=ccall,Module.setValue=setValue,Module.getValue=getValue;var ALLOC_NORMAL=0,ALLOC_STACK=1,ALLOC_STATIC=2,ALLOC_DYNAMIC=3,ALLOC_NONE=4;Module.ALLOC_NORMAL=ALLOC_NORMAL,Module.ALLOC_STACK=ALLOC_STACK,Module.ALLOC_STATIC=ALLOC_STATIC,Module.ALLOC_DYNAMIC=ALLOC_DYNAMIC,Module.ALLOC_NONE=ALLOC_NONE,Module.allocate=allocate,Module.Pointer_stringify=Pointer_stringify,Module.UTF16ToString=UTF16ToString,Module.stringToUTF16=stringToUTF16,Module.UTF32ToString=UTF32ToString,Module.stringToUTF32=stringToUTF32,Module.stackTrace=stackTrace;for(var PAGE_SIZE=4096,HEAP,HEAP8,HEAPU8,HEAP16,HEAPU16,HEAP32,HEAPU32,HEAPF32,HEAPF64,STATIC_BASE=0,STATICTOP=0,staticSealed=!1,STACK_BASE=0,STACKTOP=0,STACK_MAX=0,DYNAMIC_BASE=0,DYNAMICTOP=0,TOTAL_STACK=Module.TOTAL_STACK||5242880,TOTAL_MEMORY=Module.TOTAL_MEMORY||16777216,FAST_MEMORY=Module.FAST_MEMORY||2097152,totalMemory=65536;totalMemory<TOTAL_MEMORY||totalMemory<2*TOTAL_STACK;)totalMemory<16777216?totalMemory*=2:totalMemory+=16777216;totalMemory!==TOTAL_MEMORY&&(Module.printErr("increasing TOTAL_MEMORY to "+totalMemory+" to be compliant with the asm.js spec"),TOTAL_MEMORY=totalMemory),assert("undefined"!=typeof Int32Array&&"undefined"!=typeof Float64Array&&!!new Int32Array(1).subarray&&!!new Int32Array(1).set,"JS engine does not provide full typed array support");var buffer=new ArrayBuffer(TOTAL_MEMORY);HEAP8=new Int8Array(buffer),HEAP16=new Int16Array(buffer),HEAP32=new Int32Array(buffer),HEAPU8=new Uint8Array(buffer),HEAPU16=new Uint16Array(buffer),HEAPU32=new Uint32Array(buffer),HEAPF32=new Float32Array(buffer),HEAPF64=new Float64Array(buffer),HEAP32[0]=255,assert(255===HEAPU8[0]&&0===HEAPU8[3],"Typed arrays 2 must be run on a little-endian system"),Module.HEAP=HEAP,Module.buffer=buffer,Module.HEAP8=HEAP8,Module.HEAP16=HEAP16,Module.HEAP32=HEAP32,Module.HEAPU8=HEAPU8,Module.HEAPU16=HEAPU16,Module.HEAPU32=HEAPU32,Module.HEAPF32=HEAPF32,Module.HEAPF64=HEAPF64;var __ATPRERUN__=[],__ATINIT__=[],__ATMAIN__=[],__ATEXIT__=[],__ATPOSTRUN__=[],runtimeInitialized=!1,runtimeExited=!1;Module.addOnPreRun=Module.addOnPreRun=addOnPreRun,Module.addOnInit=Module.addOnInit=addOnInit,Module.addOnPreMain=Module.addOnPreMain=addOnPreMain,Module.addOnExit=Module.addOnExit=addOnExit,Module.addOnPostRun=Module.addOnPostRun=addOnPostRun,Module.intArrayFromString=intArrayFromString,Module.intArrayToString=intArrayToString,Module.writeStringToMemory=writeStringToMemory,Module.writeArrayToMemory=writeArrayToMemory,Module.writeAsciiToMemory=writeAsciiToMemory,Math.imul&&Math.imul(4294967295,5)===-5||(Math.imul=function(e,i){var r=e>>>16,n=65535&e,f=i>>>16,t=65535&i;return n*t+(r*t+n*f<<16)|0}),Math.imul=Math.imul;var Math_abs=Math.abs,Math_cos=Math.cos,Math_sin=Math.sin,Math_tan=Math.tan,Math_acos=Math.acos,Math_asin=Math.asin,Math_atan=Math.atan,Math_atan2=Math.atan2,Math_exp=Math.exp,Math_log=Math.log,Math_sqrt=Math.sqrt,Math_ceil=Math.ceil,Math_floor=Math.floor,Math_pow=Math.pow,Math_imul=Math.imul,Math_fround=Math.fround,Math_min=Math.min,runDependencies=0,runDependencyWatcher=null,dependenciesFulfilled=null;Module.addRunDependency=addRunDependency,Module.removeRunDependency=removeRunDependency,Module.preloadedImages={},Module.preloadedAudios={};var memoryInitializer=null;STATIC_BASE=8,STATICTOP=STATIC_BASE+329776,__ATINIT__.push(),allocate([1,0,0,0,2,0,0,0,3,0,0,0,4,0,0,0,5,0,0,0,6,0,0,0,7,0,0,0,8,0,0,0,9,0,0,0,10,0,0,0,11,0,0,0,12,0,0,0,13,0,0,0,14,0,0,0,15,0,0,0,16,0,0,0,17,0,0,0,18,0,0,0,19,0,0,0,20,0,0,0,21,0,0,0,22,0,0,0,23,0,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,45,0,0,0,0,0,0,0,45,100,101,98,117,103,0,0,45,45,100,101,98,117,103,0,0,0,0,0,0,0,0,0,45,115,104,101,108,108,0,0,45,45,115,104,101,108,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,45,99,111,112,121,0,0,0,45,45,99,111,112,121,0,0,0,0,0,0,0,0,0,0,45,114,101,99,111,118,101,114,0,0,0,0,0,0,0,0,45,45,114,101,99,111,118,101,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,65,0,0,0,0,0,45,104,117,103,101,0,0,0,45,45,104,117,103,101,0,0,45,110,111,101,110,116,0,0,45,45,110,111,101,110,116,0,0,0,0,0,0,0,0,0,45,110,111,101,110,99,0,0,45,45,110,111,101,110,99,0,0,0,0,0,0,0,0,0,45,110,115,99,108,101,97,110,0,0,0,0,0,0,0,0,45,45,110,115,99,108,101,97,110,0,0,0,0,0,0,0,45,110,111,99,100,97,116,97,0,0,0,0,0,0,0,0,45,45,110,111,99,100,97,116,97,0,0,0,0,0,0,0,45,110,111,100,105,99,116,0,45,45,110,111,100,105,99,116,0,0,0,0,0,0,0,0,45,118,101,114,115,105,111,110,0,0,0,0,0,0,0,0,45,45,118,101,114,115,105,111,110,0,0,0,0,0,0,0,45,110,111,111,117,116,0,0,45,45,110,111,111,117,116,0,45,111,0,0,0,0,0,0,45,111,117,116,112,117,116,0,45,45,111,117,116,112,117,116,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,45,104,116,109,108,111,117,116,0,0,0,0,0,0,0,0,45,45,104,116,109,108,111,117,116,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,45,110,111,119,114,97,112,0,45,45,110,111,119,114,97,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,45,104,116,109,108,0,0,0,45,45,104,116,109,108,0,0,0,0,0,0,0,0,0,0,45,120,109,108,111,117,116,0,45,45,120,109,108,111,117,116,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,45,110,111,100,101,102,100,116,100,0,0,0,0,0,0,0,45,45,110,111,100,101,102,100,116,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,45,108,111,97,100,100,116,100,0,0,0,0,0,0,0,0,45,45,108,111,97,100,100,116,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,45,100,116,100,97,116,116,114,0,0,0,0,0,0,0,0,45,45,100,116,100,97,116,116,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,45,118,97,108,105,100,0,0,45,45,118,97,108,105,100,0,0,0,0,0,0,0,0,0,45,112,111,115,116,118,97,108,105,100,0,0,0,0,0,0,45,45,112,111,115,116,118,97,108,105,100,0,0,0,0,0,0,0,0,0,0,0,0,0,45,100,116,100,118,97,108,105,100,0,0,0,0,0,0,0,45,45,100,116,100,118,97,108,105,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,45,100,116,100,118,97,108,105,100,102,112,105,0,0,0,0,45,45,100,116,100,118,97,108,105,100,102,112,105,0,0,0,0,0,0,0,0,0,0,0,45,100,114,111,112,100,116,100,0,0,0,0,0,0,0,0,45,45,100,114,111,112,100,116,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,45,105,110,115,101,114,116,0,45,45,105,110,115,101,114,116,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,45,116,105,109,105,110,103,0,45,45,116,105,109,105,110,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,45,97,117,116,111,0,0,0,45,45,97,117,116,111,0,0,0,0,0,0,0,0,0,0,45,114,101,112,101,97,116,0,45,45,114,101,112,101,97,116,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,45,112,117,115,104,0,0,0,45,45,112,117,115,104,0,0,0,0,0,0,0,0,0,0,45,112,117,115,104,115,109,97,108,108,0,0,0,0,0,0,45,45,112,117,115,104,115,109,97,108,108,0,0,0,0,0,0,16,0,0,0,0,0,0,45,109,101,109,111,114,121,0,45,45,109,101,109,111,114,121,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,45,116,101,115,116,73,79,0,45,45,116,101,115,116,73,79,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,45,120,105,110,99,108,117,100,101,0,0,0,0,0,0,0,45,45,120,105,110,99,108,117,100,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,45,110,111,120,105,110,99,108,117,100,101,110,111,100,101,0,45,45,110,111,120,105,110,99,108,117,100,101,110,111,100,101,0,0,0,0,0,0,0,0,45,110,111,102,105,120,117,112,45,98,97,115,101,45,117,114,105,115,0,0,0,0,0,0,45,45,110,111,102,105,120,117,112,45,98,97,115,101,45,117,114,105,115,0,0,0,0,0,45,110,111,119,97,114,110,105,110,103,0,0,0,0,0,0,45,45,110,111,119,97,114,110,105,110,103,0,0,0,0,0,45,112,101,100,97,110,116,105,99,0,0,0,0,0,0,0,45,45,112,101,100,97,110,116,105,99,0,0,0,0,0,0,45,100,101,98,117,103,101,110,116,0,0,0,0,0,0,0,45,45,100,101,98,117,103,101,110,116,0,0,0,0,0,0,0,0,0,0,0,0,0,0,45,99,49,52,110,0,0,0,45,45,99,49,52,110,0,0,0,0,0,0,0,0,0,0,45,99,49,52,110,49,49,0,45,45,99,49,52,110,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,45,101,120,99,45,99,49,52,110,0,0,0,0,0,0,0,45,45,101,120,99,45,99,49,52,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,45,99,97,116,97,108,111,103,115,0,0,0,0,0,0,0,45,45,99,97,116,97,108,111,103,115,0,0,0,0,0,0,0,0,0,0,0,0,0,0,45,110,111,99,97,116,97,108,111,103,115,0,0,0,0,0,45,45,110,111,99,97,116,97,108,111,103,115,0,0,0,0,0,0,0,0,0,0,0,0,45,101,110,99,111,100,101,0,45,45,101,110,99,111,100,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,85,84,70,45,56,0,0,0,68,86,69,110,99,0,0,0,45,110,111,98,108,97,110,107,115,0,0,0,0,0,0,0,45,45,110,111,98,108,97,110,107,115,0,0,0,0,0,0,0,0,0,0,0,0,0,0,45,109,97,120,109,101,109,0,45,45,109,97,120,109,101,109,0,0,0,0,0,0,0,0,37,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,45,102,111,114,109,97,116,0,45,45,102,111,114,109,97,116,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,45,112,114,101,116,116,121,0,45,45,112,114,101,116,116,121,0,0,0,0,0,0,0,0,45,115,116,114,101,97,109,0,45,45,115,116,114,101,97,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,45,119,97,108,107,101,114,0,45,45,119,97,108,107,101,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,45,115,97,120,49,0,0,0,45,45,115,97,120,49,0,0,0,0,0,0,0,0,0,0,45,115,97,120,0,0,0,0,45,45,115,97,120,0,0,0,0,0,0,0,0,0,0,0,45,99,104,107,114,101,103,105,115,116,101,114,0,0,0,0,45,45,99,104,107,114,101,103,105,115,116,101,114,0,0,0,0,0,0,0,0,0,0,0,45,114,101,108,97,120,110,103,0,0,0,0,0,0,0,0,45,45,114,101,108,97,120,110,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,45,115,99,104,101,109,97,0,45,45,115,99,104,101,109,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,45,115,99,104,101,109,97,116,114,111,110,0,0,0,0,0,45,45,115,99,104,101,109,97,116,114,111,110,0,0,0,0,0,0,0,0,0,0,0,0,45,110,111,110,101,116,0,0,45,45,110,111,110,101,116,0,45,110,111,99,111,109,112,97,99,116,0,0,0,0,0,0,45,45,110,111,99,111,109,112,97,99,116,0,0,0,0,0,45,108,111,97,100,45,116,114,97,99,101,0,0,0,0,0,45,45,108,111,97,100,45,116,114,97,99,101,0,0,0,0,0,0,0,0,0,0,0,0,45,112,97,116,104,0,0,0,45,45,112,97,116,104,0,0,45,112,97,116,116,101,114,110,0,0,0,0,0,0,0,0,45,45,112,97,116,116,101,114,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,45,120,112,97,116,104,0,0,45,45,120,112,97,116,104,0,0,0,0,0,0,0,0,0,45,111,108,100,120,109,108,49,48,0,0,0,0,0,0,0,45,45,111,108,100,120,109,108,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,85,110,107,110,111,119,110,32,111,112,116,105,111,110,32,37,115,10,0,0,0,0,0,0,83,71,77,76,95,67,65,84,65,76,79,71,95,70,73,76,69,83,0,0,0,0,0,0,86,97,114,105,97,98,108,101,32,36,83,71,77,76,95,67,65,84,65,76,79,71,95,70,73,76,69,83,32,110,111,116,32,115,101,116,10,0,0,0,88,77,76,76,73,78,84,95,73,78,68,69,78,84,0,0,0,0,0,0,0,0,0,0,60,33,68,79,67,84,89,80,69,32,72,84,77,76,32,80,85,66,76,73,67,32,34,45,47,47,87,51,67,47,47,68,84,68,32,72,84,77,76,32,52,46,48,32,84,114,97,110,115,105,116,105,111,110,97,108,47,47,69,78,34,10,0,0,9,34,104,116,116,112,58,47,47,119,119,119,46,119,51,46,111,114,103,47,84,82,47,82,69,67,45,104,116,109,108,52,48,47,108,111,111,115,101,46,100,116,100,34,62,10,0,0,60,104,116,109,108,62,60,104,101,97,100,62,60,116,105,116,108,101,62,37,115,32,111,117,116,112,117,116,60,47,116,105,116,108,101,62,60,47,104,101,97,100,62,10,0,0,0,0,60,98,111,100,121,32,98,103,99,111,108,111,114,61,34,35,102,102,102,102,102,102,34,62,60,104,49,32,97,108,105,103,110,61,34,99,101,110,116,101,114,34,62,37,115,32,111,117,116,112,117,116,60,47,104,49,62,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,83,99,104,101,109,97,116,114,111,110,32,115,99,104,101,109,97,32,37,115,32,102,97,105,108,101,100,32,116,111,32,99,111,109,112,105,108,101,10,0,0,0,0,0,0,0,0,0,67,111,109,112,105,108,105,110,103,32,116,104,101,32,115,99,104,101,109,97,115,0,0,0,0,0,0,0,0,0,0,0,82,101,108,97,120,45,78,71,32,115,99,104,101,109,97,32,37,115,32,102,97,105,108,101,100,32,116,111,32,99,111,109,112,105,108,101,10,0,0,0,0,0,0,0,0,0,0,0,87,88,83,32,115,99,104,101,109,97,32,37,115,32,102,97,105,108,101,100,32,116,111,32,99,111,109,112,105,108,101,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,97,116,116,101,114,110,32,37,115,32,102,97,105,108,101,100,32,116,111,32,99,111,109,112,105,108,101,10,0,0,0,0,0,0,0,0,0,0,0,82,101,103,105,115,116,114,97,116,105,111,110,32,99,111,117,110,116,32,111,102,102,58,32,37,100,10,0,0,0,0,0,37,100,32,105,116,101,114,97,116,105,111,110,115,0,0,0,60,47,98,111,100,121,62,60,47,104,116,109,108,62,10,0,49,46,48,0,0,0,0,0,105,110,102,111,0,0,0,0,97,98,99,0,0,0,0,0,114,0,0,0,0,0,0,0,109,109,97,112,32,102,97,105,108,117,114,101,32,102,111,114,32,102,105,108,101,32,37,115,10,0,0,0,0,0,0,0,80,97,114,115,105,110,103,0,88,105,110,99,108,117,100,101,32,112,114,111,99,101,115,115,105,110,103,0,0,0,0,0,67,111,112,121,105,110,103,0,70,114,101,101,105,110,103,32,111,114,105,103,105,110,97,108,0,0,0,0,0,0,0,0,99,111,117,108,100,32,110,111,116,32,103,101,116,32,118,97,108,105,100,32,108,105,115,116,32,111,102,32,101,108,101,109,101,110,116,115,10,0,0,0,78,111,32,101,108,101,109,101,110,116,32,99,97,110,32,98,101,32,105,110,115,101,114,116,101,100,32,117,110,100,101,114,32,114,111,111,116,10,0,0,37,100,32,101,108,101,109,101,110,116,32,116,121,112,101,115,32,99,97,110,32,98,101,32,105,110,115,101,114,116,101,100,32,117,110,100,101,114,32,114,111,111,116,58,10,0,0,0,37,115,10,0,0,0,0,0,0,0,0,0,0,0,0,0,119,98,0,0,0,0,0,0,102,97,105,108,101,100,32,116,111,32,111,112,101,110,32,37,115,10,0,0,0,0,0,0,83,97,118,105,110,103,0,0,67,97,110,39,116,32,119,114,105,116,101,32,100,97,116,97,10,0,0,0,0,0,0,0,70,97,105,108,101,100,32,116,111,32,99,97,110,111,110,105,99,97,108,105,122,101,10,0,70,97,105,108,101,100,32,116,111,32,115,97,118,101,10,0,0,0,0,0,0,0,0,0,102,97,105,108,101,100,32,115,97,118,101,32,116,111,32,37,115,10,0,0,0,0,0,0,80,97,114,115,105,110,103,32,68,84,68,0,0,0,0,0,67,111,117,108,100,32,110,111,116,32,112,97,114,115,101,32,68,84,68,32,37,115,10,0,67,111,117,108,100,110,39,116,32,97,108,108,111,99,97,116,101,32,118,97,108,105,100,97,116,105,111,110,32,99,111,110,116,101,120,116,10,0,0,0,68,111,99,117,109,101,110,116,32,37,115,32,100,111,101,115,32,110,111,116,32,118,97,108,105,100,97,116,101,32,97,103,97,105,110,115,116,32,37,115,10,0,0,0,0,0,0,0,86,97,108,105,100,97,116,105,110,103,32,97,103,97,105,110,115,116,32,68,84,68,0,0,68,111,99,117,109,101,110,116,32,37,115,32,100,111,101,115,32,110,111,116,32,118,97,108,105,100,97,116,101,10,0,0,86,97,108,105,100,97,116,105,110,103,0,0,0,0,0,0,37,115,32,118,97,108,105,100,97,116,101,115,10,0,0,0,37,115,32,102,97,105,108,115,32,116,111,32,118,97,108,105,100,97,116,101,10,0,0,0,37,115,32,118,97,108,105,100,97,116,105,111,110,32,103,101,110,101,114,97,116,101,100,32,97,110,32,105,110,116,101,114,110,97,108,32,101,114,114,111,114,10,0,0,0,0,0,0,70,114,101,101,105,110,103,0,0,0,0,0,0,0,0,0,120,109,108,83,116,114,101,97,109,80,117,115,104,40,41,32,102,97,105,108,117,114,101,10,0,0,0,0,0,0,0,0,119,97,108,107,105,110,103,32,116,104,114,111,117,103,104,32,116,104,101,32,100,111,99,0,102,97,105,108,101,100,32,116,111,32,119,97,108,107,32,116,104,114,111,117,103,104,32,116,104,101,32,100,111,99,10,0,70,97,105,108,101,100,32,116,111,32,99,114,97,116,101,32,97,32,114,101,97,100,101,114,32,102,114,111,109,32,116,104,101,32,100,111,99,117,109,101,110,116,10,0,0,0,0,0,45,45,0,0,0,0,0,0,37,100,32,37,100,32,37,115,32,37,100,32,37,100,0,0,10,0,0,0,0,0,0,0,32,37,115,10,0,0,0,0,78,111,100,101,32,37,115,32,109,97,116,99,104,101,115,32,112,97,116,116,101,114,110,32,37,115,10,0,0,0,0,0,120,109,108,80,97,116,116,101,114,110,77,97,116,99,104,32,97,110,100,32,120,109,108,83,116,114,101,97,109,80,117,115,104,32,100,105,115,97,103,114,101,101,10,0,0,0,0,0,32,32,112,97,116,116,101,114,110,32,37,115,32,110,111,100,101,32,37,115,10,0,0,0,120,109,108,83,116,114,101,97,109,80,111,112,40,41,32,102,97,105,108,117,114,101,10,0,37,115,0,0,0,0,0,0,79,117,116,32,111,102,32,109,101,109,111,114,121,32,102,111,114,32,88,80,97,116,104,10,0,0,0,0,0,0,0,0,88,80,97,116,104,32,101,118,97,108,117,97,116,105,111,110,32,102,97,105,108,117,114,101,10,0,0,0,0,0,0,0,88,80,97,116,104,32,115,101,116,32,105,115,32,101,109,112,116,121,10,0,0,0,0,0,116,114,117,101,0,0,0,0,102,97,108,115,101,0,0,0,73,110,102,105,110,105,116,121,0,0,0,0,0,0,0,0,45,73,110,102,105,110,105,116,121,0,0,0,0,0,0,0,78,97,78,0,0,0,0,0,37,48,103,0,0,0,0,0,88,80,97,116,104,32,79,98,106,101,99,116,32,105,115,32,117,110,105,110,105,116,105,97,108,105,122,101,100,10,0,0,88,80,97,116,104,32,111,98,106,101,99,116,32,111,102,32,117,110,101,120,112,101,99,116,101,100,32,116,121,112,101,10],"i8",ALLOC_NONE,Runtime.GLOBAL_BASE),allocate([60,98,62,118,97,108,105,100,105,116,121,32,119,97,114,110,105,110,103,60,47,98,62,58,32,0,0,0,0,0,0,0,60,47,112,62,10,0,0,0,60,112,114,101,62,10,0,0,37,99,0,0,0,0,0,0,32,0,0,0,0,0,0,0,94,10,0,0,0,0,0,0,60,47,112,114,101,62,0,0,60,112,62,0,0,0,0,0,37,115,58,37,100,58,32,0,69,110,116,105,116,121,58,32,108,105,110,101,32,37,100,58,32,0,0,0,0,0,0,0,60,98,62,118,97,108,105,100,105,116,121,32,101,114,114,111,114,60,47,98,62,58,32,0,60,98,62,119,97,114,110,105,110,103,60,47,98,62,58,32,0,0,0,0,0,0,0,0,60,98,62,101,114,114,111,114,60,47,98,62,58,32,0,0,117,115,101,114,95,100,97,116,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,217,0,0,0,0,0,0,112,212,0,0,0,0,0,0,83,65,88,32,103,101,110,101,114,97,116,101,100,32,97,32,100,111,99,32,33,10,0,0,1,0,0,0,2,0,0,0,3,0,0,0,4,0,0,0,5,0,0,0,6,0,0,0,7,0,0,0,8,0,0,0,9,0,0,0,10,0,0,0,11,0,0,0,12,0,0,0,13,0,0,0,14,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,18,0,0,0,19,0,0,0,20,0,0,0,21,0,0,0,22,0,0,0,23,0,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,175,190,237,222,0,0,0,0,28,0,0,0,29,0,0,0,0,0,0,0,83,65,88,46,101,110,100,69,108,101,109,101,110,116,78,115,40,37,115,0,0,0,0,0,44,32,78,85,76,76,0,0,44,32,37,115,0,0,0,0,44,32,78,85,76,76,41,10,0,0,0,0,0,0,0,0,44,32,39,37,115,39,41,10,0,0,0,0,0,0,0,0,83,65,88,46,115,116,97,114,116,69,108,101,109,101,110,116,78,115,40,37,115,0,0,0,44,32,39,37,115,39,0,0,44,32,37,100,0,0,0,0,44,32,120,109,108,110,115,0,58,37,115,0,0,0,0,0,61,39,37,115,39,0,0,0,44,32,37,100,44,32,37,100,0,0,0,0,0,0,0,0,44,32,37,115,58,37,115,61,39,0,0,0,0,0,0,0,44,32,37,115,61,39,0,0,37,46,52,115,46,46,46,39,44,32,37,100,0,0,0,0,41,10,0,0,0,0,0,0,83,65,88,46,101,120,116,101,114,110,97,108,83,117,98,115,101,116,40,37,115,44,0,0,32,44,0,0,0,0,0,0,32,37,115,44,0,0,0,0,32,41,10,0,0,0,0,0,32,37,115,41,10,0,0,0,83,65,88,46,112,99,100,97,116,97,40,37,46,50,48,115,44,32,37,100,41,10,0,0,83,65,88,46,103,101,116,80,97,114,97,109,101,116,101,114,69,110,116,105,116,121,40,37,115,41,10,0,0,0,0,0,83,65,88,46,102,97,116,97,108,69,114,114,111,114,58,32,0,0,0,0,0,0,0,0,83,65,88,46,101,114,114,111,114,58,32,0,0,0,0,0,83,65,88,46,119,97,114,110,105,110,103,58,32,0,0,0,83,65,88,46,99,111,109,109,101,110,116,40,37,115,41,10,0,0,0,0,0,0,0,0,83,65,88,46,112,114,111,99,101,115,115,105,110,103,73,110,115,116,114,117,99,116,105,111,110,40,37,115,44,32,37,115,41,10,0,0,0,0,0,0,83,65,88,46,112,114,111,99,101,115,115,105,110,103,73,110,115,116,114,117,99,116,105,111,110,40,37,115,44,32,78,85,76,76,41,10,0,0,0,0,83,65,88,46,105,103,110,111,114,97,98,108,101,87,104,105,116,101,115,112,97,99,101,40,37,115,44,32,37,100,41,10,0,0,0,0,0,0,0,0,83,65,88,46,99,104,97,114,97,99,116,101,114,115,40,37,115,44,32,37,100,41,10,0,83,65,88,46,114,101,102,101,114,101,110,99,101,40,37,115,41,10,0,0,0,0,0,0,83,65,88,46,101,110,100,68,111,99,117,109,101,110,116,40,41,10,0,0,0,0,0,0,83,65,88,46,115,116,97,114,116,68,111,99,117,109,101,110,116,40,41,10,0,0,0,0,83,65,88,46,115,101,116,68,111,99,117,109,101,110,116,76,111,99,97,116,111,114,40,41,10,0,0,0,0,0,0,0,40,110,117,108,108,41,0,0,83,65,88,46,117,110,112,97,114,115,101,100,69,110,116,105,116,121,68,101,99,108,40,37,115,44,32,37,115,44,32,37,115,44,32,37,115,41,10,0,83,65,88,46,101,108,101,109,101,110,116,68,101,99,108,40,37,115,44,32,37,100,44,32,46,46,46,41,10,0,0,0,83,65,88,46,97,116,116,114,105,98,117,116,101,68,101,99,108,40,37,115,44,32,37,115,44,32,37,100,44,32,37,100,44,32,78,85,76,76,44,32,46,46,46,41,10,0,0,0,83,65,88,46,97,116,116,114,105,98,117,116,101,68,101,99,108,40,37,115,44,32,37,115,44,32,37,100,44,32,37,100,44,32,37,115,44,32,46,46,46,41,10,0,0,0,0,0,83,65,88,46,110,111,116,97,116,105,111,110,68,101,99,108,40,37,115,44,32,37,115,44,32,37,115,41,10,0,0,0,83,65,88,46,101,110,116,105,116,121,68,101,99,108,40,37,115,44,32,37,100,44,32,37,115,44,32,37,115,44,32,37,115,41,10,0,0,0,0,0,83,65,88,46,103,101,116,69,110,116,105,116,121,40,37,115,41,10,0,0,0,0,0,0,83,65,88,46,114,101,115,111,108,118,101,69,110,116,105,116,121,40,0,0,0,0,0,0,44,32,37,115,41,10,0,0,44,32,41,10,0,0,0,0,83,65,88,46,104,97,115,69,120,116,101,114,110,97,108,83,117,98,115,101,116,40,41,10,0,0,0,0,0,0,0,0,83,65,88,46,104,97,115,73,110,116,101,114,110,97,108,83,117,98,115,101,116,40,41,10,0,0,0,0,0,0,0,0,83,65,88,46,105,115,83,116,97,110,100,97,108,111,110,101,40,41,10,0,0,0,0,0,83,65,88,46,105,110,116,101,114,110,97,108,83,117,98,115,101,116,40,37,115,44,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,175,190,237,222,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,88,83,68,32,115,99,104,101,109,97,32,37,115,32,102,97,105,108,101,100,32,116,111,32,99,111,109,112,105,108,101,10,0,0,0,0,0,0,0,0,80,97,114,115,105,110,103,32,97,110,100,32,118,97,108,105,100,97,116,105,110,103,0,0,37,115,32,58,32,102,97,105,108,101,100,32,116,111,32,112,97,114,115,101,10,0,0,0,85,110,97,98,108,101,32,116,111,32,111,112,101,110,32,37,115,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,116,111,111,107,32,37,108,100,32,109,115,10,0,0,0,0,0,0,0,0,0,0,0,76,111,97,100,101,100,32,85,82,76,61,34,37,115,34,32,73,68,61,34,37,115,34,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,47,0,0,0,0,0,0,0,102,97,105,108,101,100,32,116,111,32,108,111,97,100,32,101,120,116,101,114,110,97,108,32,101,110,116,105,116,121,32,34,37,115,34,10,0,0,0,0,110,111,100,101,45,62,95,112,114,105,118,97,116,101,32,33,61,32,78,85,76,76,0,0,46,46,47,108,105,98,120,109,108,50,47,120,109,108,108,105,110,116,46,99,0,0,0,0,100,101,114,101,103,105,115,116,101,114,78,111,100,101,0,0,42,40,108,111,110,103,42,41,110,111,100,101,45,62,95,112,114,105,118,97,116,101,32,61,61,32,40,108,111,110,103,41,32,48,120,56,49,55,50,54,51,53,52,0,0,0,0,0,79,117,116,32,111,102,32,109,101,109,111,114,121,32,105,110,32,120,109,108,108,105,110,116,58,114,101,103,105,115,116,101,114,78,111,100,101,40,41,10,0,0,0,0,0,0,0,0,77,65,88,95,80,65,84,72,83,32,114,101,97,99,104,101,100,58,32,116,111,111,32,109,97,110,121,32,112,97,116,104,115,10,0,0,0,0,0,0,82,97,110,32,111,117,116,32,111,102,32,109,101,109,111,114,121,32,110,101,101,100,115,32,62,32,37,100,32,98,121,116,101,115,10,0,0,0,0,0,37,115,58,32,117,115,105,110,103,32,108,105,98,120,109,108,32,118,101,114,115,105,111,110,32,37,115,10,0,0,0,0,32,32,32,99,111,109,112,105,108,101,100,32,119,105,116,104,58,32,0,0,0,0,0,0,84,104,114,101,97,100,115,32,0,0,0,0,0,0,0,0,84,114,101,101,32,0,0,0,79,117,116,112,117,116,32,0,80,117,115,104,32,0,0,0,82,101,97,100,101,114,32,0,80,97,116,116,101,114,110,115,32,0,0,0,0,0,0,0,87,114,105,116,101,114,32,0,83,65,88,118,49,32,0,0,70,84,80,32,0,0,0,0,72,84,84,80,32,0,0,0,68,84,68,86,97,108,105,100,32,0,0,0,0,0,0,0,72,84,77,76,32,0,0,0,76,101,103,97,99,121,32,0,67,49,52,78,32,0,0,0,67,97,116,97,108,111,103,32,0,0,0,0,0,0,0,0,88,80,97,116,104,32,0,0,88,80,111,105,110,116,101,114,32,0,0,0,0,0,0,0,88,73,110,99,108,117,100,101,32,0,0,0,0,0,0,0,73,99,111,110,118,32,0,0,73,83,79,56,56,53,57,88,32,0,0,0,0,0,0,0,85,110,105,99,111,100,101,32,0,0,0,0,0,0,0,0,82,101,103,101,120,112,115,32,0,0,0,0,0,0,0,0,65,117,116,111,109,97,116,97,32,0,0,0,0,0,0,0,69,120,112,114,32,0,0,0,83,99,104,101,109,97,115,32,0,0,0,0,0,0,0,0,83,99,104,101,109,97,116,114,111,110,32,0,0,0,0,0,77,111,100,117,108,101,115,32,0,0,0,0,0,0,0,0,68,101,98,117,103,32,0,0,77,101,109,68,101,98,117,103,32,0,0,0,0,0,0,0,82,117,110,68,101,98,117,103,32,0,0,0,0,0,0,0,90,108,105,98,32,0,0,0,76,122,109,97,32,0,0,0,85,115,97,103,101,32,58,32,37,115,32,91,111,112,116,105,111,110,115,93,32,88,77,76,102,105,108,101,115,32,46,46,46,10,0,0,0,0,0,0,9,80,97,114,115,101,32,116,104,101,32,88,77,76,32,102,105,108,101,115,32,97,110,100,32,111,117,116,112,117,116,32,116,104,101,32,114,101,115,117,108,116,32,111,102,32,116,104,101,32,112,97,114,115,105,110,103,10,0,0,0,0,0,0,9,45,45,118,101,114,115,105,111,110,32,58,32,100,105,115,112,108,97,121,32,116,104,101,32,118,101,114,115,105,111,110,32,111,102,32,116,104,101,32,88,77,76,32,108,105,98,114,97,114,121,32,117,115,101,100,10,0,0,0,0,0,0,0,9,45,45,100,101,98,117,103,32,58,32,100,117,109,112,32,97,32,100,101,98,117,103,32,116,114,101,101,32,111,102,32,116,104,101,32,105,110,45,109,101,109,111,114,121,32,100,111,99,117,109,101,110,116,10,0,9,45,45,115,104,101,108,108,32,58,32,114,117,110,32,97,32,110,97,118,105,103,97,116,105,110,103,32,115,104,101,108,108,10,0,0,0,0,0,0,9,45,45,100,101,98,117,103,101,110,116,32,58,32,100,101,98,117,103,32,116,104,101,32,101,110,116,105,116,105,101,115,32,100,101,102,105,110,101,100,32,105,110,32,116,104,101,32,100,111,99,117,109,101,110,116,10,0,0,0,0,0,0,0,9,45,45,99,111,112,121,32,58,32,117,115,101,100,32,116,111,32,116,101,115,116,32,116,104,101,32,105,110,116,101,114,110,97,108,32,99,111,112,121,32,105,109,112,108,101,109,101,110,116,97,116,105,111,110,10,0,0,0,0,0,0,0,0,9,45,45,114,101,99,111,118,101,114,32,58,32,111,117,116,112,117,116,32,119,104,97,116,32,119,97,115,32,112,97,114,115,97,98,108,101,32,111,110,32,98,114,111,107,101,110,32,88,77,76,32,100,111,99,117,109,101,110,116,115,10,0,0,9,45,45,104,117,103,101,32,58,32,114,101,109,111,118,101,32,97,110,121,32,105,110,116,101,114,110,97,108,32,97,114,98,105,116,114,97,114,121,32,112,97,114,115,101,114,32,108,105,109,105,116,115,10,0,0,9,45,45,110,111,101,110,116,32,58,32,115,117,98,115,116,105,116,117,116,101,32,101,110,116,105,116,121,32,114,101,102,101,114,101,110,99,101,115,32,98,121,32,116,104,101,105,114,32,118,97,108,117,101,10,0,9,45,45,110,111,101,110,99,32,58,32,105,103,110,111,114,101,32,97,110,121,32,101,110,99,111,100,105,110,103,32,115,112,101,99,105,102,105,101,100,32,105,110,115,105,100,101,32,116,104,101,32,100,111,99,117,109,101,110,116,10,0,0,0,9,45,45,110,111,111,117,116,32,58,32,100,111,110,39,116,32,111,117,116,112,117,116,32,116,104,101,32,114,101,115,117,108,116,32,116,114,101,101,10,0,0,0,0,0,0,0,0,9,45,45,112,97,116,104,32,39,112,97,116,104,115,39,58,32,112,114,111,118,105,100,101,32,97,32,115,101,116,32,111,102,32,112,97,116,104,115,32,102,111,114,32,114,101,115,111,117,114,99,101,115,10,0,0,9,45,45,108,111,97,100,45,116,114,97,99,101,32,58,32,112,114,105,110,116,32,116,114,97,99,101,32,111,102,32,97,108,108,32,101,120,116,101,114,110,97,108,32,101,110,116,105,116,105,101,115,32,108,111,97,100,101,100,10,0,0,0,0,9,45,45,110,111,110,101,116,32,58,32,114,101,102,117,115,101,32,116,111,32,102,101,116,99,104,32,68,84,68,115,32,111,114,32,101,110,116,105,116,105,101,115,32,111,118,101,114,32,110,101,116,119,111,114,107,10,0,0,0,0,0,0,0,9,45,45,110,111,99,111,109,112,97,99,116,32,58,32,100,111,32,110,111,116,32,103,101,110,101,114,97,116,101,32,99,111,109,112,97,99,116,32,116,101,120,116,32,110,111,100,101,115,10,0,0,0,0,0,0,9,45,45,104,116,109,108,111,117,116,32,58,32,111,117,116,112,117,116,32,114,101,115,117,108,116,115,32,97,115,32,72,84,77,76,10,0,0,0,0,9,45,45,110,111,119,114,97,112,32,58,32,100,111,32,110,111,116,32,112,117,116,32,72,84,77,76,32,100,111,99,32,119,114,97,112,112,101,114,10,0,0,0,0,0,0,0,0,9,45,45,118,97,108,105,100,32,58,32,118,97,108,105,100,97,116,101,32,116,104,101,32,100,111,99,117,109,101,110,116,32,105,110,32,97,100,100,105,116,105,111,110,32,116,111,32,115,116,100,32,119,101,108,108,45,102,111,114,109,101,100,32,99,104,101,99,107,10,0,0,9,45,45,112,111,115,116,118,97,108,105,100,32,58,32,100,111,32,97,32,112,111,115,116,101,114,105,111,114,105,32,118,97,108,105,100,97,116,105,111,110,44,32,105,46,101,32,97,102,116,101,114,32,112,97,114,115,105,110,103,10,0,0,0,9,45,45,100,116,100,118,97,108,105,100,32,85,82,76,32,58,32,100,111,32,97,32,112,111,115,116,101,114,105,111,114,105,32,118,97,108,105,100,97,116,105,111,110,32,97,103,97,105,110,115,116,32,97,32,103,105,118,101,110,32,68,84,68,10,0,0,0,0,0,0,0,9,45,45,100,116,100,118,97,108,105,100,102,112,105,32,70,80,73,32,58,32,115,97,109,101,32,98,117,116,32,110,97,109,101,32,116,104,101,32,68,84,68,32,119,105,116,104,32,97,32,80,117,98,108,105,99,32,73,100,101,110,116,105,102,105,101,114,10,0,0,0,0,9,45,45,116,105,109,105,110,103,32,58,32,112,114,105,110,116,32,115,111,109,101,32,116,105,109,105,110,103,115,10,0,9,45,45,111,117,116,112,117,116,32,102,105,108,101,32,111,114,32,45,111,32,102,105,108,101,58,32,115,97,118,101,32,116,111,32,97,32,103,105,118,101,110,32,102,105,108,101,10,0,0,0,0,0,0,0,0,9,45,45,114,101,112,101,97,116,32,58,32,114,101,112,101,97,116,32,49,48,48,32,116,105,109,101,115,44,32,102,111,114,32,116,105,109,105,110,103,32,111,114,32,112,114,111,102,105,108,105,110,103,10,0,0,9,45,45,105,110,115,101,114,116,32,58,32,97,100,45,104,111,99,32,116,101,115,116,32,102,111,114,32,118,97,108,105,100,32,105,110,115,101,114,116,105,111,110,115,10,0,0,0,9,45,45,104,116,109,108,32,58,32,117,115,101,32,116,104,101,32,72,84,77,76,32,112,97,114,115,101,114,10,0,0,9,45,45,120,109,108,111,117,116,32,58,32,102,111,114,99,101,32,116,111,32,117,115,101,32,116,104,101,32,88,77,76,32,115,101,114,105,97,108,105,122,101,114,32,119,104,101,110,32,117,115,105,110,103,32,45,45,104,116,109,108,10,0,0,9,45,45,110,111,100,101,102,100,116,100,32,58,32,100,111,32,110,111,116,32,100,101,102,97,117,108,116,32,72,84,77,76,32,100,111,99,116,121,112,101,10,0,0,0,0,0,0,9,45,45,112,117,115,104,32,58,32,117,115,101,32,116,104,101,32,112,117,115,104,32,109,111,100,101,32,111,102,32,116,104,101,32,112,97,114,115,101,114,10,0,0,0,0,0,0,9,45,45,112,117,115,104,115,109,97,108,108,32,58,32,117,115,101,32,116,104,101,32,112,117,115,104,32,109,111,100,101,32,111,102,32,116,104,101,32,112,97,114,115,101,114,32,117,115,105,110,103,32,116,105,110,121,32,105,110,99,114,101,109,101,110,116,115,10,0,0,0,9,45,45,109,101,109,111,114,121,32,58,32,112,97,114,115,101,32,102,114,111,109,32,109,101,109,111,114,121,10,0,0,9,45,45,109,97,120,109,101,109,32,110,98,98,121,116,101,115,32,58,32,108,105,109,105,116,115,32,109,101,109,111,114,121,32,97,108,108,111,99,97,116,105,111,110,32,116,111,32,110,98,98,121,116,101,115,32,98,121,116,101,115,10,0,0,9,45,45,110,111,119,97,114,110,105,110,103,32,58,32,100,111,32,110,111,116,32,101,109,105,116,32,119,97,114,110,105,110,103,115,32,102,114,111,109,32,112,97,114,115,101,114,47,118,97,108,105,100,97,116,111,114,10,0,0,0,0,0,0,9,45,45,110,111,98,108,97,110,107,115,32,58,32,100,114,111,112,32,40,105,103,110,111,114,97,98,108,101,63,41,32,98,108,97,110,107,115,32,115,112,97,99,101,115,10,0,0,9,45,45,110,111,99,100,97,116,97,32,58,32,114,101,112,108,97,99,101,32,99,100,97,116,97,32,115,101,99,116,105,111,110,32,119,105,116,104,32,116,101,120,116,32,110,111,100,101,115,10,0,0,0,0,0,9,45,45,102,111,114,109,97,116,32,58,32,114,101,102,111,114,109,97,116,47,114,101,105,110,100,101,110,116,32,116,104,101,32,105,110,112,117,116,10,0,0,0,0,0,0,0,0,9,45,45,101,110,99,111,100,101,32,101,110,99,111,100,105,110,103,32,58,32,111,117,116,112,117,116,32,105,110,32,116,104,101,32,103,105,118,101,110,32,101,110,99,111,100,105,110,103,10,0,0,0,0,0,0,9,45,45,100,114,111,112,100,116,100,32,58,32,114,101,109,111,118,101,32,116,104,101,32,68,79,67,84,89,80,69,32,111,102,32,116,104,101,32,105,110,112,117,116,32,100,111,99,115,10,0,0,0,0,0,0,9,45,45,112,114,101,116,116,121,32,83,84,89,76,69,32,58,32,112,114,101,116,116,121,45,112,114,105,110,116,32,105,110,32,97,32,112,97,114,116,105,99,117,108,97,114,32,115,116,121,108,101,10,0,0,0,9,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,48,32,68,111,32,110,111,116,32,112,114,101,116,116,121,32,112,114,105,110,116,10,0,0,0,0,0,0,0,0,9,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,49,32,70,111,114,109,97,116,32,116,104,101,32,88,77,76,32,99,111,110,116,101,110,116,44,32,97,115,32,45,45,102,111,114,109,97,116,10,0,0,0,0,0,0,0,0,9,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,50,32,65,100,100,32,119,104,105,116,101,115,112,97,99,101,32,105,110,115,105,100,101,32,116,97,103,115,44,32,112,114,101,115,101,114,118,105,110,103,32,99,111,110,116,101,110,116,10,0,0,0,0,0,9,45,45,99,49,52,110,32,58,32,115,97,118,101,32,105,110,32,87,51,67,32,99,97,110,111,110,105,99,97,108,32,102,111,114,109,97,116,32,118,49,46,48,32,40,119,105,116,104,32,99,111,109,109,101,110,116,115,41,10,0,0,0,0,9,45,45,99,49,52,110,49,49,32,58,32,115,97,118,101,32,105,110,32,87,51,67,32,99,97,110,111,110,105,99,97,108,32,102,111,114,109,97,116,32,118,49,46,49,32,40,119,105,116,104,32,99,111,109,109,101,110,116,115,41,10,0,0,9,45,45,101,120,99,45,99,49,52,110,32,58,32,115,97,118,101,32,105,110,32,87,51,67,32,101,120,99,108,117,115,105,118,101,32,99,97,110,111,110,105,99,97,108,32,102,111,114,109,97,116,32,40,119,105,116,104,32,99,111,109,109,101,110,116,115,41,10,0,0,0,9,45,45,110,115,99,108,101,97,110,32,58,32,114,101,109,111,118,101,32,114,101,100,117,110,100,97,110,116,32,110,97,109,101,115,112,97,99,101,32,100,101,99,108,97,114,97,116,105,111,110,115,10,0,0,0,9,45,45,116,101,115,116,73,79,32,58,32,116,101,115,116,32,117,115,101,114,32,73,47,79,32,115,117,112,112,111,114,116,10,0,0,0,0,0,0,9,45,45,99,97,116,97,108,111,103,115,32,58,32,117,115,101,32,83,71,77,76,32,99,97,116,97,108,111,103,115,32,102,114,111,109,32,36,83,71,77,76,95,67,65,84,65,76,79,71,95,70,73,76,69,83,10,0,0,0,0,0,0,0,9,32,32,32,32,32,32,32,32,32,32,32,32,32,111,116,104,101,114,119,105,115,101,32,88,77,76,32,67,97,116,97,108,111,103,115,32,115,116,97,114,116,105,110,103,32,102,114,111,109,32,10,0,0,0,0,9,32,32,32,32,32,32,32,32,32,37,115,32,97,114,101,32,97,99,116,105,118,97,116,101,100,32,98,121,32,100,101,102,97,117,108,116,10,0,0,102,105,108,101,58,47,47,47,101,116,99,47,120,109,108,47,99,97,116,97,108,111,103,0,9,45,45,110,111,99,97,116,97,108,111,103,115,58,32,100,101,97,99,116,105,118,97,116,101,32,97,108,108,32,99,97,116,97,108,111,103,115,10,0,9,45,45,97,117,116,111,32,58,32,103,101,110,101,114,97,116,101,32,97,32,115,109,97,108,108,32,100,111,99,32,111,110,32,116,104,101,32,102,108,121,10,0,0,0,0,0,0,9,45,45,120,105,110,99,108,117,100,101,32,58,32,100,111,32,88,73,110,99,108,117,100,101,32,112,114,111,99,101,115,115,105,110,103,10,0,0,0,9,45,45,110,111,120,105,110,99,108,117,100,101,110,111,100,101,32,58,32,115,97,109,101,32,98,117,116,32,100,111,32,110,111,116,32,103,101,110,101,114,97,116,101,32,88,73,110,99,108,117,100,101,32,110,111,100,101,115,10,0,0,0,0,9,45,45,110,111,102,105,120,117,112,45,98,97,115,101,45,117,114,105,115,32,58,32,100,111,32,110,111,116,32,102,105,120,117,112,32,120,109,108,58,98,97,115,101,32,117,114,105,115,10,0,0,0,0,0,0,9,45,45,108,111,97,100,100,116,100,32,58,32,102,101,116,99,104,32,101,120,116,101,114,110,97,108,32,68,84,68,10,0,0,0,0,0,0,0,0,9,45,45,100,116,100,97,116,116,114,32,58,32,108,111,97,100,100,116,100,32,43,32,112,111,112,117,108,97,116,101,32,116,104,101,32,116,114,101,101,32,119,105,116,104,32,105,110,104,101,114,105,116,101,100,32,97,116,116,114,105,98,117,116,101,115,32,10,0,0,0,0,9,45,45,115,116,114,101,97,109,32,58,32,117,115,101,32,116,104,101,32,115,116,114,101,97,109,105,110,103,32,105,110,116,101,114,102,97,99,101,32,116,111,32,112,114,111,99,101,115,115,32,118,101,114,121,32,108,97,114,103,101,32,102,105,108,101,115,10,0,0,0,0,9,45,45,119,97,108,107,101,114,32,58,32,99,114,101,97,116,101,32,97,32,114,101,97,100,101,114,32,97,110,100,32,119,97,108,107,32,116,104,111,117,103,104,32,116,104,101,32,114,101,115,117,108,116,105,110,103,32,100,111,99,10,0,0,9,45,45,112,97,116,116,101,114,110,32,112,97,116,116,101,114,110,95,118,97,108,117,101,32,58,32,116,101,115,116,32,116,104,101,32,112,97,116,116,101,114,110,32,115,117,112,112,111,114,116,10,0,0,0,0,9,45,45,99,104,107,114,101,103,105,115,116,101,114,32,58,32,118,101,114,105,102,121,32,116,104,101,32,110,111,100,101,32,114,101,103,105,115,116,114,97,116,105,111,110,32,99,111,100,101,10,0,0,0,0,0,9,45,45,114,101,108,97,120,110,103,32,115,99,104,101,109,97,32,58,32,100,111,32,82,101,108,97,120,78,71,32,118,97,108,105,100,97,116,105,111,110,32,97,103,97,105,110,115,116,32,116,104,101,32,115,99,104,101,109,97,10,0,0,0,9,45,45,115,99,104,101,109,97,32,115,99,104,101,109,97,32,58,32,100,111,32,118,97,108,105,100,97,116,105,111,110,32,97,103,97,105,110,115,116,32,116,104,101,32,87,88,83,32,115,99,104,101,109,97,10,0,0,0,0,0,0,0,0,9,45,45,115,99,104,101,109,97,116,114,111,110,32,115,99,104,101,109,97,32,58,32,100,111,32,118,97,108,105,100,97,116,105,111,110,32,97,103,97,105,110,115,116,32,97,32,115,99,104,101,109,97,116,114,111,110,10,0,0,0,0,0,0,9,45,45,115,97,120,49,58,32,117,115,101,32,116,104,101,32,111,108,100,32,83,65,88,49,32,105,110,116,101,114,102,97,99,101,115,32,102,111,114,32,112,114,111,99,101,115,115,105,110,103,10,0,0,0,0,9,45,45,115,97,120,58,32,100,111,32,110,111,116,32,98,117,105,108,100,32,97,32,116,114,101,101,32,98,117,116,32,119,111,114,107,32,106,117,115,116,32,97,116,32,116,104,101,32,83,65,88,32,108,101,118,101,108,10,0,0,0,0,0,9,45,45,111,108,100,120,109,108,49,48,58,32,117,115,101,32,88,77,76,45,49,46,48,32,112,97,114,115,105,110,103,32,114,117,108,101,115,32,98,101,102,111,114,101,32,116,104,101,32,53,116,104,32,101,100,105,116,105,111,110,10,0,0,9,45,45,120,112,97,116,104,32,101,120,112,114,58,32,101,118,97,108,117,97,116,101,32,116,104,101,32,88,80,97,116,104,32,101,120,112,114,101,115,115,105,111,110,44,32,105,109,112,108,121,32,45,45,110,111,111,117,116,10,0,0,0,0,10,76,105,98,120,109,108,32,112,114,111,106,101,99,116,32,104,111,109,101,32,112,97,103,101,58,32,104,116,116,112,58,47,47,120,109,108,115,111,102,116,46,111,114,103,47,10,0,84,111,32,114,101,112,111,114,116,32,98,117,103,115,32,111,114,32,103,101,116,32,115,111,109,101,32,104,101,108,112,32,99,104,101,99,107,58,32,104,116,116,112,58,47,47,120,109,108,115,111,102,116,46,111,114,103,47,98,117,103,115,46,104,116,109,108,10,0,0,0,0,83,65,88,46,101,110,100,69,108,101,109,101,110,116,40,37,115,41,10,0,0,0,0,0,83,65,88,46,115,116,97,114,116,69,108,101,109,101,110,116,40,37,115,0,0,0,0,0,37,115,39,0,0,0,0,0,108,116,0,0,0,0,0,0,0,0,0,0,17,0,0,0,56,238,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,120,242,0,0,120,242,0,0,1,0,0,0,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,103,116,0,0,0,0,0,0,0,0,0,0,17,0,0,0,144,238,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,112,242,0,0,112,242,0,0,1,0,0,0,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,97,109,112,0,0,0,0,0,0,0,0,0,17,0,0,0,232,238,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,104,242,0,0,104,242,0,0,1,0,0,0,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,97,112,111,115,0,0,0,0,0,0,0,0,17,0,0,0,64,239,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,242,0,0,96,242,0,0,1,0,0,0,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,113,117,111,116,0,0,0,0,0,0,0,0,17,0,0,0,152,239,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,241,0,0,64,241,0,0,1,0,0,0,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,120,109,108,65,100,100,68,116,100,69,110,116,105,116,121,58,32,100,111,99,117,109,101,110,116,32,105,115,32,78,85,76,76,0,0,0,0,0,0,0,120,109,108,65,100,100,68,116,100,69,110,116,105,116,121,58,32,100,111,99,117,109,101,110,116,32,119,105,116,104,111,117,116,32,101,120,116,101,114,110,97,108,32,115,117,98,115,101,116,0,0,0,0,0,0,0,120,109,108,65,100,100,68,111,99,69,110,116,105,116,121,58,32,100,111,99,117,109,101,110,116,32,105,115,32,78,85,76,76,0,0,0,0,0,0,0,120,109,108,65,100,100,68,111,99,69,110,116,105,116,121,58,32,100,111,99,117,109,101,110,116,32,119,105,116,104,111,117,116,32,105,110,116,101,114,110,97,108,32,115,117,98,115,101,116,0,0,0,0,0,0,0,60,33,69,78,84,73,84,89,32,0,0,0,0,0,0,0,32,0,0,0,0,0,0,0,62,10,0,0,0,0,0,0,32,80,85,66,76,73,67,32,0,0,0,0,0,0,0,0,32,83,89,83,84,69,77,32,0,0,0,0,0,0,0,0,32,78,68,65,84,65,32,0,60,33,69,78,84,73,84,89,32,37,32,0,0,0,0,0,120,109,108,68,117,109,112,69,110,116,105,116,105,101,115,68,101,99,108,58,32,105,110,116,101,114,110,97,108,58,32,117,110,107,110,111,119,110,32,116,121,112,101,32,101,110,116,105,116,121,32,116,121,112,101,0,34,0,0,0,0,0,0,0,38,113,117,111,116,59,0,0,38,35,120,50,53,59,0,0,120,109,108,67,111,112,121,69,110,116,105,116,121,58,58,32,109,97,108,108,111,99,32,102,97,105,108,101,100,0,0,0,120,109,108,69,110,99,111,100,101,69,110,116,105,116,105,101,115,58,32,109,97,108,108,111,99,32,102,97,105,108,101,100,0,0,0,0,0,0,0,0,45,45,62,0,0,0,0,0,120,109,108,69,110,99,111,100,101,69,110,116,105,116,105,101,115,58,32,105,110,112,117,116,32,110,111,116,32,85,84,70,45,56,0,0,0,0,0,0,73,83,79,45,56,56,53,57,45,49,0,0,0,0,0,0,38,35,37,100,59,0,0,0,120,109,108,69,110,99,111,100,101,69,110,116,105,116,105,101,115,58,32,99,104,97,114,32,111,117,116,32,111,102,32,114,97,110,103,101,10,0,0,0,38,35,120,37,88,59,0,0,120,109,108,69,110,99,111,100,101,69,110,116,105,116,105,101,115,58,32,114,101,97,108,108,111,99,32,102,97,105,108,101,100,0,0,0,0,0,0,0,120,109,108,67,114,101,97,116,101,69,110,116,105,116,121,58,32,109,97,108,108,111,99,32,102,97,105,108,101,100,0,0,39,0,0,0,0,0,0,0,38,0,0,0,0,0,0,0,62,0,0,0,0,0,0,0,60,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,85,84,70,45,56,0,0,0,85,84,70,56,0,0,0,0,85,84,70,45,49,54,0,0,85,84,70,49,54,0,0,0,73,83,79,45,49,48,54,52,54,45,85,67,83,45,50,0,85,67,83,45,50,0,0,0,85,67,83,50,0,0,0,0,73,83,79,45,49,48,54,52,54,45,85,67,83,45,52,0,85,67,83,45,52,0,0,0,85,67,83,52,0,0,0,0,73,83,79,45,56,56,53,57,45,49,0,0,0,0,0,0,73,83,79,45,76,65,84,73,78,45,49,0,0,0,0,0,73,83,79,32,76,65,84,73,78,32,49,0,0,0,0,0,73,83,79,45,56,56,53,57,45,50,0,0,0,0,0,0,73,83,79,45,76,65,84,73,78,45,50,0,0,0,0,0,73,83,79,32,76,65,84,73,78,32,50,0,0,0,0,0,73,83,79,45,56,56,53,57,45,51,0,0,0,0,0,0,73,83,79,45,56,56,53,57,45,52,0,0,0,0,0,0,73,83,79,45,56,56,53,57,45,53,0,0,0,0,0,0,73,83,79,45,56,56,53,57,45,54,0,0,0,0,0,0,73,83,79,45,56,56,53,57,45,55,0,0,0,0,0,0,73,83,79,45,56,56,53,57,45,56,0,0,0,0,0,0,73,83,79,45,56,56,53,57,45,57,0,0,0,0,0,0,73,83,79,45,50,48,50,50,45,74,80,0,0,0,0,0,83,72,73,70,84,95,74,73,83,0,0,0,0,0,0,0,69,85,67,45,74,80,0,0,69,66,67,68,73,67,0,0,83,104,105,102,116,45,74,73,83,0,0,0,0,0,0,0,120,109,108,78,101,119,67,104,97,114,69,110,99,111,100,105,110,103,72,97,110,100,108,101,114,32,58,32,110,111,32,110,97,109,101,32,33,10,0,0,120,109,108,78,101,119,67,104,97,114,69,110,99,111,100,105,110,103,72,97,110,100,108,101,114,32,58,32,111,117,116,32,111,102,32,109,101,109,111,114,121,32,33,10,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,79,100,100,32,112,114,111,98,108,101,109,32,97,116,32,101,110,100,105,97,110,110,101,115,115,32,100,101,116,101,99,116,105,111,110,10,0,0,0,0,120,109,108,73,110,105,116,67,104,97,114,69,110,99,111,100,105,110,103,72,97,110,100,108,101,114,115,32,58,32,111,117,116,32,111,102,32,109,101,109,111,114,121,32,33,10,0,0,85,84,70,45,49,54,76,69,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,85,84,70,45,49,54,66,69,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,65,83,67,73,73,0,0,0,85,83,45,65,83,67,73,73,0,0,0,0,0,0,0,0,72,84,77,76,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,120,109,108,82,101,103,105,115,116,101,114,67,104,97,114,69,110,99,111,100,105,110,103,72,97,110,100,108,101,114,58,32,78,85,76,76,32,104,97,110,100,108,101,114,32,33,10,0,120,109,108,82,101,103,105,115,116,101,114,67,104,97,114,69,110,99,111,100,105,110,103,72,97,110,100,108,101,114,58,32,84,111,111,32,109,97,110,121,32,104,97,110,100,108,101,114,32,114,101,103,105,115,116,101,114,101,100,44,32,115,101,101,32,37,115,10,0,0,0,0,77,65,88,95,69,78,67,79,68,73,78,71,95,72,65,78,68,76,69,82,83,0,0,0,101,98,99,100,105,99,0,0,69,66,67,68,73,67,45,85,83,0,0,0,0,0,0,0,73,66,77,45,48,51,55,0,83,72,73,70,84,45,74,73,83,0,0,0,0,0,0,0,83,104,105,102,116,95,74,73,83,0,0,0,0,0,0,0,105,99,111,110,118,32,58,32,112,114,111,98,108,101,109,115,32,119,105,116,104,32,102,105,108,116,101,114,115,32,102,111,114,32,39,37,115,39,10,0,48,120,37,48,50,88,32,48,120,37,48,50,88,32,48,120,37,48,50,88,32,48,120,37,48,50,88,0,0,0,0,0,105,110,112,117,116,32,99,111,110,118,101,114,115,105,111,110,32,102,97,105,108,101,100,32,100,117,101,32,116,111,32,105,110,112,117,116,32,101,114,114,111,114,44,32,98,121,116,101,115,32,37,115,10,0,0,0,120,109,108,67,104,97,114,69,110,99,79,117,116,70,117,110,99,58,32,110,111,32,111,117,116,112,117,116,32,102,117,110,99,116,105,111,110,32,33,10,0,0,0,0,0,0,0,0,38,35,37,100,59,0,0,0,111,117,116,112,117,116,32,99,111,110,118,101,114,115,105,111,110,32,102,97,105,108,101,100,32,100,117,101,32,116,111,32,99,111,110,118,32,101,114,114,111,114,44,32,98,121,116,101,115,32,37,115,10,0,0,0,37,115,58,37,100,58,32,0,69,110,116,105,116,121,58,32,108,105,110,101,32,37,100,58,32,0,0,0,0,0,0,0,78,111,32,101,114,114,111,114,32,109,101,115,115,97,103,101,32,112,114,111,118,105,100,101,100,0,0,0,0,0,0,0,104,114,101,102,0,0,0,0,37,115,0,0,0,0,0,0,77,101,109,111,114,121,32,97,108,108,111,99,97,116,105,111,110,32,102,97,105,108,101,100,32,58,32,37,115,10,0,0,77,101,109,111,114,121,32,97,108,108,111,99,97,116,105,111,110,32,102,97,105,108,101,100,10,0,0,0,0,0,0,0,101,114,114,111,114,58,32,0,10,0,0,0,0,0,0,0,119,97,114,110,105,110,103,58,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,118,97,108,105,100,105,116,121,32,101,114,114,111,114,58,32,0,0,0,0,0,0,0,0,118,97,108,105,100,105,116,121,32,119,97,114,110,105,110,103,58,32,0,0,0,0,0,0,101,108,101,109,101,110,116,32,37,115,58,32,0,0,0,0,112,97,114,115,101,114,32,0,110,97,109,101,115,112,97,99,101,32,0,0,0,0,0,0,118,97,108,105,100,105,116,121,32,0,0,0,0,0,0,0,72,84,77,76,32,112,97,114,115,101,114,32,0,0,0,0,109,101,109,111,114,121,32,0,111,117,116,112,117,116,32,0,73,47,79,32,0,0,0,0,88,73,110,99,108,117,100,101,32,0,0,0,0,0,0,0,88,80,97,116,104,32,0,0,114,101,103,101,120,112,32,0,109,111,100,117,108,101,32,0,83,99,104,101,109,97,115,32,118,97,108,105,100,105,116,121,32,0,0,0,0,0,0,0,83,99,104,101,109,97,115,32,112,97,114,115,101,114,32,0,82,101,108,97,120,45,78,71,32,112,97,114,115,101,114,32,0,0,0,0,0,0,0,0,82,101,108,97,120,45,78,71,32,118,97,108,105,100,105,116,121,32,0,0,0,0,0,0,67,97,116,97,108,111,103,32,0,0,0,0,0,0,0,0,67,49,52,78,32,0,0,0,88,83,76,84,32,0,0,0,101,110,99,111,100,105,110,103,32,0,0,0,0,0,0,0,115,99,104,101,109,97,116,114,111,110,32,0,0,0,0,0,105,110,116,101,114,110,97,108,32,98,117,102,102,101,114,32,0,0,0,0,0,0,0,0,85,82,73,32,0,0,0,0,58,32,0,0,0,0,0,0,119,97,114,110,105,110,103,32,58,32,0,0,0,0,0,0,101,114,114,111,114,32,58,32,0,0,0,0,0,0,0,0,37,115,10,0,0,0,0,0,111,117,116,32,111,102,32,109,101,109,111,114,121,32,101,114,114,111,114,0,0,0,0,0,37,115,58,37,100,58,32,10,0,0,0,0,0,0,0,0,69,110,116,105,116,121,58,32,108,105,110,101,32,37,100,58,32,10,0,0,0,0,0,0,70,97,116,97,108,58,32,112,114,111,103,114,97,109,32,99,111,109,112,105,108,101,100,32,97,103,97,105,110,115,116,32,108,105,98,120,109,108,32,37,100,32,117,115,105,110,103,32,108,105,98,120,109,108,32,37,100,10,0,0,0,0,0,0,87,97,114,110,105,110,103,58,32,112,114,111,103,114,97,109,32,99,111,109,112,105,108,101,100,32,97,103,97,105,110,115,116,32,108,105,98,120,109,108,32,37,100,32,117,115,105,110,103,32,111,108,100,101,114,32,37,100,10,0,0,0,0,0,77,101,109,111,114,121,32,97,108,108,111,99,97,116,105,111,110,32,102,97,105,108,101,100,32,58,32,37,115,10,0,0,77,101,109,111,114,121,32,97,108,108,111,99,97,116,105,111,110,32,102,97,105,108,101,100,10,0,0,0,0,0,0,0,67,104,97,114,32,48,120,37,88,32,111,117,116,32,111,102,32,97,108,108,111,119,101,100,32,114,97,110,103,101,10,0,73,110,112,117,116,32,105,115,32,110,111,116,32,112,114,111,112,101,114,32,85,84,70,45,56,44,32,105,110,100,105,99,97,116,101,32,101,110,99,111,100,105,110,103,32,33,10,0,66,121,116,101,115,58,32,48,120,37,48,50,88,32,48,120,37,48,50,88,32,48,120,37,48,50,88,32,48,120,37,48,50,88,10,0,0,0,0,0,73,110,112,117,116,32,105,115,32,110,111,116,32,112,114,111,112,101,114,32,85,84,70,45,56,44,32,105,110,100,105,99,97,116,101,32,101,110,99,111,100,105,110,103,32,33,10,37,115,0,0,0,0,0,0,0,67,104,97,114,32,48,120,48,32,111,117,116,32,111,102,32,97,108,108,111,119,101,100,32,114,97,110,103,101,10,0,0,73,110,116,101,114,110,97,108,32,101,114,114,111,114,44,32,120,109,108,67,111,112,121,67,104,97,114,77,117,108,116,105,66,121,116,101,32,48,120,37,88,32,111,117,116,32,111,102,32,98,111,117,110,100,10,0,101,110,99,111,100,105,110,103,32,117,110,107,110,111,119,110,10,0,0,0,0,0,0,0,101,110,99,111,100,105,110,103,32,110,111,116,32,115,117,112],"i8",ALLOC_NONE,Runtime.GLOBAL_BASE+54128),
	allocate([112,111,114,116,101,100,32,37,115,10,0,0,0,0,0,0,85,83,67,52,32,108,105,116,116,108,101,32,101,110,100,105,97,110,0,0,0,0,0,0,85,83,67,52,32,98,105,103,32,101,110,100,105,97,110,0,69,66,67,68,73,67,0,0,85,67,83,52,32,50,49,52,51,0,0,0,0,0,0,0,85,67,83,52,32,51,52,49,50,0,0,0,0,0,0,0,85,67,83,50,0,0,0,0,73,83,79,45,50,48,50,50,45,74,80,0,0,0,0,0,83,104,105,102,116,95,74,73,83,0,0,0,0,0,0,0,69,85,67,45,74,80,0,0,99,111,117,108,100,110,39,116,32,97,108,108,111,99,97,116,101,32,97,32,110,101,119,32,105,110,112,117,116,32,115,116,114,101,97,109,10,0,0,0,110,101,119,32,105,110,112,117,116,32,102,114,111,109,32,73,47,79,10,0,0,0,0,0,120,109,108,78,101,119,69,110,116,105,116,121,73,110,112,117,116,83,116,114,101,97,109,32,101,110,116,105,116,121,32,61,32,78,85,76,76,10,0,0,110,101,119,32,105,110,112,117,116,32,102,114,111,109,32,101,110,116,105,116,121,58,32,37,115,10,0,0,0,0,0,0,67,97,110,110,111,116,32,112,97,114,115,101,32,101,110,116,105,116,121,32,37,115,10,0,73,110,116,101,114,110,97,108,32,101,110,116,105,116,121,32,37,115,32,119,105,116,104,111,117,116,32,99,111,110,116,101,110,116,32,33,10,0,0,0,73,110,116,101,114,110,97,108,32,112,97,114,97,109,101,116,101,114,32,101,110,116,105,116,121,32,37,115,32,119,105,116,104,111,117,116,32,99,111,110,116,101,110,116,32,33,10,0,80,114,101,100,101,102,105,110,101,100,32,101,110,116,105,116,121,32,37,115,32,119,105,116,104,111,117,116,32,99,111,110,116,101,110,116,32,33,10,0,110,101,119,32,105,110,112,117,116,32,102,114,111,109,32,102,105,108,101,58,32,37,115,10,0,0,0,0,0,0,0,0,102,97,105,108,101,100,32,116,111,32,108,111,97,100,32,101,120,116,101,114,110,97,108,32,101,110,116,105,116,121,58,32,78,85,76,76,32,102,105,108,101,110,97,109,101,32,10,0,102,97,105,108,101,100,32,116,111,32,108,111,97,100,32,101,120,116,101,114,110,97,108,32,101,110,116,105,116,121,32,34,37,115,34,10,0,0,0,0,71,111,116,32,78,85,76,76,32,112,97,114,115,101,114,32,99,111,110,116,101,120,116,10,0,0,0,0,0,0,0,0,99,97,110,110,111,116,32,105,110,105,116,105,97,108,105,122,101,32,112,97,114,115,101,114,32,99,111,110,116,101,120,116,10,0,0,0,0,0,0,0,99,97,110,110,111,116,32,97,108,108,111,99,97,116,101,32,112,97,114,115,101,114,32,99,111,110,116,101,120,116,10,0,102,97,105,108,101,100,32,116,111,32,97,108,108,111,99,97,116,101,32,98,117,102,102,101,114,10,0,0,0,0,0,0,120,109,108,83,119,105,116,99,104,84,111,69,110,99,111,100,105,110,103,32,58,32,110,111,32,105,110,112,117,116,10,0,85,84,70,45,49,54,76,69,0,0,0,0,0,0,0,0,85,84,70,45,49,54,0,0,85,84,70,45,49,54,66,69,0,0,0,0,0,0,0,0,85,84,70,45,56,0,0,0,115,119,105,116,99,104,105,110,103,32,101,110,99,111,100,105,110,103,58,32,101,110,99,111,100,101,114,32,101,114,114,111,114,10,0,0,0,0,0,0,115,119,105,116,99,104,105,110,103,32,101,110,99,111,100,105,110,103,32,58,32,110,111,32,105,110,112,117,116,10,0,0,0,1,0,0,0,0,0,0,69,120,99,101,115,115,105,118,101,32,100,101,112,116,104,32,105,110,32,100,111,99,117,109,101,110,116,58,32,37,100,32,117,115,101,32,88,77,76,95,80,65,82,83,69,95,72,85,71,69,32,111,112,116,105,111,110,10,0,0,0,0,0,0,80,111,112,112,105,110,103,32,105,110,112,117,116,32,37,100,10,0,0,0,0,0,0,0,37,115,40,37,100,41,58,32,0,0,0,0,0,0,0,0,80,117,115,104,105,110,103,32,105,110,112,117,116,32,37,100,32,58,32,37,46,51,48,115,10,0,0,0,0,0,0,0,120,109,108,80,97,114,115,101,67,104,97,114,82,101,102,58,32,105,110,118,97,108,105,100,32,120,109,108,67,104,97,114,32,118,97,108,117,101,32,37,100,10,0,0,0,0,0,0,80,69,82,101,102,101,114,101,110,99,101,58,32,37,115,10,0,0,0,0,0,0,0,0,80,69,82,101,102,101,114,101,110,99,101,58,32,37,37,37,115,59,32,110,111,116,32,102,111,117,110,100,10,0,0,0,80,69,82,101,102,101,114,101,110,99,101,58,32,37,115,32,105,115,32,110,111,116,32,97,32,112,97,114,97,109,101,116,101,114,32,101,110,116,105,116,121,10,0,0,0,0,0,0,83,116,114,105,110,103,32,100,101,99,111,100,105,110,103,32,69,110,116,105,116,121,32,82,101,102,101,114,101,110,99,101,58,32,37,46,51,48,115,10,0,0,0,0,0,0,0,0,112,114,101,100,101,102,105,110,101,100,32,101,110,116,105,116,121,32,104,97,115,32,110,111,32,99,111,110,116,101,110,116,10,0,0,0,0,0,0,0,83,116,114,105,110,103,32,100,101,99,111,100,105,110,103,32,80,69,32,82,101,102,101,114,101,110,99,101,58,32,37,46,51,48,115,10,0,0,0,0,0,0,0,0,0,0,0,0,78,97,109,101,32,37,115,32,105,115,32,110,111,116,32,88,77,76,32,78,97,109,101,115,112,97,99,101,32,99,111,109,112,108,105,97,110,116,10,0,78,97,109,101,0,0,0,0,78,109,84,111,107,101,110,0,69,110,116,105,116,121,86,97,108,117,101,58,32,39,37,99,39,32,102,111,114,98,105,100,100,101,110,32,101,120,99,101,112,116,32,102,111,114,32,101,110,116,105,116,105,101,115,32,114,101,102,101,114,101,110,99,101,115,10,0,0,0,0,0,83,121,115,116,101,109,76,105,116,101,114,97,108,0,0,0,80,117,98,108,105,99,32,73,68,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,33,34,35,36,37,0,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57,58,59,0,61,62,63,64,65,66,67,68,69,70,71,72,73,74,75,76,77,78,79,80,81,82,83,84,85,86,87,88,89,90,91,92,0,94,95,96,97,98,99,100,101,102,103,104,105,106,107,108,109,110,111,112,113,114,115,116,117,118,119,120,121,122,123,124,125,126,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,83,112,97,99,101,32,114,101,113,117,105,114,101,100,32,97,102,116,101,114,32,39,83,89,83,84,69,77,39,10,0,0,83,112,97,99,101,32,114,101,113,117,105,114,101,100,32,97,102,116,101,114,32,39,80,85,66,76,73,67,39,10,0,0,83,112,97,99,101,32,114,101,113,117,105,114,101,100,32,97,102,116,101,114,32,116,104,101,32,80,117,98,108,105,99,32,73,100,101,110,116,105,102,105,101,114,10,0,0,0,0,0,67,111,109,109,101,110,116,32,116,111,111,32,98,105,103,32,102,111,117,110,100,0,0,0,99,111,109,109,101,110,116,32,100,111,101,115,110,39,116,32,115,116,97,114,116,32,97,110,100,32,115,116,111,112,32,105,110,32,116,104,101,32,115,97,109,101,32,101,110,116,105,116,121,10,0,0,0,0,0,0,68,111,117,98,108,101,32,104,121,112,104,101,110,32,119,105,116,104,105,110,32,99,111,109,109,101,110,116,58,32,60,33,45,45,37,46,53,48,115,10,0,0,0,0,0,0,0,0,68,111,117,98,108,101,32,104,121,112,104,101,110,32,119,105,116,104,105,110,32,99,111,109,109,101,110,116,10,0,0,0,88,77,76,32,100,101,99,108,97,114,97,116,105,111,110,32,97,108,108,111,119,101,100,32,111,110,108,121,32,97,116,32,116,104,101,32,115,116,97,114,116,32,111,102,32,116,104,101,32,100,111,99,117,109,101,110,116,10,0,0,0,0,0,0,168,27,1,0,184,27,1,0,0,0,0,0,0,0,0,0,120,109,108,80,97,114,115,101,80,73,84,97,114,103,101,116,58,32,105,110,118,97,108,105,100,32,110,97,109,101,32,112,114,101,102,105,120,32,39,120,109,108,39,10,0,0,0,0,99,111,108,111,110,115,32,97,114,101,32,102,111,114,98,105,100,100,101,110,32,102,114,111,109,32,80,73,32,110,97,109,101,115,32,39,37,115,39,10,0,0,0,0,0,0,0,0,80,73,32,100,101,99,108,97,114,97,116,105,111,110,32,100,111,101,115,110,39,116,32,115,116,97,114,116,32,97,110,100,32,115,116,111,112,32,105,110,32,116,104,101,32,115,97,109,101,32,101,110,116,105,116,121,10,0,0,0,0,0,0,0,80,97,114,115,101,80,73,58,32,80,73,32,37,115,32,115,112,97,99,101,32,101,120,112,101,99,116,101,100,10,0,0,80,73,32,37,115,32,116,111,111,32,98,105,103,32,102,111,117,110,100,0,0,0,0,0,80,97,114,115,101,80,73,58,32,80,73,32,37,115,32,110,101,118,101,114,32,101,110,100,32,46,46,46,10,0,0,0,111,97,115,105,115,45,120,109,108,45,99,97,116,97,108,111,103,0,0,0,0,0,0,0,83,112,97,99,101,32,114,101,113,117,105,114,101,100,32,97,102,116,101,114,32,39,60,33,78,79,84,65,84,73,79,78,39,10,0,0,0,0,0,0,83,112,97,99,101,32,114,101,113,117,105,114,101,100,32,97,102,116,101,114,32,116,104,101,32,78,79,84,65,84,73,79,78,32,110,97,109,101,39,10,0,0,0,0,0,0,0,0,99,111,108,111,110,115,32,97,114,101,32,102,111,114,98,105,100,100,101,110,32,102,114,111,109,32,110,111,116,97,116,105,111,110,32,110,97,109,101,115,32,39,37,115,39,10,0,0,78,111,116,97,116,105,111,110,32,100,101,99,108,97,114,97,116,105,111,110,32,100,111,101,115,110,39,116,32,115,116,97,114,116,32,97,110,100,32,115,116,111,112,32,105,110,32,116,104,101,32,115,97,109,101,32,101,110,116,105,116,121,10,0,83,112,97,99,101,32,114,101,113,117,105,114,101,100,32,97,102,116,101,114,32,39,60,33,69,78,84,73,84,89,39,10,0,0,0,0,0,0,0,0,83,112,97,99,101,32,114,101,113,117,105,114,101,100,32,97,102,116,101,114,32,39,37,39,10,0,0,0,0,0,0,0,120,109,108,80,97,114,115,101,69,110,116,105,116,121,68,101,99,108,58,32,110,111,32,110,97,109,101,10,0,0,0,0,99,111,108,111,110,115,32,97,114,101,32,102,111,114,98,105,100,100,101,110,32,102,114,111,109,32,101,110,116,105,116,105,101,115,32,110,97,109,101,115,32,39,37,115,39,10,0,0,83,112,97,99,101,32,114,101,113,117,105,114,101,100,32,97,102,116,101,114,32,116,104,101,32,101,110,116,105,116,121,32,110,97,109,101,10,0,0,0,73,110,118,97,108,105,100,32,85,82,73,58,32,37,115,10,0,0,0,0,0,0,0,0,83,65,88,32,99,111,109,112,97,116,105,98,105,108,105,116,121,32,109,111,100,101,32,100,111,99,117,109,101,110,116,0,78,101,119,32,68,111,99,32,102,97,105,108,101,100,0,0,102,97,107,101,0,0,0,0,83,112,97,99,101,32,114,101,113,117,105,114,101,100,32,98,101,102,111,114,101,32,39,78,68,65,84,65,39,10,0,0,83,112,97,99,101,32,114,101,113,117,105,114,101,100,32,97,102,116,101,114,32,39,78,68,65,84,65,39,10,0,0,0,120,109,108,80,97,114,115,101,69,110,116,105,116,121,68,101,99,108,58,32,101,110,116,105,116,121,32,37,115,32,110,111,116,32,116,101,114,109,105,110,97,116,101,100,10,0,0,0,69,110,116,105,116,121,32,100,101,99,108,97,114,97,116,105,111,110,32,100,111,101,115,110,39,116,32,115,116,97,114,116,32,97,110,100,32,115,116,111,112,32,105,110,32,116,104,101,32,115,97,109,101,32,101,110,116,105,116,121,10,0,0,0,83,112,97,99,101,32,114,101,113,117,105,114,101,100,32,97,102,116,101,114,32,39,35,70,73,88,69,68,39,10,0,0,65,116,116,114,105,98,117,116,101,32,100,101,102,97,117,108,116,32,118,97,108,117,101,32,100,101,99,108,97,114,97,116,105,111,110,32,101,114,114,111,114,10,0,0,0,0,0,0,78,97,109,101,32,101,120,112,101,99,116,101,100,32,105,110,32,78,79,84,65,84,73,79,78,32,100,101,99,108,97,114,97,116,105,111,110,10,0,0,115,116,97,110,100,97,108,111,110,101,58,32,97,116,116,114,105,98,117,116,101,32,110,111,116,97,116,105,111,110,32,118,97,108,117,101,32,116,111,107,101,110,32,37,115,32,100,117,112,108,105,99,97,116,101,100,10,0,0,0,0,0,0,0,115,116,97,110,100,97,108,111,110,101,58,32,97,116,116,114,105,98,117,116,101,32,101,110,117,109,101,114,97,116,105,111,110,32,118,97,108,117,101,32,116,111,107,101,110,32,37,115,32,100,117,112,108,105,99,97,116,101,100,10,0,0,0,0,83,112,97,99,101,32,114,101,113,117,105,114,101,100,32,97,102,116,101,114,32,39,78,79,84,65,84,73,79,78,39,10,0,0,0,0,0,0,0,0,83,112,97,99,101,32,114,101,113,117,105,114,101,100,32,97,102,116,101,114,32,39,60,33,65,84,84,76,73,83,84,39,10,0,0,0,0,0,0,0,65,84,84,76,73,83,84,58,32,110,111,32,110,97,109,101,32,102,111,114,32,69,108,101,109,101,110,116,10,0,0,0,65,84,84,76,73,83,84,58,32,110,111,32,110,97,109,101,32,102,111,114,32,65,116,116,114,105,98,117,116,101,10,0,83,112,97,99,101,32,114,101,113,117,105,114,101,100,32,97,102,116,101,114,32,116,104,101,32,97,116,116,114,105,98,117,116,101,32,110,97,109,101,10,0,0,0,0,0,0,0,0,83,112,97,99,101,32,114,101,113,117,105,114,101,100,32,97,102,116,101,114,32,116,104,101,32,97,116,116,114,105,98,117,116,101,32,116,121,112,101,10,0,0,0,0,0,0,0,0,83,112,97,99,101,32,114,101,113,117,105,114,101,100,32,97,102,116,101,114,32,116,104,101,32,97,116,116,114,105,98,117,116,101,32,100,101,102,97,117,108,116,32,118,97,108,117,101,10,0,0,0,0,0,0,0,105,110,32,120,109,108,80,97,114,115,101,65,116,116,114,105,98,117,116,101,76,105,115,116,68,101,99,108,10,0,0,0,65,116,116,114,105,98,117,116,101,32,108,105,115,116,32,100,101,99,108,97,114,97,116,105,111,110,32,100,111,101,115,110,39,116,32,115,116,97,114,116,32,97,110,100,32,115,116,111,112,32,105,110,32,116,104,101,32,115,97,109,101,32,101,110,116,105,116,121,10,0,0,0,69,108,101,109,101,110,116,32,99,111,110,116,101,110,116,32,100,101,99,108,97,114,97,116,105,111,110,32,100,111,101,115,110,39,116,32,115,116,97,114,116,32,97,110,100,32,115,116,111,112,32,105,110,32,116,104,101,32,115,97,109,101,32,101,110,116,105,116,121,10,0,0,120,109,108,80,97,114,115,101,69,108,101,109,101,110,116,77,105,120,101,100,67,111,110,116,101,110,116,68,101,99,108,32,58,32,78,97,109,101,32,101,120,112,101,99,116,101,100,10,0,0,0,0,0,0,0,0,120,109,108,80,97,114,115,101,69,108,101,109,101,110,116,67,111,110,116,101,110,116,68,101,99,108,32,58,32,37,115,32,39,40,39,32,101,120,112,101,99,116,101,100,10,0,0,0,83,112,97,99,101,32,114,101,113,117,105,114,101,100,32,97,102,116,101,114,32,39,69,76,69,77,69,78,84,39,10,0,120,109,108,80,97,114,115,101,69,108,101,109,101,110,116,68,101,99,108,58,32,110,111,32,110,97,109,101,32,102,111,114,32,69,108,101,109,101,110,116,10,0,0,0,0,0,0,0,83,112,97,99,101,32,114,101,113,117,105,114,101,100,32,97,102,116,101,114,32,116,104,101,32,101,108,101,109,101,110,116,32,110,97,109,101,10,0,0,80,69,82,101,102,101,114,101,110,99,101,58,32,102,111,114,98,105,100,100,101,110,32,119,105,116,104,105,110,32,109,97,114,107,117,112,32,100,101,99,108,32,105,110,32,105,110,116,101,114,110,97,108,32,115,117,98,115,101,116,10,0,0,0,120,109,108,80,97,114,115,101,69,108,101,109,101,110,116,68,101,99,108,58,32,39,69,77,80,84,89,39,44,32,39,65,78,89,39,32,111,114,32,39,40,39,32,101,120,112,101,99,116,101,100,10,0,0,0,0,69,108,101,109,101,110,116,32,100,101,99,108,97,114,97,116,105,111,110,32,100,111,101,115,110,39,116,32,115,116,97,114,116,32,97,110,100,32,115,116,111,112,32,105,110,32,116,104,101,32,115,97,109,101,32,101,110,116,105,116,121,10,0,0,83,112,97,99,101,32,110,101,101,100,101,100,32,97,102,116,101,114,32,39,60,63,120,109,108,39,10,0,0,0,0,0,49,46,48,0,0,0,0,0,83,112,97,99,101,32,110,101,101,100,101,100,32,104,101,114,101,10,0,0,0,0,0,0,77,105,115,115,105,110,103,32,101,110,99,111,100,105,110,103,32,105,110,32,116,101,120,116,32,100,101,99,108,97,114,97,116,105,111,110,10,0,0,0,35,120,37,88,0,0,0,0,35,37,100,0,0,0,0,0,105,110,118,97,108,105,100,32,101,110,116,105,116,121,32,116,121,112,101,32,102,111,117,110,100,10,0,0,0,0,0,0,69,110,116,105,116,121,32,39,37,115,39,32,102,97,105,108,101,100,32,116,111,32,112,97,114,115,101,10,0,0,0,0,110,98,107,116,101,120,116,0,120,109,108,80,97,114,115,101,69,110,116,105,116,121,82,101,102,58,32,110,111,32,110,97,109,101,10,0,0,0,0,0,69,110,116,105,116,121,32,39,37,115,39,32,110,111,116,32,100,101,102,105,110,101,100,10,0,0,0,0,0,0,0,0,69,110,116,105,116,121,32,114,101,102,101,114,101,110,99,101,32,116,111,32,117,110,112,97,114,115,101,100,32,101,110,116,105,116,121,32,37,115,10,0,65,116,116,114,105,98,117,116,101,32,114,101,102,101,114,101,110,99,101,115,32,101,120,116,101,114,110,97,108,32,101,110,116,105,116,121,32,39,37,115,39,10,0,0,0,0,0,0,39,60,39,32,105,110,32,101,110,116,105,116,121,32,39,37,115,39,32,105,115,32,110,111,116,32,97,108,108,111,119,101,100,32,105,110,32,97,116,116,114,105,98,117,116,101,115,32,118,97,108,117,101,115,10,0,65,116,116,101,109,112,116,32,116,111,32,114,101,102,101,114,101,110,99,101,32,116,104,101,32,112,97,114,97,109,101,116,101,114,32,101,110,116,105,116,121,32,39,37,115,39,10,0,120,109,108,80,97,114,115,101,80,69,82,101,102,101,114,101,110,99,101,58,32,110,111,32,110,97,109,101,10,0,0,0,73,110,116,101,114,110,97,108,58,32,37,37,37,115,59,32,105,115,32,110,111,116,32,97,32,112,97,114,97,109,101,116,101,114,32,101,110,116,105,116,121,10,0,0,0,0,0,0,120,109,108,80,97,114,115,101,68,111,99,84,121,112,101,68,101,99,108,32,58,32,110,111,32,68,79,67,84,89,80,69,32,110,97,109,101,32,33,10,0,0,0,0,0,0,0,0,101,114,114,111,114,32,112,97,114,115,105,110,103,32,97,116,116,114,105,98,117,116,101,32,110,97,109,101,10,0,0,0,83,112,101,99,105,102,105,99,97,116,105,111,110,32,109,97,110,100,97,116,101,32,118,97,108,117,101,32,102,111,114,32,97,116,116,114,105,98,117,116,101,32,37,115,10,0,0,0,120,109,108,58,108,97,110,103,0,0,0,0,0,0,0,0,77,97,108,102,111,114,109,101,100,32,118,97,108,117,101,32,102,111,114,32,120,109,108,58,108,97,110,103,32,58,32,37,115,10,0,0,0,0,0,0,120,109,108,58,115,112,97,99,101,0,0,0,0,0,0,0,100,101,102,97,117,108,116,0,112,114,101,115,101,114,118,101,0,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,118,97,108,117,101,32,34,37,115,34,32,102,111,114,32,120,109,108,58,115,112,97,99,101,32,58,32,34,100,101,102,97,117,108,116,34,32,111,114,32,34,112,114,101,115,101,114,118,101,34,32,101,120,112,101,99,116,101,100,10,0,0,0,0,120,109,108,80,97,114,115,101,83,116,97,114,116,84,97,103,58,32,105,110,118,97,108,105,100,32,101,108,101,109,101,110,116,32,110,97,109,101,10,0,97,116,116,114,105,98,117,116,101,115,32,99,111,110,115,116,114,117,99,116,32,101,114,114,111,114,10,0,0,0,0,0,120,109,108,80,97,114,115,101,83,116,97,114,116,84,97,103,58,32,112,114,111,98,108,101,109,32,112,97,114,115,105,110,103,32,97,116,116,114,105,98,117,116,101,115,10,0,0,0,67,68,97,116,97,32,115,101,99,116,105,111,110,32,116,111,111,32,98,105,103,32,102,111,117,110,100,0,0,0,0,0,67,68,97,116,97,32,115,101,99,116,105,111,110,32,110,111,116,32,102,105,110,105,115,104,101,100,10,37,46,53,48,115,10,0,0,0,0,0,0,0,100,101,116,101,99,116,101,100,32,97,110,32,101,114,114,111,114,32,105,110,32,101,108,101,109,101,110,116,32,99,111,110,116,101,110,116,10,0,0,0,67,111,117,108,100,110,39,116,32,102,105,110,100,32,101,110,100,32,111,102,32,83,116,97,114,116,32,84,97,103,32,37,115,32,108,105,110,101,32,37,100,10,0,0,0,0,0,0,80,114,101,109,97,116,117,114,101,32,101,110,100,32,111,102,32,100,97,116,97,32,105,110,32,116,97,103,32,37,115,32,108,105,110,101,32,37,100,10,0,0,0,0,0,0,0,0,85,84,70,45,49,54,0,0,85,84,70,49,54,0,0,0,68,111,99,117,109,101,110,116,32,108,97,98,101,108,108,101,100,32,85,84,70,45,49,54,32,98,117,116,32,104,97,115,32,85,84,70,45,56,32,99,111,110,116,101,110,116,10,0,85,84,70,45,56,0,0,0,85,84,70,56,0,0,0,0,85,110,115,117,112,112,111,114,116,101,100,32,101,110,99,111,100,105,110,103,32,37,115,10,0,0,0,0,0,0,0,0,66,108,97,110,107,32,110,101,101,100,101,100,32,97,102,116,101,114,32,39,60,63,120,109,108,39,10,0,0,0,0,0,85,110,115,117,112,112,111,114,116,101,100,32,118,101,114,115,105,111,110,32,39,37,115,39,10,0,0,0,0,0,0,0,66,108,97,110,107,32,110,101,101,100,101,100,32,104,101,114,101,10,0,0,0,0,0,0,83,116,97,114,116,32,116,97,103,32,101,120,112,101,99,116,101,100,44,32,39,60,39,32,110,111,116,32,102,111,117,110,100,10,0,0,0,0,0,0,85,67,83,45,52,0,0,0,85,67,83,52,0,0,0,0,120,109,108,80,97,114,115,101,67,104,117,110,107,58,32,101,110,99,111,100,101,114,32,101,114,114,111,114,10,0,0,0,72,117,103,101,32,105,110,112,117,116,32,108,111,111,107,117,112,0,0,0,0,0,0,0,13,0,0,0,0,0,0,0,99,114,101,97,116,105,110,103,32,112,97,114,115,101,114,58,32,111,117,116,32,111,102,32,109,101,109,111,114,121,10,0,110,111,110,101,0,0,0,0,112,115,101,117,100,111,114,111,111,116,0,0,0,0,0,0,86,101,114,115,105,111,110,32,109,105,115,109,97,116,99,104,32,98,101,116,119,101,101,110,32,100,111,99,117,109,101,110,116,32,97,110,100,32,101,110,116,105,116,121,10,0,0,0,120,109,108,0,0,0,0,0,120,109,108,110,115,0,0,0,104,116,116,112,58,47,47,119,119,119,46,119,51,46,111,114,103,47,88,77,76,47,49,57,57,56,47,110,97,109,101,115,112,97,99,101,0,0,0,0,99,97,110,110,111,116,32,97,108,108,111,99,97,116,101,32,112,97,114,115,101,114,32,99,111,110,116,101,120,116,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,67,111,117,108,100,110,39,116,32,102,105,110,100,32,101,110,100,32,111,102,32,83,116,97,114,116,32,84,97,103,32,37,115,10,0,0,0,0,0,0,60,33,91,67,68,65,84,65,91,0,0,0,0,0,0,0,80,80,58,32,105,110,116,101,114,110,97,108,32,101,114,114,111,114,44,32,115,116,97,116,101,32,61,61,32,67,79,77,77,69,78,84,10,0,0,0,80,80,58,32,105,110,116,101,114,110,97,108,32,101,114,114,111,114,44,32,115,116,97,116,101,32,61,61,32,73,71,78,79,82,69,0,0,0,0,0,80,80,58,32,105,110,116,101,114,110,97,108,32,101,114,114,111,114,44,32,115,116,97,116,101,32,61,61,32,80,73,10,0,0,0,0,0,0,0,0,80,80,58,32,105,110,116,101,114,110,97,108,32,101,114,114,111,114,44,32,115,116,97,116,101,32,61,61,32,69,78,84,73,84,89,95,68,69,67,76,10,0,0,0,0,0,0,0,80,80,58,32,105,110,116,101,114,110,97,108,32,101,114,114,111,114,44,32,115,116,97,116,101,32,61,61,32,69,78,84,73,84,89,95,86,65,76,85,69,10,0,0,0,0,0,0,80,80,58,32,105,110,116,101,114,110,97,108,32,101,114,114,111,114,44,32,115,116,97,116,101,32,61,61,32,65,84,84,82,73,66,85,84,69,95,86,65,76,85,69,10,0,0,0,80,80,58,32,105,110,116,101,114,110,97,108,32,101,114,114,111,114,44,32,115,116,97,116,101,32,61,61,32,83,89,83,84,69,77,95,76,73,84,69,82,65,76,10,0,0,0,0,80,80,58,32,105,110,116,101,114,110,97,108,32,101,114,114,111,114,44,32,115,116,97,116,101,32,61,61,32,80,85,66,76,73,67,95,76,73,84,69,82,65,76,10,0,0,0,0,66,121,116,101,115,58,32,48,120,37,48,50,88,32,48,120,37,48,50,88,32,48,120,37,48,50,88,32,48,120,37,48,50,88,10,0,0,0,0,0,73,110,112,117,116,32,105,115,32,110,111,116,32,112,114,111,112,101,114,32,85,84,70,45,56,44,32,105,110,100,105,99,97,116,101,32,101,110,99,111,100,105,110,103,32,33,10,37,115,0,0,0,0,0,0,0,73,110,116,101,114,110,97,108,32,101,114,114,111,114,58,32,120,109,108,80,97,114,115,101,71,101,116,76,97,115,116,115,10,0,0,0,0,0,0,0,120,109,108,80,97,114,115,101,73,110,116,101,114,110,97,108,83,117,98,115,101,116,58,32,101,114,114,111,114,32,100,101,116,101,99,116,101,100,32,105,110,32,77,97,114,107,117,112,32,100,101,99,108,97,114,97,116,105,111,110,10,0,0,0,117,110,112,97,114,115,101,97,98,108,101,0,0,0,0,0,79,112,101,110,105,110,103,32,97,110,100,32,101,110,100,105,110,103,32,116,97,103,32,109,105,115,109,97,116,99,104,58,32,37,115,32,108,105,110,101,32,37,100,32,97,110,100,32,37,115,10,0,0,0,0,0,70,97,105,108,101,100,32,116,111,32,112,97,114,115,101,32,81,78,97,109,101,32,39,37,115,39,10,0,0,0,0,0,70,97,105,108,101,100,32,116,111,32,112,97,114,115,101,32,81,78,97,109,101,32,39,37,115,58,39,10,0,0,0,0,70,97,105,108,101,100,32,116,111,32,112,97,114,115,101,32,81,78,97,109,101,32,39,37,115,58,37,115,58,39,10,0,78,67,78,97,109,101,0,0,80,98,109,32,112,111,112,112,105,110,103,32,37,100,32,78,83,10,0,0,0,0,0,0,83,116,97,114,116,84,97,103,58,32,105,110,118,97,108,105,100,32,101,108,101,109,101,110,116,32,110,97,109,101,10,0,100,105,99,116,105,111,110,97,114,121,32,97,108,108,111,99,97,116,105,111,110,32,102,97,105,108,117,114,101,0,0,0,120,109,108,110,115,58,32,39,37,115,39,32,105,115,32,110,111,116,32,97,32,118,97,108,105,100,32,85,82,73,10,0,120,109,108,110,115,58,32,85,82,73,32,37,115,32,105,115,32,110,111,116,32,97,98,115,111,108,117,116,101,10,0,0,120,109,108,32,110,97,109,101,115,112,97,99,101,32,85,82,73,32,99,97,110,110,111,116,32,98,101,32,116,104,101,32,100,101,102,97,117,108,116,32,110,97,109,101,115,112,97,99,101,10,0,0,0,0,0,0,104,116,116,112,58,47,47,119,119,119,46,119,51,46,111,114,103,47,50,48,48,48,47,120,109,108,110,115,47,0,0,0,114,101,117,115,101,32,111,102,32,116,104,101,32,120,109,108,110,115,32,110,97,109,101,115,112,97,99,101,32,110,97,109,101,32,105,115,32,102,111,114,98,105,100,100,101,110,10,0,120,109,108,32,110,97,109,101,115,112,97,99,101,32,112,114,101,102,105,120,32,109,97,112,112,101,100,32,116,111,32,119,114,111,110,103,32,85,82,73,10,0,0,0,0,0,0,0,120,109,108,32,110,97,109,101,115,112,97,99,101,32,85,82,73,32,109,97,112,112,101,100,32,116,111,32,119,114,111,110,103,32,112,114,101,102,105,120,10,0,0,0,0,0,0,0,114,101,100,101,102,105,110,105,116,105,111,110,32,111,102,32,116,104,101,32,120,109,108,110,115,32,112,114,101,102,105,120,32,105,115,32,102,111,114,98,105,100,100,101,110,10,0,0,120,109,108,110,115,58,37,115,58,32,69,109,112,116,121,32,88,77,76,32,110,97,109,101,115,112,97,99,101,32,105,115,32,110,111,116,32,97,108,108,111,119,101,100,10,0,0,0,120,109,108,110,115,58,37,115,58,32,39,37,115,39,32,105,115,32,110,111,116,32,97,32,118,97,108,105,100,32,85,82,73,10,0,0,0,0,0,0,120,109,108,110,115,58,37,115,58,32,85,82,73,32,37,115,32,105,115,32,110,111,116,32,97,98,115,111,108,117,116,101,10,0,0,0,0,0,0,0,115,116,97,110,100,97,108,111,110,101,58,32,97,116,116,114,105,98,117,116,101,32,37,115,32,111,110,32,37,115,32,100,101,102,97,117,108,116,101,100,32,102,114,111,109,32,101,120,116,101,114,110,97,108,32,115,117,98,115,101,116,10,0,0,78,97,109,101,115,112,97,99,101,32,112,114,101,102,105,120,32,37,115,32,102,111,114,32,37,115,32,111,110,32,37,115,32,105,115,32,110,111,116,32,100,101,102,105,110,101,100,10,0,0,0,0,0,0,0,0,78,97,109,101,115,112,97,99,101,100,32,65,116,116,114,105,98,117,116,101,32,37,115,32,105,110,32,39,37,115,39,32,114,101,100,101,102,105,110,101,100,10,0,0,0,0,0,0,78,97,109,101,115,112,97,99,101,32,112,114,101,102,105,120,32,37,115,32,111,110,32,37,115,32,105,115,32,110,111,116,32,100,101,102,105,110,101,100,10,0,0,0,0,0,0,0,108,97,110,103,0,0,0,0,115,112,97,99,101,0,0,0,65,116,116,86,97,108,117,101,32,108,101,110,103,116,104,32,116,111,111,32,108,111,110,103,10,0,0,0,0,0,0,0,105,110,118,97,108,105,100,32,99,104,97,114,97,99,116,101,114,32,105,110,32,97,116,116,114,105,98,117,116,101,32,118,97,108,117,101,10,0,0,0,65,116,116,86,97,108,117,101,58,32,39,32,101,120,112,101,99,116,101,100,10,0,0,0,120,109,108,80,97,114,115,101,69,110,100,84,97,103,58,32,39,60,47,39,32,110,111,116,32,102,111,117,110,100,10,0,65,116,116,114,105,98,117,116,101,32,37,115,32,114,101,100,101,102,105,110,101,100,10,0,65,116,116,114,105,98,117,116,101,32,37,115,58,37,115,32,114,101,100,101,102,105,110,101,100,10,0,0,0,0,0,0,120,109,108,80,97,114,115,101,83,116,114,105,110,103,80,69,82,101,102,101,114,101,110,99,101,58,32,110,111,32,110,97,109,101,10,0,0,0,0,0,37,37,37,115,59,32,105,115,32,110,111,116,32,97,32,112,97,114,97,109,101,116,101,114,32,101,110,116,105,116,121,10,0,0,0,0,0,0,0,0,120,109,108,76,111,97,100,69,110,116,105,116,121,67,111,110,116,101,110,116,32,112,97,114,97,109,101,116,101,114,32,101,114,114,111,114,0,0,0,0,82,101,97,100,105,110,103,32,37,115,32,101,110,116,105,116,121,32,99,111,110,116,101,110,116,32,105,110,112,117,116,10,0,0,0,0,0,0,0,0,120,109,108,76,111,97,100,69,110,116,105,116,121,67,111,110,116,101,110,116,32,105,110,112,117,116,32,101,114,114,111,114,0,0,0,0,0,0,0,0,120,109,108,76,111,97,100,69,110,116,105,116,121,67,111,110,116,101,110,116,58,32,105,110,118,97,108,105,100,32,99,104,97,114,32,118,97,108,117,101,32,37,100,10,0,0,0,0,120,109,108,80,97,114,115,101,83,116,114,105,110,103,69,110,116,105,116,121,82,101,102,58,32,110,111,32,110,97,109,101,10,0,0,0,0,0,0,0,65,108,108,32,109,97,114,107,117,112,32,111,102,32,116,104,101,32,99,111,110,100,105,116,105,111,110,97,108,32,115,101,99,116,105,111,110,32,105,115,32,110,111,116,32,105,110,32,116,104,101,32,115,97,109,101,32,101,110,116,105,116,121,10,0,0,0,0,0,0,0,0,69,110,116,101,114,105,110,103,32,73,78,67,76,85,68,69,32,67,111,110,100,105,116,105,111,110,97,108,32,83,101,99,116,105,111,110,10,0,0,0,76,101,97,118,105,110,103,32,73,78,67,76,85,68,69,32,67,111,110,100,105,116,105,111,110,97,108,32,83,101,99,116,105,111,110,10,0,0,0,0,69,110,116,101,114,105,110,103,32,73,71,78,79,82,69,32,67,111,110,100,105,116,105,111,110,97,108,32,83,101,99,116,105,111,110,10,0,0,0,0,76,101,97,118,105,110,103,32,73,71,78,79,82,69,32,67,111,110,100,105,116,105,111,110,97,108,32,83,101,99,116,105,111,110,10,0,0,0,0,0,120,109,108,80,97,114,115,101,69,108,101,109,101,110,116,67,104,105,108,100,114,101,110,67,111,110,116,101,110,116,68,101,99,108,32,58,32,100,101,112,116,104,32,37,100,32,116,111,111,32,100,101,101,112,44,32,117,115,101,32,88,77,76,95,80,65,82,83,69,95,72,85,71,69,10,0,0,0,0,0,120,109,108,80,97,114,115,101,69,108,101,109,101,110,116,67,104,105,108,100,114,101,110,67,111,110,116,101,110,116,68,101,99,108,32,58,32,39,37,99,39,32,101,120,112,101,99,116,101,100,10,0,0,0,0,0,101,120,116,101,114,110,97,108,0,0,0,0,0,0,0,0,99,97,116,97,108,111,103,0,67,97,116,97,108,111,103,32,80,73,32,115,121,110,116,97,120,32,101,114,114,111,114,58,32,37,115,10,0,0,0,0,120,109,108,45,115,116,121,108,101,115,104,101,101,116,0,0,120,109,108,45,109,111,100,101,108,0,0,0,0,0,0,0,120,109,108,80,97,114,115,101,67,111,109,109,101,110,116,58,32,105,110,118,97,108,105,100,32,120,109,108,67,104,97,114,32,118,97,108,117,101,32,37,100,10,0,0,0,0,0,0,67,111,109,109,101,110,116,32,110,111,116,32,116,101,114,109,105,110,97,116,101,100,32,10,60,33,45,45,37,46,53,48,115,10,0,0,0,0,0,0,67,111,109,109,101,110,116,32,100,111,101,115,110,39,116,32,115,116,97,114,116,32,97,110,100,32,115,116,111,112,32,105,110,32,116,104,101,32,115,97,109,101,32,101,110,116,105,116,121,10,0,0,0,0,0,0,67,111,109,109,101,110,116,32,110,111,116,32,116,101,114,109,105,110,97,116,101,100,10,0,80,67,68,65,84,65,32,105,110,118,97,108,105,100,32,67,104,97,114,32,118,97,108,117,101,32,37,100,10,0,0,0,37,115,0,0,0,0,0,0,120,109,108,80,97,114,115,101,83,116,114,105,110,103,67,104,97,114,82,101,102,58,32,105,110,118,97,108,105,100,32,120,109,108,67,104,97,114,32,118,97,108,117,101,32,37,100,10,0,0,0,0,0,0,0,0,120,109,108,78,101,119,66,108,97,110,107,115,87,114,97,112,112,101,114,73,110,112,117,116,83,116,114,101,97,109,32,101,110,116,105,116,121,10,0,0,110,101,119,32,98,108,97,110,107,115,32,119,114,97,112,112,101,114,32,102,111,114,32,101,110,116,105,116,121,58,32,37,115,10,0,0,0,0,0,0,67,104,97,114,82,101,102,58,32,105,110,118,97,108,105,100,32,104,101,120,97,100,101,99,105,109,97,108,32,118,97,108,117,101,0,0,0,0,0,0,67,104,97,114,82,101,102,58,32,105,110,118,97,108,105,100,32,100,101,99,105,109,97,108,32,118,97,108,117,101,0,0,67,104,97,114,82,101,102,58,32,105,110,118,97,108,105,100,32,118,97,108,117,101,0,0,105,110,116,101,114,110,97,108,32,101,114,114,111,114,0,0,80,69,82,101,102,101,114,101,110,99,101,32,97,116,32,101,110,100,32,111,102,32,100,111,99,117,109,101,110,116,0,0,80,69,82,101,102,101,114,101,110,99,101,32,105,110,32,112,114,111,108,111,103,0,0,0,80,69,82,101,102,101,114,101,110,99,101,32,105,110,32,101,112,105,108,111,103,0,0,0,80,69,82,101,102,101,114,101,110,99,101,58,32,110,111,32,110,97,109,101,0,0,0,0,80,69,82,101,102,101,114,101,110,99,101,58,32,101,120,112,101,99,116,105,110,103,32,39,59,39,0,0,0,0,0,0,68,101,116,101,99,116,101,100,32,97,110,32,101,110,116,105,116,121,32,114,101,102,101,114,101,110,99,101,32,108,111,111,112,0,0,0,0,0,0,0,69,110,116,105,116,121,86,97,108,117,101,58,32,34,32,111,114,32,39,32,101,120,112,101,99,116,101,100,0,0,0,0,80,69,82,101,102,101,114,101,110,99,101,115,32,102,111,114,98,105,100,100,101,110,32,105,110,32,105,110,116,101,114,110,97,108,32,115,117,98,115,101,116,0,0,0,0,0,0,0,65,116,116,86,97,108,117,101,58,32,34,32,111,114,32,39,32,101,120,112,101,99,116,101,100,0,0,0,0,0,0,0,85,110,101,115,99,97,112,101,100,32,39,60,39,32,110,111,116,32,97,108,108,111,119,101,100,32,105,110,32,97,116,116,114,105,98,117,116,101,115,32,118,97,108,117,101,115,0,0,83,121,115,116,101,109,76,105,116,101,114,97,108,32,34,32,111,114,32,39,32,101,120,112,101,99,116,101,100,0,0,0,85,110,102,105,110,105,115,104,101,100,32,83,121,115,116,101,109,32,111,114,32,80,117,98,108,105,99,32,73,68,32,34,32,111,114,32,39,32,101,120,112,101,99,116,101,100,0,0,83,101,113,117,101,110,99,101,32,39,93,93,62,39,32,110,111,116,32,97,108,108,111,119,101,100,32,105,110,32,99,111,110,116,101,110,116,0,0,0,83,89,83,84,69,77,32,111,114,32,80,85,66,76,73,67,44,32,116,104,101,32,85,82,73,32,105,115,32,109,105,115,115,105,110,103,0,0,0,0,80,85,66,76,73,67,44,32,116,104,101,32,80,117,98,108,105,99,32,73,100,101,110,116,105,102,105,101,114,32,105,115,32,109,105,115,115,105,110,103,0,0,0,0,0,0,0,0,67,111,109,109,101,110,116,32,109,117,115,116,32,110,111,116,32,99,111,110,116,97,105,110,32,39,45,45,39,32,40,100,111,117,98,108,101,45,104,121,112,104,101,110,41,0,0,0,120,109,108,80,97,114,115,101,80,73,32,58,32,110,111,32,116,97,114,103,101,116,32,110,97,109,101,0,0,0,0,0,73,110,118,97,108,105,100,32,80,73,32,110,97,109,101,0,78,79,84,65,84,73,79,78,58,32,78,97,109,101,32,101,120,112,101,99,116,101,100,32,104,101,114,101,0,0,0,0,39,62,39,32,114,101,113,117,105,114,101,100,32,116,111,32,99,108,111,115,101,32,78,79,84,65,84,73,79,78,32,100,101,99,108,97,114,97,116,105,111,110,0,0,0,0,0,0,69,110,116,105,116,121,32,118,97,108,117,101,32,114,101,113,117,105,114,101,100,0,0,0,70,114,97,103,109,101,110,116,32,110,111,116,32,97,108,108,111,119,101,100,0,0,0,0,39,40,39,32,114,101,113,117,105,114,101,100,32,116,111,32,115,116,97,114,116,32,65,84,84,76,73,83,84,32,101,110,117,109,101,114,97,116,105,111,110,0,0,0,0,0,0,0,78,109,84,111,107,101,110,32,101,120,112,101,99,116,101,100,32,105,110,32,65,84,84,76,73,83,84,32,101,110,117,109,101,114,97,116,105,111,110,0,39,41,39,32,114,101,113,117,105,114,101,100,32,116,111,32,102,105,110,105,115,104,32,65,84,84,76,73,83,84,32,101,110,117,109,101,114,97,116,105,111,110,0,0,0,0,0,0,77,105,120,101,100,67,111,110,116,101,110,116,68,101,99,108,32,58,32,39,124,39,32,111,114,32,39,41,42,39,32,101,120,112,101,99,116,101,100,0,77,105,120,101,100,67,111,110,116,101,110,116,68,101,99,108,32,58,32,39,35,80,67,68,65,84,65,39,32,101,120,112,101,99,116,101,100,0,0,0,67,111,110,116,101,110,116,68,101,99,108,32,58,32,78,97,109,101,32,111,114,32,39,40,39,32,101,120,112,101,99,116,101,100,0,0,0,0,0,0,67,111,110,116,101,110,116,68,101,99,108,32,58,32,39,44,39,32,39,124,39,32,111,114,32,39,41,39,32,101,120,112,101,99,116,101,100,0,0,0,80,69,82,101,102,101,114,101,110,99,101,58,32,102,111,114,98,105,100,100,101,110,32,119,105,116,104,105,110,32,109,97,114,107,117,112,32,100,101,99,108,32,105,110,32,105,110,116,101,114,110,97,108,32,115,117,98,115,101,116,0,0,0,0,101,120,112,101,99,116,101,100,32,39,62,39,0,0,0,0,88,77,76,32,99,111,110,100,105,116,105,111,110,97,108,32,115,101,99,116,105,111,110,32,39,91,39,32,101,120,112,101,99,116,101,100,0,0,0,0,67,111,110,116,101,110,116,32,101,114,114,111,114,32,105,110,32,116,104,101,32,101,120,116,101,114,110,97,108,32,115,117,98,115,101,116,0,0,0,0,99,111,110,100,105,116,105,111,110,97,108,32,115,101,99,116,105,111,110,32,73,78,67,76,85,68,69,32,111,114,32,73,71,78,79,82,69,32,107,101,121,119,111,114,100,32,101,120,112,101,99,116,101,100,0,0,88,77,76,32,99,111,110,100,105,116,105,111,110,97,108,32,115,101,99,116,105,111,110,32,110,111,116,32,99,108,111,115,101,100,0,0,0,0,0,0,84,101,120,116,32,100,101,99,108,97,114,97,116,105,111,110,32,39,60,63,120,109,108,39,32,114,101,113,117,105,114,101,100,0,0,0,0,0,0,0,112,97,114,115,105,110,103,32,88,77,76,32,100,101,99,108,97,114,97,116,105,111,110,58,32,39,63,62,39,32,101,120,112,101,99,116,101,100,0,0,101,120,116,101,114,110,97,108,32,112,97,114,115,101,100,32,101,110,116,105,116,105,101,115,32,99,97,110,110,111,116,32,98,101,32,115,116,97,110,100,97,108,111,110,101,0,0,0,69,110,116,105,116,121,82,101,102,58,32,101,120,112,101,99,116,105,110,103,32,39,59,39,0,0,0,0,0,0,0,0,68,79,67,84,89,80,69,32,105,109,112,114,111,112,101,114,108,121,32,116,101,114,109,105,110,97,116,101,100],"i8",ALLOC_NONE,Runtime.GLOBAL_BASE+64368),
	allocate([69,110,100,84,97,103,58,32,39,60,47,39,32,110,111,116,32,102,111,117,110,100,0,0,101,120,112,101,99,116,101,100,32,39,61,39,0,0,0,0,83,116,114,105,110,103,32,110,111,116,32,99,108,111,115,101,100,32,101,120,112,101,99,116,105,110,103,32,34,32,111,114,32,39,0,0,0,0,0,0,83,116,114,105,110,103,32,110,111,116,32,115,116,97,114,116,101,100,32,101,120,112,101,99,116,105,110,103,32,39,32,111,114,32,34,0,0,0,0,0,73,110,118,97,108,105,100,32,88,77,76,32,101,110,99,111,100,105,110,103,32,110,97,109,101,0,0,0,0,0,0,0,115,116,97,110,100,97,108,111,110,101,32,97,99,99,101,112,116,115,32,111,110,108,121,32,39,121,101,115,39,32,111,114,32,39,110,111,39,0,0,0,68,111,99,117,109,101,110,116,32,105,115,32,101,109,112,116,121,0,0,0,0,0,0,0,69,120,116,114,97,32,99,111,110,116,101,110,116,32,97,116,32,116,104,101,32,101,110,100,32,111,102,32,116,104,101,32,100,111,99,117,109,101,110,116,0,0,0,0,0,0,0,0,99,104,117,110,107,32,105,115,32,110,111,116,32,119,101,108,108,32,98,97,108,97,110,99,101,100,0,0,0,0,0,0,101,120,116,114,97,32,99,111,110,116,101,110,116,32,97,116,32,116,104,101,32,101,110,100,32,111,102,32,119,101,108,108,32,98,97,108,97,110,99,101,100,32,99,104,117,110,107,0,77,97,108,102,111,114,109,101,100,32,100,101,99,108,97,114,97,116,105,111,110,32,101,120,112,101,99,116,105,110,103,32,118,101,114,115,105,111,110,0,78,97,109,101,32,116,111,111,32,108,111,110,103,32,117,115,101,32,88,77,76,95,80,65,82,83,69,95,72,85,71,69,32,111,112,116,105,111,110,0,85,110,114,101,103,105,115,116,101,114,101,100,32,101,114,114,111,114,32,109,101,115,115,97,103,101,0,0,0,0,0,0,37,115,10,0,0,0,0,0,37,115,58,32,37,37,115,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,116,101,120,116,0,0,0,0,116,101,120,116,110,111,101,110,99,0,0,0,0,0,0,0,99,111,109,109,101,110,116,0,98,117,105,108,100,105,110,103,32,81,78,97,109,101,0,0,81,78,97,109,101,32,115,112,108,105,116,0,0,0,0,0,120,109,108,0,0,0,0,0,104,116,116,112,58,47,47,119,119,119,46,119,51,46,111,114,103,47,88,77,76,47,49,57,57,56,47,110,97,109,101,115,112,97,99,101,0,0,0,0,98,117,105,108,100,105,110,103,32,110,97,109,101,115,112,97,99,101,0,0,0,0,0,0,98,117,105,108,100,105,110,103,32,68,84,68,0,0,0,0,98,117,105,108,100,105,110,103,32,105,110,116,101,114,110,97,108,32,115,117,98,115,101,116,0,0,0,0,0,0,0,0,49,46,48,0,0,0,0,0,98,117,105,108,100,105,110,103,32,100,111,99,0,0,0,0,0,0,0,0,0,0,0,0,98,117,105,108,100,105,110,103,32,97,116,116,114,105,98,117,116,101,0,0,0,0,0,0,98,117,105,108,100,105,110,103,32,80,73,0,0,0,0,0,98,117,105,108,100,105,110,103,32,110,111,100,101,0,0,0,98,117,105,108,100,105,110,103,32,116,101,120,116,0,0,0,98,117,105,108,100,105,110,103,32,99,104,97,114,97,99,116,101,114,32,114,101,102,101,114,101,110,99,101,0,0,0,0,98,117,105,108,100,105,110,103,32,114,101,102,101,114,101,110,99,101,0,0,0,0,0,0,98,117,105,108,100,105,110,103,32,99,111,109,109,101,110,116,0,0,0,0,0,0,0,0,98,117,105,108,100,105,110,103,32,67,68,65,84,65,0,0,103,101,116,116,105,110,103,32,110,111,100,101,32,112,97,116,104,0,0,0,0,0,0,0,63,0,0,0,0,0,0,0,47,0,0,0,0,0,0,0,37,115,58,37,115,0,0,0,42,0,0,0,0,0,0,0,99,111,109,109,101,110,116,40,41,0,0,0,0,0,0,0,116,101,120,116,40,41,0,0,112,114,111,99,101,115,115,105,110,103,45,105,110,115,116,114,117,99,116,105,111,110,40,39,37,115,39,41,0,0,0,0,47,64,0,0,0,0,0,0,37,115,0,0,0,0,0,0,37,115,37,115,37,115,0,0,37,115,37,115,91,37,100,93,37,115,0,0,0,0,0,0,108,97,110,103,0,0,0,0,115,112,97,99,101,0,0,0,100,101,102,97,117,108,116,0,112,114,101,115,101,114,118,101,0,0,0,0,0,0,0,0,98,97,115,101,0,0,0,0,104,116,109,108,0,0,0,0,104,101,97,100,0,0,0,0,104,114,101,102,0,0,0,0,104,116,116,112,58,47,47,0,102,116,112,58,47,47,0,0,117,114,110,58,0,0,0,0,103,101,116,116,105,110,103,32,110,97,109,101,115,112,97,99,101,32,108,105,115,116,0,0,115,101,97,114,99,104,105,110,103,32,110,97,109,101,115,112,97,99,101,0,0,0,0,0,1,0,0,0,0,0,0,0,73,83,79,45,56,56,53,57,45,49,0,0,0,0,0,0,99,114,101,97,116,105,110,103,32,98,117,102,102,101,114,0,103,114,111,119,105,110,103,32,98,117,102,102,101,114,0,0,34,0,0,0,0,0,0,0,38,113,117,111,116,59,0,0,39,0,0,0,0,0,0,0,58,0,0,0,0,0,0,0,37,46,50,48,115,0,0,0,100,101,102,97,117,108,116,37,100,0,0,0,0,0,0,0,37,46,50,48,115,37,100,0,97,108,108,111,99,97,116,105,110,103,32,116,104,101,32,88,77,76,32,110,97,109,101,115,112,97,99,101,0,0,0,0,99,111,112,121,105,110,103,32,110,111,100,101,0,0,0,0,105,110,118,97,108,105,100,32,104,101,120,97,100,101,99,105,109,97,108,32,99,104,97,114,97,99,116,101,114,32,118,97,108,117,101,10,0,0,0,0,105,110,118,97,108,105,100,32,100,101,99,105,109,97,108,32,99,104,97,114,97,99,116,101,114,32,118,97,108,117,101,10,0,0,0,0,0,0,0,0,117,110,116,101,114,109,105,110,97,116,101,100,32,101,110,116,105,116,121,32,114,101,102,101,114,101,110,99,101,32,37,49,53,115,10,0,0,0,0,0,115,116,114,105,110,103,32,105,115,32,110,111,116,32,105,110,32,85,84,70,45,56,10,0,117,110,101,120,112,101,99,116,101,100,32,101,114,114,111,114,32,110,117,109,98,101,114,10,0,0,0,0,0,0,0,0,152,45,1,0,176,45,1,0,200,45,1,0,240,45,1,0,8,46,1,0,24,46,1,0,40,46,1,0,64,46,1,0,88,46,1,0,120,46,1,0,136,46,1,0,152,46,1,0,168,46,1,0,184,46,1,0,208,46,1,0,240,46,1,0,8,47,1,0,32,47,1,0,48,47,1,0,72,47,1,0,88,47,1,0,128,47,1,0,152,47,1,0,184,47,1,0,200,47,1,0,232,47,1,0,0,48,1,0,24,48,1,0,48,48,1,0,72,48,1,0,104,48,1,0,120,48,1,0,144,48,1,0,160,48,1,0,200,48,1,0,232,48,1,0,0,49,1,0,16,49,1,0,40,49,1,0,64,49,1,0,80,49,1,0,96,49,1,0,120,49,1,0,136,49,1,0,176,49,1,0,192,49,1,0,208,49,1,0,224,49,1,0,240,49,1,0,0,50,1,0,16,50,1,0,32,50,1,0,56,50,1,0,80,50,1,0,104,50,1,0,120,50,1,0,136,50,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,102,114,101,97,100,40,41,0,102,102,108,117,115,104,40,41,0,0,0,0,0,0,0,0,102,99,108,111,115,101,40,41,0,0,0,0,0,0,0,0,99,114,101,97,116,105,110,103,32,105,110,112,117,116,32,98,117,102,102,101,114,0,0,0,99,114,101,97,116,105,110,103,32,111,117,116,112,117,116,32,98,117,102,102,101,114,0,0,102,105,108,101,0,0,0,0,103,114,111,119,105,110,103,32,105,110,112,117,116,32,98,117,102,102,101,114,0,0,0,0,30,0,0,0,0,0,0,0,98,117,105,108,100,105,110,103,32,99,97,110,111,110,105,99,97,108,32,112,97,116,104,10,0,0,0,0,0,0,0,0,102,116,112,58,47,47,0,0,104,116,116,112,58,47,47,0,78,85,76,76,0,0,0,0,102,97,105,108,101,100,32,116,111,32,108,111,97,100,32,101,120,116,101,114,110,97,108,32,101,110,116,105,116,121,32,34,37,115,34,10,0,0,0,0,102,105,108,101,58,47,47,108,111,99,97,108,104,111,115,116,47,0,0,0,0,0,0,0,102,105,108,101,58,47,47,47,0,0,0,0,0,0,0,0,119,114,105,116,101,40,41,0,99,108,111,115,101,40,41,0,114,101,97,100,40,41,0,0,102,119,114,105,116,101,40,41,0,0,0,0,0,0,0,0,45,0,0,0,0,0,0,0,119,98,0,0,0,0,0,0,102,105,108,101,58,47,0,0,114,0,0,0,0,0,0,0,85,110,107,110,111,119,110,32,73,79,32,101,114,114,111,114,0,0,0,0,0,0,0,0,80,101,114,109,105,115,115,105,111,110,32,100,101,110,105,101,100,0,0,0,0,0,0,0,82,101,115,111,117,114,99,101,32,116,101,109,112,111,114,97,114,105,108,121,32,117,110,97,118,97,105,108,97,98,108,101,0,0,0,0,0,0,0,0,66,97,100,32,102,105,108,101,32,100,101,115,99,114,105,112,116,111,114,0,0,0,0,0,66,97,100,32,109,101,115,115,97,103,101,0,0,0,0,0,82,101,115,111,117,114,99,101,32,98,117,115,121,0,0,0,79,112,101,114,97,116,105,111,110,32,99,97,110,99,101,108,101,100,0,0,0,0,0,0,78,111,32,99,104,105,108,100,32,112,114,111,99,101,115,115,101,115,0,0,0,0,0,0,82,101,115,111,117,114,99,101,32,100,101,97,100,108,111,99,107,32,97,118,111,105,100,101,100,0,0,0,0,0,0,0,68,111,109,97,105,110,32,101,114,114,111,114,0,0,0,0,70,105,108,101,32,101,120,105,115,116,115,0,0,0,0,0,66,97,100,32,97,100,100,114,101,115,115,0,0,0,0,0,70,105,108,101,32,116,111,111,32,108,97,114,103,101,0,0,79,112,101,114,97,116,105,111,110,32,105,110,32,112,114,111,103,114,101,115,115,0,0,0,73,110,116,101,114,114,117,112,116,101,100,32,102,117,110,99,116,105,111,110,32,99,97,108,108,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,97,114,103,117,109,101,110,116,0,0,0,0,0,0,0,0,73,110,112,117,116,47,111,117,116,112,117,116,32,101,114,114,111,114,0,0,0,0,0,0,73,115,32,97,32,100,105,114,101,99,116,111,114,121,0,0,84,111,111,32,109,97,110,121,32,111,112,101,110,32,102,105,108,101,115,0,0,0,0,0,84,111,111,32,109,97,110,121,32,108,105,110,107,115,0,0,73,110,97,112,112,114,111,112,114,105,97,116,101,32,109,101,115,115,97,103,101,32,98,117,102,102,101,114,32,108,101,110,103,116,104,0,0,0,0,0,70,105,108,101,110,97,109,101,32,116,111,111,32,108,111,110,103,0,0,0,0,0,0,0,84,111,111,32,109,97,110,121,32,111,112,101,110,32,102,105,108,101,115,32,105,110,32,115,121,115,116,101,109,0,0,0,78,111,32,115,117,99,104,32,100,101,118,105,99,101,0,0,78,111,32,115,117,99,104,32,102,105,108,101,32,111,114,32,100,105,114,101,99,116,111,114,121,0,0,0,0,0,0,0,69,120,101,99,32,102,111,114,109,97,116,32,101,114,114,111,114,0,0,0,0,0,0,0,78,111,32,108,111,99,107,115,32,97,118,97,105,108,97,98,108,101,0,0,0,0,0,0,78,111,116,32,101,110,111,117,103,104,32,115,112,97,99,101,0,0,0,0,0,0,0,0,78,111,32,115,112,97,99,101,32,108,101,102,116,32,111,110,32,100,101,118,105,99,101,0,70,117,110,99,116,105,111,110,32,110,111,116,32,105,109,112,108,101,109,101,110,116,101,100,0,0,0,0,0,0,0,0,78,111,116,32,97,32,100,105,114,101,99,116,111,114,121,0,68,105,114,101,99,116,111,114,121,32,110,111,116,32,101,109,112,116,121,0,0,0,0,0,78,111,116,32,115,117,112,112,111,114,116,101,100,0,0,0,73,110,97,112,112,114,111,112,114,105,97,116,101,32,73,47,79,32,99,111,110,116,114,111,108,32,111,112,101,114,97,116,105,111,110,0,0,0,0,0,78,111,32,115,117,99,104,32,100,101,118,105,99,101,32,111,114,32,97,100,100,114,101,115,115,0,0,0,0,0,0,0,79,112,101,114,97,116,105,111,110,32,110,111,116,32,112,101,114,109,105,116,116,101,100,0,66,114,111,107,101,110,32,112,105,112,101,0,0,0,0,0,82,101,115,117,108,116,32,116,111,111,32,108,97,114,103,101,0,0,0,0,0,0,0,0,82,101,97,100,45,111,110,108,121,32,102,105,108,101,32,115,121,115,116,101,109,0,0,0,73,110,118,97,108,105,100,32,115,101,101,107,0,0,0,0,78,111,32,115,117,99,104,32,112,114,111,99,101,115,115,0,79,112,101,114,97,116,105,111,110,32,116,105,109,101,100,32,111,117,116,0,0,0,0,0,73,109,112,114,111,112,101,114,32,108,105,110,107,0,0,0,65,116,116,101,109,112,116,32,116,111,32,108,111,97,100,32,110,101,116,119,111,114,107,32,101,110,116,105,116,121,32,37,115,0,0,0,0,0,0,0,101,110,99,111,100,101,114,32,101,114,114,111,114,0,0,0,102,108,117,115,104,32,101,114,114,111,114,0,0,0,0,0,119,114,105,116,101,32,101,114,114,111,114,0,0,0,0,0,110,111,32,105,110,112,117,116,0,0,0,0,0,0,0,0,98,117,102,102,101,114,32,102,117,108,108,0,0,0,0,0,108,111,97,100,105,110,103,32,101,114,114,111,114,0,0,0,110,111,116,32,97,32,115,111,99,107,101,116,0,0,0,0,97,108,114,101,97,100,121,32,99,111,110,110,101,99,116,101,100,0,0,0,0,0,0,0,99,111,110,110,101,99,116,105,111,110,32,114,101,102,117,115,101,100,0,0,0,0,0,0,117,110,114,101,97,99,104,97,98,108,101,32,110,101,116,119,111,114,107,0,0,0,0,0,97,100,100,100,114,101,115,115,32,105,110,32,117,115,101,0,97,108,114,101,97,100,121,32,105,110,32,117,115,101,0,0,117,110,107,110,111,119,110,32,97,100,100,114,101,115,115,32,102,97,109,105,108,108,121,0,120,109,108,77,97,108,108,111,99,66,114,101,97,107,112,111,105,110,116,32,114,101,97,99,104,101,100,32,111,110,32,98,108,111,99,107,32,37,100,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,120,109,108,77,97,108,108,111,99,76,111,99,32,58,32,79,117,116,32,111,102,32,102,114,101,101,32,115,112,97,99,101,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,37,112,32,58,32,77,97,108,108,111,99,40,37,108,117,41,32,79,107,10,0,0,0,0,110,111,110,101,0,0,0,0,37,112,32,58,32,82,101,97,108,108,111,99,101,100,40,37,108,117,32,45,62,32,37,108,117,41,32,79,107,10,0,0,116,114,121,105,110,103,32,116,111,32,102,114,101,101,32,112,111,105,110,116,101,114,32,102,114,111,109,32,102,114,101,101,100,32,97,114,101,97,10,0,37,112,32,58,32,70,114,101,101,100,40,41,10,0,0,0,120,109,108,77,101,109,70,114,101,101,40,37,108,88,41,32,101,114,114,111,114,10,0,0,37,112,32,58,32,83,116,114,100,117,112,40,41,32,79,107,10,0,0,0,0,0,0,0,32,32,32,32,32,32,77,69,77,79,82,89,32,65,76,76,79,67,65,84,69,68,32,58,32,37,108,117,44,32,77,65,88,32,119,97,115,32,37,108,117,10,0,0,0,0,0,0,88,77,76,95,77,69,77,95,66,82,69,65,75,80,79,73,78,84,0,0,0,0,0,0,37,117,100,0,0,0,0,0,88,77,76,95,77,69,77,95,84,82,65,67,69,0,0,0,37,112,0,0,0,0,0,0,77,101,109,111,114,121,32,116,97,103,32,101,114,114,111,114,32,111,99,99,117,114,115,32,58,37,112,32,10,9,32,98,121,101,10,0,0,0,0,0,99,114,101,97,116,105,110,103,32,85,82,73,32,115,116,114,117,99,116,117,114,101,10,0,115,97,118,105,110,103,32,85,82,73,10,0,0,0,0,0,58,37,100,0,0,0,0,0,102,105,108,101,0,0,0,0,117,110,101,115,99,97,112,105,110,103,32,85,82,73,32,118,97,108,117,101,10,0,0,0,101,115,99,97,112,105,110,103,32,85,82,73,32,118,97,108,117,101,10,0,0,0,0,0,43,45,46,0,0,0,0,0,58,0,0,0,0,0,0,0,47,63,59,58,64,0,0,0,47,47,0,0,0,0,0,0,59,58,38,61,43,36,44,0,64,0,0,0,0,0,0,0,37,100,0,0,0,0,0,0,58,64,38,61,43,36,44,47,63,59,0,0,0,0,0,0,63,0,0,0,0,0,0,0,59,47,63,58,64,38,61,43,44,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,35,0,0,0,0,0,0,0,114,101,115,111,108,118,105,110,103,32,85,82,73,32,97,103,97,105,110,115,116,32,98,97,115,101,10,0,0,0,0,0,47,0,0,0,0,0,0,0,47,59,38,61,43,36,44,0,98,117,105,108,100,105,110,103,32,114,101,108,97,116,105,118,101,32,85,82,73,10,0,0,58,47,47,0,0,0,0,0,58,47,63,95,46,35,38,59,61,0,0,0,0,0,0,0,114,101,97,99,104,105,110,103,32,97,114,98,105,116,114,97,114,121,32,77,65,88,95,85,82,73,95,76,69,78,71,84,72,32,108,105,109,105,116,10,0,0,0,0,0,0,0,0,77,101,109,111,114,121,32,97,108,108,111,99,97,116,105,111,110,32,102,97,105,108,101,100,32,58,32,37,115,10,0,0,77,101,109,111,114,121,32,97,108,108,111,99,97,116,105,111,110,32,102,97,105,108,101,100,10,0,0,0,0,0,0,0,67,97,110,110,111,116,32,99,114,101,97,116,101,32,97,117,116,111,109,97,116,97,32,102,111,114,32,101,108,101,109,101,110,116,32,37,115,10,0,0,67,111,110,116,101,110,116,32,109,111,100,101,108,32,111,102,32,37,115,32,105,115,32,110,111,116,32,100,101,116,101,114,109,105,110,105,115,116,58,32,37,115,10,0,0,0,0,0,109,97,108,108,111,99,32,102,97,105,108,101,100,0,0,0,120,109,108,78,101,119,69,108,101,109,101,110,116,67,111,110,116,101,110,116,32,58,32,110,97,109,101,32,61,61,32,78,85,76,76,32,33,10,0,0,120,109,108,78,101,119,69,108,101,109,101,110,116,67,111,110,116,101,110,116,32,58,32,110,97,109,101,32,33,61,32,78,85,76,76,32,33,10,0,0,73,110,116,101,114,110,97,108,58,32,69,76,69,77,69,78,84,32,99,111,110,116,101,110,116,32,99,111,114,114,117,112,116,101,100,32,105,110,118,97,108,105,100,32,116,121,112,101,10,0,0,0,0,0,0,0,32,46,46,46,0,0,0,0,40,0,0,0,0,0,0,0,35,80,67,68,65,84,65,0,58,0,0,0,0,0,0,0,32,44,32,0,0,0,0,0,32,124,32,0,0,0,0,0,41,0,0,0,0,0,0,0,63,0,0,0,0,0,0,0,42,0,0,0,0,0,0,0,43,0,0,0,0,0,0,0,120,109,108,65,100,100,69,108,101,109,101,110,116,68,101,99,108,58,32,99,111,110,116,101,110,116,32,33,61,32,78,85,76,76,32,102,111,114,32,69,77,80,84,89,10,0,0,0,120,109,108,65,100,100,69,108,101,109,101,110,116,68,101,99,108,58,32,99,111,110,116,101,110,116,32,33,61,32,78,85,76,76,32,102,111,114,32,65,78,89,10,0,0,0,0,0,120,109,108,65,100,100,69,108,101,109,101,110,116,68,101,99,108,58,32,99,111,110,116,101,110,116,32,61,61,32,78,85,76,76,32,102,111,114,32,77,73,88,69,68,10,0,0,0,120,109,108,65,100,100,69,108,101,109,101,110,116,68,101,99,108,58,32,99,111,110,116,101,110,116,32,61,61,32,78,85,76,76,32,102,111,114,32,69,76,69,77,69,78,84,10,0,73,110,116,101,114,110,97,108,58,32,69,76,69,77,69,78,84,32,100,101,99,108,32,99,111,114,114,117,112,116,101,100,32,105,110,118,97,108,105,100,32,116,121,112,101,10,0,0,120,109,108,65,100,100,69,108,101,109,101,110,116,68,101,99,108,58,32,84,97,98,108,101,32,99,114,101,97,116,105,111,110,32,102,97,105,108,101,100,33,10,0,0,0,0,0,0,82,101,100,101,102,105,110,105,116,105,111,110,32,111,102,32,101,108,101,109,101,110,116,32,37,115,10,0,0,0,0,0,60,33,69,76,69,77,69,78,84,32,0,0,0,0,0,0,32,69,77,80,84,89,62,10,0,0,0,0,0,0,0,0,32,65,78,89,62,10,0,0,32,0,0,0,0,0,0,0,62,10,0,0,0,0,0,0,73,110,116,101,114,110,97,108,58,32,69,76,69,77,69,78,84,32,115,116,114,117,99,116,32,99,111,114,114,117,112,116,101,100,32,105,110,118,97,108,105,100,32,116,121,112,101,10,0,0,0,0,0,0,0,0,73,110,116,101,114,110,97,108,58,32,65,84,84,82,73,66,85,84,69,32,115,116,114,117,99,116,32,99,111,114,114,117,112,116,101,100,32,105,110,118,97,108,105,100,32,116,121,112,101,10,0,0,0,0,0,0,65,116,116,114,105,98,117,116,101,32,37,115,32,111,102,32,37,115,58,32,105,110,118,97,108,105,100,32,100,101,102,97,117,108,116,32,118,97,108,117,101,10,0,0,0,0,0,0,120,109,108,65,100,100,65,116,116,114,105,98,117,116,101,68,101,99,108,58,32,84,97,98,108,101,32,99,114,101,97,116,105,111,110,32,102,97,105,108,101,100,33,10,0,0,0,0,65,116,116,114,105,98,117,116,101,32,37,115,32,111,102,32,101,108,101,109,101,110,116,32,37,115,58,32,97,108,114,101,97,100,121,32,100,101,102,105,110,101,100,10,0,0,0,0,69,108,101,109,101,110,116,32,37,115,32,104,97,115,32,116,111,111,32,109,97,121,32,73,68,32,97,116,116,114,105,98,117,116,101,115,32,100,101,102,105,110,101,100,32,58,32,37,115,10,0,0,0,0,0,0,120,109,108,110,115,0,0,0,60,33,65,84,84,76,73,83,84,32,0,0,0,0,0,0,32,67,68,65,84,65,0,0,32,73,68,0,0,0,0,0,32,73,68,82,69,70,0,0,32,73,68,82,69,70,83,0,32,69,78,84,73,84,89,0,32,69,78,84,73,84,73,69,83,0,0,0,0,0,0,0,32,78,77,84,79,75,69,78,0,0,0,0,0,0,0,0,32,78,77,84,79,75,69,78,83,0,0,0,0,0,0,0,32,40,0,0,0,0,0,0,32,78,79,84,65,84,73,79,78,32,40,0,0,0,0,0,32,35,82,69,81,85,73,82,69,68,0,0,0,0,0,0,32,35,73,77,80,76,73,69,68,0,0,0,0,0,0,0,32,35,70,73,88,69,68,0,73,110,116,101,114,110,97,108,58,32,65,84,84,82,73,66,85,84,69,32,115,116,114,117,99,116,32,99,111,114,114,117,112,116,101,100,32,105,110,118,97,108,105,100,32,100,101,102,10,0,0,0,0,0,0,0,120,109,108,65,100,100,78,111,116,97,116,105,111,110,68,101,99,108,58,32,84,97,98,108,101,32,99,114,101,97,116,105,111,110,32,102,97,105,108,101,100,33,10,0,0,0,0,0,120,109,108,65,100,100,78,111,116,97,116,105,111,110,68,101,99,108,58,32,37,115,32,97,108,114,101,97,100,121,32,100,101,102,105,110,101,100,10,0,60,33,78,79,84,65,84,73,79,78,32,0,0,0,0,0,32,80,85,66,76,73,67,32,0,0,0,0,0,0,0,0,32,83,89,83,84,69,77,32,0,0,0,0,0,0,0,0,32,62,10,0,0,0,0,0,120,109,108,65,100,100,73,68,58,32,84,97,98,108,101,32,99,114,101,97,116,105,111,110,32,102,97,105,108,101,100,33,10,0,0,0,0,0,0,0,73,68,32,37,115,32,97,108,114,101,97,100,121,32,100,101,102,105,110,101,100,10,0,0,105,100,0,0,0,0,0,0,120,109,108,0,0,0,0,0,110,97,109,101,0,0,0,0,97,0,0,0,0,0,0,0,120,109,108,65,100,100,82,101,102,58,32,84,97,98,108,101,32,99,114,101,97,116,105,111,110,32,102,97,105,108,101,100,33,10,0,0,0,0,0,0,120,109,108,65,100,100,82,101,102,58,32,82,101,102,101,114,101,110,99,101,32,108,105,115,116,32,99,114,101,97,116,105,111,110,32,102,97,105,108,101,100,33,10,0,0,0,0,0,120,109,108,65,100,100,82,101,102,58,32,82,101,102,101,114,101,110,99,101,32,108,105,115,116,32,105,110,115,101,114,116,105,111,110,32,102,97,105,108,101,100,33,10,0,0,0,0,78,79,84,65,84,73,79,78,32,37,115,32,105,115,32,110,111,116,32,100,101,99,108,97,114,101,100,10,0,0,0,0,115,116,97,110,100,97,108,111,110,101,58,32,37,115,32,111,110,32,37,115,32,118,97,108,117,101,32,104,97,100,32,116,111,32,98,101,32,110,111,114,109,97,108,105,122,101,100,32,98,97,115,101,100,32,111,110,32,101,120,116,101,114,110,97,108,32,115,117,98,115,101,116,32,100,101,99,108,97,114,97,116,105,111,110,10,0,0,0,83,121,110,116,97,120,32,111,102,32,100,101,102,97,117,108,116,32,118,97,108,117,101,32,102,111,114,32,97,116,116,114,105,98,117,116,101,32,37,115,32,111,102,32,37,115,32,105,115,32,110,111,116,32,118,97,108,105,100,10,0,0,0,0,73,68,32,97,116,116,114,105,98,117,116,101,32,37,115,32,111,102,32,37,115,32,105,115,32,110,111,116,32,118,97,108,105,100,32,109,117,115,116,32,98,101,32,35,73,77,80,76,73,69,68,32,111,114,32,35,82,69,81,85,73,82,69,68,10,0,0,0,0,0,0,0,69,108,101,109,101,110,116,32,37,115,32,104,97,115,32,37,100,32,73,68,32,97,116,116,114,105,98,117,116,101,32,100,101,102,105,110,101,100,32,105,110,32,116,104,101,32,105,110,116,101,114,110,97,108,32,115,117,98,115,101,116,32,58,32,37,115,10,0,0,0,0,0,69,108,101,109,101,110,116,32,37,115,32,104,97,115,32,37,100,32,73,68,32,97,116,116,114,105,98,117,116,101,32,100,101,102,105,110,101,100,32,105,110,32,116,104,101,32,101,120,116,101,114,110,97,108,32,115,117,98,115,101,116,32,58,32,37,115,10,0,0,0,0,0,69,108,101,109,101,110,116,32,37,115,32,104,97,115,32,73,68,32,97,116,116,114,105,98,117,116,101,115,32,100,101,102,105,110,101,100,32,105,110,32,116,104,101,32,105,110,116,101,114,110,97,108,32,97,110,100,32,101,120,116,101,114,110,97,108,32,115,117,98,115,101,116,32,58,32,37,115,10,0,0,68,101,102,97,117,108,116,32,118,97,108,117,101,32,34,37,115,34,32,102,111,114,32,97,116,116,114,105,98,117,116,101,32,37,115,32,111,102,32,37,115,32,105,115,32,110,111,116,32,97,109,111,110,103,32,116,104,101,32,101,110,117,109,101,114,97,116,101,100,32,115,101,116,10,0,0,0,0,0,0,68,101,102,105,110,105,116,105,111,110,32,111,102,32,37,115,32,104,97,115,32,100,117,112,108,105,99,97,116,101,32,114,101,102,101,114,101,110,99,101,115,32,111,102,32,37,115,10,0,0,0,0,0,0,0,0,68,101,102,105,110,105,116,105,111,110,32,111,102,32,37,115,32,104,97,115,32,100,117,112,108,105,99,97,116,101,32,114,101,102,101,114,101,110,99,101,115,32,111,102,32,37,115,58,37,115,10,0,0,0,0,0,68,101,102,105,110,105,116,105,111,110,32,111,102,32,37,115,32,104,97,115,32,100,117,112,108,105,99,97,116,101,32,114,101,102,101,114,101,110,99,101,115,32,116,111,32,37,115,10,0,0,0,0,0,0,0,0,68,101,102,105,110,105,116,105,111,110,32,111,102,32,37,115,32,104,97,115,32,100,117,112,108,105,99,97,116,101,32,114,101,102,101,114,101,110,99,101,115,32,116,111,32,37,115,58,37,115,10,0,0,0,0,0,78,111,32,100,101,99,108,97,114,97,116,105,111,110,32,102,111,114,32,97,116,116,114,105,98,117,116,101,32,37,115,32,111,102,32,101,108,101,109,101,110,116,32,37,115,10,0,0,83,121,110,116,97,120,32,111,102,32,118,97,108,117,101,32,102,111,114,32,97,116,116,114,105,98,117,116,101,32,37,115,32,111,102,32,37,115,32,105,115,32,110,111,116,32,118,97,108,105,100,10,0,0,0,0,86,97,108,117,101,32,102,111,114,32,97,116,116,114,105,98,117,116,101,32,37,115,32,111,102,32,37,115,32,105,115,32,100,105,102,102,101,114,101,110,116,32,102,114,111,109,32,100,101,102,97,117,108,116,32,34,37,115,34,10,0,0,0,0,86,97,108,117,101,32,34,37,115,34,32,102,111,114,32,97,116,116,114,105,98,117,116,101,32,37,115,32,111,102,32,37,115,32,105,115,32,110,111,116,32,97,32,100,101,99,108,97,114,101,100,32,78,111,116,97,116,105,111,110,10,0,0,0,86,97,108,117,101,32,34,37,115,34,32,102,111,114,32,97,116,116,114,105,98,117,116,101,32,37,115,32,111,102,32,37,115,32,105,115,32,110,111,116,32,97,109,111,110,103,32,116,104,101,32,101,110,117,109,101,114,97,116,101,100,32,110,111,116,97,116,105,111,110,115,10,0,0,0,0,0,0,0,0,86,97,108,117,101,32,34,37,115,34,32,102,111,114,32,97,116,116,114,105,98,117,116,101,32,37,115,32,111,102,32,37,115,32,105,115,32,110,111,116,32,97,109,111,110,103,32,116,104,101,32,101,110,117,109,101,114,97,116,101,100,32,115,101,116,10,0,0,0,0,0,0,86,97,108,117,101,32,102,111,114,32,97,116,116,114,105,98,117,116,101,32,37,115,32,111,102,32,37,115,32,109,117,115,116,32,98,101,32,34,37,115,34,10,0,0,0,0,0,0,86,97,108,105,100,97,116,105,110,103,32,110,97,109,101,115,112,97,99,101,0,0,0,0,78,111,32,100,101,99,108,97,114,97,116,105,111,110,32,102,111,114,32,97,116,116,114,105,98,117,116,101,32,120,109,108,110,115,58,37,115,32,111,102,32,101,108,101,109,101,110,116,32,37,115,10,0,0,0,0,78,111,32,100,101,99,108,97,114,97,116,105,111,110,32,102,111,114,32,97,116,116,114,105,98,117,116,101,32,120,109,108,110,115,32,111,102,32,101,108,101,109,101,110,116,32,37,115,10,0,0,0,0,0,0,0,83,121,110,116,97,120,32,111,102,32,118,97,108,117,101,32,102,111,114,32,97,116,116,114,105,98,117,116,101,32,120,109,108,110,115,58,37,115,32,111,102,32,37,115,32,105,115,32,110,111,116,32,118,97,108,105,100,10,0,0,0,0,0,0,83,121,110,116,97,120,32,111,102,32,118,97,108,117,101,32,102,111,114,32,97,116,116,114,105,98,117,116,101,32,120,109,108,110,115,32,111,102,32,37,115,32,105,115,32,110,111,116,32,118,97,108,105,100,10,0,86,97,108,117,101,32,102,111,114,32,97,116,116,114,105,98,117,116,101,32,120,109,108,110,115,58,37,115,32,111,102,32,37,115,32,105,115,32,100,105,102,102,101,114,101,110,116,32,102,114,111,109,32,100,101,102,97,117,108,116,32,34,37,115,34,10,0,0,0,0,0,0,86,97,108,117,101,32,102,111,114,32,97,116,116,114,105,98,117,116,101,32,120,109,108,110,115,32,111,102,32,37,115,32,105,115,32,100,105,102,102,101,114,101,110,116,32,102,114,111,109,32,100,101,102,97,117,108,116,32,34,37,115,34,10,0,86,97,108,117,101,32,34,37,115,34,32,102,111,114,32,97,116,116,114,105,98,117,116,101,32,120,109,108,110,115,58,37,115,32,111,102,32,37,115,32,105,115,32,110,111,116,32,97,32,100,101,99,108,97,114,101,100,32,78,111,116,97,116,105,111,110,10,0,0,0,0,0,86,97,108,117,101,32,34,37,115,34,32,102,111,114,32,97,116,116,114,105,98,117,116,101,32,120,109,108,110,115,32,111,102,32,37,115,32,105,115,32,110,111,116,32,97,32,100,101,99,108,97,114,101,100,32,78,111,116,97,116,105,111,110,10,0,0,0,0,0,0,0,0,86,97,108,117,101,32,34,37,115,34,32,102,111,114,32,97,116,116,114,105,98,117,116,101,32,120,109,108,110,115,58,37,115,32,111,102,32,37,115,32,105,115,32,110,111,116,32,97,109,111,110,103,32,116,104,101,32,101,110,117,109,101,114,97,116,101,100,32,110,111,116,97,116,105,111,110,115,10,0,0,86,97,108,117,101,32,34,37,115,34,32,102,111,114,32,97,116,116,114,105,98,117,116,101,32,120,109,108,110,115,32,111,102,32,37,115,32,105,115,32,110,111,116,32,97,109,111,110,103,32,116,104,101,32,101,110,117,109,101,114,97,116,101,100,32,110,111,116,97,116,105,111,110,115,10,0,0,0,0,0,86,97,108,117,101,32,34,37,115,34,32,102,111,114,32,97,116,116,114,105,98,117,116,101,32,120,109,108,110,115,58,37,115,32,111,102,32,37,115,32,105,115,32,110,111,116,32,97,109,111,110,103,32,116,104,101,32,101,110,117,109,101,114,97,116,101,100,32,115,101,116,10,0,0,0,0,0,0,0,0,86,97,108,117,101,32,34,37,115,34,32,102,111,114,32,97,116,116,114,105,98,117,116,101,32,120,109,108,110,115,32,111,102,32,37,115,32,105,115,32,110,111,116,32,97,109,111,110,103,32,116,104,101,32,101,110,117,109,101,114,97,116,101,100,32,115,101,116,10,0,0,0,86,97,108,117,101,32,102,111,114,32,97,116,116,114,105,98,117,116,101,32,120,109,108,110,115,58,37,115,32,111,102,32,37,115,32,109,117,115,116,32,98,101,32,34,37,115,34,10,0,0,0,0,0,0,0,0,86,97,108,117,101,32,102,111,114,32,97,116,116,114,105,98,117,116,101,32,120,109,108,110,115,32,111,102,32,37,115,32,109,117,115,116,32,98,101,32,34,37,115,34,10,0,0,0,69,108,101,109,101,110,116,32,37,115,32,119,97,115,32,100,101,99,108,97,114,101,100,32,69,77,80,84,89,32,116,104,105,115,32,111,110,101,32,104,97,115,32,99,111,110,116,101,110,116,10,0,0,0,0,0,69,108,101,109,101,110,116,32,37,115,32,119,97,115,32,100,101,99,108,97,114,101,100,32,35,80,67,68,65,84,65,32,98,117,116,32,99,111,110,116,97,105,110,115,32,110,111,110,32,116,101,120,116,32,110,111,100,101,115,10,0,0,0,0,69,108,101,109,101,110,116,32,37,115,32,105,115,32,110,111,116,32,100,101,99,108,97,114,101,100,32,105,110,32,37,115,32,108,105,115,116,32,111,102,32,112,111,115,115,105,98,108,101,32,99,104,105,108,100,114,101,110,10,0,0,0,0,0,69,108,101,109,101,110,116,32,37,115,32,99,111,110,116,101,110,116,32,100,111,101,115,32,110,111,116,32,102,111,108,108,111,119,32,116,104,101,32,68,84,68,44,32,77,105,115,112,108,97,99,101,100,32,37,115,10,0,0,0,0,0,0,0,69,108,101,109,101,110,116,32,37,115,32,99,111,110,116,101,110,116,32,100,111,101,115,32,110,111,116,32,102,111,108,108,111,119,32,116,104,101,32,68,84,68,44,32,84,101,120,116,32,110,111,116,32,97,108,108,111,119,101,100,10,0,0,0,69,108,101,109,101,110,116,32,37,115,32,99,111,110,116,101,110,116,32,100,111,101,115,32,110,111,116,32,102,111,108,108,111,119,32,116,104,101,32,68,84,68,44,32,69,120,112,101,99,116,105,110,103,32,109,111,114,101,32,99,104,105,108,100,10,0,0,0,0,0,0,0,65,116,116,114,105,98,117,116,101,32,101,108,101,109,101,110,116,32,110,111,116,32,101,120,112,101,99,116,101,100,10,0,84,101,120,116,32,101,108,101,109,101,110,116,32,104,97,115,32,99,104,105,108,100,114,101,110,32,33,10,0,0,0,0,84,101,120,116,32,101,108,101,109,101,110,116,32,104,97,115,32,110,97,109,101,115,112,97,99,101,32,33,10,0,0,0,84,101,120,116,32,101,108,101,109,101,110,116,32,104,97,115,32,110,111,32,99,111,110,116,101,110,116,32,33,10,0,0,69,110,116,105,116,121,32,101,108,101,109,101,110,116,32,110,111,116,32,101,120,112,101,99,116,101,100,10,0,0,0,0,78,111,116,97,116,105,111,110,32,101,108,101,109,101,110,116,32,110,111,116,32,101,120,112,101,99,116,101,100,10,0,0,68,111,99,117,109,101,110,116,32,101,108,101,109,101,110,116,32,110,111,116,32,101,120,112,101,99,116,101,100,10,0,0,72,84,77,76,32,68,111,99,117,109,101,110,116,32,110,111,116,32,101,120,112,101,99,116,101,100,10,0,0,0,0,0,117,110,107,110,111,119,110,32,101,108,101,109,101,110,116,32,116,121,112,101,10,0,0,0,78,111,32,100,101,99,108,97,114,97,116,105,111,110,32,102,111,114,32,101,108,101,109,101,110,116,32,37,115,10,0,0,73,110,116,101,114,110,97,108,58,32,77,73,88,69,68,32,115,116,114,117,99,116,32,99,111,114,114,117,112,116,101,100,10,0,0,0,0,0,0,0,115,116,97,110,100,97,108,111,110,101,58,32,37,115,32,100,101,99,108,97,114,101,100,32,105,110,32,116,104,101,32,101,120,116,101,114,110,97,108,32,115,117,98,115,101,116,32,99,111,110,116,97,105,110,115,32,119,104,105,116,101,32,115,112,97,99,101,115,32,110,111,100,101,115,10,0,0,0,0,0,69,108,101,109,101,110,116,32,37,115,32,100,111,101,115,32,110,111,116,32,99,97,114,114,121,32,97,116,116,114,105,98,117,116,101,32,37,115,10,0,69,108,101,109,101,110,116,32,37,115,32,100,111,101,115,32,110,111,116,32,99,97,114,114,121,32,97,116,116,114,105,98,117,116,101,32,37,115,58,37,115,10,0,0,0,0,0,0,69,108,101,109,101,110,116,32,37,115,32,114,101,113,117,105,114,101,100,32,97,116,116,114,105,98,117,116,101,32,37,115,58,37,115,32,104,97,115,32,110,111,32,112,114,101,102,105,120,10,0,0,0,0,0,0,69,108,101,109,101,110,116,32,37,115,32,114,101,113,117,105,114,101,100,32,97,116,116,114,105,98,117,116,101,32,37,115,58,37,115,32,104,97,115,32,100,105,102,102,101,114,101,110,116,32,112,114,101,102,105,120,10,0,0,0,0,0,0,0,69,108,101,109,101,110,116,32,37,115,32,110,97,109,101,115,112,97,99,101,32,110,97,109,101,32,102,111,114,32,100,101,102,97,117,108,116,32,110,97,109,101,115,112,97,99,101,32,100,111,101,115,32,110,111,116,32,109,97,116,99,104,32,116,104,101,32,68,84,68,10,0,69,108,101,109,101,110,116,32,37,115,32,110,97,109,101,115,112,97,99,101,32,110,97,109,101,32,102,111,114,32,37,115,32,100,111,101,115,32,110,111,116,32,109,97,116,99,104,32,116,104,101,32,68,84,68,10,0,0,0,0,0,0,0,0,110,111,32,114,111,111,116,32,101,108,101,109,101,110,116,10,0,0,0,0,0,0,0,0,72,84,77,76,0,0,0,0,104,116,109,108,0,0,0,0,114,111,111,116,32,97,110,100,32,68,84,68,32,110,97,109,101,32,100,111,32,110,111,116,32,109,97,116,99,104,32,39,37,115,39,32,97,110,100,32,39,37,115,39,10,0,0,0,120,109,108,86,97,108,105,100,97,116,101,68,111,99,117,109,101,110,116,70,105,110,97,108,58,32,100,111,99,32,61,61,32,78,85,76,76,10,0,0,110,111,32,68,84,68,32,102,111,117,110,100,33,10,0,0,67,111,117,108,100,32,110,111,116,32,98,117,105,108,100,32,85,82,73,32,102,111,114,32,101,120,116,101,114,110,97,108,32,115,117,98,115,101,116,32,34,37,115,34,10,0,0,0,67,111,117,108,100,32,110,111,116,32,108,111,97,100,32,116,104,101,32,101,120,116,101,114,110,97,108,32,115,117,98,115,101,116,32,34,37,115,34,10,0,0,0,0,0,0,0,0,60,33,100,117,109,109,121,63,62,0,0,0,0,0,0,0,120,109,108,86,97,108,105,100,97,116,101,65,116,116,114,105,98,117,116,101,67,97,108,108,98,97,99,107,40,37,115,41,58,32,105,110,116,101,114,110,97,108,32,101,114,114,111,114,10,0,0,0,0,0,0,0,97,116,116,114,105,98,117,116,101,32,37,115,58,32,99,111,117,108,100,32,110,111,116,32,102,105,110,100,32,100,101,99,108,32,102,111,114,32,101,108,101,109,101,110,116,32,37,115,10,0,0,0,0,0,0,0,78,79,84,65,84,73,79,78,32,97,116,116,114,105,98,117,116,101,32,37,115,32,100,101,99,108,97,114,101,100,32,102,111,114,32,69,77,80,84,89,32,101,108,101,109,101,110,116,32,37,115,10,0,0,0,0,97,116,116,114,105,98,117,116,101,32,37,115,32,108,105,110,101,32,37,100,32,114,101,102,101,114,101,110,99,101,115,32,97,110,32,117,110,107,110,111,119,110,32,73,68,32,34,37,115,34,10,0,0,0,0,0,73,68,82,69,70,32,97,116,116,114,105,98,117,116,101,32,37,115,32,114,101,102,101,114,101,110,99,101,115,32,97,110,32,117,110,107,110,111,119,110,32,73,68,32,34,37,115,34],"i8",ALLOC_NONE,Runtime.GLOBAL_BASE+74608),
	allocate([10,0,0,0,0,0,0,0,73,68,82,69,70,83,32,115,112,108,105,116,0,0,0,0,73,68,82,69,70,83,32,97,116,116,114,105,98,117,116,101,32,37,115,32,114,101,102,101,114,101,110,99,101,115,32,97,110,32,117,110,107,110,111,119,110,32,73,68,32,34,37,115,34,10,0,0,0,0,0,0,69,108,101,109,101,110,116,32,37,115,32,99,111,110,116,101,110,116,32,100,111,101,115,32,110,111,116,32,102,111,108,108,111,119,32,116,104,101,32,68,84,68,44,32,101,120,112,101,99,116,105,110,103,32,37,115,44,32,103,111,116,32,37,115,10,0,0,0,0,0,0,0,69,108,101,109,101,110,116,32,99,111,110,116,101,110,116,32,100,111,101,115,32,110,111,116,32,102,111,108,108,111,119,32,116,104,101,32,68,84,68,44,32,101,120,112,101,99,116,105,110,103,32,37,115,44,32,103,111,116,32,37,115,10,0,0,69,108,101,109,101,110,116,32,37,115,32,99,111,110,116,101,110,116,32,100,111,101,115,32,110,111,116,32,102,111,108,108,111,119,32,116,104,101,32,68,84,68,10,0,0,0,0,0,69,108,101,109,101,110,116,32,99,111,110,116,101,110,116,32,100,111,101,115,32,110,111,116,32,102,111,108,108,111,119,32,116,104,101,32,68,84,68,10,0,0,0,0,0,0,0,0,67,68,65,84,65,0,0,0,63,63,63,0,0,0,0,0,114,101,97,108,108,111,99,32,102,97,105,108,101,100,0,0,70,97,105,108,101,100,32,116,111,32,98,117,105,108,100,32,99,111,110,116,101,110,116,32,109,111,100,101,108,32,114,101,103,101,120,112,32,102,111,114,32,37,115,10,0,0,0,0,69,78,84,73,84,89,32,97,116,116,114,105,98,117,116,101,32,37,115,32,114,101,102,101,114,101,110,99,101,32,97,110,32,117,110,107,110,111,119,110,32,101,110,116,105,116,121,32,34,37,115,34,10,0,0,0,69,78,84,73,84,89,32,97,116,116,114,105,98,117,116,101,32,37,115,32,114,101,102,101,114,101,110,99,101,32,97,110,32,101,110,116,105,116,121,32,34,37,115,34,32,111,102,32,119,114,111,110,103,32,116,121,112,101,10,0,0,0,0,0,69,78,84,73,84,73,69,83,32,97,116,116,114,105,98,117,116,101,32,37,115,32,114,101,102,101,114,101,110,99,101,32,97,110,32,117,110,107,110,111,119,110,32,101,110,116,105,116,121,32,34,37,115,34,10,0,69,78,84,73,84,73,69,83,32,97,116,116,114,105,98,117,116,101,32,37,115,32,114,101,102,101,114,101,110,99,101,32,97,110,32,101,110,116,105,116,121,32,34,37,115,34,32,111,102,32,119,114,111,110,103,32,116,121,112,101,10,0,0,0,78,79,84,65,84,73,79,78,32,97,116,116,114,105,98,117,116,101,32,37,115,32,114,101,102,101,114,101,110,99,101,32,97,110,32,117,110,107,110,111,119,110,32,110,111,116,97,116,105,111,110,32,34,37,115,34,10,0,0,0,0,0,0,0,101,108,101,109,101,110,116,32,116,97,98,108,101,32,97,108,108,111,99,97,116,105,111,110,32,102,97,105,108,101,100,0,69,108,101,109,101,110,116,32,37,115,32,104,97,115,32,116,111,111,32,109,97,110,121,32,73,68,32,97,116,116,114,105,98,117,116,101,115,32,100,101,102,105,110,101,100,32,58,32,37,115,10,0,0,0,0,0,37,115,0,0,0,0,0,0,77,101,109,111,114,121,32,97,108,108,111,99,97,116,105,111,110,32,102,97,105,108,101,100,32,58,32,37,115,10,0,0,77,101,109,111,114,121,32,97,108,108,111,99,97,116,105,111,110,32,102,97,105,108,101,100,10,0,0,0,0,0,0,0,70,111,117,110,100,32,78,85,76,76,32,99,111,110,116,101,110,116,32,105,110,32,99,111,110,116,101,110,116,32,109,111,100,101,108,32,111,102,32,37,115,10,0,0,0,0,0,0,70,111,117,110,100,32,80,67,68,65,84,65,32,105,110,32,99,111,110,116,101,110,116,32,109,111,100,101,108,32,111,102,32,37,115,10,0,0,0,0,66,117,105,108,100,105,110,103,32,99,111,110,116,101,110,116,32,109,111,100,101,108,0,0,67,111,110,116,101,110,116,77,111,100,101,108,32,98,114,111,107,101,110,32,102,111,114,32,101,108,101,109,101,110,116,32,37,115,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,200,121,1,0,200,121,1,0,176,119,1,0,136,197,1,0,208,121,1,0,216,121,1,0,224,121,1,0,232,121,1,0,240,121,1,0,248,121,1,0,208,192,1,0,24,212,1,0,112,205,1,0,240,201,1,0,216,191,1,0,56,121,1,0,80,122,1,0,40,216,1,0,48,216,1,0,168,117,1,0,0,0,0,0,168,117,1,0,176,119,1,0,0,0,0,0,216,119,1,0,176,119,1,0,0,0,0,0,160,117,1,0,168,117,1,0,24,115,1,0,208,119,1,0,216,119,1,0,176,119,1,0,0,0,0,0,0,120,1,0,168,117,1,0,24,115,1,0,208,119,1,0,216,119,1,0,176,119,1,0,0,0,0,0,48,122,1,0,176,119,1,0,208,121,1,0,216,121,1,0,224,121,1,0,232,121,1,0,240,121,1,0,248,121,1,0,208,192,1,0,56,121,1,0,80,122,1,0,40,216,1,0,48,216,1,0,168,117,1,0,48,122,1,0,0,0,0,0,136,197,1,0,176,119,1,0,168,117,1,0,0,0,0,0,208,121,1,0,176,119,1,0,168,117,1,0,0,0,0,0,216,121,1,0,176,119,1,0,168,117,1,0,0,0,0,0,224,121,1,0,176,119,1,0,168,117,1,0,0,0,0,0,232,121,1,0,176,119,1,0,168,117,1,0,0,0,0,0,240,121,1,0,176,119,1,0,168,117,1,0,0,0,0,0,248,121,1,0,176,119,1,0,168,117,1,0,0,0,0,0,216,191,1,0,176,119,1,0,168,117,1,0,0,0,0,0,56,121,1,0,176,119,1,0,168,117,1,0,24,212,1,0,0,0,0,0,80,122,1,0,176,119,1,0,168,117,1,0,24,212,1,0,0,0,0,0,40,216,1,0,176,119,1,0,168,117,1,0,0,0,0,0,48,216,1,0,176,119,1,0,168,117,1,0,0,0,0,0,96,121,1,0,176,119,1,0,168,117,1,0,0,0,0,0,208,192,1,0,176,119,1,0,176,121,1,0,240,201,1,0,216,191,1,0,56,121,1,0,80,122,1,0,40,216,1,0,48,216,1,0,168,117,1,0,0,0,0,0,176,121,1,0,176,119,1,0,240,201,1,0,216,191,1,0,56,121,1,0,80,122,1,0,40,216,1,0,48,216,1,0,168,117,1,0,152,121,1,0,0,0,0,0,152,121,1,0,176,119,1,0,240,201,1,0,216,191,1,0,56,121,1,0,80,122,1,0,40,216,1,0,48,216,1,0,168,117,1,0,176,121,1,0,0,0,0,0,24,212,1,0,176,119,1,0,168,117,1,0,112,205,1,0,240,201,1,0,216,191,1,0,56,121,1,0,80,122,1,0,40,216,1,0,48,216,1,0,0,0,0,0,112,205,1,0,176,119,1,0,168,117,1,0,24,212,1,0,0,0,0,0,240,201,1,0,176,119,1,0,168,117,1,0,24,212,1,0,0,0,0,0,176,119,1,0,176,119,1,0,168,117,1,0,208,121,1,0,216,121,1,0,224,121,1,0,232,121,1,0,240,121,1,0,248,121,1,0,144,122,1,0,0,122,1,0,72,121,1,0,152,122,1,0,96,122,1,0,128,122,1,0,88,121,1,0,112,122,1,0,0,0,0,0,96,118,1,0,176,119,1,0,168,117,1,0,0,0,0,0,56,122,1,0,176,119,1,0,0,0,0,0,128,121,1,0,192,121,1,0,72,121,1,0,0,122,1,0,176,119,1,0,168,117,1,0,0,0,0,0,32,121,1,0,32,121,1,0,168,117,1,0,0,0,0,0,120,121,1,0,176,119,1,0,0,0,0,0,32,191,1,0,120,121,1,0,32,191,1,0,176,190,1,0,176,119,1,0,0,0,0,0,176,190,1,0,120,121,1,0,176,190,1,0,176,119,1,0,0,0,0,0,152,118,1,0,176,119,1,0,168,117,1,0,208,121,1,0,216,121,1,0,224,121,1,0,232,121,1,0,240,121,1,0,248,121,1,0,80,122,1,0,40,216,1,0,48,216,1,0,32,121,1,0,0,0,0,0,112,118,1,0,112,118,1,0,104,118,1,0,176,119,1,0,120,122,1,0,192,121,1,0,32,121,1,0,72,121,1,0,0,122,1,0,152,122,1,0,0,0,0,0,104,118,1,0,112,118,1,0,104,118,1,0,176,119,1,0,120,122,1,0,192,121,1,0,32,121,1,0,72,121,1,0,0,122,1,0,152,122,1,0,0,0,0,0,120,118,1,0,112,118,1,0,104,118,1,0,120,118,1,0,120,121,1,0,176,190,1,0,32,191,1,0,176,119,1,0,0,0,0,0,128,118,1,0,120,121,1,0,176,190,1,0,32,191,1,0,0,0,0,0,144,118,1,0,112,118,1,0,104,118,1,0,120,118,1,0,120,121,1,0,176,190,1,0,32,191,1,0,128,118,1,0,136,118,1,0,176,119,1,0,0,0,0,0,136,118,1,0,112,118,1,0,104,118,1,0,120,118,1,0,120,121,1,0,176,190,1,0,32,191,1,0,128,118,1,0,144,118,1,0,136,118,1,0,176,119,1,0,0,0,0,0,160,205,1,0,200,205,1,0,0,0,0,0,200,205,1,0,200,205,1,0,0,0,0,0,184,193,1,0,40,122,1,0,176,119,1,0,168,117,1,0,208,121,1,0,216,121,1,0,224,121,1,0,232,121,1,0,240,121,1,0,248,121,1,0,80,122,1,0,40,216,1,0,48,216,1,0,32,121,1,0,0,0,0,0,144,122,1,0,168,117,1,0,0,0,0,0,0,122,1,0,168,117,1,0,0,0,0,0,72,121,1,0,168,117,1,0,0,0,0,0,152,122,1,0,168,117,1,0,0,0,0,0,96,122,1,0,168,117,1,0,0,0,0,0,128,122,1,0,168,117,1,0,0,0,0,0,88,121,1,0,168,117,1,0,0,0,0,0,112,122,1,0,168,117,1,0,0,0,0,0,184,121,1,0,168,117,1,0,0,0,0,0,136,122,1,0,168,117,1,0,0,0,0,0,168,121,1,0,168,117,1,0,0,0,0,0,144,121,1,0,168,117,1,0,0,0,0,0,104,122,1,0,168,117,1,0,0,0,0,0,24,122,1,0,168,117,1,0,0,0,0,0,160,122,1,0,168,117,1,0,0,0,0,0,136,121,1,0,168,117,1,0,0,0,0,0,40,121,1,0,168,117,1,0,0,0,0,0,48,121,1,0,168,117,1,0,0,0,0,0,112,198,1,0,168,117,1,0,0,0,0,0,192,121,1,0,168,117,1,0,0,0,0,0,168,189,1,0,168,117,1,0,0,0,0,0,96,201,1,0,168,117,1,0,0,0,0,0,88,122,1,0,168,117,1,0,0,0,0,0,104,177,1,0,168,117,1,0,0,0,0,0,144,177,1,0,168,117,1,0,0,0,0,0,120,122,1,0,168,117,1,0,0,0,0,0,80,121,1,0,168,117,1,0,0,0,0,0,8,122,1,0,168,117,1,0,0,0,0,0,0,0,0,0,32,121,1,0,0,0,0,0,0,0,1,0,32,182,1,0,40,182,1,0,0,0,0,0,200,182,1,0,64,183,1,0,0,0,0,0,40,121,1,0,0,0,0,0,0,0,1,0,72,183,1,0,40,182,1,0,0,0,0,0,96,183,1,0,0,0,0,0,0,0,0,0,48,121,1,0,0,0,0,0,0,0,1,0,160,183,1,0,40,182,1,0,0,0,0,0,96,183,1,0,0,0,0,0,0,0,0,0,56,121,1,0,0,0,0,0,0,0,0,0,168,183,1,0,192,183,1,0,0,0,0,0,96,183,1,0,0,0,0,0,0,0,0,0,64,121,1,0,0,0,0,0,1,1,2,0,104,184,1,0,120,184,1,0,0,0,0,0,0,0,0,0,128,185,1,0,0,0,0,0,184,185,1,0,0,2,2,1,0,0,0,0,192,185,1,0,0,0,0,0,0,0,0,0,224,185,1,0,64,183,1,0,8,186,1,0,72,121,1,0,0,3,0,0,0,0,1,0,16,186,1,0,40,182,1,0,0,0,0,0,96,183,1,0,0,0,0,0,0,0,0,0,224,119,1,0,0,2,2,1,0,0,0,0,32,186,1,0,0,0,0,0,0,0,0,0,0,0,0,0,64,183,1,0,56,186,1,0,64,186,1,0,0,2,2,1,1,1,1,0,80,186,1,0,0,0,0,0,0,0,0,0,0,0,0,0,96,186,1,0,0,0,0,0,80,121,1,0,0,0,0,0,0,0,1,0,120,186,1,0,40,182,1,0,0,0,0,0,144,186,1,0,0,0,0,0,176,186,1,0,88,121,1,0,0,3,0,0,0,0,1,0,184,186,1,0,40,182,1,0,0,0,0,0,96,183,1,0,0,0,0,0,0,0,0,0,96,121,1,0,0,0,0,0,0,0,0,0,208,186,1,0,224,186,1,0,0,0,0,0,224,187,1,0,0,0,0,0,0,0,0,0,160,117,1,0,1,1,0,0,0,0,0,0,40,188,1,0,56,188,1,0,96,118,1,0,64,189,1,0,136,189,1,0,0,0,0,0,168,189,1,0,0,2,2,1,0,0,1,0,176,189,1,0,0,0,0,0,0,0,0,0,200,189,1,0,224,189,1,0,0,0,0,0,112,121,1,0,0,0,0,0,0,0,2,0,232,189,1,0,224,186,1,0,0,0,0,0,248,189,1,0,0,0,0,0,0,0,0,0,120,121,1,0,0,0,0,0,0,0,0,0,88,190,1,0,40,182,1,0,0,0,0,0,96,183,1,0,0,0,0,0,0,0,0,0,128,121,1,0,0,3,0,0,1,1,0,0,104,190,1,0,224,186,1,0,0,0,0,0,0,0,0,0,96,183,1,0,0,0,0,0,136,121,1,0,0,0,0,0,0,0,1,0,136,190,1,0,40,182,1,0,0,0,0,0,96,183,1,0,0,0,0,0,0,0,0,0,144,121,1,0,0,0,0,0,0,0,1,0,152,190,1,0,40,182,1,0,0,0,0,0,96,183,1,0,0,0,0,0,0,0,0,0,176,190,1,0,0,2,2,1,0,0,0,0,184,190,1,0,0,0,0,0,0,0,0,0,200,190,1,0,0,0,0,0,0,0,0,0,32,191,1,0,0,1,0,0,0,0,0,0,48,191,1,0,72,191,1,0,176,190,1,0,200,190,1,0,0,0,0,0,0,0,0,0,152,121,1,0,0,1,0,0,0,0,0,0,80,191,1,0,224,186,1,0,0,0,0,0,96,183,1,0,0,0,0,0,0,0,0,0,160,121,1,0,0,0,0,0,0,0,2,0,104,191,1,0,224,186,1,0,0,0,0,0,120,191,1,0,0,0,0,0,0,0,0,0,168,121,1,0,0,0,0,0,0,0,1,0,192,191,1,0,40,182,1,0,0,0,0,0,96,183,1,0,0,0,0,0,0,0,0,0,216,191,1,0,0,0,0,0,1,1,0,0,224,191,1,0,240,191,1,0,48,122,1,0,0,0,0,0,88,192,1,0,0,0,0,0,96,118,1,0,0,0,0,0,0,0,0,0,160,192,1,0,224,186,1,0,0,0,0,0,96,183,1,0,200,192,1,0,0,0,0,0,208,192,1,0,0,0,0,0,0,0,0,0,216,192,1,0,240,192,1,0,152,121,1,0,96,183,1,0,0,193,1,0,0,0,0,0,176,121,1,0,0,1,0,0,0,0,0,0,8,193,1,0,40,182,1,0,0,0,0,0,96,183,1,0,0,0,0,0,0,0,0,0,184,121,1,0,0,3,0,0,0,0,1,0,32,193,1,0,40,182,1,0,0,0,0,0,96,183,1,0,0,0,0,0,0,0,0,0,48,193,1,0,0,1,0,0,1,1,1,0,56,193,1,0,0,0,0,0,0,0,0,0,88,193,1,0,0,0,0,0,0,0,0,0,184,193,1,0,0,0,0,0,0,0,0,0,200,193,1,0,224,193,1,0,0,0,0,0,96,183,1,0,0,0,0,0,0,0,0,0,192,121,1,0,0,3,0,0,1,1,1,0,224,194,1,0,40,182,1,0,0,0,0,0,0,0,0,0,248,194,1,0,0,0,0,0,200,121,1,0,0,0,0,0,0,0,0,0,32,195,1,0,56,195,1,0,184,193,1,0,48,196,1,0,64,183,1,0,144,196,1,0,248,119,1,0,0,2,2,1,0,2,0,0,152,196,1,0,0,0,0,0,0,0,0,0,0,0,0,0,168,196,1,0,0,0,0,0,0,120,1,0,0,0,0,0,0,2,0,0,224,196,1,0,248,196,1,0,232,119,1,0,0,0,0,0,8,197,1,0,0,0,0,0,208,121,1,0,0,0,0,0,0,0,0,0,48,197,1,0,40,182,1,0,0,0,0,0,96,183,1,0,200,192,1,0,0,0,0,0,216,121,1,0,0,0,0,0,0,0,0,0,48,197,1,0,40,182,1,0,0,0,0,0,96,183,1,0,200,192,1,0,0,0,0,0,224,121,1,0,0,0,0,0,0,0,0,0,48,197,1,0,40,182,1,0,0,0,0,0,96,183,1,0,200,192,1,0,0,0,0,0,232,121,1,0,0,0,0,0,0,0,0,0,48,197,1,0,40,182,1,0,0,0,0,0,96,183,1,0,200,192,1,0,0,0,0,0,240,121,1,0,0,0,0,0,0,0,0,0,48,197,1,0,40,182,1,0,0,0,0,0,96,183,1,0,200,192,1,0,0,0,0,0,248,121,1,0,0,0,0,0,0,0,0,0,48,197,1,0,40,182,1,0,0,0,0,0,96,183,1,0,200,192,1,0,0,0,0,0,168,117,1,0,1,1,0,0,0,0,0,0,64,197,1,0,80,197,1,0,0,0,0,0,120,197,1,0,0,0,0,0,0,0,0,0,136,197,1,0,0,2,2,1,0,0,0,0,144,197,1,0,0,0,0,0,0,0,0,0,96,183,1,0,168,197,1,0,0,0,0,0,32,112,1,0,1,1,0,0,0,0,0,0,192,197,1,0,216,197,1,0,0,0,0,0,232,197,1,0,248,197,1,0,0,0,0,0,0,122,1,0,0,3,0,0,0,0,1,0,0,198,1,0,40,182,1,0,0,0,0,0,96,183,1,0,0,0,0,0,0,0,0,0,8,122,1,0,0,0,0,0,0,1,2,0,24,198,1,0,224,186,1,0,0,0,0,0,0,0,0,0,48,198,1,0,0,0,0,0,112,198,1,0,0,2,2,1,0,0,1,0,120,198,1,0,0,0,0,0,0,0,0,0,136,198,1,0,200,192,1,0,224,198,1,0,240,198,1,0,0,2,2,1,0,0,1,0,248,198,1,0,0,0,0,0,0,0,0,0,8,199,1,0,200,192,1,0,0,0,0,0,16,122,1,0,0,0,0,0,0,0,2,0,152,199,1,0,224,186,1,0,0,0,0,0,120,191,1,0,0,0,0,0,0,0,0,0,168,199,1,0,0,2,2,1,1,1,0,0,176,199,1,0,0,0,0,0,0,0,0,0,0,0,0,0,200,199,1,0,0,0,0,0,24,122,1,0,0,0,0,0,0,0,1,0,232,199,1,0,40,182,1,0,0,0,0,0,96,183,1,0,0,0,0,0,0,0,0,0,32,122,1,0,0,0,0,0,0,0,1,0,8,200,1,0,40,182,1,0,0,0,0,0,32,200,1,0,0,0,0,0,0,0,0,0,40,122,1,0,0,0,0,0,0,0,0,0,112,200,1,0,40,182,1,0,0,0,0,0,136,200,1,0,200,192,1,0,0,0,0,0,48,122,1,0,0,1,1,0,0,0,0,0,208,200,1,0,224,186,1,0,0,0,0,0,96,183,1,0,0,0,0,0,0,0,0,0,208,119,1,0,0,2,2,1,0,0,0,0,224,200,1,0,0,0,0,0,0,0,0,0,0,201,1,0,64,183,1,0,0,0,0,0,96,201,1,0,0,0,0,0,0,0,2,0,104,201,1,0,128,201,1,0,0,0,0,0,96,183,1,0,0,0,0,0,232,201,1,0,240,201,1,0,0,0,0,0,1,1,0,0,248,201,1,0,240,191,1,0,0,0,0,0,0,0,0,0,88,192,1,0,0,0,0,0,200,119,1,0,0,2,2,1,0,0,0,0,8,202,1,0,0,0,0,0,0,0,0,0,40,202,1,0,0,0,0,0,72,202,1,0,232,119,1,0,0,0,0,0,0,2,0,0,80,202,1,0,144,202,1,0,160,117,1,0,96,183,1,0,0,0,0,0,0,0,0,0,56,122,1,0,0,0,0,0,0,0,0,0,152,203,1,0,224,186,1,0,96,118,1,0,96,183,1,0,0,0,0,0,0,0,0,0,72,122,1,0,0,0,0,0,0,0,2,0,56,193,1,0,216,203,1,0,96,118,1,0,224,204,1,0,88,205,1,0,0,0,0,0,112,205,1,0,0,0,0,0,0,0,0,0,120,205,1,0,136,205,1,0,48,122,1,0,96,183,1,0,144,205,1,0,0,0,0,0,160,205,1,0,0,0,0,0,0,0,0,0,176,205,1,0,192,205,1,0,200,205,1,0,208,205,1,0,0,0,0,0,24,206,1,0,200,205,1,0,0,1,0,0,0,0,0,0,32,206,1,0,56,206,1,0,0,0,0,0,64,206,1,0,0,0,0,0,0,0,0,0,176,119,1,0,0,1,0,0,0,0,0,0,144,206,1,0,40,182,1,0,0,0,0,0,96,183,1,0,200,192,1,0,0,0,0,0,160,206,1,0,0,2,2,1,0,0,0,0,168,206,1,0,0,0,0,0,0,0,0,0,192,206,1,0,0,0,0,0,232,201,1,0,80,122,1,0,0,0,0,0,0,0,0,0,216,206,1,0,240,206,1,0,0,0,0,0,96,183,1,0,88,207,1,0,0,0,0,0,88,122,1,0,0,0,0,0,0,0,1,0,96,207,1,0,40,182,1,0,0,0,0,0,224,187,1,0,0,0,0,0,0,0,0,0,96,122,1,0,0,3,0,0,1,1,1,0,120,207,1,0,40,182,1,0,0,0,0,0,0,0,0,0,96,183,1,0,0,0,0,0,104,122,1,0,0,0,0,0,0,0,1,0,152,207,1,0,40,182,1,0,0,0,0,0,96,183,1,0,0,0,0,0,0,0,0,0,16,115,1,0,0,0,0,0,0,0,2,0,192,207,1,0,56,206,1,0,0,0,0,0,216,207,1,0,240,207,1,0,248,207,1,0,0,208,1,0,0,0,0,0,0,0,1,0,8,208,1,0,32,208,1,0,0,0,0,0,48,208,1,0,0,0,0,0,0,0,0,0,112,122,1,0,0,3,0,0,0,0,1,0,144,208,1,0,40,182,1,0,0,0,0,0,96,183,1,0,0,0,0,0,0,0,0,0,120,122,1,0,0,0,0,0,0,0,1,0,168,208,1,0,40,182,1,0,0,0,0,0,96,183,1,0,0,0,0,0,0,0,0,0,128,122,1,0,0,3,0,0,1,1,1,0,208,208,1,0,40,182,1,0,0,0,0,0,0,0,0,0,96,183,1,0,0,0,0,0,136,122,1,0,0,3,0,0,0,0,1,0,232,208,1,0,40,182,1,0,0,0,0,0,96,183,1,0,0,0,0,0,0,0,0,0,24,115,1,0,0,0,0,0,0,0,0,0,248,208,1,0,56,206,1,0,0,0,0,0,8,209,1,0,0,0,0,0,248,207,1,0,104,177,1,0,0,3,0,0,0,0,1,0,32,209,1,0,40,182,1,0,0,0,0,0,96,183,1,0,0,0,0,0,0,0,0,0,144,177,1,0,0,3,0,0,0,0,1,0,48,209,1,0,40,182,1,0,0,0,0,0,96,183,1,0,0,0,0,0,0,0,0,0,152,118,1,0,0,0,0,0,0,0,0,0,160,183,1,0,64,209,1,0,120,118,1,0,96,209,1,0,192,209,1,0,0,0,0,0,136,118,1,0,1,0,0,0,0,0,0,0,208,209,1,0,224,209,1,0,120,118,1,0,232,209,1,0,0,0,0,0,0,0,0,0,104,118,1,0,0,0,0,0,0,0,0,0,56,210,1,0,224,186,1,0,0,0,0,0,72,210,1,0,176,210,1,0,0,0,0,0,200,210,1,0,0,0,0,0,0,0,1,0,216,210,1,0,56,206,1,0,0,0,0,0,240,210,1,0,0,0,0,0,88,211,1,0,144,118,1,0,0,1,0,0,0,0,0,0,104,211,1,0,224,209,1,0,120,118,1,0,232,209,1,0,0,0,0,0,0,0,0,0,112,118,1,0,0,1,0,0,0,0,0,0,120,211,1,0,224,186,1,0,0,0,0,0,72,210,1,0,176,210,1,0,0,0,0,0,128,118,1,0,0,1,0,0,0,0,0,0,144,211,1,0,224,209,1,0,120,118,1,0,232,209,1,0,0,0,0,0,0,0,0,0,216,119,1,0,0,0,0,0,0,0,0,0,160,211,1,0,56,206,1,0,0,0,0,0,232,197,1,0,0,0,0,0,0,0,0,0,120,118,1,0,0,0,0,0,0,0,0,0,176,211,1,0,192,211,1,0,104,118,1,0,232,209,1,0,208,211,1,0,0,0,0,0,144,122,1,0,0,3,0,0,0,0,1,0,216,211,1,0,40,182,1,0,0,0,0,0,96,183,1,0,0,0,0,0,0,0,0,0,152,122,1,0,0,3,0,0,1,1,1,0,0,212,1,0,40,182,1,0,0,0,0,0,0,0,0,0,96,183,1,0,0,0,0,0,24,212,1,0,0,0,0,0,0,0,0,0,32,212,1,0,136,205,1,0,48,122,1,0,96,183,1,0,48,212,1,0,0,0,0,0,160,122,1,0,0,0,0,0,0,0,1,0,64,212,1,0,40,182,1,0,0,0,0,0,96,183,1,0,0,0,0,0,0,0,0,0,34,0,0,0,56,127,1,0,64,127,1,0,38,0,0,0,112,127,1,0,120,127,1,0,39,0,0,0,152,127,1,0,160,127,1,0,60,0,0,0,176,127,1,0,184,127,1,0,62,0,0,0,216,127,1,0,224,127,1,0,160,0,0,0,8,128,1,0,16,128,1,0,161,0,0,0,72,128,1,0,80,128,1,0,162,0,0,0,128,128,1,0,136,128,1,0,163,0,0,0,168,128,1,0,176,128,1,0,164,0,0,0,208,128,1,0,216,128,1,0,165,0,0,0,248,128,1,0,0,129,1,0,166,0,0,0,40,129,1,0,48,129,1,0,167,0,0,0,96,129,1,0,104,129,1,0,168,0,0,0,136,129,1,0,144,129,1,0,169,0,0,0,192,129,1,0,200,129,1,0,170,0,0,0,232,129,1,0,240,129,1,0,171,0,0,0,32,130,1,0,40,130,1,0,172,0,0,0,128,130,1,0,136,130,1,0,173,0,0,0,160,130,1,0,168,130,1,0,174,0,0,0,224,130,1,0,232,130,1,0,175,0,0,0,40,131,1,0,48,131,1,0,176,0,0,0,112,131,1,0,120,131,1,0,177,0,0,0,152,131,1,0,160,131,1,0,178,0,0,0,216,131,1,0,224,131,1,0,179,0,0,0,40,132,1,0,48,132,1,0,180,0,0,0,120,132,1,0,128,132,1,0,181,0,0,0,176,132,1,0,184,132,1,0,182,0,0,0,216,132,1,0,224,132,1,0,183,0,0,0,16,133,1,0,24,133,1,0,184,0,0,0,88,133,1,0,96,133,1,0,185,0,0,0,144,133,1,0,152,133,1,0,186,0,0,0,208,133,1,0,216,133,1,0,187,0,0,0,8,134,1,0,16,134,1,0,188,0,0,0,104,134,1,0,112,134,1,0,189,0,0,0,184,134,1,0,192,134,1,0,190,0,0,0,0,135,1,0,8,135,1,0,191,0,0,0,80,135,1,0,88,135,1,0,192,0,0,0,152,135,1,0,160,135,1,0,193,0,0,0,248,135,1,0,0,136,1,0,194,0,0,0,56,136,1,0,64,136,1,0,195,0,0,0,120,136,1,0,128,136,1,0,196,0,0,0,184,136,1,0,192,136,1,0,197,0,0,0,248,136,1,0,0,137,1,0,198,0,0,0,88,137,1,0,96,137,1,0,199,0,0,0,168,137,1,0,176,137,1,0,200,0,0,0,232,137,1,0,240,137,1,0,201,0,0,0,40,138,1,0,48,138,1,0,202,0,0,0,104,138,1,0,112,138,1,0,203,0,0,0,168,138,1,0,176,138,1,0,204,0,0,0,232,138,1,0,240,138,1,0,205,0,0,0,40,139,1,0,48,139,1,0,206,0,0,0,104,139,1,0,112,139,1,0,207,0,0,0,168,139,1,0,176,139,1,0,208,0,0,0,232,139,1,0,240,139,1,0,209,0,0,0,32,140,1,0,40,140,1,0,210,0,0,0,96,140,1,0,104,140,1,0,211,0,0,0,160,140,1,0,168,140,1,0,212,0,0,0,224,140,1,0,232,140,1,0,213,0,0,0,32,141,1,0,40,141,1,0,214,0,0,0,96,141,1,0,104,141,1,0,215,0,0,0,160,141,1,0,168,141,1,0,216,0,0,0,208,141,1,0,216,141,1,0,217,0,0,0,40,142,1,0,48,142,1,0,218,0,0,0,104,142,1,0,112,142,1,0,219,0,0,0,168,142,1,0,176,142,1,0,220,0,0,0,232,142,1,0,240,142,1,0,221,0,0,0,40,143,1,0,48,143,1,0,222,0,0,0,104,143,1,0,112,143,1,0,223,0,0,0,160,143,1,0,168,143,1,0,224,0,0,0,224,143,1,0,232,143,1,0,225,0,0,0,56,144,1,0,64,144,1,0,226,0,0,0,112,144,1,0,120,144,1,0,227,0,0,0,176,144,1,0,184,144,1,0,228,0,0,0,232,144,1,0,240,144,1,0,229,0,0,0,40,145,1,0,48,145,1,0,230,0,0,0,136,145,1,0,144,145,1,0,231,0,0,0,208,145,1,0,216,145,1,0,232,0,0,0,16,146,1,0,24,146,1,0,233,0,0,0,72,146,1,0,80,146,1,0,234,0,0,0,128,146,1,0,136,146,1,0,235,0,0,0,192,146,1,0,200,146,1,0,236,0,0,0,0,147,1,0,8,147,1,0,237,0,0,0,56,147,1,0,64,147,1,0,238,0,0,0,112,147,1,0,120,147,1,0,239,0,0,0,176,147,1,0,184,147,1,0,240,0,0,0,240,147,1,0,248,147,1,0,241,0,0,0,32,148,1,0,40,148,1,0,242,0,0,0,88,148,1,0,96,148,1,0,243,0,0,0,144,148,1,0,152,148,1,0,244,0,0,0,200,148,1,0,208,148,1,0,245,0,0,0,8,149,1,0,16,149,1,0,246,0,0,0,64,149,1,0,72,149,1,0,247,0,0,0,128,149,1,0,136,149,1,0,248,0,0,0,168,149,1,0,176,149,1,0,249,0,0,0,0,150,1,0,8,150,1,0,250,0,0,0,56,150,1,0,64,150,1,0,251,0,0,0,112,150,1,0,120,150,1,0,252,0,0,0,176,150,1,0,184,150,1,0,253,0,0,0,240,150,1,0,248,150,1,0,254,0,0,0,40,151,1,0,48,151,1,0,255,0,0,0,96,151,1,0,104,151,1,0,82,1,0,0,160,151,1,0,168,151,1,0,83,1,0,0,216,151,1,0,224,151,1,0,96,1,0,0,8,152,1,0,16,152,1,0,97,1,0,0,72,152,1,0,80,152,1,0,120,1,0,0,128,152,1,0,136,152,1,0,146,1,0,0,192,152,1,0,200,152,1,0,198,2,0,0,8,153,1,0,16,153,1,0,220,2,0,0,72,153,1,0,80,153,1,0,145,3,0,0,112,153,1,0,120,153,1,0,146,3,0,0,160,153,1,0,168,153,1,0,147,3,0,0,208,153,1,0,216,153,1,0,148,3,0,0,8,154,1,0,16,154,1,0,149,3,0,0,64,154,1,0,72,154,1,0,150,3,0,0,112,154,1,0,120,154,1,0,151,3,0,0,160,154,1,0,168,154,1,0,152,3,0,0,208,154,1,0,216,154,1,0,153,3,0,0,8,155,1,0,16,155,1,0,154,3,0,0,56,155,1,0,64,155,1,0,155,3,0,0,104,155,1,0,112,155,1,0,156,3,0,0,160,155,1,0,168,155,1,0,157,3,0,0,200,155,1,0,208,155,1,0,158,3,0,0,240,155,1,0,248,155,1,0,159,3,0,0,32,156,1,0,40,156,1,0,160,3,0,0,80,156,1,0,88,156,1,0,161,3,0,0,128,156,1,0,136,156,1,0,163,3,0,0,176,156,1,0,184,156,1,0,164,3,0,0,232,156,1,0,240,156,1,0,165,3,0,0,24,157,1,0,32,157,1,0,166,3,0,0,80,157,1,0,88,157,1,0,167,3,0,0,136,157,1,0,144,157,1,0,168,3,0,0,184,157,1,0,192,157,1,0,169,3,0,0,240,157,1,0,248,157,1,0,177,3,0,0,40,158,1,0,48,158,1,0,178,3,0,0,96,158,1,0,104,158,1,0,179,3,0,0,144,158,1,0,152,158,1,0,180,3,0,0,200,158,1,0,208,158,1,0,181,3,0,0,0,159,1,0,8,159,1,0,182,3,0,0,56,159,1,0,64,159,1,0,183,3,0,0,104,159,1,0,112,159,1,0,184,3,0,0,152,159,1,0,160,159,1,0,185,3,0,0,208,159,1,0,216,159,1,0,186,3,0,0,0,160,1,0,8,160,1,0,187,3,0,0,56,160,1,0,64,160,1,0,188,3,0,0,112,160,1,0,120,160,1,0,189,3,0,0,160,160,1,0,168,160,1,0,190,3,0,0,208,160,1,0,216,160,1,0,191,3,0,0,0,161,1,0,8,161,1,0,192,3,0,0,48,161,1,0,56,161,1,0,193,3,0,0,96,161,1,0,104,161,1,0,194,3,0,0,144,161,1,0,152,161,1,0,195,3,0,0,200,161,1,0,208,161,1,0,196,3,0,0,0,162,1,0,8,162,1,0,197,3,0,0,48,162,1,0,56,162,1,0,198,3,0,0,104,162,1,0,112,162,1,0,199,3,0,0,152,162,1,0,160,162,1,0,200,3,0,0,200,162,1,0,208,162,1,0,201,3,0,0,248,162,1,0,0,163,1,0,209,3,0,0,48,163,1,0,64,163,1,0,210,3,0,0,112,163,1,0,120,163,1,0,214,3,0,0,168,163,1,0,176,163,1,0,2,32,0,0,208,163,1,0,216,163,1,0,3,32,0,0,240,163,1,0,248,163,1,0,9,32,0,0,16,164,1,0,24,164,1,0,12,32,0,0,56,164,1,0,64,164,1,0,13,32,0,0,112,164,1,0,120,164,1,0,14,32,0,0,160,164,1,0,168,164,1,0,15,32,0,0,208,164,1,0,216,164,1,0,19,32,0,0,0,165,1,0,8,165,1,0,20,32,0,0,32,165,1,0,40,165,1,0,24,32,0,0,64,165,1,0,72,165,1,0,25,32,0,0,120,165,1,0,128,165,1,0,26,32,0,0,176,165,1,0,184,165,1,0,28,32,0,0,224,165,1,0,232,165,1,0,29,32,0,0,24,166,1,0,32,166,1,0,30,32,0,0,80,166,1,0,88,166,1,0,32,32,0,0,128,166,1,0,136,166,1,0,33,32,0,0,160,166,1,0,168,166,1,0,34,32,0,0,200,166,1,0,208,166,1,0,38,32,0,0,0,167,1,0,8,167,1,0,48,32,0,0,64,167,1,0,72,167,1,0,50,32,0,0,104,167,1,0,112,167,1,0,51,32,0,0,152,167,1,0,160,167,1,0,57,32,0,0,208,167,1,0,216,167,1,0,58,32,0,0,24,168,1,0,32,168,1,0,62,32,0,0,96,168,1,0,104,168,1,0,68,32,0,0,152,168,1,0,160,168,1,0,172,32,0,0,192,168,1,0,200,168,1,0,17,33,0,0,224,168,1,0,232,168,1,0,24,33,0,0,32,169,1,0,40,169,1,0,28,33,0,0,104,169,1,0,112,169,1,0,34,33,0,0,176,169,1,0,184,169,1,0,53,33,0,0,216,169,1,0,224,169,1,0,144,33,0,0,24,170,1,0,32,170,1,0,145,33,0,0,64,170,1,0,72,170,1,0,146,33,0,0,104,170,1,0,112,170,1,0,147,33,0,0,144,170,1,0,152,170,1,0,148,33,0,0,184,170,1,0,192,170,1,0,181,33,0,0,232,170,1,0,240,170,1,0,208,33,0,0,56,171,1,0,64,171,1,0,209,33,0,0,104,171,1,0,112,171,1,0,210,33,0,0,152,171,1,0,160,171,1,0,211,33,0,0,200,171,1,0,208,171,1,0,212,33,0,0,248,171,1,0,0,172,1,0,0,34,0,0,40,172,1,0,48,172,1,0,2,34,0,0,72,172,1,0,80,172,1,0,3,34,0,0,120,172,1,0,128,172,1,0,5,34,0,0,160,172,1,0,168,172,1,0,7,34,0,0,216,172,1,0,224,172,1,0,8,34,0,0,16,173,1,0,24,173,1,0,9,34,0,0,56,173,1,0,64,173,1,0,11,34,0,0,104,173,1,0,112,173,1,0,15,34,0,0,152,173,1,0,160,173,1,0,17,34,0,0,208,173,1,0,216,173,1,0,18,34,0,0,248,173,1,0,0,174,1,0,23,34,0,0,32,174,1,0,40,174,1,0,26,34,0,0,80,174,1,0,88,174,1,0,29,34,0,0,136,174,1,0,144,174,1,0,30,34,0,0,176,174,1,0,184,174,1,0,32,34,0,0,216,174,1,0,224,174,1,0,39,34,0,0,248,174,1,0,0,175,1,0,40,34,0,0,40,175,1,0,48,175,1,0,41,34,0,0,88,175,1,0,96,175,1,0,42,34,0,0,136,175,1,0,144,175,1,0,43,34,0,0,176,175,1,0,184,175,1,0,52,34,0,0,216,175,1,0,224,175,1,0,60,34,0,0,0,176,1,0,8,176,1,0,69,34,0,0,72,176,1,0,80,176,1,0,72,34,0,0,120,176,1,0,128,176,1,0,96,34,0,0,176,176,1,0,184,176,1,0,97,34,0,0,216,176,1,0,224,176,1,0,100,34,0,0,0,177,1,0,8,177,1,0,101,34,0,0,48,177,1,0,56,177,1,0,130,34,0,0,104,177,1,0,112,177,1,0,131,34,0,0,144,177,1,0,152,177,1,0,132,34,0,0,184,177,1,0,192,177,1,0,134,34,0,0,224,177,1,0,232,177,1,0,135,34,0,0,16,178,1,0,24,178,1,0,149,34,0,0,64,178,1,0,72,178,1,0,151,34,0,0,120,178,1,0,128,178,1,0,165,34,0,0,176,178,1,0,184,178,1,0,197,34,0,0,240,178,1,0,248,178,1,0,8,35,0,0,24,179,1,0,32,179,1,0,9,35,0,0,80,179,1,0,88,179,1,0,10,35,0,0,120,179,1,0,128,179,1,0,11,35,0,0,176,179,1,0,184,179,1,0,41,35,0,0,216,179,1,0,224,179,1,0,42,35,0,0,24,180,1,0,32,180,1,0,202,37,0,0,88,180,1,0,96,180,1,0,96,38,0,0,120,180,1,0,128,180,1,0,99,38,0,0,160,180,1,0,168,180,1,0,101,38,0,0,216,180,1,0,224,180,1,0,102,38,0,0,16,181,1,0,24,181,1,0,0,0,0,0,35,37,117,0,0,0,0,0,72,84,77,76,32,100,111,99,117,109,101,110,116,32,99,114,101,97,116,105,111,110,32,102,97,105,108,101,100,10,0,0,104,116,109,108,0,0,0,0,104,116,116,112,58,47,47,119,119,119,46,119,51,46,111,114,103,47,84,82,47,82,69,67,45,104,116,109,108,52,48,47,108,111,111,115,101,46,100,116,100,0,0,0,0,0,0,0,45,47,47,87,51,67,47,47,68,84,68,32,72,84,77,76,32,52,46,48,32,84,114,97,110,115,105,116,105,111,110,97,108,47,47,69,78,0,0,0,104,116,109,108,80,97,114,115,101,69,110,116,105,116,121,82,101,102,58,32,110,111,32,110,97,109,101,10,0,0,0,0,104,116,109,108,80,97,114,115,101,69,110,116,105,116,121,82,101,102,58,32,101,120,112,101,99,116,105,110,103,32,39,59,39,10,0,0,0,0,0,0,104,116,109,108,80,97,114,115,101,67,104,97,114,82,101,102,58,32,99,111,110,116,101,120,116,32,101,114,114,111,114,10,0,0,0,0,0,0,0,0,104,116,109,108,80,97,114,115,101,67,104,97,114,82,101,102,58,32,109,105,115,115,105,110,103,32,115,101,109,105,99,111,108,111,110,10,0,0,0,0,104,116,109,108,80,97,114,115,101,67,104,97,114,82,101,102,58,32,105,110,118,97,108,105,100,32,118,97,108,117,101,10,0,0,0,0,0,0,0,0,104,116,109,108,80,97,114,115,101,67,104,97,114,82,101,102,58,32,105,110,118,97,108,105,100,32,120,109,108,67,104,97,114,32,118,97,108,117,101,32,37,100,10,0,0,0,0,0,84,97,103,32,37,115,32,105,110,118,97,108,105,100,10,0,67,111,117,108,100,110,39,116,32,102,105,110,100,32,101,110,100,32,111,102,32,83,116,97,114,116,32,84,97,103,32,37,115,10,0,0,0,0,0,0,104,116,109,108,80,97,114,115,101,68,111,99,117,109,101,110,116,58,32,99,111,110,116,101,120,116,32,101,114,114,111,114,10,0,0,0,0,0,0,0,68,111,99,117,109,101,110,116,32,105,115,32,101,109,112,116,121,10,0,0,0,0,0,0,78,101,119,80,97,114,115,101,114,67,116,120,116,58,32,111,117,116,32,111,102,32,109,101,109,111,114,121,10,0,0,0,104,116,109,108,80,97,114,115,101,67,104,117,110,107,58,32,99,111,110,116,101,120,116,32,101,114,114,111,114,10,0,0,101,110,99,111,100,101,114,32,101,114,114,111,114,10,0,0,99,104,97,114,115,101,116,61,0,0,0,0,0,0,0,0,111,117,116,32,111,102,32,109,101,109,111,114,121,10,0,0,1,0,0,0,0,0,0,0,99,104,97,114,115,101,116,0,61,0,0,0,0,0,0,0,104,116,109,108,67,104,101,99,107,69,110,99,111,100,105,110,103,58,32,119,114,111,110,103,32,101,110,99,111,100,105,110,103,32,109,101,116,97,10,0,104,116,109,108,67,104,101,99,107,69,110,99,111,100,105,110,103,58,32,117,110,107,110,111,119,110,32,101,110,99,111,100,105,110,103,32,37,115,10,0,104,116,109,108,67,104,101,99,107,69,110,99,111,100,105,110,103,58,32,101,110,99,111,100,101,114,32,101,114,114,111,114,10,0,0,0,0,0,0,0,99,111,117,108,100,110,39,116,32,97,108,108,111,99,97,116,101,32,97,32,110,101,119,32,105,110,112,117,116,32,115,116,114,101,97,109,10,0,0,0,115,99,114,105,112,116,0,0,115,116,121,108,101,0,0,0,77,105,115,112,108,97,99,101,100,32,68,79,67,84,89,80,69,32,100,101,99,108,97,114,97,116,105,111,110,10,0,0,68,79,67,84,89,80,69,0,59,32,62,47,0,0,0,0,60,38,0,0,0,0,0,0,100,101,116,101,99,116,101,100,32,97,110,32,101,114,114,111,114,32,105,110,32,101,108,101,109,101,110,116,32,99,111,110],"i8",ALLOC_NONE,Runtime.GLOBAL_BASE+84848),allocate([116,101,110,116,10,0,0,0,72,80,80,58,32,105,110,116,101,114,110,97,108,32,101,114,114,111,114,44,32,115,116,97,116,101,32,61,61,32,67,68,65,84,65,10,0,0,0,0,72,80,80,58,32,105,110,116,101,114,110,97,108,32,101,114,114,111,114,44,32,115,116,97,116,101,32,61,61,32,68,84,68,10,0,0,0,0,0,0,72,80,80,58,32,105,110,116,101,114,110,97,108,32,101,114,114,111,114,44,32,115,116,97,116,101,32,61,61,32,67,79,77,77,69,78,84,10,0,0,72,80,80,58,32,105,110,116,101,114,110,97,108,32,101,114,114,111,114,44,32,115,116,97,116,101,32,61,61,32,80,73,10,0,0,0,0,0,0,0,72,80,80,58,32,105,110,116,101,114,110,97,108,32,101,114,114,111,114,44,32,115,116,97,116,101,32,61,61,32,69,78,84,73,84,89,95,68,69,67,76,10,0,0,0,0,0,0,72,80,80,58,32,105,110,116,101,114,110,97,108,32,101,114,114,111,114,44,32,115,116,97,116,101,32,61,61,32,69,78,84,73,84,89,95,86,65,76,85,69,10,0,0,0,0,0,72,80,80,58,32,105,110,116,101,114,110,97,108,32,101,114,114,111,114,44,32,115,116,97,116,101,32,61,61,32,65,84,84,82,73,66,85,84,69,95,86,65,76,85,69,10,0,0,72,80,80,58,32,105,110,116,101,114,110,97,108,32,101,114,114,111,114,44,32,115,116,97,116,101,32,61,61,32,88,77,76,95,80,65,82,83,69,82,95,83,89,83,84,69,77,95,76,73,84,69,82,65,76,10,0,0,0,0,0,0,0,0,72,80,80,58,32,105,110,116,101,114,110,97,108,32,101,114,114,111,114,44,32,115,116,97,116,101,32,61,61,32,88,77,76,95,80,65,82,83,69,82,95,73,71,78,79,82,69,10,0,0,0,0,0,0,0,0,72,80,80,58,32,105,110,116,101,114,110,97,108,32,101,114,114,111,114,44,32,115,116,97,116,101,32,61,61,32,88,77,76,95,80,65,82,83,69,82,95,76,73,84,69,82,65,76,10,0,0,0,0,0,0,0,104,116,109,108,80,97,114,115,101,69,110,100,84,97,103,58,32,39,60,47,39,32,110,111,116,32,102,111,117,110,100,10,0,0,0,0,0,0,0,0,69,110,100,32,116,97,103,32,58,32,101,120,112,101,99,116,101,100,32,39,62,39,10,0,98,111,100,121,0,0,0,0,104,101,97,100,0,0,0,0,85,110,101,120,112,101,99,116,101,100,32,101,110,100,32,116,97,103,32,58,32,37,115,10,0,0,0,0,0,0,0,0,79,112,101,110,105,110,103,32,97,110,100,32,101,110,100,105,110,103,32,116,97,103,32,109,105,115,109,97,116,99,104,58,32,37,115,32,97,110,100,32,37,115,10,0,0,0,0,0,96,118,1,0,150,0,0,0,104,118,1,0,160,0,0,0,112,118,1,0,160,0,0,0,120,118,1,0,170,0,0,0,128,118,1,0,180,0,0,0,136,118,1,0,180,0,0,0,144,118,1,0,180,0,0,0,152,118,1,0,190,0,0,0,168,117,1,0,200,0,0,0,160,117,1,0,200,0,0,0,32,112,1,0,220,0,0,0,0,0,0,0,100,0,0,0,100,105,118,0,0,0,0,0,116,100,0,0,0,0,0,0,116,104,0,0,0,0,0,0,116,114,0,0,0,0,0,0,116,104,101,97,100,0,0,0,116,98,111,100,121,0,0,0,116,102,111,111,116,0,0,0,116,97,98,108,101,0,0,0,38,0,0,0,0,0,0,0,69,108,101,109,101,110,116,32,37,115,32,101,109,98,101,100,115,32,99,108,111,115,101,32,116,97,103,10,0,0,0,0,73,110,118,97,108,105,100,32,99,104,97,114,32,105,110,32,67,68,65,84,65,32,48,120,37,88,10,0,0,0,0,0,67,104,97,114,32,48,120,37,88,32,111,117,116,32,111,102,32,97,108,108,111,119,101,100,32,114,97,110,103,101,10,0,85,110,115,117,112,112,111,114,116,101,100,32,101,110,99,111,100,105,110,103,32,37,115,0,66,121,116,101,115,58,32,48,120,37,48,50,88,32,48,120,37,48,50,88,32,48,120,37,48,50,88,32,48,120,37,48,50,88,10,0,0,0,0,0,66,121,116,101,115,58,32,48,120,37,48,50,88,10,0,0,73,110,112,117,116,32,105,115,32,110,111,116,32,112,114,111,112,101,114,32,85,84,70,45,56,44,32,105,110,100,105,99,97,116,101,32,101,110,99,111,100,105,110,103,32,33,10,0,72,84,84,80,45,69,81,85,73,86,0,0,0,0,0,0,67,79,78,84,69,78,84,0,67,72,65,82,83,69,84,61,0,0,0,0,0,0,0,0,112,0,0,0,0,0,0,0,32,112,1,0,168,117,1,0,0,0,0,0,0,0,0,0,109,101,116,97,0,0,0,0,108,105,110,107,0,0,0,0,116,105,116,108,101,0,0,0,98,97,115,101,0,0,0,0,110,111,102,114,97,109,101,115,0,0,0,0,0,0,0,0,102,114,97,109,101,0,0,0,102,114,97,109,101,115,101,116,0,0,0,0,0,0,0,0,45,47,47,87,51,67,47,47,68,84,68,32,72,84,77,76,32,52,46,48,49,47,47,69,78,0,0,0,0,0,0,0,45,47,47,87,51,67,47,47,68,84,68,32,72,84,77,76,32,52,47,47,69,78,0,0,32,121,1,0,40,121,1,0,48,121,1,0,56,121,1,0,64,121,1,0,72,121,1,0,80,121,1,0,88,121,1,0,96,121,1,0,160,117,1,0,112,121,1,0,120,121,1,0,128,121,1,0,136,121,1,0,144,121,1,0,152,121,1,0,160,121,1,0,168,121,1,0,96,118,1,0,176,121,1,0,184,121,1,0,192,121,1,0,200,121,1,0,208,121,1,0,216,121,1,0,224,121,1,0,232,121,1,0,240,121,1,0,248,121,1,0,0,122,1,0,8,122,1,0,16,122,1,0,24,122,1,0,32,122,1,0,40,122,1,0,48,122,1,0,232,119,1,0,56,122,1,0,72,122,1,0,176,119,1,0,80,122,1,0,88,122,1,0,96,122,1,0,104,122,1,0,112,122,1,0,120,122,1,0,128,122,1,0,136,122,1,0,104,118,1,0,112,118,1,0,144,122,1,0,152,122,1,0,160,122,1,0,0,0,0,0,97,0,0,0,0,0,0,0,97,98,98,114,0,0,0,0,97,99,114,111,110,121,109,0,97,100,100,114,101,115,115,0,97,112,112,108,101,116,0,0,98,0,0,0,0,0,0,0,98,100,111,0,0,0,0,0,98,105,103,0,0,0,0,0,98,108,111,99,107,113,117,111,116,101,0,0,0,0,0,0,98,117,116,116,111,110,0,0,99,97,112,116,105,111,110,0,99,101,110,116,101,114,0,0,99,105,116,101,0,0,0,0,99,111,100,101,0,0,0,0,100,100,0,0,0,0,0,0,100,101,108,0,0,0,0,0,100,102,110,0,0,0,0,0,100,116,0,0,0,0,0,0,101,109,0,0,0,0,0,0,102,111,110,116,0,0,0,0,102,111,114,109,0,0,0,0,104,49,0,0,0,0,0,0,104,50,0,0,0,0,0,0,104,51,0,0,0,0,0,0,104,52,0,0,0,0,0,0,104,53,0,0,0,0,0,0,104,54,0,0,0,0,0,0,105,0,0,0,0,0,0,0,105,102,114,97,109,101,0,0,105,110,115,0,0,0,0,0,107,98,100,0,0,0,0,0,108,97,98,101,108,0,0,0,108,101,103,101,110,100,0,0,108,105,0,0,0,0,0,0,110,111,115,99,114,105,112,116,0,0,0,0,0,0,0,0,111,98,106,101,99,116,0,0,112,114,101,0,0,0,0,0,113,0,0,0,0,0,0,0,115,0,0,0,0,0,0,0,115,97,109,112,0,0,0,0,115,109,97,108,108,0,0,0,115,112,97,110,0,0,0,0,115,116,114,105,107,101,0,0,115,116,114,111,110,103,0,0,116,116,0,0,0,0,0,0,117,0,0,0,0,0,0,0,118,97,114,0,0,0,0,0,104,116,109,108,73,110,105,116,80,97,114,115,101,114,67,116,120,116,58,32,111,117,116,32,111,102,32,109,101,109,111,114,121,10,0,0,0,0,0,0,104,116,109,108,80,97,114,115,101,68,111,99,84,121,112,101,68,101,99,108,32,58,32,110,111,32,68,79,67,84,89,80,69,32,110,97,109,101,32,33,10,0,0,0,0,0,0,0,68,79,67,84,89,80,69,32,105,109,112,114,111,112,101,114,108,121,32,116,101,114,109,105,110,97,116,101,100,10,0,0,83,112,97,99,101,32,114,101,113,117,105,114,101,100,32,97,102,116,101,114,32,39,83,89,83,84,69,77,39,10,0,0,104,116,109,108,80,97,114,115,101,69,120,116,101,114,110,97,108,73,68,58,32,83,89,83,84,69,77,44,32,110,111,32,85,82,73,10,0,0,0,0,83,112,97,99,101,32,114,101,113,117,105,114,101,100,32,97,102,116,101,114,32,39,80,85,66,76,73,67,39,10,0,0,104,116,109,108,80,97,114,115,101,69,120,116,101,114,110,97,108,73,68,58,32,80,85,66,76,73,67,44,32,110,111,32,80,117,98,108,105,99,32,73,100,101,110,116,105,102,105,101,114,10,0,0,0,0,0,0,85,110,102,105,110,105,115,104,101,100,32,80,117,98,105,100,76,105,116,101,114,97,108,10,0,0,0,0,0,0,0,0,80,117,98,105,100,76,105,116,101,114,97,108,32,34,32,111,114,32,39,32,101,120,112,101,99,116,101,100,10,0,0,0,85,110,102,105,110,105,115,104,101,100,32,83,121,115,116,101,109,76,105,116,101,114,97,108,10,0,0,0,0,0,0,0,32,111,114,32,39,32,101,120,112,101,99,116,101,100,10,0,80,97,114,115,101,80,73,58,32,80,73,32,37,115,32,115,112,97,99,101,32,101,120,112,101,99,116,101,100,10,0,0,80,97,114,115,101,80,73,58,32,80,73,32,37,115,32,110,101,118,101,114,32,101,110,100,32,46,46,46,10,0,0,0,80,73,32,105,115,32,110,111,116,32,115,116,97,114,116,101,100,32,99,111,114,114,101,99,116,108,121,0,0,0,0,0,98,117,102,102,101,114,32,97,108,108,111,99,97,116,105,111,110,32,102,97,105,108,101,100,10,0,0,0,0,0,0,0,103,114,111,119,105,110,103,32,98,117,102,102,101,114,32,102,97,105,108,101,100,10,0,0,67,111,109,109,101,110,116,32,110,111,116,32,116,101,114,109,105,110,97,116,101,100,32,10,60,33,45,45,37,46,53,48,115,10,0,0,0,0,0,0,104,116,109,108,80,97,114,115,101,83,116,97,114,116,84,97,103,58,32,105,110,118,97,108,105,100,32,101,108,101,109,101,110,116,32,110,97,109,101,10,0,0,0,0,0,0,0,0,104,116,109,108,80,97,114,115,101,69,108,101,109,101,110,116,73,110,116,101,114,110,97,108,58,32,99,111,110,116,101,120,116,32,101,114,114,111,114,10,0,0,0,0,0,0,0,0,104,116,109,108,80,97,114,115,101,83,116,97,114,116,84,97,103,58,32,99,111,110,116,101,120,116,32,101,114,114,111,114,10,0,0,0,0,0,0,0,104,116,109,108,80,97,114,115,101,83,116,97,114,116,84,97,103,58,32,109,105,115,112,108,97,99,101,100,32,60,104,116,109,108,62,32,116,97,103,10,0,0,0,0,0,0,0,0,104,116,109,108,80,97,114,115,101,83,116,97,114,116,84,97,103,58,32,109,105,115,112,108,97,99,101,100,32,60,104,101,97,100,62,32,116,97,103,10,0,0,0,0,0,0,0,0,104,116,109,108,80,97,114,115,101,83,116,97,114,116,84,97,103,58,32,109,105,115,112,108,97,99,101,100,32,60,98,111,100,121,62,32,116,97,103,10,0,0,0,0,0,0,0,0,65,116,116,114,105,98,117,116,101,32,37,115,32,114,101,100,101,102,105,110,101,100,10,0,104,116,109,108,80,97,114,115,101,83,116,97,114,116,84,97,103,58,32,112,114,111,98,108,101,109,32,112,97,114,115,105,110,103,32,97,116,116,114,105,98,117,116,101,115,10,0,0,104,116,116,112,45,101,113,117,105,118,0,0,0,0,0,0,67,111,110,116,101,110,116,45,84,121,112,101,0,0,0,0,99,111,110,116,101,110,116,0,101,114,114,111,114,32,112,97,114,115,105,110,103,32,97,116,116,114,105,98,117,116,101,32,110,97,109,101,10,0,0,0,65,116,116,86,97,108,117,101,58,32,34,32,101,120,112,101,99,116,101,100,10,0,0,0,65,116,116,86,97,108,117,101,58,32,39,32,101,120,112,101,99,116,101,100,10,0,0,0,65,116,116,86,97,108,117,101,58,32,110,111,32,118,97,108,117,101,32,102,111,117,110,100,10,0,0,0,0,0,0,0,103,114,111,119,105,110,103,32,98,117,102,102,101,114,10,0,77,101,109,111,114,121,32,97,108,108,111,99,97,116,105,111,110,32,102,97,105,108,101,100,32,58,32,37,115,10,0,0,77,101,109,111,114,121,32,97,108,108,111,99,97,116,105,111,110,32,102,97,105,108,101,100,10,0,0,0,0,0,0,0,113,117,111,116,0,0,0,0,113,117,111,116,97,116,105,111,110,32,109,97,114,107,32,61,32,65,80,76,32,113,117,111,116,101,44,32,85,43,48,48,50,50,32,73,83,79,110,117,109,0,0,0,0,0,0,0,97,109,112,0,0,0,0,0,97,109,112,101,114,115,97,110,100,44,32,85,43,48,48,50,54,32,73,83,79,110,117,109,0,0,0,0,0,0,0,0,97,112,111,115,0,0,0,0,115,105,110,103,108,101,32,113,117,111,116,101,0,0,0,0,108,116,0,0,0,0,0,0,108,101,115,115,45,116,104,97,110,32,115,105,103,110,44,32,85,43,48,48,51,67,32,73,83,79,110,117,109,0,0,0,103,116,0,0,0,0,0,0,103,114,101,97,116,101,114,45,116,104,97,110,32,115,105,103,110,44,32,85,43,48,48,51,69,32,73,83,79,110,117,109,0,0,0,0,0,0,0,0,110,98,115,112,0,0,0,0,110,111,45,98,114,101,97,107,32,115,112,97,99,101,32,61,32,110,111,110,45,98,114,101,97,107,105,110,103,32,115,112,97,99,101,44,32,85,43,48,48,65,48,32,73,83,79,110,117,109,0,0,0,0,0,0,105,101,120,99,108,0,0,0,105,110,118,101,114,116,101,100,32,101,120,99,108,97,109,97,116,105,111,110,32,109,97,114,107,44,32,85,43,48,48,65,49,32,73,83,79,110,117,109,0,0,0,0,0,0,0,0,99,101,110,116,0,0,0,0,99,101,110,116,32,115,105,103,110,44,32,85,43,48,48,65,50,32,73,83,79,110,117,109,0,0,0,0,0,0,0,0,112,111,117,110,100,0,0,0,112,111,117,110,100,32,115,105,103,110,44,32,85,43,48,48,65,51,32,73,83,79,110,117,109,0,0,0,0,0,0,0,99,117,114,114,101,110,0,0,99,117,114,114,101,110,99,121,32,115,105,103,110,44,32,85,43,48,48,65,52,32,73,83,79,110,117,109,0,0,0,0,121,101,110,0,0,0,0,0,121,101,110,32,115,105,103,110,32,61,32,121,117,97,110,32,115,105,103,110,44,32,85,43,48,48,65,53,32,73,83,79,110,117,109,0,0,0,0,0,98,114,118,98,97,114,0,0,98,114,111,107,101,110,32,98,97,114,32,61,32,98,114,111,107,101,110,32,118,101,114,116,105,99,97,108,32,98,97,114,44,32,85,43,48,48,65,54,32,73,83,79,110,117,109,0,115,101,99,116,0,0,0,0,115,101,99,116,105,111,110,32,115,105,103,110,44,32,85,43,48,48,65,55,32,73,83,79,110,117,109,0,0,0,0,0,117,109,108,0,0,0,0,0,100,105,97,101,114,101,115,105,115,32,61,32,115,112,97,99,105,110,103,32,100,105,97,101,114,101,115,105,115,44,32,85,43,48,48,65,56,32,73,83,79,100,105,97,0,0,0,0,99,111,112,121,0,0,0,0,99,111,112,121,114,105,103,104,116,32,115,105,103,110,44,32,85,43,48,48,65,57,32,73,83,79,110,117,109,0,0,0,111,114,100,102,0,0,0,0,102,101,109,105,110,105,110,101,32,111,114,100,105,110,97,108,32,105,110,100,105,99,97,116,111,114,44,32,85,43,48,48,65,65,32,73,83,79,110,117,109,0,0,0,0,0,0,0,108,97,113,117,111,0,0,0,108,101,102,116,45,112,111,105,110,116,105,110,103,32,100,111,117,98,108,101,32,97,110,103,108,101,32,113,117,111,116,97,116,105,111,110,32,109,97,114,107,32,61,32,108,101,102,116,32,112,111,105,110,116,105,110,103,32,103,117,105,108,108,101,109,101,116,44,32,85,43,48,48,65,66,32,73,83,79,110,117,109,0,0,0,0,0,0,110,111,116,0,0,0,0,0,110,111,116,32,115,105,103,110,44,32,85,43,48,48,65,67,32,73,83,79,110,117,109,0,115,104,121,0,0,0,0,0,115,111,102,116,32,104,121,112,104,101,110,32,61,32,100,105,115,99,114,101,116,105,111,110,97,114,121,32,104,121,112,104,101,110,44,32,85,43,48,48,65,68,32,73,83,79,110,117,109,0,0,0,0,0,0,0,114,101,103,0,0,0,0,0,114,101,103,105,115,116,101,114,101,100,32,115,105,103,110,32,61,32,114,101,103,105,115,116,101,114,101,100,32,116,114,97,100,101,32,109,97,114,107,32,115,105,103,110,44,32,85,43,48,48,65,69,32,73,83,79,110,117,109,0,0,0,0,0,109,97,99,114,0,0,0,0,109,97,99,114,111,110,32,61,32,115,112,97,99,105,110,103,32,109,97,99,114,111,110,32,61,32,111,118,101,114,108,105,110,101,32,61,32,65,80,76,32,111,118,101,114,98,97,114,44,32,85,43,48,48,65,70,32,73,83,79,100,105,97,0,100,101,103,0,0,0,0,0,100,101,103,114,101,101,32,115,105,103,110,44,32,85,43,48,48,66,48,32,73,83,79,110,117,109,0,0,0,0,0,0,112,108,117,115,109,110,0,0,112,108,117,115,45,109,105,110,117,115,32,115,105,103,110,32,61,32,112,108,117,115,45,111,114,45,109,105,110,117,115,32,115,105,103,110,44,32,85,43,48,48,66,49,32,73,83,79,110,117,109,0,0,0,0,0,115,117,112,50,0,0,0,0,115,117,112,101,114,115,99,114,105,112,116,32,116,119,111,32,61,32,115,117,112,101,114,115,99,114,105,112,116,32,100,105,103,105,116,32,116,119,111,32,61,32,115,113,117,97,114,101,100,44,32,85,43,48,48,66,50,32,73,83,79,110,117,109,0,0,0,0,0,0,0,0,115,117,112,51,0,0,0,0,115,117,112,101,114,115,99,114,105,112,116,32,116,104,114,101,101,32,61,32,115,117,112,101,114,115,99,114,105,112,116,32,100,105,103,105,116,32,116,104,114,101,101,32,61,32,99,117,98,101,100,44,32,85,43,48,48,66,51,32,73,83,79,110,117,109,0,0,0,0,0,0,97,99,117,116,101,0,0,0,97,99,117,116,101,32,97,99,99,101,110,116,32,61,32,115,112,97,99,105,110,103,32,97,99,117,116,101,44,32,85,43,48,48,66,52,32,73,83,79,100,105,97,0,0,0,0,0,109,105,99,114,111,0,0,0,109,105,99,114,111,32,115,105,103,110,44,32,85,43,48,48,66,53,32,73,83,79,110,117,109,0,0,0,0,0,0,0,112,97,114,97,0,0,0,0,112,105,108,99,114,111,119,32,115,105,103,110,32,61,32,112,97,114,97,103,114,97,112,104,32,115,105,103,110,44,32,85,43,48,48,66,54,32,73,83,79,110,117,109,0,0,0,0,109,105,100,100,111,116,0,0,109,105,100,100,108,101,32,100,111,116,32,61,32,71,101,111,114,103,105,97,110,32,99,111,109,109,97,32,71,114,101,101,107,32,109,105,100,100,108,101,32,100,111,116,44,32,85,43,48,48,66,55,32,73,83,79,110,117,109,0,0,0,0,0,99,101,100,105,108,0,0,0,99,101,100,105,108,108,97,32,61,32,115,112,97,99,105,110,103,32,99,101,100,105,108,108,97,44,32,85,43,48,48,66,56,32,73,83,79,100,105,97,0,0,0,0,0,0,0,0,115,117,112,49,0,0,0,0,115,117,112,101,114,115,99,114,105,112,116,32,111,110,101,32,61,32,115,117,112,101,114,115,99,114,105,112,116,32,100,105,103,105,116,32,111,110,101,44,32,85,43,48,48,66,57,32,73,83,79,110,117,109,0,0,111,114,100,109,0,0,0,0,109,97,115,99,117,108,105,110,101,32,111,114,100,105,110,97,108,32,105,110,100,105,99,97,116,111,114,44,32,85,43,48,48,66,65,32,73,83,79,110,117,109,0,0,0,0,0,0,114,97,113,117,111,0,0,0,114,105,103,104,116,45,112,111,105,110,116,105,110,103,32,100,111,117,98,108,101,32,97,110,103,108,101,32,113,117,111,116,97,116,105,111,110,32,109,97,114,107,32,114,105,103,104,116,32,112,111,105,110,116,105,110,103,32,103,117,105,108,108,101,109,101,116,44,32,85,43,48,48,66,66,32,73,83,79,110,117,109,0,0,0,0,0,0,102,114,97,99,49,52,0,0,118,117,108,103,97,114,32,102,114,97,99,116,105,111,110,32,111,110,101,32,113,117,97,114,116,101,114,32,61,32,102,114,97,99,116,105,111,110,32,111,110,101,32,113,117,97,114,116,101,114,44,32,85,43,48,48,66,67,32,73,83,79,110,117,109,0,0,0,0,0,0,0,102,114,97,99,49,50,0,0,118,117,108,103,97,114,32,102,114,97,99,116,105,111,110,32,111,110,101,32,104,97,108,102,32,61,32,102,114,97,99,116,105,111,110,32,111,110,101,32,104,97,108,102,44,32,85,43,48,48,66,68,32,73,83,79,110,117,109,0,0,0,0,0,102,114,97,99,51,52,0,0,118,117,108,103,97,114,32,102,114,97,99,116,105,111,110,32,116,104,114,101,101,32,113,117,97,114,116,101,114,115,32,61,32,102,114,97,99,116,105,111,110,32,116,104,114,101,101,32,113,117,97,114,116,101,114,115,44,32,85,43,48,48,66,69,32,73,83,79,110,117,109,0,105,113,117,101,115,116,0,0,105,110,118,101,114,116,101,100,32,113,117,101,115,116,105,111,110,32,109,97,114,107,32,61,32,116,117,114,110,101,100,32,113,117,101,115,116,105,111,110,32,109,97,114,107,44,32,85,43,48,48,66,70,32,73,83,79,110,117,109,0,0,0,0,65,103,114,97,118,101,0,0,108,97,116,105,110,32,99,97,112,105,116,97,108,32,108,101,116,116,101,114,32,65,32,119,105,116,104,32,103,114,97,118,101,32,61,32,108,97,116,105,110,32,99,97,112,105,116,97,108,32,108,101,116,116,101,114,32,65,32,103,114,97,118,101,44,32,85,43,48,48,67,48,32,73,83,79,108,97,116,49,0,0,0,0,0,0,0,0,65,97,99,117,116,101,0,0,108,97,116,105,110,32,99,97,112,105,116,97,108,32,108,101,116,116,101,114,32,65,32,119,105,116,104,32,97,99,117,116,101,44,32,85,43,48,48,67,49,32,73,83,79,108,97,116,49,0,0,0,0,0,0,0,65,99,105,114,99,0,0,0,108,97,116,105,110,32,99,97,112,105,116,97,108,32,108,101,116,116,101,114,32,65,32,119,105,116,104,32,99,105,114,99,117,109,102,108,101,120,44,32,85,43,48,48,67,50,32,73,83,79,108,97,116,49,0,0,65,116,105,108,100,101,0,0,108,97,116,105,110,32,99,97,112,105,116,97,108,32,108,101,116,116,101,114,32,65,32,119,105,116,104,32,116,105,108,100,101,44,32,85,43,48,48,67,51,32,73,83,79,108,97,116,49,0,0,0,0,0,0,0,65,117,109,108,0,0,0,0,108,97,116,105,110,32,99,97,112,105,116,97,108,32,108,101,116,116,101,114,32,65,32,119,105,116,104,32,100,105,97,101,114,101,115,105,115,44,32,85,43,48,48,67,52,32,73,83,79,108,97,116,49,0,0,0,65,114,105,110,103,0,0,0,108,97,116,105,110,32,99,97,112,105,116,97,108,32,108,101,116,116,101,114,32,65,32,119,105,116,104,32,114,105,110,103,32,97,98,111,118,101,32,61,32,108,97,116,105,110,32,99,97,112,105,116,97,108,32,108,101,116,116,101,114,32,65,32,114,105,110,103,44,32,85,43,48,48,67,53,32,73,83,79,108,97,116,49,0,0,0,0,65,69,108,105,103,0,0,0,108,97,116,105,110,32,99,97,112,105,116,97,108,32,108,101,116,116,101,114,32,65,69,32,61,32,108,97,116,105,110,32,99,97,112,105,116,97,108,32,108,105,103,97,116,117,114,101,32,65,69,44,32,85,43,48,48,67,54,32,73,83,79,108,97,116,49,0,0,0,0,0,67,99,101,100,105,108,0,0,108,97,116,105,110,32,99,97,112,105,116,97,108,32,108,101,116,116,101,114,32,67,32,119,105,116,104,32,99,101,100,105,108,108,97,44,32,85,43,48,48,67,55,32,73,83,79,108,97,116,49,0,0,0,0,0,69,103,114,97,118,101,0,0,108,97,116,105,110,32,99,97,112,105,116,97,108,32,108,101,116,116,101,114,32,69,32,119,105,116,104,32,103,114,97,118,101,44,32,85,43,48,48,67,56,32,73,83,79,108,97,116,49,0,0,0,0,0,0,0,69,97,99,117,116,101,0,0,108,97,116,105,110,32,99,97,112,105,116,97,108,32,108,101,116,116,101,114,32,69,32,119,105,116,104,32,97,99,117,116,101,44,32,85,43,48,48,67,57,32,73,83,79,108,97,116,49,0,0,0,0,0,0,0,69,99,105,114,99,0,0,0,108,97,116,105,110,32,99,97,112,105,116,97,108,32,108,101,116,116,101,114,32,69,32,119,105,116,104,32,99,105,114,99,117,109,102,108,101,120,44,32,85,43,48,48,67,65,32,73,83,79,108,97,116,49,0,0,69,117,109,108,0,0,0,0,108,97,116,105,110,32,99,97,112,105,116,97,108,32,108,101,116,116,101,114,32,69,32,119,105,116,104,32,100,105,97,101,114,101,115,105,115,44,32,85,43,48,48,67,66,32,73,83,79,108,97,116,49,0,0,0,73,103,114,97,118,101,0,0,108,97,116,105,110,32,99,97,112,105,116,97,108,32,108,101,116,116,101,114,32,73,32,119,105,116,104,32,103,114,97,118,101,44,32,85,43,48,48,67,67,32,73,83,79,108,97,116,49,0,0,0,0,0,0,0,73,97,99,117,116,101,0,0,108,97,116,105,110,32,99,97,112,105,116,97,108,32,108,101,116,116,101,114,32,73,32,119,105,116,104,32,97,99,117,116,101,44,32,85,43,48,48,67,68,32,73,83,79,108,97,116,49,0,0,0,0,0,0,0,73,99,105,114,99,0,0,0,108,97,116,105,110,32,99,97,112,105,116,97,108,32,108,101,116,116,101,114,32,73,32,119,105,116,104,32,99,105,114,99,117,109,102,108,101,120,44,32,85,43,48,48,67,69,32,73,83,79,108,97,116,49,0,0,73,117,109,108,0,0,0,0,108,97,116,105,110,32,99,97,112,105,116,97,108,32,108,101,116,116,101,114,32,73,32,119,105,116,104,32,100,105,97,101,114,101,115,105,115,44,32,85,43,48,48,67,70,32,73,83,79,108,97,116,49,0,0,0,69,84,72,0,0,0,0,0,108,97,116,105,110,32,99,97,112,105,116,97,108,32,108,101,116,116,101,114,32,69,84,72,44,32,85,43,48,48,68,48,32,73,83,79,108,97,116,49,0,0,0,0,0,0,0,0,78,116,105,108,100,101,0,0,108,97,116,105,110,32,99,97,112,105,116,97,108,32,108,101,116,116,101,114,32,78,32,119,105,116,104,32,116,105,108,100,101,44,32,85,43,48,48,68,49,32,73,83,79,108,97,116,49,0,0,0,0,0,0,0,79,103,114,97,118,101,0,0,108,97,116,105,110,32,99,97,112,105,116,97,108,32,108,101,116,116,101,114,32,79,32,119,105,116,104,32,103,114,97,118,101,44,32,85,43,48,48,68,50,32,73,83,79,108,97,116,49,0,0,0,0,0,0,0,79,97,99,117,116,101,0,0,108,97,116,105,110,32,99,97,112,105,116,97,108,32,108,101,116,116,101,114,32,79,32,119,105,116,104,32,97,99,117,116,101,44,32,85,43,48,48,68,51,32,73,83,79,108,97,116,49,0,0,0,0,0,0,0,79,99,105,114,99,0,0,0,108,97,116,105,110,32,99,97,112,105,116,97,108,32,108,101,116,116,101,114,32,79,32,119,105,116,104,32,99,105,114,99,117,109,102,108,101,120,44,32,85,43,48,48,68,52,32,73,83,79,108,97,116,49,0,0,79,116,105,108,100,101,0,0,108,97,116,105,110,32,99,97,112,105,116,97,108,32,108,101,116,116,101,114,32,79,32,119,105,116,104,32,116,105,108,100,101,44,32,85,43,48,48,68,53,32,73,83,79,108,97,116,49,0,0,0,0,0,0,0,79,117,109,108,0,0,0,0,108,97,116,105,110,32,99,97,112,105,116,97,108,32,108,101,116,116,101,114,32,79,32,119,105,116,104,32,100,105,97,101,114,101,115,105,115,44,32,85,43,48,48,68,54,32,73,83,79,108,97,116,49,0,0,0,116,105,109,101,115,0,0,0,109,117,108,116,105,112,108,105,99,97,116,105,111,110,32,115,105,103,110,44,32,85,43,48,48,68,55,32,73,83,79,110,117,109,0,0,0,0,0,0,79,115,108,97,115,104,0,0,108,97,116,105,110,32,99,97,112,105,116,97,108,32,108,101,116,116,101,114,32,79,32,119,105,116,104,32,115,116,114,111,107,101,32,108,97,116,105,110,32,99,97,112,105,116,97,108,32,108,101,116,116,101,114,32,79,32,115,108,97,115,104,44,32,85,43,48,48,68,56,32,73,83,79,108,97,116,49,0,85,103,114,97,118,101,0,0,108,97,116,105,110,32,99,97,112,105,116,97,108,32,108,101,116,116,101,114,32,85,32,119,105,116,104,32,103,114,97,118,101,44,32,85,43,48,48,68,57,32,73,83,79,108,97,116,49,0,0,0,0,0,0,0,85,97,99,117,116,101,0,0,108,97,116,105,110,32,99,97,112,105,116,97,108,32,108,101,116,116,101,114,32,85,32,119,105,116,104,32,97,99,117,116,101,44,32,85,43,48,48,68,65,32,73,83,79,108,97,116,49,0,0,0,0,0,0,0,85,99,105,114,99,0,0,0,108,97,116,105,110,32,99,97,112,105,116,97,108,32,108,101,116,116,101,114,32,85,32,119,105,116,104,32,99,105,114,99,117,109,102,108,101,120,44,32,85,43,48,48,68,66,32,73,83,79,108,97,116,49,0,0,85,117,109,108,0,0,0,0,108,97,116,105,110,32,99,97,112,105,116,97,108,32,108,101,116,116,101,114,32,85,32,119,105,116,104,32,100,105,97,101,114,101,115,105,115,44,32,85,43,48,48,68,67,32,73,83,79,108,97,116,49,0,0,0,89,97,99,117,116,101,0,0,108,97,116,105,110,32,99,97,112,105,116,97,108,32,108,101,116,116,101,114,32,89,32,119,105,116,104,32,97,99,117,116,101,44,32,85,43,48,48,68,68,32,73,83,79,108,97,116,49,0,0,0,0,0,0,0,84,72,79,82,78,0,0,0,108,97,116,105,110,32,99,97,112,105,116,97,108,32,108,101,116,116,101,114,32,84,72,79,82,78,44,32,85,43,48,48,68,69,32,73,83,79,108,97,116,49,0,0,0,0,0,0,115,122,108,105,103,0,0,0,108,97,116,105,110,32,115,109,97,108,108,32,108,101,116,116,101,114,32,115,104,97,114,112,32,115,32,61,32,101,115,115,45,122,101,100,44,32,85,43,48,48,68,70,32,73,83,79,108,97,116,49,0,0,0,0,97,103,114,97,118,101,0,0,108,97,116,105,110,32,115,109,97,108,108,32,108,101,116,116,101,114,32,97,32,119,105,116,104,32,103,114,97,118,101,32,61,32,108,97,116,105,110,32,115,109,97,108,108,32,108,101,116,116,101,114,32,97,32,103,114,97,118,101,44,32,85,43,48,48,69,48,32,73,83,79,108,97,116,49,0,0,0,0,97,97,99,117,116,101,0,0,108,97,116,105,110,32,115,109,97,108,108,32,108,101,116,116,101,114,32,97,32,119,105,116,104,32,97,99,117,116,101,44,32,85,43,48,48,69,49,32,73,83,79,108,97,116,49,0,97,99,105,114,99,0,0,0,108,97,116,105,110,32,115,109,97,108,108,32,108,101,116,116,101,114,32,97,32,119,105,116,104,32,99,105,114,99,117,109,102,108,101,120,44,32,85,43,48,48,69,50,32,73,83,79,108,97,116,49,0,0,0,0,97,116,105,108,100,101,0,0,108,97,116,105,110,32,115,109,97,108,108,32,108,101,116,116,101,114,32,97,32,119,105,116,104,32,116,105,108,100,101,44,32,85,43,48,48,69,51,32,73,83,79,108,97,116,49,0,97,117,109,108,0,0,0,0,108,97,116,105,110,32,115,109,97,108,108,32,108,101,116,116,101,114,32,97,32,119,105,116,104,32,100,105,97,101,114,101,115,105,115,44,32,85,43,48,48,69,52,32,73,83,79,108,97,116,49,0,0,0,0,0,97,114,105,110,103,0,0,0,108,97,116,105,110,32,115,109,97,108,108,32,108,101,116,116,101,114,32,97,32,119,105,116,104,32,114,105,110,103,32,97,98,111,118,101,32,61,32,108,97,116,105,110,32,115,109,97,108,108,32,108,101,116,116,101,114,32,97,32,114,105,110,103,44,32,85,43,48,48,69,53,32,73,83,79,108,97,116,49,0,0,0,0,0,0,0,0,97,101,108,105,103,0,0,0,108,97,116,105,110,32,115,109,97,108,108,32,108,101,116,116,101,114,32,97,101,32,61,32,108,97,116,105,110,32,115,109,97,108,108,32,108,105,103,97,116,117,114,101,32,97,101,44,32,85,43,48,48,69,54,32,73,83,79,108,97,116,49,0,99,99,101,100,105,108,0,0,108,97,116,105,110,32,115,109,97,108,108,32,108,101,116,116,101,114,32,99,32,119,105,116,104,32,99,101,100,105,108,108,97,44,32,85,43,48,48,69,55,32,73,83,79,108,97,116,49,0,0,0,0,0,0,0,101,103,114,97,118,101,0,0,108,97,116,105,110,32,115,109,97,108,108,32,108,101,116,116,101,114,32,101,32,119,105,116,104,32,103,114,97,118,101,44,32,85,43,48,48,69,56,32,73,83,79,108,97,116,49,0,101,97,99,117,116,101,0,0,108,97,116,105,110,32,115,109,97,108,108,32,108,101,116,116,101,114,32,101,32,119,105,116,104,32,97,99,117,116,101,44,32,85,43,48,48,69,57,32,73,83,79,108,97,116,49,0,101,99,105,114,99,0,0,0,108,97,116,105,110,32,115,109,97,108,108,32,108,101,116,116,101,114,32,101,32,119,105,116,104,32,99,105,114,99,117,109,102,108,101,120,44,32,85,43,48,48,69,65,32,73,83,79,108,97,116,49,0,0,0,0,101,117,109,108,0,0,0,0,108,97,116,105,110,32,115,109,97,108,108,32,108,101,116,116,101,114,32,101,32,119,105,116,104,32,100,105,97,101,114,101,115,105,115,44,32,85,43,48,48,69,66,32,73,83,79,108,97,116,49,0,0,0,0,0,105,103,114,97,118,101,0,0,108,97,116,105,110,32,115,109,97,108,108,32,108,101,116,116,101,114,32,105,32,119,105,116,104,32,103,114,97,118,101,44,32,85,43,48,48,69,67,32,73,83,79,108,97,116,49,0,105,97,99,117,116,101,0,0,108,97,116,105,110,32,115,109,97,108,108,32,108,101,116,116,101,114,32,105,32,119,105,116,104,32,97,99,117,116,101,44,32,85,43,48,48,69,68,32,73,83,79,108,97,116,49,0,105,99,105,114,99,0,0,0,108,97,116,105,110,32,115,109,97,108,108,32,108,101,116,116,101,114,32,105,32,119,105,116,104,32,99,105,114,99,117,109,102,108,101,120,44,32,85,43,48,48,69,69,32,73,83,79,108,97,116,49,0,0,0,0,105,117,109,108,0,0,0,0,108,97,116,105,110,32,115,109,97,108,108,32,108,101,116,116,101,114,32,105,32,119,105,116,104,32,100,105,97,101,114,101,115,105,115,44,32,85,43,48,48,69,70,32,73,83,79,108,97,116,49,0,0,0,0,0,101,116,104,0,0,0,0,0,108,97,116,105,110,32,115,109,97,108,108,32,108,101,116,116,101,114,32,101,116,104,44,32,85,43,48,48,70,48,32,73,83,79,108,97,116,49,0,0,110,116,105,108,100,101,0,0,108,97,116,105,110,32,115,109,97,108,108,32,108,101,116,116,101,114,32,110,32,119,105,116,104,32,116,105,108,100,101,44,32,85,43,48,48,70,49,32,73,83,79,108,97,116,49,0,111,103,114,97,118,101,0,0,108,97,116,105,110,32,115,109,97,108,108,32,108,101,116,116,101,114,32,111,32,119,105,116,104,32,103,114,97,118,101,44,32,85,43,48,48,70,50,32,73,83,79,108,97,116,49,0,111,97,99,117,116,101,0,0,108,97,116,105,110,32,115,109,97,108,108,32,108,101,116,116,101,114,32,111,32,119,105,116,104,32,97,99,117,116,101,44,32,85,43,48,48,70,51,32,73,83,79,108,97,116,49,0,111,99,105,114,99,0,0,0,108,97,116,105,110,32,115,109,97,108,108,32,108,101,116,116,101,114,32,111,32,119,105,116,104,32,99,105,114,99,117,109,102,108,101,120,44,32,85,43,48,48,70,52,32,73,83,79,108,97,116,49,0,0,0,0,111,116,105,108,100,101,0,0,108,97,116,105,110,32,115,109,97,108,108,32,108,101,116,116,101,114,32,111,32,119,105,116,104,32,116,105,108,100,101,44,32,85,43,48,48,70,53,32,73,83,79,108,97,116,49,0,111,117,109,108,0,0,0,0,108,97,116,105,110,32,115,109,97,108,108,32,108,101,116,116,101,114,32,111,32,119,105,116,104,32,100,105,97,101,114,101,115,105,115,44,32,85,43,48,48,70,54,32,73,83,79,108,97,116,49,0,0,0,0,0,100,105,118,105,100,101,0,0,100,105,118,105,115,105,111,110,32,115,105,103,110,44,32,85,43,48,48,70,55,32,73,83,79,110,117,109,0,0,0,0,111,115,108,97,115,104,0,0,108,97,116,105,110,32,115,109,97,108,108,32,108,101,116,116,101,114,32,111,32,119,105,116,104,32,115,116,114,111,107,101,44,32,61,32,108,97,116,105,110,32,115,109,97,108,108,32,108,101,116,116,101,114,32,111,32,115,108,97,115,104,44,32,85,43,48,48,70,56,32,73,83,79,108,97,116,49,0,0,117,103,114,97,118,101,0,0,108,97,116,105,110,32,115,109,97,108,108,32,108,101,116,116,101,114,32,117,32,119,105,116,104,32,103,114,97,118,101,44,32,85,43,48,48,70,57,32,73,83,79,108,97,116,49,0,117,97,99,117,116,101,0,0,108,97,116,105,110,32,115,109,97,108,108,32,108,101,116,116,101,114,32,117,32,119,105,116,104,32,97,99,117,116,101,44,32,85,43,48,48,70,65,32,73,83,79,108,97,116,49,0,117,99,105,114,99,0,0,0,108,97,116,105,110,32,115,109,97,108,108,32,108,101,116,116,101,114,32,117,32,119,105,116,104,32,99,105,114,99,117,109,102,108,101,120,44,32,85,43,48,48,70,66,32,73,83,79,108,97,116,49,0,0,0,0,117,117,109,108,0,0,0,0,108,97,116,105,110,32,115,109,97,108,108,32,108,101,116,116,101,114,32,117,32,119,105,116,104,32,100,105,97,101,114,101,115,105,115,44,32,85,43,48,48,70,67,32,73,83,79,108,97,116,49,0,0,0,0,0,121,97,99,117,116,101,0,0,108,97,116,105,110,32,115,109,97,108,108,32,108,101,116,116,101,114,32,121,32,119,105,116,104,32,97,99,117,116,101,44,32,85,43,48,48,70,68,32,73,83,79,108,97,116,49,0,116,104,111,114,110,0,0,0,108,97,116,105,110,32,115,109,97,108,108,32,108,101,116,116,101,114,32,116,104,111,114,110,32,119,105,116,104,44,32,85,43,48,48,70,69,32,73,83,79,108,97,116,49,0,0,0,121,117,109,108,0,0,0,0,108,97,116,105,110,32,115,109,97,108,108,32,108,101,116,116,101,114,32,121,32,119,105,116,104,32,100,105,97,101,114,101,115,105,115,44,32,85,43,48,48,70,70,32,73,83,79,108,97,116,49,0,0,0,0,0,79,69,108,105,103,0,0,0,108,97,116,105,110,32,99,97,112,105,116,97,108,32,108,105,103,97,116,117,114,101,32,79,69,44,32,85,43,48,49,53,50,32,73,83,79,108,97,116,50,0,0,0,0,0,0,0,111,101,108,105,103,0,0,0,108,97,116,105,110,32,115,109,97,108,108,32,108,105,103,97,116,117,114,101,32,111,101,44,32,85,43,48,49,53,51,32,73,83,79,108,97,116,50,0,83,99,97,114,111,110,0,0,108,97,116,105,110,32,99,97,112,105,116,97,108,32,108,101,116,116,101,114,32,83,32,119,105,116,104,32,99,97,114,111,110,44,32,85,43,48,49,54,48,32,73,83,79,108,97,116,50,0,0,0,0,0,0,0,115,99,97,114,111,110,0,0,108,97,116,105,110,32,115,109,97,108,108,32,108,101,116,116,101,114,32,115,32,119,105,116,104,32,99,97,114,111,110,44,32,85,43,48,49,54,49,32,73,83,79,108,97,116,50,0,89,117,109,108,0,0,0,0,108,97,116,105,110,32,99,97,112,105,116,97,108,32,108,101,116,116,101,114,32,89,32,119,105,116,104,32,100,105,97,101,114,101,115,105,115,44,32,85,43,48,49,55,56,32,73,83,79,108,97,116,50,0,0,0,102,110,111,102,0,0,0,0,108,97,116,105,110,32,115,109,97,108,108,32,102,32,119,105,116,104,32,104,111,111,107,32,61,32,102,117,110,99,116,105,111,110,32,61,32,102,108,111,114,105,110,44,32,85,43,48,49,57,50,32,73,83,79,116,101,99,104,0,0,0,0,0,99,105,114,99,0,0,0,0,109,111,100,105,102,105,101,114,32,108,101,116,116,101,114,32,99,105,114,99,117,109,102,108,101,120,32,97,99,99,101,110,116,44,32,85,43,48,50,67,54,32,73,83,79,112,117,98,0,0,0,0,0,0,0,0,116,105,108,100,101,0,0,0,115,109,97,108,108,32,116,105,108,100,101,44,32,85,43,48,50,68,67,32,73,83,79,100,105,97,0,0,0,0,0,0,65,108,112,104,97,0,0,0,103,114,101,101,107,32,99,97,112,105,116,97,108,32,108,101,116,116,101,114,32,97,108,112,104,97,44,32,85,43,48,51,57,49,0,0,0,0,0,0,66,101,116,97,0,0,0,0,103,114,101,101,107,32,99,97,112,105,116,97,108,32,108,101,116,116,101,114,32,98,101,116,97,44,32,85,43,48,51,57,50,0,0,0,0,0,0,0,71,97,109,109,97,0,0,0,103,114,101,101,107,32,99,97,112,105,116,97,108,32,108,101,116,116,101,114,32,103,97,109,109,97,44,32,85,43,48,51,57,51,32,73,83,79,103,114,107,51,0,0,0,0,0,0,68,101,108,116,97,0,0,0,103,114,101,101,107,32,99,97,112,105,116,97,108,32,108,101,116,116,101,114,32,100,101,108,116,97,44,32,85,43,48,51,57,52,32,73,83,79,103,114,107,51,0,0,0,0,0,0,69,112,115,105,108,111,110,0,103,114,101,101,107,32,99,97,112,105,116,97,108,32,108,101,116,116,101,114,32,101,112,115,105,108,111,110,44,32,85,43,48,51,57,53,0,0,0,0,90,101,116,97,0,0,0,0,103,114,101,101,107,32,99,97,112,105,116,97,108,32,108,101,116,116,101,114,32,122,101,116,97,44,32,85,43,48,51,57,54,0,0,0,0,0,0,0,69,116,97,0,0,0,0,0,103,114,101,101,107,32,99,97,112,105,116,97,108,32,108,101,116,116,101,114,32,101,116,97,44,32,85,43,48,51,57,55,0,0,0,0,0,0,0,0,84,104,101,116,97,0,0,0,103,114,101,101,107,32,99,97,112,105,116,97,108,32,108,101,116,116,101,114,32,116,104,101,116,97,44,32,85,43,48,51,57,56,32,73,83,79,103,114,107,51,0,0,0,0,0,0,73,111,116,97,0,0,0,0,103,114,101,101,107,32,99,97,112,105,116,97,108,32,108,101,116,116,101,114,32,105,111,116,97,44,32,85,43,48,51,57,57,0,0,0,0,0,0,0,75,97,112,112,97,0,0,0,103,114,101,101,107,32,99,97,112,105,116,97,108,32,108,101,116,116,101,114,32,107,97,112,112,97,44,32,85,43,48,51,57,65,0,0,0,0,0,0,76,97,109,98,100,97,0,0,103,114,101,101,107,32,99,97],"i8",ALLOC_NONE,Runtime.GLOBAL_BASE+95088),
	allocate([112,105,116,97,108,32,108,101,116,116,101,114,32,108,97,109,98,100,97,44,32,85,43,48,51,57,66,32,73,83,79,103,114,107,51,0,0,0,0,0,77,117,0,0,0,0,0,0,103,114,101,101,107,32,99,97,112,105,116,97,108,32,108,101,116,116,101,114,32,109,117,44,32,85,43,48,51,57,67,0,78,117,0,0,0,0,0,0,103,114,101,101,107,32,99,97,112,105,116,97,108,32,108,101,116,116,101,114,32,110,117,44,32,85,43,48,51,57,68,0,88,105,0,0,0,0,0,0,103,114,101,101,107,32,99,97,112,105,116,97,108,32,108,101,116,116,101,114,32,120,105,44,32,85,43,48,51,57,69,32,73,83,79,103,114,107,51,0,79,109,105,99,114,111,110,0,103,114,101,101,107,32,99,97,112,105,116,97,108,32,108,101,116,116,101,114,32,111,109,105,99,114,111,110,44,32,85,43,48,51,57,70,0,0,0,0,80,105,0,0,0,0,0,0,103,114,101,101,107,32,99,97,112,105,116,97,108,32,108,101,116,116,101,114,32,112,105,44,32,85,43,48,51,65,48,32,73,83,79,103,114,107,51,0,82,104,111,0,0,0,0,0,103,114,101,101,107,32,99,97,112,105,116,97,108,32,108,101,116,116,101,114,32,114,104,111,44,32,85,43,48,51,65,49,0,0,0,0,0,0,0,0,83,105,103,109,97,0,0,0,103,114,101,101,107,32,99,97,112,105,116,97,108,32,108,101,116,116,101,114,32,115,105,103,109,97,44,32,85,43,48,51,65,51,32,73,83,79,103,114,107,51,0,0,0,0,0,0,84,97,117,0,0,0,0,0,103,114,101,101,107,32,99,97,112,105,116,97,108,32,108,101,116,116,101,114,32,116,97,117,44,32,85,43,48,51,65,52,0,0,0,0,0,0,0,0,85,112,115,105,108,111,110,0,103,114,101,101,107,32,99,97,112,105,116,97,108,32,108,101,116,116,101,114,32,117,112,115,105,108,111,110,44,32,85,43,48,51,65,53,32,73,83,79,103,114,107,51,0,0,0,0,80,104,105,0,0,0,0,0,103,114,101,101,107,32,99,97,112,105,116,97,108,32,108,101,116,116,101,114,32,112,104,105,44,32,85,43,48,51,65,54,32,73,83,79,103,114,107,51,0,0,0,0,0,0,0,0,67,104,105,0,0,0,0,0,103,114,101,101,107,32,99,97,112,105,116,97,108,32,108,101,116,116,101,114,32,99,104,105,44,32,85,43,48,51,65,55,0,0,0,0,0,0,0,0,80,115,105,0,0,0,0,0,103,114,101,101,107,32,99,97,112,105,116,97,108,32,108,101,116,116,101,114,32,112,115,105,44,32,85,43,48,51,65,56,32,73,83,79,103,114,107,51,0,0,0,0,0,0,0,0,79,109,101,103,97,0,0,0,103,114,101,101,107,32,99,97,112,105,116,97,108,32,108,101,116,116,101,114,32,111,109,101,103,97,44,32,85,43,48,51,65,57,32,73,83,79,103,114,107,51,0,0,0,0,0,0,97,108,112,104,97,0,0,0,103,114,101,101,107,32,115,109,97,108,108,32,108,101,116,116,101,114,32,97,108,112,104,97,44,32,85,43,48,51,66,49,32,73,83,79,103,114,107,51,0,0,0,0,0,0,0,0,98,101,116,97,0,0,0,0,103,114,101,101,107,32,115,109,97,108,108,32,108,101,116,116,101,114,32,98,101,116,97,44,32,85,43,48,51,66,50,32,73,83,79,103,114,107,51,0,103,97,109,109,97,0,0,0,103,114,101,101,107,32,115,109,97,108,108,32,108,101,116,116,101,114,32,103,97,109,109,97,44,32,85,43,48,51,66,51,32,73,83,79,103,114,107,51,0,0,0,0,0,0,0,0,100,101,108,116,97,0,0,0,103,114,101,101,107,32,115,109,97,108,108,32,108,101,116,116,101,114,32,100,101,108,116,97,44,32,85,43,48,51,66,52,32,73,83,79,103,114,107,51,0,0,0,0,0,0,0,0,101,112,115,105,108,111,110,0,103,114,101,101,107,32,115,109,97,108,108,32,108,101,116,116,101,114,32,101,112,115,105,108,111,110,44,32,85,43,48,51,66,53,32,73,83,79,103,114,107,51,0,0,0,0,0,0,122,101,116,97,0,0,0,0,103,114,101,101,107,32,115,109,97,108,108,32,108,101,116,116,101,114,32,122,101,116,97,44,32,85,43,48,51,66,54,32,73,83,79,103,114,107,51,0,101,116,97,0,0,0,0,0,103,114,101,101,107,32,115,109,97,108,108,32,108,101,116,116,101,114,32,101,116,97,44,32,85,43,48,51,66,55,32,73,83,79,103,114,107,51,0,0,116,104,101,116,97,0,0,0,103,114,101,101,107,32,115,109,97,108,108,32,108,101,116,116,101,114,32,116,104,101,116,97,44,32,85,43,48,51,66,56,32,73,83,79,103,114,107,51,0,0,0,0,0,0,0,0,105,111,116,97,0,0,0,0,103,114,101,101,107,32,115,109,97,108,108,32,108,101,116,116,101,114,32,105,111,116,97,44,32,85,43,48,51,66,57,32,73,83,79,103,114,107,51,0,107,97,112,112,97,0,0,0,103,114,101,101,107,32,115,109,97,108,108,32,108,101,116,116,101,114,32,107,97,112,112,97,44,32,85,43,48,51,66,65,32,73,83,79,103,114,107,51,0,0,0,0,0,0,0,0,108,97,109,98,100,97,0,0,103,114,101,101,107,32,115,109,97,108,108,32,108,101,116,116,101,114,32,108,97,109,98,100,97,44,32,85,43,48,51,66,66,32,73,83,79,103,114,107,51,0,0,0,0,0,0,0,109,117,0,0,0,0,0,0,103,114,101,101,107,32,115,109,97,108,108,32,108,101,116,116,101,114,32,109,117,44,32,85,43,48,51,66,67,32,73,83,79,103,114,107,51,0,0,0,110,117,0,0,0,0,0,0,103,114,101,101,107,32,115,109,97,108,108,32,108,101,116,116,101,114,32,110,117,44,32,85,43,48,51,66,68,32,73,83,79,103,114,107,51,0,0,0,120,105,0,0,0,0,0,0,103,114,101,101,107,32,115,109,97,108,108,32,108,101,116,116,101,114,32,120,105,44,32,85,43,48,51,66,69,32,73,83,79,103,114,107,51,0,0,0,111,109,105,99,114,111,110,0,103,114,101,101,107,32,115,109,97,108,108,32,108,101,116,116,101,114,32,111,109,105,99,114,111,110,44,32,85,43,48,51,66,70,32,78,69,87,0,0,112,105,0,0,0,0,0,0,103,114,101,101,107,32,115,109,97,108,108,32,108,101,116,116,101,114,32,112,105,44,32,85,43,48,51,67,48,32,73,83,79,103,114,107,51,0,0,0,114,104,111,0,0,0,0,0,103,114,101,101,107,32,115,109,97,108,108,32,108,101,116,116,101,114,32,114,104,111,44,32,85,43,48,51,67,49,32,73,83,79,103,114,107,51,0,0,115,105,103,109,97,102,0,0,103,114,101,101,107,32,115,109,97,108,108,32,108,101,116,116,101,114,32,102,105,110,97,108,32,115,105,103,109,97,44,32,85,43,48,51,67,50,32,73,83,79,103,114,107,51,0,0,115,105,103,109,97,0,0,0,103,114,101,101,107,32,115,109,97,108,108,32,108,101,116,116,101,114,32,115,105,103,109,97,44,32,85,43,48,51,67,51,32,73,83,79,103,114,107,51,0,0,0,0,0,0,0,0,116,97,117,0,0,0,0,0,103,114,101,101,107,32,115,109,97,108,108,32,108,101,116,116,101,114,32,116,97,117,44,32,85,43,48,51,67,52,32,73,83,79,103,114,107,51,0,0,117,112,115,105,108,111,110,0,103,114,101,101,107,32,115,109,97,108,108,32,108,101,116,116,101,114,32,117,112,115,105,108,111,110,44,32,85,43,48,51,67,53,32,73,83,79,103,114,107,51,0,0,0,0,0,0,112,104,105,0,0,0,0,0,103,114,101,101,107,32,115,109,97,108,108,32,108,101,116,116,101,114,32,112,104,105,44,32,85,43,48,51,67,54,32,73,83,79,103,114,107,51,0,0,99,104,105,0,0,0,0,0,103,114,101,101,107,32,115,109,97,108,108,32,108,101,116,116,101,114,32,99,104,105,44,32,85,43,48,51,67,55,32,73,83,79,103,114,107,51,0,0,112,115,105,0,0,0,0,0,103,114,101,101,107,32,115,109,97,108,108,32,108,101,116,116,101,114,32,112,115,105,44,32,85,43,48,51,67,56,32,73,83,79,103,114,107,51,0,0,111,109,101,103,97,0,0,0,103,114,101,101,107,32,115,109,97,108,108,32,108,101,116,116,101,114,32,111,109,101,103,97,44,32,85,43,48,51,67,57,32,73,83,79,103,114,107,51,0,0,0,0,0,0,0,0,116,104,101,116,97,115,121,109,0,0,0,0,0,0,0,0,103,114,101,101,107,32,115,109,97,108,108,32,108,101,116,116,101,114,32,116,104,101,116,97,32,115,121,109,98,111,108,44,32,85,43,48,51,68,49,32,78,69,87,0,0,0,0,0,117,112,115,105,104,0,0,0,103,114,101,101,107,32,117,112,115,105,108,111,110,32,119,105,116,104,32,104,111,111,107,32,115,121,109,98,111,108,44,32,85,43,48,51,68,50,32,78,69,87,0,0,0,0,0,0,112,105,118,0,0,0,0,0,103,114,101,101,107,32,112,105,32,115,121,109,98,111,108,44,32,85,43,48,51,68,54,32,73,83,79,103,114,107,51,0,101,110,115,112,0,0,0,0,101,110,32,115,112,97,99,101,44,32,85,43,50,48,48,50,32,73,83,79,112,117,98,0,101,109,115,112,0,0,0,0,101,109,32,115,112,97,99,101,44,32,85,43,50,48,48,51,32,73,83,79,112,117,98,0,116,104,105,110,115,112,0,0,116,104,105,110,32,115,112,97,99,101,44,32,85,43,50,48,48,57,32,73,83,79,112,117,98,0,0,0,0,0,0,0,122,119,110,106,0,0,0,0,122,101,114,111,32,119,105,100,116,104,32,110,111,110,45,106,111,105,110,101,114,44,32,85,43,50,48,48,67,32,78,69,87,32,82,70,67,32,50,48,55,48,0,0,0,0,0,0,122,119,106,0,0,0,0,0,122,101,114,111,32,119,105,100,116,104,32,106,111,105,110,101,114,44,32,85,43,50,48,48,68,32,78,69,87,32,82,70,67,32,50,48,55,48,0,0,108,114,109,0,0,0,0,0,108,101,102,116,45,116,111,45,114,105,103,104,116,32,109,97,114,107,44,32,85,43,50,48,48,69,32,78,69,87,32,82,70,67,32,50,48,55,48,0,114,108,109,0,0,0,0,0,114,105,103,104,116,45,116,111,45,108,101,102,116,32,109,97,114,107,44,32,85,43,50,48,48,70,32,78,69,87,32,82,70,67,32,50,48,55,48,0,110,100,97,115,104,0,0,0,101,110,32,100,97,115,104,44,32,85,43,50,48,49,51,32,73,83,79,112,117,98,0,0,109,100,97,115,104,0,0,0,101,109,32,100,97,115,104,44,32,85,43,50,48,49,52,32,73,83,79,112,117,98,0,0,108,115,113,117,111,0,0,0,108,101,102,116,32,115,105,110,103,108,101,32,113,117,111,116,97,116,105,111,110,32,109,97,114,107,44,32,85,43,50,48,49,56,32,73,83,79,110,117,109,0,0,0,0,0,0,0,114,115,113,117,111,0,0,0,114,105,103,104,116,32,115,105,110,103,108,101,32,113,117,111,116,97,116,105,111,110,32,109,97,114,107,44,32,85,43,50,48,49,57,32,73,83,79,110,117,109,0,0,0,0,0,0,115,98,113,117,111,0,0,0,115,105,110,103,108,101,32,108,111,119,45,57,32,113,117,111,116,97,116,105,111,110,32,109,97,114,107,44,32,85,43,50,48,49,65,32,78,69,87,0,108,100,113,117,111,0,0,0,108,101,102,116,32,100,111,117,98,108,101,32,113,117,111,116,97,116,105,111,110,32,109,97,114,107,44,32,85,43,50,48,49,67,32,73,83,79,110,117,109,0,0,0,0,0,0,0,114,100,113,117,111,0,0,0,114,105,103,104,116,32,100,111,117,98,108,101,32,113,117,111,116,97,116,105,111,110,32,109,97,114,107,44,32,85,43,50,48,49,68,32,73,83,79,110,117,109,0,0,0,0,0,0,98,100,113,117,111,0,0,0,100,111,117,98,108,101,32,108,111,119,45,57,32,113,117,111,116,97,116,105,111,110,32,109,97,114,107,44,32,85,43,50,48,49,69,32,78,69,87,0,100,97,103,103,101,114,0,0,100,97,103,103,101,114,44,32,85,43,50,48,50,48,32,73,83,79,112,117,98,0,0,0,68,97,103,103,101,114,0,0,100,111,117,98,108,101,32,100,97,103,103,101,114,44,32,85,43,50,48,50,49,32,73,83,79,112,117,98,0,0,0,0,98,117,108,108,0,0,0,0,98,117,108,108,101,116,32,61,32,98,108,97,99,107,32,115,109,97,108,108,32,99,105,114,99,108,101,44,32,85,43,50,48,50,50,32,73,83,79,112,117,98,0,0,0,0,0,0,104,101,108,108,105,112,0,0,104,111,114,105,122,111,110,116,97,108,32,101,108,108,105,112,115,105,115,32,61,32,116,104,114,101,101,32,100,111,116,32,108,101,97,100,101,114,44,32,85,43,50,48,50,54,32,73,83,79,112,117,98,0,0,0,112,101,114,109,105,108,0,0,112,101,114,32,109,105,108,108,101,32,115,105,103,110,44,32,85,43,50,48,51,48,32,73,83,79,116,101,99,104,0,0,112,114,105,109,101,0,0,0,112,114,105,109,101,32,61,32,109,105,110,117,116,101,115,32,61,32,102,101,101,116,44,32,85,43,50,48,51,50,32,73,83,79,116,101,99,104,0,0,80,114,105,109,101,0,0,0,100,111,117,98,108,101,32,112,114,105,109,101,32,61,32,115,101,99,111,110,100,115,32,61,32,105,110,99,104,101,115,44,32,85,43,50,48,51,51,32,73,83,79,116,101,99,104,0,108,115,97,113,117,111,0,0,115,105,110,103,108,101,32,108,101,102,116,45,112,111,105,110,116,105,110,103,32,97,110,103,108,101,32,113,117,111,116,97,116,105,111,110,32,109,97,114,107,44,32,85,43,50,48,51,57,32,73,83,79,32,112,114,111,112,111,115,101,100,0,0,114,115,97,113,117,111,0,0,115,105,110,103,108,101,32,114,105,103,104,116,45,112,111,105,110,116,105,110,103,32,97,110,103,108,101,32,113,117,111,116,97,116,105,111,110,32,109,97,114,107,44,32,85,43,50,48,51,65,32,73,83,79,32,112,114,111,112,111,115,101,100,0,111,108,105,110,101,0,0,0,111,118,101,114,108,105,110,101,32,61,32,115,112,97,99,105,110,103,32,111,118,101,114,115,99,111,114,101,44,32,85,43,50,48,51,69,32,78,69,87,0,0,0,0,0,0,0,0,102,114,97,115,108,0,0,0,102,114,97,99,116,105,111,110,32,115,108,97,115,104,44,32,85,43,50,48,52,52,32,78,69,87,0,0,0,0,0,0,101,117,114,111,0,0,0,0,101,117,114,111,32,115,105,103,110,44,32,85,43,50,48,65,67,32,78,69,87,0,0,0,105,109,97,103,101,0,0,0,98,108,97,99,107,108,101,116,116,101,114,32,99,97,112,105,116,97,108,32,73,32,61,32,105,109,97,103,105,110,97,114,121,32,112,97,114,116,44,32,85,43,50,49,49,49,32,73,83,79,97,109,115,111,0,0,119,101,105,101,114,112,0,0,115,99,114,105,112,116,32,99,97,112,105,116,97,108,32,80,32,61,32,112,111,119,101,114,32,115,101,116,32,61,32,87,101,105,101,114,115,116,114,97,115,115,32,112,44,32,85,43,50,49,49,56,32,73,83,79,97,109,115,111,0,0,0,0,114,101,97,108,0,0,0,0,98,108,97,99,107,108,101,116,116,101,114,32,99,97,112,105,116,97,108,32,82,32,61,32,114,101,97,108,32,112,97,114,116,32,115,121,109,98,111,108,44,32,85,43,50,49,49,67,32,73,83,79,97,109,115,111,0,0,0,0,0,0,0,0,116,114,97,100,101,0,0,0,116,114,97,100,101,32,109,97,114,107,32,115,105,103,110,44,32,85,43,50,49,50,50,32,73,83,79,110,117,109,0,0,97,108,101,102,115,121,109,0,97,108,101,102,32,115,121,109,98,111,108,32,61,32,102,105,114,115,116,32,116,114,97,110,115,102,105,110,105,116,101,32,99,97,114,100,105,110,97,108,44,32,85,43,50,49,51,53,32,78,69,87,0,0,0,0,108,97,114,114,0,0,0,0,108,101,102,116,119,97,114,100,115,32,97,114,114,111,119,44,32,85,43,50,49,57,48,32,73,83,79,110,117,109,0,0,117,97,114,114,0,0,0,0,117,112,119,97,114,100,115,32,97,114,114,111,119,44,32,85,43,50,49,57,49,32,73,83,79,110,117,109,0,0,0,0,114,97,114,114,0,0,0,0,114,105,103,104,116,119,97,114,100,115,32,97,114,114,111,119,44,32,85,43,50,49,57,50,32,73,83,79,110,117,109,0,100,97,114,114,0,0,0,0,100,111,119,110,119,97,114,100,115,32,97,114,114,111,119,44,32,85,43,50,49,57,51,32,73,83,79,110,117,109,0,0,104,97,114,114,0,0,0,0,108,101,102,116,32,114,105,103,104,116,32,97,114,114,111,119,44,32,85,43,50,49,57,52,32,73,83,79,97,109,115,97,0,0,0,0,0,0,0,0,99,114,97,114,114,0,0,0,100,111,119,110,119,97,114,100,115,32,97,114,114,111,119,32,119,105,116,104,32,99,111,114,110,101,114,32,108,101,102,116,119,97,114,100,115,32,61,32,99,97,114,114,105,97,103,101,32,114,101,116,117,114,110,44,32,85,43,50,49,66,53,32,78,69,87,0,0,0,0,0,108,65,114,114,0,0,0,0,108,101,102,116,119,97,114,100,115,32,100,111,117,98,108,101,32,97,114,114,111,119,44,32,85,43,50,49,68,48,32,73,83,79,116,101,99,104,0,0,117,65,114,114,0,0,0,0,117,112,119,97,114,100,115,32,100,111,117,98,108,101,32,97,114,114,111,119,44,32,85,43,50,49,68,49,32,73,83,79,97,109,115,97,0,0,0,0,114,65,114,114,0,0,0,0,114,105,103,104,116,119,97,114,100,115,32,100,111,117,98,108,101,32,97,114,114,111,119,44,32,85,43,50,49,68,50,32,73,83,79,116,101,99,104,0,100,65,114,114,0,0,0,0,100,111,119,110,119,97,114,100,115,32,100,111,117,98,108,101,32,97,114,114,111,119,44,32,85,43,50,49,68,51,32,73,83,79,97,109,115,97,0,0,104,65,114,114,0,0,0,0,108,101,102,116,32,114,105,103,104,116,32,100,111,117,98,108,101,32,97,114,114,111,119,44,32,85,43,50,49,68,52,32,73,83,79,97,109,115,97,0,102,111,114,97,108,108,0,0,102,111,114,32,97,108,108,44,32,85,43,50,50,48,48,32,73,83,79,116,101,99,104,0,112,97,114,116,0,0,0,0,112,97,114,116,105,97,108,32,100,105,102,102,101,114,101,110,116,105,97,108,44,32,85,43,50,50,48,50,32,73,83,79,116,101,99,104,0,0,0,0,101,120,105,115,116,0,0,0,116,104,101,114,101,32,101,120,105,115,116,115,44,32,85,43,50,50,48,51,32,73,83,79,116,101,99,104,0,0,0,0,101,109,112,116,121,0,0,0,101,109,112,116,121,32,115,101,116,32,61,32,110,117,108,108,32,115,101,116,32,61,32,100,105,97,109,101,116,101,114,44,32,85,43,50,50,48,53,32,73,83,79,97,109,115,111,0,110,97,98,108,97,0,0,0,110,97,98,108,97,32,61,32,98,97,99,107,119,97,114,100,32,100,105,102,102,101,114,101,110,99,101,44,32,85,43,50,50,48,55,32,73,83,79,116,101,99,104,0,0,0,0,0,105,115,105,110,0,0,0,0,101,108,101,109,101,110,116,32,111,102,44,32,85,43,50,50,48,56,32,73,83,79,116,101,99,104,0,0,0,0,0,0,110,111,116,105,110,0,0,0,110,111,116,32,97,110,32,101,108,101,109,101,110,116,32,111,102,44,32,85,43,50,50,48,57,32,73,83,79,116,101,99,104,0,0,0,0,0,0,0,110,105,0,0,0,0,0,0,99,111,110,116,97,105,110,115,32,97,115,32,109,101,109,98,101,114,44,32,85,43,50,50,48,66,32,73,83,79,116,101,99,104,0,0,0,0,0,0,112,114,111,100,0,0,0,0,110,45,97,114,121,32,112,114,111,100,117,99,116,32,61,32,112,114,111,100,117,99,116,32,115,105,103,110,44,32,85,43,50,50,48,70,32,73,83,79,97,109,115,98,0,0,0,0,115,117,109,0,0,0,0,0,110,45,97,114,121,32,115,117,109,109,97,116,105,111,110,44,32,85,43,50,50,49,49,32,73,83,79,97,109,115,98,0,109,105,110,117,115,0,0,0,109,105,110,117,115,32,115,105,103,110,44,32,85,43,50,50,49,50,32,73,83,79,116,101,99,104,0,0,0,0,0,0,108,111,119,97,115,116,0,0,97,115,116,101,114,105,115,107,32,111,112,101,114,97,116,111,114,44,32,85,43,50,50,49,55,32,73,83,79,116,101,99,104,0,0,0,0,0,0,0,114,97,100,105,99,0,0,0,115,113,117,97,114,101,32,114,111,111,116,32,61,32,114,97,100,105,99,97,108,32,115,105,103,110,44,32,85,43,50,50,49,65,32,73,83,79,116,101,99,104,0,0,0,0,0,0,112,114,111,112,0,0,0,0,112,114,111,112,111,114,116,105,111,110,97,108,32,116,111,44,32,85,43,50,50,49,68,32,73,83,79,116,101,99,104,0,105,110,102,105,110,0,0,0,105,110,102,105,110,105,116,121,44,32,85,43,50,50,49,69,32,73,83,79,116,101,99,104,0,0,0,0,0,0,0,0,97,110,103,0,0,0,0,0,97,110,103,108,101,44,32,85,43,50,50,50,48,32,73,83,79,97,109,115,111,0,0,0,97,110,100,0,0,0,0,0,108,111,103,105,99,97,108,32,97,110,100,32,61,32,119,101,100,103,101,44,32,85,43,50,50,50,55,32,73,83,79,116,101,99,104,0,0,0,0,0,111,114,0,0,0,0,0,0,108,111,103,105,99,97,108,32,111,114,32,61,32,118,101,101,44,32,85,43,50,50,50,56,32,73,83,79,116,101,99,104,0,0,0,0,0,0,0,0,99,97,112,0,0,0,0,0,105,110,116,101,114,115,101,99,116,105,111,110,32,61,32,99,97,112,44,32,85,43,50,50,50,57,32,73,83,79,116,101,99,104,0,0,0,0,0,0,99,117,112,0,0,0,0,0,117,110,105,111,110,32,61,32,99,117,112,44,32,85,43,50,50,50,65,32,73,83,79,116,101,99,104,0,0,0,0,0,105,110,116,0,0,0,0,0,105,110,116,101,103,114,97,108,44,32,85,43,50,50,50,66,32,73,83,79,116,101,99,104,0,0,0,0,0,0,0,0,116,104,101,114,101,52,0,0,116,104,101,114,101,102,111,114,101,44,32,85,43,50,50,51,52,32,73,83,79,116,101,99,104,0,0,0,0,0,0,0,115,105,109,0,0,0,0,0,116,105,108,100,101,32,111,112,101,114,97,116,111,114,32,61,32,118,97,114,105,101,115,32,119,105,116,104,32,61,32,115,105,109,105,108,97,114,32,116,111,44,32,85,43,50,50,51,67,32,73,83,79,116,101,99,104,0,0,0,0,0,0,0,99,111,110,103,0,0,0,0,97,112,112,114,111,120,105,109,97,116,101,108,121,32,101,113,117,97,108,32,116,111,44,32,85,43,50,50,52,53,32,73,83,79,116,101,99,104,0,0,97,115,121,109,112,0,0,0,97,108,109,111,115,116,32,101,113,117,97,108,32,116,111,32,61,32,97,115,121,109,112,116,111,116,105,99,32,116,111,44,32,85,43,50,50,52,56,32,73,83,79,97,109,115,114,0,110,101,0,0,0,0,0,0,110,111,116,32,101,113,117,97,108,32,116,111,44,32,85,43,50,50,54,48,32,73,83,79,116,101,99,104,0,0,0,0,101,113,117,105,118,0,0,0,105,100,101,110,116,105,99,97,108,32,116,111,44,32,85,43,50,50,54,49,32,73,83,79,116,101,99,104,0,0,0,0,108,101,0,0,0,0,0,0,108,101,115,115,45,116,104,97,110,32,111,114,32,101,113,117,97,108,32,116,111,44,32,85,43,50,50,54,52,32,73,83,79,116,101,99,104,0,0,0,103,101,0,0,0,0,0,0,103,114,101,97,116,101,114,45,116,104,97,110,32,111,114,32,101,113,117,97,108,32,116,111,44,32,85,43,50,50,54,53,32,73,83,79,116,101,99,104,0,0,0,0,0,0,0,0,115,117,98,0,0,0,0,0,115,117,98,115,101,116,32,111,102,44,32,85,43,50,50,56,50,32,73,83,79,116,101,99,104,0,0,0,0,0,0,0,115,117,112,0,0,0,0,0,115,117,112,101,114,115,101,116,32,111,102,44,32,85,43,50,50,56,51,32,73,83,79,116,101,99,104,0,0,0,0,0,110,115,117,98,0,0,0,0,110,111,116,32,97,32,115,117,98,115,101,116,32,111,102,44,32,85,43,50,50,56,52,32,73,83,79,97,109,115,110,0,115,117,98,101,0,0,0,0,115,117,98,115,101,116,32,111,102,32,111,114,32,101,113,117,97,108,32,116,111,44,32,85,43,50,50,56,54,32,73,83,79,116,101,99,104,0,0,0,115,117,112,101,0,0,0,0,115,117,112,101,114,115,101,116,32,111,102,32,111,114,32,101,113,117,97,108,32,116,111,44,32,85,43,50,50,56,55,32,73,83,79,116,101,99,104,0,111,112,108,117,115,0,0,0,99,105,114,99,108,101,100,32,112,108,117,115,32,61,32,100,105,114,101,99,116,32,115,117,109,44,32,85,43,50,50,57,53,32,73,83,79,97,109,115,98,0,0,0,0,0,0,0,111,116,105,109,101,115,0,0,99,105,114,99,108,101,100,32,116,105,109,101,115,32,61,32,118,101,99,116,111,114,32,112,114,111,100,117,99,116,44,32,85,43,50,50,57,55,32,73,83,79,97,109,115,98,0,0,112,101,114,112,0,0,0,0,117,112,32,116,97,99,107,32,61,32,111,114,116,104,111,103,111,110,97,108,32,116,111,32,61,32,112,101,114,112,101,110,100,105,99,117,108,97,114,44,32,85,43,50,50,65,53,32,73,83,79,116,101,99,104,0,115,100,111,116,0,0,0,0,100,111,116,32,111,112,101,114,97,116,111,114,44,32,85,43,50,50,67,53,32,73,83,79,97,109,115,98,0,0,0,0,108,99,101,105,108,0,0,0,108,101,102,116,32,99,101,105,108,105,110,103,32,61,32,97,112,108,32,117,112,115,116,105,108,101,44,32,85,43,50,51,48,56,32,73,83,79,97,109,115,99,0,0,0,0,0,0,114,99,101,105,108,0,0,0,114,105,103,104,116,32,99,101,105,108,105,110,103,44,32,85,43,50,51,48,57,32,73,83,79,97,109,115,99,0,0,0,108,102,108,111,111,114,0,0,108,101,102,116,32,102,108,111,111,114,32,61,32,97,112,108,32,100,111,119,110,115,116,105,108,101,44,32,85,43,50,51,48,65,32,73,83,79,97,109,115,99,0,0,0,0,0,0,114,102,108,111,111,114,0,0,114,105,103,104,116,32,102,108,111,111,114,44,32,85,43,50,51,48,66,32,73,83,79,97,109,115,99,0,0,0,0,0,108,97,110,103,0,0,0,0,108,101,102,116,45,112,111,105,110,116,105,110,103,32,97,110,103,108,101,32,98,114,97,99,107,101,116,32,61,32,98,114,97,44,32,85,43,50,51,50,57,32,73,83,79,116,101,99,104,0,0,0,0,0,0,0,114,97,110,103,0,0,0,0,114,105,103,104,116,45,112,111,105,110,116,105,110,103,32,97,110,103,108,101,32,98,114,97,99,107,101,116,32,61,32,107,101,116,44,32,85,43,50,51,50,65,32,73,83,79,116,101,99,104,0,0,0,0,0,0,108,111,122,0,0,0,0,0,108,111,122,101,110,103,101,44,32,85,43,50,53,67,65,32,73,83,79,112,117,98,0,0,115,112,97,100,101,115,0,0,98,108,97,99,107,32,115,112,97,100,101,32,115,117,105,116,44,32,85,43,50,54,54,48,32,73,83,79,112,117,98,0,99,108,117,98,115,0,0,0,98,108,97,99,107,32,99,108,117,98,32,115,117,105,116,32,61,32,115,104,97,109,114,111,99,107,44,32,85,43,50,54,54,51,32,73,83,79,112,117,98,0,0,0,0,0,0,0,104,101,97,114,116,115,0,0,98,108,97,99,107,32,104,101,97,114,116,32,115,117,105,116,32,61,32,118,97,108,101,110,116,105,110,101,44,32,85,43,50,54,54,53,32,73,83,79,112,117,98,0,0,0,0,0,100,105,97,109,115,0,0,0,98,108,97,99,107,32,100,105,97,109,111,110,100,32,115,117,105,116,44,32,85,43,50,54,54,54,32,73,83,79,112,117,98,0,0,0,0,0,0,0,111,110,99,108,105,99,107,0,111,110,100,98,108,99,108,105,99,107,0,0,0,0,0,0,111,110,109,111,117,115,101,100,111,119,110,0,0,0,0,0,111,110,109,111,117,115,101,117,112,0,0,0,0,0,0,0,111,110,109,111,117,115,101,111,118,101,114,0,0,0,0,0,111,110,109,111,117,115,101,111,117,116,0,0,0,0,0,0,111,110,107,101,121,112,114,101,115,115,0,0,0,0,0,0,111,110,107,101,121,100,111,119,110,0,0,0,0,0,0,0,111,110,107,101,121,117,112,0,111,110,108,111,97,100,0,0,111,110,117,110,108,111,97,100,0,0,0,0,0,0,0,0,111,110,102,111,99,117,115,0,111,110,98,108,117,114,0,0,111,110,115,117,98,109,105,116,0,0,0,0,0,0,0,0,111,110,114,101,115,101,116,0,111,110,99,104,97,110,103,101,0,0,0,0,0,0,0,0,111,110,115,101,108,101,99,116,0,0,0,0,0,0,0,0,97,110,99,104,111,114,32,0,144,122,1,0,0,122,1,0,72,121,1,0,152,122,1,0,96,122,1,0,128,122,1,0,88,121,1,0,112,122,1,0,184,121,1,0,136,122,1,0,168,121,1,0,144,121,1,0,104,122,1,0,24,122,1,0,160,122,1,0,136,121,1,0,40,121,1,0,48,121,1,0,32,121,1,0,112,198,1,0,64,121,1,0,48,193,1,0,72,122,1,0,192,121,1,0,64,186,1,0,168,189,1,0,16,115,1,0,96,201,1,0,88,122,1,0,104,177,1,0,144,177,1,0,120,122,1,0,80,121,1,0,8,122,1,0,240,198,1,0,0,208,1,0,200,210,1,0,32,122,1,0,112,121,1,0,0,0,0,0,152,212,1,0,160,212,1,0,24,115,1,0,216,119,1,0,216,179,1,0,216,191,1,0,64,181,1,0,72,181,1,0,88,181,1,0,104,181,1,0,120,181,1,0,136,181,1,0,152,181,1,0,168,181,1,0,184,181,1,0,96,114,1,0,112,212,1,0,168,212,1,0,128,214,1,0,136,214,1,0,152,214,1,0,160,214,1,0,224,212,1,0,8,216,1,0,16,216,1,0,208,212,1,0,216,181,1,0,224,181,1,0,0,0,0,0,0,0,0,0,32,216,1,0,0,0,0,0,97,98,98,114,101,118,105,97,116,101,100,32,102,111,114,109,0,0,0,0,0,0,0,0,152,212,1,0,160,212,1,0,24,115,1,0,216,119,1,0,216,179,1,0,216,191,1,0,64,181,1,0,72,181,1,0,88,181,1,0,104,181,1,0,120,181,1,0,136,181,1,0,152,181,1,0,168,181,1,0,184,181,1,0,0,0,0,0,0,0,0,0,0,0,0,0,105,110,102,111,114,109,97,116,105,111,110,32,111,110,32,97,117,116,104,111,114,32,0,0,144,122,1,0,0,122,1,0,72,121,1,0,152,122,1,0,96,122,1,0,128,122,1,0,88,121,1,0,112,122,1,0,184,121,1,0,136,122,1,0,168,121,1,0,144,121,1,0,104,122,1,0,24,122,1,0,160,122,1,0,136,121,1,0,40,121,1,0,48,121,1,0,32,121,1,0,112,198,1,0,64,121,1,0,48,193,1,0,72,122,1,0,192,121,1,0,64,186,1,0,168,189,1,0,16,115,1,0,96,201,1,0,88,122,1,0,104,177,1,0,144,177,1,0,120,122,1,0,80,121,1,0,8,122,1,0,240,198,1,0,0,208,1,0,200,210,1,0,32,122,1,0,112,121,1,0,176,119,1,0,0,0,0,0,0,0,0,0,106,97,118,97,32,97,112,112,108,101,116,32,0,0,0,0,208,121,1,0,216,121,1,0,224,121,1,0,232,121,1,0,240,121,1,0,248,121,1,0,24,212,1,0,112,205,1,0,216,191,1,0,240,201,1,0,80,122,1,0,176,119,1,0,208,192,1,0,96,118,1,0,128,121,1,0,56,122,1,0,232,119,1,0,96,121,1,0,200,121,1,0,168,199,1,0,136,197,1,0,152,118,1,0,184,193,1,0,56,121,1,0,144,122,1,0,0,122,1,0,72,121,1,0,152,122,1,0,96,122,1,0,128,122,1,0,88,121,1,0,112,122,1,0,184,121,1,0,136,122,1,0,168,121,1,0,144,121,1,0,104,122,1,0,24,122,1,0,160,122,1,0,136,121,1,0,40,121,1,0,48,121,1,0,32,121,1,0,112,198,1,0,64,121,1,0,48,193,1,0,72,122,1,0,192,121,1,0,64,186,1,0,168,189,1,0,16,115,1,0,96,201,1,0,88,122,1,0,104,177,1,0,144,177,1,0,120,122,1,0,80,121,1,0,8,122,1,0,240,198,1,0,0,208,1,0,200,210,1,0,32,122,1,0,112,121,1,0,160,206,1,0,0,0,0,0,0,0,0,0,152,212,1,0,160,212,1,0,24,115,1,0,216,119,1,0,56,214,1,0,96,214,1,0,200,214,1,0,168,212,1,0,0,213,1,0,248,212,1,0,48,213,1,0,24,214,1,0,32,214,1,0,0,0,0,0,97,114,101,97,0,0,0,0,99,108,105,101,110,116,45,115,105,100,101,32,105,109,97,103,101,32,109,97,112,32,97,114,101,97,32,0,0,0,0,0,8,216,1,0,16,216,1,0,128,214,1,0,24,216,1,0,208,212,1,0,224,212,1,0,216,181,1,0,224,181,1,0,0,0,0,0,0,0,0,0,200,214,1,0,0,0,0,0,98,111,108,100,32,116,101,120,116,32,115,116,121,108,101,0,100,111,99,117,109,101,110,116,32,98,97,115,101,32,117,114,105,32,0,0,0,0,0,0,128,214,1,0,0,0,0,0,98,97,115,101,102,111,110,116,0,0,0,0,0,0,0,0,98,97,115,101,32,102,111,110,116,32,115,105,122,101,32,0,152,212,1,0,160,213,1,0,128,215,1,0,136,215,1,0,0,0,0,0,0,0,0,0,105,49,56,110,32,98,105,100,105,32,111,118,101,114,45,114,105,100,101,32,0,0,0,0,152,212,1,0,160,212,1,0,24,115,1,0,216,119,1,0,216,179,1,0,216,191,1,0,0,0,0,0,0,0,0,0,216,191,1,0,0,0,0,0,108,97,114,103,101,32,116,101,120,116,32,115,116,121,108,101,0,0,0,0,0,0,0,0,108,111,110,103,32,113,117,111,116,97,116,105,111,110,32,0,208,121,1,0,216,121,1,0,224,121,1,0,232,121,1,0,240,121,1,0,248,121,1,0,24,212,1,0,112,205,1,0,216,191,1,0,240,201,1,0,80,122,1,0,176,119,1,0,208,192,1,0,96,118,1,0,128,121,1,0,56,122,1,0,232,119,1,0,96,121,1,0,200,121,1,0,168,199,1,0,136,197,1,0,152,118,1,0,184,193,1,0,56,121,1,0,144,122,1,0,0,122,1,0,72,121,1,0,152,122,1,0,96,122,1,0,128,122,1,0,88,121,1,0,112,122,1,0,184,121,1,0,136,122,1,0,168,121,1,0,144,121,1,0,104,122,1,0,24,122,1,0,160,122,1,0,136,121,1,0,40,121,1,0,48,121,1,0,32,121,1,0,112,198,1,0,64,121,1,0,48,193,1,0,72,122,1,0,192,121,1,0,64,186,1,0,168,189,1,0,16,115,1,0,96,201,1,0,88,122,1,0,104,177,1,0,144,177,1,0,120,122,1,0,80,121,1,0,8,122,1,0,240,198,1,0,0,208,1,0,200,210,1,0,32,122,1,0,112,121,1,0,0,0,0,0,152,212,1,0,160,212,1,0,24,115,1,0,216,119,1,0,216,179,1,0,216,191,1,0,64,181,1,0,72,181,1,0,88,181,1,0,104,181,1,0,120,181,1,0,136,181,1,0,152,181,1,0,168,181,1,0,184,181,1,0,136,121,1,0,0,0,0,0,0,0,0,0,100,111,99,117,109,101,110,116,32,98,111,100,121,32,0,0,208,121,1,0,216,121,1,0,224,121,1,0,232,121,1,0,240,121,1,0,248,121,1,0,24,212,1,0,112,205,1,0,216,191,1,0,240,201,1,0,80,122,1,0,176,119,1,0,208,192,1,0,96,118,1,0,128,121,1,0,56,122,1,0,232,119,1,0,96,121,1,0,200,121,1,0,168,199,1,0,136,197,1,0,152,118,1,0,184,193,1,0,56,121,1,0,144,122,1,0,0,122,1,0,72,121,1,0,152,122,1,0,96,122,1,0,128,122,1,0,88,121,1,0,112,122,1,0,184,121,1,0,136,122,1,0,168,121,1,0,144,121,1,0,104,122,1,0,24,122,1,0,160,122,1,0,136,121,1,0,40,121,1,0,48,121,1,0,32,121,1,0,112,198,1,0,64,121,1,0,48,193,1,0,72,122,1,0,192,121,1,0,64,186,1,0,168,189,1,0,16,115,1,0,96,201,1,0,88,122,1,0,104,177,1,0,144,177,1,0,120,122,1,0,80,121,1,0,8,122,1,0,240,198,1,0,0,208,1,0,200,210,1,0,32,122,1,0,112,121,1,0,16,122,1,0,160,121,1,0,0,0,0,0,152,212,1,0,160,212,1,0,24,115,1,0,216,119,1,0,216,179,1,0,216,191,1,0,64,181,1,0,72,181,1,0,88,181,1,0,104,181,1,0,120,181,1,0,136,181,1,0,152,181,1,0,168,181,1,0,184,181,1,0,192,181,1,0,200,181,1,0,0,0,0,0,224,215,1,0,128,212,1,0,240,215,1,0,208,119,1,0,248,215,1,0,0,216,1,0,0,0,0,0,0,0,0,0,98,114,0,0,0,0,0,0,102,111,114,99,101,100,32,108,105,110,101,32,98,114,101,97,107,32,0,0,0,0,0,0,152,212,1,0,160,212,1,0,24,115,1,0,216,119,1,0,0,0,0,0,0,0,0,0,216,215,1,0,0,0,0,0,112,117,115,104,32,98,117,116,116,111,110,32,0,0,0,0,152,212,1,0,160,212,1,0,24,115,1,0,216,119,1,0,216,179,1,0,216,191,1,0,64,181,1,0,72,181,1,0,88,181,1,0,104,181,1,0,120,181,1,0,136,181,1,0,152,181,1,0,168,181,1,0,184,181,1,0,168,212,1,0,232,213,1,0,112,212,1,0,176,212,1,0,208,212,1,0,224,212,1,0,216,181,1,0,224,181,1,0,0,0,0,0,116,97,98,108,101,32,99,97,112,116,105,111,110,32,0,0,115,104,111,114,116,104,97,110,100,32,102,111,114,32,100,105,118,32,97,108,105,103,110,61,99,101,110,116,101,114,32,0,99,105,116,97,116,105,111,110,0,0,0,0,0,0,0,0,99,111,109,112,117,116,101,114,32,99,111,100,101,32,102,114,97,103,109,101,110,116,0,0,99,111,108,0,0,0,0,0,116,97,98,108,101,32,99,111,108,117,109,110,32,0,0,0,152,212,1,0,160,212,1,0,24,115,1,0,216,119,1,0,216,179,1,0,216,191,1,0,64,181,1,0,72,181,1,0,88,181,1,0,104,181,1,0,120,181,1,0,136,181,1,0,152,181,1,0,168,181,1,0,184,181,1,0,120,122,1,0,248,212,1,0,48,213,1,0,56,213,1,0,64,213,1,0,72,213,1,0,0,0,0,0,99,111,108,103,114,111,117,112,0,0,0,0,0,0,0,0,116,97,98,108,101,32,99,111,108,117,109,110,32,103,114,111,117,112,32,0,0,0,0,0,176,190,1,0,0,0,0,0,100,101,102,105,110,105,116,105,111,110,32,100,101,115,99,114,105,112,116,105,111,110,32,0,100,101,108,101,116,101,100,32,116,101,120,116,32,0,0,0,152,212,1,0,160,212,1,0,24,115,1,0,216,119,1,0,216,179,1,0,216,191,1,0,64,181,1,0,72,181,1,0,88,181,1,0,104,181,1,0,120,181,1,0,136,181,1,0,152,181,1,0,168,181,1,0,184,181,1,0,200,215,1,0,136,121,1,0,0,0,0,0,105,110,115,116,97,110,99,101,32,100,101,102,105,110,105,116,105,111,110,0,0,0,0,0,100,105,114,0,0,0,0,0,100,105,114,101,99,116,111,114,121,32,108,105,115,116,0,0,208,121,1,0,216,121,1,0,224,121,1,0,232,121,1,0,240,121,1,0,248,121,1,0,24,212,1,0,112,205,1,0,216,191,1,0,240,201,1,0,80,122,1,0,176,119,1,0,208,192,1,0,96,118,1,0,128,121,1,0,56,122,1,0,232,119,1,0,96,121,1,0,200,121,1,0,168,199,1,0,136,197,1,0,152,118,1,0,184,193,1,0,56,121,1,0,48,122,1,0,0,0,0,0,152,212,1,0,160,212,1,0,24,115,1,0,216,119,1,0,216,179,1,0,216,191,1,0,64,181,1,0,72,181,1,0,88,181,1,0,104,181,1,0,120,181,1,0,136,181,1,0,152,181,1,0,168,181,1,0,184,181,1,0,120,212,1,0,0,0,0,0,0,0,0,0,103,101,110,101,114,105,99,32,108,97,110,103,117,97,103,101,47,115,116,121,108,101,32,99,111,110,116,97,105,110,101,114,0,0,0,0,0,0,0,0,48,213,1,0,0,0,0,0,100,108,0,0,0,0,0,0,100,101,102,105,110,105,116,105,111,110,32,108,105,115,116,32,0,0,0,0,0,0,0,0,176,121,1,0,152,121,1,0,0,0,0,0,0,0,0,0,120,212,1,0,0,0,0,0,100,101,102,105,110,105,116,105,111,110,32,116,101,114,109,32,0,0,0,0,0,0,0,0,101,109,112,104,97,115,105,115,0,0,0,0,0,0,0,0,101,109,98,101,100,0,0,0,103,101,110,101,114,105,99,32,101,109,98,101,100,100,101,100,32,111,98,106,101,99,116,32,0,0,0,0,0,0,0,0,152,212,1,0,160,212,1,0,24,115,1,0,216,119,1,0,48,213,1,0,200,214,1,0,88,213,1,0,144,121,1,0,56,214,1,0,240,214,1,0,0,213,1,0,144,215,1,0,24,214,1,0,168,212,1,0,152,215,1,0,160,215,1,0,176,215,1,0,200,213,1,0,112,212,1,0,192,215,1,0,32,214,1,0,248,212,1,0,0,0,0,0,0,0,0,0,102,105,101,108,100,115,101,116,0,0,0,0,0,0,0,0,102,111,114,109,32,99,111,110,116,114,111,108,32,103,114,111,117,112,32,0,0,0,0,0,208,121,1,0,216,121,1,0,224,121,1,0,232,121,1,0,240,121,1,0,248,121,1,0,24,212,1,0,112,205,1,0,216,191,1,0,240,201,1,0,80,122,1,0,176,119,1,0,208,192,1,0,96,118,1,0,128,121,1,0,56,122,1,0,232,119,1,0,96,121,1,0,200,121,1,0,168,199,1,0,136,197,1,0,152,118,1,0,184,193,1,0,56,121,1,0,144,122,1,0,0,122,1,0,72,121,1,0,152,122,1,0,96,122,1,0,128,122,1,0,88,121,1,0,112,122,1,0,184,121,1,0,136,122,1,0,168,121,1,0,144,121,1,0,104,122,1,0,24,122,1,0,160,122,1,0,136,121,1,0,40,121,1,0,48,121,1,0,32,121,1,0,112,198,1,0,64,121,1,0,48,193,1,0,72,122,1,0,192,121,1,0,64,186,1,0,168,189,1,0,16,115,1,0,96,201,1,0,88,122,1,0,104,177,1,0,144,177,1,0,120,122,1,0,80,121,1,0,8,122,1,0,240,198,1,0,0,208,1,0,200,210,1,0,32,122,1,0,112,121,1,0,40,122,1,0,108,111,99,97,108,32,99,104,97,110,103,101,32,116,111,32,102,111,110,116,32,0,0,0,152,212,1,0,160,212,1,0,24,115,1,0,216,119,1,0,216,179,1,0,216,191,1,0,160,213,1,0,128,215,1,0,136,215,1,0,0,0,0,0,105,110,116,101,114,97,99,116,105,118,101,32,102,111,114,109,32,0,0,0,0,0,0,0,208,121,1,0,216,121,1,0,224,121,1,0,232,121,1,0,240,121,1,0,248,121,1,0,24,212,1,0,112,205,1,0,216,191,1,0,240,201,1,0,144,122,1,0,0,122,1,0,72,121,1,0,152,122,1,0,96,122,1,0,128,122,1],"i8",ALLOC_NONE,Runtime.GLOBAL_BASE+105328),
	allocate([88,121,1,0,112,122,1,0,184,121,1,0,136,122,1,0,168,121,1,0,144,121,1,0,104,122,1,0,24,122,1,0,160,122,1,0,136,121,1,0,40,121,1,0,48,121,1,0,32,121,1,0,112,198,1,0,64,121,1,0,48,193,1,0,72,122,1,0,192,121,1,0,64,186,1,0,168,189,1,0,16,115,1,0,96,201,1,0,88,122,1,0,104,177,1,0,144,177,1,0,120,122,1,0,80,121,1,0,8,122,1,0,240,198,1,0,0,208,1,0,200,210,1,0,32,122,1,0,112,121,1,0,80,122,1,0,176,119,1,0,96,118,1,0,128,121,1,0,56,122,1,0,232,119,1,0,96,121,1,0,168,199,1,0,136,197,1,0,152,118,1,0,184,193,1,0,56,121,1,0,0,0,0,0,152,212,1,0,160,212,1,0,24,115,1,0,216,119,1,0,216,179,1,0,216,191,1,0,64,181,1,0,72,181,1,0,88,181,1,0,104,181,1,0,120,181,1,0,136,181,1,0,152,181,1,0,168,181,1,0,184,181,1,0,96,215,1,0,104,215,1,0,216,214,1,0,168,212,1,0,232,181,1,0,248,181,1,0,112,215,1,0,0,0,0,0,0,0,0,0,88,215,1,0,0,0,0,0,115,117,98,119,105,110,100,111,119,32,0,0,0,0,0,0,152,212,1,0,160,212,1,0,24,115,1,0,216,119,1,0,224,214,1,0,168,212,1,0,200,213,1,0,240,214,1,0,0,215,1,0,16,215,1,0,72,215,1,0,32,215,1,0,0,0,0,0,0,0,0,0,119,105,110,100,111,119,32,115,117,98,100,105,118,105,115,105,111,110,0,0,0,0,0,0,0,120,1,0,248,119,1,0,232,119,1,0,0,0,0,0,152,212,1,0,160,212,1,0,24,115,1,0,216,119,1,0,136,212,1,0,144,212,1,0,192,181,1,0,200,181,1,0,0,0,0,0,0,0,0,0,104,101,97,100,105,110,103,32,0,0,0,0,0,0,0,0,100,111,99,117,109,101,110,116,32,104,101,97,100,32,0,0,216,119,1,0,168,199,1,0,224,119,1,0,16,115,1,0,24,115,1,0,200,119,1,0,208,119,1,0,72,122,1,0,0,0,0,0,0,0,0,0,216,179,1,0,216,191,1,0,64,215,1,0,0,0,0,0,104,114,0,0,0,0,0,0,104,111,114,105,122,111,110,116,97,108,32,114,117,108,101,32,0,0,0,0,0,0,0,0,48,213,1,0,56,215,1,0,160,213,1,0,248,212,1,0,0,0,0,0,0,0,0,0,100,111,99,117,109,101,110,116,32,114,111,111,116,32,101,108,101,109,101,110,116,32,0,0,168,117,1,0,160,117,1,0,0,120,1,0,0,0,0,0,216,179,1,0,216,191,1,0,0,0,0,0,0,0,0,0,48,215,1,0,0,0,0,0,105,116,97,108,105,99,32,116,101,120,116,32,115,116,121,108,101,0,0,0,0,0,0,0,105,110,108,105,110,101,32,115,117,98,119,105,110,100,111,119,32,0,0,0,0,0,0,0,152,212,1,0,160,212,1,0,24,115,1,0,216,119,1,0,224,214,1,0,168,212,1,0,200,213,1,0,240,214,1,0,0,215,1,0,16,215,1,0,32,215,1,0,48,213,1,0,0,213,1,0,248,212,1,0,0,0,0,0,0,0,0,0,105,109,103,0,0,0,0,0,101,109,98,101,100,100,101,100,32,105,109,97,103,101,32,0,152,212,1,0,160,212,1,0,24,115,1,0,216,119,1,0,216,179,1,0,216,191,1,0,64,181,1,0,72,181,1,0,88,181,1,0,104,181,1,0,120,181,1,0,136,181,1,0,152,181,1,0,168,181,1,0,184,181,1,0,224,214,1,0,168,212,1,0,0,213,1,0,248,212,1,0,112,214,1,0,208,214,1,0,0,0,0,0,200,213,1,0,200,214,1,0,0,0,0,0,0,0,0,0,105,110,112,117,116,0,0,0,102,111,114,109,32,99,111,110,116,114,111,108,32,0,0,0,152,212,1,0,160,212,1,0,24,115,1,0,216,119,1,0,216,179,1,0,216,191,1,0,64,181,1,0,72,181,1,0,88,181,1,0,104,181,1,0,120,181,1,0,136,181,1,0,152,181,1,0,168,181,1,0,184,181,1,0,112,212,1,0,168,212,1,0,232,213,1,0,176,214,1,0,176,212,1,0,192,212,1,0,160,213,1,0,184,214,1,0,200,213,1,0,200,214,1,0,112,214,1,0,208,214,1,0,208,212,1,0,224,212,1,0,216,181,1,0,224,181,1,0,16,182,1,0,0,182,1,0,216,214,1,0,0,0,0,0,0,0,0,0,105,110,115,101,114,116,101,100,32,116,101,120,116,0,0,0,105,115,105,110,100,101,120,0,115,105,110,103,108,101,32,108,105,110,101,32,112,114,111,109,112,116,32,0,0,0,0,0,152,212,1,0,160,212,1,0,24,115,1,0,216,119,1,0,216,179,1,0,216,191,1,0,168,214,1,0,0,0,0,0,116,101,120,116,32,116,111,32,98,101,32,101,110,116,101,114,101,100,32,98,121,32,116,104,101,32,117,115,101,114,0,0,102,111,114,109,32,102,105,101,108,100,32,108,97,98,101,108,32,116,101,120,116,32,0,0,152,212,1,0,160,212,1,0,24,115,1,0,216,119,1,0,216,179,1,0,216,191,1,0,64,181,1,0,72,181,1,0,88,181,1,0,104,181,1,0,120,181,1,0,136,181,1,0,152,181,1,0,168,181,1,0,184,181,1,0,224,213,1,0,224,212,1,0,216,181,1,0,224,181,1,0,0,0,0,0,102,105,101,108,100,115,101,116,32,108,101,103,101,110,100,32,0,0,0,0,0,0,0,0,152,212,1,0,160,212,1,0,24,115,1,0,216,119,1,0,216,179,1,0,216,191,1,0,64,181,1,0,72,181,1,0,88,181,1,0,104,181,1,0,120,181,1,0,136,181,1,0,152,181,1,0,168,181,1,0,184,181,1,0,224,212,1,0,0,0,0,0,0,0,0,0,108,105,115,116,32,105,116,101,109,32,0,0,0,0,0,0,97,32,109,101,100,105,97,45,105,110,100,101,112,101,110,100,101,110,116,32,108,105,110,107,32,0,0,0,0,0,0,0,152,212,1,0,160,212,1,0,24,115,1,0,216,119,1,0,216,179,1,0,216,191,1,0,64,181,1,0,72,181,1,0,88,181,1,0,104,181,1,0,120,181,1,0,136,181,1,0,152,181,1,0,168,181,1,0,184,181,1,0,96,114,1,0,128,214,1,0,136,214,1,0,112,212,1,0,152,214,1,0,160,214,1,0,152,213,1,0,0,0,0,0,0,0,0,0,109,97,112,0,0,0,0,0,99,108,105,101,110,116,45,115,105,100,101,32,105,109,97,103,101,32,109,97,112,32,0,0,208,121,1,0,216,121,1,0,224,121,1,0,232,121,1,0,240,121,1,0,248,121,1,0,24,212,1,0,112,205,1,0,216,191,1,0,240,201,1,0,80,122,1,0,176,119,1,0,208,192,1,0,96,118,1,0,128,121,1,0,56,122,1,0,232,119,1,0,96,121,1,0,200,121,1,0,168,199,1,0,136,197,1,0,152,118,1,0,184,193,1,0,56,121,1,0,184,185,1,0,0,0,0,0,168,212,1,0,0,0,0,0,109,101,110,117,0,0,0,0,109,101,110,117,32,108,105,115,116,32,0,0,0,0,0,0,103,101,110,101,114,105,99,32,109,101,116,97,105,110,102,111,114,109,97,116,105,111,110,32,0,0,0,0,0,0,0,0,216,179,1,0,216,191,1,0,80,126,1,0,168,212,1,0,120,214,1,0,96,114,1,0,0,0,0,0,0,0,0,0,112,126,1,0,0,0,0,0,97,108,116,101,114,110,97,116,101,32,99,111,110,116,101,110,116,32,99,111,110,116,97,105,110,101,114,32,102,111,114,32,110,111,110,32,102,114,97,109,101,45,98,97,115,101,100,32,114,101,110,100,101,114,105,110,103,32,0,0,0,0,0,0,160,117,1,0,208,121,1,0,216,121,1,0,224,121,1,0,232,121,1,0,240,121,1,0,248,121,1,0,24,212,1,0,112,205,1,0,216,191,1,0,240,201,1,0,80,122,1,0,176,119,1,0,208,192,1,0,96,118,1,0,128,121,1,0,56,122,1,0,232,119,1,0,96,121,1,0,200,121,1,0,168,199,1,0,136,197,1,0,152,118,1,0,184,193,1,0,56,121,1,0,144,122,1,0,0,122,1,0,72,121,1,0,152,122,1,0,96,122,1,0,128,122,1,0,88,121,1,0,112,122,1,0,184,121,1,0,136,122,1,0,168,121,1,0,144,121,1,0,104,122,1,0,24,122,1,0,160,122,1,0,136,121,1,0,40,121,1,0,48,121,1,0,32,121,1,0,112,198,1,0,64,121,1,0,48,193,1,0,72,122,1,0,192,121,1,0,64,186,1,0,168,189,1,0,16,115,1,0,96,201,1,0,88,122,1,0,104,177,1,0,144,177,1,0,120,122,1,0,80,121,1,0,8,122,1,0,240,198,1,0,0,208,1,0,200,210,1,0,32,122,1,0,112,121,1,0,0,0,0,0,0,0,0,0,97,108,116,101,114,110,97,116,101,32,99,111,110,116,101,110,116,32,99,111,110,116,97,105,110,101,114,32,102,111,114,32,110,111,110,32,115,99,114,105,112,116,45,98,97,115,101,100,32,114,101,110,100,101,114,105,110,103,32,0,0,0,0,0,208,121,1,0,216,121,1,0,224,121,1,0,232,121,1,0,240,121,1,0,248,121,1,0,24,212,1,0,112,205,1,0,216,191,1,0,240,201,1,0,80,122,1,0,176,119,1,0,208,192,1,0,96,118,1,0,128,121,1,0,56,122,1,0,232,119,1,0,96,121,1,0,200,121,1,0,168,199,1,0,136,197,1,0,152,118,1,0,184,193,1,0,56,121,1,0,144,122,1,0,0,122,1,0,72,121,1,0,152,122,1,0,96,122,1,0,128,122,1,0,88,121,1,0,112,122,1,0,184,121,1,0,136,122,1,0,168,121,1,0,144,121,1,0,104,122,1,0,24,122,1,0,160,122,1,0,136,121,1,0,40,121,1,0,48,121,1,0,32,121,1,0,112,198,1,0,64,121,1,0,48,193,1,0,72,122,1,0,192,121,1,0,64,186,1,0,168,189,1,0,16,115,1,0,96,201,1,0,88,122,1,0,104,177,1,0,144,177,1,0,120,122,1,0,80,121,1,0,8,122,1,0,240,198,1,0,0,208,1,0,200,210,1,0,32,122,1,0,112,121,1,0,160,206,1,0,0,0,0,0,0,0,0,0,152,212,1,0,160,212,1,0,24,115,1,0,216,119,1,0,216,179,1,0,216,191,1,0,64,181,1,0,72,181,1,0,88,181,1,0,104,181,1,0,120,181,1,0,136,181,1,0,152,181,1,0,168,181,1,0,184,181,1,0,40,214,1,0,48,214,1,0,56,214,1,0,72,214,1,0,112,212,1,0,80,214,1,0,96,214,1,0,104,214,1,0,0,213,1,0,248,212,1,0,112,214,1,0,168,212,1,0,208,212,1,0,0,0,0,0,0,0,0,0,48,213,1,0,88,213,1,0,24,214,1,0,32,214,1,0,0,0,0,0,0,0,0,0,111,108,0,0,0,0,0,0,111,114,100,101,114,101,100,32,108,105,115,116,32,0,0,0,48,122,1,0,0,0,0,0,112,212,1,0,120,212,1,0,16,214,1,0,0,0,0,0,111,112,116,103,114,111,117,112,0,0,0,0,0,0,0,0,111,112,116,105,111,110,32,103,114,111,117,112,32,0,0,0,200,205,1,0,0,0,0,0,111,112,116,105,111,110,0,0,152,212,1,0,160,212,1,0,24,115,1,0,216,119,1,0,216,179,1,0,216,191,1,0,64,181,1,0,72,181,1,0,88,181,1,0,104,181,1,0,120,181,1,0,136,181,1,0,152,181,1,0,168,181,1,0,184,181,1,0,176,212,1,0,0,0,0,0,0,0,0,0,32,122,1,0,0,0,0,0,115,101,108,101,99,116,97,98,108,101,32,99,104,111,105,99,101,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,152,212,1,0,160,212,1,0,24,115,1,0,216,119,1,0,216,179,1,0,216,191,1,0,64,181,1,0,72,181,1,0,88,181,1,0,104,181,1,0,120,181,1,0,136,181,1,0,152,181,1,0,168,181,1,0,184,181,1,0,176,212,1,0,32,122,1,0,0,214,1,0,232,213,1,0,0,0,0,0,112,97,114,97,103,114,97,112,104,32,0,0,0,0,0,0,112,97,114,97,109,0,0,0,110,97,109,101,100,32,112,114,111,112,101,114,116,121,32,118,97,108,117,101,32,0,0,0,152,212,1,0,232,213,1,0,240,213,1,0,112,212,1,0,0,0,0,0,0,0,0,0,112,114,101,102,111,114,109,97,116,116,101,100,32,116,101,120,116,32,0,0,0,0,0,0,184,121,1,0,136,122,1,0,168,121,1,0,144,121,1,0,104,122,1,0,24,122,1,0,160,122,1,0,136,121,1,0,40,121,1,0,48,121,1,0,144,122,1,0,0,122,1,0,72,121,1,0,152,122,1,0,96,122,1,0,128,122,1,0,32,121,1,0,168,189,1,0,16,115,1,0,96,201,1,0,88,122,1,0,120,122,1,0,80,121,1,0,8,122,1,0,0,0,0,0,0,0,0,0,248,212,1,0,0,0,0,0,115,104,111,114,116,32,105,110,108,105,110,101,32,113,117,111,116,97,116,105,111,110,32,0,115,116,114,105,107,101,45,116,104,114,111,117,103,104,32,116,101,120,116,32,115,116,121,108,101,0,0,0,0,0,0,0,115,97,109,112,108,101,32,112,114,111,103,114,97,109,32,111,117,116,112,117,116,44,32,115,99,114,105,112,116,115,44,32,101,116,99,46,0,0,0,0,115,99,114,105,112,116,32,115,116,97,116,101,109,101,110,116,115,32,0,0,0,0,0,0,96,114,1,0,200,213,1,0,208,213,1,0,216,213,1,0,224,213,1,0,0,0,0,0,184,213,1,0,0,0,0,0,112,212,1,0,0,0,0,0,115,101,108,101,99,116,0,0,111,112,116,105,111,110,32,115,101,108,101,99,116,111,114,32,0,0,0,0,0,0,0,0,160,205,1,0,200,205,1,0,0,0,0,0,0,0,0,0,152,212,1,0,160,212,1,0,24,115,1,0,216,119,1,0,216,179,1,0,216,191,1,0,64,181,1,0,72,181,1,0,88,181,1,0,104,181,1,0,120,181,1,0,136,181,1,0,152,181,1,0,168,181,1,0,184,181,1,0,168,212,1,0,160,213,1,0,168,213,1,0,176,212,1,0,208,212,1,0,216,181,1,0,224,181,1,0,0,182,1,0,0,0,0,0,115,109,97,108,108,32,116,101,120,116,32,115,116,121,108,101,0,0,0,0,0,0,0,0,103,101,110,101,114,105,99,32,108,97,110,103,117,97,103,101,47,115,116,121,108,101,32,99,111,110,116,97,105,110,101,114,32,0,0,0,0,0,0,0,115,116,114,105,107,101,45,116,104,114,111,117,103,104,32,116,101,120,116,0,0,0,0,0,115,116,114,111,110,103,32,101,109,112,104,97,115,105,115,0,115,116,121,108,101,32,105,110,102,111,32,0,0,0,0,0,216,179,1,0,216,191,1,0,152,213,1,0,216,119,1,0,0,0,0,0,0,0,0,0,115,117,98,115,99,114,105,112,116,0,0,0,0,0,0,0,115,117,112,101,114,115,99,114,105,112,116,32,0,0,0,0,120,121,1,0,176,190,1,0,32,191,1,0,128,118,1,0,144,118,1,0,136,118,1,0,120,118,1,0,0,0,0,0,152,212,1,0,160,212,1,0,24,115,1,0,216,119,1,0,216,179,1,0,216,191,1,0,64,181,1,0,72,181,1,0,88,181,1,0,104,181,1,0,120,181,1,0,136,181,1,0,152,181,1,0,168,181,1,0,184,181,1,0,80,213,1,0,248,212,1,0,88,213,1,0,248,119,1,0,96,213,1,0,104,213,1,0,120,213,1,0,136,213,1,0,0,0,0,0,48,213,1,0,128,212,1,0,0,0,0,0,0,0,0,0,116,97,98,108,101,32,98,111,100,121,32,0,0,0,0,0,120,118,1,0,0,0,0,0,152,212,1,0,160,212,1,0,24,115,1,0,216,119,1,0,216,179,1,0,216,191,1,0,64,181,1,0,72,181,1,0,88,181,1,0,104,181,1,0,120,181,1,0,136,181,1,0,152,181,1,0,168,181,1,0,184,181,1,0,48,213,1,0,56,213,1,0,64,213,1,0,72,213,1,0,0,0,0,0,116,97,98,108,101,32,100,97,116,97,32,99,101,108,108,0,152,212,1,0,160,212,1,0,24,115,1,0,216,119,1,0,216,179,1,0,216,191,1,0,64,181,1,0,72,181,1,0,88,181,1,0,104,181,1,0,120,181,1,0,136,181,1,0,152,181,1,0,168,181,1,0,184,181,1,0,40,121,1,0,8,213,1,0,16,213,1,0,24,213,1,0,32,213,1,0,40,213,1,0,48,213,1,0,56,213,1,0,64,213,1,0,72,213,1,0,0,0,0,0,240,212,1,0,128,212,1,0,248,212,1,0,0,213,1,0,0,0,0,0,0,0,0,0,116,101,120,116,97,114,101,97,0,0,0,0,0,0,0,0,109,117,108,116,105,45,108,105,110,101,32,116,101,120,116,32,102,105,101,108,100,32,0,0,152,212,1,0,160,212,1,0,24,115,1,0,216,119,1,0,216,179,1,0,216,191,1,0,64,181,1,0,72,181,1,0,88,181,1,0,104,181,1,0,120,181,1,0,136,181,1,0,152,181,1,0,168,181,1,0,184,181,1,0,168,212,1,0,176,212,1,0,192,212,1,0,208,212,1,0,224,212,1,0,216,181,1,0,224,181,1,0,16,182,1,0,0,182,1,0,0,0,0,0,0,0,0,0,136,212,1,0,144,212,1,0,0,0,0,0,0,0,0,0,116,97,98,108,101,32,102,111,111,116,101,114,32,0,0,0,116,97,98,108,101,32,104,101,97,100,101,114,32,99,101,108,108,0,0,0,0,0,0,0,116,97,98,108,101,32,104,101,97,100,101,114,32,0,0,0,100,111,99,117,109,101,110,116,32,116,105,116,108,101,32,0,116,97,98,108,101,32,114,111,119,32,0,0,0,0,0,0,112,118,1,0,104,118,1,0,0,0,0,0,0,0,0,0,128,212,1,0,0,0,0,0,116,101,108,101,116,121,112,101,32,111,114,32,109,111,110,111,115,112,97,99,101,100,32,116,101,120,116,32,115,116,121,108,101,0,0,0,0,0,0,0,117,110,100,101,114,108,105,110,101,100,32,116,101,120,116,32,115,116,121,108,101,0,0,0,117,108,0,0,0,0,0,0,117,110,111,114,100,101,114,101,100,32,108,105,115,116,32,0,112,212,1,0,120,212,1,0,0,0,0,0,0,0,0,0,105,110,115,116,97,110,99,101,32,111,102,32,97,32,118,97,114,105,97,98,108,101,32,111,114,32,112,114,111,103,114,97,109,32,97,114,103,117,109,101,110,116,0,0,0,0,0,0,116,121,112,101,0,0,0,0,99,111,109,112,97,99,116,0,98,103,99,111,108,111,114,0,114,111,119,115,0,0,0,0,99,111,108,115,0,0,0,0,105,100,0,0,0,0,0,0,99,108,97,115,115,0,0,0,110,97,109,101,0,0,0,0,100,105,115,97,98,108,101,100,0,0,0,0,0,0,0,0,114,101,97,100,111,110,108,121,0,0,0,0,0,0,0,0,116,97,98,105,110,100,101,120,0,0,0,0,0,0,0,0,97,99,99,101,115,115,107,101,121,0,0,0,0,0,0,0,110,111,119,114,97,112,0,0,119,105,100,116,104,0,0,0,104,101,105,103,104,116,0,0,97,120,105,115,0,0,0,0,104,101,97,100,101,114,115,0,115,99,111,112,101,0,0,0,114,111,119,115,112,97,110,0,99,111,108,115,112,97,110,0,97,108,105,103,110,0,0,0,99,104,97,114,0,0,0,0,99,104,97,114,111,102,102,0,118,97,108,105,103,110,0,0,115,117,109,109,97,114,121,0,98,111,114,100,101,114,0,0,114,117,108,101,115,0,0,0,99,101,108,108,115,112,97,99,105,110,103,0,0,0,0,0,99,101,108,108,112,97,100,100,105,110,103,0,0,0,0,0,100,97,116,97,112,97,103,101,115,105,122,101,0,0,0,0,109,101,100,105,97,0,0,0,115,105,122,101,0,0,0,0,109,117,108,116,105,112,108,101,0,0,0,0,0,0,0,0,108,97,110,103,117,97,103,101,0,0,0,0,0,0,0,0,115,114,99,0,0,0,0,0,100,101,102,101,114,0,0,0,101,118,101,110,116,0,0,0,102,111,114,0,0,0,0,0,118,97,108,117,101,0,0,0,118,97,108,117,101,116,121,112,101,0,0,0,0,0,0,0,115,101,108,101,99,116,101,100,0,0,0,0,0,0,0,0,115,116,97,114,116,0,0,0,104,115,112,97,99,101,0,0,118,115,112,97,99,101,0,0,100,101,99,108,97,114,101,0,99,108,97,115,115,105,100,0,99,111,100,101,98,97,115,101,0,0,0,0,0,0,0,0,100,97,116,97,0,0,0,0,99,111,100,101,116,121,112,101,0,0,0,0,0,0,0,0,97,114,99,104,105,118,101,0,115,116,97,110,100,98,121,0,117,115,101,109,97,112,0,0,115,99,104,101,109,101,0,0,104,114,101,102,0,0,0,0,104,114,101,102,108,97,110,103,0,0,0,0,0,0,0,0,114,101,108,0,0,0,0,0,114,101,118,0,0,0,0,0,112,114,111,109,112,116,0,0,99,104,101,99,107,101,100,0,109,97,120,108,101,110,103,116,104,0,0,0,0,0,0,0,97,108,116,0,0,0,0,0,105,115,109,97,112,0,0,0,97,99,99,101,112,116,0,0,108,111,110,103,100,101,115,99,0,0,0,0,0,0,0,0,102,114,97,109,101,98,111,114,100,101,114,0,0,0,0,0,109,97,114,103,105,110,119,105,100,116,104,0,0,0,0,0,109,97,114,103,105,110,104,101,105,103,104,116,0,0,0,0,115,99,114,111,108,108,105,110,103,0,0,0,0,0,0,0,118,101,114,115,105,111,110,0,110,111,115,104,97,100,101,0,112,114,111,102,105,108,101,0,110,111,114,101,115,105,122,101,0,0,0,0,0,0,0,0,97,99,116,105,111,110,0,0,109,101,116,104,111,100,0,0,101,110,99,116,121,112,101,0,97,99,99,101,112,116,45,99,104,97,114,115,101,116,0,0,99,111,108,111,114,0,0,0,102,97,99,101,0,0,0,0,104,105,100,100,101,110,0,0,112,97,108,101,116,116,101,0,112,108,117,103,105,110,115,112,97,99,101,0,0,0,0,0,112,108,117,103,105,110,117,114,108,0,0,0,0,0,0,0,117,110,105,116,115,0,0,0,100,97,116,101,116,105,109,101,0,0,0,0,0,0,0,0,99,108,101,97,114,0,0,0,98,97,99,107,103,114,111,117,110,100,0,0,0,0,0,0,116,101,120,116,0,0,0,0,118,108,105,110,107,0,0,0,97,108,105,110,107,0,0,0,115,104,97,112,101,0,0,0,99,111,111,114,100,115,0,0,110,111,104,114,101,102,0,0,116,97,114,103,101,116,0,0,108,105,115,116,105,110,103,0,120,109,112,0,0,0,0,0,104,116,109,108,0,0,0,0,104,101,97,100,0,0,0,0,109,101,116,97,0,0,0,0,104,116,116,112,45,101,113,117,105,118,0,0,0,0,0,0,67,111,110,116,101,110,116,45,84,121,112,101,0,0,0,0,99,111,110,116,101,110,116,0,99,104,97,114,115,101,116,61,0,0,0,0,0,0,0,0,67,104,97,114,115,101,116,61,0,0,0,0,0,0,0,0,67,72,65,82,83,69,84,61,0,0,0,0,0,0,0,0,99,104,97,114,115,101,116,32,61,0,0,0,0,0,0,0,67,104,97,114,115,101,116,32,61,0,0,0,0,0,0,0,67,72,65,82,83,69,84,32,61,0,0,0,0,0,0,0,116,101,120,116,47,104,116,109,108,59,32,99,104,97,114,115,101,116,61,37,115,0,0,0,200,218,1,0,208,218,1,0,216,218,1,0,224,218,1,0,232,218,1,0,248,218,1,0,0,219,1,0,16,219,1,0,24,219,1,0,40,219,1,0,48,219,1,0,56,219,1,0,72,219,1,0,0,0,0,0,72,84,77,76,0,0,0,0,97,115,99,105,105,0,0,0,115,99,114,105,112,116,0,0,115,116,121,108,101,0,0,0,60,33,45,45,0,0,0,0,45,45,62,0,0,0,0,0,60,63,0,0,0,0,0,0,32,0,0,0,0,0,0,0,62,0,0,0,0,0,0,0,38,0,0,0,0,0,0,0,59,0,0,0,0,0,0,0,60,0,0,0,0,0,0,0,58,0,0,0,0,0,0,0,10,0,0,0,0,0,0,0,98,111,100,121,0,0,0,0,62,60,47,0,0,0,0,0,60,47,0,0,0,0,0,0,85,84,70,45,56,0,0,0,60,33,68,79,67,84,89,80,69,32,0,0,0,0,0,0,32,80,85,66,76,73,67,32,0,0,0,0,0,0,0,0,32,83,89,83,84,69,77,32,0,0,0,0,0,0,0,0,62,10,0,0,0,0,0,0,61,0,0,0,0,0,0,0,104,114,101,102,0,0,0,0,97,99,116,105,111,110,0,0,115,114,99,0,0,0,0,0,110,97,109,101,0,0,0,0,97,0,0,0,0,0,0,0,34,0,0,0,0,0,0,0,64,47,58,61,63,59,35,37,38,44,43,0,0,0,0,0,61,34,34,0,0,0,0,0,115,116,114,105,110,103,32,105,115,32,110,111,116,32,105,110,32,85,84,70,45,56,10,0,105,110,118,97,108,105,100,32,99,104,97,114,97,99,116,101,114,32,118,97,108,117,101,10,0,0,0,0,0,0,0,0,117,110,107,110,111,119,110,32,101,110,99,111,100,105,110,103,32,37,115,10,0,0,0,0,72,84,77,76,32,104,97,115,32,110,111,32,68,79,67,84,89,80,69,10,0,0,0,0,117,110,101,120,112,101,99,116,101,100,32,101,114,114,111,114,32,110,117,109,98,101,114,10,0,0,0,0,0,0,0,0,99,104,101,99,107,101,100,0,99,111,109,112,97,99,116,0,100,101,99,108,97,114,101,0,100,101,102,101,114,0,0,0,100,105,115,97,98,108,101,100,0,0,0,0,0,0,0,0,105,115,109,97,112,0,0,0,109,117,108,116,105,112,108,101,0,0,0,0,0,0,0,0,110,111,104,114,101,102,0,0,110,111,114,101,115,105,122,101,0,0,0,0,0,0,0,0,110,111,115,104,97,100,101,0,110,111,119,114,97,112,0,0,114,101,97,100,111,110,108,121,0,0,0,0,0,0,0,0,115,101,108,101,99,116,101,100,0,0,0,0,0,0,0,0,40,78,85,76,76,41,0,0,35,37,88,0,0,0,0,0,46,46,46,0,0,0,0,0,78,85,76,76,10,0,0,0,45,0,0,0,0,0,0,0,97,0,0,0,0,0,0,0,116,0,0,0,0,0,0,0,67,0,0,0,0,0,0,0,101,0,0,0,0,0,0,0,69,0,0,0,0,0,0,0,112,0,0,0,0,0,0,0,99,0,0,0,0,0,0,0,100,0,0,0,0,0,0,0,104,0,0,0,0,0,0,0,84,0,0,0,0,0,0,0,70,0,0,0,0,0,0,0,78,0,0,0,0,0,0,0,110,0,0,0,0,0,0,0,63,0,0,0,0,0,0,0,32,37,56,100,32,0,0,0,37,115,58,0,0,0,0,0,37,115,0,0,0,0,0,0,100,101,102,97,117,108,116,32,45,62,32,37,115,0,0,0,37,115,32,45,62,32,37,115,0,0,0,0,0,0,0,0,10,0,0,0,0,0,0,0,37,115,58,32,110,111,32,115,117,99,104,32,110,111,100,101,10,0,0,0,0,0,0,0,37,115,32,105,115,32,97,32,66,111,111,108,101,97,110,10,0,0,0,0,0,0,0,0,37,115,32,105,115,32,97,32,110,117,109,98,101,114,10,0,37,115,32,105,115,32,97,32,115,116,114,105,110,103,10,0,37,115,32,105,115,32,97,32,112,111,105,110,116,10,0,0,37,115,32,105,115,32,97,32,114,97,110,103,101,10,0,0,37,115,32,105,115,32,117,115,101,114,45,100,101,102,105,110,101,100,10,0,0,0,0,0,37,115,32,105,115,32,97,110,32,88,83,76,84,32,118,97,108,117,101,32,116,114,101,101,10,0,0,0,0,0,0,0,32,78,111,32,98,97,115,101,32,102,111,117,110,100,32,33,33,33,10,0,0,0,0,0,37,115,10,0,0,0,0,0,70,97,105,108,101,100,32,116,111,32,119,114,105,116,101,32,116,111,32,37,115,10,0,0,119,0,0,0,0,0,0,0,70,97,105,108,101,100,32,116,111,32,115,97,118,101,32,116,111,32,37,115,10,0,0,0,84,111,32,115,97,118,101,32,116,111,32,115,117,98,112,97,114,116,115,32,111,102,32,97,32,100,111,99,117,109,101,110,116,32,117,115,101,32,116,104,101,32,39,119,114,105,116,101,39,32,99,111,109,109,97,110,100,10,0,0,0,0,0,0,47,10,0,0,0,0,0,0,32,32,0,0,0,0,0,0,37,115,32,62,32,0,0,0,47,0,0,0,0,0,0,0,37,115,58,37,115,32,62,32,0,0,0,0,0,0,0,0,63,32,62,32,0,0,0,0,101,120,105,116,0,0,0,0,113,117,105,116,0,0,0,0,98,121,101,0,0,0,0,0,104,101,108,112,0,0,0,0,9,98,97,115,101,32,32,32,32,32,32,32,32,32,100,105,115,112,108,97,121,32,88,77,76,32,98,97,115,101,32,111,102,32,116,104,101,32,110,111,100,101,10,0,0,0,0,0,9,115,101,116,98,97,115,101,32,85,82,73,32,32,99,104,97,110,103,101,32,116,104,101,32,88,77,76,32,98,97,115,101,32,111,102,32,116,104,101,32,110,111,100,101,10,0,0,9,98,121,101,32,32,32,32,32,32,32,32,32,32,108,101,97,118,101,32,115,104,101,108,108,10,0,0,0,0,0,0,9,99,97,116,32,91,110,111,100,101,93,32,32,32,100,105,115,112,108,97,121,32,110,111,100,101,32,111,114,32,99,117,114,114,101,110,116,32,110,111,100,101,10,0,0,0,0,0,9,99,100,32,91,112,97,116,104,93,32,32,32,32,99,104,97,110,103,101,32,100,105,114,101,99,116,111,114,121,32,116,111,32,112,97,116,104,32,111,114,32,116,111,32,114,111,111,116,10,0,0,0,0,0,0,9,100,105,114,32,91,112,97,116,104,93,32,32,32,100,117,109,112,115,32,105,110,102,111,114,109,97,116,105,111,110,115,32,97,98,111,117,116,32,116,104,101,32,110,111,100,101,32,40,110,97,109,101,115,112,97,99,101,44,32,97,116,116,114,105,98,117,116,101,115,44,32,99,111,110,116,101,110,116,41,10,0,0,0,0,0,0,0,9,100,117,32,91,112,97,116,104,93,32,32,32,32,115,104,111,119,32,116,104,101,32,115,116,114,117,99,116,117,114,101,32,111,102,32,116,104,101,32,115,117,98,116,114,101,101,32,117,110,100,101,114,32,112,97,116,104,32,111,114,32,116,104,101,32,99,117,114,114,101,110,116,32,110,111,100,101,10,0,9,101,120,105,116,32,32,32,32,32,32,32,32,32,108,101,97,118,101,32,115,104,101,108,108,10,0,0,0,0,0,0,9,104,101,108,112,32,32,32,32,32,32,32,32,32,100,105,115,112,108,97,121,32,116,104,105,115,32,104,101,108,112,10,0,0,0,0,0,0,0,0,9,102,114,101,101,32,32,32,32,32,32,32,32,32,100,105,115,112,108,97,121,32,109,101,109,111,114,121,32,117,115,97,103,101,10,0,0,0,0,0,9,108,111,97,100,32,91,110,97,109,101,93,32,32,108,111,97,100,32,97,32,110,101,119,32,100,111,99,117,109,101,110,116,32,119,105,116,104,32,110,97,109,101,10,0,0,0,0,9,108,115,32,91,112,97,116,104,93,32,32,32,32,108,105,115,116,32,99,111,110,116,101,110,116,115,32,111,102,32,112,97,116,104,32,111,114,32,116,104,101,32,99,117,114,114,101,110,116,32,100,105,114,101,99,116,111,114,121,10,0,0,0,9,115,101,116,32,120,109,108,95,102,114,97,103,109,101,110,116,32,114,101,112,108,97,99,101,32,116,104,101,32,99,117,114,114,101,110,116,32,110,111,100,101,32,99,111,110,116,101,110,116,32,119,105,116,104,32,116,104,101,32,102,114,97,103,109,101,110,116,32,112,97,114,115,101,100,32,105,110,32,99,111,110,116,101,120,116,10,0,9,120,112,97,116,104,32,101,120,112,114,32,32,32,101,118,97,108,117,97,116,101,32,116,104,101,32,88,80,97,116,104,32,101,120,112,114,101,115,115,105,111,110,32,105,110,32,116,104,97,116,32,99,111,110,116,101,120,116,32,97,110,100,32,112,114,105,110,116,32,116,104,101,32,114,101,115,117,108,116,10,0,0,0,0,0,0,0,9,115,101,116,110,115,32,110,115,114,101,103,32,32,114,101,103,105,115,116,101,114,32,97,32,110,97,109,101,115,112,97,99,101,32,116,111,32,97,32,112,114,101,102,105,120,32,105,110,32,116,104,101,32,88,80,97,116,104,32,101,118,97,108,117,97,116,105,111,110,32,99,111,110,116,101,120,116,10,0,9,32,32,32,32,32,32,32,32,32,32,32,32,32,102,111,114,109,97,116,32,102,111,114,32,110,115,114,101,103,32,105,115,58,32,112,114,101,102,105,120,61,91,110,115,117,114,105,93,32,40,105,46,101,46,32,112,114,101,102,105,120,61,32,117,110,115,101,116,115,32,97,32,112,114,101,102,105,120,41,10,0,0,0,0,0,0,0,9,115,101,116,114,111,111,116,110,115,32,32,32,32,114,101,103,105,115,116,101,114,32,97,108,108,32,110,97,109,101,115,112,97,99,101,32,102,111,117,110,100,32,111,110,32,116,104,101,32,114,111,111,116,32,101,108,101,109,101,110,116,10,0,9,32,32,32,32,32,32,32,32,32,32,32,32,32,116,104,101,32,100,101,102,97,117,108,116,32,110,97,109,101,115,112,97,99,101,32,105,102,32,97,110,121,32,117,115,101,115,32,39,100,101,102,97,117,108,116,110,115,39,32,112,114,101,102,105,120,10,0,0,0,0,0,9,112,119,100,32,32,32,32,32,32,32,32,32,32,100,105,115,112,108,97,121,32,99,117,114,114,101,110,116,32,119,111,114,107,105,110,103,32,100,105,114,101,99,116,111,114,121,10,0,0,0,0,0,0,0,0,9,119,104,101,114,101,105,115,32,32,32,32,32,32,100,105,115,112,108,97,121,32,97,98,115,111,108,117,116,101,32,112,97,116,104,32,111,102,32,91,112,97,116,104,93,32,111,114,32,99,117,114,114,101,110,116,32,119,111,114,107,105,110,103,32,100,105,114,101,99,116,111,114,121,10,0,0,0,0,0,9,113,117,105,116,32,32,32,32,32,32,32,32,32,108,101,97,118,101,32,115,104,101,108,108,10,0,0,0,0,0,0,9,115,97,118,101,32,91,110,97,109,101,93,32,32,115,97,118,101,32,116,104,105,115,32,100,111,99,117,109,101,110,116,32,116,111,32,110,97,109,101,32,111,114,32,116,104,101,32,111,114,105,103,105,110,97,108,32,110,97,109,101,10,0,0,9,119,114,105,116,101,32,91,110,97,109,101,93,32,119,114,105,116,101,32,116,104,101,32,99,117,114,114,101,110,116,32,110,111,100,101,32,116,111,32,116,104,101,32,102,105,108,101,110,97,109,101,10,0,0,0,9,118,97,108,105,100,97,116,101,32,32,32,32,32,99,104,101,99,107,32,116,104,101,32,100,111,99,117,109,101,110,116,32,102,111,114,32,101,114,114,111,114,115,10,0,0,0,0,9,114,101,108,97,120,110,103,32,114,110,103,32,32,118,97,108,105,100,97,116,101,32,116,104,101,32,100,111,99,117,109,101,110,116,32,97,103,97,105,115,110,116,32,116,104,101,32,82,101,108,97,120,45,78,71,32,115,99,104,101,109,97,115,10,0,0,0,0,0,0,0,9,103,114,101,112,32,115,116,114,105,110,103,32,32,115,101,97,114,99,104,32,102,111,114,32,97,32,115,116,114,105,110,103,32,105,110,32,116,104,101,32,115,117,98,116,114,101,101,10,0,0,0,0,0,0,0,118,97,108,105,100,97,116,101,0,0,0,0,0,0,0,0,108,111,97,100,0,0,0,0,114,101,108,97,120,110,103,0,115,97,118,101,0,0,0,0,119,114,105,116,101,0,0,0,87,114,105,116,101,32,99,111,109,109,97,110,100,32,114,101,113,117,105,114,101,115,32,97,32,102,105,108,101,110,97,109,101,32,97,114,103,117,109,101,110,116,10,0,0,0,0,0,103,114,101,112,0,0,0,0,102,114,101,101,0,0,0,0,37,100,0,0,0,0,0,0,112,119,100,0,0,0,0,0,100,117,0,0,0,0,0,0,98,97,115,101,0,0,0,0,115,101,116,0,0,0,0,0,115,101,116,110,115,0,0,0,115,101,116,110,115,58,32,112,114,101,102,105,120,61,91,110,115,117,114,105,93,32,114,101,113,117,105,114,101,100,10,0,115,101,116,114,111,111,116,110,115,0,0,0,0,0,0,0,120,112,97,116,104,0,0,0,120,112,97,116,104,58,32,101,120,112,114,101,115,115,105,111,110,32,114,101,113,117,105,114,101,100,10,0,0,0,0,0,115,101,116,98,97,115,101,0,108,115,0,0,0,0,0,0,100,105,114,0,0,0,0,0,119,104,101,114,101,105,115,0,99,100,0,0,0,0,0,0,99,97,110,110,111,116,32,99,100,32,116,111,32,110,97,109,101,115,112,97,99,101,10,0,37,115,32,105,115,32,97,32,37,100,32,78,111,100,101,32,83,101,116,10,0,0,0,0,37,115,32,105,115,32,97,110,32,101,109,112,116,121,32,78,111,100,101,32,83,101,116,10,0,0,0,0,0,0,0,0,99,97,116,0,0,0,0,0,32,45,45,45,45,45,45,45,10,0,0,0,0,0,0,0,85,110,107,110,111,119,110,32,99,111,109,109,97,110,100,32,37,115,10,0,0,0,0,0,100,101,102,97,117,108,116,110,115,0,0,0,0,0,0,0,69,114,114,111,114,58,32,117,110,97,98,108,101,32,116,111,32,114,101,103,105,115,116,101,114,32,78,83,32,119,105,116,104,32,112,114,101,102,105,120,61,34,37,115,34,32,97,110,100,32,104,114,101,102,61,34,37,115,34,10,0,0,0,0,102,97,105,108,101,100,32,116,111,32,112,97,114,115,101,32,99,111,110,116,101,110,116,10,0,0,0,0,0,0,0,0,37,115,32,58,32,0,0,0,82,101,108,97,120,45,78,71,32,115,99,104,101,109,97,32,37,115,32,102,97,105,108,101,100,32,116,111,32,99,111,109,112,105,108,101,10,0,0,0,37,115,32,118,97,108,105,100,97,116,101,115,10,0,0,0,37,115,32,102,97,105,108,115,32,116,111,32,118,97,108,105,100,97,116,101,10,0,0,0,37,115,32,118,97,108,105,100,97,116,105,111,110,32,103,101,110,101,114,97,116,101,100,32,97,110,32,105,110,116,101,114,110,97,108,32,101,114,114,111,114,10,0,0,0,0,0,0,68,84,68,32,110,111,100,101,32,105,115,32,78,85,76,76,10,0,0,0,0,0,0,0,78,111,100,101,32,105,115,32,110,111,116,32,97,32,68,84,68,0,0,0,0,0,0,0,68,84,68,40,37,115,41,0,68,84,68,0,0,0,0,0,44,32,80,85,66,76,73,67,32,37,115,0,0,0,0,0,44,32,83,89,83,84,69,77,32,37,115,0,0,0,0,0,78,111,100,101,32,104,97,115,32,110,111,32,112,97,114,101,110,116,10,0,0,0,0,0,78,111,100,101,32,104,97,115,32,110,111,32,100,111,99,10,0,0,0,0,0,0,0,0,112,115,101,117,100,111,114,111,111,116,0,0,0,0,0,0,78,111,100,101,32,100,111,99,32,100,105,102,102,101,114,115,32,102,114,111,109,32,112,97,114,101,110,116,39,115,32,111,110,101,10,0,0,0,0,0,65,116,116,114,32,104,97,115,32,110,111,32,112,114,101,118,32,97,110,100,32,110,111,116,32,102,105,114,115,116,32,111,102,32,97,116,116,114,32,108,105,115,116,10,0,0,0,0,78,111,100,101,32,104,97,115,32,110,111,32,112,114,101,118,32,97,110,100,32,110,111,116,32,102,105,114,115,116,32,111,102,32,112,97,114,101,110,116,32,108,105,115,116,10,0,0,78,111,100,101,32,112,114,101,118,45,62,110,101,120,116,32,58,32,98,97,99,107,32,108,105,110,107,32,119,114,111,110,103,10,0,0,0,0,0,0,78,111,100,101,32,104,97,115,32,110,111,32,110,101,120,116,32,97,110,100,32,110,111,116,32,108,97,115,116,32,111,102,32,112,97,114,101,110,116,32,108,105,115,116,10,0,0,0,78,111,100,101,32,110,101,120,116,45,62,112,114,101,118,32,58,32,102,111,114,119,97,114,100,32,108,105,110,107,32,119,114,111,110,103,10,0,0,0,110,98,107,116,101,120,116,0,84,101,120,116,32,110,111,100,101,32,104,97,115,32,119,114,111,110,103,32,110,97,109,101,32,39,37,115,39,0,0,0,67,111,109,109,101,110,116,32,110,111,100,101,32,104,97,115,32,119,114,111,110,103,32,110,97,109,101,32,39,37,115,39,0,0,0,0,0,0,0,0,67,68,97,116,97,32,115,101,99,116,105,111,110,32,104,97,115,32,110,111,110,32,78,85,76,76,32,110,97,109,101,32,39,37,115,39,0,0,0,0,78,97,109,101,32,105,115,32,78,85,76,76,0,0,0,0,78,97,109,101,32,105,115,32,110,111,116,32,97,110,32,78,67,78,97,109,101,32,39,37,115,39,0,0,0,0,0,0,78,97,109,101,32,105,115,32,110,111,116,32,102,114,111,109,32,116,104,101,32,100,111,99,117,109,101,110,116,32,100,105,99,116,105,111,110,110,97,114,121,32,39,37,115,39,0,0,83,116,114,105,110,103,32,105,115,32,110,111,116,32,85,84,70,45,56,32,37,115,0,0,82,101,102,101,114,101,110,99,101,32,116,111,32,100,101,102,97,117,108,116,32,110,97,109,101,115,112,97,99,101,32,110,111,116,32,105,110,32,115,99,111,112,101,10,0,0,0,0,82,101,102,101,114,101,110,99,101,32,116,111,32,110,97,109,101,115,112,97,99,101,32,39,37,115,39,32,110,111,116,32,105,110,32,115,99,111,112,101,10,0,0,0,0,0,0,0,82,101,102,101,114,101,110,99,101,32,116,111,32,100,101,102,97,117,108,116,32,110,97,109,101,115,112,97,99,101,32,110,111,116,32,111,110,32,97,110,99,101,115,116,111,114,10,0,82,101,102,101,114,101,110,99,101,32,116,111,32,110,97,109,101,115,112,97,99,101,32,39,37,115,39,32,110,111,116,32,111,110,32,97,110,99,101,115,116,111,114,10,0,0,0,0,68,79,67,85,77,69,78,84,32,61,61,32,78,85,76,76,32,33,10,0,0,0,0,0,110,97,109,101,61,0,0,0,118,101,114,115,105,111,110,61,0,0,0,0,0,0,0,0,101,110,99,111,100,105,110,103,61,0,0,0,0,0,0,0,85,82,76,61,0,0,0,0,115,116,97,110,100,97,108,111,110,101,61,116,114,117,101,10,0,0,0,0,0,0,0,0,110,97,109,101,115,112,97,99,101,32,110,111,100,101,32,105,115,32,78,85,76,76,10,0,78,111,100,101,32,105,115,32,110,111,116,32,97,32,110,97,109,101,115,112,97,99,101,32,100,101,99,108,97,114,97,116,105,111,110,0,0,0,0,0,73,110,99,111,109,112,108,101,116,101,32,110,97,109,101,115,112,97,99,101,32,37,115,32,104,114,101,102,61,78,85,76,76,10,0,0,0,0,0,0,73,110,99,111,109,112,108,101,116,101,32,100,101,102,97,117,108,116,32,110,97,109,101,115,112,97,99,101,32,104,114,101,102,61,78,85,76,76,10,0,110,97,109,101,115,112,97,99,101,32,37,115,32,104,114,101,102,61,0,0,0,0,0,0,100,101,102,97,117,108,116,32,110,97,109,101,115,112,97,99,101,32,104,114,101,102,61,0,77,105,115,112,108,97,99,101,100,32,69,76,69,77,69,78,84,32,110,111,100,101,10,0,77,105,115,112,108,97,99,101,100,32,65,84,84,82,73,66,85,84,69,32,110,111,100,101,10,0,0,0,0,0,0,0,77,105,115,112,108,97,99,101,100,32,84,69,88,84,32,110,111,100,101,10,0,0,0,0,77,105,115,112,108,97,99,101,100,32,67,68,65,84,65,32,110,111,100,101,10,0,0,0,77,105,115,112,108,97,99,101,100,32,69,78,84,73,84,89,82,69,70,32,110,111,100,101],"i8",ALLOC_NONE,Runtime.GLOBAL_BASE+115568),
	allocate([10,0,0,0,0,0,0,0,77,105,115,112,108,97,99,101,100,32,69,78,84,73,84,89,32,110,111,100,101,10,0,0,77,105,115,112,108,97,99,101,100,32,80,73,32,110,111,100,101,10,0,0,0,0,0,0,77,105,115,112,108,97,99,101,100,32,67,79,77,77,69,78,84,32,110,111,100,101,10,0,68,79,67,85,77,69,78,84,10,0,0,0,0,0,0,0,72,84,77,76,32,68,79,67,85,77,69,78,84,10,0,0,77,105,115,112,108,97,99,101,100,32,68,79,67,84,89,80,69,32,110,111,100,101,10,0,77,105,115,112,108,97,99,101,100,32,70,82,65,71,77,69,78,84,32,110,111,100,101,10,0,0,0,0,0,0,0,0,77,105,115,112,108,97,99,101,100,32,78,79,84,65,84,73,79,78,32,110,111,100,101,10,0,0,0,0,0,0,0,0,85,110,107,110,111,119,110,32,110,111,100,101,32,116,121,112,101,32,37,100,10,0,0,0,110,111,100,101,32,105,115,32,78,85,76,76,10,0,0,0,69,76,69,77,69,78,84,32,0,0,0,0,0,0,0,0,58,0,0,0,0,0,0,0,69,114,114,111,114,44,32,65,84,84,82,73,66,85,84,69,32,102,111,117,110,100,32,104,101,114,101,10,0,0,0,0,84,69,88,84,32,110,111,32,101,110,99,0,0,0,0,0,84,69,88,84,0,0,0,0,32,99,111,109,112,97,99,116,10,0,0,0,0,0,0,0,32,105,110,116,101,114,110,101,100,10,0,0,0,0,0,0,67,68,65,84,65,95,83,69,67,84,73,79,78,10,0,0,69,78,84,73,84,89,95,82,69,70,40,37,115,41,10,0,69,78,84,73,84,89,10,0,80,73,32,37,115,10,0,0,67,79,77,77,69,78,84,10,0,0,0,0,0,0,0,0,69,114,114,111,114,44,32,68,79,67,85,77,69,78,84,32,102,111,117,110,100,32,104,101,114,101,10,0,0,0,0,0,68,79,67,85,77,69,78,84,95,84,89,80,69,10,0,0,68,79,67,85,77,69,78,84,95,70,82,65,71,10,0,0,78,79,84,65,84,73,79,78,10,0,0,0,0,0,0,0,73,78,67,76,85,68,69,32,83,84,65,82,84,10,0,0,73,78,67,76,85,68,69,32,69,78,68,10,0,0,0,0,80,66,77,58,32,100,111,99,32,61,61,32,78,85,76,76,32,33,33,33,10,0,0,0,99,111,110,116,101,110,116,61,0,0,0,0,0,0,0,0,69,110,116,105,116,121,32,105,115,32,78,85,76,76,10,0,73,78,84,69,82,78,65,76,95,71,69,78,69,82,65,76,95,69,78,84,73,84,89,32,0,0,0,0,0,0,0,0,69,88,84,69,82,78,65,76,95,71,69,78,69,82,65,76,95,80,65,82,83,69,68,95,69,78,84,73,84,89,32,0,69,88,84,69,82,78,65,76,95,71,69,78,69,82,65,76,95,85,78,80,65,82,83,69,68,95,69,78,84,73,84,89,32,0,0,0,0,0,0,0,73,78,84,69,82,78,65,76,95,80,65,82,65,77,69,84,69,82,95,69,78,84,73,84,89,32,0,0,0,0,0,0,69,88,84,69,82,78,65,76,95,80,65,82,65,77,69,84,69,82,95,69,78,84,73,84,89,32,0,0,0,0,0,0,69,78,84,73,84,89,95,37,100,32,33,32,0,0,0,0,69,120,116,101,114,110,97,108,73,68,61,37,115,10,0,0,83,121,115,116,101,109,73,68,61,37,115,10,0,0,0,0,85,82,73,61,37,115,10,0,69,110,116,105,116,121,32,100,101,99,108,97,114,97,116,105,111,110,32,105,115,32,78,85,76,76,10,0,0,0,0,0,78,111,100,101,32,105,115,32,110,111,116,32,97,110,32,101,110,116,105,116,121,32,100,101,99,108,97,114,97,116,105,111,110,0,0,0,0,0,0,0,69,78,84,73,84,89,68,69,67,76,40,0,0,0,0,0,41,0,0,0,0,0,0,0,69,110,116,105,116,121,32,100,101,99,108,97,114,97,116,105,111,110,32,104,97,115,32,110,111,32,110,97,109,101,0,0,44,32,105,110,116,101,114,110,97,108,10,0,0,0,0,0,44,32,101,120,116,101,114,110,97,108,32,112,97,114,115,101,100,10,0,0,0,0,0,0,44,32,117,110,112,97,114,115,101,100,10,0,0,0,0,0,44,32,112,97,114,97,109,101,116,101,114,10,0,0,0,0,44,32,101,120,116,101,114,110,97,108,32,112,97,114,97,109,101,116,101,114,10,0,0,0,44,32,112,114,101,100,101,102,105,110,101,100,10,0,0,0,32,69,120,116,101,114,110,97,108,73,68,61,37,115,10,0,32,83,121,115,116,101,109,73,68,61,37,115,10,0,0,0,32,85,82,73,61,37,115,10,0,0,0,0,0,0,0,0,32,99,111,110,116,101,110,116,61,0,0,0,0,0,0,0,65,116,116,114,105,98,117,116,101,32,100,101,99,108,97,114,97,116,105,111,110,32,105,115,32,78,85,76,76,10,0,0,78,111,100,101,32,105,115,32,110,111,116,32,97,110,32,97,116,116,114,105,98,117,116,101,32,100,101,99,108,97,114,97,116,105,111,110,0,0,0,0,65,84,84,82,68,69,67,76,40,37,115,41,0,0,0,0,78,111,100,101,32,97,116,116,114,105,98,117,116,101,32,100,101,99,108,97,114,97,116,105,111,110,32,104,97,115,32,110,111,32,110,97,109,101,0,0,32,102,111,114,32,37,115,0,78,111,100,101,32,97,116,116,114,105,98,117,116,101,32,100,101,99,108,97,114,97,116,105,111,110,32,104,97,115,32,110,111,32,101,108,101,109,101,110,116,32,110,97,109,101,0,0,32,67,68,65,84,65,0,0,32,73,68,0,0,0,0,0,32,73,68,82,69,70,0,0,32,73,68,82,69,70,83,0,32,69,78,84,73,84,89,0,32,69,78,84,73,84,73,69,83,0,0,0,0,0,0,0,32,78,77,84,79,75,69,78,0,0,0,0,0,0,0,0,32,78,77,84,79,75,69,78,83,0,0,0,0,0,0,0,32,69,78,85,77,69,82,65,84,73,79,78,0,0,0,0,32,78,79,84,65,84,73,79,78,32,0,0,0,0,0,0,124,37,115,0,0,0,0,0,32,40,37,115,0,0,0,0,46,46,46,41,0,0,0,0,32,82,69,81,85,73,82,69,68,0,0,0,0,0,0,0,32,73,77,80,76,73,69,68,0,0,0,0,0,0,0,0,32,70,73,88,69,68,0,0,34,0,0,0,0,0,0,0,69,108,101,109,101,110,116,32,100,101,99,108,97,114,97,116,105,111,110,32,105,115,32,78,85,76,76,10,0,0,0,0,78,111,100,101,32,105,115,32,110,111,116,32,97,110,32,101,108,101,109,101,110,116,32,100,101,99,108,97,114,97,116,105,111,110,0,0,0,0,0,0,69,76,69,77,68,69,67,76,40,0,0,0,0,0,0,0,69,108,101,109,101,110,116,32,100,101,99,108,97,114,97,116,105,111,110,32,104,97,115,32,110,111,32,110,97,109,101,0,44,32,85,78,68,69,70,73,78,69,68,0,0,0,0,0,44,32,69,77,80,84,89,0,44,32,65,78,89,0,0,0,44,32,77,73,88,69,68,32,0,0,0,0,0,0,0,0,69,110,116,105,116,105,101,115,32,105,110,32,105,110,116,101,114,110,97,108,32,115,117,98,115,101,116,10,0,0,0,0,78,111,32,101,110,116,105,116,105,101,115,32,105,110,32,105,110,116,101,114,110,97,108,32,115,117,98,115,101,116,10,0,69,110,116,105,116,105,101,115,32,105,110,32,101,120,116,101,114,110,97,108,32,115,117,98,115,101,116,10,0,0,0,0,78,111,32,101,110,116,105,116,105,101,115,32,105,110,32,101,120,116,101,114,110,97,108,32,115,117,98,115,101,116,10,0,69,110,116,105,116,121,32,105,115,32,78,85,76,76,0,0,73,78,84,69,82,78,65,76,32,71,69,78,69,82,65,76,44,32,0,0,0,0,0,0,69,88,84,69,82,78,65,76,32,80,65,82,83,69,68,44,32,0,0,0,0,0,0,0,69,88,84,69,82,78,65,76,32,85,78,80,65,82,83,69,68,44,32,0,0,0,0,0,73,78,84,69,82,78,65,76,32,80,65,82,65,77,69,84,69,82,44,32,0,0,0,0,69,88,84,69,82,78,65,76,32,80,65,82,65,77,69,84,69,82,44,32,0,0,0,0,85,110,107,110,111,119,110,32,101,110,116,105,116,121,32,116,121,112,101,32,37,100,10,0,73,68,32,34,37,115,34,0,83,89,83,84,69,77,32,34,37,115,34,0,0,0,0,0,10,32,111,114,105,103,32,34,37,115,34,0,0,0,0,0,10,32,99,111,110,116,101,110,116,32,34,37,115,34,0,0,65,116,116,114,32,105,115,32,78,85,76,76,0,0,0,0,65,84,84,82,73,66,85,84,69,32,0,0,0,0,0,0,65,116,116,114,105,98,117,116,101,32,104,97,115,32,110,111,32,110,97,109,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,63,0,0,0,0,0,0,240,191,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,37,115,0,0,0,0,0,0,96,0,2,0,104,0,2,0,128,0,2,0,152,0,2,0,176,0,2,0,216,0,2,0,240,0,2,0,8,1,2,0,32,1,2,0,64,1,2,0,88,1,2,0,112,1,2,0,128,1,2,0,160,1,2,0,184,1,2,0,216,1,2,0,248,1,2,0,8,2,2,0,24,2,2,0,48,2,2,0,80,2,2,0,96,2,2,0,120,2,2,0,152,2,2,0,176,2,2,0,200,2,2,0,79,98,106,101,99,116,32,105,115,32,101,109,112,116,121,32,40,78,85,76,76,41,10,0,79,98,106,101,99,116,32,105,115,32,117,110,105,110,105,116,105,97,108,105,122,101,100,10,0,0,0,0,0,0,0,0,79,98,106,101,99,116,32,105,115,32,97,32,78,111,100,101,32,83,101,116,32,58,10,0,79,98,106,101,99,116,32,105,115,32,97,110,32,88,83,76,84,32,118,97,108,117,101,32,116,114,101,101,32,58,10,0,79,98,106,101,99,116,32,105,115,32,97,32,66,111,111,108,101,97,110,32,58,32,0,0,116,114,117,101,10,0,0,0,102,97,108,115,101,10,0,0,79,98,106,101,99,116,32,105,115,32,97,32,110,117,109,98,101,114,32,58,32,73,110,102,105,110,105,116,121,10,0,0,79,98,106,101,99,116,32,105,115,32,97,32,110,117,109,98,101,114,32,58,32,45,73,110,102,105,110,105,116,121,10,0,79,98,106,101,99,116,32,105,115,32,97,32,110,117,109,98,101,114,32,58,32,78,97,78,10,0,0,0,0,0,0,0,79,98,106,101,99,116,32,105,115,32,97,32,110,117,109,98,101,114,32,58,32,48,10,0,79,98,106,101,99,116,32,105,115,32,97,32,110,117,109,98,101,114,32,58,32,37,48,103,10,0,0,0,0,0,0,0,79,98,106,101,99,116,32,105,115,32,97,32,115,116,114,105,110,103,32,58,32,0,0,0,10,0,0,0,0,0,0,0,79,98,106,101,99,116,32,105,115,32,97,32,112,111,105,110,116,32,58,32,105,110,100,101,120,32,37,100,32,105,110,32,110,111,100,101,0,0,0,0,79,98,106,101,99,116,32,105,115,32,97,32,99,111,108,108,97,112,115,101,100,32,114,97,110,103,101,32,58,10,0,0,105,110,100,101,120,32,37,100,32,105,110,32,0,0,0,0,110,111,100,101,10,0,0,0,79,98,106,101,99,116,32,105,115,32,97,32,114,97,110,103,101,32,58,10,0,0,0,0,70,114,111,109,32,0,0,0,84,111,32,0,0,0,0,0,79,98,106,101,99,116,32,105,115,32,97,32,76,111,99,97,116,105,111,110,32,83,101,116,58,10,0,0,0,0,0,0,79,98,106,101,99,116,32,105,115,32,117,115,101,114,32,100,101,102,105,110,101,100,10,0,46,46,47,108,105,98,120,109,108,50,47,120,112,97,116,104,46,99,0,0,0,0,0,0,88,80,97,116,104,32,115,116,97,99,107,32,100,101,112,116,104,32,108,105,109,105,116,32,114,101,97,99,104,101,100,10,0,0,0,0,0,0,0,0,112,117,115,104,105,110,103,32,118,97,108,117,101,10,0,0,99,114,101,97,116,105,110,103,32,110,111,100,101,115,101,116,10,0,0,0,0,0,0,0,103,114,111,119,105,110,103,32,110,111,100,101,115,101,116,10,0,0,0,0,0,0,0,0,103,114,111,119,105,110,103,32,110,111,100,101,115,101,116,32,104,105,116,32,108,105,109,105,116,10,0,0,0,0,0,0,109,101,114,103,105,110,103,32,110,111,100,101,115,101,116,10,0,0,0,0,0,0,0,0,109,101,114,103,105,110,103,32,110,111,100,101,115,101,116,32,104,105,116,32,108,105,109,105,116,10,0,0,0,0,0,0,99,114,101,97,116,105,110,103,32,110,111,100,101,32,115,101,116,32,111,98,106,101,99,116,10,0,0,0,0,0,0,0,120,109,108,0,0,0,0,0,104,116,116,112,58,47,47,119,119,119,46,119,51,46,111,114,103,47,88,77,76,47,49,57,57,56,47,110,97,109,101,115,112,97,99,101,0,0,0,0,99,114,101,97,116,105,110,103,32,102,108,111,97,116,32,111,98,106,101,99,116,10,0,0,99,114,101,97,116,105,110,103,32,98,111,111,108,101,97,110,32,111,98,106,101,99,116,10,0,0,0,0,0,0,0,0,99,114,101,97,116,105,110,103,32,115,116,114,105,110,103,32,111,98,106,101,99,116,10,0,0,0,0,0,0,0,0,0,99,111,112,121,105,110,103,32,111,98,106,101,99,116,10,0,120,109,108,88,80,97,116,104,79,98,106,101,99,116,67,111,112,121,58,32,117,110,115,117,112,112,111,114,116,101,100,32,116,121,112,101,32,37,100,10,0,0,0,0,0,0,0,0,116,114,117,101,0,0,0,0,102,97,108,115,101,0,0,0,73,110,102,105,110,105,116,121,0,0,0,0,0,0,0,0,45,73,110,102,105,110,105,116,121,0,0,0,0,0,0,0,78,97,78,0,0,0,0,0,48,0,0,0,0,0,0,0,85,110,105,109,112,108,101,109,101,110,116,101,100,32,98,108,111,99,107,32,97,116,32,37,115,58,37,100,10,0,0,0,99,114,101,97,116,105,110,103,32,99,111,110,116,101,120,116,10,0,0,0,0,0,0,0,99,114,101,97,116,105,110,103,32,112,97,114,115,101,114,32,99,111,110,116,101,120,116,10,0,0,0,0,0,0,0,0,102,97,107,101,32,110,111,100,101,32,108,105,98,120,115,108,116,0,0,0,0,0,0,0,184,254,1,0,0,0,0,0,120,109,108,88,80,97,116,104,84,114,97,110,115,108,97,116,101,70,117,110,99,116,105,111,110,58,32,73,110,118,97,108,105,100,32,85,84,70,56,32,115,116,114,105,110,103,10,0,0,0,0,0,0,0,240,63,0,0,0,0,0,0,36,64,0,0,0,0,0,0,89,64,0,0,0,0,0,64,143,64,0,0,0,0,0,136,195,64,0,0,0,0,0,106,248,64,0,0,0,0,128,132,46,65,0,0,0,0,208,18,99,65,0,0,0,0,132,215,151,65,0,0,0,0,101,205,205,65,0,0,0,32,95,160,2,66,0,0,0,232,118,72,55,66,0,0,0,162,148,26,109,66,0,0,64,229,156,48,162,66,0,0,144,30,196,188,214,66,0,0,52,38,245,107,12,67,0,128,224,55,121,195,65,67,0,160,216,133,87,52,118,67,0,200,78,103,109,193,171,67,0,61,145,96,228,88,225,67,64,140,181,120,29,175,21,68,110,111,100,101,0,0,0,0,116,101,120,116,0,0,0,0,99,111,109,109,101,110,116,0,112,114,111,99,101,115,115,105,110,103,45,105,110,115,116,114,117,99,116,105,111,110,0,0,73,110,116,101,114,110,97,108,32,101,114,114,111,114,32,97,116,32,37,115,58,37,100,10,0,0,0,0,0,0,0,0,78,85,76,76,32,99,111,110,116,101,120,116,32,112,111,105,110,116,101,114,10,0,0,0,120,109,108,88,80,97,116,104,69,118,97,108,58,32,101,118,97,108,117,97,116,105,111,110,32,102,97,105,108,101,100,10,0,0,0,0,0,0,0,0,120,109,108,88,80,97,116,104,69,118,97,108,58,32,37,100,32,111,98,106,101,99,116,32,108,101,102,116,32,111,110,32,116,104,101,32,115,116,97,99,107,10,0,0,0,0,0,0,98,111,111,108,101,97,110,0,99,101,105,108,105,110,103,0,99,111,117,110,116,0,0,0,99,111,110,99,97,116,0,0,99,111,110,116,97,105,110,115,0,0,0,0,0,0,0,0,105,100,0,0,0,0,0,0,102,108,111,111,114,0,0,0,108,97,115,116,0,0,0,0,108,97,110,103,0,0,0,0,108,111,99,97,108,45,110,97,109,101,0,0,0,0,0,0,110,111,116,0,0,0,0,0,110,97,109,101,0,0,0,0,110,97,109,101,115,112,97,99,101,45,117,114,105,0,0,0,110,111,114,109,97,108,105,122,101,45,115,112,97,99,101,0,110,117,109,98,101,114,0,0,112,111,115,105,116,105,111,110,0,0,0,0,0,0,0,0,114,111,117,110,100,0,0,0,115,116,114,105,110,103,0,0,115,116,114,105,110,103,45,108,101,110,103,116,104,0,0,0,115,116,97,114,116,115,45,119,105,116,104,0,0,0,0,0,115,117,98,115,116,114,105,110,103,0,0,0,0,0,0,0,115,117,98,115,116,114,105,110,103,45,98,101,102,111,114,101,0,0,0,0,0,0,0,0,115,117,98,115,116,114,105,110,103,45,97,102,116,101,114,0,115,117,109,0,0,0,0,0,116,114,97,110,115,108,97,116,101,0,0,0,0,0,0,0,101,115,99,97,112,101,45,117,114,105,0,0,0,0,0,0,104,116,116,112,58,47,47,119,119,119,46,119,51,46,111,114,103,47,50,48,48,50,47,48,56,47,120,113,117,101,114,121,45,102,117,110,99,116,105,111,110,115,0,0,0,0,0,0,99,114,101,97,116,105,110,103,32,101,118,97,108,117,97,116,105,111,110,32,99,111,110,116,101,120,116,10,0,0,0,0,120,109,108,88,80,97,116,104,82,117,110,69,118,97,108,58,32,108,97,115,116,32,105,115,32,108,101,115,115,32,116,104,97,110,32,122,101,114,111,10,0,0,0,0,0,0,0,0,120,109,108,88,80,97,116,104,67,111,109,112,79,112,69,118,97,108,58,32,118,97,114,105,97,98,108,101,32,37,115,32,98,111,117,110,100,32,116,111,32,117,110,100,101,102,105,110,101,100,32,112,114,101,102,105,120,32,37,115,10,0,0,0,120,109,108,88,80,97,116,104,67,111,109,112,79,112,69,118,97,108,58,32,112,97,114,97,109,101,116,101,114,32,101,114,114,111,114,10,0,0,0,0,120,109,108,88,80,97,116,104,67,111,109,112,79,112,69,118,97,108,58,32,102,117,110,99,116,105,111,110,32,37,115,32,98,111,117,110,100,32,116,111,32,117,110,100,101,102,105,110,101,100,32,112,114,101,102,105,120,32,37,115,10,0,0,0,120,109,108,88,80,97,116,104,67,111,109,112,79,112,69,118,97,108,58,32,102,117,110,99,116,105,111,110,32,37,115,32,110,111,116,32,102,111,117,110,100,10,0,0,0,0,0,0,88,80,97,116,104,58,32,117,110,107,110,111,119,110,32,112,114,101,99,111,109,112,105,108,101,100,32,111,112,101,114,97,116,105,111,110,32,37,100,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,120,109,108,88,80,97,116,104,67,111,109,112,105,108,101,100,69,118,97,108,58,32,101,118,97,108,117,97,116,105,111,110,32,102,97,105,108,101,100,10,0,0,0,0,0,0,0,0,120,109,108,88,80,97,116,104,67,111,109,112,105,108,101,100,69,118,97,108,58,32,37,100,32,111,98,106,101,99,116,115,32,108,101,102,116,32,111,110,32,116,104,101,32,115,116,97,99,107,46,10,0,0,0,0,97,100,100,105,110,103,32,115,116,101,112,10,0,0,0,0,58,58,0,0,0,0,0,0,114,97,110,103,101,45,116,111,0,0,0,0,0,0,0,0,97,110,99,101,115,116,111,114,0,0,0,0,0,0,0,0,97,110,99,101,115,116,111,114,45,111,114,45,115,101,108,102,0,0,0,0,0,0,0,0,97,116,116,114,105,98,117,116,101,0,0,0,0,0,0,0,99,104,105,108,100,0,0,0,100,101,115,99,101,110,100,97,110,116,0,0,0,0,0,0,100,101,115,99,101,110,100,97,110,116,45,111,114,45,115,101,108,102,0,0,0,0,0,0,102,111,108,108,111,119,105,110,103,0,0,0,0,0,0,0,102,111,108,108,111,119,105,110,103,45,115,105,98,108,105,110,103,0,0,0,0,0,0,0,110,97,109,101,115,112,97,99,101,0,0,0,0,0,0,0,112,97,114,101,110,116,0,0,112,114,101,99,101,100,105,110,103,0,0,0,0,0,0,0,112,114,101,99,101,100,105,110,103,45,115,105,98,108,105,110,103,0,0,0,0,0,0,0,115,101,108,102,0,0,0,0,97,108,108,111,99,97,116,105,110,103,32,110,97,109,101,115,112,97,99,101,115,32,97,114,114,97,121,10,0,0,0,0,97,108,108,111,99,97,116,105,110,103,32,115,116,114,101,97,109,97,98,108,101,32,101,120,112,114,101,115,115,105,111,110,10,0,0,0,0,0,0,0,0,0,0,0,18,0,0,0,40,247,1,0,32,247,1,0,0,0,0,0,0,0,0,0,99,111,109,112,97,114,105,110,103,32,110,111,100,101,115,101,116,115,10,0,0,0,0,0,97,108,108,111,99,97,116,105,110,103,32,99,111,109,112,111,110,101,110,116,10,0,0,0,97,108,108,111,99,97,116,105,110,103,32,115,116,101,112,115,10,0,0,0,0,0,0,0,37,100,0,0,0,0,0,0,37,42,46,42,101,0,0,0,37,48,46,42,102,0,0,0,120,109,108,80,111,105,110,116,101,114,76,105,115,116,67,114,101,97,116,101,58,32,97,108,108,111,99,97,116,105,110,103,32,105,116,101,109,10,0,0,120,109,108,80,111,105,110,116,101,114,76,105,115,116,65,100,100,83,105,122,101,58,32,114,101,45,97,108,108,111,99,97,116,105,110,103,32,105,116,101,109,10,0,0,0,0,0,0,100,117,112,108,105,99,97,116,105,110,103,32,110,97,109,101,115,112,97,99,101,10,0,0,77,101,109,111,114,121,32,97,108,108,111,99,97,116,105,111,110,32,102,97,105,108,101,100,32,58,32,37,115,10,0,0,77,101,109,111,114,121,32,97,108,108,111,99,97,116,105,111,110,32,102,97,105,108,101,100,10,0,0,0,0,0,0,0,76,111,99,97,116,105,111,110,83,101,116,32,105,115,32,78,85,76,76,32,33,10,0,0,37,100,32,58,32,0,0,0,78,111,100,101,32,105,115,32,78,85,76,76,32,33,10,0,32,47,10,0,0,0,0,0,86,97,108,117,101,32,84,114,101,101,32,105,115,32,78,85,76,76,32,33,10,0,0,0,78,111,100,101,83,101,116,32,105,115,32,78,85,76,76,32,33,10,0,0,0,0,0,0,83,101,116,32,99,111,110,116,97,105,110,115,32,37,100,32,110,111,100,101,115,58,10,0,79,107,10,0,0,0,0,0,78,117,109,98,101,114,32,101,110,99,111,100,105,110,103,10,0,0,0,0,0,0,0,0,85,110,102,105,110,105,115,104,101,100,32,108,105,116,101,114,97,108,10,0,0,0,0,0,83,116,97,114,116,32,111,102,32,108,105,116,101,114,97,108,10,0,0,0,0,0,0,0,69,120,112,101,99,116,101,100,32,36,32,102,111,114,32,118,97,114,105,97,98,108,101,32,114,101,102,101,114,101,110,99,101,10,0,0,0,0,0,0,85,110,100,101,102,105,110,101,100,32,118,97,114,105,97,98,108,101,10,0,0,0,0,0,73,110,118,97,108,105,100,32,112,114,101,100,105,99,97,116,101,10,0,0,0,0,0,0,73,110,118,97,108,105,100,32,101,120,112,114,101,115,115,105,111,110,10,0,0,0,0,0,77,105,115,115,105,110,103,32,99,108,111,115,105,110,103,32,99,117,114,108,121,32,98,114,97,99,101,10,0,0,0,0,85,110,114,101,103,105,115,116,101,114,101,100,32,102,117,110,99,116,105,111,110,10,0,0,73,110,118,97,108,105,100,32,111,112,101,114,97,110,100,10,0,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,116,121,112,101,10,0,0,0,73,110,118,97,108,105,100,32,110,117,109,98,101,114,32,111,102,32,97,114,103,117,109,101,110,116,115,10,0,0,0,0,73,110,118,97,108,105,100,32,99,111,110,116,101,120,116,32,115,105,122,101,10,0,0,0,73,110,118,97,108,105,100,32,99,111,110,116,101,120,116,32,112,111,115,105,116,105,111,110,10,0,0,0,0,0,0,0,77,101,109,111,114,121,32,97,108,108,111,99,97,116,105,111,110,32,101,114,114,111,114,10,0,0,0,0,0,0,0,0,83,121,110,116,97,120,32,101,114,114,111,114,10,0,0,0,82,101,115,111,117,114,99,101,32,101,114,114,111,114,10,0,83,117,98,32,114,101,115,111,117,114,99,101,32,101,114,114,111,114,10,0,0,0,0,0,85,110,100,101,102,105,110,101,100,32,110,97,109,101,115,112,97,99,101,32,112,114,101,102,105,120,10,0,0,0,0,0,69,110,99,111,100,105,110,103,32,101,114,114,111,114,10,0,67,104,97,114,32,111,117,116,32,111,102,32,88,77,76,32,114,97,110,103,101,10,0,0,73,110,118,97,108,105,100,32,111,114,32,105,110,99,111,109,112,108,101,116,101,32,99,111,110,116,101,120,116,10,0,0,83,116,97,99,107,32,117,115,97,103,101,32,101,114,114,111,114,10,0,0,0,0,0,0,70,111,114,98,105,100,100,101,110,32,118,97,114,105,97,98,108,101,10,0,0,0,0,0,63,63,32,85,110,107,110,111,119,110,32,101,114,114,111,114,32,63,63,10,0,0,0,0,128,0,0,0,0,0,0,0,0,1,2,3,4,5,6,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,240,0,0,0,0,0,0,69,114,114,111,114,32,97,108,108,111,99,97,116,105,110,103,32,116,101,109,112,111,114,97,114,121,32,115,116,111,114,97,103,101,32,102,111,114,32,116,105,109,32,115,111,114,116,58,32,110,101,101,100,32,37,108,117,32,98,121,116,101,115,0,97,108,108,111,99,97,116,105,110,103,32,114,97,110,103,101,0,0,0,0,0,0,0,0,73,110,116,101,114,110,97,108,32,101,114,114,111,114,32,97,116,32,37,115,58,37,100,10,0,0,0,0,0,0,0,0,46,46,47,108,105,98,120,109,108,50,47,120,112,111,105,110,116,101,114,46,99,0,0,0,97,108,108,111,99,97,116,105,110,103,32,108,111,99,97,116,105,111,110,115,101,116,0,0,97,100,100,105,110,103,32,108,111,99,97,116,105,111,110,32,116,111,32,115,101,116,0,0,114,97,110,103,101,45,116,111,0,0,0,0,0,0,0,0,114,97,110,103,101,0,0,0,114,97,110,103,101,45,105,110,115,105,100,101,0,0,0,0,115,116,114,105,110,103,45,114,97,110,103,101,0,0,0,0,115,116,97,114,116,45,112,111,105,110,116,0,0,0,0,0,101,110,100,45,112,111,105,110,116,0,0,0,0,0,0,0,104,101,114,101,0,0,0,0,32,111,114,105,103,105,110,0,120,109,108,88,80,116,114,69,118,97,108,58,32,101,118,97,108,117,97,116,105,111,110,32,102,97,105,108,101,100,32,116,111,32,114,101,116,117,114,110,32,97,32,110,111,100,101,32,115,101,116,10,0,0,0,0,120,109,108,88,80,116,114,69,118,97,108,58,32,111,98,106,101,99,116,40,115,41,32,108,101,102,116,32,111,110,32,116,104,101,32,101,118,97,108,32,115,116,97,99,107,10,0,0,85,110,105,109,112,108,101,109,101,110,116,101,100,32,98,108,111,99,107,32,97,116,32,37,115,58,37,100,10,0,0,0,97,108,108,111,99,97,116,105,110,103,32,112,111,105,110,116,0,0,0,0,0,0,0,0,97,108,108,111,99,97,116,105,110,103,32,101,118,97,108,117,97,116,105,111,110,32,99,111,110,116,101,120,116,0,0,0,97,108,108,111,99,97,116,105,110,103,32,98,117,102,102,101,114,0,0,0,0,0,0,0,120,112,111,105,110,116,101,114,0,0,0,0,0,0,0,0,101,108,101,109,101,110,116,0,120,109,108,110,115,0,0,0,117,110,115,117,112,112,111,114,116,101,100,32,115,99,104,101,109,101,32,39,37,115,39,10,0,0,0,0,0,0,0,0,119,97,114,110,105,110,103,58,32,67,104,105,108,100,83,101,113,32,110,111,116,32,115,116,97,114,116,105,110,103,32,98,121,32,47,49,10,0,0,0,77,101,109,111,114,121,32,97,108,108,111,99,97,116,105,111,110,32,102,97,105,108,101,100,32,58,32,37,115,10,0,0,99,114,101,97,116,105,110,103,32,88,73,110,99,108,117,100,101,32,99,111,110,116,101,120,116,0,0,0,0,0,0,0,88,73,110,99,108,117,100,101,32,101,114,114,111,114,58,32,119,111,117,108,100,32,114,101,115,117,108,116,32,105,110,32,109,117,108,116,105,112,108,101,32,114,111,111,116,32,110,111,100,101,115,10,0,0,0,0,102,97,105,108,101,100,32,116,111,32,98,117,105,108,100,32,110,111,100,101,10,0,0,0,104,114,101,102,0,0,0,0,0,0,0,0,0,0,0,0,112,97,114,115,101,0,0,0,120,109,108,0,0,0,0,0,116,101,120,116,0,0,0,0,105,110,118,97,108,105,100,32,118,97,108,117,101,32,37,115,32,102,111,114,32,39,112,97,114,115,101,39,10,0,0,0,102,97,105,108,101,100,32,98,117,105,108,100,32,85,82,76,10,0,0,0,0,0,0,0,102,97,108,108,98,97,99,107,0,0,0,0,0,0,0,0,104,116,116,112,58,47,47,119,119,119,46,119,51,46,111,114,103,47,50,48,48,51,47,88,73,110,99,108,117,100,101,0,104,116,116,112,58,47,47,119,119,119,46,119,51,46,111,114,103,47,50,48,48,49,47,88,73,110,99,108,117,100,101,0,99,111,117,108,100,32,110,111,116,32,108,111,97,100,32,37,115,44,32,97,110,100,32,110,111,32,102,97,108,108,98,97,99,107,32,119,97,115,32,102,111,117,110,100,10,0,0,0,105,110,118,97,108,105,100,32,118,97,108,117,101,32,85,82,73,32,37,115,10,0,0,0,102,114,97,103,109,101,110,116,32,105,100,101,110,116,105,102,105,101,114,32,102,111,114,98,105,100,100,101,110,32,102,111,114,32,116,101,120,116,58,32,37,115,10,0,0,0,0,0,116,101,120,116,32,115,101,114,105,97,108,105,122,97,116,105,111,110,32,111,102,32,100,111,99,117,109,101,110,116,32,110,111,116,32,97,118,97,105,108,97,98,108,101,10,0,0,0,101,110,99,111,100,105,110,103,0,0,0,0,0,0,0,0,101,110,99,111,100,105,110,103,32,37,115,32,110,111,116,32,115,117,112,112,111,114,116,101,100,10,0,0,0,0,0,0,37,115,32,99,111,110,116,97,105,110,115,32,105,110,118,97,108,105,100,32,99,104,97,114,10,0,0,0,0,0,0,0,112,114,111,99,101,115,115,105,110,103,32,116,101,120,116,0,99,111,117,108,100,32,110,111,116,32,99,114,101,97,116,101,32,88,80,111,105,110,116,101,114,32,99,111,110,116,101,120,116,10,0,0,0,0,0,0,88,80,111,105,110,116,101,114,32,101,118,97,108,117,97,116,105,111,110,32,102,97,105,108,101,100,58,32,35,37,115,10,0,0,0,0,0,0,0,0,88,80,111,105,110,116,101,114,32,105,115,32,110,111,116,32,97,32,114,97,110,103,101,58,32,35,37,115,10,0,0,0,88,80,111,105,110,116,101,114,32,115,101,108,101,99,116,115,32,97,110,32,97,116,116,114,105,98,117,116,101,58,32,35,37,115,10,0,0,0,0,0,88,80,111,105,110,116,101,114,32,115,101,108,101,99,116,115,32,97,32,110,97,109,101,115,112,97,99,101,58,32,35,37,115,10,0,0,0,0,0,0,88,80,111,105,110,116,101,114,32,115,101,108,101,99,116,115,32,117,110,101,120,112,101,99,116,101,100,32,110,111,100,101,115,58,32,35,37,115,10,0,98,97,115,101,0,0,0,0,104,116,116,112,58,47,47,119,119,119,46,119,51,46,111,114,103,47,88,77,76,47,49,57,57,56,47,110,97,109,101,115,112,97,99,101,0,0,0,0,116,114,121,105,110,103,32,116,111,32,98,117,105,108,100,32,114,101,108,97,116,105,118,101,32,85,82,73,32,102,114,111,109,32,37,115,10,0,0,0,116,114,121,105,110,103,32,116,111,32,114,101,98,117,105,108,100,32,98,97,115,101,32,102,114,111,109,32,37,115,10,0,112,114,111,99,101,115,115,105,110,103,32,100,111,99,0,0,109,105,115,109,97,116,99,104,32,105,110,32,114,101,100,101,102,105,110,105,116,105,111,110,32,111,102,32,101,110,116,105,116,121,32,37,115,10,0,0,99,97,110,110,111,116,32,97,108,108,111,99,97,116,101,32,112,97,114,115,101,114,32,99,111,110,116,101,120,116,0,0,120,112,111,105,110,116,101,114,0,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,102,114,97,103,109,101,110,116,32,105,100,101,110,116,105,102,105,101,114,32,105,110,32,85,82,73,32,37,115,32,117,115,101,32,116,104,101,32,120,112,111,105,110,116,101,114,32,97,116,116,114,105,98,117,116,101,10,0,0,0,0,0,0,0,100,101,116,101,99,116,101,100,32,97,32,108,111,99,97,108,32,114,101,99,117,114,115,105,111,110,32,119,105,116,104,32,110,111,32,120,112,111,105,110,116,101,114,32,105,110,32,37,115,10,0,0,0,0,0,0,100,101,116,101,99,116,101,100,32,97,32,114,101,99,117,114,115,105,111,110,32,105,110,32,37,115,10,0,0,0,0,0,103,114,111,119,105,110,103,32,88,73,110,99,108,117,100,101,32,99,111,110,116,101,120,116,0,0,0,0,0,0,0,0,105,110,99,108,117,100,101,0,37,115,32,104,97,115,32,97,110,32,39,105,110,99,108,117,100,101,39,32,99,104,105,108,100,10,0,0,0,0,0,0,37,115,32,104,97,115,32,109,117,108,116,105,112,108,101,32,102,97,108,108,98,97,99,107,32,99,104,105,108,100,114,101,110,10,0,0,0,0,0,0,37,115,32,105,115,32,110,111,116,32,116,104,101,32,99,104,105,108,100,32,111,102,32,97,110,32,39,105,110,99,108,117,100,101,39,10,0,0,0,0,97,100,100,105,110,103,32,85,82,76,0,0,0,0,0,0,77,101,109,111,114,121,32,97,108,108,111,99,97,116,105,111,110,32,102,97,105,108,101,100,32,58,32,37,115,10,0,0,0,0,0,0,0,0,0,0,111,117,116,32,111,102,32,109,101,109,111,114,121,10,0,0,1,0,0,0,0,0,0,0,82,101,115,111,108,118,101,58,32,112,117,98,73,68,32,37,115,32,115,121,115,73,68,32,37,115,10,0,0,0,0,0,82,101,115,111,108,118,101,58,32,112,117,98,73,68,32,37,115,10,0,0,0,0,0,0,82,101,115,111,108,118,101,58,32,115,121,115,73,68,32,37,115,10,0,0,0,0,0,0,82,101,115,111,108,118,101,32,85,82,73,32,37,115,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,88,77,76,95,68,69,66,85,71,95,67,65,84,65,76,79,71,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,88,77,76,95,67,65,84,65,76,79,71,95,70,73,76,69,83,0,0,0,0,0,0,0,102,105,108,101,58,47,47,47,101,116,99,47,120,109,108,47,99,97,116,97,108,111,103,0,67,97,116,97,108,111,103,115,32,99,108,101,97,110,117,112,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,99,97,116,97,108,111,103,0,3,0,0,0,0,0,0,0,65,100,100,105,110,103,32,100,111,99,117,109,101,110,116,32,99,97,116,97,108,111,103,32,37,115,10,0,0,0,0,0,76,111,99,97,108,32,82,101,115,111,108,118,101,58,32,112,117,98,73,68,32,37,115,32,115,121,115,73,68,32,37,115,10,0,0,0,0,0,0,0,76,111,99,97,108,32,82,101,115,111,108,118,101,58,32,112,117,98,73,68,32,37,115,10,0,0,0,0,0,0,0,0,76,111,99,97,108,32,82,101,115,111,108,118,101,58,32,115,121,115,73,68,32,37,115,10,0,0,0,0,0,0,0,0,70,111,117,110,100,32,37,115,32,105,110,32,102,105,108,101,32,104,97,115,104,10,0,0,37,115,32,110,111,116,32,102,111,117,110,100,32,105,110,32,102,105,108,101,32,104,97,115,104,10,0,0,0,0,0,0,37,115,32,97,100,100,101,100,32,116,111,32,102,105,108,101,32,104,97,115,104,10,0,0,70,97,105,108,101,100,32,116,111,32,112,97,114,115,101,32,99,97,116,97,108,111,103,32,37,115,10,0,0,0,0,0,37,100,32,80,97,114,115,105,110,103,32,99,97,116,97,108,111,103,32,37,115,10,0,0,117,114,110,58,111,97,115,105,115,58,110,97,109,101,115,58,116,99,58,101,110,116,105,116,121,58,120,109,108,110,115,58,120,109,108,58,99,97,116,97,108,111,103,0,0,0,0,0,112,114,101,102,101,114,0,0,115,121,115,116,101,109,0,0,112,117,98,108,105,99,0,0,73,110,118,97,108,105,100,32,118,97,108,117,101,32,102,111,114,32,112,114,101,102,101,114,58,32,39,37,115,39,10,0,70,105,108,101,32,37,115,32,105,115,32,110,111,116,32,97,110,32,88,77,76,32,67,97,116,97,108,111,103,10,0,0,103,114,111,117,112,0,0,0,105,100,0,0,0,0,0,0,98,97,115,101,0,0,0,0,104,116,116,112,58,47,47,119,119,119,46,119,51,46,111,114,103,47,88,77,76,47,49,57,57,56,47,110,97,109,101,115,112,97,99,101,0,0,0,0,112,117,98,108,105,99,73,100,0,0,0,0,0,0,0,0,117,114,105,0,0,0,0,0,115,121,115,116,101,109,73,100,0,0,0,0,0,0,0,0,114,101,119,114,105,116,101,83,121,115,116,101,109,0,0,0,115,121,115,116,101,109,73,100,83,116,97,114,116,83,116,114,105,110,103,0,0,0,0,0,114,101,119,114,105,116,101,80,114,101,102,105,120,0,0,0,100,101,108,101,103,97,116,101,80,117,98,108,105,99,0,0,112,117,98,108,105,99,73,100,83,116,97,114,116,83,116,114,105,110,103,0,0,0,0,0,100,101,108,101,103,97,116,101,83,121,115,116,101,109,0,0,110,97,109,101,0,0,0,0,114,101,119,114,105,116,101,85,82,73,0,0,0,0,0,0,117,114,105,83,116,97,114,116,83,116,114,105,110,103,0,0,100,101,108,101,103,97,116,101,85,82,73,0,0,0,0,0,110,101,120,116,67,97,116,97,108,111,103,0,0,0,0,0,37,115,32,101,110,116,114,121,32,108,97,99,107,115,32,39,37,115,39,10,0,0,0,0,70,111,117,110,100,32,37,115,58,32,39,37,115,39,32,39,37,115,39,10,0,0,0,0,70,111,117,110,100,32,37,115,58,32,39,37,115,39,10,0,37,115,32,101,110,116,114,121,32,39,37,115,39,32,98,114,111,107,101,110,32,63,58,32,37,115,10,0,0,0,0,0,83,89,83,84,69,77,0,0,80,85,66,76,73,67,0,0,68,69,76,69,71,65,84,69,0,0,0,0,0,0,0,0,69,78,84,73,84,89,0,0,68,79,67,84,89,80,69,0,76,73,78,75,84,89,80,69,0,0,0,0,0,0,0,0,78,79,84,65,84,73,79,78,0,0,0,0,0,0,0,0,83,71,77,76,68,69,67,76,0,0,0,0,0,0,0,0,68,79,67,85,77,69,78,84,0,0,0,0,0,0,0,0,67,65,84,65,76,79,71,0,66,65,83,69,0,0,0,0,117,114,110,58,112,117,98,108,105,99,105,100,58,0,0,0,85,82,78,32,73,68,32,37,115,32,101,120,112,97,110,100,101,100,32,116,111,32,78,85,76,76,10,0,0,0,0,0,85,82,78,32,73,68,32,101,120,112,97,110,100,101,100,32,116,111,32,37,115,10,0,0,68,101,116,101,99,116,101,100,32,114,101,99,117,114,115,105,111,110,32,105,110,32,99,97,116,97,108,111,103,32,37,115,10,0,0,0,0,0,0,0,70,111,117,110,100,32,85,82,73,32,109,97,116,99,104,32,37,115,10,0,0,0,0,0,85,115,105,110,103,32,114,101,119,114,105,116,105,110,103,32,114,117,108,101,32,37,115,10,0,0,0,0,0,0,0,0,84,114,121,105,110,103,32,85,82,73,32,100,101,108,101,103,97,116,101,32,37,115,10,0,80,117,98,108,105,99,32,85,82,78,32,73,68,32,37,115,32,101,120,112,97,110,100,101,100,32,116,111,32,78,85,76,76,10,0,0,0,0,0,0,80,117,98,108,105,99,32,85,82,78,32,73,68,32,101,120,112,97,110,100,101,100,32,116,111,32,37,115,10,0,0,0,83,121,115,116,101,109,32,85,82,78,32,73,68,32,37,115,32,101,120,112,97,110,100,101,100,32,116,111,32,78,85,76,76,10,0,0,0,0,0,0,83,121,115,116,101,109,32,85,82,78,32,73,68,32,101,120,112,97,110,100,101,100,32,116,111,32,37,115,10,0,0,0,70,111,117,110,100,32,115,121,115,116,101,109,32,109,97,116,99,104,32,37,115,44,32,117,115,105,110,103,32,37,115,10,0,0,0,0,0,0,0,0,84,114,121,105,110,103,32,115,121,115,116,101,109,32,100,101,108,101,103,97,116,101,32,37,115,10,0,0,0,0,0,0,70,111,117,110,100,32,112,117,98,108,105,99,32,109,97,116,99,104,32,37,115,10,0,0,84,114,121,105,110,103,32,112,117,98,108,105,99,32,100,101,108,101,103,97,116,101,32,37,115,10,0,0,0,0,0,0,97,108,108,111,99,97,116,105,110,103,32,99,97,116,97,108,111,103,32,101,110,116,114,121,0,0,0,0,0,0,0,0,77,101,109,111,114,121,32,97,108,108,111,99,97,116,105,111,110,32,102,97,105,108,101,100,32,58,32,37,115,10,0,0,79,86,69,82,82,73,68,69,0,0,0,0,0,0,0,0,97,108,108,111,99,97,116,105,110,103,32,112,117,98,108,105,99,32,73,68,0,0,0,0,97,108,108,111,99,97,116,105,110,103,32,99,97,116,97,108,111,103,0,0,0,0,0,0,97,108,108,111,99,97,116,105,110,103,32,99,97,116,97,108,111,103,32,100,97,116,97,0,70,114,101,101,32,99,97,116,97,108,111,103,32,101,110,116,114,121,32,37,115,10,0,0,70,114,101,101,32,99,97,116,97,108,111,103,32,101,110,116,114,121,10,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,0,0,0,0,0,0,32,0,0,0,0,0,0,0,32,0,0,0,0,0,0,0,33,0,0,0,0,0,0,0,34,0,0,0,0,0,0,0,50,48,57,48,50,0,0,0,96,18,2,0,0,0,0,0,1,0,0,0,0,0,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,32,32,0,0,0,0,0,0,8,19,2,0,0,0,0,0,0,0,0,0,0,0,0,0,36,0,0,0,37,0,0,0,38,0,0,0,39,0,0,0,40,0,0,0,41,0,0,0,42,0,0,0,43,0,0,0,44,0,0,0,45,0,0,0,46,0,0,0,47,0,0,0,48,0,0,0,49,0,0,0,50,0,0,0,51,0,0,0,52,0,0,0,53,0,0,0,53,0,0,0,54,0,0,0,55,0,0,0,56],"i8",ALLOC_NONE,Runtime.GLOBAL_BASE+125808),
	allocate([57,0,0,0,57,0,0,0,58,0,0,0,59,0,0,0,60,0,0,0,0,0,0,0,61,0,0,0,62,0,0,0,63,0,0,0,64,0,0,0,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,47,0,0,0,48,0,0,0,49,0,0,0,50,0,0,0,51,0,0,0,0,0,0,0,53,0,0,0,65,0,0,0,54,0,0,0,55,0,0,0,56,0,0,0,57,0,0,0,57,0,0,0,58,0,0,0,59,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,101,120,101,99,117,116,105,110,103,32,99,49,52,110,0,0,105,110,118,97,108,105,100,32,109,111,100,101,32,102,111,114,32,101,120,101,99,117,116,105,110,103,32,99,49,52,110,0,120,109,108,67,49,52,78,69,120,101,99,117,116,101,58,32,111,117,116,112,117,116,32,98,117,102,102,101,114,32,101,110,99,111,100,101,114,32,33,61,32,78,85,76,76,32,98,117,116,32,67,49,52,78,32,114,101,113,117,105,114,101,115,32,85,84,70,56,32,111,117,116,112,117,116,10,0,0,0,0,120,109,108,67,49,52,78,69,120,101,99,117,116,101,58,32,117,110,97,98,108,101,32,116,111,32,99,114,101,97,116,101,32,67,49,52,78,32,99,111,110,116,101,120,116,10,0,0,112,114,111,99,101,115,115,105,110,103,32,100,111,99,115,32,99,104,105,108,100,114,101,110,32,108,105,115,116,0,0,0,102,108,117,115,104,105,110,103,32,111,117,116,112,117,116,32,98,117,102,102,101,114,0,0,100,117,109,112,105,110,103,32,100,111,99,32,116,111,32,109,101,109,111,114,121,0,0,0,99,114,101,97,116,105,110,103,32,111,117,116,112,117,116,32,98,117,102,102,101,114,0,0,115,97,118,105,110,103,32,100,111,99,32,116,111,32,111,117,116,112,117,116,32,98,117,102,102,101,114,0,0,0,0,0,99,111,112,105,110,103,32,99,97,110,111,110,105,99,97,110,105,122,101,100,32,100,111,99,117,109,101,110,116,0,0,0,77,101,109,111,114,121,32,97,108,108,111,99,97,116,105,111,110,32,102,97,105,108,101,100,32,58,32,37,115,10,0,0,102,114,101,101,105,110,103,32,99,111,110,116,101,120,116,0,100,101,115,116,114,111,121,105,110,103,32,110,97,109,101,115,112,97,99,101,115,32,115,116,97,99,107,0,0,0,0,0,73,110,116,101,114,110,97,108,32,101,114,114,111,114,32,58,32,37,115,10,0,0,0,0,112,114,111,99,101,115,115,105,110,103,32,110,111,100,101,32,108,105,115,116,0,0,0,0,112,114,111,99,101,115,115,105,110,103,32,110,111,100,101,0,110,111,114,109,97,108,105,122,105,110,103,32,116,101,120,116,32,110,111,100,101,0,0,0,10,60,63,0,0,0,0,0,60,63,0,0,0,0,0,0,32,0,0,0,0,0,0,0,110,111,114,109,97,108,105,122,105,110,103,32,112,105,32,110,111,100,101,0,0,0,0,0,63,62,10,0,0,0,0,0,63,62,0,0,0,0,0,0,10,60,33,45,45,0,0,0,60,33,45,45,0,0,0,0,110,111,114,109,97,108,105,122,105,110,103,32,99,111,109,109,101,110,116,32,110,111,100,101,0,0,0,0,0,0,0,0,45,45,62,10,0,0,0,0,45,45,62,0,0,0,0,0,88,77,76,95,65,84,84,82,73,66,85,84,69,95,78,79,68,69,0,0,0,0,0,0,88,77,76,95,78,65,77,69,83,80,65,67,69,95,68,69,67,76,0,0,0,0,0,0,88,77,76,95,69,78,84,73,84,89,95,82,69,70,95,78,79,68,69,0,0,0,0,0,88,77,76,95,69,78,84,73,84,89,95,78,79,68,69,0,85,110,107,110,111,119,110,32,110,111,100,101,32,116,121,112,101,32,37,100,32,102,111,117,110,100,32,58,32,37,115,10,0,0,0,0,0,0,0,0,78,111,100,101,32,37,115,32,105,115,32,105,110,118,97,108,105,100,32,104,101,114,101,32,58,32,37,115,10,0,0,0,97,108,108,111,99,97,116,105,110,103,32,98,117,102,102,101,114,0,0,0,0,0,0,0,103,114,111,119,105,110,103,32,98,117,102,102,101,114,0,0,112,114,111,99,101,115,115,105,110,103,32,101,108,101,109,101,110,116,32,110,111,100,101,0,99,104,101,99,107,105,110,103,32,102,111,114,32,114,101,108,97,116,105,118,101,32,110,97,109,101,115,112,97,99,101,115,0,0,0,0,0,0,0,0,60,0,0,0,0,0,0,0,58,0,0,0,0,0,0,0,112,114,111,99,101,115,115,105,110,103,32,110,97,109,101,115,112,97,99,101,115,32,97,120,105,115,0,0,0,0,0,0,112,114,111,99,101,115,115,105,110,103,32,97,116,116,114,105,98,117,116,101,115,32,97,120,105,115,0,0,0,0,0,0,62,0,0,0,0,0,0,0,112,114,111,99,101,115,115,105,110,103,32,99,104,105,108,100,114,101,110,115,32,108,105,115,116,0,0,0,0,0,0,0,60,47,0,0,0,0,0,0,114,101,115,116,111,114,105,110,103,32,110,97,109,101,115,112,97,99,101,115,32,115,116,97,99,107,0,0,0,0,0,0,99,114,101,97,116,105,110,103,32,97,116,116,114,105,98,117,116,101,115,32,108,105,115,116,0,0,0,0,0,0,0,0,108,97,110,103,0,0,0,0,115,112,97,99,101,0,0,0,98,97,115,101,0,0,0,0,104,116,116,112,58,47,47,119,119,119,46,119,51,46,111,114,103,47,88,77,76,47,49,57,57,56,47,110,97,109,101,115,112,97,99,101,0,0,0,0,119,114,105,116,105,110,103,32,97,116,116,114,105,98,117,116,101,115,0,0,0,0,0,0,61,34,0,0,0,0,0,0,110,111,114,109,97,108,105,122,105,110,103,32,97,116,116,114,105,98,117,116,101,115,32,97,120,105,115,0,0,0,0,0,34,0,0,0,0,0,0,0,112,114,111,99,101,115,115,105,110,103,32,120,109,108,58,98,97,115,101,32,97,116,116,114,105,98,117,116,101,0,0,0,112,114,111,99,101,115,115,105,110,103,32,120,109,108,58,98,97,115,101,32,97,116,116,114,105,98,117,116,101,32,45,32,99,97,110,39,116,32,103,101,116,32,97,116,116,114,32,118,97,108,117,101,0,0,0,0,47,0,0,0,0,0,0,0,112,114,111,99,101,115,115,105,110,103,32,120,109,108,58,98,97,115,101,32,97,116,116,114,105,98,117,116,101,32,45,32,99,97,110,39,116,32,109,111,100,105,102,121,32,117,114,105,0,0,0,0,0,0,0,0,112,114,111,99,101,115,115,105,110,103,32,120,109,108,58,98,97,115,101,32,97,116,116,114,105,98,117,116,101,32,45,32,99,97,110,39,116,32,99,111,110,115,116,114,117,99,116,32,117,114,105,0,0,0,0,0,0,0,0,0,0,0,0,0,112,114,111,99,101,115,115,105,110,103,32,120,109,108,58,98,97,115,101,32,97,116,116,114,105,98,117,116,101,32,45,32,99,97,110,39,116,32,99,111,110,115,116,114,117,99,116,32,97,116,116,114,105,98,117,116,101,0,0,0,0,0,0,0,120,109,108,0,0,0,0,0,115,104,105,102,116,105,110,103,32,110,97,109,101,115,112,97,99,101,115,32,115,116,97,99,107,0,0,0,0,0,0,0,112,114,111,99,101,115,115,105,110,103,32,110,97,109,101,115,112,97,99,101,115,32,97,120,105,115,32,40,101,120,99,32,99,49,52,110,41,0,0,0,99,114,101,97,116,105,110,103,32,110,97,109,101,115,112,97,99,101,115,32,108,105,115,116,32,40,101,120,99,32,99,49,52,110,41,0,0,0,0,0,35,100,101,102,97,117,108,116,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,119,114,105,116,105,110,103,32,110,97,109,101,115,112,97,99,101,115,0,0,0,0,0,0,32,120,109,108,110,115,58,0,61,0,0,0,0,0,0,0,32,120,109,108,110,115,61,0,34,34,0,0,0,0,0,0,115,101,97,114,99,104,105,110,103,32,110,97,109,101,115,112,97,99,101,115,32,115,116,97,99,107,32,40,101,120,99,32,99,49,52,110,41,0,0,0,97,100,100,105,110,103,32,110,97,109,101,115,112,97,99,101,32,116,111,32,115,116,97,99,107,0,0,0,0,0,0,0,97,100,100,105,110,103,32,110,111,100,101,32,116,111,32,115,116,97,99,107,0,0,0,0,115,101,97,114,99,104,105,110,103,32,110,97,109,101,115,112,97,99,101,115,32,115,116,97,99,107,32,40,99,49,52,110,41,0,0,0,0,0,0,0,112,114,111,99,101,115,115,105,110,103,32,110,97,109,101,115,112,97,99,101,115,32,97,120,105,115,32,40,99,49,52,110,41,0,0,0,0,0,0,0,99,114,101,97,116,105,110,103,32,110,97,109,101,115,112,97,99,101,115,32,108,105,115,116,32,40,99,49,52,110,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,115,97,118,105,110,103,32,110,97,109,101,115,112,97,99,101,115,32,115,116,97,99,107,0,112,97,114,115,105,110,103,32,110,97,109,101,115,112,97,99,101,32,117,114,105,0,0,0,117,114,110,0,0,0,0,0,100,97,118,0,0,0,0,0,82,101,108,97,116,105,118,101,32,110,97,109,101,115,112,97,99,101,32,85,82,32,105,115,32,105,110,118,97,108,105,100,32,104,101,114,101,32,58,32,37,115,10,0,0,0,0,0,99,114,101,97,116,105,110,103,32,110,101,119,32,99,111,110,116,101,120,116,0,0,0,0,120,109,108,67,49,52,78,78,101,119,67,116,120,58,32,111,117,116,112,117,116,32,98,117,102,102,101,114,32,101,110,99,111,100,101,114,32,33,61,32,78,85,76,76,32,98,117,116,32,67,49,52,78,32,114,101,113,117,105,114,101,115,32,85,84,70,56,32,111,117,116,112,117,116,10,0,0,0,0,0,120,109,108,67,49,52,78,78,101,119,67,116,120,58,32,115,111,117,114,99,101,32,100,111,99,117,109,101,110,116,32,110,111,116,32,105,110,32,85,84,70,56,10,0,0,0,0,0,99,114,101,97,116,105,110,103,32,99,111,110,116,101,120,116,0,0,0,0,0,0,0,0,120,109,108,67,49,52,78,78,101,119,67,116,120,58,32,120,109,108,67,49,52,78,86,105,115,105,98,108,101,78,115,83,116,97,99,107,67,114,101,97,116,101,32,102,97,105,108,101,100,10,0,0,0,0,0,0,99,114,101,97,116,105,110,103,32,110,97,109,101,115,112,97,99,101,115,32,115,116,97,99,107,0,0,0,0,0,0,0,37,115,0,0,0,0,0,0,73,110,118,97,108,105,100,32,112,97,114,97,109,101,116,101,114,32,58,32,37,115,10,0,0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57,58,59,60,61,62,63,64,97,98,99,100,101,102,103,104,105,106,107,108,109,110,111,112,113,114,115,116,117,118,119,120,121,122,123,92,93,94,95,96,97,98,99,100,101,102,103,104,105,106,107,108,109,110,111,112,113,114,115,116,117,118,119,120,121,122,123,124,125,126,127,128,129,130,131,132,133,134,135,136,137,138,139,140,141,142,143,144,145,146,147,148,149,150,151,152,153,154,155,156,157,158,159,160,161,162,163,164,165,166,167,168,169,170,171,172,173,174,175,176,177,178,179,180,181,182,183,184,185,186,187,188,189,190,191,192,193,194,195,196,197,198,199,200,201,202,203,204,205,206,207,208,209,210,211,212,213,214,215,216,217,218,219,220,221,222,223,224,225,226,227,228,229,230,231,232,233,234,235,236,237,238,239,240,241,242,243,244,245,246,247,248,249,250,251,252,253,254,255,109,97,108,108,111,99,32,111,102,32,37,108,100,32,98,121,116,101,32,102,97,105,108,101,100,10,0,0,0,0,0,0,99,114,101,97,116,105,110,103,32,98,117,102,102,101,114,0,0,0,0,0,0,0,0,0,103,114,111,119,105,110,103,32,98,117,102,102,101,114,0,0,34,0,0,0,0,0,0,0,38,113,117,111,116,59,0,0,39,0,0,0,0,0,0,0,73,110,112,117,116,32,114,101,102,101,114,101,110,99,101,32,111,117,116,115,105,100,101,32,111,102,32,116,104,101,32,98,117,102,102,101,114,0,0,0,99,114,101,97,116,105,110,103,32,101,120,101,99,117,116,105,111,110,32,99,111,110,116,101,120,116,0,0,0,0,0,0,120,109,108,70,65,80,97,114,115,101,82,101,103,69,120,112,58,32,101,120,116,114,97,32,99,104,97,114,97,99,116,101,114,115,0,0,0,0,0,0,110,111,116,32,37,115,0,0,97,116,111,109,32,112,117,115,104,58,32,97,116,111,109,32,105,115,32,78,85,76,76,0,112,117,115,104,105,110,103,32,97,116,111,109,0,0,0,0,97,108,108,111,99,97,116,105,110,103,32,99,111,117,110,116,101,114,0,0,0,0,0,0,97,100,100,32,115,116,97,116,101,58,32,115,116,97,116,101,32,105,115,32,78,85,76,76,0,0,0,0,0,0,0,0,97,100,100,32,115,116,97,116,101,58,32,116,97,114,103,101,116,32,105,115,32,78,85,76,76,0,0,0,0,0,0,0,97,100,100,105,110,103,32,116,114,97,110,115,105,116,105,111,110,0,0,0,0,0,0,0,103,101,110,114,97,116,101,32,116,114,97,110,115,105,116,105,111,110,58,32,97,116,111,109,32,61,61,32,78,85,76,76,0,0,0,0,0,0,0,0,99,111,112,121,105,110,103,32,97,116,111,109,0,0,0,0,97,108,108,111,99,97,116,105,110,103,32,114,97,110,103,101,0,0,0,0,0,0,0,0,97,108,108,111,99,97,116,105,110,103,32,97,116,111,109,0,84,79,68,79,58,32,88,77,76,95,82,69,71,69,88,80,95,83,84,82,73,78,71,10,0,0,0,0,0,0,0,0,114,117,110,110,105,110,103,32,114,101,103,101,120,112,0,0,101,112,115,105,108,111,110,32,116,114,97,110,115,105,116,105,111,110,32,108,101,102,116,32,97,116,32,114,117,110,116,105,109,101,10,0,0,0,0,0,101,120,101,99,32,115,97,118,101,58,32,97,108,108,111,99,97,116,105,111,110,32,102,97,105,108,101,100,0,0,0,0,115,97,118,105,110,103,32,114,101,103,101,120,112,0,0,0,99,111,109,112,105,108,105,110,103,32,114,101,103,101,120,112,0,0,0,0,0,0,0,0,102,97,105,108,101,100,32,116,111,32,99,111,109,112,105,108,101,58,32,37,115,10,0,0,101,120,112,101,99,116,105,110,103,32,97,32,98,114,97,110,99,104,32,97,102,116,101,114,32,124,0,0,0,0,0,0,105,110,116,101,114,110,97,108,58,32,110,111,32,97,116,111,109,32,103,101,110,101,114,97,116,101,100,0,0,0,0,0,73,109,112,114,111,112,101,114,32,113,117,97,110,116,105,102,105,101,114,0,0,0,0,0,85,110,116,101,114,109,105,110,97,116,101,100,32,113,117,97,110,116,105,102,105,101,114,0,120,109,108,70,65,80,97,114,115,101,65,116,111,109,58,32,101,120,112,101,99,116,105,110,103,32,39,41,39,0,0,0,120,109,108,70,65,80,97,114,115,101,67,104,97,114,67,108,97,115,115,58,32,39,93,39,32,101,120,112,101,99,116,101,100,0,0,0,0,0,0,0,69,115,99,97,112,101,100,32,115,101,113,117,101,110,99,101,58,32,101,120,112,101,99,116,105,110,103,32,92,0,0,0,69,120,112,101,99,116,105,110,103,32,39,123,39,0,0,0,69,120,112,101,99,116,105,110,103,32,39,125,39,0,0,0,87,114,111,110,103,32,101,115,99,97,112,101,32,115,101,113,117,101,110,99,101,44,32,109,105,115,117,115,101,32,111,102,32,99,104,97,114,97,99,116,101,114,32,39,92,39,0,0,73,115,88,88,88,88,32,101,120,112,101,99,116,101,100,0,85,110,107,110,111,119,110,32,99,104,97,114,32,112,114,111,112,101,114,116,121,0,0,0,97,100,100,32,114,97,110,103,101,58,32,97,116,111,109,32,105,115,32,78,85,76,76,0,97,100,100,32,114,97,110,103,101,58,32,97,116,111,109,32,105,115,32,110,111,116,32,114,97,110,103,101,115,0,0,0,97,100,100,105,110,103,32,114,97,110,103,101,115,0,0,0,99,104,97,114,67,108,97,115,115,69,120,112,114,58,32,39,93,39,32,101,120,112,101,99,116,101,100,0,0,0,0,0,69,120,112,101,99,116,105,110,103,32,39,93,39,0,0,0,73,110,118,97,108,105,100,32,101,115,99,97,112,101,32,118,97,108,117,101,0,0,0,0,69,120,112,101,99,116,105,110,103,32,97,32,99,104,97,114,32,114,97,110,103,101,0,0,69,120,112,101,99,116,105,110,103,32,116,104,101,32,101,110,100,32,111,102,32,97,32,99,104,97,114,32,114,97,110,103,101,0,0,0,0,0,0,0,69,110,100,32,111,102,32,114,97,110,103,101,32,105,115,32,98,101,102,111,114,101,32,115,116,97,114,116,32,111,102,32,114,97,110,103,101,0,0,0,97,100,100,105,110,103,32,115,116,97,116,101,0,0,0,0,97,108,108,111,99,97,116,105,110,103,32,115,116,97,116,101,0,0,0,0,0,0,0,0,85,110,105,109,112,108,101,109,101,110,116,101,100,32,98,108,111,99,107,32,97,116,32,37,115,58,37,100,10,0,0,0,46,46,47,108,105,98,120,109,108,50,47,120,109,108,114,101,103,101,120,112,46,99,0,0,112,117,115,104,105,110,103,32,105,110,112,117,116,32,115,116,114,105,110,103,0,0,0,0,77,101,109,111,114,121,32,97,108,108,111,99,97,116,105,111,110,32,102,97,105,108,101,100,32,58,32,37,115,10,0,0,85,110,105,109,112,108,101,109,101,110,116,101,100,32,98,108,111,99,107,32,97,116,32,37,115,58,37,100,10,0,0,0,46,46,47,108,105,98,120,109,108,50,47,120,109,108,115,99,104,101,109,97,115,46,99,0,10,0,0,0,0,0,0,0,120,109,108,83,99,104,101,109,97,67,104,101,99,107,70,97,99,101,116,0,0,0,0,0,97,32,116,121,112,101,32,117,115,101,114,32,100,101,114,105,118,101,100,32,116,121,112,101,32,104,97,115,32,110,111,32,98,97,115,101,32,116,121,112,101,0,0,0,0,0,0,0,42,0,0,0,0,0,0,0,73,110,116,101,114,110,97,108,32,101,114,114,111,114,58,32,120,109,108,83,99,104,101,109,97,67,104,101,99,107,70,97,99,101,116,44,32,102,97,105,108,101,100,32,116,111,32,118,97,108,105,100,97,116,101,32,116,104,101,32,118,97,108,117,101,32,39,37,115,39,32,111,102,32,116,104,101,32,102,97,99,101,116,32,39,37,115,39,32,97,103,97,105,110,115,116,32,116,104,101,32,98,97,115,101,32,116,121,112,101,0,0,84,104,101,32,118,97,108,117,101,32,39,37,115,39,32,111,102,32,116,104,101,32,102,97,99,101,116,32,100,111,101,115,32,110,111,116,32,118,97,108,105,100,97,116,101,32,97,103,97,105,110,115,116,32,116,104,101,32,98,97,115,101,32,116,121,112,101,32,39,37,115,39,0,0,0,0,0,0,0,0,118,97,108,117,101,32,119,97,115,32,110,111,116,32,99,111,109,112,117,116,101,100,0,0,84,104,101,32,118,97,108,117,101,32,39,37,115,39,32,111,102,32,116,104,101,32,102,97,99,101,116,32,39,112,97,116,116,101,114,110,39,32,105,115,32,110,111,116,32,97,32,118,97,108,105,100,32,114,101,103,117,108,97,114,32,101,120,112,114,101,115,115,105,111,110,0,118,97,108,105,100,97,116,105,110,103,32,102,97,99,101,116,32,118,97,108,117,101,0,0,84,104,101,32,118,97,108,117,101,32,39,37,115,39,32,111,102,32,116,104,101,32,102,97,99,101,116,32,39,37,115,39,32,105,115,32,110,111,116,32,97,32,118,97,108,105,100,32,39,37,115,39,0,0,0,0,110,111,110,78,101,103,97,116,105,118,101,73,110,116,101,103,101,114,0,0,0,0,0,0,112,111,115,105,116,105,118,101,73,110,116,101,103,101,114,0,112,114,101,115,101,114,118,101,0,0,0,0,0,0,0,0,114,101,112,108,97,99,101,0,99,111,108,108,97,112,115,101,0,0,0,0,0,0,0,0,84,104,101,32,118,97,108,117,101,32,39,37,115,39,32,111,102,32,116,104,101,32,102,97,99,101,116,32,39,119,104,105,116,101,115,112,97,99,101,39,32,105,115,32,110,111,116,32,118,97,108,105,100,0,0,0,70,97,105,108,101,100,32,116,111,32,108,111,99,97,116,101,32,116,104,101,32,109,97,105,110,32,115,99,104,101,109,97,32,114,101,115,111,117,114,99,101,32,97,116,32,39,37,115,39,0,0,0,0,0,0,0,70,97,105,108,101,100,32,116,111,32,108,111,99,97,116,101,32,116,104,101,32,109,97,105,110,32,115,99,104,101,109,97,32,114,101,115,111,117,114,99,101,0,0,0,0,0,0,0,120,109,108,83,99,104,101,109,97,80,97,114,115,101,0,0,65,110,32,105,110,116,101,114,110,97,108,32,101,114,114,111,114,32,111,99,99,117,114,101,100,0,0,0,0,0,0,0,97,108,108,111,99,97,116,105,110,103,32,118,97,108,105,100,97,116,105,111,110,32,99,111,110,116,101,120,116,0,0,0,84,104,101,32,100,111,99,117,109,101,110,116,32,104,97,115,32,110,111,32,100,111,99,117,109,101,110,116,32,101,108,101,109,101,110,116,0,0,0,0,120,109,108,83,99,104,101,109,97,65,117,103,109,101,110,116,73,68,67,58,32,97,108,108,111,99,97,116,105,110,103,32,97,110,32,97,117,103,109,101,110,116,101,100,32,73,68,67,32,100,101,102,105,110,105,116,105,111,110,0,0,0,0,0,120,109,108,83,99,104,101,109,97,67,114,101,97,116,101,80,67,116,120,116,79,110,86,67,116,120,116,0,0,0,0,0,102,97,105,108,101,100,32,116,111,32,99,114,101,97,116,101,32,97,32,116,101,109,112,46,32,112,97,114,115,101,114,32,99,111,110,116,101,120,116,0,120,109,108,83,99,104,101,109,97,83,65,88,72,97,110,100,108,101,67,68,97,116,97,83,101,99,116,105,111,110,0,0,99,97,108,108,105,110,103,32,120,109,108,83,99,104,101,109,97,86,80,117,115,104,84,101,120,116,40,41,0,0,0,0,78,101,105,116,104,101,114,32,99,104,97,114,97,99,116,101,114,32,110,111,114,32,101,108,101,109,101,110,116,32,99,111,110,116,101,110,116,32,105,115,32,97,108,108,111,119,101,100,32,98,101,99,97,117,115,101,32,116,104,101,32,101,108,101,109,101,110,116,32,105,115,32,39,110,105,108,108,101,100,39,0,0,0,0,0,0,0,0,67,104,97,114,97,99,116,101,114,32,99,111,110,116,101,110,116,32,105,115,32,110,111,116,32,97,108,108,111,119,101,100,44,32,98,101,99,97,117,115,101,32,116,104,101,32,99,111,110,116,101,110,116,32,116,121,112,101,32,105,115,32,101,109,112,116,121,0,0,0,0,0,67,104,97,114,97,99,116,101,114,32,99,111,110,116,101,110,116,32,111,116,104,101,114,32,116,104,97,110,32,119,104,105,116,101,115,112,97,99,101,32,105,115,32,110,111,116,32,97,108,108,111,119,101,100,32,98,101,99,97,117,115,101,32,116,104,101,32,99,111,110,116,101,110,116,32,116,121,112,101,32,105,115,32,39,101,108,101,109,101,110,116,45,111,110,108,121,39,0,0,0,0,0,0,0,120,109,108,83,99,104,101,109,97,83,65,88,72,97,110,100,108,101,69,110,100,69,108,101,109,101,110,116,78,115,0,0,101,108,101,109,32,112,111,112,32,109,105,115,109,97,116,99,104,0,0,0,0,0,0,0,99,97,108,108,105,110,103,32,120,109,108,83,99,104,101,109,97,86,97,108,105,100,97,116,111,114,80,111,112,69,108,101,109,40,41,0,0,0,0,0,120,109,108,83,99,104,101,109,97,86,97,108,105,100,97,116,111,114,80,111,112,69,108,101,109,0,0,0,0,0,0,0,102,97,105,108,101,100,32,116,111,32,99,114,101,97,116,101,32,97,32,114,101,103,101,120,32,99,111,110,116,101,120,116,0,0,0,0,0,0,0,0,77,105,115,115,105,110,103,32,99,104,105,108,100,32,101,108,101,109,101,110,116,40,115,41,0,0,0,0,0,0,0,0,99,97,108,108,105,110,103,32,120,109,108,83,99,104,101,109,97,86,67,104,101,99,107,67,86,67,83,105,109,112,108,101,84,121,112,101,40,41,0,0,99,97,108,108,105,110,103,32,120,109,108,83,99,104,101,109,97,67,104,101,99,107,67,79,83,86,97,108,105,100,68,101,102,97,117,108,116,40,41,0,99,97,108,108,105,110,103,32,120,109,108,78,101,119,84,101,120,116,40,41,0,0,0,0,84,104,101,32,99,111,110,116,101,110,116,32,109,117,115,116,32,110,111,116,32,99,111,110,116,97,105,110,116,32,101,108,101,109,101,110,116,32,110,111,100,101,115,32,115,105,110,99,101,32,116,104,101,114,101,32,105,115,32,97,32,102,105,120,101,100,32,118,97,108,117,101,32,99,111,110,115,116,114,97,105,110,116,0,0,0,0,0,84,104,101,32,105,110,105,116,105,97,108,32,118,97,108,117,101,32,39,37,115,39,32,100,111,101,115,32,110,111,116,32,109,97,116,99,104,32,116,104,101,32,102,105,120,101,100,32,118,97,108,117,101,32,99,111,110,115,116,114,97,105,110,116,32,39,37,115,39,0,0,0,84,104,101,32,97,99,116,117,97,108,32,118,97,108,117,101,32,39,37,115,39,32,100,111,101,115,32,110,111,116,32,109,97,116,99,104,32,116,104,101,32,102,105,120,101,100,32,118,97,108,117,101,32,99,111,110,115,116,114,97,105,110,116,32,39,37,115,39,0,0,0,0,97,108,108,111,99,97,116,105,110,103,32,73,68,67,32,108,105,115,116,32,111,102,32,110,111,100,101,45,116,97,98,108,101,32,105,116,101,109,115,0,114,101,45,97,108,108,111,99,97,116,105,110,103,32,73,68,67,32,108,105,115,116,32,111,102,32,110,111,100,101,45,116,97,98,108,101,32,105,116,101,109,115,0,0,0,0,0,0,97,108,108,111,99,97,116,105,110,103,32,97,110,32,97,114,114,97,121,32,111,102,32,73,68,67,32,110,111,100,101,45,116,97,98,108,101,32,105,116,101,109,115,0,0,0,0,0,97,108,108,111,99,97,116,105,110,103,32,97,32,80,83,86,73,32,73,68,67,32,98,105,110,100,105,110,103,32,105,116,101,109,0,0,0,0,0,0,97,108,108,111,99,97,116,105,110,103,32,110,101,119,32,105,116,101,109,32,108,105,115,116,0,0,0,0,0,0,0,0,103,114,111,119,105,110,103,32,105,116,101,109,32,108,105,115,116,0,0,0,0,0,0,0,77,111,114,101,32,116,104,97,110,32,111,110,101,32,109,97,116,99,104,32,102,111,117,110,100,32,102,111,114,32,107,101,121,45,115,101,113,117,101,110,99,101,32,37,115,32,111,102,32,107,101,121,114,101,102,32,39,37,115,39,0,0,0,0,78,111,32,109,97,116,99,104,32,102,111,117,110,100,32,102,111,114,32,107,101,121,45,115,101,113,117,101,110,99,101,32,37,115,32,111,102,32,107,101,121,114,101,102,32,39,37,115,39,0,0,0,0,0,0,0,104,116,116,112,58,47,47,119,119,119,46,119,51,46,111,114,103,47,50,48,48,49,47,88,77,76,83,99,104,101,109,97,0,0,0,0,0,0,0,0,91,0,0,0,0,0,0,0,39,0,0,0,0,0,0,0,120,109,108,83,99,104,101,109,97,70,111,114,109,97,116,73,68,67,75,101,121,83,101,113,117,101,110,99,101,0,0,0,102,97,105,108,101,100,32,116,111,32,99,111,109,112,117,116,101,32,97,32,99,97,110,111,110,105,99,97,108,32,118,97,108,117,101,0,0,0,0,0,63,63,63,0,0,0,0,0,39,44,32,0,0,0,0,0,93,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,0,0,0,0,69,108,101,109,101,110,116,32,39,37,115,39,58,32,0,0,46,10,0,0,0,0,0,0,114,101,45,97,108,108,111,99,97,116,105,110,103,32,97,110,32,97,114,114,97,121,32,111,102,32,73,68,67,32,110,111,100,101,45,116,97,98,108,101,32,105,116,101,109,115,0,0,120,109,108,83,99,104,101,109,97,88,80,97,116,104,80,114,111,99,101,115,115,72,105,115,116,111,114,121,0,0,0,0,99,97,108,108,105,110,103,32,120,109,108,83,116,114,101,97,109,80,111,112,40,41,0,0,102,105,101,108,100,32,114,101,115,111,108,118,101,115,32,116,111,32,97,32,67,84,32,119,105,116,104,32,115,105,109,112,108,101,32,99,111,110,116,101,110,116,32,98,117,116,32,116,104,101,32,67,84,32,105,115,32,109,105,115,115,105,110,103,32,116,104,101,32,83,84,32,100,101,102,105,110,105,116,105,111,110,0,0,0,0,0,0,84,104,101,32,88,80,97,116,104,32,39,37,115,39,32,111,102,32,97,32,102,105,101,108,100,32,111,102,32,37,115,32,100,111,101,115,32,101,118,97,108,117,97,116,101,32,116,111,32,97,32,110,111,100,101,32,111,102,32,110,111,110,45,115,105,109,112,108,101,32,116,121,112,101,0,0,0,0,0,0,87,97,114,110,105,110,103,58,32,78,111,32,112,114,101,99,111,109,112,117,116,101,100,32,118,97,108,117,101,32,97,118,97,105,108,97,98,108,101,44,32,116,104,101,32,118,97,108,117,101,32,119,97,115,32,101,105,116,104,101,114,32,105,110,118,97,108,105,100,32,111,114,32,115,111,109,101,116,104,105,110,103,32,115,116,114,97,110,103,101,32,104,97,112,112,101,110,100,0,0,0,0,0,0,97,108,108,111,99,97,116,105,110,103,32,97,110,32,97,114,114,97,121,32,111,102,32,107,101,121,45,115,101,113,117,101,110,99,101,115,0,0,0,0,114,101,97,108,108,111,99,97,116,105,110,103,32,97,110,32,97,114,114,97,121,32,111,102,32,107,101,121,45,115,101,113,117,101,110,99,101,115,0,0,84,104,101,32,88,80,97,116,104,32,39,37,115,39,32,111,102,32,97,32,102,105,101,108,100,32,111,102,32,37,115,32,101,118,97,108,117,97,116,101,115,32,116,111,32,97,32,110,111,100,101,45,115,101,116,32,119,105,116,104,32,109,111,114,101,32,116,104,97,110,32,111,110,101,32,109,101,109,98,101,114,0,0,0,0,0,0,0,97,108,108,111,99,97,116,105,110,103,32,97,110,32,73,68,67,32,107,101,121,45,115,101,113,117,101,110,99,101,0,0,97,108,108,111,99,97,116,105,110,103,32,97,32,73,68,67,32,107,101,121,0,0,0,0,68,117,112,108,105,99,97,116,101,32,107,101,121,45,115,101,113,117,101,110,99,101,32,37,115,32,105,110,32,37,115,0,97,108,108,111,99,97,116,105,110,103,32,97,110,32,73,68,67,32,110,111,100,101,45,116,97,98,108,101,32,105,116,101,109,0,0,0,0,0,0,0,78,111,116,32,97,108,108,32,102,105,101,108,100,115,32,111,102,32,37,115,32,101,118,97,108,117,97,116,101,32,116,111,32,97,32,110,111,100,101,0,84,104,101,32,115,116,97,116,101,32,111,98,106,101,99,116,32,116,111,32,98,101,32,114,101,109,111,118,101,100,32,105,115,32,110,111,116,32,116,104,101,32,102,105,114,115,116,32,105,110,32,116,104,101,32,108,105,115,116,0,0,0,0,0,97,108,108,111,99,97,116,105,110,103,32,116,104,101,32,73,68,67,32,110,111,100,101,32,116,97,98,108,101,32,105,116,101,109,32,108,105,115,116,0,114,101,45,97,108,108,111,99,97,116,105,110,103,32,116,104,101,32,73,68,67,32,110,111,100,101,32,116,97,98,108,101,32,105,116,101,109,32,108,105,115,116,0,0,0,0,0,0,97,108,108,111,99,97,116,105,110,103,32,116,104,101,32,73,68,67,32,107,101,121,32,115,116,111,114,97,103,101,32,108,105,115,116,0,0,0,0,0,114,101,45,97,108,108,111,99,97,116,105,110,103,32,116,104,101,32,73,68,67,32,107,101,121,32,115,116,111,114,97,103,101,32,108,105,115,116,0,0,32,39,0,0,0,0,0,0,99,111,109,112,108,101,120,32,116,121,112,101,32,100,101,102,105,110,105,116,105,111,110,0,115,105,109,112,108,101,32,116,121,112,101,32,100,101,102,105,110,105,116,105,111,110,0,0,101,108,101,109,101,110,116,32,100,101,99,108,97,114,97,116,105,111,110,0,0,0,0,0,97,116,116,114,105,98,117,116,101,32,117,115,101,0,0,0,97,116,116,114,105,98,117,116,101,32,100,101,99,108,97,114,97,116,105,111,110,0,0,0,109,111,100,101,108,32,103,114,111,117,112,32,100,101,102,105,110,105,116,105,111,110,0,0,97,116,116,114,105,98,117,116,101,32,103,114,111,117,112,32,100,101,102,105,110,105,116,105,111,110,0,0,0,0,0,0,110,111,116,97,116,105,111,110,32,100,101,99,108,97,114,97,116,105,111,110,0,0,0,0,109,111,100,101,108,32,103,114,111,117,112,32,40,115,101,113,117,101,110,99,101,41,0,0,109,111,100,101,108,32,103,114,111,117,112,32,40,99,104,111,105,99,101,41,0,0,0,0,109,111,100,101,108,32,103,114,111,117,112,32,40,97,108,108,41,0,0,0,0,0,0,0,112,97,114,116,105,99,108,101,0,0,0,0,0,0,0,0,117,110,105,113,117,101,32,105,100,101,110,116,105,116,121,45,99,111,110,115,116,114,97,105,110,116,0,0,0,0,0,0,107,101,121,32,105,100,101,110,116,105,116,121,45,99,111,110,115,116,114,97,105,110,116,0,107,101,121,114,101,102,32,105,100,101,110,116,105,116,121,45,99,111,110,115,116,114,97,105,110,116,0,0,0,0,0,0,119,105,108,100,99,97,114,100,32,40,97,110,121,41,0,0,91,104,101,108,112,101,114,32,99,111,109,112,111,110,101,110,116,93,32,81,78,97,109,101,32,114,101,102,101,114,101,110,99,101,0,0,0,0,0,0,91,104,101,108,112,101,114,32,99,111,109,112,111,110,101,110,116,93,32,97,116,116,114,105,98,117,116,101,32,117,115,101,32,112,114,111,104,105,98,105,116,105,111,110,0,0,0,0,78,111,116,32,97,32,115,99,104,101,109,97,32,99,111,109,112,111,110,101,110,116,0,0,70,111,114,32,97,32,115,116,114,105,110,103,32,116,111,32,98,101,32,97,32,118,97,108,105,100,32,100,101,102,97,117,108,116,44,32,116,104,101,32,116,121,112,101,32,100,101,102,105,110,105,116,105,111,110,32,109,117,115,116,32,98,101,32,97,32,115,105,109,112,108,101,32,116,121,112,101,32,111,114,32,97,32,99,111,109,112,108,101,120,32,116,121,112,101,32,119,105,116,104,32,115,105,109,112,108,101,32,99,111,110,116,101,110,116,32,111,114,32,109,105,120,101,100,32,99,111,110,116,101,110,116,32,97,110,100,32,97,32,112,97,114,116,105,99,108,101,32,101,109,112,116,105,97,98,108,101,0,0,0,120,109,108,83,99,104,101,109,97,67,104,101,99,107,67,79,83,86,97,108,105,100,68,101,102,97,117,108,116,0,0,0,46,0,0,0,0,0,0,0,32,69,120,112,101,99,116,101,100,32,105,115,32,111,110,101,32,111,102,32,40,32,0,0,32,69,120,112,101,99,116,101,100,32,105,115,32,40,32,0,35,35,111,116,104,101,114,0,123,42,125,0,0,0,0,0,123,35,35,111,116,104,101,114,58,0,0,0,0,0,0,0,123,0,0,0,0,0,0,0,125,0,0,0,0,0,0,0,44,32,0,0,0,0,0,0,32,41,46,10,0,0,0,0,69,108,101,109,101,110,116,32,39,0,0,0,0,0,0,0,97,116,116,114,105,98,117,116,101,32,39,0,0,0,0,0,39,58,32,0,0,0,0,0,120,109,108,83,99,104,101,109,97,83,65,88,72,97,110,100,108,101,83,116,97,114,116,69,108,101,109,101,110,116,78,115,0,0,0,0,0,0,0,0,99,97,108,108,105,110,103,32,120,109,108,83,99,104,101,109,97,86,97,108,105,100,97,116,111,114,80,117,115,104,69,108,101,109,40,41,0,0,0,0,97,108,108,111,99,97,116,105,110,103,32,110,97,109,101,115,112,97,99,101,32,98,105,110,100,105,110,103,115,32,102,111,114,32,83,65,88,32,118,97,108,105,100,97,116,105,111,110,0,0,0,0,0,0,0,0,114,101,45,97,108,108,111,99,97,116,105,110,103,32,110,97,109,101,115,112,97,99,101,32,98,105,110,100,105,110,103,115,32,102,111,114,32,83,65,88,32,118,97,108,105,100,97,116,105,111,110,0,0,0,0,0,99,97,108,108,105,110,103,32,120,109,108,83,99,104,101,109,97,86,97,108,105,100,97,116,111,114,80,117,115,104,65,116,116,114,105,98,117,116,101,40,41,0,0,0,0,0,0,0,99,97,108,108,105,110,103,32,120,109,108,83,99,104,101,109,97,86,97,108,105,100,97,116,101,69,108,101,109,40,41,0,120,109,108,83,99,104,101,109,97,86,97,108,105,100,97,116,101,69,108,101,109,0,0,0,105,110,32,115,107,105,112,45,115,116,97,116,101,0,0,0,99,97,108,108,105,110,103,32,120,109,108,83,99,104,101,109,97,83,116,114,101,97,109,86,97,108,105,100,97,116,101,67,104,105,108,100,69,108,101,109,101,110,116,40,41,0,0,0,116,104,101,32,99,104,105,108,100,32,101,108,101,109,101,110,116,32,119,97,115,32,118,97,108,105,100,32,98,117,116,32,110,101,105,116,104,101,114,32,116,104,101,32,100,101,99,108,97,114,97,116,105,111,110,32,110,111,114,32,116,104,101,32,116,121,112,101,32,119,97,115,32,115,101,116,0,0,0,0,78,111,32,109,97,116,99,104,105,110,103,32,103,108,111,98,97,108,32,100,101,99,108,97,114,97,116,105,111,110,32,97,118,97,105,108,97,98,108,101,32,102,111,114,32,116,104,101,32,118,97,108,105,100,97,116,105,111,110,32,114,111,111,116,0,0,0,0,0,0,0,0,99,97,108,108,105,110,103,32,120,109,108,83,99,104,101,109,97,86,97,108,105,100,97,116,101,69,108,101,109,87,105,108,100,99,97,114,100,40,41,0,99,97,108,108,105,110,103,32,120,109,108,83,99,104,101,109,97,86,97,108,105,100,97,116,101,69,108,101,109,68,101,99,108,40,41,0,0,0,0,0,84,104,101,32,116,121,112,101,32,100,101,102,105,110,105,116,105,111,110,32,105,115,32,97,98,115,101,110,116,0,0,0,84,104,101,32,116,121,112,101,32,100,101,102,105,110,105,116,105,111,110,32,105,115,32,97,98,115,116,114,97,99,116,0,99,97,108,108,105,110,103,32,120,109,108,83,99,104,101,109,97,88,80,97,116,104,69,118,97,108,117,97,116,101,40,41,0,0,0,0,0,0,0,0,99,97,108,108,105,110,103,32,97,116,116,114,105,98,117,116,101,115,32,118,97,108,105,100,97,116,105,111,110,0,0,0,84,104,101,32,97,116,116,114,105,98,117,116,101,32,39,37,115,39,32,105,115,32,110,111,116,32,97,108,108,111,119,101,100,46,10,0,0,0,0,0,120,109,108,83,99,104,101,109,97,86,65,116,116,114,105,98,117,116,101,115,67,111,109,112,108,101,120,0,0,0,0,0,99,97,108,108,105,110,103,32,120,109,108,83,99,104,101,109,97,71,101,116,70,114,101,115,104,65,116,116,114,73,110,102,111,40,41,0,0,0,0,0,100,101,102,97,117,108,116,47,102,105,120,101,100,32,118,97,108,117,101,32,111,110,32,97,110,32,97,116,116,114,105,98,117,116,101,32,117,115,101,32,119,97,115,32,110,111,116,32,112,114,101,99,111,109,112,117,116,101,100,0,0,0,0,0,99,97,108,108,105,110,103,32,120,109,108,83,99,104,101,109,97,67,111,112,121,86,97,108,117,101,40,41,0,0,0,0,99,97,108,108,108,105,110,103,32,120,109,108,78,101,119,80,114,111,112,40,41,0,0,0,112,37,100,0,0,0,0,0,99,111,117,108,100,32,110,111,116,32,99,111,109,112,117,116,101,32,97,32,110,115,32,112,114,101,102,105,120,32,102,111,114,32,97,32,100,101,102,97,117,108,116,47,102,105,120,101,100,32,97,116,116,114,105,98,117,116,101,0,0,0,0,0,99,97,108,108,105,110,103,32,120,109,108,83,99,104,101,109,97,83,116,114,101,97,109,86,97,108,105,100,97,116,101,83,105,109,112,108,101,84,121,112,101,86,97,108,117,101,40,41,0,0,0,0,0,0,0,0,84,104,101,32,97,116,116,114,105,98,117,116,101,32,39,37,115,39,32,105,115,32,114,101,113,117,105,114,101,100,32,98,117,116,32,109,105,115,115,105,110,103,0,0,0,0,0,0,84,104,101,32,118,97,108,117,101,32,39,37,115,39,32,100,111,101,115,32,110,111,116,32,109,97,116,99,104,32,116,104,101,32,102,105,120,101,100,32,118,97,108,117,101,32,99,111,110,115,116,114,97,105,110,116,32,39,37,115,39,0,0,0,78,111,32,109,97,116,99,104,105,110,103,32,103,108,111,98,97,108,32,97,116,116,114,105,98,117,116,101,32,100,101,99,108,97,114,97,116,105,111,110,32,97,118,97,105,108,97,98,108,101,44,32,98,117,116,32,100,101,109,97,110,100,101,100,32,98,121,32,116,104,101,32,115,116,114,105,99,116,32,119,105,108,100,99,97,114,100,0,35,35,0,0,0,0,0,0,97,108,108,111,99,97,116,105,110,103,32,97,116,116,114,105,98,117,116,101,32,105,110,102,111,32,108,105,115,116,0,0,114,101,45,97,108,108,111,99,97,116,105,110,103,32,97,116,116,114,105,98,117,116,101,32,105,110,102,111,32,108,105,115,116,0,0,0,0,0,0,0,120,109,108,83,99,104,101,109,97,71,101,116,70,114,101,115,104,65,116,116,114,73,110,102,111,0,0,0,0,0,0,0,97,116,116,114,32,105,110,102,111,32,110,111,116,32,99,108,101,97,114,101,100,0,0,0,99,114,101,97,116,105,110,103,32,110,101,119,32,97,116,116,114,105,98,117,116,101,32,105,110,102,111,0,0,0,0,0,120,109,108,83,99,104,101,109,97,88,80,97,116,104,69,118,97,108,117,97,116,101,0,0,99,97,108,108,105,110,103,32,120,109,108,83,116,114,101,97,109,80,117,115,104,40,41,0,97,108,108,111,99,97,116,105,110,103,32,116,104,101,32,115,116,97,116,101,32,111,98,106,101,99,116,32,104,105,115,116,111,114,121,0,0,0,0,0,114,101,45,97,108,108,111,99,97,116,105,110,103,32,116,104,101,32,115,116,97,116,101,32,111,98,106,101,99,116,32,104,105,115,116,111,114,121,0,0,97,108,108,111,99,97,116,105,110,103,32,97,110,32,73,68,67,32,115,116,97,116,101,32,111,98,106,101,99,116,0,0,120,109,108,83,99,104,101,109,97,73,68,67,65,100,100,83,116,97,116,101,79,98,106,101,99,116,0,0,0,0,0,0,102,97,105,108,101,100,32,116,111,32,99,114,101,97,116,101,32,97,110,32,88,80,97,116,104,32,118,97,108,105,100,97,116,105,111,110,32,99,111,110,116,101,120,116,0,0,0,0,78,111,32,109,97,116,99,104,105,110,103,32,100,101,99,108,97,114,97,116,105,111,110,32,97,118,97,105,108,97,98,108,101,0,0,0,0,0,0,0,84,104,101,32,101,108,101,109,101,110,116,32,100,101,99,108,97,114,97,116,105,111,110,32,105,115,32,97,98,115,116,114,97,99,116,0,0,0,0,0,120,109,108,83,99,104,101,109,97,86,97,108,105,100,97,116],"i8",ALLOC_NONE,Runtime.GLOBAL_BASE+136048),
	allocate([101,69,108,101,109,68,101,99,108,0,0,0,0,0,0,0,99,97,108,108,105,110,103,32,120,109,108,83,99,104,101,109,97,86,67,104,101,99,107,67,86,67,83,105,109,112,108,101,84,121,112,101,40,41,32,116,111,32,118,97,108,105,100,97,116,101,32,116,104,101,32,97,116,116,114,105,98,117,116,101,32,39,120,115,105,58,110,105,108,39,0,0,0,0,0,0,84,104,101,32,101,108,101,109,101,110,116,32,105,115,32,110,111,116,32,39,110,105,108,108,97,98,108,101,39,0,0,0,84,104,101,32,101,108,101,109,101,110,116,32,99,97,110,110,111,116,32,98,101,32,39,110,105,108,108,101,100,39,32,98,101,99,97,117,115,101,32,116,104,101,114,101,32,105,115,32,97,32,102,105,120,101,100,32,118,97,108,117,101,32,99,111,110,115,116,114,97,105,110,116,32,100,101,102,105,110,101,100,32,102,111,114,32,105,116,0,99,97,108,108,105,110,103,32,120,109,108,83,99,104,101,109,97,80,114,111,99,101,115,115,88,83,73,84,121,112,101,40,41,32,116,111,32,112,114,111,99,101,115,115,32,116,104,101,32,97,116,116,114,105,98,117,116,101,32,39,120,115,105,58,116,121,112,101,39,0,0,0,120,109,108,83,99,104,101,109,97,73,68,67,82,101,103,105,115,116,101,114,77,97,116,99,104,101,114,115,0,0,0,0,84,104,101,32,99,104,97,105,110,32,111,102,32,73,68,67,32,109,97,116,99,104,101,114,115,32,105,115,32,101,120,112,101,99,116,101,100,32,116,111,32,98,101,32,101,109,112,116,121,0,0,0,0,0,0,0,67,111,117,108,100,32,110,111,116,32,102,105,110,100,32,97,110,32,97,117,103,109,101,110,116,101,100,32,73,68,67,32,105,116,101,109,32,102,111,114,32,97,110,32,73,68,67,32,100,101,102,105,110,105,116,105,111,110,0,0,0,0,0,0,97,108,108,111,99,97,116,105,110,103,32,97,110,32,73,68,67,32,109,97,116,99,104,101,114,0,0,0,0,0,0,0,120,109,108,83,99,104,101,109,97,86,97,108,105,100,97,116,101,69,108,101,109,101,110,116,66,121,68,101,99,108,97,114,97,116,105,111,110,0,0,0,99,97,108,108,105,110,103,32,120,109,108,83,99,104,101,109,97,81,78,97,109,101,69,120,112,97,110,100,40,41,32,116,111,32,118,97,108,105,100,97,116,101,32,116,104,101,32,97,116,116,114,105,98,117,116,101,32,39,120,115,105,58,116,121,112,101,39,0,0,0,0,0,84,104,101,32,81,78,97,109,101,32,118,97,108,117,101,32,39,37,115,39,32,111,102,32,116,104,101,32,120,115,105,58,116,121,112,101,32,97,116,116,114,105,98,117,116,101,32,100,111,101,115,32,110,111,116,32,114,101,115,111,108,118,101,32,116,111,32,97,32,116,121,112,101,32,100,101,102,105,110,105,116,105,111,110,0,0,0,0,84,104,101,32,116,121,112,101,32,100,101,102,105,110,105,116,105,111,110,32,39,37,115,39,44,32,115,112,101,99,105,102,105,101,100,32,98,121,32,120,115,105,58,116,121,112,101,44,32,105,115,32,98,108,111,99,107,101,100,32,111,114,32,110,111,116,32,118,97,108,105,100,108,121,32,100,101,114,105,118,101,100,32,102,114,111,109,32,116,104,101,32,116,121,112,101,32,100,101,102,105,110,105,116,105,111,110,32,111,102,32,116,104,101,32,101,108,101,109,101,110,116,32,100,101,99,108,97,114,97,116,105,111,110,0,0,120,109,108,83,99,104,101,109,97,84,121,112,101,70,105,120,117,112,0,0,0,0,0,0,116,104,105,115,32,102,117,110,99,116,105,111,110,32,110,101,101,100,115,32,97,32,112,97,114,115,101,114,32,99,111,110,116,101,120,116,0,0,0,0,120,109,108,83,99,104,101,109,97,70,105,120,117,112,83,105,109,112,108,101,84,121,112,101,83,116,97,103,101,84,119,111,0,0,0,0,0,0,0,0,109,105,115,115,105,110,103,32,98,97,115,101,84,121,112,101,0,0,0,0,0,0,0,0,73,116,32,105,115,32,97,110,32,101,114,114,111,114,32,102,111,114,32,98,111,116,104,32,39,108,101,110,103,116,104,39,32,97,110,100,32,101,105,116,104,101,114,32,111,102,32,39,109,105,110,76,101,110,103,116,104,39,32,111,114,32,39,109,97,120,76,101,110,103,116,104,39,32,116,111,32,98,101,32,115,112,101,99,105,102,105,101,100,32,111,110,32,116,104,101,32,115,97,109,101,32,116,121,112,101,32,100,101,102,105,110,105,116,105,111,110,0,0,0,73,116,32,105,115,32,97,110,32,101,114,114,111,114,32,102,111,114,32,98,111,116,104,32,39,37,115,39,32,97,110,100,32,39,37,115,39,32,116,111,32,98,101,32,115,112,101,99,105,102,105,101,100,32,111,110,32,116,104,101,32,115,97,109,101,32,116,121,112,101,32,100,101,102,105,110,105,116,105,111,110,0,0,0,0,0,0,0,84,104,101,32,98,97,115,101,32,116,121,112,101,39,115,32,102,97,99,101,116,32,105,115,32,39,102,105,120,101,100,39,44,32,116,104,117,115,32,116,104,101,32,118,97,108,117,101,32,109,117,115,116,32,110,111,116,32,100,105,102,102,101,114,0,0,0,0,0,0,0,0,84,104,101,32,39,119,104,105,116,101,115,112,97,99,101,39,32,118,97,108,117,101,32,104,97,115,32,116,111,32,98,101,32,101,113,117,97,108,32,116,111,32,111,114,32,115,116,114,111,110,103,101,114,32,116,104,97,110,32,116,104,101,32,39,119,104,105,116,101,115,112,97,99,101,39,32,118,97,108,117,101,32,111,102,32,116,104,101,32,98,97,115,101,32,116,121,112,101,0,0,0,0,0,0,100,101,114,105,118,105,110,103,32,102,97,99,101,116,115,44,32,99,114,101,97,116,105,110,103,32,97,32,102,97,99,101,116,32,108,105,110,107,0,0,120,109,108,83,99,104,101,109,97,68,101,114,105,118,101,65,110,100,86,97,108,105,100,97,116,101,70,97,99,101,116,115,0,0,0,0,0,0,0,0,97,110,32,101,114,114,111,114,32,111,99,99,117,114,101,100,0,0,0,0,0,0,0,0,39,32,104,97,115,32,116,111,32,98,101,0,0,0,0,0,32,101,113,117,97,108,32,116,111,0,0,0,0,0,0,0,32,103,114,101,97,116,101,114,32,116,104,97,110,0,0,0,32,108,101,115,115,32,116,104,97,110,0,0,0,0,0,0,32,111,114,32,101,113,117,97,108,32,116,111,0,0,0,0,39,32,111,102,32,116,104,101,32,98,97,115,101,32,116,121,112,101,0,0,0,0,0,0,37,115,58,32,0,0,0,0,97,116,111,109,105,99,32,116,121,112,101,32,39,120,115,58,0,0,0,0,0,0,0,0,108,105,115,116,32,116,121,112,101,32,39,120,115,58,0,0,117,110,105,111,110,32,116,121,112,101,32,39,120,115,58,0,115,105,109,112,108,101,32,116,121,112,101,32,39,120,115,58,0,0,0,0,0,0,0,0,108,111,99,97,108,32,0,0,97,116,111,109,105,99,32,116,121,112,101,0,0,0,0,0,108,105,115,116,32,116,121,112,101,0,0,0,0,0,0,0,117,110,105,111,110,32,116,121,112,101,0,0,0,0,0,0,115,105,109,112,108,101,32,116,121,112,101,0,0,0,0,0,99,111,109,112,108,101,120,32,116,121,112,101,0,0,0,0,97,116,116,114,105,98,117,116,101,32,117,115,101,32,0,0,40,117,110,107,110,111,119,110,41,0,0,0,0,0,0,0,97,116,116,114,105,98,117,116,101,32,100,101,99,108,46,0,101,108,101,109,101,110,116,32,100,101,99,108,46,0,0,0,117,110,105,113,117,101,32,39,0,0,0,0,0,0,0,0,107,101,121,32,39,0,0,0,107,101,121,82,101,102,32,39,0,0,0,0,0,0,0,0,32,119,105,108,100,99,97,114,100,0,0,0,0,0,0,0,102,97,99,101,116,32,39,0,109,111,100,101,108,32,103,114,111,117,112,32,100,101,102,46,0,0,0,0,0,0,0,0,44,32,97,116,116,114,105,98,117,116,101,32,39,0,0,0,115,107,105,112,0,0,0,0,108,97,120,0,0,0,0,0,115,116,114,105,99,116,0,0,105,110,118,97,108,105,100,32,112,114,111,99,101,115,115,32,99,111,110,116,101,110,116,115,0,0,0,0,0,0,0,0,73,110,116,101,114,110,97,108,32,101,114,114,111,114,58,32,120,109,108,83,99,104,101,109,97,67,114,101,97,116,101,86,67,116,120,116,79,110,80,67,116,120,116,44,32,102,97,105,108,101,100,32,116,111,32,99,114,101,97,116,101,32,97,32,116,101,109,112,46,32,118,97,108,105,100,97,116,105,111,110,32,99,111,110,116,101,120,116,46,10,0,0,0,0,0,0,120,109,108,83,99,104,101,109,97,67,104,101,99,107,67,79,83,83,84,82,101,115,116,114,105,99,116,115,0,0,0,0,103,105,118,101,110,32,116,121,112,101,32,105,115,32,110,111,116,32,97,32,117,115,101,114,45,100,101,114,105,118,101,100,32,115,105,109,112,108,101,84,121,112,101,0,0,0,0,0,84,104,101,32,98,97,115,101,32,116,121,112,101,32,39,37,115,39,32,105,115,32,110,111,116,32,97,110,32,97,116,111,109,105,99,32,115,105,109,112,108,101,32,116,121,112,101,0,84,104,101,32,102,105,110,97,108,32,111,102,32,105,116,115,32,98,97,115,101,32,116,121,112,101,32,39,37,115,39,32,109,117,115,116,32,110,111,116,32,99,111,110,116,97,105,110,32,39,114,101,115,116,114,105,99,116,105,111,110,39,0,0,102,97,105,108,101,100,32,116,111,32,103,101,116,32,112,114,105,109,105,116,105,118,101,32,116,121,112,101,0,0,0,0,102,97,105,108,101,100,32,116,111,32,101,118,97,108,117,97,116,101,32,116,104,101,32,105,116,101,109,32,116,121,112,101,0,0,0,0,0,0,0,0,84,104,101,32,105,116,101,109,32,116,121,112,101,32,39,37,115,39,32,100,111,101,115,32,110,111,116,32,104,97,118,101,32,97,32,118,97,114,105,101,116,121,32,111,102,32,97,116,111,109,105,99,32,111,114,32,117,110,105,111,110,0,0,0,84,104,101,32,105,116,101,109,32,116,121,112,101,32,105,115,32,97,32,117,110,105,111,110,32,116,121,112,101,44,32,98,117,116,32,116,104,101,32,109,101,109,98,101,114,32,116,121,112,101,32,39,37,115,39,32,111,102,32,116,104,105,115,32,105,116,101,109,32,116,121,112,101,32,105,115,32,110,111,116,32,97,116,111,109,105,99,0,84,104,101,32,102,105,110,97,108,32,111,102,32,105,116,115,32,105,116,101,109,32,116,121,112,101,32,39,37,115,39,32,109,117,115,116,32,110,111,116,32,99,111,110,116,97,105,110,32,39,108,105,115,116,39,0,84,104,101,32,98,97,115,101,32,116,121,112,101,32,39,37,115,39,32,109,117,115,116,32,98,101,32,97,32,108,105,115,116,32,116,121,112,101,0,0,84,104,101,32,39,102,105,110,97,108,39,32,111,102,32,116,104,101,32,98,97,115,101,32,116,121,112,101,32,39,37,115,39,32,109,117,115,116,32,110,111,116,32,99,111,110,116,97,105,110,32,39,114,101,115,116,114,105,99,116,105,111,110,39,0,0,0,0,0,0,0,0,102,97,105,108,101,100,32,116,111,32,101,118,97,108,32,116,104,101,32,105,116,101,109,32,116,121,112,101,32,111,102,32,97,32,98,97,115,101,32,116,121,112,101,0,0,0,0,0,84,104,101,32,105,116,101,109,32,116,121,112,101,32,39,37,115,39,32,105,115,32,110,111,116,32,118,97,108,105,100,108,121,32,100,101,114,105,118,101,100,32,102,114,111,109,32,116,104,101,32,105,116,101,109,32,116,121,112,101,32,39,37,115,39,32,111,102,32,116,104,101,32,98,97,115,101,32,116,121,112,101,32,39,37,115,39,0,84,104,101,32,109,101,109,98,101,114,32,116,121,112,101,32,39,37,115,39,32,105,115,32,110,101,105,116,104,101,114,32,97,110,32,97,116,111,109,105,99,44,32,110,111,114,32,97,32,108,105,115,116,32,116,121,112,101,0,0,0,0,0,0,84,104,101,32,39,102,105,110,97,108,39,32,111,102,32,109,101,109,98,101,114,32,116,121,112,101,32,39,37,115,39,32,99,111,110,116,97,105,110,115,32,39,117,110,105,111,110,39,0,0,0,0,0,0,0,0,78,111,32,102,97,99,101,116,115,32,97,108,108,111,119,101,100,0,0,0,0,0,0,0,84,104,101,32,98,97,115,101,32,116,121,112,101,32,39,37,115,39,32,105,115,32,110,111,116,32,97,32,117,110,105,111,110,32,116,121,112,101,0,0,84,104,101,32,39,102,105,110,97,108,39,32,111,102,32,105,116,115,32,98,97,115,101,32,116,121,112,101,32,39,37,115,39,32,109,117,115,116,32,110,111,116,32,99,111,110,116,97,105,110,32,39,114,101,115,116,114,105,99,116,105,111,110,39,0,0,0,0,0,0,0,0,100,105,102,102,101,114,101,110,116,32,110,117,109,98,101,114,32,111,102,32,109,101,109,98,101,114,32,116,121,112,101,115,32,105,110,32,98,97,115,101,0,0,0,0,0,0,0,0,84,104,101,32,109,101,109,98,101,114,32,116,121,112,101,32,37,115,32,105,115,32,110,111,116,32,118,97,108,105,100,108,121,32,100,101,114,105,118,101,100,32,102,114,111,109,32,105,116,115,32,99,111,114,114,101,115,112,111,110,100,105,110,103,32,109,101,109,98,101,114,32,116,121,112,101,32,37,115,32,111,102,32,116,104,101,32,98,97,115,101,32,116,121,112,101,32,37,115,0,0,0,0,0,37,115,58,32,84,104,101,32,102,97,99,101,116,32,39,37,115,39,32,105,115,32,110,111,116,32,97,108,108,111,119,101,100,46,10,0,0,0,0,0,37,115,58,32,84,104,101,32,102,97,99,101,116,32,39,37,115,39,32,105,115,32,110,111,116,32,97,108,108,111,119,101,100,32,111,110,32,116,121,112,101,115,32,100,101,114,105,118,101,100,32,102,114,111,109,32,116,104,101,32,116,121,112,101,32,37,115,46,10,0,0,0,78,111,32,98,97,115,101,32,116,121,112,101,32,101,120,105,115,116,101,110,116,0,0,0,84,104,101,32,98,97,115,101,32,116,121,112,101,32,39,37,115,39,32,105,115,32,110,111,116,32,97,32,115,105,109,112,108,101,32,116,121,112,101,0,65,32,116,121,112,101,44,32,100,101,114,105,118,101,100,32,98,121,32,108,105,115,116,32,111,114,32,117,110,105,111,110,44,32,109,117,115,116,32,104,97,118,101,32,116,104,101,32,115,105,109,112,108,101,32,117,114,45,116,121,112,101,32,100,101,102,105,110,105,116,105,111,110,32,97,115,32,98,97,115,101,32,116,121,112,101,44,32,110,111,116,32,39,37,115,39,0,0,0,0,0,0,0,0,84,104,101,32,118,97,114,105,101,116,121,32,105,115,32,97,98,115,101,110,116,0,0,0,97,108,108,111,99,97,116,105,110,103,32,97,32,116,121,112,101,32,108,105,110,107,0,0,120,109,108,83,99,104,101,109,97,70,105,120,117,112,67,111,109,112,108,101,120,84,121,112,101,0,0,0,0,0,0,0,73,110,116,101,114,110,97,108,32,101,114,114,111,114,58,32,120,109,108,83,99,104,101,109,97,84,121,112,101,70,105,120,117,112,44,32,99,111,109,112,108,101,120,32,116,121,112,101,32,39,37,115,39,58,32,116,104,101,32,60,115,105,109,112,108,101,67,111,110,116,101,110,116,62,60,114,101,115,116,114,105,99,116,105,111,110,62,32,105,115,32,109,105,115,115,105,110,103,32,97,32,60,115,105,109,112,108,101,84,121,112,101,62,32,99,104,105,108,100,44,32,98,117,116,32,119,97,115,32,110,111,116,32,99,97,116,99,104,101,100,32,98,121,32,120,109,108,83,99,104,101,109,97,67,104,101,99,107,83,82,67,67,84,40,41,0,0,0,73,110,116,101,114,110,97,108,32,101,114,114,111,114,58,32,120,109,108,83,99,104,101,109,97,84,121,112,101,70,105,120,117,112,44,32,99,111,109,112,108,101,120,32,116,121,112,101,32,39,37,115,39,58,32,116,104,101,32,60,101,120,116,101,110,115,105,111,110,62,101,100,32,98,97,115,101,32,116,121,112,101,32,105,115,32,97,32,99,111,109,112,108,101,120,32,116,121,112,101,32,119,105,116,104,32,110,111,32,115,105,109,112,108,101,32,99,111,110,116,101,110,116,32,116,121,112,101,0,0,0,0,0,0,0,0,73,110,116,101,114,110,97,108,32,101,114,114,111,114,58,32,120,109,108,83,99,104,101,109,97,84,121,112,101,70,105,120,117,112,44,32,99,111,109,112,108,101,120,32,116,121,112,101,32,39,37,115,39,32,119,105,116,104,32,60,115,105,109,112,108,101,67,111,110,116,101,110,116,62,58,32,117,110,104,97,110,100,108,101,100,32,100,101,114,105,118,97,116,105,111,110,32,99,97,115,101,0,0,0,84,104,101,32,116,121,112,101,32,104,97,115,32,97,110,32,39,97,108,108,39,32,109,111,100,101,108,32,103,114,111,117,112,32,105,110,32,105,116,115,32,123,99,111,110,116,101,110,116,32,116,121,112,101,125,32,97,110,100,32,116,104,117,115,32,99,97,110,110,111,116,32,98,101,32,100,101,114,105,118,101,100,32,102,114,111,109,32,97,32,110,111,110,45,101,109,112,116,121,32,116,121,112,101,44,32,115,105,110,99,101,32,116,104,105,115,32,119,111,117,108,100,32,112,114,111,100,117,99,101,32,97,32,39,115,101,113,117,101,110,99,101,39,32,109,111,100,101,108,32,103,114,111,117,112,32,99,111,110,116,97,105,110,105,110,103,32,116,104,101,32,39,97,108,108,39,32,109,111,100,101,108,32,103,114,111,117,112,59,32,39,97,108,108,39,32,109,111,100,101,108,32,103,114,111,117,112,115,32,97,114,101,32,110,111,116,32,97,108,108,111,119,101,100,32,116,111,32,97,112,112,101,97,114,32,105,110,115,105,100,101,32,111,116,104,101,114,32,109,111,100,101,108,32,103,114,111,117,112,115,0,0,0,0,65,32,116,121,112,101,32,99,97,110,110,111,116,32,98,101,32,100,101,114,105,118,101,100,32,98,121,32,101,120,116,101,110,115,105,111,110,32,102,114,111,109,32,97,32,116,121,112,101,32,119,104,105,99,104,32,104,97,115,32,97,110,32,39,97,108,108,39,32,109,111,100,101,108,32,103,114,111,117,112,32,105,110,32,105,116,115,32,123,99,111,110,116,101,110,116,32,116,121,112,101,125,44,32,115,105,110,99,101,32,116,104,105,115,32,119,111,117,108,100,32,112,114,111,100,117,99,101,32,97,32,39,115,101,113,117,101,110,99,101,39,32,109,111,100,101,108,32,103,114,111,117,112,32,99,111,110,116,97,105,110,105,110,103,32,116,104,101,32,39,97,108,108,39,32,109,111,100,101,108,32,103,114,111,117,112,59,32,39,97,108,108,39,32,109,111,100,101,108,32,103,114,111,117,112,115,32,97,114,101,32,110,111,116,32,97,108,108,111,119,101,100,32,116,111,32,97,112,112,101,97,114,32,105,110,115,105,100,101,32,111,116,104,101,114,32,109,111,100,101,108,32,103,114,111,117,112,115,0,0,0,0,0,0,84,104,101,32,98,97,115,101,32,116,121,112,101,32,109,117,115,116,32,98,101,32,97,32,99,111,109,112,108,101,120,32,116,121,112,101,0,0,0,0,84,104,101,32,39,102,105,110,97,108,39,32,111,102,32,116,104,101,32,98,97,115,101,32,116,121,112,101,32,100,101,102,105,110,105,116,105,111,110,32,99,111,110,116,97,105,110,115,32,39,114,101,115,116,114,105,99,116,105,111,110,39,0,0,84,104,101,32,123,99,111,110,116,101,110,116,32,116,121,112,101,125,32,37,115,32,105,115,32,110,111,116,32,118,97,108,105,100,108,121,32,100,101,114,105,118,101,100,32,102,114,111,109,32,116,104,101,32,98,97,115,101,32,116,121,112,101,39,115,32,123,99,111,110,116,101,110,116,32,116,121,112,101,125,32,37,115,0,0,0,0,0,84,104,101,32,99,111,110,116,101,110,116,32,116,121,112,101,32,111,102,32,116,104,101,32,98,97,115,101,32,116,121,112,101,32,109,117,115,116,32,98,101,32,101,105,116,104,101,114,32,97,32,115,105,109,112,108,101,32,116,121,112,101,32,111,114,32,39,109,105,120,101,100,39,32,97,110,100,32,97,110,32,101,109,112,116,105,97,98,108,101,32,112,97,114,116,105,99,108,101,0,0,0,0,0,84,104,101,32,99,111,110,116,101,110,116,32,116,121,112,101,32,111,102,32,116,104,101,32,98,97,115,101,32,116,121,112,101,32,109,117,115,116,32,98,101,32,101,105,116,104,101,114,32,101,109,112,116,121,32,111,114,32,39,109,105,120,101,100,39,32,40,111,114,32,39,101,108,101,109,101,110,116,115,45,111,110,108,121,39,41,32,97,110,100,32,97,110,32,101,109,112,116,105,97,98,108,101,32,112,97,114,116,105,99,108,101,0,0,0,0,0,0,0,0,73,102,32,116,104,101,32,99,111,110,116,101,110,116,32,116,121,112,101,32,105,115,32,39,109,105,120,101,100,39,44,32,116,104,101,110,32,116,104,101,32,99,111,110,116,101,110,116,32,116,121,112,101,32,111,102,32,116,104,101,32,98,97,115,101,32,116,121,112,101,32,109,117,115,116,32,97,108,115,111,32,98,101,32,39,109,105,120,101,100,39,0,0,0,0,0,84,104,101,32,116,121,112,101,32,105,115,32,110,111,116,32,97,32,118,97,108,105,100,32,114,101,115,116,114,105,99,116,105,111,110,32,111,102,32,105,116,115,32,98,97,115,101,32,116,121,112,101,0,0,0,0,84,104,101,32,39,111,112,116,105,111,110,97,108,39,32,97,116,116,114,105,98,117,116,101,32,117,115,101,32,105,115,32,105,110,99,111,110,115,105,115,116,101,110,116,32,119,105,116,104,32,116,104,101,32,99,111,114,114,101,115,112,111,110,100,105,110,103,32,39,114,101,113,117,105,114,101,100,39,32,97,116,116,114,105,98,117,116,101,32,117,115,101,32,111,102,32,116,104,101,32,37,115,32,37,115,0,0,0,0,0,0,0,98,97,115,101,0,0,0,0,114,101,100,101,102,105,110,101,100,0,0,0,0,0,0,0,84,104,101,32,97,116,116,114,105,98,117,116,101,32,100,101,99,108,97,114,97,116,105,111,110,39,115,32,37,115,32,105,115,32,110,111,116,32,118,97,108,105,100,108,121,32,100,101,114,105,118,101,100,32,102,114,111,109,32,116,104,101,32,99,111,114,114,101,115,112,111,110,100,105,110,103,32,37,115,32,111,102,32,116,104,101,32,97,116,116,114,105,98,117,116,101,32,100,101,99,108,97,114,97,116,105,111,110,32,105,110,32,116,104,101,32,37,115,32,37,115,0,0,0,0,0,0,0,84,104,101,32,101,102,102,101,99,116,105,118,101,32,118,97,108,117,101,32,99,111,110,115,116,114,97,105,110,116,32,111,102,32,116,104,101,32,97,116,116,114,105,98,117,116,101,32,117,115,101,32,105,115,32,105,110,99,111,110,115,105,115,116,101,110,116,32,119,105,116,104,32,105,116,115,32,99,111,114,114,101,115,112,111,110,100,101,110,116,32,105,110,32,116,104,101,32,37,115,32,37,115,0,78,101,105,116,104,101,114,32,97,32,109,97,116,99,104,105,110,103,32,97,116,116,114,105,98,117,116,101,32,117,115,101,44,32,110,111,114,32,97,32,109,97,116,99,104,105,110,103,32,119,105,108,100,99,97,114,100,32,101,120,105,115,116,115,32,105,110,32,116,104,101,32,37,115,32,37,115,0,0,0,65,32,109,97,116,99,104,105,110,103,32,97,116,116,114,105,98,117,116,101,32,117,115,101,32,102,111,114,32,116,104,101,32,39,114,101,113,117,105,114,101,100,39,32,37,115,32,111,102,32,116,104,101,32,37,115,32,37,115,32,105,115,32,109,105,115,115,105,110,103,0,0,84,104,101,32,37,115,32,104,97,115,32,97,110,32,97,116,116,114,105,98,117,116,101,32,119,105,108,100,99,97,114,100,44,32,98,117,116,32,116,104,101,32,37,115,32,37,115,32,39,37,115,39,32,100,111,101,115,32,110,111,116,32,104,97,118,101,32,111,110,101,0,0,84,104,101,32,97,116,116,114,105,98,117,116,101,32,119,105,108,100,99,97,114,100,32,105,115,32,110,111,116,32,97,32,118,97,108,105,100,32,115,117,98,115,101,116,32,111,102,32,116,104,101,32,119,105,108,100,99,97,114,100,32,105,110,32,116,104,101,32,37,115,32,37,115,32,39,37,115,39,0,0,84,104,101,32,123,112,114,111,99,101,115,115,32,99,111,110,116,101,110,116,115,125,32,111,102,32,116,104,101,32,97,116,116,114,105,98,117,116,101,32,119,105,108,100,99,97,114,100,32,105,115,32,119,101,97,107,101,114,32,116,104,97,110,32,116,104,101,32,111,110,101,32,105,110,32,116,104,101,32,37,115,32,37,115,32,39,37,115,39,0,0,0,0,0,0,0,58,32,0,0,0,0,0,0,84,104,101,32,39,102,105,110,97,108,39,32,111,102,32,116,104,101,32,98,97,115,101,32,116,121,112,101,32,100,101,102,105,110,105,116,105,111,110,32,99,111,110,116,97,105,110,115,32,39,101,120,116,101,110,115,105,111,110,39,0,0,0,0,84,104,101,32,99,111,110,116,101,110,116,32,116,121,112,101,32,109,117,115,116,32,115,112,101,99,105,102,121,32,97,32,112,97,114,116,105,99,108,101,0,0,0,0,0,0,0,0,84,104,101,32,99,111,110,116,101,110,116,32,116,121,112,101,32,111,102,32,98,111,116,104,44,32,116,104,101,32,116,121,112,101,32,97,110,100,32,105,116,115,32,98,97,115,101,32,116,121,112,101,44,32,109,117,115,116,32,101,105,116,104,101,114,32,39,109,105,120,101,100,39,32,111,114,32,39,101,108,101,109,101,110,116,45,111,110,108,121,39,0,0,0,0,0,84,104,101,32,99,111,110,116,101,110,116,32,116,121,112,101,32,109,117,115,116,32,98,101,32,116,104,101,32,115,105,109,112,108,101,32,98,97,115,101,32,116,121,112,101,0,0,0,73,102,32,116,104,101,32,98,97,115,101,32,116,121,112,101,32,105,115,32,97,32,115,105,109,112,108,101,32,116,121,112,101,44,32,116,104,101,32,100,101,114,105,118,97,116,105,111,110,32,109,101,116,104,111,100,32,109,117,115,116,32,98,101,32,39,101,120,116,101,110,115,105,111,110,39,0,0,0,0,68,117,112,108,105,99,97,116,101,32,37,115,0,0,0,0,84,104,101,114,101,32,109,117,115,116,32,110,111,116,32,101,120,105,115,116,32,109,111,114,101,32,116,104,97,110,32,111,110,101,32,97,116,116,114,105,98,117,116,101,32,100,101,99,108,97,114,97,116,105,111,110,32,111,102,32,116,121,112,101,32,39,120,115,58,73,68,39,32,40,111,114,32,100,101,114,105,118,101,100,32,102,114,111,109,32,39,120,115,58,73,68,39,41,46,32,84,104,101,32,37,115,32,118,105,111,108,97,116,101,115,32,116,104,105,115,32,99,111,110,115,116,114,97,105,110,116,0,0,0,0,0,73,110,116,101,114,110,97,108,32,101,114,114,111,114,58,32,120,109,108,83,99,104,101,109,97,73,116,101,109,76,105,115,116,82,101,109,111,118,101,44,32,105,110,100,101,120,32,101,114,114,111,114,46,10,0,0,120,109,108,83,99,104,101,109,97,70,105,120,117,112,84,121,112,101,65,116,116,114,105,98,117,116,101,85,115,101,115,0,110,111,32,98,97,115,101,32,116,121,112,101,0,0,0,0,102,97,105,108,101,100,32,116,111,32,101,120,112,97,110,100,32,97,116,116,114,105,98,117,116,101,115,0,0,0,0,0,84,104,101,32,117,110,105,111,110,32,111,102,32,116,104,101,32,119,105,108,99,97,114,100,32,105,115,32,110,111,116,32,101,120,112,114,101,115,115,105,98,108,101,46,10,0,0,0,99,114,101,97,116,105,110,103,32,119,105,108,100,99,97,114,100,32,110,97,109,101,115,112,97,99,101,32,99,111,110,115,116,114,97,105,110,116,0,0,120,109,108,83,99,104,101,109,97,69,120,112,97,110,100,65,116,116,114,105,98,117,116,101,71,114,111,117,112,82,101,102,115,0,0,0,0,0,0,0,117,110,101,120,112,101,99,116,101,100,32,97,116,116,114,32,112,114,111,104,105,98,105,116,105,111,110,32,102,111,117,110,100,0,0,0,0,0,0,0,83,107,105,112,112,105,110,103,32,112,111,105,110,116,108,101,115,115,32,97,116,116,114,105,98,117,116,101,32,117,115,101,32,112,114,111,104,105,98,105,116,105,111,110,32,39,37,115,39,44,32,115,105,110,99,101,32,97,32,99,111,114,114,101,115,112,111,110,100,105,110,103,32,97,116,116,114,105,98,117,116,101,32,117,115,101,32,101,120,105,115,116,115,32,97,108,114,101,97,100,121,32,105,110,32,116,104,101,32,116,121,112,101,32,100,101,102,105,110,105,116,105,111,110,0,0,0,0,84,104,101,32,105,110,116,101,114,115,101,99,116,105,111,110,32,111,102,32,116,104,101,32,119,105,108,99,97,114,100,32,105,115,32,110,111,116,32,101,120,112,114,101,115,115,105,98,108,101,46,10,0,0,0,0,97,100,100,105,110,103,32,119,105,108,100,99,97,114,100,0,97,108,108,111,99,97,116,105,110,103,32,109,111,100,101,108,32,103,114,111,117,112,32,99,111,109,112,111,110,101,110,116,0,0,0,0,0,0,0,0,97,108,108,111,99,97,116,105,110,103,32,112,97,114,116,105,99,108,101,32,99,111,109,112,111,110,101,110,116,0,0,0,120,109,108,83,99,104,101,109,97,70,105,120,117,112,83,105,109,112,108,101,84,121,112,101,83,116,97,103,101,79,110,101,0,0,0,0,0,0,0,0,108,105,115,116,32,116,121,112,101,32,104,97,115,32,110,111,32,105,116,101,109,45,116,121,112,101,32,97,115,115,105,103,110,101,100,0,0,0,0,0,117,110,105,111,110,32,116,121,112,101,32,104,97,115,32,110,111,32,109,101,109,98,101,114,45,116,121,112,101,115,32,97,115,115,105,103,110,101,100,0,116,121,112,101,32,104,97,115,32,110,111,32,98,97,115,101,45,116,121,112,101,32,97,115,115,105,103,110,101,100,0,0,97,108,108,111,99,97,116,105,110,103,32,116,121,112,101,0,97,108,108,111,99,97,116,105,110,103,32,114,101,100,101,102,105,110,105,116,105,111,110,32,105,110,102,111,0,0,0,0,73,102,32,117,115,105,110,103,32,60,99,111,109,112,108,101,120,67,111,110,116,101,110,116,62,44,32,116,104,101,32,98,97,115,101,32,116,121,112,101,32,105,115,32,101,120,112,101,99,116,101,100,32,116,111,32,98,101,32,97,32,99,111,109,112,108,101,120,32,116,121,112,101,46,32,84,104,101,32,98,97,115,101,32,116,121,112,101,32,39,37,115,39,32,105,115,32,97,32,115,105,109,112,108,101,32,116,121,112,101,0,0,73,102,32,117,115,105,110,103,32,60,115,105,109,112,108,101,67,111,110,116,101,110,116,62,32,97,110,100,32,60,114,101,115,116,114,105,99,116,105,111,110,62,44,32,116,104,101,32,98,97,115,101,32,116,121,112,101,32,109,117,115,116,32,98,101,32,97,32,99,111,109,112,108,101,120,32,116,121,112,101,46,32,84,104,101,32,98,97,115,101,32,116,121,112,101,32,39,37,115,39,32,105,115,32,97,32,115,105,109,112,108,101,32,116,121,112,101,0,0,0,73,110,116,101,114,110,97,108,32,101,114,114,111,114,58,32,120,109,108,83,99,104,101,109,97,67,104,101,99,107,83,82,67,67,84,44,32,39,37,115,39,44,32,98,97,115,101,32,116,121,112,101,32,104,97,115,32,110,111,32,99,111,110,116,101,110,116,32,116,121,112,101,0,0,0,0,0,0,0,0,65,32,60,115,105,109,112,108,101,84,121,112,101,62,32,105,115,32,101,120,112,101,99,116,101,100,32,97,109,111,110,103,32,116,104,101,32,99,104,105,108,100,114,101,110,32,111,102,32,60,114,101,115,116,114,105,99,116,105,111,110,62,44,32,105,102,32,60,115,105,109,112,108,101,67,111,110,116,101,110,116,62,32,105,115,32,117,115,101,100,32,97,110,100,32,116,104,101,32,98,97,115,101,32,116,121,112,101,32,39,37,115,39,32,105,115,32,97,32,99,111,109,112,108,101,120,32,116,121,112,101,0,0,0,0,0,73,102,32,60,115,105,109,112,108,101,67,111,110,116,101,110,116,62,32,97,110,100,32,60,114,101,115,116,114,105,99,116,105,111,110,62,32,105,115,32,117,115,101,100,44,32,116,104,101,32,98,97,115,101,32,116,121,112,101,32,109,117,115,116,32,98,101,32,97,32,115,105,109,112,108,101,32,116,121,112,101,32,111,114,32,97,32,99,111,109,112,108,101,120,32,116,121,112,101,32,119,105,116,104,32,109,105,120,101,100,32,99,111,110,116,101,110,116,32,97,110,100,32,112,97,114,116,105,99,108,101,32,101,109,112,116,105,97,98,108,101,46,32,84,104,101,32,98,97,115,101,32,116,121,112,101,32,39,37,115,39,32,105,115,32,110,111,110,101,32,111,102,32,116,104,111,115,101,0,0,0,0,0,0,73,102,32,60,115,105,109,112,108,101,67,111,110,116,101,110,116,62,32,97,110,100,32,60,101,120,116,101,110,115,105,111,110,62,32,105,115,32,117,115,101,100,44,32,116,104,101,32,98,97,115,101,32,116,121,112,101,32,109,117,115,116,32,98,101,32,97,32,115,105,109,112,108,101,32,116,121,112,101,46,32,84,104,101,32,98,97,115,101,32,116,121,112,101,32,39,37,115,39,32,105,115,32,97,32,99,111,109,112,108,101,120,32,116,121,112,101,0,0,0,184,44,2,0,0,0,0,0,84,104,101,32,81,78,97,109,101,32,118,97,108,117,101,32,39,37,115,39,32,104,97,115,32,110,111,32,99,111,114,114,101,115,112,111,110,100,105,110,103,32,110,97,109,101,115,112,97,99,101,32,100,101,99,108,97,114,97,116,105,111,110,32,105,110,32,115,99,111,112,101,0,0,0,0,0,0,0,0,120,109,108,83,99,104,101,109,97,76,111,111,107,117,112,78,97,109,101,115,112,97,99,101,0,0,0,0,0,0,0,0,110,111,32,110,111,100,101,32,111,114,32,110,111,100,101,39,115,32,100,111,99,32,97,118,97,108,105,97,98,108,101,0,39,37,115,39,32,105,115,32,110,111,116,32,97,32,118,97,108,105,100,32,118,97,108,117,101,32,111,102,32,0,0,0,84,104,101,32,99,104,97,114,97,99,116,101,114,32,99,111,110,116,101,110,116,32,105,115,32,110,111,116,32,97,32,118,97,108,105,100,32,118,97,108,117,101,32,111,102,32,0,0,116,104,101,32,108,111,99,97,108,32,0,0,0,0,0,0,116,104,101,32,0,0,0,0,120,115,58,0,0,0,0,0,120,109,108,83,99,104,101,109,97,86,97,108,105,100,97,116,101,69,108,101,109,87,105,108,100,99,97,114,100,0,0,0,98,97,100,32,97,114,103,117,109,101,110,116,115,0,0,0,78,111,32,109,97,116,99,104,105,110,103,32,103,108,111,98,97,108,32,101,108,101,109,101,110,116,32,100,101,99,108,97,114,97,116,105,111,110,32,97,118,97,105,108,97,98,108,101,44,32,98,117,116,32,100,101,109,97,110,100,101,100,32,98,121,32,116,104,101,32,115,116,114,105,99,116,32,119,105,108,100,99,97,114,100,0,0,0,99,97,108,108,105,110,103,32,120,109,108,83,99,104,101,109,97,80,114,111,99,101,115,115,88,83,73,84,121,112,101,40,41,32,116,111,32,112,114,111,99,101,115,115,32,116,104,101,32,97,116,116,114,105,98,117,116,101,32,39,120,115,105,58,110,105,108,39,0,0,0,0,120,109,108,83,99,104,101,109,97,86,97,108,105,100,97,116,101,67,104,105,108,100,69,108,101,109,0,0,0,0,0,0,110,111,116,32,105,110,116,101,110,100,101,100,32,102,111,114,32,116,104,101,32,118,97,108,105,100,97,116,105,111,110,32,114,111,111,116,0,0,0,0,78,101,105,116,104,101,114,32,99,104,97,114,97,99,116,101,114,32,110,111,114,32,101,108,101,109,101,110,116,32,99,111,110,116,101,110,116,32,105,115,32,97,108,108,111,119,101,100,44,32,98,101,99,97,117,115,101,32,116,104,101,32,101,108,101,109,101,110,116,32,119,97,115,32,39,110,105,108,108,101,100,39,0,0,0,0,0,0,69,108,101,109,101,110,116,32,99,111,110,116,101,110,116,32,105,115,32,110,111,116,32,97,108,108,111,119,101,100,44,32,98,101,99,97,117,115,101,32,116,104,101,32,99,111,110,116,101,110,116,32,116,121,112,101,32,105,115,32,101,109,112,116,121,0,0,0,0,0,0,0,116,121,112,101,32,104,97,115,32,101,108,101,109,32,99,111,110,116,101,110,116,32,98,117,116,32,110,111,32,99,111,110,116,101,110,116,32,109,111,100,101,108,0,0,0,0,0,0,118,97,108,105,100,97,116,105,110,103,32,101,108,101,109,44,32,98,117,116,32,101,108,101,109,32,99,111,110,116,101,110,116,32,105,115,32,97,108,114,101,97,100,121,32,105,110,118,97,108,105,100,0,0,0,0,99,97,108,108,105,110,103,32,120,109,108,82,101,103,69,120,101,99,80,117,115,104,83,116,114,105,110,103,50,40,41,0,84,104,105,115,32,101,108,101,109,101,110,116,32,105,115,32,110,111,116,32,101,120,112,101,99,116,101,100,0,0,0,0,69,108,101,109,101,110,116,32,99,111,110,116,101,110,116,32,105,115,32,110,111,116,32,97,108,108,111,119,101,100,44,32,98,101,99,97,117,115,101,32,116,104,101,32,99,111,110,116,101,110,116,32,116,121,112,101,32,105,115,32,97,32,115,105,109,112,108,101,32,116,121,112,101,32,100,101,102,105,110,105,116,105,111,110,0,0,0,0,69,108,101,109,101,110,116,32,99,111,110,116,101,110,116,32,105,115,32,110,111,116,32,97,108,108,111,119,101,100,44,32,98,101,99,97,117,115,101,32,116,104,101,32,116,121,112,101,32,100,101,102,105,110,105,116,105,111,110,32,105,115,32,115,105,109,112,108,101,0,0,0,84,104,101,32,118,97,108,117,101,32,109,117,115,116,32,99,111,110,115,105,115,116,32,111,102,32,116,117,112,108,101,115,58,32,116,104,101,32,116,97,114,103,101,116,32,110,97,109,101,115,112,97,99,101,32,110,97,109,101,32,97,110,100,32,116,104,101,32,100,111,99,117,109,101,110,116,39,115,32,85,82,73,0,0,0,0,0,0,120,109,108,83,99,104,101,109,97,65,115,115,101,109,98,108,101,66,121,88,83,73,0,0,97,115,115,101,109,98,108,105,110,103,32,115,99,104,101,109,97,116,97,0,0,0,0,0,120,109,108,83,99,104,101,109,97,65,115,115,101,109,98,108,101,66,121,76,111,99,97,116,105,111,110,0,0,0,0,0,110,111,32,112,97,114,115,101,114,32,99,111,110,116,101,120,116,32,97,118,97,105,108,97,98,108,101,0,0,0,0,0,110,111,32,99,111,110,115,116,114,117,99,116,111,114,0,0,84,104,101,32,100,111,99,117,109,101,110,116,32,97,116,32,108,111,99,97,116,105,111,110,32,39,37,115,39,32,99,111,117,108,100,32,110,111,116,32,98,101,32,97,99,113,117,105,114,101,100,0,0,0,0,0,120,109,108,83,99,104,101,109,97,80,117,115,104,65,116,116,114,105,98,117,116,101,0,0,110,105,108,0,0,0,0,0,152,95,2,0,0,0,0,0,116,121,112,101,0,0,0,0,115,99,104,101,109,97,76,111,99,97,116,105,111,110,0,0,110,111,78,97,109,101,115,112,97,99,101,83,99,104,101,109,97,76,111,99,97,116,105,111,110,0,0,0,0,0,0,0,120,95,2,0,0,0,0,0,104,116,116,112,58,47,47,119,119,119,46,119,51,46,111,114,103,47,50,48,48,48,47,120,109,108,110,115,47,0,0,0,104,116,116,112,58,47,47,119,119,119,46,119,51,46,111,114,103,47,50,48,48,49,47,88,77,76,83,99,104,101,109,97,45,105,110,115,116,97,110,99,101,0,0,0,0,0,0,0,120,109,108,83,99,104,101,109,97,86,97,108,105,100,97,116,111,114,80,117,115,104,69,108,101,109,0,0,0,0,0,0,99,97,108,108,105,110,103,32,120,109,108,83,99,104,101,109,97,71,101,116,70,114,101,115,104,69,108,101,109,73,110,102,111,40,41,0,0,0,0,0,120,109,108,83,99,104,101,109,97,71,101,116,70,114,101,115,104,69,108,101,109,73,110,102,111,0,0,0,0,0,0,0,105,110,99,111,110,115,105,115,116,101,110,116,32,100,101,112,116,104,32,101,110,99,111,117,110,116,101,114,101,100,0,0,97,108,108,111,99,97,116,105,110,103,32,116,104,101,32,101,108,101,109,101,110,116,32,105,110,102,111,32,97,114,114,97,121,0,0,0,0,0,0,0,114,101,45,97,108,108,111,99,97,116,105,110,103,32,116,104,101,32,101,108,101,109,101,110,116,32,105,110,102,111,32,97,114,114,97,121,0,0,0,0,97,108,108,111,99,97,116,105,110,103,32,97,110,32,101,108,101,109,101,110,116,32,105,110,102,111,0,0,0,0,0,0,101,108,101,109,32,105,110,102,111,32,104,97,115,32,110,111,116,32,98,101,101,110,32,99,108,101,97,114,101,100,0,0,120,109,108,83,99,104,101,109,97,86,83,116,97,114,116,0,110,111,32,105,110,115,116,97,110,99,101,32,116,111,32,118,97,108,105,100,97,116,101,0,120,109,108,83,99,104,101,109,97,68,111,99,87,97,108,107,0,0,0,0,0,0,0,0,120,109,108,83,99,104,101,109,97,86,68,111,99,87,97,108,107,0,0,0,0,0,0,0,116,104,101,114,101,32,105,115,32,97,116,32,108,101,97,115,116,32,111,110,101,32,101,110,116,105,116,121,32,114,101,102,101,114,101,110,99,101,32,105,110,32,116,104,101,32,110,111,100,101,45,116,114,101,101,32,99,117,114,114,101,110,116,108,121,32,98,101,105,110,103,32,118,97,108,105,100,97,116,101,100,46,32,80,114,111,99,101,115,115,105,110,103,32,111,102,32,101,110,116,105,116,105,101,115,32,119,105,116,104,32,116,104,105,115,32,88,77,76,32,83,99,104,101,109,97,32,112,114,111,99,101,115,115,111,114,32,105,115,32,110,111,116,32,115,117,112,112,111,114,116,101,100,32,40,121,101,116,41,46,32,80,108,101,97,115,101,32,115,117,98,115,116,105,116,117,116,101,32,101,110,116,105,116,105,101,115,32,98,101,102,111,114,101,32,118,97,108,105,100,97,116,105,111,110,46,0,0,101,108,101,109,101,110,116,32,112,111,115,105,116,105,111,110,32,109,105,115,109,97,116,99,104,0,0,0,0,0,0,0,97,108,108,111,99,97,116,105,110,103,32,97,110,32,105,116,101,109,32,108,105,115,116,32,115,116,114,117,99,116,117,114,101,0,0,0,0,0,0,0,120,109,108,83,99,104,101,109,97,86,67,104,101,99,107,67,86,67,83,105,109,112,108,101,84,121,112,101,0,0,0,0,99,111,117,108,100,32,110,111,116,32,103,101,116,32,116,104,101,32,98,117,105,108,116,45,105,110,32,116,121,112,101,0,118,97,108,105,100,97,116,105,110,103,32,97,103,97,105,110,115,116,32,97,32,98,117,105,108,116,45,105,110,32,116,121,112,101,0,0,0,0,0,0,118,97,108,105,100,97,116,105,110,103,32,102,97,99,101,116,115,32,111,102,32,97,116,111,109,105,99,32,115,105,109,112,108,101,32,116,121,112,101,0,118,97,108,105,100,97,116,105,110,103,32,97,110,32,105,116,101,109,32,111,102,32,108,105,115,116,32,115,105,109,112,108,101,32,116,121,112,101,0,0,118,97,108,105,100,97,116,105,110,103,32,102,97,99,101,116,115,32,111,102,32,108,105,115,116,32,115,105,109,112,108,101,32,116,121,112,101,0,0,0,117,110,105,111,110,32,115,105,109,112,108,101,32,116,121,112,101,32,104,97,115,32,110,111,32,109,101,109,98,101,114,32,116,121,112,101,115,0,0,0,118,97,108,105,100,97,116,105,110,103,32,109,101,109,98,101,114,115,32,111,102,32,117,110,105,111,110,32,115,105,109,112],"i8",ALLOC_NONE,Runtime.GLOBAL_BASE+146288),
	allocate([108,101,32,116,121,112,101,0,118,97,108,105,100,97,116,105,110,103,32,102,97,99,101,116,115,32,111,102,32,117,110,105,111,110,32,115,105,109,112,108,101,32,116,121,112,101,0,0,120,109,108,83,99,104,101,109,97,86,97,108,105,100,97,116,101,70,97,99,101,116,115,0,118,97,108,105,100,97,116,105,110,103,32,97,103,97,105,110,115,116,32,97,32,97,116,111,109,105,99,32,116,121,112,101,32,102,97,99,101,116,0,0,118,97,108,105,100,97,116,105,110,103,32,97,103,97,105,110,115,116,32,97,32,108,105,115,116,32,116,121,112,101,32,102,97,99,101,116,0,0,0,0,118,97,108,105,100,97,116,105,110,103,32,97,103,97,105,110,115,116,32,97,110,32,101,110,117,109,101,114,97,116,105,111,110,32,102,97,99,101,116,0,118,97,108,105,100,97,116,105,110,103,32,97,103,97,105,110,115,116,32,97,32,112,97,116,116,101,114,110,32,102,97,99,101,116,0,0,0,0,0,0,39,93,32,0,0,0,0,0,84,104,101,32,118,97,108,117,101,32,39,37,115,39,32,104,97,115,32,97,32,108,101,110,103,116,104,32,111,102,32,39,37,115,39,59,32,0,0,0,84,104,101,32,118,97,108,117,101,32,104,97,115,32,97,32,108,101,110,103,116,104,32,111,102,32,39,37,115,39,59,32,0,0,0,0,0,0,0,0,37,108,117,0,0,0,0,0,116,104,105,115,32,100,105,102,102,101,114,115,32,102,114,111,109,32,116,104,101,32,97,108,108,111,119,101,100,32,108,101,110,103,116,104,32,111,102,32,39,37,115,39,46,10,0,0,116,104,105,115,32,101,120,99,101,101,100,115,32,116,104,101,32,97,108,108,111,119,101,100,32,109,97,120,105,109,117,109,32,108,101,110,103,116,104,32,111,102,32,39,37,115,39,46,10,0,0,0,0,0,0,0,116,104,105,115,32,117,110,100,101,114,114,117,110,115,32,116,104,101,32,97,108,108,111,119,101,100,32,109,105,110,105,109,117,109,32,108,101,110,103,116,104,32,111,102,32,39,37,115,39,46,10,0,0,0,0,0,84,104,101,32,118,97,108,117,101,32,39,37,115,39,32,105,115,32,110,111,116,32,97,110,32,101,108,101,109,101,110,116,32,111,102,32,116,104,101,32,115,101,116,32,123,37,115,125,46,10,0,0,0,0,0,0,84,104,101,32,118,97,108,117,101,32,39,37,115,39,32,105,115,32,110,111,116,32,97,99,99,101,112,116,101,100,32,98,121,32,116,104,101,32,112,97,116,116,101,114,110,32,39,37,115,39,46,10,0,0,0,0,84,104,101,32,118,97,108,117,101,32,39,37,115,39,32,105,115,32,108,101,115,115,32,116,104,97,110,32,116,104,101,32,109,105,110,105,109,117,109,32,118,97,108,117,101,32,97,108,108,111,119,101,100,32,40,39,37,115,39,41,46,10,0,0,84,104,101,32,118,97,108,117,101,32,39,37,115,39,32,105,115,32,103,114,101,97,116,101,114,32,116,104,97,110,32,116,104,101,32,109,97,120,105,109,117,109,32,118,97,108,117,101,32,97,108,108,111,119,101,100,32,40,39,37,115,39,41,46,10,0,0,0,0,0,0,0,84,104,101,32,118,97,108,117,101,32,39,37,115,39,32,109,117,115,116,32,98,101,32,103,114,101,97,116,101,114,32,116,104,97,110,32,39,37,115,39,46,10,0,0,0,0,0,0,84,104,101,32,118,97,108,117,101,32,39,37,115,39,32,109,117,115,116,32,98,101,32,108,101,115,115,32,116,104,97,110,32,39,37,115,39,46,10,0,84,104,101,32,118,97,108,117,101,32,39,37,115,39,32,104,97,115,32,109,111,114,101,32,100,105,103,105,116,115,32,116,104,97,110,32,97,114,101,32,97,108,108,111,119,101,100,32,40,39,37,115,39,41,46,10,0,0,0,0,0,0,0,0,84,104,101,32,118,97,108,117,101,32,39,37,115,39,32,104,97,115,32,109,111,114,101,32,102,114,97,99,116,105,111,110,97,108,32,100,105,103,105,116,115,32,116,104,97,110,32,97,114,101,32,97,108,108,111,119,101,100,32,40,39,37,115,39,41,46,10,0,0,0,0,0,84,104,101,32,118,97,108,117,101,32,39,37,115,39,32,105,115,32,110,111,116,32,102,97,99,101,116,45,118,97,108,105,100,46,10,0,0,0,0,0,84,104,101,32,118,97,108,117,101,32,105,115,32,110,111,116,32,102,97,99,101,116,45,118,97,108,105,100,46,10,0,0,120,109,108,83,99,104,101,109,97,70,111,114,109,97,116,70,97,99,101,116,69,110,117,109,83,101,116,0,0,0,0,0,99,111,109,112,117,116,101,32,116,104,101,32,99,97,110,111,110,105,99,97,108,32,108,101,120,105,99,97,108,32,114,101,112,114,101,115,101,110,116,97,116,105,111,110,0,0,0,0,44,32,39,0,0,0,0,0,120,109,108,83,99,104,101,109,97,86,97,108,105,100,97,116,101,81,78,97,109,101,0,0,99,97,108,108,105,110,103,32,120,109,108,86,97,108,105,100,97,116,101,81,78,97,109,101,40,41,0,0,0,0,0,0,120,109,108,83,99,104,101,109,97,86,97,108,105,100,97,116,101,78,111,116,97,116,105,111,110,0,0,0,0,0,0,0,97,32,115,99,104,101,109,97,32,105,115,32,110,101,101,100,101,100,32,111,110,32,116,104,101,32,118,97,108,105,100,97,116,105,111,110,32,99,111,110,116,101,120,116,0,0,0,0,112,97,116,116,101,114,110,0,109,97,120,69,120,99,108,117,115,105,118,101,0,0,0,0,109,97,120,73,110,99,108,117,115,105,118,101,0,0,0,0,109,105,110,69,120,99,108,117,115,105,118,101,0,0,0,0,109,105,110,73,110,99,108,117,115,105,118,101,0,0,0,0,119,104,105,116,101,83,112,97,99,101,0,0,0,0,0,0,101,110,117,109,101,114,97,116,105,111,110,0,0,0,0,0,108,101,110,103,116,104,0,0,109,97,120,76,101,110,103,116,104,0,0,0,0,0,0,0,109,105,110,76,101,110,103,116,104,0,0,0,0,0,0,0,116,111,116,97,108,68,105,103,105,116,115,0,0,0,0,0,102,114,97,99,116,105,111,110,68,105,103,105,116,115,0,0,73,110,116,101,114,110,97,108,32,69,114,114,111,114,0,0,67,97,110,110,111,116,32,99,114,101,97,116,101,32,97,117,116,111,109,97,116,97,32,102,111,114,32,99,111,109,112,108,101,120,32,116,121,112,101,32,37,115,10,0,0,0,0,0,70,97,105,108,101,100,32,116,111,32,99,111,109,112,105,108,101,32,116,104,101,32,99,111,110,116,101,110,116,32,109,111,100,101,108,0,0,0,0,0,84,104,101,32,99,111,110,116,101,110,116,32,109,111,100,101,108,32,105,115,32,110,111,116,32,100,101,116,101,114,109,105,110,105,115,116,0,0,0,0,120,109,108,83,99,104,101,109,97,66,117,105,108,100,65,67,111,110,116,101,110,116,77,111,100,101,108,0,0,0,0,0,112,97,114,116,105,99,108,101,32,105,115,32,78,85,76,76,0,0,0,0,0,0,0,0,60,101,108,101,109,101,110,116,62,32,112,97,114,116,105,99,108,101,32,104,97,115,32,110,111,32,116,101,114,109,0,0,102,111,117,110,100,32,117,110,101,120,112,101,99,116,101,100,32,116,101,114,109,32,111,102,32,116,121,112,101,32,39,37,115,39,32,105,110,32,99,111,110,116,101,110,116,32,109,111,100,101,108,0,0,0,0,0,73,110,116,101,114,110,97,108,32,101,114,114,111,114,58,32,0,0,0,0,0,0,0,0,73,110,116,101,114,110,97,108,32,101,114,114,111,114,58,32,120,109,108,83,99,104,101,109,97,66,117,105,108,100,67,111,110,116,101,110,116,77,111,100,101,108,70,111,114,83,117,98,115,116,71,114,111,117,112,44,32,100,101,99,108,97,114,97,116,105,111,110,32,105,115,32,109,97,114,107,101,100,32,104,97,118,105,110,103,32,97,32,115,117,98,115,116,46,32,103,114,111,117,112,32,98,117,116,32,110,111,110,101,32,97,118,97,105,108,97,98,108,101,46,10,0,0,0,0,0,0,0,97,108,108,111,99,97,116,105,110,103,32,97,32,115,117,98,115,116,105,116,117,116,105,111,110,32,103,114,111,117,112,32,99,111,110,116,97,105,110,101,114,0,0,0,0,0,0,0,120,109,108,83,99,104,101,109,97,83,117,98,115,116,71,114,111,117,112,65,100,100,0,0,102,97,105,108,101,100,32,116,111,32,97,100,100,32,97,32,110,101,119,32,115,117,98,115,116,105,116,117,116,105,111,110,32,99,111,110,116,97,105,110,101,114,0,0,0,0,0,0,79,110,108,121,32,103,108,111,98,97,108,32,101,108,101,109,101,110,116,32,100,101,99,108,97,114,97,116,105,111,110,115,32,99,97,110,32,104,97,118,101,32,97,32,115,117,98,115,116,105,116,117,116,105,111,110,32,103,114,111,117,112,32,97,102,102,105,108,105,97,116,105,111,110,0,0,0,0,0,0,84,104,101,32,101,108,101,109,101,110,116,32,100,101,99,108,97,114,97,116,105,111,110,32,39,37,115,39,32,100,101,102,105,110,101,115,32,97,32,99,105,114,99,117,108,97,114,32,115,117,98,115,116,105,116,117,116,105,111,110,32,103,114,111,117,112,32,116,111,32,101,108,101,109,101,110,116,32,100,101,99,108,97,114,97,116,105,111,110,32,39,37,115,39,0,0,84,104,101,32,116,121,112,101,32,100,101,102,105,110,105,116,105,111,110,32,39,37,115,39,32,119,97,115,32,101,105,116,104,101,114,32,114,101,106,101,99,116,101,100,32,98,121,32,116,104,101,32,115,117,98,115,116,105,116,117,116,105,111,110,32,103,114,111,117,112,32,97,102,102,105,108,105,97,116,105,111,110,32,39,37,115,39,44,32,111,114,32,110,111,116,32,118,97,108,105,100,108,121,32,100,101,114,105,118,101,100,32,102,114,111,109,32,105,116,115,32,116,121,112,101,32,100,101,102,105,110,105,116,105,111,110,32,39,37,115,39,0,0,0,84,104,101,32,116,121,112,101,32,100,101,102,105,110,105,116,105,111,110,32,40,111,114,32,116,121,112,101,32,100,101,102,105,110,105,116,105,111,110,39,115,32,99,111,110,116,101,110,116,32,116,121,112,101,41,32,105,115,32,111,114,32,105,115,32,100,101,114,105,118,101,100,32,102,114,111,109,32,73,68,59,32,118,97,108,117,101,32,99,111,110,115,116,114,97,105,110,116,115,32,97,114,101,32,110,111,116,32,97,108,108,111,119,101,100,32,105,110,32,99,111,110,106,117,110,99,116,105,111,110,32,119,105,116,104,32,115,117,99,104,32,97,32,116,121,112,101,32,100,101,102,105,110,105,116,105,111,110,0,0,73,110,116,101,114,110,97,108,32,101,114,114,111,114,58,32,120,109,108,83,99,104,101,109,97,67,104,101,99,107,69,108,101,109,80,114,111,112,115,67,111,114,114,101,99,116,44,32,116,121,112,101,32,105,115,32,109,105,115,115,105,110,103,46,46,46,32,115,107,105,112,112,105,110,103,32,118,97,108,105,100,97,116,105,111,110,32,111,102,32,116,104,101,32,118,97,108,117,101,32,99,111,110,115,116,114,97,105,110,116,0,0,102,105,120,101,100,0,0,0,100,101,102,97,117,108,116,0,120,109,108,83,99,104,101,109,97,69,108,101,109,67,104,101,99,107,86,97,108,67,111,110,115,116,114,0,0,0,0,0,102,97,105,108,101,100,32,116,111,32,118,97,108,105,100,97,116,101,32,116,104,101,32,118,97,108,117,101,32,99,111,110,115,116,114,97,105,110,116,32,111,102,32,97,110,32,101,108,101,109,101,110,116,32,100,101,99,108,97,114,97,116,105,111,110,0,0,0,0,0,0,0,70,111,114,32,97,32,115,116,114,105,110,103,32,116,111,32,98,101,32,97,32,118,97,108,105,100,32,100,101,102,97,117,108,116,44,32,116,104,101,32,116,121,112,101,32,100,101,102,105,110,105,116,105,111,110,32,109,117,115,116,32,98,101,32,97,32,115,105,109,112,108,101,32,116,121,112,101,32,111,114,32,97,32,99,111,109,112,108,101,120,32,116,121,112,101,32,119,105,116,104,32,109,105,120,101,100,32,99,111,110,116,101,110,116,32,97,110,100,32,97,32,112,97,114,116,105,99,108,101,32,101,109,112,116,105,97,98,108,101,0,0,0,0,0,120,109,108,83,99,104,101,109,97,80,97,114,115,101,67,104,101,99,107,67,79,83,86,97,108,105,100,68,101,102,97,117,108,116,0,0,0,0,0,0,84,104,101,32,97,116,116,114,105,98,117,116,101,32,100,101,99,108,97,114,97,116,105,111,110,32,104,97,115,32,97,32,39,102,105,120,101,100,39,32,118,97,108,117,101,32,99,111,110,115,116,114,97,105,110,116,32,44,32,116,104,117,115,32,116,104,101,32,97,116,116,114,105,98,117,116,101,32,117,115,101,32,109,117,115,116,32,97,108,115,111,32,104,97,118,101,32,97,32,39,102,105,120,101,100,39,32,118,97,108,117,101,32,99,111,110,115,116,114,97,105,110,116,0,0,0,0,0,86,97,108,117,101,32,99,111,110,115,116,114,97,105,110,116,115,32,97,114,101,32,110,111,116,32,97,108,108,111,119,101,100,32,105,102,32,116,104,101,32,116,121,112,101,32,100,101,102,105,110,105,116,105,111,110,32,105,115,32,111,114,32,105,115,32,100,101,114,105,118,101,100,32,102,114,111,109,32,120,115,58,73,68,0,0,0,0,120,109,108,83,99,104,101,109,97,67,104,101,99,107,65,116,116,114,85,115,101,80,114,111,112,115,67,111,114,114,101,99,116,0,0,0,0,0,0,0,84,104,101,32,118,97,108,117,101,32,111,102,32,116,104,101,32,118,97,108,117,101,32,99,111,110,115,116,114,97,105,110,116,32,105,115,32,110,111,116,32,118,97,108,105,100,0,0,84,104,101,32,39,102,105,120,101,100,39,32,118,97,108,117,101,32,99,111,110,115,116,114,97,105,110,116,32,111,102,32,116,104,101,32,97,116,116,114,105,98,117,116,101,32,117,115,101,32,109,117,115,116,32,109,97,116,99,104,32,116,104,101,32,97,116,116,114,105,98,117,116,101,32,100,101,99,108,97,114,97,116,105,111,110,39,115,32,118,97,108,117,101,32,99,111,110,115,116,114,97,105,110,116,32,39,37,115,39,0,0,120,109,108,83,99,104,101,109,97,67,104,101,99,107,65,116,116,114,80,114,111,112,115,67,111,114,114,101,99,116,0,0,84,104,101,32,117,110,105,111,110,32,116,121,112,101,32,100,101,102,105,110,105,116,105,111,110,32,105,115,32,99,105,114,99,117,108,97,114,0,0,0,67,105,114,99,117,108,97,114,32,114,101,102,101,114,101,110,99,101,32,116,111,32,116,104,101,32,97,116,116,114,105,98,117,116,101,32,103,114,111,117,112,32,39,37,115,39,32,100,101,102,105,110,101,100,0,0,67,105,114,99,117,108,97,114,32,114,101,102,101,114,101,110,99,101,32,116,111,32,116,104,101,32,109,111,100,101,108,32,103,114,111,117,112,32,100,101,102,105,110,105,116,105,111,110,32,39,37,115,39,32,100,101,102,105,110,101,100,0,0,0,84,104,101,32,100,101,102,105,110,105,116,105,111,110,32,105,115,32,99,105,114,99,117,108,97,114,0,0,0,0,0,0,114,101,102,0,0,0,0,0,37,115,44,32,97,116,116,114,105,98,117,116,101,32,39,37,115,39,58,32,84,104,101,32,81,78,97,109,101,32,118,97,108,117,101,32,39,37,115,39,32,100,111,101,115,32,110,111,116,32,114,101,115,111,108,118,101,32,116,111,32,97,40,110,41,32,37,115,46,10,0,0,114,101,102,101,114,0,0,0,84,104,101,32,107,101,121,114,101,102,32,114,101,102,101,114,101,110,99,101,115,32,97,32,107,101,121,114,101,102,0,0,84,104,101,32,99,97,114,100,105,110,97,108,105,116,121,32,111,102,32,116,104,101,32,107,101,121,114,101,102,32,100,105,102,102,101,114,115,32,102,114,111,109,32,116,104,101,32,99,97,114,100,105,110,97,108,105,116,121,32,111,102,32,116,104,101,32,114,101,102,101,114,101,110,99,101,100,32,107,101,121,47,117,110,105,113,117,101,32,39,37,115,39,0,0,0,0,65,32,109,111,100,101,108,32,103,114,111,117,112,32,100,101,102,105,110,105,116,105,111,110,32,105,115,32,114,101,102,101,114,101,110,99,101,100,44,32,98,117,116,32,105,116,32,99,111,110,116,97,105,110,115,32,97,110,32,39,97,108,108,39,32,109,111,100,101,108,32,103,114,111,117,112,44,32,119,104,105,99,104,32,99,97,110,110,111,116,32,98,101,32,99,111,110,116,97,105,110,101,100,32,98,121,32,109,111,100,101,108,32,103,114,111,117,112,115,0,105,116,101,109,84,121,112,101,0,0,0,0,0,0,0,0,84,104,101,32,112,97,114,116,105,99,108,101,39,115,32,123,109,97,120,32,111,99,99,117,114,115,125,32,109,117,115,116,32,98,101,32,49,44,32,115,105,110,99,101,32,116,104,101,32,114,101,102,101,114,101,110,99,101,32,114,101,115,111,108,118,101,115,32,116,111,32,97,110,32,39,97,108,108,39,32,109,111,100,101,108,32,103,114,111,117,112,0,0,0,0,0,109,101,109,98,101,114,84,121,112,101,115,0,0,0,0,0,116,121,112,101,32,100,101,102,105,110,105,116,105,111,110,0,115,117,98,115,116,105,116,117,116,105,111,110,71,114,111,117,112,0,0,0,0,0,0,0,120,109,108,83,99,104,101,109,97,65,100,100,67,111,109,112,111,110,101,110,116,115,0,0,85,110,101,120,112,101,99,116,101,100,32,103,108,111,98,97,108,32,99,111,109,112,111,110,101,110,116,32,116,121,112,101,0,0,0,0,0,0,0,0,102,97,105,108,101,100,32,116,111,32,99,114,101,97,116,101,32,97,32,99,111,109,112,111,110,101,110,116,32,104,97,115,104,32,116,97,98,108,101,0,65,32,103,108,111,98,97,108,32,37,115,32,39,37,115,39,32,100,111,101,115,32,97,108,114,101,97,100,121,32,101,120,105,115,116,0,0,0,0,0,84,104,101,32,37,115,32,39,37,115,39,32,116,111,32,98,101,32,114,101,100,101,102,105,110,101,100,32,99,111,117,108,100,32,110,111,116,32,98,101,32,102,111,117,110,100,32,105,110,32,116,104,101,32,114,101,100,101,102,105,110,101,100,32,115,99,104,101,109,97,0,0,120,109,108,83,99,104,101,109,97,82,101,115,111,108,118,101,82,101,100,101,102,82,101,102,101,114,101,110,99,101,115,0,85,110,101,120,112,101,99,116,101,100,32,114,101,100,101,102,105,110,101,100,32,99,111,109,112,111,110,101,110,116,32,116,121,112,101,0,0,0,0,0,84,104,101,32,114,101,102,101,114,101,110,99,101,100,32,37,115,32,119,97,115,32,97,108,114,101,97,100,121,32,114,101,100,101,102,105,110,101,100,46,32,77,117,108,116,105,112,108,101,32,114,101,100,101,102,105,110,105,116,105,111,110,32,111,102,32,116,104,101,32,115,97,109,101,32,99,111,109,112,111,110,101,110,116,32,105,115,32,110,111,116,32,115,117,112,112,111,114,116,101,100,0,0,0,105,110,99,108,117,100,101,0,105,109,112,111,114,116,0,0,114,101,100,101,102,105,110,101,0,0,0,0,0,0,0,0,97,110,110,111,116,97,116,105,111,110,0,0,0,0,0,0,99,111,109,112,108,101,120,84,121,112,101,0,0,0,0,0,115,105,109,112,108,101,84,121,112,101,0,0,0,0,0,0,101,108,101,109,101,110,116,0,97,116,116,114,105,98,117,116,101,0,0,0,0,0,0,0,97,116,116,114,105,98,117,116,101,71,114,111,117,112,0,0,103,114,111,117,112,0,0,0,110,111,116,97,116,105,111,110,0,0,0,0,0,0,0,0,40,40,105,110,99,108,117,100,101,32,124,32,105,109,112,111,114,116,32,124,32,114,101,100,101,102,105,110,101,32,124,32,97,110,110,111,116,97,116,105,111,110,41,42,44,32,40,40,40,115,105,109,112,108,101,84,121,112,101,32,124,32,99,111,109,112,108,101,120,84,121,112,101,32,124,32,103,114,111,117,112,32,124,32,97,116,116,114,105,98,117,116,101,71,114,111,117,112,41,32,124,32,101,108,101,109,101,110,116,32,124,32,97,116,116,114,105,98,117,116,101,32,124,32,110,111,116,97,116,105,111,110,41,44,32,97,110,110,111,116,97,116,105,111,110,42,41,42,41,0,0,0,37,115,58,32,37,115,46,10,0,0,0,0,0,0,0,0,37,115,58,32,84,104,101,32,99,111,110,116,101,110,116,32,105,115,32,110,111,116,32,118,97,108,105,100,46,32,69,120,112,101,99,116,101,100,32,105,115,32,37,115,46,10,0,0,37,115,58,32,84,104,101,32,99,111,110,116,101,110,116,32,105,115,32,110,111,116,32,118,97,108,105,100,46,10,0,0,110,97,109,101,0,0,0,0,78,111,116,97,116,105,111,110,32,104,97,115,32,110,111,32,110,97,109,101,10,0,0,0,105,100,0,0,0,0,0,0,40,97,110,110,111,116,97,116,105,111,110,63,41,0,0,0,68,117,112,108,105,99,97,116,101,32,118,97,108,117,101,32,39,37,115,39,32,111,102,32,115,105,109,112,108,101,32,116,121,112,101,32,39,120,115,58,73,68,39,0,0,0,0,0,84,104,101,32,118,97,108,117,101,32,39,37,115,39,32,111,102,32,115,105,109,112,108,101,32,116,121,112,101,32,39,120,115,58,73,68,39,32,105,115,32,110,111,116,32,97,32,118,97,108,105,100,32,39,120,115,58,78,67,78,97,109,101,39,0,0,0,0,0,0,0,0,39,46,0,0,0,0,0,0,84,104,101,32,118,97,108,117,101,32,39,37,115,39,32,105,115,32,110,111,116,32,118,97,108,105,100,46,0,0,0,0,84,104,101,32,99,104,97,114,97,99,116,101,114,32,99,111,110,116,101,110,116,32,105,115,32,110,111,116,32,118,97,108,105,100,46,0,0,0,0,0,32,69,120,112,101,99,116,101,100,32,105,115,32,39,0,0,39,46,10,0,0,0,0,0,97,100,100,32,97,110,110,111,116,97,116,105,111,110,0,0,97,108,108,0,0,0,0,0,99,104,111,105,99,101,0,0,115,101,113,117,101,110,99,101,0,0,0,0,0,0,0,0,40,97,110,110,111,116,97,116,105,111,110,63,44,32,40,97,108,108,32,124,32,99,104,111,105,99,101,32,124,32,115,101,113,117,101,110,99,101,41,63,41,0,0,0,0,0,0,0,40,48,32,124,32,49,41,0,49,0,0,0,0,0,0,0,120,115,58,110,111,110,78,101,103,97,116,105,118,101,73,110,116,101,103,101,114,0,0,0,40,120,115,58,110,111,110,78,101,103,97,116,105,118,101,73,110,116,101,103,101,114,32,124,32,117,110,98,111,117,110,100,101,100,41,0,0,0,0,0,109,97,120,79,99,99,117,114,115,0,0,0,0,0,0,0,109,105,110,79,99,99,117,114,115,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,118,97,108,117,101,32,102,111,114,32,109,105,110,79,99,99,117,114,115,32,40,109,117,115,116,32,98,101,32,48,32,111,114,32,49,41,0,0,0,0,73,110,118,97,108,105,100,32,118,97,108,117,101,32,102,111,114,32,109,97,120,79,99,99,117,114,115,32,40,109,117,115,116,32,98,101,32,48,32,111,114,32,49,41,0,0,0,0,40,97,110,110,111,116,97,116,105,111,110,63,44,32,40,97,110,110,111,116,97,116,105,111,110,63,44,32,101,108,101,109,101,110,116,42,41,0,0,0,97,110,121,0,0,0,0,0,84,104,101,32,114,101,100,101,102,105,110,105,110,103,32,109,111,100,101,108,32,103,114,111,117,112,32,100,101,102,105,110,105,116,105,111,110,32,39,37,115,39,32,109,117,115,116,32,110,111,116,32,99,111,110,116,97,105,110,32,109,111,114,101,32,116,104,97,110,32,111,110,101,32,114,101,102,101,114,101,110,99,101,32,116,111,32,116,104,101,32,114,101,100,101,102,105,110,101,100,32,100,101,102,105,110,105,116,105,111,110,0,84,104,101,32,114,101,100,101,102,105,110,105,110,103,32,109,111,100,101,108,32,103,114,111,117,112,32,100,101,102,105,110,105,116,105,111,110,32,39,37,115,39,32,109,117,115,116,32,110,111,116,32,99,111,110,116,97,105,110,32,97,32,114,101,102,101,114,101,110,99,101,32,116,111,32,116,104,101,32,114,101,100,101,102,105,110,101,100,32,100,101,102,105,110,105,116,105,111,110,32,119,105,116,104,32,97,32,109,97,120,79,99,99,117,114,115,47,109,105,110,79,99,99,117,114,115,32,111,116,104,101,114,32,116,104,97,110,32,49,0,0,0,0,0,40,97,110,110,111,116,97,116,105,111,110,63,44,32,40,101,108,101,109,101,110,116,32,124,32,103,114,111,117,112,32,124,32,99,104,111,105,99,101,32,124,32,115,101,113,117,101,110,99,101,32,124,32,97,110,121,41,42,41,0,0,0,0,0,110,97,109,101,115,112,97,99,101,0,0,0,0,0,0,0,112,114,111,99,101,115,115,67,111,110,116,101,110,116,115,0,40,115,116,114,105,99,116,32,124,32,115,107,105,112,32,124,32,108,97,120,41,0,0,0,35,35,97,110,121,0,0,0,40,40,35,35,97,110,121,32,124,32,35,35,111,116,104,101,114,41,32,124,32,76,105,115,116,32,111,102,32,40,120,115,58,97,110,121,85,82,73,32,124,32,40,35,35,116,97,114,103,101,116,78,97,109,101,115,112,97,99,101,32,124,32,35,35,108,111,99,97,108,41,41,41,0,0,0,0,0,0,0,35,35,116,97,114,103,101,116,78,97,109,101,115,112,97,99,101,0,0,0,0,0,0,0,35,35,108,111,99,97,108,0,120,109,108,83,99,104,101,109,97,80,86,97,108,65,116,116,114,78,111,100,101,86,97,108,117,101,0,0,0,0,0,0,116,104,101,32,103,105,118,101,110,32,116,121,112,101,32,105,115,32,110,111,116,32,97,32,98,117,105,108,116,45,105,110,32,116,121,112,101,0,0,0,118,97,108,105,100,97,116,105,111,110,32,117,115,105,110,103,32,116,104,101,32,103,105,118,101,110,32,116,121,112,101,32,105,115,32,110,111,116,32,115,117,112,112,111,114,116,101,100,32,119,104,105,108,101,32,112,97,114,115,105,110,103,32,97,32,115,99,104,101,109,97,0,102,97,105,108,101,100,32,116,111,32,118,97,108,105,100,97,116,101,32,97,32,115,99,104,101,109,97,32,97,116,116,114,105,98,117,116,101,32,118,97,108,117,101,0,0,0,0,0,97,108,108,111,99,97,116,105,110,103,32,81,78,97,109,101,32,114,101,102,101,114,101,110,99,101,32,105,116,101,109,0,82,101,102,101,114,101,110,99,101,115,32,102,114,111,109,32,116,104,105,115,32,115,99,104,101,109,97,32,116,111,32,99,111,109,112,111,110,101,110,116,115,32,105,110,32,110,111,32,110,97,109,101,115,112,97,99,101,32,97,114,101,32,110,111,116,32,97,108,108,111,119,101,100,44,32,115,105,110,99,101,32,110,111,116,32,105,110,100,105,99,97,116,101,100,32,98,121,32,97,110,32,105,109,112,111,114,116,32,115,116,97,116,101,109,101,110,116,0,0,0,82,101,102,101,114,101,110,99,101,115,32,102,114,111,109,32,116,104,105,115,32,115,99,104,101,109,97,32,116,111,32,99,111,109,112,111,110,101,110,116,115,32,105,110,32,116,104,101,32,110,97,109,101,115,112,97,99,101,32,39,37,115,39,32,97,114,101,32,110,111,116,32,97,108,108,111,119,101,100,44,32,115,105,110,99,101,32,110,111,116,32,105,110,100,105,99,97,116,101,100,32,98,121,32,97,110,32,105,109,112,111,114,116,32,115,116,97,116,101,109,101,110,116,0,0,0,0,0,84,104,101,32,118,97,108,117,101,32,39,37,115,39,32,111,102,32,115,105,109,112,108,101,32,116,121,112,101,32,39,120,115,58,81,78,97,109,101,39,32,104,97,115,32,110,111,32,99,111,114,114,101,115,112,111,110,100,105,110,103,32,110,97,109,101,115,112,97,99,101,32,100,101,99,108,97,114,97,116,105,111,110,32,105,110,32,115,99,111,112,101,0,0,0,0,84,104,101,32,118,97,108,117,101,32,109,117,115,116,32,98,101,32,103,114,101,97,116,101,114,32,116,104,97,110,32,111,114,32,101,113,117,97,108,32,116,111,32,49,0,0,0,0,84,104,101,32,118,97,108,117,101,32,109,117,115,116,32,110,111,116,32,98,101,32,103,114,101,97,116,101,114,32,116,104,97,110,32,116,104,101,32,118,97,108,117,101,32,111,102,32,39,109,97,120,79,99,99,117,114,115,39,0,0,0,0,0,37,115,44,32,97,116,116,114,105,98,117,116,101,32,39,37,115,39,58,32,37,115,46,10,0,0,0,0,0,0,0,0,85,110,107,110,111,119,110,0,117,110,98,111,117,110,100,101,100,0,0,0,0,0,0,0,37,115,84,104,101,32,97,116,116,114,105,98,117,116,101,32,39,37,115,39,32,105,115,32,110,111,116,32,97,108,108,111,119,101,100,46,10,0,0,0,97,100,100,105,110,103,32,103,114,111,117,112,0,0,0,0,37,115,58,32,84,104,101,32,97,116,116,114,105,98,117,116,101,32,39,37,115,39,32,105,115,32,114,101,113,117,105,114,101,100,32,98,117,116,32,109,105,115,115,105,110,103,46,10,0,0,0,0,0,0,0,0,97,110,121,65,116,116,114,105,98,117,116,101,0,0,0,0,40,97,110,110,111,116,97,116,105,111,110,63,44,32,40,40,97,116,116,114,105,98,117,116,101,32,124,32,97,116,116,114,105,98,117,116,101,71,114,111,117,112,41,42,44,32,97,110,121,65,116,116,114,105,98,117,116,101,63,41,41,0,0,0,84,104,101,32,114,101,100,101,102,105,110,105,110,103,32,97,116,116,114,105,98,117,116,101,32,103,114,111,117,112,32,100,101,102,105,110,105,116,105,111,110,32,39,37,115,39,32,109,117,115,116,32,110,111,116,32,99,111,110,116,97,105,110,32,109,111,114,101,32,116,104,97,110,32,111,110,101,32,114,101,102,101,114,101,110,99,101,32,116,111,32,116,104,101,32,114,101,100,101,102,105,110,101,100,32,100,101,102,105,110,105,116,105,111,110,0,0,0,0,0,102,111,114,109,0,0,0,0,113,117,97,108,105,102,105,101,100,0,0,0,0,0,0,0,117,110,113,117,97,108,105,102,105,101,100,0,0,0,0,0,40,113,117,97,108,105,102,105,101,100,32,124,32,117,110,113,117,97,108,105,102,105,101,100,41,0,0,0,0,0,0,0,117,115,101,0,0,0,0,0,111,112,116,105,111,110,97,108,0,0,0,0,0,0,0,0,112,114,111,104,105,98,105,116,101,100,0,0,0,0,0,0,114,101,113,117,105,114,101,100,0,0,0,0,0,0,0,0,40,111,112,116,105,111,110,97,108,32,124,32,112,114,111,104,105,98,105,116,101,100,32,124,32,114,101,113,117,105,114,101,100,41,0,0,0,0,0,0,84,104,101,32,118,97,108,117,101,32,111,102,32,116,104,101,32,97,116,116,114,105,98,117,116,101,32,39,117,115,101,39,32,109,117,115,116,32,98,101,32,39,111,112,116,105,111,110,97,108,39,32,105,102,32,116,104,101,32,97,116,116,114,105,98,117,116,101,32,39,100,101,102,97,117,108,116,39,32,105,115,32,112,114,101,115,101,110,116,0,0,0,0,0,0,0,84,104,101,32,116,97,114,103,101,116,32,110,97,109,101,115,112,97,99,101,32,109,117,115,116,32,110,111,116,32,109,97,116,99,104,32,39,37,115,39,0,0,0,0,0,0,0,0,120,109,108,110,115,0,0,0,84,104,101,32,118,97,108,117,101,32,111,102,32,116,104,101,32,97,116,116,114,105,98,117,116,101,32,109,117,115,116,32,110,111,116,32,109,97,116,99,104,32,39,120,109,108,110,115,39,0,0,0,0,0,0,0,83,107,105,112,112,105,110,103,32,97,116,116,114,105,98,117,116,101,32,117,115,101,32,112,114,111,104,105,98,105,116,105,111,110,44,32,115,105,110,99,101,32,105,116,32,105,115,32,112,111,105,110,116,108,101,115,115,32,105,110,115,105,100,101,32,97,110,32,60,97,116,116,114,105,98,117,116,101,71,114,111,117,112,62,0,0,0,0,83,107,105,112,112,105,110,103,32,97,116,116,114,105,98,117,116,101,32,117,115,101,32,112,114,111,104,105,98,105,116,105,111,110,44,32,115,105,110,99,101,32,105,116,32,105,115,32,112,111,105,110,116,108,101,115,115,32,119,104,101,110,32,101,120,116,101,110,100,105,110,103,32,97,32,116,121,112,101,0,83,107,105,112,112,105,110,103,32,100,117,112,108,105,99,97,116,101,32,97,116,116,114,105,98,117,116,101,32,117,115,101,32,112,114,111,104,105,98,105,116,105,111,110,32,39,37,115,39,0,0,0,0,0,0,0,84,104,101,32,97,116,116,114,105,98,117,116,101,32,39,116,121,112,101,39,32,97,110,100,32,116,104,101,32,60,115,105,109,112,108,101,84,121,112,101,62,32,99,104,105,108,100,32,97,114,101,32,109,117,116,117,97,108,108,121,32,101,120,99,108,117,115,105,118,101,0,0,40,97,110,110,111,116,97,116,105,111,110,63,44,32,115,105,109,112,108,101,84,121,112,101,63,41,0,0,0,0,0,0,97,108,108,111,99,97,116,105,110,103,32,97,116,116,114,105,98,117,116,101,32,117,115,101,32,112,114,111,104,105,98,105,116,105,111,110,0,0,0,0,97,108,108,111,99,97,116,105,110,103,32,97,116,116,114,105,98,117,116,101,0,0,0,0,37,115,58,32,84,104,101,32,97,116,116,114,105,98,117,116,101,115,32,39,37,115,39,32,97,110,100,32,39,37,115,39,32,97,114,101,32,109,117,116,117,97,108,108,121,32,101,120,99,108,117,115,105,118,101,46,10,0,0,0,0,0,0,0,97,108,108,111,99,97,116,105,110,103,32,97,116,116,114,105,98,117,116,101,32,103,114,111,117,112,0,0,0,0,0,0,79,110,108,121,32,116,104,101,32,97,116,116,114,105,98,117,116,101,115,32,39,109,105,110,79,99,99,117,114,115,39,44,32,39,109,97,120,79,99,99,117,114,115,39,32,97,110,100,32,39,105,100,39,32,97,114,101,32,97,108,108,111,119,101,100,32,105,110,32,97,100,100,105,116,105,111,110,32,116,111,32,39,114,101,102,39,0,0,98,108,111,99,107,0,0,0,110,105,108,108,97,98,108,101,0,0,0,0,0,0,0,0,102,105,110,97,108,0,0,0,97,98,115,116,114,97,99,116,0,0,0,0,0,0,0,0,40,35,97,108,108,32,124,32,76,105,115,116,32,111,102,32,40,101,120,116,101,110,115,105,111,110,32,124,32,114,101,115,116,114,105,99,116,105,111,110,41,41,0,0,0,0,0,0,40,35,97,108,108,32,124,32,76,105,115,116,32,111,102,32,40,101,120,116,101,110,115,105,111,110,32,124,32,114,101,115,116,114,105,99,116,105,111,110,32,124,32,115,117,98,115,116,105,116,117,116,105,111,110,41,41,0,0,0,0,0,0,0,84,104,101,32,97,116,116,114,105,98,117,116,101,32,39,116,121,112,101,39,32,97,110,100,32,116,104,101,32,60,99,111,109,112,108,101,120,84,121,112,101,62,32,99,104,105,108,100,32,97,114,101,32,109,117,116,117,97,108,108,121,32,101,120,99,108,117,115,105,118,101,0,117,110,105,113,117,101,0,0,107,101,121,0,0,0,0,0,107,101,121,114,101,102,0,0,40,97,110,110,111,116,97,116,105,111,110,63,44,32,40,40,115,105,109,112,108,101,84,121,112,101,32,124,32,99,111,109,112,108,101,120,84,121,112,101,41,63,44,32,40,117,110,105,113,117,101,32,124,32,107,101,121,32,124,32,107,101,121,114,101,102,41,42,41,41,0,0,65,32,99,104,105,108,100,32,101,108,101,109,101,110,116,32,105,115,32,109,105,115,115,105,110,103,0,0,0,0,0,0,40,97,110,110,111,116,97,116,105,111,110,63,44,32,40,115,101,108,101,99,116,111,114,44,32,102,105,101,108,100,43,41,41,0,0,0,0,0,0,0,115,101,108,101,99,116,111,114,0,0,0,0,0,0,0,0,102,105,101,108,100,0,0,0,120,112,97,116,104,0,0,0,97,108,108,111,99,97,116,105,110,103,32,97,32,39,115,101,108,101,99,116,111,114,39,32,111,102,32,97,110,32,105,100,101,110,116,105,116,121,45,99,111,110,115,116,114,97,105,110,116,32,100,101,102,105,110,105,116,105,111,110,0,0,0,0,73,110,116,101,114,110,97,108,32,101,114,114,111,114,58,32,120,109,108,83,99,104,101,109,97,80,97,114,115,101,73,68,67,83,101,108,101,99,116,111,114,65,110,100,70,105,101,108,100,44,32,118,97,108,105,100,97,116,105,110,103,32,116,104,101,32,88,80,97,116,104,32,101,120,112,114,101,115,115,105,111,110,32,111,102,32,97,32,73,68,67,32,115,101,108,101,99,116,111,114,46,10,0,0,73,110,116,101,114,110,97,108,32,101,114,114,111,114,58,32,120,109,108,83,99,104,101,109,97,65,100,100,65,110,110,111,116,97,116,105,111,110,44,32,84,104,101,32,105,116,101,109,32,105,115,32,110,111,116,32,97,32,97,110,110,111,116,97,116,101,100,32,115,99,104,101,109,97,32,99,111,109,112,111,110,101,110,116,0,0,0,0,73,110,116,101,114,110,97,108,32,101,114,114,111,114,58,32,120,109,108,83,99,104,101,109,97,67,104,101,99,107,67,83,101,108,101,99,116,111,114,88,80,97,116,104,44,32,116,104,101,32,115,101,108,101,99,116,111,114,32,105,115,32,110,111,116,32,115,112,101,99,105,102,105,101,100,46,10,0,0,0,84,104,101,32,88,80,97,116,104,32,101,120,112,114,101,115,115,105,111,110,32,111,102,32,116,104,101,32,115,101,108,101,99,116,111,114,32,105,115,32,110,111,116,32,118,97,108,105,100,0,0,0,0,0,0,0,97,108,108,111,99,97,116,105,110,103,32,97,32,110,97,109,101,115,112,97,99,101,32,97,114,114,97,121,0,0,0,0,84,104,101,32,88,80,97,116,104,32,101,120,112,114,101,115,115,105,111,110,32,39,37,115,39,32,99,111,117,108,100,32,110,111,116,32,98,101,32,99,111,109,112,105,108,101,100,0,97,108,108,111,99,97,116,105,110,103,32,97,110,32,105,100,101,110,116,105,116,121,45,99,111,110,115,116,114,97,105,110,116,32,100,101,102,105,110,105,116,105,111,110,0,0,0,0,35,97,108,108,0,0,0,0,101,120,116,101,110,115,105,111,110,0,0,0,0,0,0,0,114,101,115,116,114,105,99,116,105,111,110,0,0,0,0,0,115,117,98,115,116,105,116,117,116,105,111,110,0,0,0,0,108,105,115,116,0,0,0,0,117,110,105,111,110,0,0,0,116,114,117,101,0,0,0,0,102,97,108,115,101,0,0,0,48,0,0,0,0,0,0,0,97,108,108,111,99,97,116,105,110,103,32,101,108,101,109,101,110,116,0,0,0,0,0,0,82,101,100,101,102,105,110,105,116,105,111,110,32,111,102,32,98,117,105,108,116,45,105,110,32,115,105,109,112,108,101,32,116,121,112,101,115,32,105,115,32,110,111,116,32,115,117,112,112,111,114,116,101,100,0,0,40,35,97,108,108,32,124,32,76,105,115,116,32,111,102,32,40,108,105,115,116,32,124,32,117,110,105,111,110,32,124,32,114,101,115,116,114,105,99,116,105,111,110,41,0,0,0,0,40,97,110,110,111,116,97,116,105,111,110,63,44,32,40,114,101,115,116,114,105,99,116,105,111,110,32,124,32,108,105,115,116,32,124,32,117,110,105,111,110,41,41,0,0,0,0,0,84,104,105,115,32,105,115,32,97,32,114,101,100,101,102,105,110,105,116,105,111,110,44,32,116,104,117,115,32,116,104,101,32,60,115,105,109,112,108,101,84,121,112,101,62,32,109,117,115,116,32,104,97,118,101,32,97,32,60,114,101,115,116,114,105,99,116,105,111,110,62,32,99,104,105,108,100,0,0,0,120,109,108,83,99,104,101,109,97,80,97,114,115,101,85,110,105,111,110,44,32,97,108,108,111,99,97,116,105,110,103,32,97,32,116,121,112,101,32,108,105,110,107,0,0,0,0,0,40,97,110,110,111,116,97,116,105,111,110,63,44,32,115,105,109,112,108,101,84,121,112,101,42,41,0,0,0,0,0,0,69,105,116,104,101,114,32,116,104,101,32,97,116,116,114,105,98,117,116,101,32,39,109,101,109,98,101,114,84,121,112,101,115,39,32,111,114,32,97,116,32,108,101,97,115,116,32,111,110,101,32,60,115,105,109,112,108,101,84,121,112,101,62,32,99,104,105,108,100,32,109,117,115,116,32,98,101,32,112,114,101,115,101,110,116,0,0,0,84,104,101,32,97,116,116,114,105,98,117,116,101,32,39,105,116,101,109,84,121,112,101,39,32,97,110,100,32,116,104,101,32,60,115,105,109,112,108,101,84,121,112,101,62,32,99,104,105,108,100,32,97,114,101,32,109,117,116,117,97,108,108,121,32,101,120,99,108,117,115,105,118,101,0,0,0,0,0,0,69,105,116,104,101,114,32,116,104,101,32,97,116,116,114,105,98,117,116,101,32,39,105,116,101,109,84,121,112,101,39,32,111,114,32,116,104,101,32,60,115,105,109,112,108,101,84,121,112,101,62,32,99,104,105,108,100,32,109,117,115,116,32,98,101,32,112,114,101,115,101,110,116,0,0,0,0,0,0,0,84,104,105,115,32,105,115,32,97,32,114,101,100,101,102,105,110,105,116,105,111,110,44,32,98,117,116,32,116,104,101,32,81,78,97,109,101,32,118,97,108,117,101,32,39,37,115,39,32,111,102,32,116,104,101,32,39,98,97,115,101,39,32,97,116,116,114,105,98,117,116,101,32,100,111,101,115,32,110,111,116,32,109,97,116,99,104,32,116,104,101,32,116,121,112,101,39,115,32,100,101,115,105,103,110,97,116,105,111,110,32,39,37,115,39,0,0,0,0,0,84,104,101,32,97,116,116,114,105,98,117,116,101,32,39,98,97,115,101,39,32,97,110,100,32,116,104,101,32,60,115,105,109,112,108,101,84,121,112,101,62,32,99,104,105,108,100,32,97,114,101,32,109,117,116,117,97,108,108,121,32,101,120,99,108,117,115,105,118,101,0,0,69,105,116,104,101,114,32,116,104,101,32,97,116,116,114,105,98,117,116,101,32,39,98,97,115,101,39,32,111,114,32,97,32,60,115,105,109,112,108,101,84,121,112,101,62,32,99,104,105,108,100,32,109,117,115,116,32,98,101,32,112,114,101,115,101,110,116,0,0,0,0,0,97,108,108,111,99,97,116,105,110,103,32,97,32,102,97,99,101,116,32,108,105,110,107,0,97,110,110,111,116,97,116,105,111,110,63,44,32,40,103,114,111,117,112,32,124,32,97,108,108,32,124,32,99,104,111,105,99,101,32,124,32,115,101,113,117,101,110,99,101,41,63,44,32,40,40,97,116,116,114,105,98,117,116,101,32,124,32,97,116,116,114,105,98,117,116,101,71,114,111,117,112,41,42,44,32,97,110,121,65,116,116,114,105,98,117,116,101,63,41,41,0,0,0,0,0,0,0,0,40,97,110,110,111,116,97,116,105,111,110,63,44,32,40,115,105,109,112,108,101,84,121,112,101,63,44,32,40,109,105,110,69,120,99,108,117,115,105,118,101,32,124,32,109,105,110,73,110,99,108,117,115,105,118,101,32,124,32,109,97,120,69,120,99,108,117,115,105,118,101,32,124,32,109,97,120,73,110,99,108,117,115,105,118,101,32,124,32,116,111,116,97,108,68,105,103,105,116,115,32,124,32,102,114,97,99,116,105,111,110,68,105,103,105,116,115,32,124,32,108,101,110,103,116,104,32,124,32,109,105,110,76,101,110,103,116,104,32,124,32,109,97,120,76,101,110,103,116,104,32,124,32,101,110,117,109,101,114,97,116,105,111,110,32,124,32,119,104,105,116,101,83,112,97,99,101,32,124,32,112,97,116,116,101,114,110,41,42,41,63,44,32,40,40,97,116,116,114,105,98,117,116,101,32,124,32,97,116,116,114,105,98,117,116,101,71,114,111,117,112,41,42,44,32,97,110,121,65,116,116,114,105,98,117,116,101,63,41,41,0,0,0,0,0,0,0,0,40,97,110,110,111,116,97,116,105,111,110,63,44,32,40,115,105,109,112,108,101,84,121,112],"i8",ALLOC_NONE,Runtime.GLOBAL_BASE+156528),
	allocate([101,63,44,32,40,109,105,110,69,120,99,108,117,115,105,118,101,32,124,32,109,105,110,73,110,99,108,117,115,105,118,101,32,124,32,109,97,120,69,120,99,108,117,115,105,118,101,32,124,32,109,97,120,73,110,99,108,117,115,105,118,101,32,124,32,116,111,116,97,108,68,105,103,105,116,115,32,124,32,102,114,97,99,116,105,111,110,68,105,103,105,116,115,32,124,32,108,101,110,103,116,104,32,124,32,109,105,110,76,101,110,103,116,104,32,124,32,109,97,120,76,101,110,103,116,104,32,124,32,101,110,117,109,101,114,97,116,105,111,110,32,124,32,119,104,105,116,101,83,112,97,99,101,32,124,32,112,97,116,116,101,114,110,41,42,41,41,0,97,108,108,111,99,97,116,105,110,103,32,102,97,99,101,116,0,0,0,0,0,0,0,0,118,97,108,117,101,0,0,0,70,97,99,101,116,32,37,115,32,104,97,115,32,110,111,32,118,97,108,117,101,10,0,0,85,110,107,110,111,119,110,32,102,97,99,101,116,32,116,121,112,101,32,37,115,10,0,0,70,97,99,101,116,32,37,115,32,104,97,115,32,117,110,101,120,112,101,99,116,101,100,32,99,104,105,108,100,32,99,111,110,116,101,110,116,10,0,0,109,105,120,101,100,0,0,0,40,35,97,108,108,32,124,32,76,105,115,116,32,111,102,32,40,101,120,116,101,110,115,105,111,110,32,124,32,114,101,115,116,114,105,99,116,105,111,110,41,41,32,0,0,0,0,0,115,105,109,112,108,101,67,111,110,116,101,110,116,0,0,0,99,111,109,112,108,101,120,67,111,110,116,101,110,116,0,0,40,97,110,110,111,116,97,116,105,111,110,63,44,32,40,115,105,109,112,108,101,67,111,110,116,101,110,116,32,124,32,99,111,109,112,108,101,120,67,111,110,116,101,110,116,32,124,32,40,40,103,114,111,117,112,32,124,32,97,108,108,32,124,32,99,104,111,105,99,101,32,124,32,115,101,113,117,101,110,99,101,41,63,44,32,40,40,97,116,116,114,105,98,117,116,101,32,124,32,97,116,116,114,105,98,117,116,101,71,114,111,117,112,41,42,44,32,97,110,121,65,116,116,114,105,98,117,116,101,63,41,41,41,41,0,0,84,104,105,115,32,105,115,32,97,32,114,101,100,101,102,105,110,105,116,105,111,110,44,32,116,104,117,115,32,116,104,101,32,60,99,111,109,112,108,101,120,84,121,112,101,62,32,109,117,115,116,32,104,97,118,101,32,97,32,60,114,101,115,116,114,105,99,116,105,111,110,62,32,111,114,32,60,101,120,116,101,110,115,105,111,110,62,32,103,114,97,110,100,45,99,104,105,108,100,0,0,0,0,0,40,97,110,110,111,116,97,116,105,111,110,63,44,32,40,114,101,115,116,114,105,99,116,105,111,110,32,124,32,101,120,116,101,110,115,105,111,110,41,41,0,0,0,0,0,0,0,0,40,97,110,110,111,116,97,116,105,111,110,63,44,32,40,40,103,114,111,117,112,32,124,32,97,108,108,32,124,32,99,104,111,105,99,101,32,124,32,115,101,113,117,101,110,99,101,41,63,44,32,40,40,97,116,116,114,105,98,117,116,101,32,124,32,97,116,116,114,105,98,117,116,101,71,114,111,117,112,41,42,44,32,97,110,121,65,116,116,114,105,98,117,116,101,63,41,41,41,0,0,0,0,0,70,97,105,108,101,100,32,116,111,32,108,111,97,100,32,116,104,101,32,100,111,99,117,109,101,110,116,32,39,37,115,39,32,102,111,114,32,105,110,99,108,117,115,105,111,110,0,0,70,97,105,108,101,100,32,116,111,32,108,111,97,100,32,116,104,101,32,100,111,99,117,109,101,110,116,32,39,37,115,39,32,102,111,114,32,114,101,100,101,102,105,110,105,116,105,111,110,0,0,0,0,0,0,0,84,104,101,32,116,97,114,103,101,116,32,110,97,109,101,115,112,97,99,101,32,111,102,32,116,104,101,32,105,110,99,108,117,100,101,100,47,114,101,100,101,102,105,110,101,100,32,115,99,104,101,109,97,32,39,37,115,39,32,104,97,115,32,116,111,32,98,101,32,97,98,115,101,110,116,44,32,115,105,110,99,101,32,116,104,101,32,105,110,99,108,117,100,105,110,103,47,114,101,100,101,102,105,110,105,110,103,32,115,99,104,101,109,97,32,104,97,115,32,110,111,32,116,97,114,103,101,116,32,110,97,109,101,115,112,97,99,101,0,0,0,0,0,0,84,104,101,32,116,97,114,103,101,116,32,110,97,109,101,115,112,97,99,101,32,39,37,115,39,32,111,102,32,116,104,101,32,105,110,99,108,117,100,101,100,47,114,101,100,101,102,105,110,101,100,32,115,99,104,101,109,97,32,39,37,115,39,32,100,105,102,102,101,114,115,32,102,114,111,109,32,39,37,115,39,32,111,102,32,116,104,101,32,105,110,99,108,117,100,105,110,103,47,114,101,100,101,102,105,110,105,110,103,32,115,99,104,101,109,97,0,0,0,0,84,104,101,32,116,97,114,103,101,116,32,110,97,109,101,115,112,97,99,101,32,111,102,32,116,104,101,32,105,110,99,108,117,100,101,100,47,114,101,100,101,102,105,110,101,100,32,115,99,104,101,109,97,32,39,37,115,39,32,104,97,115,32,116,111,32,98,101,32,97,98,115,101,110,116,32,111,114,32,116,104,101,32,115,97,109,101,32,97,115,32,116,104,101,32,105,110,99,108,117,100,105,110,103,47,114,101,100,101,102,105,110,105,110,103,32,115,99,104,101,109,97,39,115,32,116,97,114,103,101,116,32,110,97,109,101,115,112,97,99,101,0,0,0,40,97,110,110,111,116,97,116,105,111,110,32,124,32,40,115,105,109,112,108,101,84,121,112,101,32,124,32,99,111,109,112,108,101,120,84,121,112,101,32,124,32,103,114,111,117,112,32,124,32,97,116,116,114,105,98,117,116,101,71,114,111,117,112,41,41,42,0,0,0,0,0,120,109,108,83,99,104,101,109,97,80,97,114,115,101,78,101,119,68,111,99,0,0,0,0,114,101,112,97,114,115,105,110,103,32,97,32,115,99,104,101,109,97,32,100,111,99,0,0,112,97,114,115,105,110,103,32,97,32,115,99,104,101,109,97,32,100,111,99,44,32,98,117,116,32,116,104,101,114,101,39,115,32,110,111,32,100,111,99,0,0,0,0,0,0,0,0,120,109,108,83,99,104,101,109,97,80,97,114,115,101,73,110,99,108,117,100,101,79,114,82,101,100,101,102,105,110,101,0,99,111,117,108,100,32,110,111,116,32,98,117,105,108,100,32,97,110,32,85,82,73,32,102,114,111,109,32,116,104,101,32,115,99,104,101,109,97,76,111,99,97,116,105,111,110,0,0,84,104,101,32,115,99,104,101,109,97,32,100,111,99,117,109,101,110,116,32,39,37,115,39,32,99,97,110,110,111,116,32,114,101,100,101,102,105,110,101,32,105,116,115,101,108,102,46,0,0,0,0,0,0,0,0,84,104,101,32,115,99,104,101,109,97,32,100,111,99,117,109,101,110,116,32,39,37,115,39,32,99,97,110,110,111,116,32,105,110,99,108,117,100,101,32,105,116,115,101,108,102,46,0,84,104,101,32,118,97,108,117,101,32,111,102,32,116,104,101,32,97,116,116,114,105,98,117,116,101,32,39,110,97,109,101,115,112,97,99,101,39,32,109,117,115,116,32,110,111,116,32,109,97,116,99,104,32,116,104,101,32,116,97,114,103,101,116,32,110,97,109,101,115,112,97,99,101,32,39,37,115,39,32,111,102,32,116,104,101,32,105,109,112,111,114,116,105,110,103,32,115,99,104,101,109,97,0,84,104,101,32,97,116,116,114,105,98,117,116,101,32,39,110,97,109,101,115,112,97,99,101,39,32,109,117,115,116,32,98,101,32,101,120,105,115,116,101,110,116,32,105,102,32,116,104,101,32,105,109,112,111,114,116,105,110,103,32,115,99,104,101,109,97,32,104,97,115,32,110,111,32,116,97,114,103,101,116,32,110,97,109,101,115,112,97,99,101,0,0,0,0,0,0,70,97,105,108,101,100,32,116,111,32,108,111,99,97,116,101,32,97,32,115,99,104,101,109,97,32,97,116,32,108,111,99,97,116,105,111,110,32,39,37,115,39,46,32,83,107,105,112,112,105,110,103,32,116,104,101,32,105,109,112,111,114,116,0,73,110,116,101,114,110,97,108,32,101,114,114,111,114,58,32,120,109,108,83,99,104,101,109,97,80,86,97,108,65,116,116,114,44,32,116,104,101,32,103,105,118,101,110,32,116,121,112,101,32,39,37,115,39,32,105,115,32,110,111,116,32,97,32,98,117,105,108,116,45,105,110,32,116,121,112,101,46,10,0,97,112,112,105,110,102,111,0,115,111,117,114,99,101,0,0,100,111,99,117,109,101,110,116,97,116,105,111,110,0,0,0,108,97,110,103,0,0,0,0,104,116,116,112,58,47,47,119,119,119,46,119,51,46,111,114,103,47,88,77,76,47,49,57,57,56,47,110,97,109,101,115,112,97,99,101,0,0,0,0,40,97,112,112,105,110,102,111,32,124,32,100,111,99,117,109,101,110,116,97,116,105,111,110,41,42,0,0,0,0,0,0,97,108,108,111,99,97,116,105,110,103,32,97,110,110,111,116,97,116,105,111,110,0,0,0,116,97,114,103,101,116,78,97,109,101,115,112,97,99,101,0,101,108,101,109,101,110,116,70,111,114,109,68,101,102,97,117,108,116,0,0,0,0,0,0,97,116,116,114,105,98,117,116,101,70,111,114,109,68,101,102,97,117,108,116,0,0,0,0,102,105,110,97,108,68,101,102,97,117,108,116,0,0,0,0,40,35,97,108,108,32,124,32,76,105,115,116,32,111,102,32,40,101,120,116,101,110,115,105,111,110,32,124,32,114,101,115,116,114,105,99,116,105,111,110,32,124,32,108,105,115,116,32,124,32,117,110,105,111,110,41,41,0,0,0,0,0,0,0,98,108,111,99,107,68,101,102,97,117,108,116,0,0,0,0,84,104,101,32,115,99,104,101,109,97,32,109,117,115,116,32,110,111,116,32,105,109,112,111,114,116,47,105,110,99,108,117,100,101,47,114,101,100,101,102,105,110,101,32,105,116,115,101,108,102,0,0,0,0,0,0,105,110,95,109,101,109,111,114,121,95,98,117,102,102,101,114,0,0,0,0,0,0,0,0,84,104,101,32,115,99,104,101,109,97,32,100,111,99,117,109,101,110,116,32,39,37,115,39,32,99,97,110,110,111,116,32,98,101,32,105,109,112,111,114,116,101,100,44,32,115,105,110,99,101,32,105,116,32,119,97,115,32,97,108,114,101,97,100,121,32,105,110,99,108,117,100,101,100,32,111,114,32,114,101,100,101,102,105,110,101,100,0,84,104,101,32,115,99,104,101,109,97,32,100,111,99,117,109,101,110,116,32,39,37,115,39,32,99,97,110,110,111,116,32,98,101,32,105,110,99,108,117,100,101,100,32,111,114,32,114,101,100,101,102,105,110,101,100,44,32,115,105,110,99,101,32,105,116,32,119,97,115,32,97,108,114,101,97,100,121,32,105,109,112,111,114,116,101,100,0,83,107,105,112,112,105,110,103,32,105,109,112,111,114,116,32,111,102,32,115,99,104,101,109,97,32,108,111,99,97,116,101,100,32,97,116,32,39,37,115,39,32,102,111,114,32,116,104,101,32,110,97,109,101,115,112,97,99,101,32,39,37,115,39,44,32,115,105,110,99,101,32,116,104,105,115,32,110,97,109,101,115,112,97,99,101,32,119,97,115,32,97,108,114,101,97,100,121,32,105,109,112,111,114,116,101,100,32,119,105,116,104,32,116,104,101,32,115,99,104,101,109,97,32,108,111,99,97,116,101,100,32,97,116,32,39,37,115,39,0,0,0,0,0,120,109,108,83,99,104,101,109,97,65,100,100,83,99,104,101,109,97,68,111,99,0,0,0,116,114,121,105,110,103,32,116,111,32,108,111,97,100,32,97,32,115,99,104,101,109,97,32,100,111,99,44,32,98,117,116,32,97,32,100,111,99,32,105,115,32,97,108,114,101,97,100,121,32,97,115,115,105,103,110,101,100,32,116,111,32,116,104,101,32,115,99,104,101,109,97,32,98,117,99,107,101,116,0,120,109,108,83,99,104,101,109,97,71,101,116,68,111,99,44,32,97,108,108,111,99,97,116,105,110,103,32,97,32,112,97,114,115,101,114,32,99,111,110,116,101,120,116,0,0,0,0,70,97,105,108,101,100,32,116,111,32,112,97,114,115,101,32,116,104,101,32,88,77,76,32,114,101,115,111,117,114,99,101,32,39,37,115,39,0,0,0,78,111,32,105,110,102,111,114,109,97,116,105,111,110,32,102,111,114,32,112,97,114,115,105,110,103,32,119,97,115,32,112,114,111,118,105,100,101,100,32,119,105,116,104,32,116,104,101,32,103,105,118,101,110,32,115,99,104,101,109,97,32,112,97,114,115,101,114,32,99,111,110,116,101,120,116,46,10,0,0,84,104,101,32,100,111,99,117,109,101,110,116,32,39,37,115,39,32,104,97,115,32,110,111,32,100,111,99,117,109,101,110,116,32,101,108,101,109,101,110,116,0,0,0,0,0,0,0,115,99,104,101,109,97,0,0,84,104,101,32,88,77,76,32,100,111,99,117,109,101,110,116,32,39,37,115,39,32,105,115,32,110,111,116,32,97,32,115,99,104,101,109,97,32,100,111,99,117,109,101,110,116,0,0,120,109,108,83,99,104,101,109,97,66,117,99,107,101,116,67,114,101,97,116,101,0,0,0,110,111,32,109,97,105,110,32,115,99,104,101,109,97,32,111,110,32,99,111,110,115,116,114,117,99,116,111,114,0,0,0,97,108,108,111,99,97,116,105,110,103,32,115,99,104,101,109,97,32,98,117,99,107,101,116,0,0,0,0,0,0,0,0,102,105,114,115,116,32,98,117,99,107,101,116,32,98,117,116,32,105,116,39,115,32,97,110,32,105,110,99,108,117,100,101,32,111,114,32,114,101,100,101,102,105,110,101,0,0,0,0,109,97,105,110,32,98,117,99,107,101,116,32,98,117,116,32,105,116,39,115,32,110,111,116,32,116,104,101,32,102,105,114,115,116,32,111,110,101,0,0,102,97,105,108,101,100,32,116,111,32,97,100,100,32,116,104,101,32,115,99,104,101,109,97,32,98,117,99,107,101,116,32,116,111,32,116,104,101,32,104,97,115,104,0,0,0,0,0,97,108,108,111,99,97,116,105,110,103,32,115,99,104,101,109,97,32,114,101,108,97,116,105,111,110,0,0,0,0,0,0,97,108,108,111,99,97,116,105,110,103,32,115,99,104,101,109,97,32,99,111,110,115,116,114,117,99,116,105,111,110,32,99,111,110,116,101,120,116,0,0,97,108,108,111,99,97,116,105,110,103,32,108,105,115,116,32,111,102,32,115,99,104,101,109,97,32,98,117,99,107,101,116,115,0,0,0,0,0,0,0,97,108,108,111,99,97,116,105,110,103,32,108,105,115,116,32,111,102,32,112,101,110,100,105,110,103,32,103,108,111,98,97,108,32,99,111,109,112,111,110,101,110,116,115,0,0,0,0,97,108,108,111,99,97,116,105,110,103,32,115,99,104,101,109,97,0,0,0,0,0,0,0,40,78,85,76,76,41,0,0,97,108,108,111,99,97,116,105,110,103,32,115,99,104,101,109,97,32,112,97,114,115,101,114,32,99,111,110,116,101,120,116,0,0,0,0,0,0,0,0,73,110,116,101,114,110,97,108,32,101,114,114,111,114,58,32,120,109,108,83,99,104,101,109,97,67,111,109,112,111,110,101,110,116,76,105,115,116,70,114,101,101,44,32,117,110,101,120,112,101,99,116,101,100,32,99,111,109,112,111,110,101,110,116,32,116,121,112,101,32,39,37,115,39,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,97,110,121,84,121,112,101,0,0,0,0,0,0,0,0,0,97,108,108,111,99,97,116,105,110,103,32,109,111,100,101,108,32,103,114,111,117,112,32,99,111,109,112,111,110,101,110,116,0,0,0,0,0,0,0,0,97,108,108,111,99,97,116,105,110,103,32,119,105,108,100,99,97,114,100,32,99,111,109,112,111,110,101,110,116,0,0,0,99,111,117,108,100,32,110,111,116,32,99,114,101,97,116,101,32,97,110,32,97,116,116,114,105,98,117,116,101,32,119,105,108,100,99,97,114,100,32,111,110,32,97,110,121,84,121,112,101,0,0,0,0,0,0,0,97,110,121,83,105,109,112,108,101,84,121,112,101,0,0,0,0,0,0,0,0,0,0,0,115,116,114,105,110,103,0,0,0,0,0,0,0,0,0,0,100,101,99,105,109,97,108,0,0,0,0,0,0,0,0,0,100,97,116,101,0,0,0,0,0,0,0,0,0,0,0,0,100,97,116,101,84,105,109,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,116,105,109,101,0,0,0,0,0,0,0,0,0,0,0,0,103,89,101,97,114,0,0,0,0,0,0,0,0,0,0,0,103,89,101,97,114,77,111,110,116,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,103,77,111,110,116,104,0,0,0,0,0,0,0,0,0,0,103,77,111,110,116,104,68,97,121,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,103,68,97,121,0,0,0,0,0,0,0,0,0,0,0,0,100,117,114,97,116,105,111,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,102,108,111,97,116,0,0,0,0,0,0,0,0,0,0,0,100,111,117,98,108,101,0,0,0,0,0,0,0,0,0,0,98,111,111,108,101,97,110,0,0,0,0,0,0,0,0,0,97,110,121,85,82,73,0,0,0,0,0,0,0,0,0,0,104,101,120,66,105,110,97,114,121,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,98,97,115,101,54,52,66,105,110,97,114,121,0,0,0,0,0,0,0,0,0,0,0,0,78,79,84,65,84,73,79,78,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,81,78,97,109,101,0,0,0,0,0,0,0,0,0,0,0,105,110,116,101,103,101,114,0,0,0,0,0,0,0,0,0,110,111,110,80,111,115,105,116,105,118,101,73,110,116,101,103,101,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,110,101,103,97,116,105,118,101,73,110,116,101,103,101,114,0,0,0,0,0,0,0,0,0,108,111,110,103,0,0,0,0,0,0,0,0,0,0,0,0,105,110,116,0,0,0,0,0,0,0,0,0,0,0,0,0,115,104,111,114,116,0,0,0,0,0,0,0,0,0,0,0,98,121,116,101,0,0,0,0,0,0,0,0,0,0,0,0,110,111,110,78,101,103,97,116,105,118,101,73,110,116,101,103,101,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,117,110,115,105,103,110,101,100,76,111,110,103,0,0,0,0,0,0,0,0,0,0,0,0,117,110,115,105,103,110,101,100,73,110,116,0,0,0,0,0,0,0,0,0,0,0,0,0,117,110,115,105,103,110,101,100,83,104,111,114,116,0,0,0,0,0,0,0,0,0,0,0,117,110,115,105,103,110,101,100,66,121,116,101,0,0,0,0,0,0,0,0,0,0,0,0,112,111,115,105,116,105,118,101,73,110,116,101,103,101,114,0,0,0,0,0,0,0,0,0,110,111,114,109,97,108,105,122,101,100,83,116,114,105,110,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,116,111,107,101,110,0,0,0,0,0,0,0,0,0,0,0,108,97,110,103,117,97,103,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,78,97,109,101,0,0,0,0,0,0,0,0,0,0,0,0,78,77,84,79,75,69,78,0,0,0,0,0,0,0,0,0,78,67,78,97,109,101,0,0,0,0,0,0,0,0,0,0,73,68,0,0,0,0,0,0,0,0,0,0,0,0,0,0,73,68,82,69,70,0,0,0,0,0,0,0,0,0,0,0,69,78,84,73,84,89,0,0,0,0,0,0,0,0,0,0,69,78,84,73,84,73,69,83,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,73,68,82,69,70,83,0,0,0,0,0,0,0,0,0,0,78,77,84,79,75,69,78,83,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,123,0,0,0,0,0,0,0,125,0,0,0,0,0,0,0,48,46,48,0,0,0,0,0,37,108,117,37,108,117,37,108,117,0,0,0,0,0,0,0,37,108,117,37,108,117,0,0,37,108,117,0,0,0,0,0,48,0,0,0,0,0,0,0,45,37,108,117,37,108,117,37,108,117,0,0,0,0,0,0,45,37,108,117,37,108,117,0,45,37,108,117,0,0,0,0,116,114,117,101,0,0,0,0,102,97,108,115,101,0,0,0,80,37,108,117,89,37,108,117,77,37,108,117,68,84,37,108,117,72,37,108,117,77,37,46,49,52,103,83,0,0,0,0,45,80,37,108,117,89,37,108,117,77,37,108,117,68,84,37,108,117,72,37,108,117,77,37,46,49,52,103,83,0,0,0,37,48,52,108,100,0,0,0,45,45,37,48,50,117,0,0,45,45,45,37,48,50,117,0,45,45,37,48,50,117,45,37,48,50,117,0,0,0,0,0,45,37,48,52,108,100,45,37,48,50,117,0,0,0,0,0,37,48,52,108,100,45,37,48,50,117,0,0,0,0,0,0,37,48,50,117,58,37,48,50,117,58,37,48,50,46,49,52,103,90,0,0,0,0,0,0,37,48,50,117,58,37,48,50,117,58,37,48,50,46,49,52,103,0,0,0,0,0,0,0,37,48,52,108,100,58,37,48,50,117,58,37,48,50,117,90,0,0,0,0,0,0,0,0,37,48,52,108,100,58,37,48,50,117,58,37,48,50,117,0,37,48,52,108,100,58,37,48,50,117,58,37,48,50,117,84,37,48,50,117,58,37,48,50,117,58,37,48,50,46,49,52,103,90,0,0,0,0,0,0,37,48,52,108,100,58,37,48,50,117,58,37,48,50,117,84,37,48,50,117,58,37,48,50,117,58,37,48,50,46,49,52,103,0,0,0,0,0,0,0,37,48,49,46,49,52,101,0,63,63,63,0,0,0,0,0,31,0,0,0,29,0,0,0,31,0,0,0,30,0,0,0,31,0,0,0,30,0,0,0,31,0,0,0,31,0,0,0,30,0,0,0,31,0,0,0,30,0,0,0,31,0,0,0,31,0,0,0,28,0,0,0,31,0,0,0,30,0,0,0,31,0,0,0,30,0,0,0,31,0,0,0,31,0,0,0,30,0,0,0,31,0,0,0,30,0,0,0,31,0,0,0,85,110,105,109,112,108,101,109,101,110,116,101,100,32,98,108,111,99,107,32,97,116,32,37,115,58,37,100,10,0,0,0,46,46,47,108,105,98,120,109,108,50,47,120,109,108,115,99,104,101,109,97,115,116,121,112,101,115,46,99,0,0,0,0,0,0,0,0,31,0,0,0,60,0,0,0,91,0,0,0,121,0,0,0,152,0,0,0,182,0,0,0,213,0,0,0,244,0,0,0,18,1,0,0,49,1,0,0,79,1,0,0,0,0,0,0,31,0,0,0,59,0,0,0,90,0,0,0,120,0,0,0,151,0,0,0,181,0,0,0,212,0,0,0,243,0,0,0,17,1,0,0,48,1,0,0,78,1,0,0,0,0,0,0,28,0,0,0,59,0,0,0,89,0,0,0,120,0,0,0,150,0,0,0,181,0,0,0,212,0,0,0,242,0,0,0,17,1,0,0,47,1,0,0,78,1,0,0,0,0,0,0,31,0,0,0,62,0,0,0,92,0,0,0,123,0,0,0,153,0,0,0,184,0,0,0,215,0,0,0,245,0,0,0,20,1,0,0,50,1,0,0,81,1,0,0,37,102,0,0,0,0,0,0,37,108,102,0,0,0,0,0,97,108,108,111,99,97,116,105,110,103,32,104,101,120,98,105,110,32,100,97,116,97,0,0,97,108,108,111,99,97,116,105,110,103,32,98,97,115,101,54,52,32,100,97,116,97,0,0,89,77,68,72,77,83,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,245,64,0,0,0,0,0,32,172,64,0,0,0,0,0,0,78,64,0,0,0,0,0,0,240,63,0,0,0,0,0,0,0,0,97,108,108,111,99,97,116,105,110,103,32,112,97,114,116,105,99,108,101,32,99,111,109,112,111,110,101,110,116,0,0,0,99,111,117,108,100,32,110,111,116,32,105,110,105,116,105,97,108,105,122,101,32,98,97,115,105,99,32,116,121,112,101,115,0,0,0,0,0,0,0,0,104,116,116,112,58,47,47,119,119,119,46,119,51,46,111,114,103,47,50,48,48,49,47,88,77,76,83,99,104,101,109,97,0,0,0,0,0,0,0,0,16,206,2,0,128,0,0,0,18,0,0,0,7,0,0,0,144,205,2,0,216,205,2,0,11,0,0,0,3,0,0,0,72,205,2,0,120,205,2,0,23,1,0,0,50,0,0,0,88,199,2,0,184,203,2,0,140,1,0,0,28,0,0,0,72,192,2,0,120,198,2,0,20,0,0,0,0,0,0,0,248,191,2,0,0,0,0,0,211,0,0,0,20,0,0,0,8,188,2,0,88,191,2,0,10,0,0,0,0,0,0,0,224,187,2,0,0,0,0,0,134,1,0,0,31,0,0,0,208,180,2,0,232,186,2,0,113,0,0,0,6,0,0,0,216,178,2,0,160,180,2,0,55,0,0,0,2,0,0,0,232,177,2,0,200,178,2,0,108,0,0,0,5,0,0,0,16,176,2,0,192,177,2,0,42,0,0,0,5,0,0,0,64,175,2,0,232,175,2,0,21,0,0,0,2,0,0,0,216,174,2,0,48,175,2,0,20,0,0,0,2,0,0,0,120,174,2,0,200,174,2,0,84,0,0,0,2,0,0,0,24,173,2,0,104,174,2,0,11,0,0,0,0,0,0,0,232,172,2,0,0,0,0,0,63,0,0,0,0,0,0,0,232,171,2,0,0,0,0,0,72,0,0,0,2,0,0,0,184,170,2,0,216,171,2,0,65,0,0,0,0,0,0,0,176,169,2,0,0,0,0,0,133,0,0,0,20,0,0,0,248,166,2,0,16,169,2,0,13,0,0,0,0,0,0,0,192,166,2,0,0,0,0,0,22,0,0,0,0,0,0,0,104,166,2,0,0,0,0,0,48,0,0,0,10,0,0,0,88,165,2,0,24,166,2,0,103,0,0,0,10,0,0,0,104,163,2,0,8,165,2,0,9,0,0,0,0,0,0,0,64,163,2,0,0,0,0,0,32,0,32,0,160,0,160,0,128,22,128,22,14,24,14,24,0,32,10,32,40,32,41,32,47,32,47,32,95,32,95,32,0,48,0,48,0,0,0,0,166,0,167,0,169,0,169,0,174,0,174,0,176,0,176,0,182,0,182,0,130,4,130,4,14,6,15,6,233,6,233,6,253,6,254,6,250,9,250,9,112,11,112,11,243,11,248,11,250,11,250,11,1,15,3,15,19,15,23,15,26,15,31,15,52,15,52,15,54,15,54,15,56,15,56,15,190,15,197,15,199,15,204,15,207,15,207,15,64,25,64,25,224,25,255,25,0,33,1,33,3,33,6,33,8,33,9,33,20,33,20,33,22,33,24,33,30,33,35,33,37,33,37,33,39,33,39,33,41,33,41,33,46,33,46,33,50,33,50,33,58,33,59,33,74,33,74,33,149,33,153,33,156,33,159,33,161,33,162,33,164,33,165,33,167,33,173,33,175,33,205,33,208,33,209,33,211,33,211,33,213,33,243,33,0,35,7,35,12,35,31,35,34,35,40,35,43,35,123,35,125,35,154,35,183,35,208,35,0,36,38,36,64,36,74,36,156,36,233,36,0,37,182,37,184,37,192,37,194,37,247,37,0,38,23,38,25,38,110,38,112,38,125,38,128,38,145,38,160,38,161,38,1,39,4,39,6,39,9,39,12,39,39,39,41,39,75,39,77,39,77,39,79,39,82,39,86,39,86,39,88,39,94,39,97,39,103,39,148,39,148,39,152,39,175,39,177,39,190,39,0,40,255,40,0,43,13,43,128,46,153,46,155,46,243,46,0,47,213,47,240,47,251,47,4,48,4,48,18,48,19,48,32,48,32,48,54,48,55,48,62,48,63,48,144,49,145,49,150,49,159,49,0,50,30,50,42,50,67,50,80,50,80,50,96,50,125,50,127,50,127,50,138,50,176,50,192,50,254,50,0,51,255,51,192,77,255,77,144,164,198,164,253,253,253,253,228,255,228,255,232,255,232,255,237,255,238,255,252,255,253,255,0,0,0,0,2,1,1,0,2,1,1,0,55,1,1,0,63,1,1,0,0,208,1,0,245,208,1,0,0,209,1,0,38,209,1,0,42,209,1,0,100,209,1,0,106,209,1,0,108,209,1,0,131,209,1,0,132,209,1,0,140,209,1,0,169,209,1,0,174,209,1,0,221,209,1,0,0,211,1,0,86,211,1,0,43,0,43,0,60,0,62,0,124,0,124,0,126,0,126,0,172,0,172,0,177,0,177,0,215,0,215,0,247,0,247,0,246,3,246,3,68,32,68,32,82,32,82,32,122,32,124,32,138,32,140,32,64,33,68,33,75,33,75,33,144,33,148,33,154,33,155,33,160,33,160,33,163,33,163,33,166,33,166,33,174,33,174,33,206,33,207,33,210,33,210,33,212,33,212,33,244,33,255,34,8,35,11,35,32,35,33,35,124,35,124,35,155,35,179,35,183,37,183,37,193,37,193,37,248,37,255,37,111,38,111,38,208,39,229,39,240,39,255,39,0,41,130,41,153,41,215,41,220,41,251,41,254,41,255,42,41,251,41,251,98,254,98,254,100,254,102,254,11,255,11,255,28,255,30,255,92,255,92,255,94,255,94,255,226,255,226,255,233,255,236,255,193,214,1,0,193,214,1,0,219,214,1,0,219,214,1,0,251,214,1,0,251,214,1,0,21,215,1,0,21,215,1,0,53,215,1,0,53,215,1,0,79,215,1,0,79,215,1,0,111,215,1,0,111,215,1,0,137,215,1,0,137,215,1,0,169,215,1,0,169,215,1,0,195,215,1,0,195,215,1,0,94,0,94,0,96,0,96,0,168,0,168,0,175,0,175,0,180,0,180,0,184,0,184,0,194,2,197,2,210,2,223,2,229,2,237,2,239,2,255,2,116,3,117,3,132,3,133,3,189,31,189,31,191,31,193,31,205,31,207,31,221,31,223,31,237,31,239,31,253,31,254,31,155,48,156,48,62,255,62,255,64,255,64,255,227,255,227,255,36,0,36,0,162,0,165,0,242,9,243,9,241,10,241,10,249,11,249,11,63,14,63,14,219,23,219,23,160,32,177,32,252,253,252,253,105,254,105,254,4,255,4,255,224,255,225,255,229,255,230,255,0,0,0,0,36,0,36,0,43,0,43,0,60,0,62,0,94,0,94,0,96,0,96,0,124,0,124,0,126,0,126,0,162,0,169,0,172,0,172,0,174,0,177,0,180,0,180,0,182,0,182,0,184,0,184,0,215,0,215,0,247,0,247,0,194,2,197,2,210,2,223,2,229,2,237,2,239,2,255,2,116,3,117,3,132,3,133,3,246,3,246,3,130,4,130,4,14,6,15,6,233,6,233,6,253,6,254,6,242,9,243,9,250,9,250,9,241,10,241,10,112,11,112,11,243,11,250,11,63,14,63,14,1,15,3,15,19,15,23,15,26,15,31,15,52,15,52,15,54,15,54,15,56,15,56,15,190,15,197,15,199,15,204,15,207,15,207,15,219,23,219,23,64,25,64,25,224,25,255,25,189,31,189,31,191,31,193,31,205,31,207,31,221,31,223,31,237,31,239,31,253,31,254,31,68,32,68,32,82,32,82,32,122,32,124,32,138,32,140,32,160,32,177,32,0,33,1,33,3,33,6,33,8,33,9,33,20,33,20,33,22,33,24,33,30,33,35,33,37,33,37,33,39,33,39,33,41,33,41,33,46,33,46,33,50,33,50,33,58,33,59,33,64,33,68,33,74,33,75,33,144,33,40,35,43,35,179,35,183,35,208,35,0,36,38,36,64,36,74,36,156,36,233,36,0,37,23,38,25,38,125,38,128,38,145,38,160,38,161,38,1,39,4,39,6,39,9,39,12,39,39,39,41,39,75,39,77,39,77,39,79,39,82,39,86,39,86,39,88,39,94,39,97,39,103,39,148,39,148,39,152,39,175,39,177,39,190,39,208,39,229,39,240,39,130,41,153,41,215,41,220,41,251,41,254,41,13,43,128,46,153,46,155,46,243,46,0,47,213,47,240,47,251,47,4,48,4,48,18,48,19,48,32,48,32,48,54,48,55,48,62,48,63,48,155,48,156,48,144,49,145,49,150,49,159,49,0,50,30,50,42,50,67,50,80,50,80,50,96,50,125,50,127,50,127,50,138,50,176,50,192,50,254,50,0,51,255,51,192,77,255,77,144,164,198,164,41,251,41,251,252,253,253,253,98,254,98,254,100,254,102,254,105,254,105,254,4,255,4,255,11,255,11,255,28,255,30,255,62,255,62,255,64,255,64,255,92,255,92,255,94,255,94,255,224,255,230,255,232,255,238,255,252,255,253,255,0,0,0,0,2,1,1,0,2,1,1,0,55,1,1,0,63,1,1,0,0,208,1,0,245,208,1,0,0,209,1,0,38,209,1,0,42,209,1,0,100,209,1,0,106,209,1,0,108,209,1,0,131,209,1,0,132,209,1,0,140,209,1,0,169,209,1,0,174,209,1,0,221,209,1,0,0,211,1,0,86,211,1,0,193,214,1,0,193,214,1,0,219,214,1,0,219,214,1,0,251,214,1,0,251,214,1,0,21,215,1,0,21,215,1,0,53,215,1,0,53,215,1,0,79,215,1,0,79,215,1,0,111,215,1,0,111,215,1,0,137,215,1,0,137,215,1,0,169,215,1,0,169,215,1,0,195,215,1,0,195,215,1,0,40,0,40,0,91,0,91,0,123,0,123,0,58,15,58,15,60,15,60,15,155,22,155,22,26,32,26,32,30,32,30,32,69,32,69,32,125,32,125,32,141,32,141,32,41,35,41,35,180,35,180,35,104,39,104,39,106,39,106,39,108,39,108,39,110,39,110,39,112,39,112,39,114,39,114,39,116,39,116,39,230,39,230,39,232,39,232,39,234,39,234,39,131,41,131,41,133,41,133,41,135,41,135,41,137,41,137,41,139,41,139,41,141,41,141,41,143,41,143,41,145,41,145,41,147,41,147,41,149,41,149,41,151,41,151,41,216,41,216,41,218,41,218,41,252,41,252,41,8,48,8,48,10,48,10,48,12,48,12,48,14,48,14,48,16,48,16,48,20,48,20,48,22,48,22,48,24,48,24,48,26,48,26,48,29,48,29,48,62,253,62,253,53,254,53,254,55,254,55,254,57,254,57,254,59,254,59,254,61,254,61,254,63,254,63,254,65,254,65,254,67,254,67,254,71,254,71,254,89,254,89,254,91,254,91,254,93,254,93,254,8,255,8,255,59,255,59,255,91,255,91,255,95,255,95,255,98,255,98,255,0,0,0,0,33,0,35,0,37,0,39,0,42,0,42,0,44,0,44,0,46,0,47,0,58,0,59,0,63,0,64,0,92,0,92,0,161,0,161,0,183,0,183,0,191,0,191,0,126,3,126,3,135,3,135,3,90,5,95,5,137,5,137,5,190,5,190,5,192,5,192,5,195,5,195,5,243,5,244,5,12,6,13,6,27,6,27,6,31,6,31,6,106,6,109,6,212,6,212,6,0,7,13,7,100,9,101,9,112,9,112,9,244,13,244,13,79,14,79,14,90,14,91,14,4,15,18,15,133,15,133,15,74,16,79,16,251,16,251,16,97,19,104,19,109,22,110,22,235,22,237,22,53,23,54,23,212,23,214,23,216,23,218,23,0,24,5,24,7,24,10,24,68,25,69,25,22,32,23,32,32,32,39,32,48,32,56,32,59,32,62,32,65,32,67,32,71,32,81,32,83,32,83,32,87,32,87,32,182,35,182,35,1,48,3,48,61,48,61,48,48,254,48,254,69,254,70,254,73,254,76,254,80,254,82,254,84,254,87,254,95,254,97,254,104,254,104,254,106,254,107,254,1,255,3,255,5,255,7,255,10,255,10,255,12,255,12,255,14,255,15,255,26,255,27,255,31,255,32,255,60,255,60,255,97,255,97,255,100,255,100,255,0,1,1,0,1,1,1,0,159,3,1,0,159,3,1,0,41,0,41,0,93,0,93,0,125,0,125,0,59,15,59,15,61,15,61,15,156,22,156,22,70,32,70,32,126,32,126,32,142,32,142,32,42,35,42,35,181,35,181,35,105,39,105,39,107,39,107,39,109,39,109,39,111,39,111,39,113,39,113,39,115,39,115,39,117,39,117,39,231,39,231,39,233,39,233,39,235,39,235,39,132,41,132,41,134,41,134,41,136,41,136,41,138,41,138,41,140,41,140,41,142,41,142,41,144,41,144,41,146,41,146,41,148,41,148,41,150,41,150,41,152,41,152,41,217,41,217,41,219,41,219,41,253,41,253,41,9,48,9,48,11,48,11,48,13,48,13,48,15,48,15,48,17,48,17,48,21,48,21,48,23,48,23,48,25,48,25,48,27,48,27,48,30,48,31,48,63,253,63,253,54,254,54,254,56,254,56,254,58,254,58,254,60,254,60,254,62,254,62,254,64,254,64,254,66,254,66,254,68,254,68,254,72,254,72,254,90,254,90,254,92,254,92,254,94,254,94,254,9,255,9,255,61,255,61,255,93,255,93,255,96,255,96,255,99,255,99,255,0,0,0,0,45,0,45,0,138,5,138,5,6,24,6,24,16,32,21,32,28,48,28,48,48,48,48,48,160,48,160,48,49,254,50,254,88,254,88,254,99,254,99,254,13,255,13,255,0,0,0,0,33,0,35,0,37,0,42,0,44,0,47,0,58,0,59,0,63,0,64,0,91,0,93,0,95,0,95,0,123,0,123,0,125,0,125,0,161,0,161,0,171,0,171,0,183,0,183,0,187,0,187,0,191,0,191,0,126,3,126,3,135,3,135,3,90,5,95,5,137,5,138,5,190,5,190,5,192,5,192,5,195,5,195,5,243,5,244,5,12,6,13,6,27,6,27,6,31,6,31,6,106,6,109,6,212,6,212,6,0,7,13,7,100,9,101,9,112,9,112,9,244,13,244,13,79,14,79,14,90,14,91,14,4,15,18,15,58,15,61,15,133,15,133,15,74,16,79,16,251,16,251,16,97,19,104,19,109,22,110,22,155,22,156,22,235,22,237,22,53,23,54,23,212,23,214,23,216,23,218,23,0,24,10,24,68,25,69,25,16,32,39,32,48,32,67,32,69,32,81,32,83,32,84,32,87,32,87,32,125,32,126,32,141,32,142,32,41,35,42,35,180,35,182,35,104,39,117,39,230,39,235,39,131,41,152,41,216,41,219,41,252,41,253,41,1,48,3,48,8,48,17,48,20,48,31,48,48,48,48,48,61,48,61,48,160,48,160,48,251,48,251,48,62,253,63,253,48,254,82,254,84,254,97,254,99,254,99,254,104,254,104,254,106,254,107,254,1,255,3,255,5,255,10,255,12,255,15,255,26,255,27,255,31,255,32,255,59,255,61,255,63,255,63,255,91,255,91,255,93,255,93,255,95,255,101,255,0,1,1,0,1,1,1,0,159,3,1,0,159,3,1,0,178,0,179,0,185,0,185,0,188,0,190,0,244,9,249,9,240,11,242,11,42,15,51,15,114,19,124,19,240,23,249,23,112,32,112,32,116,32,121,32,128,32,137,32,83,33,95,33,96,36,155,36,234,36,255,36,118,39,147,39,146,49,149,49,32,50,41,50,81,50,95,50,128,50,137,50,177,50,191,50,7,1,1,0,51,1,1,0,32,3,1,0,35,3,1,0,48,0,57,0,96,6,105,6,240,6,249,6,102,9,111,9,230,9,239,9,102,10,111,10,230,10,239,10,102,11,111,11,231,11,239,11,102,12,111,12,230,12,239,12,102,13,111,13,80,14,89,14,208,14,217,14,32,15,41,15,64,16,73,16,105,19,113,19,224,23,233,23,16,24,25,24,70,25,79,25,16,255,25,255,0,0,0,0,160,4,1,0,169,4,1,0,206,215,1,0,255,215,1,0,48,0,57,0,178,0,179,0,185,0,185,0,188,0,190,0,96,6,105,6,240,6,249,6,102,9,111,9,230,9,239,9,244,9,249,9,102,10,111,10,230,10,239,10,102,11,111,11,231,11,242,11,102,12,111,12,230,12,239,12,102,13,111,13,80,14,89,14,208,14,217,14,32,15,51,15,64,16,73,16,105,19,124,19,238,22,240,22,224,23,233,23,240,23,249,23,16,24,25,24,70,25,79,25,112,32,112,32,116,32,121,32,128,32,137,32,83,33,131,33,96,36,155,36,234,36,255,36,118,39,147,39,7,48,7,48,33,48,41,48,56,48,58,48,146,49,149,49,32,50,41,50,81,50,95,50,128,50,137,50,177,50,191,50,16,255,25,255,7,1,1,0,51,1,1,0,32,3,1,0,35,3,1,0,74,3,1,0,74,3,1,0,160,4,1,0,169,4,1,0,206,215,1,0,255,215,1,0,0,3,87,3,93,3,111,3,131,4,134,4,145,5,161,5,163,5,185,5,187,5,189,5,191,5,191,5,193,5,194,5,196,5,196,5,16,6,21,6,75,6,88,6,112,6,112,6,214,6,220,6,223,6,228,6,231,6,232,6,234,6,237,6,17,7,17,7,48,7,74,7,166,7,176,7,1,9,2,9,60,9,60,9,65,9,72,9,77,9,77,9,81,9,84,9,98,9,99,9,129,9,129,9,188,9,188,9,193,9,196,9,205,9,205,9,226,9,227,9,1,10,2,10,60,10,60,10,65,10,66,10,71,10,72,10,75,10,77,10,112,10,113,10,129,10,130,10,188,10,188,10,193,10,197,10,199,10,200,10,205,10,205,10,226,10,227,10,1,11,1,11,60,11,60,11,63,11,63,11,65,11,67,11,77,11,77,11,86,11,86,11,130,11,130,11,192,11,192,11,205,11,205,11,62,12,64,12,70,12,72,12,74,12,77,12,85,12,86,12,188,12,188,12,191,12,191,12,198,12,198,12,204,12,205,12,65,13,67,13,77,13,77,13,202,13,202,13,210,13,212,13,214,13,214,13,49,14,49,14,52,14,58,14,71,14,78,14,177,14,177,14,180,14,185,14,187,14,188,14,200,14,205,14,24,15,25,15,53,15,53,15,55,15,55,15,57,15,57,15,113,15,126,15,128,15,132,15,134,15,135,15,144,15,151,15,153,15,188,15,198,15,198,15,45,16,48,16,50,16,50,16,54,16,55,16,57,16,57,16,88,16,89,16,18,23,20,23,50,23,52,23,82,23,83,23,114,23,115,23,183,23,189,23,198,23,198,23,201,23,211,23,221,23,221,23,11,24,13,24,169,24,169,24,32,25,34,25,39,25,40,25,50,25,50,25,57,25,59,25,208,32,220,32,225,32,225,32,229,32,234,32,42,48,47,48,153,48,154,48,30,251,30,251,0,254,15,254,32,254,35,254,103,209,1,0,105,209,1,0,123,209,1,0,130,209,1,0,133,209,1,0,139,209,1,0,170,209,1,0,173,209,1,0,0,1,14,0,239,1,14,0,3,9,3,9,62,9,64,9,73,9,76,9,130,9,131,9,190,9,192,9,199,9,200,9,203,9,204,9,215,9,215,9,3,10,3,10,62,10,64,10,131,10,131,10,190,10,192,10,201,10,201,10,203,10,204,10,2,11,3,11,62,11,62,11,64,11,64,11,71,11,72,11,75,11,76,11,87,11,87,11,190,11,191,11,193,11,194,11,198,11,200,11,202,11,204,11,215,11,215,11,1,12,3,12,65,12,68,12,130,12,131,12,190,12,190,12,192,12,196,12,199,12,200,12,202,12,203,12,213,12,214,12,2,13,3,13,62,13,64,13,70,13,72,13,74,13,76,13,87,13,87,13,130,13,131,13,207,13,209,13,216,13,223,13,242,13,243,13,62,15,63,15,127,15,127,15,44,16,44,16,49,16,49,16,56,16,56,16,86,16,87,16,182,23,182,23,190,23,197,23,199,23,200,23,35,25,38,25,41,25,43,25,48,25,49,25,51,25,56,25,0,0,0,0,101,209,1,0,102,209,1,0,109,209,1,0,114,209,1,0,0,3,87,3,93,3,111,3,131,4,134,4,136,4,137,4,145,5,161,5,163,5,185,5,187,5,189,5,191,5,191,5,193,5,194,5,196,5,196,5,16,6,21,6,75,6,88,6,112,6,112,6,214,6,220,6,222,6,228,6,231,6,232,6,234,6,237,6,17,7,17,7,48,7,74,7,166,7,176,7,1,9,3,9,60,9,60,9,62,9,77,9,81,9,84,9,98,9,99,9,129,9,131,9,188,9,188,9,190,9,196,9,199,9,200,9,203,9,205,9,215,9,215,9,226,9,227,9,1,10,3,10,60,10,60,10,62,10,66,10,71,10,72,10,75,10,77,10,112,10,113,10,129,10,131,10,188,10,188,10],"i8",ALLOC_NONE,Runtime.GLOBAL_BASE+166768),
	allocate([190,10,197,10,199,10,201,10,203,10,205,10,226,10,227,10,1,11,3,11,60,11,60,11,62,11,67,11,71,11,72,11,75,11,77,11,86,11,87,11,130,11,130,11,190,11,194,11,198,11,200,11,202,11,205,11,215,11,215,11,1,12,3,12,62,12,68,12,70,12,72,12,74,12,77,12,85,12,86,12,130,12,131,12,188,12,188,12,190,12,196,12,198,12,200,12,202,12,205,12,213,12,214,12,2,13,3,13,62,13,67,13,70,13,72,13,74,13,77,13,87,13,87,13,130,13,131,13,202,13,202,13,207,13,212,13,214,13,214,13,216,13,223,13,242,13,243,13,49,14,49,14,52,14,58,14,71,14,78,14,177,14,177,14,180,14,185,14,187,14,188,14,200,14,205,14,24,15,25,15,53,15,53,15,55,15,55,15,57,15,57,15,62,15,63,15,113,15,132,15,134,15,135,15,144,15,151,15,153,15,188,15,198,15,198,15,44,16,50,16,54,16,57,16,86,16,89,16,18,23,20,23,50,23,52,23,82,23,83,23,114,23,115,23,182,23,211,23,221,23,221,23,11,24,13,24,169,24,169,24,32,25,43,25,48,25,59,25,208,32,234,32,42,48,47,48,153,48,154,48,30,251,30,251,0,254,15,254,32,254,35,254,0,0,0,0,101,209,1,0,105,209,1,0,109,209,1,0,114,209,1,0,123,209,1,0,130,209,1,0,133,209,1,0,139,209,1,0,170,209,1,0,173,209,1,0,0,1,14,0,239,1,14,0,65,0,90,0,192,0,214,0,216,0,222,0,0,1,0,1,2,1,2,1,4,1,4,1,6,1,6,1,8,1,8,1,10,1,10,1,12,1,12,1,14,1,14,1,16,1,16,1,18,1,18,1,20,1,20,1,22,1,22,1,24,1,24,1,26,1,26,1,28,1,28,1,30,1,30,1,32,1,32,1,34,1,34,1,36,1,36,1,38,1,38,1,40,1,40,1,42,1,42,1,44,1,44,1,46,1,46,1,48,1,48,1,50,1,50,1,52,1,52,1,54,1,54,1,57,1,57,1,59,1,59,1,61,1,61,1,63,1,63,1,65,1,65,1,67,1,67,1,69,1,69,1,71,1,71,1,74,1,74,1,76,1,76,1,78,1,78,1,80,1,80,1,82,1,82,1,84,1,84,1,86,1,86,1,88,1,88,1,90,1,90,1,92,1,92,1,94,1,94,1,96,1,96,1,98,1,98,1,100,1,100,1,102,1,102,1,104,1,104,1,106,1,106,1,108,1,108,1,110,1,110,1,112,1,112,1,114,1,114,1,116,1,116,1,118,1,118,1,120,1,121,1,123,1,123,1,125,1,125,1,129,1,130,1,132,1,132,1,134,1,135,1,137,1,139,1,142,1,145,1,147,1,148,1,150,1,152,1,156,1,157,1,159,1,160,1,162,1,162,1,164,1,164,1,166,1,167,1,169,1,169,1,172,1,172,1,174,1,175,1,177,1,179,1,181,1,181,1,183,1,184,1,188,1,188,1,196,1,196,1,199,1,199,1,202,1,202,1,205,1,205,1,207,1,207,1,209,1,209,1,211,1,211,1,213,1,213,1,215,1,215,1,217,1,217,1,219,1,219,1,222,1,222,1,224,1,224,1,226,1,226,1,228,1,228,1,230,1,230,1,232,1,232,1,234,1,234,1,236,1,236,1,238,1,238,1,241,1,241,1,244,1,244,1,246,1,248,1,250,1,250,1,252,1,252,1,254,1,254,1,0,2,0,2,2,2,2,2,4,2,4,2,6,2,6,2,8,2,8,2,10,2,10,2,12,2,12,2,14,2,14,2,16,2,16,2,18,2,18,2,20,2,20,2,22,2,22,2,24,2,24,2,26,2,26,2,28,2,28,2,30,2,30,2,32,2,32,2,34,2,34,2,36,2,36,2,38,2,38,2,40,2,40,2,42,2,42,2,44,2,44,2,46,2,46,2,48,2,48,2,50,2,50,2,134,3,134,3,136,3,138,3,140,3,140,3,142,3,143,3,145,3,161,3,163,3,171,3,210,3,212,3,216,3,216,3,218,3,218,3,220,3,220,3,222,3,222,3,224,3,224,3,226,3,226,3,228,3,228,3,230,3,230,3,232,3,232,3,234,3,234,3,236,3,236,3,238,3,238,3,244,3,244,3,247,3,247,3,249,3,250,3,0,4,47,4,96,4,96,4,98,4,98,4,100,4,100,4,102,4,102,4,104,4,104,4,106,4,106,4,108,4,108,4,110,4,110,4,112,4,112,4,114,4,114,4,116,4,116,4,118,4,118,4,120,4,120,4,122,4,122,4,124,4,124,4,126,4,126,4,128,4,128,4,138,4,138,4,140,4,140,4,142,4,142,4,144,4,144,4,146,4,146,4,148,4,148,4,150,4,150,4,152,4,152,4,154,4,154,4,156,4,156,4,158,4,158,4,160,4,160,4,162,4,162,4,164,4,164,4,166,4,166,4,168,4,168,4,170,4,170,4,172,4,172,4,174,4,174,4,176,4,176,4,178,4,178,4,180,4,180,4,182,4,182,4,184,4,184,4,186,4,186,4,188,4,188,4,190,4,190,4,192,4,193,4,195,4,195,4,197,4,197,4,199,4,199,4,201,4,201,4,203,4,203,4,205,4,205,4,208,4,208,4,210,4,210,4,212,4,212,4,214,4,214,4,216,4,216,4,218,4,218,4,220,4,220,4,222,4,222,4,224,4,224,4,226,4,226,4,228,4,228,4,230,4,230,4,232,4,232,4,234,4,234,4,236,4,236,4,238,4,238,4,240,4,240,4,242,4,242,4,244,4,244,4,248,4,248,4,0,5,0,5,2,5,2,5,4,5,4,5,6,5,6,5,8,5,8,5,10,5,10,5,12,5,12,5,14,5,14,5,49,5,86,5,160,16,197,16,0,30,0,30,2,30,2,30,4,30,4,30,6,30,6,30,8,30,8,30,10,30,10,30,12,30,12,30,14,30,14,30,16,30,16,30,18,30,18,30,20,30,20,30,22,30,22,30,24,30,24,30,26,30,26,30,28,30,28,30,30,30,30,30,32,30,32,30,34,30,34,30,36,30,36,30,38,30,38,30,40,30,40,30,42,30,42,30,44,30,44,30,46,30,46,30,48,30,48,30,50,30,50,30,52,30,52,30,54,30,54,30,56,30,56,30,58,30,58,30,60,30,60,30,62,30,62,30,64,30,64,30,66,30,66,30,68,30,68,30,70,30,70,30,72,30,72,30,74,30,74,30,76,30,76,30,78,30,78,30,80,30,80,30,82,30,82,30,84,30,84,30,86,30,86,30,88,30,88,30,90,30,90,30,92,30,92,30,94,30,94,30,96,30,96,30,98,30,98,30,100,30,100,30,102,30,102,30,104,30,104,30,106,30,106,30,108,30,108,30,110,30,110,30,112,30,112,30,114,30,114,30,116,30,116,30,118,30,118,30,120,30,120,30,122,30,122,30,124,30,124,30,126,30,126,30,128,30,128,30,130,30,130,30,132,30,132,30,134,30,134,30,136,30,136,30,138,30,138,30,140,30,140,30,142,30,142,30,144,30,144,30,146,30,146,30,148,30,148,30,160,30,160,30,162,30,162,30,164,30,164,30,166,30,166,30,168,30,168,30,170,30,170,30,172,30,172,30,174,30,174,30,176,30,176,30,178,30,178,30,180,30,180,30,182,30,182,30,184,30,184,30,186,30,186,30,188,30,188,30,190,30,190,30,192,30,192,30,194,30,194,30,196,30,196,30,198,30,198,30,200,30,200,30,202,30,202,30,204,30,204,30,206,30,206,30,208,30,208,30,210,30,210,30,212,30,212,30,214,30,214,30,216,30,216,30,218,30,218,30,220,30,220,30,222,30,222,30,224,30,224,30,226,30,226,30,228,30,228,30,230,30,230,30,232,30,232,30,234,30,234,30,236,30,236,30,238,30,238,30,240,30,240,30,242,30,242,30,244,30,244,30,246,30,246,30,248,30,248,30,8,31,15,31,24,31,29,31,40,31,47,31,56,31,63,31,72,31,77,31,89,31,89,31,91,31,91,31,93,31,93,31,95,31,95,31,104,31,111,31,184,31,187,31,200,31,203,31,216,31,219,31,232,31,236,31,248,31,251,31,2,33,2,33,7,33,7,33,11,33,13,33,16,33,18,33,21,33,21,33,25,33,29,33,36,33,36,33,38,33,38,33,40,33,40,33,42,33,45,33,48,33,49,33,51,33,51,33,62,33,63,33,69,33,69,33,33,255,58,255,0,4,1,0,39,4,1,0,0,212,1,0,25,212,1,0,52,212,1,0,77,212,1,0,104,212,1,0,129,212,1,0,156,212,1,0,156,212,1,0,158,212,1,0,159,212,1,0,162,212,1,0,162,212,1,0,165,212,1,0,166,212,1,0,169,212,1,0,172,212,1,0,174,212,1,0,181,212,1,0,208,212,1,0,233,212,1,0,4,213,1,0,5,213,1,0,7,213,1,0,10,213,1,0,13,213,1,0,20,213,1,0,22,213,1,0,28,213,1,0,56,213,1,0,57,213,1,0,59,213,1,0,62,213,1,0,64,213,1,0,68,213,1,0,70,213,1,0,70,213,1,0,74,213,1,0,80,213,1,0,108,213,1,0,133,213,1,0,160,213,1,0,185,213,1,0,212,213,1,0,237,213,1,0,8,214,1,0,33,214,1,0,60,214,1,0,85,214,1,0,112,214,1,0,137,214,1,0,168,214,1,0,192,214,1,0,226,214,1,0,250,214,1,0,28,215,1,0,52,215,1,0,86,215,1,0,110,215,1,0,144,215,1,0,168,215,1,0,197,1,197,1,200,1,200,1,203,1,203,1,242,1,242,1,136,31,143,31,152,31,159,31,168,31,175,31,188,31,188,31,204,31,204,31,252,31,252,31,187,1,187,1,192,1,195,1,208,5,234,5,240,5,242,5,33,6,58,6,65,6,74,6,110,6,111,6,113,6,211,6,213,6,213,6,238,6,239,6,250,6,252,6,255,6,255,6,16,7,16,7,18,7,47,7,77,7,79,7,128,7,165,7,177,7,177,7,4,9,57,9,61,9,61,9,80,9,80,9,88,9,97,9,133,9,140,9,143,9,144,9,147,9,168,9,170,9,176,9,178,9,178,9,182,9,185,9,189,9,189,9,220,9,221,9,223,9,225,9,240,9,241,9,5,10,10,10,15,10,16,10,19,10,40,10,42,10,48,10,50,10,51,10,53,10,54,10,56,10,57,10,89,10,92,10,94,10,94,10,114,10,116,10,133,10,141,10,143,10,145,10,147,10,168,10,170,10,176,10,178,10,179,10,181,10,185,10,189,10,189,10,208,10,208,10,224,10,225,10,5,11,12,11,15,11,16,11,19,11,40,11,42,11,48,11,50,11,51,11,53,11,57,11,61,11,61,11,92,11,93,11,95,11,97,11,113,11,113,11,131,11,131,11,133,11,138,11,142,11,144,11,146,11,149,11,153,11,154,11,156,11,156,11,158,11,159,11,163,11,164,11,168,11,170,11,174,11,181,11,183,11,185,11,5,12,12,12,14,12,16,12,18,12,40,12,42,12,51,12,53,12,57,12,96,12,97,12,133,12,140,12,142,12,144,12,146,12,168,12,170,12,179,12,181,12,185,12,189,12,189,12,222,12,222,12,224,12,225,12,5,13,12,13,14,13,16,13,18,13,40,13,42,13,57,13,96,13,97,13,133,13,150,13,154,13,177,13,179,13,187,13,189,13,189,13,192,13,198,13,1,14,48,14,50,14,51,14,64,14,69,14,129,14,130,14,132,14,132,14,135,14,136,14,138,14,138,14,141,14,141,14,148,14,151,14,153,14,159,14,161,14,163,14,165,14,165,14,167,14,167,14,170,14,171,14,173,14,176,14,178,14,179,14,189,14,189,14,192,14,196,14,220,14,221,14,0,15,0,15,64,15,71,15,73,15,106,15,136,15,139,15,0,16,33,16,35,16,39,16,41,16,42,16,80,16,85,16,208,16,248,16,0,17,89,17,95,17,162,17,168,17,249,17,0,18,6,18,8,18,70,18,72,18,72,18,74,18,77,18,80,18,86,18,88,18,88,18,90,18,93,18,96,18,134,18,136,18,136,18,138,18,141,18,144,18,174,18,176,18,176,18,178,18,181,18,184,18,190,18,192,18,192,18,194,18,197,18,200,18,206,18,208,18,214,18,216,18,238,18,240,18,14,19,16,19,16,19,18,19,21,19,24,19,30,19,32,19,70,19,72,19,90,19,160,19,244,19,1,20,108,22,111,22,118,22,129,22,154,22,160,22,234,22,0,23,12,23,14,23,17,23,32,23,49,23,64,23,81,23,96,23,108,23,110,23,112,23,128,23,179,23,220,23,220,23,32,24,66,24,68,24,119,24,128,24,168,24,0,25,28,25,80,25,109,25,112,25,116,25,53,33,56,33,6,48,6,48,60,48,60,48,65,48,150,48,159,48,159,48,161,48,250,48,255,48,255,48,5,49,44,49,49,49,142,49,160,49,183,49,240,49,255,49,0,52,0,52,181,77,181,77,0,78,0,78,165,159,165,159,0,160,140,164,0,172,0,172,163,215,163,215,0,249,45,250,48,250,106,250,29,251,29,251,31,251,40,251,42,251,54,251,56,251,60,251,62,251,62,251,64,251,65,251,67,251,68,251,70,251,177,251,211,251,61,253,80,253,143,253,146,253,199,253,240,253,251,253,112,254,116,254,118,254,252,254,102,255,111,255,113,255,157,255,160,255,190,255,194,255,199,255,202,255,207,255,210,255,215,255,218,255,220,255,0,0,0,0,0,0,1,0,11,0,1,0,13,0,1,0,38,0,1,0,40,0,1,0,58,0,1,0,60,0,1,0,61,0,1,0,63,0,1,0,77,0,1,0,80,0,1,0,93,0,1,0,128,0,1,0,250,0,1,0,0,3,1,0,30,3,1,0,48,3,1,0,73,3,1,0,128,3,1,0,157,3,1,0,80,4,1,0,157,4,1,0,0,8,1,0,5,8,1,0,8,8,1,0,8,8,1,0,10,8,1,0,53,8,1,0,55,8,1,0,56,8,1,0,60,8,1,0,60,8,1,0,63,8,1,0,63,8,1,0,0,0,2,0,0,0,2,0,214,166,2,0,214,166,2,0,0,248,2,0,29,250,2,0,176,2,193,2,198,2,209,2,224,2,228,2,238,2,238,2,122,3,122,3,89,5,89,5,64,6,64,6,229,6,230,6,70,14,70,14,198,14,198,14,215,23,215,23,67,24,67,24,44,29,97,29,5,48,5,48,49,48,53,48,59,48,59,48,157,48,158,48,252,48,254,48,112,255,112,255,158,255,159,255,97,0,122,0,170,0,170,0,181,0,181,0,186,0,186,0,223,0,246,0,248,0,255,0,1,1,1,1,3,1,3,1,5,1,5,1,7,1,7,1,9,1,9,1,11,1,11,1,13,1,13,1,15,1,15,1,17,1,17,1,19,1,19,1,21,1,21,1,23,1,23,1,25,1,25,1,27,1,27,1,29,1,29,1,31,1,31,1,33,1,33,1,35,1,35,1,37,1,37,1,39,1,39,1,41,1,41,1,43,1,43,1,45,1,45,1,47,1,47,1,49,1,49,1,51,1,51,1,53,1,53,1,55,1,56,1,58,1,58,1,60,1,60,1,62,1,62,1,64,1,64,1,66,1,66,1,68,1,68,1,70,1,70,1,72,1,73,1,75,1,75,1,77,1,77,1,79,1,79,1,81,1,81,1,83,1,83,1,85,1,85,1,87,1,87,1,89,1,89,1,91,1,91,1,93,1,93,1,95,1,95,1,97,1,97,1,99,1,99,1,101,1,101,1,103,1,103,1,105,1,105,1,107,1,107,1,109,1,109,1,111,1,111,1,113,1,113,1,115,1,115,1,117,1,117,1,119,1,119,1,122,1,122,1,124,1,124,1,126,1,128,1,131,1,131,1,133,1,133,1,136,1,136,1,140,1,141,1,146,1,146,1,149,1,149,1,153,1,155,1,158,1,158,1,161,1,161,1,163,1,163,1,165,1,165,1,168,1,168,1,170,1,171,1,173,1,173,1,176,1,176,1,180,1,180,1,182,1,182,1,185,1,186,1,189,1,191,1,198,1,198,1,201,1,201,1,204,1,204,1,206,1,206,1,208,1,208,1,210,1,210,1,212,1,212,1,214,1,214,1,216,1,216,1,218,1,218,1,220,1,221,1,223,1,223,1,225,1,225,1,227,1,227,1,229,1,229,1,231,1,231,1,233,1,233,1,235,1,235,1,237,1,237,1,239,1,240,1,243,1,243,1,245,1,245,1,249,1,249,1,251,1,251,1,253,1,253,1,255,1,255,1,1,2,1,2,3,2,3,2,5,2,5,2,7,2,7,2,9,2,9,2,11,2,11,2,13,2,13,2,15,2,15,2,17,2,17,2,19,2,19,2,21,2,21,2,23,2,23,2,25,2,25,2,27,2,27,2,29,2,29,2,31,2,31,2,33,2,33,2,35,2,35,2,37,2,37,2,39,2,39,2,41,2,41,2,43,2,43,2,45,2,45,2,47,2,47,2,49,2,49,2,51,2,54,2,80,2,175,2,144,3,144,3,172,3,206,3,208,3,209,3,213,3,215,3,217,3,217,3,219,3,219,3,221,3,221,3,223,3,223,3,225,3,225,3,227,3,227,3,229,3,229,3,231,3,231,3,233,3,233,3,235,3,235,3,237,3,237,3,239,3,243,3,245,3,245,3,248,3,248,3,251,3,251,3,48,4,95,4,97,4,97,4,99,4,99,4,101,4,101,4,103,4,103,4,105,4,105,4,107,4,107,4,109,4,109,4,111,4,111,4,113,4,113,4,115,4,115,4,117,4,117,4,119,4,119,4,121,4,121,4,123,4,123,4,125,4,125,4,127,4,127,4,129,4,129,4,139,4,139,4,141,4,141,4,143,4,143,4,145,4,145,4,147,4,147,4,149,4,149,4,151,4,151,4,153,4,153,4,155,4,155,4,157,4,157,4,159,4,159,4,161,4,161,4,163,4,163,4,165,4,165,4,167,4,167,4,169,4,169,4,171,4,171,4,173,4,173,4,175,4,175,4,177,4,177,4,179,4,179,4,181,4,181,4,183,4,183,4,185,4,185,4,187,4,187,4,189,4,189,4,191,4,191,4,194,4,194,4,196,4,196,4,198,4,198,4,200,4,200,4,202,4,202,4,204,4,204,4,206,4,206,4,209,4,209,4,211,4,211,4,213,4,213,4,215,4,215,4,217,4,217,4,219,4,219,4,221,4,221,4,223,4,223,4,225,4,225,4,227,4,227,4,229,4,229,4,231,4,231,4,233,4,233,4,235,4,235,4,237,4,237,4,239,4,239,4,241,4,241,4,243,4,243,4,245,4,245,4,249,4,249,4,1,5,1,5,3,5,3,5,5,5,5,5,7,5,7,5,9,5,9,5,11,5,11,5,13,5,13,5,15,5,15,5,97,5,135,5,0,29,43,29,98,29,107,29,1,30,1,30,3,30,3,30,5,30,5,30,7,30,7,30,9,30,9,30,11,30,11,30,13,30,13,30,15,30,15,30,17,30,17,30,19,30,19,30,21,30,21,30,23,30,23,30,25,30,25,30,27,30,27,30,29,30,29,30,31,30,31,30,33,30,33,30,35,30,35,30,37,30,37,30,39,30,39,30,41,30,41,30,43,30,43,30,45,30,45,30,47,30,47,30,49,30,49,30,51,30,51,30,53,30,53,30,55,30,55,30,57,30,57,30,59,30,59,30,61,30,61,30,63,30,63,30,65,30,65,30,67,30,67,30,69,30,69,30,71,30,71,30,73,30,73,30,75,30,75,30,77,30,77,30,79,30,79,30,81,30,81,30,83,30,83,30,85,30,85,30,87,30,87,30,89,30,89,30,91,30,91,30,93,30,93,30,95,30,95,30,97,30,97,30,99,30,99,30,101,30,101,30,103,30,103,30,105,30,105,30,107,30,107,30,109,30,109,30,111,30,111,30,113,30,113,30,115,30,115,30,117,30,117,30,119,30,119,30,121,30,121,30,123,30,123,30,125,30,125,30,127,30,127,30,129,30,129,30,131,30,131,30,133,30,133,30,135,30,135,30,137,30,137,30,139,30,139,30,141,30,141,30,143,30,143,30,145,30,145,30,147,30,147,30,149,30,155,30,161,30,161,30,163,30,163,30,165,30,165,30,167,30,167,30,169,30,169,30,171,30,171,30,173,30,173,30,175,30,175,30,177,30,177,30,179,30,179,30,181,30,181,30,183,30,183,30,185,30,185,30,187,30,187,30,189,30,189,30,191,30,191,30,193,30,193,30,195,30,195,30,197,30,197,30,199,30,199,30,201,30,201,30,203,30,203,30,205,30,205,30,207,30,207,30,209,30,209,30,211,30,211,30,213,30,213,30,215,30,215,30,217,30,217,30,219,30,219,30,221,30,221,30,223,30,223,30,225,30,225,30,227,30,227,30,229,30,229,30,231,30,231,30,233,30,233,30,235,30,235,30,237,30,237,30,239,30,239,30,241,30,241,30,243,30,243,30,245,30,245,30,247,30,247,30,249,30,249,30,0,31,7,31,16,31,21,31,32,31,39,31,48,31,55,31,64,31,69,31,80,31,87,31,96,31,103,31,112,31,125,31,128,31,135,31,144,31,151,31,160,31,167,31,176,31,180,31,182,31,183,31,190,31,190,31,194,31,196,31,198,31,199,31,208,31,211,31,214,31,215,31,224,31,231,31,242,31,244,31,246,31,247,31,113,32,113,32,127,32,127,32,10,33,10,33,14,33,15,33,19,33,19,33,47,33,47,33,52,33,52,33,57,33,57,33,61,33,61,33,70,33,73,33,0,251,6,251,19,251,23,251,65,255,90,255,40,4,1,0,79,4,1,0,26,212,1,0,51,212,1,0,78,212,1,0,84,212,1,0,86,212,1,0,103,212,1,0,130,212,1,0,155,212,1,0,182,212,1,0,185,212,1,0,187,212,1,0,187,212,1,0,189,212,1,0,195,212,1,0,197,212,1,0,207,212,1,0,234,212,1,0,3,213,1,0,30,213,1,0,55,213,1,0,82,213,1,0,107,213,1,0,134,213,1,0,159,213,1,0,186,213,1,0,211,213,1,0,238,213,1,0,7,214,1,0,34,214,1,0,59,214,1,0,86,214,1,0,111,214,1,0,138,214,1,0,163,214,1,0,194,214,1,0,218,214,1,0,220,214,1,0,225,214,1,0,252,214,1,0,20,215,1,0,22,215,1,0,27,215,1,0,54,215,1,0,78,215,1,0,80,215,1,0,85,215,1,0,112,215,1,0,136,215,1,0,138,215,1,0,143,215,1,0,170,215,1,0,194,215,1,0,196,215,1,0,201,215,1,0,65,0,90,0,97,0,122,0,170,0,170,0,181,0,181,0,186,0,186,0,192,0,214,0,216,0,246,0,248,0,54,2,80,2,193,2,198,2,209,2,224,2,228,2,238,2,238,2,122,3,122,3,134,3,134,3,136,3,138,3,140,3,140,3,142,3,161,3,163,3,206,3,208,3,245,3,247,3,251,3,0,4,129,4,138,4,206,4,208,4,245,4,248,4,249,4,0,5,15,5,49,5,86,5,89,5,89,5,97,5,135,5,208,5,234,5,240,5,242,5,33,6,58,6,64,6,74,6,110,6,111,6,113,6,211,6,213,6,213,6,229,6,230,6,238,6,239,6,250,6,252,6,255,6,255,6,16,7,16,7,18,7,47,7,77,7,79,7,128,7,165,7,177,7,177,7,4,9,57,9,61,9,61,9,80,9,80,9,88,9,97,9,133,9,140,9,143,9,144,9,147,9,168,9,170,9,176,9,178,9,178,9,182,9,185,9,189,9,189,9,220,9,221,9,223,9,225,9,240,9,241,9,5,10,10,10,15,10,16,10,19,10,40,10,42,10,48,10,50,10,51,10,53,10,54,10,56,10,57,10,89,10,92,10,94,10,94,10,114,10,116,10,133,10,141,10,143,10,145,10,147,10,168,10,170,10,176,10,178,10,179,10,181,10,185,10,189,10,189,10,208,10,208,10,224,10,225,10,5,11,12,11,15,11,16,11,19,11,40,11,42,11,48,11,50,11,51,11,53,11,57,11,61,11,61,11,92,11,93,11,95,11,97,11,113,11,113,11,131,11,131,11,133,11,138,11,142,11,144,11,146,11,149,11,153,11,154,11,156,11,156,11,158,11,159,11,163,11,164,11,168,11,170,11,174,11,181,11,183,11,185,11,5,12,12,12,14,12,16,12,18,12,40,12,42,12,51,12,53,12,57,12,96,12,97,12,133,12,140,12,142,12,144,12,146,12,168,12,170,12,179,12,181,12,185,12,189,12,189,12,222,12,222,12,224,12,225,12,5,13,12,13,14,13,16,13,18,13,40,13,42,13,57,13,96,13,97,13,133,13,150,13,154,13,177,13,179,13,187,13,189,13,189,13,192,13,198,13,1,14,48,14,50,14,51,14,64,14,70,14,129,14,130,14,132,14,132,14,135,14,136,14,138,14,138,14,141,14,141,14,148,14,151,14,153,14,159,14,161,14,163,14,165,14,165,14,167,14,167,14,170,14,171,14,173,14,176,14,178,14,179,14,189,14,189,14,192,14,196,14,198,14,198,14,220,14,221,14,0,15,0,15,64,15,71,15,73,15,106,15,136,15,139,15,0,16,33,16,35,16,39,16,41,16,42,16,80,16,85,16,160,16,197,16,208,16,248,16,0,17,89,17,95,17,162,17,168,17,249,17,0,18,6,18,8,18,70,18,72,18,72,18,74,18,77,18,80,18,86,18,88,18,88,18,90,18,93,18,96,18,134,18,136,18,136,18,138,18,141,18,144,18,174,18,176,18,176,18,178,18,181,18,184,18,190,18,192,18,192,18,194,18,197,18,200,18,206,18,208,18,214,18,216,18,238,18,240,18,14,19,16,19,16,19,18,19,21,19,24,19,30,19,32,19,70,19,72,19,90,19,160,19,244,19,1,20,108,22,111,22,118,22,129,22,154,22,160,22,234,22,0,23,12,23,14,23,17,23,32,23,49,23,64,23,81,23,96,23,108,23,110,23,112,23,128,23,179,23,215,23,215,23,220,23,220,23,32,24,119,24,128,24,168,24,0,25,28,25,80,25,109,25,112,25,116,25,0,29,107,29,0,30,155,30,160,30,249,30,0,31,21,31,24,31,29,31,32,31,69,31,72,31,77,31,80,31,87,31,89,31,89,31,91,31,91,31,93,31,93,31,95,31,125,31,128,31,180,31,182,31,188,31,190,31,190,31,194,31,196,31,198,31,204,31,208,31,211,31,214,31,219,31,224,31,236,31,242,31,244,31,246,31,252,31,113,32,113,32,127,32,127,32,2,33,2,33,7,33,7,33,10,33,19,33,21,33,21,33,25,33,29,33,36,33,36,33,38,33,38,33,40,33,40,33,42,33,45,33,47,33,49,33,51,33,57,33,61,33,63,33,69,33,73,33,5,48,6,48,49,48,53,48,59,48,60,48,65,48,150,48,157,48,159,48,161,48,250,48,252,48,255,48,5,49,44,49,49,49,142,49,160,49,183,49,240,49,255,49,0,52,0,52,181,77,181,77,0,78,0,78,165,159,165,159,0,160,140,164,0,172,0,172,163,215,163,215,0,249,45,250,48,250,106,250,0,251,6,251,19,251,23,251,29,251,29,251,31,251,40,251,42,251,54,251,56,251,60,251,62,251,62,251,64,251,65,251,67,251,68,251,70,251,177,251,211,251,61,253,80,253,143,253,146,253,199,253,240,253,251,253,112,254,116,254,118,254,252,254,33,255,58,255,65,255,90,255,102,255,190,255,194,255,199,255,202,255,207,255,210,255,215,255,218,255,220,255,0,0,0,0,0,0,1,0,11,0,1,0,13,0,1,0,38,0,1,0,40,0,1,0,58,0,1,0,60,0,1,0,61,0,1,0,63,0,1,0,77,0,1,0,80,0,1,0,93,0,1,0,128,0,1,0,250,0,1,0,0,3,1,0,30,3,1,0,48,3,1,0,73,3,1,0,128,3,1,0,157,3,1,0,0,4,1,0,157,4,1,0,0,8,1,0,5,8,1,0,8,8,1,0,8,8,1,0,10,8,1,0,53,8,1,0,55,8,1,0,56,8,1,0,60,8,1,0,60,8,1,0,63,8,1,0,63,8,1,0,0,212,1,0,84,212,1,0,86,212,1,0,156,212,1,0,158,212,1,0,159,212,1,0,162,212,1,0,162,212,1,0,165,212,1,0,166,212,1,0,169,212,1,0,172,212,1,0,174,212,1,0,185,212,1,0,187,212,1,0,187,212,1,0,189,212,1,0,195,212,1,0,197,212,1,0,5,213,1,0,7,213,1,0,10,213,1,0,13,213,1,0,20,213,1,0,22,213,1,0,28,213,1,0,30,213,1,0,57,213,1,0,59,213,1,0,62,213,1,0,64,213,1,0,68,213,1,0,70,213,1,0,70,213,1,0,74,213,1,0,80,213,1,0,82,213,1,0,163,214,1,0,168,214,1,0,192,214,1,0,194,214,1,0,218,214,1,0,220,214,1,0,250,214,1,0,252,214,1,0,20,215,1,0,22,215,1,0,52,215,1,0,54,215,1,0,78,215,1,0,80,215,1,0,110,215,1,0,112,215,1,0,136,215,1,0,138,215,1,0,168,215,1,0,170,215,1,0,194,215,1,0,196,215,1,0,201,215,1,0,0,0,2,0,0,0,2,0,214,166,2,0,214,166,2,0,0,248,2,0,29,250,2,0,173,0,173,0,0,6,3,6,221,6,221,6,15,7,15,7,180,23,181,23,11,32,15,32,42,32,46,32,96,32,99,32,106,32,111,32,255,254,255,254,249,255,251,255,0,0,0,0,115,209,1,0,122,209,1,0,1,0,14,0,1,0,14,0,32,0,14,0,127,0,14,0,0,0,31,0,127,0,159,0,173,0,173,0,0,6,3,6,221,6,221,6,15,7,15,7,180,23,181,23,11,32,15,32,42,32,46,32,96,32,99,32,106,32,111,32,0,216,0,216,127,219,128,219,255,219,0,220,255,223,0,224,255,248,255,248,255,254,255,254,249,255,251,255,115,209,1,0,122,209,1,0,1,0,14,0,1,0,14,0,32,0,14,0,127,0,14,0,0,0,15,0,0,0,15,0,253,255,15,0,253,255,15,0,0,0,16,0,0,0,16,0,253,255,16,0,253,255,16,0,16,210,2,0,66,0,0,0,32,210,2,0,67,0,0,0,64,210,2,0,68,0,0,0,72,210,2,0,69,0,0,0,104,210,2,0,70,0,0,0,136,210,2,0,71,0,0,0,152,210,2,0,72,0,0,0,160,210,2,0,73,0,0,0,176,210,2,0,74,0,0,0,184,210,2,0,75,0,0,0,200,210,2,0,76,0,0,0,216,210,2,0,77,0,0,0,240,210,2,0,78,0,0,0,0,211,2,0,79,0,0,0,16,211,2,0,80,0,0,0,24,211,2,0,81,0,0,0,48,211,2,0,82,0,0,0,72,211,2,0,83,0,0,0,96,211,2,0,84,0,0,0,128,211,2,0,85,0,0,0,168,211,2,0,86,0,0,0,192,211,2,0,87,0,0,0,224,211,2,0,88,0,0,0,248,211,2,0,89,0,0,0,24,212,2,0,90,0,0,0,56,212,2,0,91,0,0,0,72,212,2,0,92,0,0,0,104,212,2,0,93,0,0,0,144,212,2,0,94,0,0,0,168,212,2,0,95,0,0,0,200,212,2,0,96,0,0,0,216,212,2,0,97,0,0,0,232,212,2,0,98,0,0,0,0,213,2,0,99,0,0,0,16,213,2,0,100,0,0,0,40,213,2,0,101,0,0,0,48,213,2,0,102,0,0,0,64,213,2,0,103,0,0,0,80,213,2,0,104,0,0,0,104,213,2,0,105,0,0,0,136,213,2,0,106,0,0,0,152,213,2,0,107,0,0,0,176,213,2,0,108,0,0,0,192,213,2,0,109,0,0,0,208,213,2,0,110,0,0,0,216,213,2,0,111,0,0,0,224,213,2,0,112,0,0,0,240,213,2,0,113,0,0,0,0,214,2,0,114,0,0,0,16,214,2,0,115,0,0,0,32,214,2,0,116,0,0,0,64,214,2,0,117,0,0,0,88,214,2,0,118,0,0,0,104,214,2,0,119,0,0,0,120,214,2,0,120,0,0,0,128,214,2,0,121,0,0,0,136,214,2,0,122,0,0,0,168,214,2,0,123,0,0,0,184,214,2,0,124,0,0,0,200,214,2,0,125,0,0,0,216,214,2,0,126,0,0,0,0,215,2,0,127,0,0,0,8,215,2,0,128,0,0,0,24,215,2,0,129,0,0,0,32,215,2,0,130,0,0,0,48,215,2,0,131,0,0,0,80,215,2,0,132,0,0,0,88,215,2,0,133,0,0,0,104,215,2,0,134,0,0,0,112,215,2,0,135,0,0,0,136,215,2,0,136,0,0,0,152,215,2,0,137,0,0,0,168,215,2,0,138,0,0,0,192,215,2,0,139,0,0,0,216,215,2,0,140,0,0,0,224,215,2,0,141,0,0,0,248,215,2,0,142,0,0,0,16,216,2,0,143,0,0,0,32,216,2,0,144,0,0,0,48,216,2,0,145,0,0,0,80,216,2,0,146,0,0,0,104,216,2,0,147,0,0,0,144,216,2,0,148,0,0,0,184,216,2,0,149,0,0,0,208,216,2,0,150,0,0,0,240,216,2,0,151,0,0,0,8,217,2,0,152,0,0,0,24,217,2,0,153,0,0,0,40,217,2,0,154,0,0,0,48,217,2,0,155,0,0,0,64,217,2,0,156,0,0,0,72,217,2,0,157,0,0,0,88,217,2,0,158,0,0,0,120,217,2,0,159,0,0,0,128,217,2,0,160,0,0,0,136,217,2,0,161,0,0,0,160,217,2,0,162,0,0,0,176,217,2,0,163,0,0,0,192,217,2,0,164,0,0,0,200,217,2,0,165,0,0,0,208,217,2,0,166,0,0,0,216,217,2,0,167,0,0,0,240,217,2,0,168,0,0,0,8,218,2,0,169,0,0,0,24,218,2,0,170,0,0,0,56,218,2,0,171,0,0,0,80,218,2,0,172,0,0,0,104,218,2,0,173,0,0,0,144,218,2,0,174,0,0,0,176,218,2,0,175,0,0,0,208,218,2,0,176,0,0,0,216,218,2,0,177,0,0,0,224,218,2,0,178,0,0,0,240,218,2,0,179,0,0,0,248,218,2,0,180,0,0,0,0,219,2,0,181,0,0,0,24,219,2,0,182,0,0,0,32,219,2,0,183,0,0,0,40,219,2,0,184,0,0,0,48,219,2,0,185,0,0,0,56,219,2,0,186,0,0,0,64,219,2,0,187,0,0,0,80,219,2,0,188,0,0,0,120,219,2,0,189,0,0,0,144,219,2,0,190,0,0,0,176,219,2,0,191,0,0,0,192,219,2,0,192,0,0,0,208,219,2,0,193,0,0,0,65,101,103,101,97,110,78,117,109,98,101,114,115,0,0,0,65,108,112,104,97,98,101,116,105,99,80,114,101,115,101,110,116,97,116,105,111,110,70,111,114,109,115,0,0,0,0,0,65,114,97,98,105,99,0,0,65,114,97,98,105,99,80,114,101,115,101,110,116,97,116,105,111,110,70,111,114,109,115,45,65,0,0,0,0,0,0,0,65,114,97,98,105,99,80,114,101,115,101,110,116,97,116,105,111,110,70,111,114,109,115,45,66,0,0,0,0,0,0,0,65,114,109,101,110,105,97,110,0,0,0,0,0,0,0,0,65,114,114,111,119,115,0,0,66,97,115,105,99,76,97,116,105,110,0,0,0,0,0,0,66,101,110,103,97,108,105,0,66,108,111,99,107,69,108,101,109,101,110,116,115,0,0,0,66,111,112,111,109,111,102,111,0,0,0,0,0,0,0,0,66,111,112,111,109,111,102,111,69,120,116,101,110,100,101,100,0,0,0,0,0,0,0,0,66,111,120,68,114,97,119,105,110,103,0,0,0,0,0,0,66,114,97,105,108,108,101,80,97,116,116,101,114,110,115,0,66,117,104,105,100,0,0,0,66,121,122,97,110,116,105,110,101,77,117,115,105,99,97,108,83,121,109,98,111,108,115,0,67,74,75,67,111,109,112,97,116,105,98,105,108,105,116,121,0,0,0,0,0,0,0,0,67,74,75,67,111,109,112,97,116,105,98,105,108,105,116,121,70,111,114,109,115,0,0,0,67,74,75,67,111,109,112,97,116,105,98,105,108,105,116,121,73,100,101,111,103,114,97,112,104,115,0,0,0,0,0,0,67,74,75,67,111,109,112,97,116,105,98,105,108,105,116,121,73,100,101,111,103,114,97,112,104,115,83,117,112,112,108,101,109,101,110,116,0,0,0,0,67,74,75,82,97,100,105,99,97,108,115,83,117,112,112,108,101,109,101,110,116,0,0,0,67,74,75,83,121,109,98,111,108,115,97,110,100,80,117,110,99,116,117,97,116,105,111,110,0,0,0,0,0,0,0,0,67,74,75,85,110,105,102,105,101,100,73,100,101,111,103,114,97,112,104,115,0,0,0,0,67,74,75,85,110,105,102,105,101,100,73,100,101,111,103,114,97,112,104,115,69,120,116,101,110,115,105,111,110,65,0,0,67,74,75,85,110,105,102,105,101,100,73,100,101,111,103,114,97,112,104,115,69,120,116,101,110,115,105,111,110,66,0,0,67,104,101,114,111,107,101,101,0,0,0,0,0,0,0,0,67,111,109,98,105,110,105,110,103,68,105,97,99,114,105,116,105,99,97,108,77,97,114,107,115,0,0,0,0,0,0,0,67,111,109,98,105,110,105,110,103,68,105,97,99,114,105,116,105,99,97,108,77,97,114,107,115,102,111,114,83,121,109,98,111,108,115,0,0,0,0,0,67,111,109,98,105,110,105,110,103,72,97,108,102,77,97,114,107,115,0,0,0,0,0,0,67,111,109,98,105,110,105,110,103,77,97,114,107,115,102,111,114,83,121,109,98,111,108,115,0,0,0,0,0,0,0,0,67,111,110,116,114,111,108,80,105,99,116,117,114,101,115,0,67,117,114,114,101,110,99,121,83,121,109,98,111,108,115,0,67,121,112,114,105,111,116,83,121,108,108,97,98,97,114,121,0,0,0,0,0,0,0,0,67,121,114,105,108,108,105,99,0,0,0,0,0,0,0,0,67,121,114,105,108,108,105,99,83,117,112,112,108,101,109,101,110,116,0,0,0,0,0,0,68,101,115,101,114,101,116,0,68,101,118,97,110,97,103,97,114,105,0,0,0,0,0,0,68,105,110,103,98,97,116,115,0,0,0,0,0,0,0,0,69,110,99,108,111,115,101,100,65,108,112,104,97,110,117,109,101,114,105,99,115,0,0,0,69,110,99,108,111,115,101,100,67,74,75,76,101,116,116,101,114,115,97,110,100,77,111,110,116,104,115,0,0,0,0,0,69,116,104,105,111,112,105,99,0,0,0,0,0,0,0,0,71,101,110,101,114,97,108,80,117,110,99,116,117,97,116,105,111,110,0,0,0,0,0,0,71,101,111,109,101,116,114,105,99,83,104,97,112,101,115,0,71,101,111,114,103,105,97,110,0,0,0,0,0,0,0,0,71,111,116,104,105,99,0,0,71,114,101,101,107,0,0,0,71,114,101,101,107,69,120,116,101,110,100,101,100,0,0,0,71,114,101,101,107,97,110,100,67,111,112,116,105,99,0,0,71,117,106,97,114,97,116,105,0,0,0,0,0,0,0,0,71,117,114,109,117,107,104,105,0,0,0,0,0,0,0,0,72,97,108,102,119,105,100,116,104,97,110,100,70,117,108,108,119,105,100,116,104,70,111,114,109,115,0,0,0,0,0,0,72,97,110,103,117,108,67,111,109,112,97,116,105,98,105,108,105,116,121,74,97,109,111,0,72,97,110,103,117,108,74,97,109,111,0,0,0,0,0,0,72,97,110,103,117,108,83,121,108,108,97,98,108,101,115,0,72,97,110,117,110,111,111,0,72,101,98,114,101,119,0,0,72,105,103,104,80,114,105,118,97,116,101,85,115,101,83,117,114,114,111,103,97,116,101,115,0,0,0,0,0,0,0,0,72,105,103,104,83,117,114,114,111,103,97,116,101,115,0,0,72,105,114,97,103,97,110,97,0,0,0,0,0,0,0,0,73,80,65,69,120,116,101,110,115,105,111,110,115,0,0,0,73,100,101,111,103,114,97,112,104,105,99,68,101,115,99,114,105,112,116,105,111,110,67,104,97,114,97,99,116,101,114,115,0,0,0,0,0,0,0,0,75,97,110,98,117,110,0,0,75,97,110,103,120,105,82,97,100,105,99,97,108,115,0,0,75,97,110,110,97,100,97,0,75,97,116,97,107,97,110,97,0,0,0,0,0,0,0,0,75,97,116,97,107,97,110,97,80,104,111,110,101,116,105,99,69,120,116,101,110,115,105,111,110,115,0,0,0,0,0,0,75,104,109,101,114,0,0,0,75,104,109,101,114,83,121,109,98,111,108,115,0,0,0,0,76,97,111,0,0,0,0,0,76,97,116,105,110,45,49,83,117,112,112,108,101,109,101,110,116,0,0,0,0,0,0,0,76,97,116,105,110,69,120,116,101,110,100,101,100,45,65,0,76,97,116,105,110,69,120,116,101,110,100,101,100,45,66,0,76,97,116,105,110,69,120,116,101,110,100,101,100,65,100,100,105,116,105,111,110,97,108,0,76,101,116,116,101,114,108,105,107,101,83,121,109,98,111,108,115,0,0,0,0,0,0,0,76,105,109,98,117,0,0,0,76,105,110,101,97,114,66,73,100,101,111,103,114,97,109,115,0,0,0,0,0,0,0,0,76,105,110,101,97,114,66,83,121,108,108,97,98,97,114,121,0,0,0,0,0,0,0,0,76,111,119,83,117,114,114,111,103,97,116,101,115,0,0,0,77,97,108,97,121,97,108,97,109,0,0,0,0,0,0,0,77,97,116,104,101,109,97,116,105,99,97,108,65,108,112,104,97,110,117,109,101,114,105,99,83,121,109,98,111,108,115,0,77,97,116,104,101,109,97,116,105,99,97,108,79,112,101,114,97,116,111,114,115,0,0,0,77,105,115,99,101,108,108,97,110,101,111,117,115,77,97,116,104,101,109,97,116,105,99,97,108,83,121,109,98,111,108,115,45,65,0,0,0,0,0,0,77,105,115,99,101,108,108,97,110,101,111,117,115,77,97,116,104,101,109,97,116,105,99,97,108,83,121,109,98,111,108,115,45,66,0,0,0,0,0,0,77,105,115,99,101,108,108,97,110,101,111,117,115,83,121,109,98,111,108,115,0,0,0,0,77,105,115,99,101,108,108,97,110,101,111,117,115,83,121,109,98,111,108,115,97,110,100,65,114,114,111,119,115,0,0,0,77,105,115,99,101,108,108,97,110,101,111,117,115,84,101,99,104,110,105,99,97,108,0,0,77,111,110,103,111,108,105,97,110,0,0,0,0,0,0,0,77,117,115,105,99,97,108,83,121,109,98,111,108,115,0,0,77,121,97,110,109,97,114,0,78,117,109,98,101,114,70,111,114,109,115,0,0,0,0,0,79,103,104,97,109,0,0,0,79,108,100,73,116,97,108,105,99,0,0,0,0,0,0,0,79,112,116,105,99,97,108,67,104,97,114,97,99,116,101,114,82,101,99,111,103,110,105,116,105,111,110,0,0,0,0,0,79,114,105,121,97,0,0,0,79,115,109,97,110,121,97,0,80,104,111,110,101,116,105,99,69,120,116,101,110,115,105,111,110,115,0,0,0,0,0,0,80,114,105,118,97,116,101,85,115,101,0,0,0,0,0,0,80,114,105,118,97,116,101,85,115,101,65,114,101,97,0,0,82,117,110,105,99,0,0,0,83,104,97,118,105,97,110,0,83,105,110,104,97,108,97,0,83,109,97,108,108,70,111,114,109,86,97,114,105,97,110,116,115,0,0,0,0,0,0,0,83,112,97,99,105,110,103,77,111,100,105,102,105,101,114,76,101,116,116,101,114,115,0,0,83,112,101,99,105,97,108,115,0,0,0,0,0,0,0,0,83,117,112,101,114,115,99,114,105,112,116,115,97,110,100,83,117,98,115,99,114,105,112,116,115,0,0,0,0,0,0,0,83,117,112,112,108,101,109,101,110,116,97,108,65,114,114,111,119,115,45,65,0,0,0,0,83,117,112,112,108,101,109,101,110,116,97,108,65,114,114,111,119,115,45,66,0,0,0,0,83,117,112,112,108,101,109,101,110,116,97,108,77,97,116,104,101,109,97,116,105,99,97,108,79,112,101,114,97,116,111,114,115,0,0,0,0,0,0,0,83,117,112,112,108,101,109,101,110,116,97,114,121,80,114,105,118,97,116,101,85,115,101,65,114,101,97,45,65,0,0,0,83,117,112,112,108,101,109,101,110,116,97,114,121,80,114,105,118,97,116,101,85,115,101,65,114,101,97,45,66,0,0,0,83,121,114,105,97,99,0,0,84,97,103,97,108,111,103,0,84,97,103,98,97,110,119,97,0,0,0,0,0,0,0,0,84,97,103,115,0,0,0,0,84,97,105,76,101,0,0,0,84,97,105,88,117,97,110,74,105,110,103,83,121,109,98,111,108,115,0,0,0,0,0,0,84,97,109,105,108,0,0,0,84,101,108,117,103,117,0,0,84,104,97,97,110,97,0,0,84,104,97,105,0,0,0,0,84,105,98,101,116,97,110,0,85,103,97,114,105,116,105,99,0,0,0,0,0,0,0,0,85,110,105,102,105,101,100,67,97,110,97,100,105,97,110,65,98,111,114,105,103,105,110,97,108,83,121,108,108,97,98,105,99,115],"i8",ALLOC_NONE,Runtime.GLOBAL_BASE+177008),allocate([86,97,114,105,97,116,105,111,110,83,101,108,101,99,116,111,114,115,0,0,0,0,0,0,86,97,114,105,97,116,105,111,110,83,101,108,101,99,116,111,114,115,83,117,112,112,108,101,109,101,110,116,0,0,0,0,89,105,82,97,100,105,99,97,108,115,0,0,0,0,0,0,89,105,83,121,108,108,97,98,108,101,115,0,0,0,0,0,89,105,106,105,110,103,72,101,120,97,103,114,97,109,83,121,109,98,111,108,115,0,0,0,0,0,0,0,0,0,0,0,104,116,116,112,58,47,47,119,119,119,46,119,51,46,111,114,103,47,50,48,48,51,47,88,73,110,99,108,117,100,101,0,104,116,116,112,58,47,47,119,119,119,46,119,51,46,111,114,103,47,50,48,48,49,47,88,73,110,99,108,117,100,101,0,120,109,108,78,101,119,84,101,120,116,82,101,97,100,101,114,32,58,32,109,97,108,108,111,99,32,102,97,105,108,101,100,10,0,0,0,0,0,0,0,120,109,108,110,115,0,0,0,104,116,116,112,58,47,47,119,119,119,46,119,51,46,111,114,103,47,50,48,48,48,47,120,109,108,110,115,47,0,0,0,58,0,0,0,0,0,0,0,35,116,101,120,116,0,0,0,35,99,100,97,116,97,45,115,101,99,116,105,111,110,0,0,35,99,111,109,109,101,110,116,0,0,0,0,0,0,0,0,35,100,111,99,117,109,101,110,116,0,0,0,0,0,0,0,35,100,111,99,117,109,101,110,116,45,102,114,97,103,109,101,110,116,0,0,0,0,0,0,120,109,108,84,101,120,116,82,101,97,100,101,114,83,101,116,117,112,32,58,32,109,97,108,108,111,99,32,102,97,105,108,101,100,10,0,0,0,0,0,120,109,108,77,97,108,108,111,99,32,102,97,105,108,101,100,32,33,10,0,0,0,0,0,120,109,108,82,101,97,108,108,111,99,32,102,97,105,108,101,100,32,33,10,0,0,0,0,105,110,99,108,117,100,101,0,118,115,110,112,114,105,110,116,102,32,102,97,105,108,101,100,32,33,10,0,0,0,0,0,37,115,0,0,0,0,0,0,69,120,112,97,110,100,32,102,97,105,108,101,100,32,33,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,70,97,105,108,101,100,32,116,111,32,97,108,108,111,99,97,116,101,32,115,104,32,116,97,98,108,101,32,102,111,114,32,82,101,108,97,120,45,78,71,32,116,121,112,101,115,10,0,104,116,116,112,58,47,47,119,119,119,46,119,51,46,111,114,103,47,50,48,48,49,47,88,77,76,83,99,104,101,109,97,45,100,97,116,97,116,121,112,101,115,0,0,0,0,0,0,64,241,2,0,0,0,0,0,98,117,105,108,100,105,110,103,32,112,97,114,115,101,114,10,0,0,0,0,0,0,0,0,120,109,108,82,101,108,97,120,78,71,80,97,114,115,101,58,32,99,111,117,108,100,32,110,111,116,32,108,111,97,100,32,37,115,10,0,0,0,0,0,120,109,108,82,101,108,97,120,78,71,80,97,114,115,101,58,32,99,111,117,108,100,32,110,111,116,32,112,97,114,115,101,32,115,99,104,101,109,97,115,10,0,0,0,0,0,0,0,105,110,95,109,101,109,111,114,121,95,98,117,102,102,101,114,0,0,0,0,0,0,0,0,120,109,108,82,101,108,97,120,78,71,80,97,114,115,101,58,32,110,111,116,104,105,110,103,32,116,111,32,112,97,114,115,101,10,0,0,0,0,0,0,120,109,108,82,101,108,97,120,78,71,80,97,114,115,101,58,32,37,115,32,105,115,32,101,109,112,116,121,10,0,0,0,115,99,104,101,109,97,115,0,35,116,101,120,116,0,0,0,32,84,79,68,79,32,0,0,0,0,0,0,0,0,0,0,98,117,105,108,100,105,110,103,32,99,111,110,116,101,120,116,10,0,0,0,0,0,0,0,111,117,116,32,111,102,32,109,101,109,111,114,121,10,0,0,102,97,105,108,101,100,32,116,111,32,118,97,108,105,100,97,116,101,32,116,121,112,101,32,37,115,10,0,0,0,0,0,84,121,112,101,32,37,115,32,100,111,101,115,110,39,116,32,97,108,108,111,119,32,118,97,108,117,101,32,39,37,115,39,10,0,0,0,0,0,0,0,73,68,32,37,115,32,114,101,100,101,102,105,110,101,100,10,0,0,0,0,0,0,0,0,102,97,105,108,101,100,32,116,111,32,99,111,109,112,97,114,101,32,116,121,112,101,32,37,115,10,0,0,0,0,0,0,73,110,116,101,114,110,97,108,32,101,114,114,111,114,58,32,110,111,32,115,116,97,116,101,10,0,0,0,0,0,0,0,73,110,116,101,114,110,97,108,32,101,114,114,111,114,58,32,110,111,32,100,101,102,105,110,101,10,0,0,0,0,0,0,73,110,116,101,114,110,97,108,32,101,114,114,111,114,58,32,37,115,10,0,0,0,0,0,69,120,116,114,97,32,100,97,116,97,32,105,110,32,108,105,115,116,58,32,37,115,10,0,73,110,116,101,114,110,97,108,58,32,105,110,116,101,114,108,101,97,118,101,32,98,108,111,99,107,32,104,97,115,32,110,111,32,100,97,116,97,10,0,73,110,118,97,108,105,100,32,115,101,113,117,101,110,99,101,32,105,110,32,105,110,116,101,114,108,101,97,118,101,10,0,69,120,116,114,97,32,101,108,101,109,101,110,116,32,37,115,32,105,110,32,105,110,116,101,114,108,101,97,118,101,10,0,69,120,112,101,99,116,105,110,103,32,101,108,101,109,101,110,116,32,37,115,44,32,103,111,116,32,37,115,10,0,0,0,69,120,112,101,99,116,105,110,103,32,97,32,110,97,109,101,115,112,97,99,101,32,102,111,114,32,101,108,101,109,101,110,116,32,37,115,10,0,0,0,69,108,101,109,101,110,116,32,37,115,32,104,97,115,32,119,114,111,110,103,32,110,97,109,101,115,112,97,99,101,58,32,101,120,112,101,99,116,105,110,103,32,37,115,10,0,0,0,68,105,100,32,110,111,116,32,101,120,112,101,99,116,32,101,108,101,109,101,110,116,32,37,115,32,116,104,101,114,101,10,0,0,0,0,0,0,0,0,68,105,100,32,110,111,116,32,101,120,112,101,99,116,32,116,101,120,116,32,105,110,32,101,108,101,109,101,110,116,32,37,115,32,99,111,110,116,101,110,116,10,0,0,0,0,0,0,69,120,112,101,99,116,105,110,103,32,110,111,32,110,97,109,101,115,112,97,99,101,32,102,111,114,32,101,108,101,109,101,110,116,32,37,115,10,0,0,69,120,112,101,99,116,105,110,103,32,101,108,101,109,101,110,116,32,37,115,32,116,111,32,98,101,32,101,109,112,116,121,10,0,0,0,0,0,0,0,69,120,112,101,99,116,105,110,103,32,97,110,32,101,108,101,109,101,110,116,32,37,115,44,32,103,111,116,32,110,111,116,104,105,110,103,10,0,0,0,69,120,112,101,99,116,105,110,103,32,97,110,32,101,108,101,109,101,110,116,32,103,111,116,32,116,101,120,116,10,0,0,69,108,101,109,101,110,116,32,37,115,32,102,97,105,108,101,100,32,116,111,32,118,97,108,105,100,97,116,101,32,97,116,116,114,105,98,117,116,101,115,10,0,0,0,0,0,0,0,69,108,101,109,101,110,116,32,37,115,32,102,97,105,108,101,100,32,116,111,32,118,97,108,105,100,97,116,101,32,99,111,110,116,101,110,116,10,0,0,69,108,101,109,101,110,116,32,37,115,32,104,97,115,32,101,120,116,114,97,32,99,111,110,116,101,110,116,58,32,37,115,10,0,0,0,0,0,0,0,73,110,118,97,108,105,100,32,97,116,116,114,105,98,117,116,101,32,37,115,32,102,111,114,32,101,108,101,109,101,110,116,32,37,115,10,0,0,0,0,68,97,116,97,116,121,112,101,32,101,108,101,109,101,110,116,32,37,115,32,99,111,110,116,97,105,110,115,32,110,111,32,100,97,116,97,10,0,0,0,68,97,116,97,116,121,112,101,32,101,108,101,109,101,110,116,32,37,115,32,104,97,115,32,99,104,105,108,100,32,101,108,101,109,101,110,116,115,10,0,86,97,108,117,101,32,101,108,101,109,101,110,116,32,37,115,32,104,97,115,32,99,104,105,108,100,32,101,108,101,109,101,110,116,115,10,0,0,0,0,76,105,115,116,32,101,108,101,109,101,110,116,32,37,115,32,104,97,115,32,99,104,105,108,100,32,101,108,101,109,101,110,116,115,10,0,0,0,0,0,69,114,114,111,114,32,118,97,108,105,100,97,116,105,110,103,32,100,97,116,97,116,121,112,101,32,37,115,10,0,0,0,69,114,114,111,114,32,118,97,108,105,100,97,116,105,110,103,32,118,97,108,117,101,32,37,115,10,0,0,0,0,0,0,69,114,114,111,114,32,118,97,108,105,100,97,116,105,110,103,32,108,105,115,116,10,0,0,78,111,32,116,111,112,32,103,114,97,109,109,97,114,32,100,101,102,105,110,101,100,10,0,69,120,116,114,97,32,100,97,116,97,32,105,110,32,116,104,101,32,100,111,99,117,109,101,110,116,10,0,0,0,0,0,85,110,107,110,111,119,110,32,101,114,114,111,114,32,33,10,0,0,0,0,0,0,0,0,85,110,107,110,111,119,110,32,101,114,114,111,114,32,99,111,100,101,32,37,100,10,0,0,115,116,111,114,105,110,103,32,115,116,97,116,101,115,10,0,77,101,109,111,114,121,32,97,108,108,111,99,97,116,105,111,110,32,102,97,105,108,101,100,32,58,32,37,115,10,0,0,77,101,109,111,114,121,32,97,108,108,111,99,97,116,105,111,110,32,102,97,105,108,101,100,10,0,0,0,0,0,0,0,85,110,105,109,112,108,101,109,101,110,116,101,100,32,98,108,111,99,107,32,97,116,32,37,115,58,37,100,10,0,0,0,46,46,47,108,105,98,120,109,108,50,47,114,101,108,97,120,110,103,46,99,0,0,0,0,97,100,100,105,110,103,32,115,116,97,116,101,115,10,0,0,35,97,110,121,0,0,0,0,118,97,108,105,100,97,116,105,110,103,10,0,0,0,0,0,110,111,110,97,109,101,0,0,97,108,108,111,99,97,116,105,110,103,32,115,116,97,116,101,115,10,0,0,0,0,0,0,78,85,76,76,32,100,101,102,105,110,105,116,105,111,110,32,108,105,115,116,0,0,0,0,99,97,108,108,98,97,99,107,32,111,110,32,37,115,32,109,105,115,115,105,110,103,32,99,111,110,116,101,120,116,10,0,99,97,108,108,98,97,99,107,32,111,110,32,37,115,32,109,105,115,115,105,110,103,32,100,101,102,105,110,101,10,0,0,99,97,108,108,98,97,99,107,32,111,110,32,37,115,32,109,105,115,115,105,110,103,32,105,110,102,111,10,0,0,0,0,99,97,108,108,98,97,99,107,32,111,110,32,37,115,32,100,101,102,105,110,101,32,105,115,32,110,111,116,32,101,108,101,109,101,110,116,10,0,0,0,112,117,115,104,105,110,103,32,101,114,114,111,114,10,0,0,82,78,71,32,105,110,116,101,114,110,97,108,32,101,114,114,111,114,32,116,114,121,105,110,103,32,116,111,32,99,111,109,112,105,108,101,32,37,115,10,0,0,0,0,0,0,0,0,110,111,110,101,0,0,0,0,101,109,112,116,121,0,0,0,110,111,116,65,108,108,111,119,101,100,0,0,0,0,0,0,101,120,99,101,112,116,0,0,116,101,120,116,0,0,0,0,101,108,101,109,101,110,116,0,100,97,116,97,116,121,112,101,0,0,0,0,0,0,0,0,118,97,108,117,101,0,0,0,108,105,115,116,0,0,0,0,97,116,116,114,105,98,117,116,101,0,0,0,0,0,0,0,100,101,102,0,0,0,0,0,114,101,102,0,0,0,0,0,101,120,116,101,114,110,97,108,82,101,102,0,0,0,0,0,112,97,114,101,110,116,82,101,102,0,0,0,0,0,0,0,111,112,116,105,111,110,97,108,0,0,0,0,0,0,0,0,122,101,114,111,79,114,77,111,114,101,0,0,0,0,0,0,111,110,101,79,114,77,111,114,101,0,0,0,0,0,0,0,99,104,111,105,99,101,0,0,103,114,111,117,112,0,0,0,105,110,116,101,114,108,101,97,118,101,0,0,0,0,0,0,115,116,97,114,116,0,0,0,110,111,111,112,0,0,0,0,112,97,114,97,109,0,0,0,117,110,107,110,111,119,110,0,97,108,108,111,99,97,116,105,110,103,32,100,101,102,105,110,101,10,0,0,0,0,0,0,69,108,101,109,101,110,116,32,111,114,32,116,101,120,116,32,99,111,110,102,108,105,99,116,115,32,105,110,32,105,110,116,101,114,108,101,97,118,101,10,0,0,0,0,0,0,0,0,65,116,116,114,105,98,117,116,101,115,32,99,111,110,102,108,105,99,116,115,32,105,110,32,105,110,116,101,114,108,101,97,118,101,10,0,0,0,0,0,105,110,32,105,110,116,101,114,108,101,97,118,101,32,99,111,109,112,117,116,97,116,105,111,110,10,0,0,0,0,0,0,24,231,2,0,0,0,0,0,1,0,0,0,0,0,0,0,103,101,116,116,105,110,103,32,101,108,101,109,101,110,116,32,108,105,115,116,10,0,0,0,103,114,97,109,109,97,114,0,70,111,117,110,100,32,102,111,114,98,105,100,100,101,110,32,112,97,116,116,101,114,110,32,100,97,116,97,47,101,120,99,101,112,116,47,47,114,101,102,10,0,0,0,0,0,0,0,73,110,116,101,114,110,97,108,32,102,111,117,110,100,32,110,111,32,100,101,102,105,110,101,32,102,111,114,32,112,97,114,101,110,116,32,114,101,102,115,10,0,0,0,0,0,0,0,73,110,116,101,114,110,97,108,32,102,111,117,110,100,32,110,111,32,100,101,102,105,110,101,32,102,111,114,32,114,101,102,32,37,115,10,0,0,0,0,110,117,108,108,0,0,0,0,70,111,117,110,100,32,102,111,114,98,105,100,100,101,110,32,112,97,116,116,101,114,110,32,100,97,116,97,47,101,120,99,101,112,116,47,47,101,108,101,109,101,110,116,40,114,101,102,41,10,0,0,0,0,0,0,70,111,117,110,100,32,102,111,114,98,105,100,100,101,110,32,112,97,116,116,101,114,110,32,108,105,115,116,47,47,101,108,101,109,101,110,116,40,114,101,102,41,10,0,0,0,0,0,70,111,117,110,100,32,102,111,114,98,105,100,100,101,110,32,112,97,116,116,101,114,110,32,97,116,116,114,105,98,117,116,101,47,47,101,108,101,109,101,110,116,40,114,101,102,41,10,0,0,0,0,0,0,0,0,69,108,101,109,101,110,116,32,37,115,32,97,116,116,114,105,98,117,116,101,115,32,104,97,118,101,32,97,32,99,111,110,116,101,110,116,32,116,121,112,101,32,101,114,114,111,114,10,0,0,0,0,0,0,0,0,69,108,101,109,101,110,116,32,37,115,32,104,97,115,32,97,32,99,111,110,116,101,110,116,32,116,121,112,101,32,101,114,114,111,114,10,0,0,0,0,70,111,117,110,100,32,102,111,114,98,105,100,100,101,110,32,112,97,116,116,101,114,110,32,97,116,116,114,105,98,117,116,101,47,47,97,116,116,114,105,98,117,116,101,10,0,0,0,70,111,117,110,100,32,102,111,114,98,105,100,100,101,110,32,112,97,116,116,101,114,110,32,108,105,115,116,47,47,97,116,116,114,105,98,117,116,101,10,0,0,0,0,0,0,0,0,70,111,117,110,100,32,102,111,114,98,105,100,100,101,110,32,112,97,116,116,101,114,110,32,111,110,101,79,114,77,111,114,101,47,47,103,114,111,117,112,47,47,97,116,116,114,105,98,117,116,101,10,0,0,0,0,70,111,117,110,100,32,102,111,114,98,105,100,100,101,110,32,112,97,116,116,101,114,110,32,111,110,101,79,114,77,111,114,101,47,47,105,110,116,101,114,108,101,97,118,101,47,47,97,116,116,114,105,98,117,116,101,10,0,0,0,0,0,0,0,70,111,117,110,100,32,102,111,114,98,105,100,100,101,110,32,112,97,116,116,101,114,110,32,100,97,116,97,47,101,120,99,101,112,116,47,47,97,116,116,114,105,98,117,116,101,10,0,70,111,117,110,100,32,102,111,114,98,105,100,100,101,110,32,112,97,116,116,101,114,110,32,115,116,97,114,116,47,47,97,116,116,114,105,98,117,116,101,10,0,0,0,0,0,0,0,70,111,117,110,100,32,97,110,121,78,97,109,101,32,97,116,116,114,105,98,117,116,101,32,119,105,116,104,111,117,116,32,111,110,101,79,114,77,111,114,101,32,97,110,99,101,115,116,111,114,10,0,0,0,0,0,70,111,117,110,100,32,110,115,78,97,109,101,32,97,116,116,114,105,98,117,116,101,32,119,105,116,104,111,117,116,32,111,110,101,79,114,77,111,114,101,32,97,110,99,101,115,116,111,114,10,0,0,0,0,0,0,70,111,117,110,100,32,102,111,114,98,105,100,100,101,110,32,112,97,116,116,101,114,110,32,100,97,116,97,47,101,120,99,101,112,116,47,47,111,110,101,79,114,77,111,114,101,10,0,70,111,117,110,100,32,102,111,114,98,105,100,100,101,110,32,112,97,116,116,101,114,110,32,115,116,97,114,116,47,47,111,110,101,79,114,77,111,114,101,10,0,0,0,0,0,0,0,70,111,117,110,100,32,102,111,114,98,105,100,100,101,110,32,112,97,116,116,101,114,110,32,108,105,115,116,47,47,108,105,115,116,10,0,0,0,0,0,70,111,117,110,100,32,102,111,114,98,105,100,100,101,110,32,112,97,116,116,101,114,110,32,100,97,116,97,47,101,120,99,101,112,116,47,47,108,105,115,116,10,0,0,0,0,0,0,70,111,117,110,100,32,102,111,114,98,105,100,100,101,110,32,112,97,116,116,101,114,110,32,115,116,97,114,116,47,47,108,105,115,116,10,0,0,0,0,70,111,117,110,100,32,102,111,114,98,105,100,100,101,110,32,112,97,116,116,101,114,110,32,100,97,116,97,47,101,120,99,101,112,116,47,47,103,114,111,117,112,10,0,0,0,0,0,70,111,117,110,100,32,102,111,114,98,105,100,100,101,110,32,112,97,116,116,101,114,110,32,115,116,97,114,116,47,47,103,114,111,117,112,10,0,0,0,70,111,117,110,100,32,102,111,114,98,105,100,100,101,110,32,112,97,116,116,101,114,110,32,108,105,115,116,47,47,105,110,116,101,114,108,101,97,118,101,10,0,0,0,0,0,0,0,70,111,117,110,100,32,102,111,114,98,105,100,100,101,110,32,112,97,116,116,101,114,110,32,100,97,116,97,47,101,120,99,101,112,116,47,47,105,110,116,101,114,108,101,97,118,101,10,0,0,0,0,0,0,0,0,70,111,117,110,100,32,102,111,114,98,105,100,100,101,110,32,112,97,116,116,101,114,110,32,115,116,97,114,116,47,47,105,110,116,101,114,108,101,97,118,101,10,0,0,0,0,0,0,70,111,117,110,100,32,102,111,114,98,105,100,100,101,110,32,112,97,116,116,101,114,110,32,115,116,97,114,116,47,47,100,97,116,97,10,0,0,0,0,70,111,117,110,100,32,102,111,114,98,105,100,100,101,110,32,112,97,116,116,101,114,110,32,115,116,97,114,116,47,47,118,97,108,117,101,10,0,0,0,70,111,117,110,100,32,102,111,114,98,105,100,100,101,110,32,112,97,116,116,101,114,110,32,108,105,115,116,47,47,116,101,120,116,10,0,0,0,0,0,70,111,117,110,100,32,102,111,114,98,105,100,100,101,110,32,112,97,116,116,101,114,110,32,100,97,116,97,47,101,120,99,101,112,116,47,47,116,101,120,116,10,0,0,0,0,0,0,70,111,117,110,100,32,102,111,114,98,105,100,100,101,110,32,112,97,116,116,101,114,110,32,115,116,97,114,116,47,47,116,101,120,116,10,0,0,0,0,70,111,117,110,100,32,102,111,114,98,105,100,100,101,110,32,112,97,116,116,101,114,110,32,100,97,116,97,47,101,120,99,101,112,116,47,47,101,109,112,116,121,10,0,0,0,0,0,70,111,117,110,100,32,102,111,114,98,105,100,100,101,110,32,112,97,116,116,101,114,110,32,115,116,97,114,116,47,47,101,109,112,116,121,10,0,0,0,98,117,105,108,100,105,110,103,32,99,104,111,105,99,101,10,0,0,0,0,0,0,0,0,98,117,105,108,100,105,110,103,32,103,114,111,117,112,10,0,65,116,116,114,105,98,117,116,101,115,32,99,111,110,102,108,105,99,116,115,32,105,110,32,103,114,111,117,112,10,0,0,68,101,116,101,99,116,101,100,32,97,32,99,121,99,108,101,32,105,110,32,37,115,32,114,101,102,101,114,101,110,99,101,115,10,0,0,0,0,0,0,115,116,97,114,116,32,104,97,115,32,110,111,32,99,104,105,108,100,114,101,110,10,0,0,101,108,101,109,101,110,116,32,101,109,112,116,121,32,105,115,32,110,111,116,32,101,109,112,116,121,10,0,0,0,0,0,101,108,101,109,101,110,116,32,110,111,116,65,108,108,111,119,101,100,32,105,115,32,110,111,116,32,101,109,112,116,121,10,0,0,0,0,0,0,0,0,115,116,97,114,116,32,109,111,114,101,32,116,104,97,110,32,111,110,101,32,99,104,105,108,100,114,101,110,10,0,0,0,101,109,112,116,121,58,32,104,97,100,32,97,32,99,104,105,108,100,32,110,111,100,101,10,0,0,0,0,0,0,0,0,116,101,120,116,58,32,104,97,100,32,97,32,99,104,105,108,100,32,110,111,100,101,10,0,69,108,101,109,101,110,116,32,37,115,32,105,115,32,101,109,112,116,121,10,0,0,0,0,110,97,109,101,0,0,0,0,114,101,102,32,104,97,115,32,110,111,32,110,97,109,101,10,0,0,0,0,0,0,0,0,114,101,102,32,110,97,109,101,32,39,37,115,39,32,105,115,32,110,111,116,32,97,110,32,78,67,78,97,109,101,10,0,114,101,102,32,105,115,32,110,111,116,32,101,109,112,116,121,10,0,0,0,0,0,0,0,67,111,117,108,100,32,110,111,116,32,99,114,101,97,116,101,32,114,101,102,101,114,101,110,99,101,115,32,104,97,115,104,10,0,0,0,0,0,0,0,69,114,114,111,114,32,114,101,102,115,32,100,101,102,105,110,105,116,105,111,110,115,32,39,37,115,39,10,0,0,0,0,69,114,114,111,114,32,114,101,102,115,32,100,101,102,105,110,105,116,105,111,110,115,10,0,100,97,116,97,0,0,0,0,120,109,108,82,101,108,97,120,78,71,80,97,114,115,101,58,32,110,111,116,65,108,108,111,119,101,100,32,101,108,101,109,101,110,116,32,105,115,32,110,111,116,32,101,109,112,116,121,10,0,0,0,0,0,0,0,85,115,101,32,111,102,32,112,97,114,101,110,116,82,101,102,32,119,105,116,104,111,117,116,32,97,32,112,97,114,101,110,116,32,103,114,97,109,109,97,114,10,0,0,0,0,0,0,112,97,114,101,110,116,82,101,102,32,104,97,115,32,110,111,32,110,97,109,101,10,0,0,112,97,114,101,110,116,82,101,102,32,110,97,109,101,32,39,37,115,39,32,105,115,32,110,111,116,32,97,110,32,78,67,78,97,109,101,10,0,0,0,112,97,114,101,110,116,82,101,102,32,105,115,32,110,111,116,32,101,109,112,116,121,10,0,73,110,116,101,114,110,97,108,32,101,114,114,111,114,32,112,97,114,101,110,116,82,101,102,32,100,101,102,105,110,105,116,105,111,110,115,32,39,37,115,39,10,0,0,0,0,0,0,109,105,120,101,100,0,0,0,77,105,120,101,100,32,105,115,32,101,109,112,116,121,10,0,85,110,101,120,112,101,99,116,101,100,32,110,111,100,101,32,37,115,32,105,115,32,110,111,116,32,97,32,112,97,116,116,101,114,110,10,0,0,0,0,110,115,0,0,0,0,0,0,99,114,101,97,116,101,32,105,110,116,101,114,108,101,97,118,101,115,10,0,0,0,0,0,105,110,116,101,114,108,101,97,118,101,37,100,0,0,0,0,70,97,105,108,101,100,32,116,111,32,97,100,100,32,37,115,32,116,111,32,104,97,115,104,32,116,97,98,108,101,10,0,69,108,101,109,101,110,116,32,105,110,116,101,114,108,101,97,118,101,32,105,115,32,101,109,112,116,121,10,0,0,0,0,116,121,112,101,0,0,0,0,118,97,108,117,101,32,116,121,112,101,32,39,37,115,39,32,105,115,32,110,111,116,32,97,110,32,78,67,78,97,109,101,10,0,0,0,0,0,0,0,104,116,116,112,58,47,47,114,101,108,97,120,110,103,46,111,114,103,47,110,115,47,115,116,114,117,99,116,117,114,101,47,49,46,48,0,0,0,0,0,85,115,101,32,111,102,32,117,110,114,101,103,105,115,116,101,114,101,100,32,116,121,112,101,32,108,105,98,114,97,114,121,32,39,37,115,39,10,0,0,73,110,116,101,114,110,97,108,32,101,114,114,111,114,32,119,105,116,104,32,116,121,112,101,32,108,105,98,114,97,114,121,32,39,37,115,39,58,32,110,111,32,39,104,97,118,101,39,10,0,0,0,0,0,0,0,69,114,114,111,114,32,116,121,112,101,32,39,37,115,39,32,105,115,32,110,111,116,32,101,120,112,111,114,116,101,100,32,98,121,32,116,121,112,101,32,108,105,98,114,97,114,121,32,39,37,115,39,10,0,0,0,69,120,112,101,99,116,105,110,103,32,97,32,115,105,110,103,108,101,32,116,101,120,116,32,118,97,108,117,101,32,102,111,114,32,60,118,97,108,117,101,62,99,111,110,116,101,110,116,10,0,0,0,0,0,0,0,69,108,101,109,101,110,116,32,60,118,97,108,117,101,62,32,104,97,115,32,110,111,32,99,111,110,116,101,110,116,10,0,86,97,108,117,101,32,39,37,115,39,32,105,115,32,110,111,116,32,97,99,99,101,112,116,97,98,108,101,32,102,111,114,32,116,121,112,101,32,39,37,115,39,10,0,0,0,0,0,100,97,116,97,116,121,112,101,76,105,98,114,97,114,121,0,58,47,35,63,0,0,0,0,100,97,116,97,32,104,97,115,32,110,111,32,116,121,112,101,10,0,0,0,0,0,0,0,100,97,116,97,32,116,121,112,101,32,39,37,115,39,32,105,115,32,110,111,116,32,97,110,32,78,67,78,97,109,101,10,0,0,0,0,0,0,0,0,73,68,82,69,70,0,0,0,73,68,82,69,70,83,0,0,84,121,112,101,32,108,105,98,114,97,114,121,32,39,37,115,39,32,100,111,101,115,32,110,111,116,32,97,108,108,111,119,32,116,121,112,101,32,112,97,114,97,109,101,116,101,114,115,10,0,0,0,0,0,0,0,112,97,114,97,109,32,104,97,115,32,110,111,32,110,97,109,101,10,0,0,0,0,0,0,101,120,99,101,112,116,32,104,97,115,32,110,111,32,99,111,110,116,101,110,116,10,0,0,69,108,101,109,101,110,116,32,100,97,116,97,32,104,97,115,32,117,110,101,120,112,101,99,116,101,100,32,99,111,110,116,101,110,116,32,37,115,10,0,120,109,108,82,101,108,97,120,78,71,80,97,114,115,101,97,116,116,114,105,98,117,116,101,58,32,97,116,116,114,105,98,117,116,101,32,104,97,115,32,110,111,32,99,104,105,108,100,114,101,110,10,0,0,0,0,97,116,116,114,105,98,117,116,101,32,104,97,115,32,105,110,118,97,108,105,100,32,99,111,110,116,101,110,116,10,0,0,82,78,71,32,73,110,116,101,114,110,97,108,32,101,114,114,111,114,44,32,110,111,111,112,32,102,111,117,110,100,32,105,110,32,97,116,116,114,105,98,117,116,101,10,0,0,0,0,97,116,116,114,105,98,117,116,101,32,104,97,115,32,109,117,108,116,105,112,108,101,32,99,104,105,108,100,114,101,110,10,0,0,0,0,0,0,0,0,97,110,121,78,97,109,101,0,110,115,78,97,109,101,0,0,69,108,101,109,101,110,116,32,37,115,32,110,97,109,101,32,39,37,115,39,32,105,115,32,110,111,116,32,97,110,32,78,67,78,97,109,101,10,0,0,110,97,109,101,32,39,37,115,39,32,105,115,32,110,111,116,32,97,110,32,78,67,78,97,109,101,10,0,0,0,0,0,104,116,116,112,58,47,47,119,119,119,46,119,51,46,111,114,103,47,50,48,48,48,47,120,109,108,110,115,0,0,0,0,65,116,116,114,105,98,117,116,101,32,119,105,116,104,32,110,97,109,101,115,112,97,99,101,32,39,37,115,39,32,105,115,32,110,111,116,32,97,108,108,111,119,101,100,10,0,0,0,120,109,108,110,115,0,0,0,65,116,116,114,105,98,117,116,101,32,119,105,116,104,32,81,78,97,109,101,32,39,120,109,108,110,115,39,32,105,115,32,110,111,116,32,97,108,108,111,119,101,100,10,0,0,0,0,110,115,78,97,109,101,32,104,97,115,32,110,111,32,110,115,32,97,116,116,114,105,98,117,116,101,10,0,0,0,0,0,69,108,101,109,101,110,116,32,99,104,111,105,99,101,32,105,115,32,101,109,112,116,121,10,0,0,0,0,0,0,0,0,101,120,112,101,99,116,105,110,103,32,110,97,109,101,44,32,97,110,121,78,97,109,101,44,32,110,115,78,97,109,101,32,111,114,32,99,104,111,105,99,101,32,58,32,103,111,116,32,37,115,10,0,0,0,0,0,110,111,116,104,105,110,103,0,69,120,112,101,99,116,105,110,103,32,97,110,32,101,120,99,101,112,116,32,110,111,100,101,10,0,0,0,0,0,0,0,101,120,99,101,112,116,78,97,109,101,67,108,97,115,115,32,97,108,108,111,119,115,32,111,110,108,121,32,97,32,115,105,110,103,108,101,32,101,120,99,101,112,116,32,110,111,100,101,10,0,0,0,0,0,0,0,120,109,108,82,101,108,97,120,78,71,80,97,114,115,101,69,108,101,109,101,110,116,58,32,101,108,101,109,101,110,116,32,104,97,115,32,110,111,32,99,104,105,108,100,114,101,110,10,0,0,0,0,0,0,0,0,120,109,108,82,101,108,97,120,78,71,80,97,114,115,101,69,108,101,109,101,110,116,58,32,101,108,101,109,101,110,116,32,104,97,115,32,110,111,32,99,111,110,116,101,110,116,10,0,82,78,71,32,73,110,116,101,114,110,97,108,32,101,114,114,111,114,44,32,115,116,97,114,116,32,102,111,117,110,100,32,105,110,32,101,108,101,109,101,110,116,10,0,0,0,0,0,82,78,71,32,73,110,116,101,114,110,97,108,32,101,114,114,111,114,44,32,112,97,114,97,109,32,102,111,117,110,100,32,105,110,32,101,108,101,109,101,110,116,10,0,0,0,0,0,82,78,71,32,73,110,116,101,114,110,97,108,32,101,114,114,111,114,44,32,101,120,99,101,112,116,32,102,111,117,110,100,32,105,110,32,101,108,101,109,101,110,116,10,0,0,0,0,82,78,71,32,73,110,116,101,114,110,97,108,32,101,114,114,111,114,44,32,110,111,111,112,32,102,111,117,110,100,32,105,110,32,101,108,101,109,101,110,116,10,0,0,0,0,0,0,70,97,105,108,101,100,32,116,111,32,112,97,114,115,101,32,60,103,114,97,109,109,97,114,62,32,99,111,110,116,101,110,116,10,0,0,0,0,0,0,69,108,101,109,101,110,116,32,60,103,114,97,109,109,97,114,62,32,104,97,115,32,110,111,32,60,115,116,97,114,116,62,10,0,0,0,0,0,0,0,73,110,116,101,114,110,97,108,32,101,114,114,111,114,58,32,110,111,32,103,114,97,109,109,97,114,32,105,110,32,67,104,101,99,107,82,101,102,101,114,101,110,99,101,32,37,115,10,0,0,0,0,0,0,0,0,73,110,116,101,114,110,97,108,32,101,114,114,111,114,58,32,114,101,102,101,114,101,110,99,101,32,104,97,115,32,99,111,110,116,101,110,116,32,105,110,32,67,104,101,99,107,82,101,102,101,114,101,110,99,101,32,37,115,10,0,0,0,0,0,82,101,102,101,114,101,110,99,101,32,37,115,32,104,97,115,32,110,111,32,109,97,116,99,104,105,110,103,32,100,101,102,105,110,105,116,105,111,110,10,0,0,0,0,0,0,0,0,99,111,109,98,105,110,101,0,68,101,102,105,110,101,115,32,102,111,114,32,37,115,32,117,115,101,32,98,111,116,104,32,39,99,104,111,105,99,101,39,32,97,110,100,32,39,105,110,116,101,114,108,101,97,118,101,39,10,0,0,0,0,0,0,68,101,102,105,110,101,115,32,102,111,114,32,37,115,32,117,115,101,32,117,110,107,110,111,119,110,32,99,111,109,98,105,110,101,32,118,97,108,117,101,32,39,37,115,39,39,10,0,83,111,109,101,32,100,101,102,105,110,101,115,32,102,111,114,32,37,115,32,110,101,101,100,115,32,116,104,101,32,99,111,109,98,105,110,101,32,97,116,116,114,105,98,117,116,101,10,0,0,0,0,0,0,0,0,70,97,105,108,101,100,32,116,111,32,99,114,101,97,116,101,32,105,110,116,101,114,108,101,97,118,101,115,32,104,97,115,104,32,116,97,98,108,101,10,0,0,0,0,0,0,0,0,73,110,116,101,114,110,97,108,32,101,114,114,111,114,58,32,115,116,97,114,116,32,101,108,101,109,101,110,116,32,110,111,116,32,102,111,117,110,100,10,0,0,0,0,0,0,0,0,60,115,116,97,114,116,62,32,117,115,101,32,98,111,116,104,32,39,99,104,111,105,99,101,39,32,97,110,100,32,39,105,110,116,101,114,108,101,97,118,101,39,10,0,0,0,0,0,60,115,116,97,114,116,62,32,117,115,101,115,32,117,110,107,110,111,119,110,32,99,111,109,98,105,110,101,32,118,97,108,117,101,32,39,37,115,39,39,10,0,0,0,0,0,0,0,83,111,109,101,32,60,115,116,97,114,116,62,32,101,108,101,109,101,110,116,32,109,105,115,115,32,116,104,101,32,99,111,109,98,105,110,101,32,97,116,116,114,105,98,117,116,101,10,0,0,0,0,0,0,0,0,103,114,97,109,109,97,114,32,104,97,115,32,110,111,32,99,104,105,108,100,114,101,110,10,0,0,0,0,0,0,0,0,100,101,102,105,110,101,0,0,105,110,99,108,117,100,101,0,103,114,97,109,109,97,114,32,104,97,115,32,117,110,101,120,112,101,99,116,101,100,32,99,104,105,108,100,32,37,115,10,0,0,0,0,0,0,0,0,73,110,99,108,117,100,101,32,110,111,100,101,32,104,97,115,32,110,111,32,100,97,116,97,10,0,0,0,0,0,0,0,73,110,99,108,117,100,101,32,100,111,99,117,109,101,110,116,32,105,115,32,101,109,112,116,121,10,0,0,0,0,0,0,73,110,99,108,117,100,101,32,100,111,99,117,109,101,110,116,32,114,111,111,116,32,105,115,32,110,111,116,32,97,32,103,114,97,109,109,97,114,10,0,100,101,102,105,110,101,32,104,97,115,32,110,111,32,110,97,109,101,10,0,0,0,0,0,100,101,102,105,110,101,32,110,97,109,101,32,39,37,115,39,32,105,115,32,110,111,116,32,97,110,32,78,67,78,97,109,101,10,0,0,0,0,0,0,100,101,102,105,110,101,32,104,97,115,32,110,111,32,99,104,105,108,100,114,101,110,10,0,67,111,117,108,100,32,110,111,116,32,99,114,101,97,116,101,32,100,101,102,105,110,105,116,105,111,110,32,104,97,115,104,10,0,0,0,0,0,0,0,73,110,116,101,114,110,97,108,32,101,114,114,111,114,32,111,110,32,100,101,102,105,110,101,32,97,103,103,114,101,103,97,116,105,111,110,32,111,102,32,37,115,10,0,0,0,0,0,101,108,101,109,101,110,116,32,37,115,32,100,111,101,115,110,39,116,32,97,108,108,111,119,32,102,111,114,101,105,103,110,32,101,108,101,109,101,110,116,115,10,0,0,0,0,0,0,104,114,101,102,0,0,0,0,120,109,108,82,101,108,97,120,78,71,80,97,114,115,101,58,32,101,120,116,101,114,110,97,108,82,101,102,32,104,97,115,32,110,111,32,104,114,101,102,32,97,116,116,114,105,98,117,116,101,10,0,0,0,0,0,73,110,99,111,114,114,101,99,116,32,85,82,73,32,102,111,114,32,101,120,116,101,114,110,97,108,82,101,102,32,37,115,10,0,0,0,0,0,0,0,70,114,97,103,109,101,110,116,32,102,111,114,98,105,100,100,101,110,32,105,110,32,85,82,73,32,102,111,114,32,101,120,116,101,114,110,97,108,82,101,102,32,37,115,10,0,0,0,70,97,105,108,101,100,32,116,111,32,99,111,109,112,117,116,101,32,85,82,76,32,102,111,114,32,101,120,116,101,114,110,97,108,82,101,102,32,37,115,10,0,0,0,0,0,0,0,70,97,105,108,101,100,32,116,111,32,108,111,97,100,32,101,120,116,101,114,110,97,108,82,101,102,32,37,115,10,0,0,120,109,108,82,101,108,97,120,78,71,80,97,114,115,101,58,32,105,110,99,108,117,100,101,32,104,97,115,32,110,111,32,104,114,101,102,32,97,116,116,114,105,98,117,116,101,10,0,70,97,105,108,101,100,32,116,111,32,99,111,109,112,117,116,101,32,85,82,76,32,102,111,114,32,105,110,99,108,117,100,101,32,37,115,10,0,0,0,70,97,105,108,101,100,32,116,111,32,108,111,97,100,32,105,110,99,108,117,100,101,32,37,115,10,0,0,0,0,0,0,70,97,105,108,101,100,32,116,111,32,99,114,101,97,116,101,32,97,32,110,97,109,101,32,37,115,32,101,108,101,109,101,110,116,10,0,0,0,0,0,120,109,108,82,101,108,97,120,78,71,80,97,114,115,101,58,32,110,111,32,110,97,109,101,115,112,97,99,101,32,102,111,114,32,112,114,101,102,105,120,32,37,115,10,0,0,0,0,70,111,117,110,100,32,110,115,78,97,109,101,47,101,120,99,101,112,116,47,47,110,115,78,97,109,101,32,102,111,114,98,105,100,100,101,110,32,99,111,110,115,116,114,117,99,116,10,0,0,0,0,0,0,0,0,70,111,117,110,100,32,97,110,121,78,97,109,101,47,101,120,99,101,112,116,47,47,97,110,121,78,97,109,101,32,102,111,114,98,105,100,100,101,110,32,99,111,110,115,116,114,117,99,116,10,0,0,0,0,0,0,70,111,117,110,100,32,110,115,78,97,109,101,47,101,120,99,101,112,116,47,47,97,110,121,78,97,109,101,32,102,111,114,98,105,100,100,101,110,32,99,111,110,115,116,114,117,99,116,10,0,0,0,0,0,0,0,100,105,118,0,0,0,0,0,68,101,116,101,99,116,101,100,32,97,110,32,73,110,99,108,117,100,101,32,114,101,99,117,114,115,105,111,110,32,102,111,114,32,37,115,10,0,0,0,120,109,108,82,101,108,97,120,78,71,58,32,99,111,117,108,100,32,110,111,116,32,108,111,97,100,32,37,115,10,0,0,97,108,108,111,99,97,116,105,110,103,32,105,110,99,108,117,100,101,10,0,0,0,0,0,120,109,108,82,101,108,97,120,78,71,58,32,105,110,99,108,117,100,101,100,32,100,111,99,117,109,101,110,116,32,105,115,32,101,109,112,116,121,32,37,115,10,0,0,0,0,0,0,120,109,108,82,101,108,97,120,78,71,58,32,105,110,99,108,117,100,101,100,32,100,111,99,117,109,101,110,116,32,37,115,32,114,111,111,116,32,105,115,32,110,111,116,32,97,32,103,114,97,109,109,97,114,10,0,120,109,108,82,101,108,97,120,78,71,58,32,105,110,99,108,117,100,101,32,37,115,32,104,97,115,32,97,32,115,116,97,114,116,32,98,117,116,32,110,111,116,32,116,104,101,32,105,110,99,108,117,100,101,100,32,103,114,97,109,109,97,114,10,0,0,0,0,0,0,0,0,120,109,108,82,101,108,97,120,78,71,58,32,105,110,99,108,117,100,101,32,37,115,32,104,97,115,32,100,101,102,105,110,101,32,119,105,116,104,111,117,116,32,110,97,109,101,10,0,120,109,108,82,101,108,97,120,78,71,58,32,105,110,99,108,117,100,101,32,37,115,32,104,97,115,32,97,32,100,101,102,105,110,101,32,37,115,32,98,117,116,32,110,111,116,32,116,104,101,32,105,110,99,108,117,100,101,100,32,103,114,97,109,109,97,114,10,0,0,0,0,68,101,116,101,99,116,101,100,32,97,110,32,101,120,116,101,114,110,97,108,82,101,102,32,114,101,99,117,114,115,105,111,110,32,102,111,114,32,37,115,10,0,0,0,0,0,0,0,120,109,108,82,101,108,97,120,78,71,58,32,97,108,108,111,99,97,116,101,32,109,101,109,111,114,121,32,102,111,114,32,100,111,99,32,37,115,10,0,97,100,100,105,110,103,32,100,111,99,117,109,101,110,116,10,0,0,0,0,0,0,0,0,65,116,116,114,105,98,117,116,101,32,37,115,32,105,115,32,110,111,116,32,97,108,108,111,119,101,100,32,111,110,32,37,115,10,0,0,0,0,0,0,65,116,116,114,105,98,117,116,101,32,37,115,32,99,111,110,116,97,105,110,115,32,105,110,118,97,108,105,100,32,85,82,73,32,37,115,10,0,0,0,65,116,116,114,105,98,117,116,101,32,37,115,32,85,82,73,32,37,115,32,105,115,32,110,111,116,32,97,98,115,111,108,117,116,101,10,0,0,0,0,65,116,116,114,105,98,117,116,101,32,37,115,32,85,82,73,32,37,115,32,104,97,115,32,97,32,102,114,97,103,109,101,110,116,32,73,68,10,0,0,85,110,107,110,111,119,110,32,97,116,116,114,105,98,117,116,101,32,37,115,32,111,110,32,37,115,10,0,0,0,0,0,115,116,114,105,110,103,0,0,116,111,107,101,110,0,0,0,104,116,116,112,58,47,47,119,119,119,46,119,51,46,111,114,103,47,50,48,48,49,47,88,77,76,83,99,104,101,109,97,0,0,0,0,0,0,0,0,109,105,110,73,110,99,108,117,115,105,118,101,0,0,0,0,109,105,110,69,120,99,108,117,115,105,118,101,0,0,0,0,109,97,120,73,110,99,108,117,115,105,118,101,0,0,0,0,109,97,120,69,120,99,108,117,115,105,118,101,0,0,0,0,116,111,116,97,108,68,105,103,105,116,115,0,0,0,0,0,102,114,97,99,116,105,111,110,68,105,103,105,116,115,0,0,112,97,116,116,101,114,110,0,101,110,117,109,101,114,97,116,105,111,110,0,0,0,0,0,119,104,105,116,101,83,112,97,99,101,0,0,0,0,0,0,108,101,110,103,116,104,0,0,109,97,120,76,101,110,103,116,104,0,0,0,0,0,0,0,109,105,110,76,101,110,103,116,104,0,0,0,0,0,0,0,82,101,108,97,120,45,78,71,32,116,121,112,101,115,32,108,105,98,114,97,114,121,32,39,37,115,39,32,97,108,114,101,97,100,121,32,114,101,103,105,115,116,101,114,101,100,10,0,97,100,100,105,110,103,32,116,121,112,101,115,32,108,105,98,114,97,114,121,10,0,0,0,82,101,108,97,120,45,78,71,32,116,121,112,101,115,32,108,105,98,114,97,114,121,32,102,97,105,108,101,100,32,116,111,32,114,101,103,105,115,116,101,114,32,39,37,115,39,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,120,109,108,83,65,88,50,73,110,116,101,114,110,97,108,83,117,98,115,101,116,0,0,0,120,109,108,83,65,88,50,69,120,116,101,114,110,97,108,83,117,98,115,101,116,0,0,0,69,110,116,105,116,121,40,37,115,41,32,100,111,99,117,109,101,110,116,32,109,97,114,107,101,100,32,115,116,97,110,100,97,108,111,110,101,32,98,117,116,32,114,101,113,117,105,114,101,115,32,101,120,116,101,114,110,97,108,32,115,117,98,115,101,116,10,0,0,0,0,0,70,97,105,108,117,114,101,32,116,111,32,112,114,111,99,101,115,115,32,101,110,116,105,116,121,32,37,115,10,0,0,0,69,110,116,105,116,121,40,37,115,41,32,97,108,114,101,97,100,121,32,100,101,102,105,110,101,100,32,105,110,32,116,104,101,32,105,110,116,101,114,110,97,108,32,115,117,98,115,101,116,10,0,0,0,0,0,0,69,110,116,105,116,121,40,37,115,41,32,97,108,114,101,97,100,121,32,100,101,102,105,110,101,100,32,105,110,32,116,104,101,32,101,120,116,101,114,110,97,108,32,115,117,98,115,101,116,10,0,0,0,0,0,0,83,65,88,46,120,109,108,83,65,88,50,69,110,116,105,116,121,68,101,99,108,40,37,115,41,32,99,97,108,108,101,100,32,119,104,105,108,101,32,110,111,116,32,105,110,32,115,117,98,115,101,116,10,0,0,0,120,109,108,58,105,100,0,0,120,109,108,58,105,100,32,58,32,97,116,116,114,105,98,117,116,101,32,116,121,112,101,32,115,104,111,117,108,100,32,98,101,32,73,68,10,0,0,0,83,65,88,46,120,109,108,83,65,88,50,65,116,116,114,105,98,117,116,101,68,101,99,108,40,37,115,41,32,99,97,108,108,101,100,32,119,104,105,108],"i8",ALLOC_NONE,Runtime.GLOBAL_BASE+187248),
	allocate([101,32,110,111,116,32,105,110,32,115,117,98,115,101,116,10,0,0,0,0,0,0,0,0,83,65,88,46,120,109,108,83,65,88,50,69,108,101,109,101,110,116,68,101,99,108,40,37,115,41,32,99,97,108,108,101,100,32,119,104,105,108,101,32,110,111,116,32,105,110,32,115,117,98,115,101,116,10,0,0,83,65,88,46,120,109,108,83,65,88,50,78,111,116,97,116,105,111,110,68,101,99,108,40,37,115,41,32,101,120,116,101,114,110,97,108,73,68,32,111,114,32,80,117,98,108,105,99,73,68,32,109,105,115,115,105,110,103,10,0,0,0,0,0,83,65,88,46,120,109,108,83,65,88,50,78,111,116,97,116,105,111,110,68,101,99,108,40,37,115,41,32,99,97,108,108,101,100,32,119,104,105,108,101,32,110,111,116,32,105,110,32,115,117,98,115,101,116,10,0,83,65,88,46,120,109,108,83,65,88,50,85,110,112,97,114,115,101,100,69,110,116,105,116,121,68,101,99,108,40,37,115,41,32,99,97,108,108,101,100,32,119,104,105,108,101,32,110,111,116,32,105,110,32,115,117,98,115,101,116,10,0,0,0,120,109,108,83,65,88,50,83,116,97,114,116,68,111,99,117,109,101,110,116,0,0,0,0,86,97,108,105,100,97,116,105,111,110,32,102,97,105,108,101,100,58,32,110,111,32,68,84,68,32,102,111,117,110,100,32,33,0,0,0,0,0,0,0,120,109,108,83,65,88,50,83,116,97,114,116,69,108,101,109,101,110,116,0,0,0,0,0,78,97,109,101,115,112,97,99,101,32,112,114,101,102,105,120,32,37,115,32,105,115,32,110,111,116,32,100,101,102,105,110,101,100,10,0,0,0,0,0,120,109,108,83,65,88,50,83,116,97,114,116,69,108,101,109,101,110,116,78,115,0,0,0,120,109,108,0,0,0,0,0,78,97,109,101,115,112,97,99,101,32,112,114,101,102,105,120,32,37,115,32,119,97,115,32,110,111,116,32,102,111,117,110,100,10,0,0,0,0,0,0,78,97,109,101,115,112,97,99,101,32,100,101,102,97,117,108,116,32,112,114,101,102,105,120,32,119,97,115,32,110,111,116,32,102,111,117,110,100,10,0,120,109,108,83,65,88,50,67,104,97,114,97,99,116,101,114,115,0,0,0,0,0,0,0,120,109,108,83,65,88,50,67,104,97,114,97,99,116,101,114,115,58,32,120,109,108,83,116,114,100,117,112,32,114,101,116,117,114,110,101,100,32,78,85,76,76,0,0,0,0,0,0,120,109,108,83,65,88,50,67,104,97,114,97,99,116,101,114,115,58,32,104,117,103,101,32,116,101,120,116,32,110,111,100,101,0,0,0,0,0,0,0,120,109,108,83,65,88,50,67,104,97,114,97,99,116,101,114,115,32,111,118,101,114,102,108,111,119,32,112,114,101,118,101,110,116,101,100,0,0,0,0,2,0,0,0,0,0,0,0,120,109,108,83,65,88,50,84,101,120,116,78,111,100,101,0,120,109,108,83,65,88,50,65,116,116,114,105,98,117,116,101,78,115,0,0,0,0,0,0,120,109,108,58,105,100,32,58,32,97,116,116,114,105,98,117,116,101,32,118,97,108,117,101,32,37,115,32,105,115,32,110,111,116,32,97,110,32,78,67,78,97,109,101,10,0,0,0,120,109,108,110,115,0,0,0,105,110,118,97,108,105,100,32,110,97,109,101,115,112,97,99,101,32,100,101,99,108,97,114,97,116,105,111,110,32,39,37,115,39,10,0,0,0,0,0,65,118,111,105,100,32,97,116,116,114,105,98,117,116,101,32,101,110,100,105,110,103,32,119,105,116,104,32,39,58,39,32,108,105,107,101,32,39,37,115,39,10,0,0,0,0,0,0,120,109,108,110,115,58,32,37,115,32,110,111,116,32,97,32,118,97,108,105,100,32,85,82,73,10,0,0,0,0,0,0,120,109,108,110,115,58,32,85,82,73,32,37,115,32,105,115,32,110,111,116,32,97,98,115,111,108,117,116,101,10,0,0,69,109,112,116,121,32,110,97,109,101,115,112,97,99,101,32,110,97,109,101,32,102,111,114,32,112,114,101,102,105,120,32,37,115,10,0,0,0,0,0,120,109,108,110,115,58,37,115,58,32,37,115,32,110,111,116,32,97,32,118,97,108,105,100,32,85,82,73,10,0,0,0,120,109,108,110,115,58,37,115,58,32,85,82,73,32,37,115,32,105,115,32,110,111,116,32,97,98,115,111,108,117,116,101,10,0,0,0,0,0,0,0,78,97,109,101,115,112,97,99,101,32,112,114,101,102,105,120,32,37,115,32,111,102,32,97,116,116,114,105,98,117,116,101,32,37,115,32,105,115,32,110,111,116,32,100,101,102,105,110,101,100,10,0,0,0,0,0,65,116,116,114,105,98,117,116,101,32,37,115,32,105,110,32,37,115,32,114,101,100,101,102,105,110,101,100,10,0,0,0,58,0,0,0,0,0,0,0,115,116,97,110,100,97,108,111,110,101,58,32,97,116,116,114,105,98,117,116,101,32,37,115,32,111,110,32,37,115,32,100,101,102,97,117,108,116,101,100,32,102,114,111,109,32,101,120,116,101,114,110,97,108,32,115,117,98,115,101,116,10,0,0,111,117,116,32,111,102,32,109,101,109,111,114,121,10,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,0,1,1,1,0,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,0,1,0,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,0,0,0,0,1,0,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,49,1,52,1,62,1,65,1,72,1,74,1,126,1,128,1,195,1,205,1,240,1,244,1,245,1,250,1,23,2,80,2,168,2,187,2,193,2,134,3,134,3,136,3,138,3,140,3,140,3,142,3,161,3,163,3,206,3,208,3,214,3,218,3,218,3,220,3,220,3,222,3,222,3,224,3,224,3,226,3,243,3,1,4,12,4,14,4,79,4,81,4,92,4,94,4,129,4,144,4,196,4,199,4,200,4,203,4,204,4,208,4,235,4,238,4,245,4,248,4,249,4,49,5,86,5,89,5,89,5,97,5,134,5,208,5,234,5,240,5,242,5,33,6,58,6,65,6,74,6,113,6,183,6,186,6,190,6,192,6,206,6,208,6,211,6,213,6,213,6,229,6,230,6,5,9,57,9,61,9,61,9,88,9,97,9,133,9,140,9,143,9,144,9,147,9,168,9,170,9,176,9,178,9,178,9,182,9,185,9,220,9,221,9,223,9,225,9,240,9,241,9,5,10,10,10,15,10,16,10,19,10,40,10,42,10,48,10,50,10,51,10,53,10,54,10,56,10,57,10,89,10,92,10,94,10,94,10,114,10,116,10,133,10,139,10,141,10,141,10,143,10,145,10,147,10,168,10,170,10,176,10,178,10,179,10,181,10,185,10,189,10,189,10,224,10,224,10,5,11,12,11,15,11,16,11,19,11,40,11,42,11,48,11,50,11,51,11,54,11,57,11,61,11,61,11,92,11,93,11,95,11,97,11,133,11,138,11,142,11,144,11,146,11,149,11,153,11,154,11,156,11,156,11,158,11,159,11,163,11,164,11,168,11,170,11,174,11,181,11,183,11,185,11,5,12,12,12,14,12,16,12,18,12,40,12,42,12,51,12,53,12,57,12,96,12,97,12,133,12,140,12,142,12,144,12,146,12,168,12,170,12,179,12,181,12,185,12,222,12,222,12,224,12,225,12,5,13,12,13,14,13,16,13,18,13,40,13,42,13,57,13,96,13,97,13,1,14,46,14,48,14,48,14,50,14,51,14,64,14,69,14,129,14,130,14,132,14,132,14,135,14,136,14,138,14,138,14,141,14,141,14,148,14,151,14,153,14,159,14,161,14,163,14,165,14,165,14,167,14,167,14,170,14,171,14,173,14,174,14,176,14,176,14,178,14,179,14,189,14,189,14,192,14,196,14,64,15,71,15,73,15,105,15,160,16,197,16,208,16,246,16,0,17,0,17,2,17,3,17,5,17,7,17,9,17,9,17,11,17,12,17,14,17,18,17,60,17,60,17,62,17,62,17,64,17,64,17,76,17,76,17,78,17,78,17,80,17,80,17,84,17,85,17,89,17,89,17,95,17,97,17,99,17,99,17,101,17,101,17,103,17,103,17,105,17,105,17,109,17,110,17,114,17,115,17,117,17,117,17,158,17,158,17,168,17,168,17,171,17,171,17,174,17,175,17,183,17,184,17,186,17,186,17,188,17,194,17,235,17,235,17,240,17,240,17,249,17,249,17,0,30,155,30,160,30,249,30,0,31,21,31,24,31,29,31,32,31,69,31,72,31,77,31,80,31,87,31,89,31,89,31,91,31,91,31,93,31,93,31,95,31,125,31,128,31,180,31,182,31,188,31,190,31,190,31,194,31,196,31,198,31,204,31,208,31,211,31,214,31,219,31,224,31,236,31,242,31,244,31,246,31,252,31,38,33,38,33,42,33,43,33,46,33,46,33,128,33,130,33,65,48,148,48,161,48,250,48,5,49,44,49,0,172,163,215,0,0,0,0,197,0,0,0,0,0,0,0,40,9,3,0,0,0,0,0,0,3,69,3,96,3,97,3,131,4,134,4,145,5,161,5,163,5,185,5,187,5,189,5,191,5,191,5,193,5,194,5,196,5,196,5,75,6,82,6,112,6,112,6,214,6,220,6,221,6,223,6,224,6,228,6,231,6,232,6,234,6,237,6,1,9,3,9,60,9,60,9,62,9,76,9,77,9,77,9,81,9,84,9,98,9,99,9,129,9,131,9,188,9,188,9,190,9,190,9,191,9,191,9,192,9,196,9,199,9,200,9,203,9,205,9,215,9,215,9,226,9,227,9,2,10,2,10,60,10,60,10,62,10,62,10,63,10,63,10,64,10,66,10,71,10,72,10,75,10,77,10,112,10,113,10,129,10,131,10,188,10,188,10,190,10,197,10,199,10,201,10,203,10,205,10,1,11,3,11,60,11,60,11,62,11,67,11,71,11,72,11,75,11,77,11,86,11,87,11,130,11,131,11,190,11,194,11,198,11,200,11,202,11,205,11,215,11,215,11,1,12,3,12,62,12,68,12,70,12,72,12,74,12,77,12,85,12,86,12,130,12,131,12,190,12,196,12,198,12,200,12,202,12,205,12,213,12,214,12,2,13,3,13,62,13,67,13,70,13,72,13,74,13,77,13,87,13,87,13,49,14,49,14,52,14,58,14,71,14,78,14,177,14,177,14,180,14,185,14,187,14,188,14,200,14,205,14,24,15,25,15,53,15,53,15,55,15,55,15,57,15,57,15,62,15,62,15,63,15,63,15,113,15,132,15,134,15,139,15,144,15,149,15,151,15,151,15,153,15,173,15,177,15,183,15,185,15,185,15,208,32,220,32,225,32,225,32,42,48,47,48,153,48,153,48,154,48,154,48,0,0,0,0,95,0,0,0,0,0,0,0,80,12,3,0,0,0,0,0,96,6,105,6,240,6,249,6,102,9,111,9,230,9,239,9,102,10,111,10,230,10,239,10,102,11,111,11,231,11,239,11,102,12,111,12,230,12,239,12,102,13,111,13,80,14,89,14,208,14,217,14,32,15,41,15,14,0,0,0,0,0,0,0,224,13,3,0,0,0,0,0,208,2,208,2,209,2,209,2,135,3,135,3,64,6,64,6,70,14,70,14,198,14,198,14,5,48,5,48,49,48,53,48,157,48,158,48,252,48,254,48,10,0,0,0,0,0,0,0,40,14,3,0,0,0,0,0,104,116,116,112,58,47,47,119,119,119,46,119,51,46,111,114,103,47,88,77,76,47,49,57,57,56,47,110,97,109,101,115,112,97,99,101,0,0,0,0,99,104,105,108,100,0,0,0,97,116,116,114,105,98,117,116,101,0,0,0,0,0,0,0,45,47,47,87,51,67,47,47,68,84,68,32,88,72,84,77,76,32,49,46,48,32,83,116,114,105,99,116,47,47,69,78,0,0,0,0,0,0,0,0,45,47,47,87,51,67,47,47,68,84,68,32,88,72,84,77,76,32,49,46,48,32,70,114,97,109,101,115,101,116,47,47,69,78,0,0,0,0,0,0,45,47,47,87,51,67,47,47,68,84,68,32,88,72,84,77,76,32,49,46,48,32,84,114,97,110,115,105,116,105,111,110,97,108,47,47,69,78,0,0,104,116,116,112,58,47,47,119,119,119,46,119,51,46,111,114,103,47,84,82,47,120,104,116,109,108,49,47,68,84,68,47,120,104,116,109,108,49,45,115,116,114,105,99,116,46,100,116,100,0,0,0,0,0,0,0,104,116,116,112,58,47,47,119,119,119,46,119,51,46,111,114,103,47,84,82,47,120,104,116,109,108,49,47,68,84,68,47,120,104,116,109,108,49,45,102,114,97,109,101,115,101,116,46,100,116,100,0,0,0,0,0,104,116,116,112,58,47,47,119,119,119,46,119,51,46,111,114,103,47,84,82,47,120,104,116,109,108,49,47,68,84,68,47,120,104,116,109,108,49,45,116,114,97,110,115,105,116,105,111,110,97,108,46,100,116,100,0,38,35,49,48,59,0,0,0,38,35,49,51,59,0,0,0,38,35,57,59,0,0,0,0,38,113,117,111,116,59,0,0,38,108,116,59,0,0,0,0,38,103,116,59,0,0,0,0,38,97,109,112,59,0,0,0,73,83,79,45,56,56,53,57,45,49,0,0,0,0,0,0,99,114,101,97,116,105,110,103,32,98,117,102,102,101,114,0,85,84,70,45,56,0,0,0,99,114,101,97,116,105,110,103,32,111,117,116,112,117,116,0,60,63,0,0,0,0,0,0,32,0,0,0,0,0,0,0,63,62,0,0,0,0,0,0,60,33,45,45,0,0,0,0,45,45,62,0,0,0,0,0,38,0,0,0,0,0,0,0,59,0,0,0,0,0,0,0,60,33,91,67,68,65,84,65,91,93,93,62,0,0,0,0,60,33,91,67,68,65,84,65,91,0,0,0,0,0,0,0,93,93,62,0,0,0,0,0,60,0,0,0,0,0,0,0,58,0,0,0,0,0,0,0,104,116,109,108,0,0,0,0,32,120,109,108,110,115,61,34,104,116,116,112,58,47,47,119,119,119,46,119,51,46,111,114,103,47,49,57,57,57,47,120,104,116,109,108,34,0,0,0,104,101,97,100,0,0,0,0,109,101,116,97,0,0,0,0,104,116,116,112,45,101,113,117,105,118,0,0,0,0,0,0,67,111,110,116,101,110,116,45,84,121,112,101,0,0,0,0,32,47,62,0,0,0,0,0,62,0,0,0,0,0,0,0,10,0,0,0,0,0,0,0,60,109,101,116,97,32,104,116,116,112,45,101,113,117,105,118,61,34,67,111,110,116,101,110,116,45,84,121,112,101,34,32,99,111,110,116,101,110,116,61,34,116,101,120,116,47,104,116,109,108,59,32,99,104,97,114,115,101,116,61,0,0,0,0,34,32,47,62,0,0,0,0,60,47,0,0,0,0,0,0,104,116,116,112,58,47,47,119,119,119,46,119,51,46,111,114,103,47,49,57,57,57,47,120,104,116,109,108,0,0,0,0,97,114,101,97,0,0,0,0,98,114,0,0,0,0,0,0,98,97,115,101,0,0,0,0,98,97,115,101,102,111,110,116,0,0,0,0,0,0,0,0,99,111,108,0,0,0,0,0,102,114,97,109,101,0,0,0,104,114,0,0,0,0,0,0,105,109,103,0,0,0,0,0,105,110,112,117,116,0,0,0,105,115,105,110,100,101,120,0,108,105,110,107,0,0,0,0,112,97,114,97,109,0,0,0,105,100,0,0,0,0,0,0,110,97,109,101,0,0,0,0,108,97,110,103,0,0,0,0,120,109,108,0,0,0,0,0,97,0,0,0,0,0,0,0,112,0,0,0,0,0,0,0,100,105,118,0,0,0,0,0,109,97,112,0,0,0,0,0,97,112,112,108,101,116,0,0,102,111,114,109,0,0,0,0,105,102,114,97,109,101,0,0,32,105,100,61,34,0,0,0,34,0,0,0,0,0,0,0,32,120,109,108,58,108,97,110,103,61,34,0,0,0,0,0,32,108,97,110,103,61,34,0,61,34,0,0,0,0,0,0,60,33,68,79,67,84,89,80,69,32,0,0,0,0,0,0,32,80,85,66,76,73,67,32,0,0,0,0,0,0,0,0,32,83,89,83,84,69,77,32,0,0,0,0,0,0,0,0,32,91,10,0,0,0,0,0,93,62,0,0,0,0,0,0,120,109,108,69,115,99,97,112,101,69,110,116,105,116,105,101,115,32,58,32,99,104,97,114,32,111,117,116,32,111,102,32,114,97,110,103,101,10,0,0,115,116,114,105,110,103,32,105,115,32,110,111,116,32,105,110,32,85,84,70,45,56,10,0,105,110,118,97,108,105,100,32,99,104,97,114,97,99,116,101,114,32,118,97,108,117,101,10,0,0,0,0,0,0,0,0,117,110,107,110,111,119,110,32,101,110,99,111,100,105,110,103,32,37,115,10,0,0,0,0,100,111,99,117,109,101,110,116,32,104,97,115,32,110,111,32,68,79,67,84,89,80,69,10,0,0,0,0,0,0,0,0,117,110,101,120,112,101,99,116,101,100,32,101,114,114,111,114,32,110,117,109,98,101,114,10,0,0,0,0,0,0,0,0,47,62,0,0,0,0,0,0,72,84,77,76,0,0,0,0,99,114,101,97,116,105,110,103,32,101,110,99,111,100,105,110,103,32,98,117,102,102,101,114,0,0,0,0,0,0,0,0,60,63,120,109,108,32,118,101,114,115,105,111,110,61,0,0,34,49,46,48,34,0,0,0,32,101,110,99,111,100,105,110,103,61,0,0,0,0,0,0,32,115,116,97,110,100,97,108,111,110,101,61,34,110,111,34,0,0,0,0,0,0,0,0,32,115,116,97,110,100,97,108,111,110,101,61,34,121,101,115,34,0,0,0,0,0,0,0,63,62,10,0,0,0,0,0,99,114,101,97,116,105,110,103,32,115,97,118,105,110,103,32,99,111,110,116,101,120,116,0,120,109,108,110,115,58,0,0,120,109,108,110,115,0,0,0,61,0,0,0,0,0,0,0,97,108,108,111,99,97,116,105,110,103,32,115,99,104,101,109,97,32,112,97,114,115,101,114,32,99,111,110,116,101,120,116,0,0,0,0,0,0,0,0,97,108,108,111,99,97,116,105,110,103,32,115,99,104,101,109,97,32,112,97,114,115,101,114,32,88,80,97,116,104,32,99,111,110,116,101,120,116,0,0,120,109,108,83,99,104,101,109,97,116,114,111,110,80,97,114,115,101,58,32,99,111,117,108,100,32,110,111,116,32,108,111,97,100,32,39,37,115,39,46,10,0,0,0,0,0,0,0,120,109,108,83,99,104,101,109,97,116,114,111,110,80,97,114,115,101,58,32,99,111,117,108,100,32,110,111,116,32,112,97,114,115,101,46,10,0,0,0,105,110,95,109,101,109,111,114,121,95,98,117,102,102,101,114,0,0,0,0,0,0,0,0,84,104,101,32,115,99,104,101,109,97,32,104,97,115,32,110,111,32,100,111,99,117,109,101,110,116,32,101,108,101,109,101,110,116,46,10,0,0,0,0,115,99,104,101,109,97,0,0,96,25,3,0,0,0,0,0,56,25,3,0,0,0,0,0,84,104,101,32,88,77,76,32,100,111,99,117,109,101,110,116,32,39,37,115,39,32,105,115,32,110,111,116,32,97,32,88,77,76,32,115,99,104,101,109,97,116,114,111,110,32,100,111,99,117,109,101,110,116,0,0,116,105,116,108,101,0,0,0,110,115,0,0,0,0,0,0,112,114,101,102,105,120,0,0,117,114,105,0,0,0,0,0,110,115,32,101,108,101,109,101,110,116,32,104,97,115,32,110,111,32,117,114,105,0,0,0,110,115,32,101,108,101,109,101,110,116,32,104,97,115,32,110,111,32,112,114,101,102,105,120,0,0,0,0,0,0,0,0,112,97,116,116,101,114,110,0,69,120,112,101,99,116,105,110,103,32,97,32,112,97,116,116,101,114,110,32,101,108,101,109,101,110,116,32,105,110,115,116,101,97,100,32,111,102,32,37,115,0,0,0,0,0,0,0,84,104,101,32,115,99,104,101,109,97,116,114,111,110,32,100,111,99,117,109,101,110,116,32,39,37,115,39,32,104,97,115,32,110,111,32,112,97,116,116,101,114,110,0,0,0,0,0,97,108,108,111,99,97,116,105,110,103,32,118,97,108,105,100,97,116,105,111,110,32,99,111,110,116,101,120,116,0,0,0,85,110,105,109,112,108,101,109,101,110,116,101,100,32,98,108,111,99,107,32,97,116,32,37,115,58,37,100,10,0,0,0,46,46,47,108,105,98,120,109,108,50,47,115,99,104,101,109,97,116,114,111,110,46,99,0,80,97,116,116,101,114,110,58,32,37,115,10,0,0,0,0,37,115,0,0,0,0,0,0,110,111,100,101,32,102,97,105,108,101,100,32,97,115,115,101,114,116,0,0,0,0,0,0,110,111,100,101,32,102,97,105,108,101,100,32,114,101,112,111,114,116,0,0,0,0,0,0,37,115,32,108,105,110,101,32,37,108,100,58,32,37,115,10,0,0,0,0,0,0,0,0,110,97,109,101,0,0,0,0,112,97,116,104,0,0,0,0,58,0,0,0,0,0,0,0,105,100,0,0,0,0,0,0,114,117,108,101,0,0,0,0,69,120,112,101,99,116,105,110,103,32,97,32,114,117,108,101,32,101,108,101,109,101,110,116,32,105,110,115,116,101,97,100,32,111,102,32,37,115,0,0,80,97,116,116,101,114,110,32,104,97,115,32,110,111,32,114,117,108,101,32,101,108,101,109,101,110,116,0,0,0,0,0,99,111,110,116,101,120,116,0,114,117,108,101,32,104,97,115,32,110,111,32,99,111,110,116,101,120,116,32,97,116,116,114,105,98,117,116,101,0,0,0,114,117,108,101,32,104,97,115,32,97,110,32,101,109,112,116,121,32,99,111,110,116,101,120,116,32,97,116,116,114,105,98,117,116,101,0,0,0,0,0,97,115,115,101,114,116,0,0,116,101,115,116,0,0,0,0,97,115,115,101,114,116,32,104,97,115,32,110,111,32,116,101,115,116,32,97,116,116,114,105,98,117,116,101,0,0,0,0,97,115,115,101,114,116,32,104,97,115,32,97,110,32,101,109,112,116,121,32,116,101,115,116,32,97,116,116,114,105,98,117,116,101,0,0,0,0,0,0,114,101,112,111,114,116,0,0,69,120,112,101,99,116,105,110,103,32,97,110,32,97,115,115,101,114,116,32,111,114,32,97,32,114,101,112,111,114,116,32,101,108,101,109,101,110,116,32,105,110,115,116,101,97,100,32,111,102,32,37,115,0,0,0,114,117,108,101,32,104,97,115,32,110,111,32,97,115,115,101,114,116,32,110,111,114,32,114,101,112,111,114,116,32,101,108,101,109,101,110,116,0,0,0,70,97,105,108,101,100,32,116,111,32,99,111,109,112,105,108,101,32,116,101,115,116,32,101,120,112,114,101,115,115,105,111,110,32,37,115,0,0,0,0,97,108,108,111,99,97,116,105,110,103,32,115,99,104,101,109,97,32,116,101,115,116,0,0,70,97,105,108,101,100,32,116,111,32,99,111,109,112,105,108,101,32,99,111,110,116,101,120,116,32,101,120,112,114,101,115,115,105,111,110,32,37,115,0,97,108,108,111,99,97,116,105,110,103,32,115,99,104,101,109,97,32,114,117,108,101,0,0,97,108,108,111,99,97,116,105,110,103,32,115,99,104,101,109,97,32,112,97,116,116,101,114,110,0,0,0,0,0,0,0,97,108,108,111,99,97,116,105,110,103,32,112,97,114,115,101,114,32,110,97,109,101,115,112,97,99,101,115,0,0,0,0,97,108,108,111,99,97,116,105,110,103,32,115,99,104,101,109,97,0,0,0,0,0,0,0,104,116,116,112,58,47,47,119,119,119,46,97,115,99,99,46,110,101,116,47,120,109,108,47,115,99,104,101,109,97,116,114,111,110,0,0,0,0,0,0,104,116,116,112,58,47,47,112,117,114,108,46,111,99,108,99,46,111,114,103,47,100,115,100,108,47,115,99,104,101,109,97,116,114,111,110,0,0,0,0,67,97,110,110,111,116,32,105,110,105,116,105,97,108,105,122,101,32,109,101,109,111,114,121,32,102,111,114,32,108,105,115,116,0,0,0,0,0,0,0,67,97,110,110,111,116,32,105,110,105,116,105,97,108,105,122,101,32,109,101,109,111,114,121,32,102,111,114,32,115,101,110,116,105,110,101,108,0,0,0,67,97,110,110,111,116,32,105,110,105,116,105,97,108,105,122,101,32,109,101,109,111,114,121,32,102,111,114,32,110,101,119,32,108,105,110,107,0,0,0,117,116,102,56,0,0,200,119,99,104,97,114,116,0,0,198,117,99,115,50,0,117,99,115,50,98,101,0,0,196,117,99,115,50,108,101,0,0,197,117,116,102,49,54,0,117,116,102,49,54,98,101,0,0,194,117,116,102,49,54,108,101,0,0,193,117,99,115,52,0,117,99,115,52,98,101,0,117,116,102,51,50,0,117,116,102,51,50,98,101,0,0,192,117,99,115,52,108,101,0,117,116,102,51,50,108,101,0,0,195,97,115,99,105,105,0,117,115,97,115,99,105,105,0,105,115,111,54,52,54,0,105,115,111,54,52,54,117,115,0,0,199,101,117,99,106,112,0,0,208,115,104,105,102,116,106,105,115,0,115,106,105,115,0,0,209,103,98,49,56,48,51,48,0,0,216,103,98,107,0,0,217,103,98,50,51,49,50,0,0,218,98,105,103,53,0,98,105,103,102,105,118,101,0,99,112,57,53,48,0,98,105,103,53,104,107,115,99,115,0,0,224,101,117,99,107,114,0,107,115,99,53,54,48,49,0,107,115,120,49,48,48,49,0,99,112,57,52,57,0,0,232,105,115,111,56,56,53,57,49,0,108,97,116,105,110,49,0,0,128,105,115,111,56,56,53,57,50,0,0,32,0,84,0,137,18,0,32,1,6,0,0,152,65,134,26,127,0,48,72,32,0,88,32,201,18,0,36,17,198,35,0,156,81,198,26,128,80,66,136,32,90,0,0,192,4,0,16,113,1,0,29,0,112,2,0,41,0,0,192,7,33,48,1,5,0,0,88,1,0,0,94,208,1,128,29,0,0,128,6,0,91,0,0,0,5,0,20,129,1,0,30,0,128,2,0,42,0,0,0,8,34,52,17,5,0,0,92,1,0,0,95,212,1,192,29,0,0,144,70,36,105,115,111,56,56,53,57,51,0,0,32,0,212,0,9,0,0,4,48,3,0,0,244,64,70,11,63,0,16,64,32,0,216,0,0,0,0,0,64,3,0,0,248,80,134,11,64,0,16,128,32,0,0,0,64,0,0,108,144,1,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,188,0,0,0,43,0,0,0,0,0,200,33,6,0,0,0,0,64,0,0,112,160,1,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,192,0,0,0,44,0,0,0,0,0,204,49,70,36,105,115,111,56,56,53,57,52,0,0,32,0,84,48,4,23,0,220,96,4,0,0,152,49,66,12,108,0,48,8,0,0,88,32,73,23,0,224,112,196,35,0,156,65,130,12,109,72,65,200,20,17,0,0,0,0,0,0,0,192,14,29,0,112,2,0,37,0,0,64,14,33,56,65,69,16,0,0,0,0,0,0,224,1,0,0,0,184,1,7,0,18,0,0,0,0,0,0,0,0,15,30,0,128,2,0,38,0,0,128,14,34,60,81,133,16,0,0,0,0,0,0,228,1,0,0,0,188,17,71,36,105,115,111,56,56,53,57,53,0,0,32,0,136,51,14,57,229,152,115,14,58,233,168,179,14,59,237,0,224,206,59,240,196,35,207,60,244,212,99,207,61,248,228,163,207,62,252,244,227,207,63,0,5,36,208,64,4,21,100,208,65,8,37,164,208,66,12,53,228,208,67,16,69,36,209,68,20,85,100,209,69,24,101,164,209,70,28,117,228,209,71,32,133,36,210,72,36,149,100,210,73,40,165,164,210,74,44,181,228,210,75,53,194,20,147,76,51,209,84,147,77,55,225,148,147,78,59,13,192,83,79,105,115,111,56,56,53,57,54,0,0,32,0,4,16,64,0,0,4,16,64,0,1,4,16,64,0,115,1,16,64,0,1,4,16,64,0,1,4,16,64,0,1,4,16,0,93,1,4,16,64,93,1,216,117,23,94,121,233,181,23,95,125,249,245,23,96,129,9,54,24,97,133,25,118,24,98,137,41,182,24,99,141,57,246,88,0,1,4,16,64,0,144,69,38,217,100,148,85,102,217,101,152,101,166,217,102,156,117,230,217,103,160,133,38,90,0,1,4,16,64,0,1,4,16,64,0,1,4,16,64,0,105,115,111,56,56,53,57,55,0,0,32,0,144,88,34,0,51,210,8,0,0,0,0,160,9,0,0,0,16,128,136,0,0,0,0,0,155,112,210,9,0,158,124,2,10,0,161,0,32,202,40,164,148,98,202,41,168,164,162,202,42,172,180,226,202,43,176,196,34,203,44,180,212,18,128,45,183,224,146,139,46,187,240,210,139,47,191,0,19,140,48,195,16,83,140,49,199,32,147,140,50,203,48,211,140,51,207,64,19,141,52,211,80,83,141,53,215,96,147,141,54,219,112,211,141,55,223,128,19,78,0,105,115,111,56,56,53,57,56,0,0,32,0,4,0,0,0,0,0,0,0,0,0,0,192,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,0,0,0,0,0,64,0,1,4,16,64,0,1,4,16,64,0,1,4,16,64,0,1,4,16,64,0,1,4,16,64,0,1,4,16,64,0,1,4,16,64,0,1,4,16,192,136,83,81,85,149,85,87,97,149,149,86,91,113,213,149,87,95,129,21,150,88,99,145,85,150,89,103,161,149,150,90,107,177,213,86,0,1,120,248,97,0,105,115,111,56,56,53,57,57,0,0,80,45,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,244,64,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,46,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,80,6,0,105,115,111,56,56,53,57,49,48,0,0,32,0,84,48,66,12,57,220,16,4,0,70,132,96,6,27,131,0,0,135,20,0,88,64,130,12,58,224,32,4,0,71,136,112,70,27,132,136,24,199,20,17,0,0,0,0,0,0,0,192,14,29,0,112,2,0,37,0,0,0,0,0,56,65,5,0,0,0,0,128,27,0,224,1,0,0,0,0,0,0,0,18,0,0,0,0,0,0,0,0,15,30,0,128,2,0,38,0,0,0,0,0,60,81,5,0,0,0,0,192,27,0,228,1,0,0,0,0,0,192,16,105,115,111,56,56,53,57,49,49,0,116,105,115,54,50,48,0,0,32,0,188,6,91,108,178,205,70,91,109,182,221,134,91,110,186,237,198,91,111,190,253,6,92,112,194,13,71,92,113,198,29,135,92,114,202,45,199,92,115,206,61,7,93,116,210,77,71,93,117,214,93,135,93,118,218,109,199,93,119,222,125,7,94,120,226,141,71,94,121,230,157,135,94,0,1,4,16,64,122,234,173,199,94,123,238,189,7,95,124,242,205,71,95,125,246,221,135,95,126,250,237,199,95,127,254,253,7,96,128,2,14,72,96,129,1,4,16,64,0,105,115,111,56,56,53,57,49,51,0,0,32,0,160,8,0,0,0,164,8,0,0,13,0,192,5,0,0,0,0,192,2,0,0,0,0,0,39,2,0,0,0,16,0,208,5,0,0,0,0,128,3,21,236,16,193,5,0,0,112,194,8,29,0,240,71,9,49,4,145,131,17,102,48,225,4,0,84,0,0,0,0,120,40,1,6,28,0,4,50,8,0,22,240,32,1,6,0,0,128,2,9,30,0,0,136,9,50,8,161,195,17,103,52,241,4,0,85,0,0,0,0,121,44,17,70,28,0,8,66,72,137,105,115,111,56,56,53,57,49,52,0,0,32,0,24,120,32,0,27,112,128,32,0,20,2,96,97,130,26,2,0,128,31,10,46,248,2,12,12,54,8,128,131,21,62,120,33,132,27,98,152,97,132,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,122,0,0,0,0,0,0,0,128,132,0,0,0,0,0,0,0,192,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,123,0,0,0,0,0,0,0,192,132,0,0,0,0,0,0,0,208,7,0,105,115,111,56,56,53,57,49,53,0,108,97,116,105,110,57,0,0,36,51,2,96,6,0,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,131,0,0,0,0,132,0,0,0,0,88,100,225,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,105,115,111,56,56,53,57,49,54,0,0,32,0,84,96,129,18,51,166,104,6,0,103,0,160,8,0,127,0,0,72,32,0,0,208,193,18,131,160,8,0,0,132,120,176,8,0,88,100,225,135,32,0,0,0,192,4,0,92,0,0,0,0,0,0,0,0,0,0,0,0,0,33,48,1,0,0,0,88,1,0,24,118,0,0,0,0,0,156,192,8,0,0,0,0,0,5,0,96,0,0,0,0,0,0,0,0,0,0,0,0,0,34,52,1,0,0,0,92,1,64,24,119,0,0,0,0,0,160,208,8,0,99,112,49,50,53,48,0,119,105,110,100,111,119,115,49,50,53,48,0,0,0,51,6,96,98,0,41,182,168,226,138,1,184,104,198,139,96,168,49,200,31,1,144,88,226,137,40,178,8,98,136,1,216,120,6,140,97,172,65,8,32,0,60,2,137,18,0,84,0,0,0,0,0,64,6,0,0,0,0,64,32,0,0,32,201,18,0,0,0,0,0,0,88,80,6,0,72,80,146,132,32,90,0,0,192,4,0,16,113,1,0,29,0,112,2,0,41,0,0,192,7,33,48,1,5,0,0,88,1,0,0,94,208,1,128,29,0,0,128,6,0,91,0,0,0,5,0,20,129,1,0,30,0,128,2,0,42,0,0,0,8,34,52,17,5,0,0,92,1,0,0,95,212,1,192,29,0,0,144,70,36,99,112,49,50,53,49,0,119,105,110,100,111,119,115,49,50,53,49,0,0,0,227,144,99,162,76,41,182,168,226,138,51,186,168,206,139,235,180,195,206,59,49,145,88,226,137,40,178,8,98,136,1,216,136,19,140,57,237,164,83,79,0,184,195,83,58,0,248,4,0,0,226,0,80,14,0,0,0,0,0,58,0,0,112,78,77,63,1,0,0,0,48,213,56,19,0,55,153,67,147,77,240,196,35,207,60,244,212,99,207,61,248,228,163,207,62,252,244,227,207,63,0,5,36,208,64,4,21,100,208,65,8,37,164,208,66,12,53,228,208,67,16,69,36,209,68,20,85,100,209,69,24,101,164,209,70,28,117,228,209,71,32,133,36,210,72,36,149,100,210,73,40,165,164,210,74,44,181,228,210,75,99,112,49,50,53,50,0,119,105,110,100,111,119,115,49,50,53,50,0,0,0,51,6,96,98,33,41,182,168,226,138,142,184,104,198,139,88,4,48,72,0,1,144,88,226,137,40,178,8,98,136,147,216,120,6,140,89,4,64,136,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,99,112,49,50,53,51,0,119,105,110,100,111,119,115,49,50,53,51,0,0,0,51,6,96,98,33,41,182,168,226,138,1,184,24,192,139,1,4,16,64,0,1,144,88,226,137,40,178,8,98,136,1,216,24,0,140,1,4,16,64,0,0,112,210,9,0,0,0,0,0,0,0,0,16,0,0,0,0,0,128,136,0,0,0,0,0,155,0,0,0,0,158,124,2,10,0,161,0,32,202,40,164,148,98,202,41,168,164,162,202,42,172,180,226,202,43,176,196,34,203,44,180,212,18,128,45,183,224,146,139,46,187,240,210,139,47,191,0,19,140,48,195,16,83,140,49,199,32,147,140,50,203,48,211,140,51,207,64,19,141,52,211,80,83,141,53,215,96,147,141,54,219,112,211,141,55,223,128,19,78,0,99,112,49,50,53,52,0,119,105,110,100,111,119,115,49,50,53,52,0,0,0,51,6,96,98,33,41,182,168,226,138,142,184,104,198,139,88,4,16,64,0,1,144,88,226,137,40,178,8,98,136,147,216,120,6,140,89,4,16,128,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,45,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,244,64,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,46,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,80,6,0,99,112,49,50,53,53,0,119,105,110,100,111,119,115,49,50,53,53,0,0,0,51,6,96,98,33,41,182,168,226,138,142,184,24,192,139,1,4,16,64,0,1,144,88,226,137,40,178,8,98,136,147,216,24,0,140,1,4,16,64,0,0,0,0,0,0,49,2,0,0,0,0,0,192,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,0,0,0,0,0,0,0,64,5,37,212,80,68,21,101,212,81,72,37,21,128,82,75,49,213,148,83,79,65,21,149,84,110,189,5,87,92,114,5,16,64,0,1,4,16,64,0,83,81,85,149,85,87,97,149,149,86,91,113,213,149,87,95,129,21,150,88,99,145,85,150,89,103,161,149,150,90,107,177,213,86,0,1,120,248,97,0,99,112,49,50,53,54,0,119,105,110,100,111,119,115,49,50,53,54,0,0,0,51,146,102,98,33,41,182,168,226,138,142,184,56,218,139,88,148,134,154,105,170,145,88,226,137,40,178,8,98,136,169,217,120,26,140,89,112,216,225,106,0,204,5,0,0,0,0,0,0,0,0,0,192,26,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,23,0,0,0,0,64,93,173,217,117,23,94,121,233,181,23,95,125,249,245,23,96,129,9,54,24,97,133,25,118,24,98,137,41,182,24,0,140,53,230,216,99,144,69,38,217,100,0,80,6,64,101,150,93,134,25,0,0,0,0,0,0,153,105,6,0,0,155,113,214,153,103,0,124,6,26,0,161,1,32,26,0,0,120,248,161,107,99,112,49,50,53,55,0,119,105,110,100,111,119,115,49,50,53,55,0,0,0,51,6,96,98,0,41,182,168,226,138,1,184,24,192,139,1,16,240,136,2,1,144,88,226,137,40,178,8,98,136,1,216,24,0,140,1,24,32,73,0,0,4,0,0,0,0,4,0,0,0,13,0,192,5,0,0,0,0,192,2,0,0,0,0,0,0,0,0,0,0,16,0,208,5,0,0,0,0,128,3,21,236,16,193,5,0,0,112,194,8,29,0,240,71,9,49,4,145,131,17,102,48,225,4,0,84,0,0,0,0,120,40,1,6,28,0,4,50,8,0,22,240,32,1,6,0,0,128,2,9,30,0,0,136,9,50,8,161,195,17,103,52,241,4,0,85,0,0,0,0,121,44,17,70,28,0,8,66,72,36,99,112,49,50,53,56,0,119,105,110,100,111,119,115,49,50,53,56,0,0,0,51,6,96,98,33,41,182,168,226,138,142,184,24,192,139,88,4,16,64,0,1,144,88,226,137,40,178,8,98,136,147,216,24,0,140,89,4,16,128,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,4,0,0,0,0,0,0,0,0,0,0,149,0,0,0,0,33,0,128,9,0,0,24,2,0,0,0,0,0,0,0,0,32,114,9,0,0,0,0,0,5,0,0,0,0,0,0,0,0,0,0,150,0,0,0,0,34,0,144,9,0,0,28,2,0,0,0,0,0,0,0,0,36,34,35,0,107,111,105,56,114,0,0,0,62,254,8,100,144,66,14,73,100,145,70,30,137,164,153,103,162,153,166,154,107,178,217,38,143,110,222,136,99,142,58,238,40,64,143,7,32,144,192,3,73,42,185,36,76,76,54,233,228,147,80,70,41,229,148,84,86,105,229,149,88,102,169,165,56,91,114,217,165,151,95,130,25,166,152,99,146,89,102,1,46,65,20,145,73,20,85,68,210,68,37,97,148,145,70,27,113,212,145,71,31,189,4,82,72,34,141,100,145,68,44,173,116,17,74,45,165,116,146,74,14,193,19,143,65,244,212,67,208,60,5,225,147,143,62,251,240,211,143,63,255,60,4,80,64,2,13,100,143,60,12,45,116,15,66,13,37,116,144,66,107,111,105,56,117,0,0,0,62,254,8,100,144,66,14,73,100,145,70,30,137,164,153,103,162,153,166,154,107,178,217,38,143,110,222,136,99,142,58,238,40,64,143,7,32,144,192,3,73,42,185,36,76,51,53,89,147,77,80,70,41,229,148,84,254,100,229,149,88,102,169,165,56,229,112,121,14,58,95,130,25,166,152,99,250,84,102,1,46,65,20,145,73,20,85,68,210,68,37,97,148,145,70,27,113,212,145,71,31,189,4,82,72,34,141,100,145,68,44,173,116,17,74,45,165,116,146,74,14,193,19,143,65,244,212,67,208,60,5,225,147,143,62,251,240,211,143,63,255,60,4,80,64,2,13,100,143,60,12,45,116,15,66,13,37,116,144,66,0,0,0,0,0,0,0,0,0,48,1,48,2,48,12,255,14,255,251,48,26,255,27,255,31,255,1,255,155,48,156,48,180,0,64,255,168,0,62,255,227,255,63,255,253,48,254,48,157,48,158,48,3,48,221,78,5,48,6,48,7,48,252,48,21,32,16,32,15,255,92,0,28,48,22,32,92,255,38,32,37,32,24,32,25,32,28,32,29,32,8,255,9,255,20,48,21,48,59,255,61,255,91,255,93,255,8,48,9,48,10,48,11,48,12,48,13,48,14,48,15,48,16,48,17,48,11,255,18,34,177,0,215,0,247,0,29,255,96,34,28,255,30,255,102,34,103,34,30,34,52,34,66,38,64,38,176,0,50,32,51,32,3,33,229,255,4,255,162,0,163,0,5,255,3,255,6,255,10,255,32,255,167,0,6,38,5,38,203,37,207,37,206,37,199,37,198,37,161,37,160,37,179,37,178,37,189,37,188,37,59,32,18,48,146,33,144,33,145,33,147,33,19,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,34,11,34,134,34,135,34,130,34,131,34,42,34,41,34,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,39,34,40,34,172,0,210,33,212,33,0,34,3,34,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,34,165,34,18,35,2,34,7,34,97,34,82,34,106,34,107,34,26,34,61,34,29,34,53,34,43,34,44,34,0,0,0,0,0,0,0,0,0,0,0,0,0,0,43,33,48,32,111,38,109,38,106,38,32,32,33,32,182,0,0,0,0,0,0,0,0,0,239,37,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,255,17,255,18,255,19,255,20,255,21,255,22,255,23,255,24,255,25,255],"i8",ALLOC_NONE,Runtime.GLOBAL_BASE+197488),allocate([33,255,34,255,35,255,36,255,37,255,38,255,39,255,40,255,41,255,42,255,43,255,44,255,45,255,46,255,47,255,48,255,49,255,50,255,51,255,52,255,53,255,54,255,55,255,56,255,57,255,58,255,0,0,0,0,0,0,0,0,0,0,0,0,65,255,66,255,67,255,68,255,69,255,70,255,71,255,72,255,73,255,74,255,75,255,76,255,77,255,78,255,79,255,80,255,81,255,82,255,83,255,84,255,85,255,86,255,87,255,88,255,89,255,90,255,0,0,0,0,0,0,0,0,65,48,66,48,67,48,68,48,69,48,70,48,71,48,72,48,73,48,74,48,75,48,76,48,77,48,78,48,79,48,80,48,81,48,82,48,83,48,84,48,85,48,86,48,87,48,88,48,89,48,90,48,91,48,92,48,93,48,94,48,95,48,96,48,97,48,98,48,99,48,100,48,101,48,102,48,103,48,104,48,105,48,106,48,107,48,108,48,109,48,110,48,111,48,112,48,113,48,114,48,115,48,116,48,117,48,118,48,119,48,120,48,121,48,122,48,123,48,124,48,125,48,126,48,127,48,128,48,129,48,130,48,131,48,132,48,133,48,134,48,135,48,136,48,137,48,138,48,139,48,140,48,141,48,142,48,143,48,144,48,145,48,146,48,147,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,161,48,162,48,163,48,164,48,165,48,166,48,167,48,168,48,169,48,170,48,171,48,172,48,173,48,174,48,175,48,176,48,177,48,178,48,179,48,180,48,181,48,182,48,183,48,184,48,185,48,186,48,187,48,188,48,189,48,190,48,191,48,192,48,193,48,194,48,195,48,196,48,197,48,198,48,199,48,200,48,201,48,202,48,203,48,204,48,205,48,206,48,207,48,208,48,209,48,210,48,211,48,212,48,213,48,214,48,215,48,216,48,217,48,218,48,219,48,220,48,221,48,222,48,223,48,224,48,225,48,226,48,227,48,228,48,229,48,230,48,231,48,232,48,233,48,234,48,235,48,236,48,237,48,238,48,239,48,240,48,241,48,242,48,243,48,244,48,245,48,246,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,3,146,3,147,3,148,3,149,3,150,3,151,3,152,3,153,3,154,3,155,3,156,3,157,3,158,3,159,3,160,3,161,3,163,3,164,3,165,3,166,3,167,3,168,3,169,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,177,3,178,3,179,3,180,3,181,3,182,3,183,3,184,3,185,3,186,3,187,3,188,3,189,3,190,3,191,3,192,3,193,3,195,3,196,3,197,3,198,3,199,3,200,3,201,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,4,17,4,18,4,19,4,20,4,21,4,1,4,22,4,23,4,24,4,25,4,26,4,27,4,28,4,29,4,30,4,31,4,32,4,33,4,34,4,35,4,36,4,37,4,38,4,39,4,40,4,41,4,42,4,43,4,44,4,45,4,46,4,47,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,4,49,4,50,4,51,4,52,4,53,4,81,4,54,4,55,4,56,4,57,4,58,4,59,4,60,4,61,4,62,4,63,4,64,4,65,4,66,4,67,4,68,4,69,4,70,4,71,4,72,4,73,4,74,4,75,4,76,4,77,4,78,4,79,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,37,2,37,12,37,16,37,24,37,20,37,28,37,44,37,36,37,52,37,60,37,1,37,3,37,15,37,19,37,27,37,23,37,35,37,51,37,43,37,59,37,75,37,32,37,47,37,40,37,55,37,63,37,29,37,48,37,37,37,56,37,66,37],"i8",ALLOC_NONE,Runtime.GLOBAL_BASE+207728),
	allocate([156,78,22,85,3,90,63,150,192,84,27,97,40,99,246,89,34,144,117,132,28,131,80,122,170,96,225,99,37,110,237,101,102,132,166,130,245,155,147,104,39,87,161,101,113,98,155,91,208,89,123,134,244,152,98,125,190,125,142,155,22,98,159,124,183,136,137,91,181,94,9,99,151,102,72,104,199,149,141,151,79,103,229,78,10,79,77,79,157,79,73,80,242,86,55,89,212,89,1,90,9,92,223,96,15,97,112,97,19,102,5,105,186,112,79,117,112,117,251,121,173,125,239,125,195,128,14,132,99,136,2,139,85,144,122,144,59,83,149,78,165,78,223,87,178,128,193,144,239,120,0,78,241,88,162,110,56,144,50,122,40,131,139,130,47,156,65,81,112,83,189,84,225,84,224,86,251,89,21,95,242,152,235,109,228,128,45,133,98,150,112,150,160,150,251,151,11,84,243,83,135,91,207,112,189,127,194,143,232,150,111,83,92,157,186,122,17,78,147,120,252,129,38,110,24,86,4,85,29,107,26,133,59,156,229,89,169,83,102,109,220,116,143,149,66,86,145,78,75,144,242,150,79,131,12,153,225,83,182,85,48,91,113,95,32,102,243,102,4,104,56,108,243,108,41,109,91,116,200,118,78,122,52,152,241,130,91,136,96,138,237,146,178,109,171,117,202,118,197,153,166,96,1,139,138,141,178,149,142,105,173,83,134,81,18,87,48,88,68,89,180,91,246,94,40,96,169,99,244,99,191,108,20,111,142,112,20,113,89,113,213,113,63,115,1,126,118,130,209,130,151,133,96,144,91,146,27,157,105,88,188,101,90,108,37,117,249,81,46,89,101,89,128,95,220,95,188,98,250,101,42,106,39,107,180,107,139,115,193,127,86,137,44,157,14,157,196,158,161,92,150,108,123,131,4,81,75,92,182,97,198,129,118,104,97,114,89,78,250,79,120,83,105,96,41,110,79,122,243,151,11,78,22,83,238,78,85,79,61,79,161,79,115,79,160,82,239,83,9,86,15,89,193,90,182,91,225,91,209,121,135,102,156,103,182,103,76,107,179,108,107,112,194,115,141,121,190,121,60,122,135,123,177,130,219,130,4,131,119,131,239,131,211,131,102,135,178,138,41,86,168,140,230,143,78,144,30,151,138,134,196,79,232,92,17,98,89,114,59,117,229,129,189,130,254,134,192,140,197,150,19,153,213,153,203,78,26,79,227,137,222,86,74,88,202,88,251,94,235,95,42,96,148,96,98,96,208,97,18,98,208,98,57,101,65,155,102,102,176,104,119,109,112,112,76,117,134,118,117,125,165,130,249,135,139,149,142,150,157,140,241,81,190,82,22,89,179,84,179,91,22,93,104,97,130,105,175,109,141,120,203,132,87,136,114,138,167,147,184,154,108,109,168,153,217,134,163,87,255,103,206,134,14,146,131,82,135,86,4,84,211,94,225,98,185,100,60,104,56,104,187,107,114,115,186,120,107,122,154,137,210,137,107,141,3,143,237,144,163,149,148,150,105,151,102,91,179,92,125,105,77,152,78,152,155,99,32,123,43,106,127,106,182,104,13,156,95,111,114,82,157,85,112,96,236,98,59,109,7,110,209,110,91,132,16,137,68,143,20,78,57,156,246,83,27,105,58,106,132,151,42,104,92,81,195,122,178,132,220,145,140,147,91,86,40,157,34,104,5,131,49,132,165,124,8,82,197,130,230,116,126,78,131,79,160,81,210,91,10,82,216,82,231,82,251,93,154,85,42,88,230,89,140,91,152,91,219,91,114,94,121,94,163,96,31,97,99,97,190,97,219,99,98,101,209,103,83,104,250,104,62,107,83,107,87,108,34,111,151,111,69,111,176,116,24,117,227,118,11,119,255,122,161,123,33,124,233,125,54,127,240,127,157,128,102,130,158,131,179,137,204,138,171,140,132,144,81,148,147,149,145,149,162,149,101,150,211,151,40,153,24,130,56,78,43,84,184,92,204,93,169,115,76,118,60,119,169,92,235,127,11,141,193,150,17,152,84,152,88,152,1,79,14,79,113,83,156,85,104,86,250,87,71,89,9,91,196,91,144,92,12,94,126,94,204,95,238,99,58,103,215,101,226,101,31,103,203,104,196,104,95,106,48,94,197,107,23,108,125,108,127,117,72,121,99,91,0,122,0,125,189,95,143,137,24,138,180,140,119,141,204,142,29,143,226,152,14,154,60,155,128,78,125,80,0,81,147,89,156,91,47,98,128,98,236,100,58,107,160,114,145,117,71,121,169,127,251,135,188,138,112,139,172,99,202,131,160,151,9,84,3,84,171,85,84,104,88,106,112,138,39,120,117,103,205,158,116,83,162,91,26,129,80,134,6,144,24,78,69,78,199,78,17,79,202,83,56,84,174,91,19,95,37,96,81,101,61,103,66,108,114,108,227,108,120,112,3,116,118,122,174,122,8,123,26,125,254,124,102,125,231,101,91,114,187,83,69,92,232,93,210,98,224,98,25,99,32,110,90,134,49,138,221,141,248,146,1,111,166,121,90,155,168,78,171,78,172,78,155,79,160,79,209,80,71,81,246,122,113,81,246,81,84,83,33,83,127,83,235,83,172,85,131,88,225,92,55,95,74,95,47,96,80,96,109,96,31,99,89,101,75,106,193,108,194,114,237,114,239,119,248,128,5,129,8,130,78,133,247,144,225,147,255,151,87,153,90,154,240,78,221,81,45,92,129,102,109,105,64,92,242,102,117,105,137,115,80,104,129,124,197,80,228,82,71,87,254,93,38,147,164,101,35,107,61,107,52,116,129,121,189,121,75,123,202,125,185,130,204,131,127,136,95,137,57,139,209,143,209,145,31,84,128,146,93,78,54,80,229,83,58,83,215,114,150,115,233,119,230,130,175,142,198,153,200,153,210,153,119,81,26,97,94,134,176,85,122,122,118,80,211,91,71,144,133,150,50,78,219,106,231,145,81,92,72,92,152,99,159,122,147,108,116,151,97,143,170,122,138,113,136,150,130,124,23,104,112,126,81,104,108,147,242,82,27,84,171,133,19,138,164,127,205,142,225,144,102,83,136,136,65,121,194,79,190,80,17,82,68,81,83,85,45,87,234,115,139,87,81,89,98,95,132,95,117,96,118,97,103,97,169,97,178,99,58,100,108,101,111,102,66,104,19,110,102,117,61,122,251,124,76,125,153,125,75,126,107,127,14,131,74,131,205,134,8,138,99,138,102,139,253,142,26,152,143,157,184,130,206,143,232,155,135,82,31,98,131,100,192,111,153,150,65,104,145,80,32,107,122,108,84,111,116,122,80,125,64,136,35,138,8,103,246,78,57,80,38,80,101,80,124,81,56,82,99,82,167,85,15,87,5,88,204,90,250,94,178,97,248,97,243,98,114,99,28,105,41,106,125,114,172,114,46,115,20,120,111,120,121,125,12,119,169,128,139,137,25,139,226,140,210,142,99,144,117,147,122,150,85,152,19,154,120,158,67,81,159,83,179,83,123,94,38,95,27,110,144,110,132,115,254,115,67,125,55,130,0,138,250,138,80,150,78,78,11,80,228,83,124,84,250,86,209,89,100,91,241,93,171,94,39,95,56,98,69,101,175,103,86,110,208,114,202,124,180,136,161,128,225,128,240,131,78,134,135,138,232,141,55,146,199,150,103,152,19,159,148,78,146,78,13,79,72,83,73,84,62,84,47,90,140,95,161,95,159,96,167,104,142,106,90,116,129,120,158,138,164,138,119,139,144,145,94,78,201,155,164,78,124,79,175,79,25,80,22,80,73,81,108,81,159,82,185,82,254,82,154,83,227,83,17,84,14,84,137,85,81,87,162,87,125,89,84,91,93,91,143,91,229,93,231,93,247,93,120,94,131,94,154,94,183,94,24,95,82,96,76,97,151,98,216,98,167,99,59,101,2,102,67,102,244,102,109,103,33,104,151,104,203,105,95,108,42,109,105,109,47,110,157,110,50,117,135,118,108,120,63,122,224,124,5,125,24,125,94,125,177,125,21,128,3,128,175,128,177,128,84,129,143,129,42,130,82,131,76,136,97,136,27,139,162,140,252,140,202,144,117,145,113,146,63,120,252,146,164,149,77,150,5,152,153,153,216,154,59,157,91,82,171,82,247,83,8,84,213,88,247,98,224,111,106,140,95,143,185,158,75,81,59,82,74,84,253,86,64,122,119,145,96,157,210,158,68,115,9,111,112,129,17,117,253,95,218,96,168,154,219,114,188,143,100,107,3,152,202,78,240,86,100,87,190,88,90,90,104,96,199,97,15,102,6,102,57,104,177,104,247,109,213,117,58,125,110,130,66,155,155,78,80,79,201,83,6,85,111,93,230,93,238,93,251,103,153,108,115,116,2,120,80,138,150,147,223,136,80,87,167,94,43,99,181,80,172,80,141,81,0,103,201,84,94,88,187,89,176,91,105,95,77,98,161,99,61,104,115,107,8,110,125,112,199,145,128,114,21,120,38,120,109,121,142,101,48,125,220,131,193,136,9,143,155,150,100,82,40,87,80,103,106,127,161,140,180,81,66,87,42,150,58,88,138,105,180,128,178,84,14,93,252,87,149,120,250,157,92,79,74,82,139,84,62,100,40,102,20,103,245,103,132,122,86,123,34,125,47,147,92,104,173,155,57,123,25,83,138,81,55,82,223,91,246,98,174,100,230,100,45,103,186,107,169,133,209,150,144,118,214,155,76,99,6,147,171,155,191,118,82,102,9,78,152,80,194,83,113,92,232,96,146,100,99,101,95,104,230,113,202,115,35,117,151,123,130,126,149,134,131,139,219,140,120,145,16,153,172,101,171,102,139,107,213,78,212,78,58,79,127,79,58,82,248,83,242,83,227,85,219,86,235,88,203,89,201,89,255,89,80,91,77,92,2,94,43,94,215,95,29,96,7,99,47,101,92,91,175,101,189,101,232,101,157,103,98,107,123,107,15,108,69,115,73,121,193,121,248,124,25,125,43,125,162,128,2,129,243,129,150,137,94,138,105,138,102,138,140,138,238,138,199,140,220,140,204,150,252,152,111,107,139,78,60,79,141,79,80,81,87,91,250,91,72,97,1,99,66,102,33,107,203,110,187,108,62,114,189,116,212,117,193,120,58,121,12,128,51,128,234,129,148,132,158,143,80,108,127,158,15,95,88,139,43,157,250,122,248,142,141,91,235,150,3,78,241,83,247,87,49,89,201,90,164,91,137,96,127,110,6,111,190,117,234,140,159,91,0,133,224,123,114,80,244,103,157,130,97,92,74,133,30,126,14,130,153,81,4,92,104,99,102,141,156,101,110,113,62,121,23,125,5,128,29,139,202,142,110,144,199,134,170,144,31,80,250,82,58,92,83,103,124,112,53,114,76,145,200,145,43,147,229,130,194,91,49,95,249,96,59,78,214,83,136,91,75,98,49,103,138,107,233,114,224,115,46,122,107,129,163,141,82,145,150,153,18,81,215,83,106,84,255,91,136,99,57,106,172,125,0,151,218,86,206,83,104,84,151,91,49,92,222,93,238,79,1,97,254,98,50,109,192,121,203,121,66,125,77,126,210,127,237,129,31,130,144,132,70,136,114,137,144,139,116,142,47,143,49,144,75,145,108,145,198,150,156,145,192,78,79,79,69,81,65,83,147,95,14,98,212,103,65,108,11,110,99,115,38,126,205,145,131,146,212,83,25,89,191,91,209,109,93,121,46,126,155,124,126,88,159,113,250,81,83,136,240,143,202,79,251,92,37,102,172,119,227,122,28,130,255,153,198,81,170,95,236,101,111,105,137,107,243,109,150,110,100,111,254,118,20,125,225,93,117,144,135,145,6,152,230,81,29,82,64,98,145,102,217,102,26,110,182,94,210,125,114,127,248,102,175,133,247,133,248,138,169,82,217,83,115,89,143,94,144,95,85,96,228,146,100,150,183,80,31,81,221,82,32,83,71,83,236,83,232,84,70,85,49,85,23,86,104,89,190,89,60,90,181,91,6,92,15,92,17,92,26,92,132,94,138,94,224,94,112,95,127,98,132,98,219,98,140,99,119,99,7,102,12,102,45,102,118,102,126,103,162,104,31,106,53,106,188,108,136,109,9,110,88,110,60,113,38,113,103,113,199,117,1,119,93,120,1,121,101,121,240,121,224,122,17,123,167,124,57,125,150,128,214,131,139,132,73,133,93,136,243,136,31,138,60,138,84,138,115,138,97,140,222,140,164,145,102,146,126,147,24,148,156,150,152,151,10,78,8,78,30,78,87,78,151,81,112,82,206,87,52,88,204,88,34,91,56,94,197,96,254,100,97,103,86,103,68,109,182,114,115,117,99,122,184,132,114,139,184,145,32,147,49,86,244,87,254,152,237,98,13,105,150,107,237,113,84,126,119,128,114,130,230,137,223,152,85,135,177,143,59,92,56,79,225,79,181,79,7,85,32,90,221,91,233,91,195,95,78,97,47,99,176,101,75,102,238,104,155,105,120,109,241,109,51,117,185,117,31,119,94,121,230,121,51,125,227,129,175,130,170,133,170,137,58,138,171,142,155,143,50,144,221,145,7,151,186,78,193,78,3,82,117,88,236,88,11,92,26,117,61,92,78,129,10,138,197,143,99,150,109,151,37,123,207,138,8,152,98,145,243,86,168,83,23,144,57,84,130,87,37,94,168,99,52,108,138,112,97,119,139,124,224,127,112,136,66,144,84,145,16,147,24,147,143,150,94,116,196,154,7,93,105,93,112,101,162,103,168,141,219,150,110,99,73,103,25,105,197,131,23,152,192,150,254,136,132,111,122,100,248,91,22,78,44,112,93,117,47,102,196,81,54,82,226,82,211,89,129,95,39,96,16,98,63,101,116,101,31,102,116,102,242,104,22,104,99,107,5,110,114,114,31,117,219,118,190,124,86,128,240,88,253,136,127,137,160,138,147,138,203,138,29,144,146,145,82,151,89,151,137,101,14,122,6,129,187,150,45,94,220,96,26,98,165,101,20,102,144,103,243,119,77,122,77,124,62,126,10,129,172,140,100,141,225,141,95,142,169,120,7,82,217,98,165,99,66,100,152,98,45,138,131,122,192,123,172,138,234,150,118,125,12,130,73,135,217,78,72,81,67,83,96,83,163,91,2,92,22,92,221,93,38,98,71,98,176,100,19,104,52,104,201,108,69,109,23,109,211,103,92,111,78,113,125,113,203,101,127,122,173,123,218,125,74,126,168,127,122,129,27,130,57,130,166,133,110,138,206,140,245,141,120,144,119,144,173,146,145,146,131,149,174,155,77,82,132,85,56,111,54,113,104,81,133,121,85,126,179,129,206,124,76,86,81,88,168,92,170,99,254,102,253,102,90,105,217,114,143,117,142,117,14,121,86,121,223,121,151,124,32,125,68,125,7,134,52,138,59,150,97,144,32,159,231,80,117,82,204,83,226,83,9,80,170,85,238,88,79,89,61,114,139,91,100,92,29,83,227,96,243,96,92,99,131,99,63,99,187,99,205,100,233,101,249,102,227,93,205,105,253,105,21,111,229,113,137,78,233,117,248,118,147,122,223,124,207,125,156,125,97,128,73,131,88,131,108,132,188,132,251,133,197,136,112,141,1,144,109,144,151,147,28,151,18,154,207,80,151,88,142,97,211,129,53,133,8,141,32,144,195,79,116,80,71,82,115,83,111,96,73,99,95,103,44,110,179,141,31,144,215,79,94,92,202,140,207,101,154,125,82,83,150,136,118,81,195,99,88,91,107,91,10,92,13,100,81,103,92,144,214,78,26,89,42,89,112,108,81,138,62,85,21,88,165,89,240,96,83,98,193,103,53,130,85,105,64,150,196,153,40,154,83,79,6,88,254,91,16,128,177,92,47,94,133,95,32,96,75,97,52,98,255,102,240,108,222,110,206,128,127,129,212,130,139,136,184,140,0,144,46,144,138,150,219,158,219,155,227,78,240,83,39,89,44,123,141,145,76,152,249,157,221,110,39,112,83,83,68,85,133,91,88,98,158,98,211,98,162,108,239,111,34,116,23,138,56,148,193,111,254,138,56,131,231,81,248,134,234,83,233,83,70,79,84,144,176,143,106,89,49,129,253,93,234,122,191,143,218,104,55,140,248,114,72,156,61,106,176,138,57,78,88,83,6,86,102,87,197,98,162,99,230,101,78,107,225,109,91,110,173,112,237,119,239,122,170,123,187,125,61,128,198,128,203,134,149,138,91,147,227,86,199,88,62,95,173,101,150,102,128,106,181,107,55,117,199,138,36,80,229,119,48,87,27,95,101,96,122,102,96,108,244,117,26,122,110,127,244,129,24,135,69,144,179,153,201,123,92,117,249,122,81,123,196,132,16,144,233,121,146,122,54,131,225,90,64,119,45,78,242,78,153,91,224,95,189,98,60,102,241,103,232,108,107,134,119,136,59,138,78,145,243,146,208,153,23,106,38,112,42,115,231,130,87,132,175,140,1,78,70,81,203,81,139,85,245,91,22,94,51,94,129,94,20,95,53,95,107,95,180,95,242,97,17,99,162,102,29,103,110,111,82,114,58,117,58,119,116,128,57,129,120,129,118,135,191,138,220,138,133,141,243,141,154,146,119,149,2,152,229,156,197,82,87,99,244,118,21,103,136,108,205,115,195,140,174,147,115,150,37,109,156,88,14,105,204,105,253,143,154,147,219,117,26,144,90,88,2,104,180,99,251,105,67,79,44,111,216,103,187,143,38,133,180,125,84,147,63,105,112,111,106,87,247,88,44,91,44,125,42,114,10,84,227,145,180,157,173,78,78,79,92,80,117,80,67,82,158,140,72,84,36,88,154,91,29,94,149,94,173,94,247,94,31,95,140,96,181,98,58,99,208,99,175,104,64,108,135,120,142,121,11,122,224,125,71,130,2,138,230,138,68,142,19,144,184,144,45,145,216,145,14,159,229,108,88,100,226,100,117,101,244,110,132,118,27,123,105,144,209,147,186,110,242,84,185,95,164,100,77,143,237,143,68,146,120,81,107,88,41,89,85,92,151,94,251,109,143,126,28,117,188,140,226,142,91,152,185,112,29,79,191,107,177,111,48,117,251,150,78,81,16,84,53,88,87,88,172,89,96,92,146,95,151,101,92,103,33,110,123,118,223,131,237,140,20,144,253,144,77,147,37,120,58,120,170,82,166,94,31,87,116,89,18,96,18,80,90,81,172,81,205,81,0,82,16,85,84,88,88,88,87,89,149,91,246,92,139,93,188,96,149,98,45,100,113,103,67,104,188,104,223,104,215,118,216,109,111,110,155,109,111,112,200,113,83,95,216,117,119,121,73,123,84,123,82,123,214,124,113,125,48,82,99,132,105,133,228,133,14,138,4,139,70,140,15,142,3,144,15,144,25,148,118,150,45,152,48,154,216,149,205,80,213,82,12,84,2,88,14,92,167,97,158,100,30,109,179,119,229,122,244,128,4,132,83,144,133,146,224,92,7,157,63,83,151,95,179,95,156,109,121,114,99,119,191,121,228,123,210,107,236,114,173,138,3,104,97,106,248,81,129,122,52,105,74,92,246,156,235,130,197,91,73,145,30,112,120,86,111,92,199,96,102,101,140,108,90,140,65,144,19,152,81,84,199,102,13,146,72,89,163,144,133,81,77,78,234,81,153,133,14,139,88,112,122,99,75,147,98,105,180,153,4,126,119,117,87,83,96,105,223,142,227,150,93,108,140,78,60,92,16,95,233,143,2,83,209,140,137,128,121,134,255,94,229,101,115,78,101,81,130,89,63,92,238,151,251,78,138,89,205,95,141,138,225,111,176,121,98,121,231,91,113,132,43,115,177,113,116,94,245,95,123,99,154,100,195,113,152,124,67,78,252,94,75,78,220,87,162,86,169,96,195,111,13,125,253,128,51,129,191,129,178,143,151,137,164,134,244,93,138,98,173,100,135,137,119,103,226,108,62,109,54,116,52,120,70,90,117,127,173,130,172,153,243,79,195,94,221,98,146,99,87,101,111,103,195,118,76,114,204,128,186,128,41,143,77,145,13,80,249,87,146,90,133,104,115,105,100,113,253,114,183,140,242,88,224,140,106,150,25,144,127,135,228,121,231,119,41,132,47,79,101,82,90,83,205,98,207,103,202,108,125,118,148,123,149,124,54,130,132,133,235,143,221,102,32,111,6,114,27,126,171,131,193,153,166,158,253,81,177,123,114,120,184,123,135,128,72,123,232,106,97,94,140,128,81,117,96,117,107,81,98,146,140,110,122,118,151,145,234,154,16,79,112,127,156,98,79,123,165,149,233,156,122,86,89,88,228,134,188,150,52,79,36,82,74,83,205,83,219,83,6,94,44,100,145,101,127,103,62,108,78,108,72,114,175,114,237,115,84,117,65,126,44,130,233,133,169,140,196,123,198,145,105,113,18,152,239,152,61,99,105,102,106,117,228,118,208,120,67,133,238,134,42,83,81,83,38,84,131,89,135,94,124,95,178,96,73,98,121,98,171,98,144,101,212,107,204,108,178,117,174,118,145,120,216,121,203,125,119,127,165,128,171,136,185,138,187,140,127,144,94,151,219,152,11,106,56,124,153,80,62,92,174,95,135,103,216,107,53,116,9,119,142,127,59,159,202,103,23,122,57,83,139,117,237,154,102,95,157,129,241,131,152,128,60,95,197,95,98,117,70,123,60,144,103,104,235,89,155,90,16,125,126,118,44,139,245,79,106,95,25,106,55,108,2,111,226,116,104,121,104,136,85,138,121,140,223,94,207,99,197,117,210,121,215,130,40,147,242,146,156,132,237,134,45,156,193,84,108,95,140,101,92,109,21,112,167,140,211,140,59,152,79,101,246,116,13,78,216,78,224,87,43,89,102,90,204,91,168,81,3,94,156,94,22,96,118,98,119,101,167,101,110,102,110,109,54,114,38,123,80,129,154,129,153,130,92,139,160,140,230,140,116,141,28,150,68,150,174,79,171,100,102,107,30,130,97,132,106,133,232,144,1,92,83,105,168,152,122,132,87,133,15,79,111,82,169,95,69,94,13,103,143,121,121,129,7,137,134,137,245,109,23,95,85,98,184,108,207,78,105,114,146,155,6,82,59,84,116,86,179,88,164,97,110,98,26,113,110,89,137,124,222,124,27,125,240,150,135,101,94,128,25,78,117,79,117,81,64,88,99,94,115,94,10,95,196,103,38,78,61,133,137,149,91,150,115,124,1,152,251,80,193,88,86,118,167,120,37,82,165,119,17,133,134,123,79,80,9,89,71,114,199,123,232,125,186,143,212,143,77,144,191,79,201,82,41,90,1,95,173,151,221,79,23,130,234,146,3,87,85,99,105,107,43,117,220,136,20,143,66,122,223,82,147,88,85,97,10,98,174,102,205,107,63,124,233,131,35,80,248,79,5,83,70,84,49,88,73,89,157,91,240,92,239,92,41,93,150,94,177,98,103,99,62,101,185,101,11,103,213,108,225,108,249,112,50,120,43,126,222,128,179,130,12,132,236,132,2,135,18,137,42,138,74,140,166,144,210,146,253,152,243,156,108,157,79,78,161,78,141,80,86,82,74,87,168,89,61,94,216,95,217,95,63,98,180,102,27,103,208,103,210,104,146,81,33,125,170,128,168,129,0,139,140,140,191,140,126,146,50,150,32,84,44,152,23,83,213,80,92,83,168,88,178,100,52,103,103,114,102,119,70,122,230,145,195,82,161,108,134,107,0,88,76,94,84,89,44,103,251,127,225,81,198,118,105,100,232,120,84,155,187,158,203,87,185,89,39,102,154,103,206,107,233,84,217,105,85,94,156,129,149,103,170,155,254,103,82,156,93,104,166,78,227,79,200,83,185,98,43,103,171,108,196,143,173,79,109,126,191,158,7,78,98,97,128,110,43,111,19,133,115,84,42,103,69,155,243,93,149,123,172,92,198,91,28,135,74,110,209,132,20,122,8,129,153,89,141,124,17,108,32,119,217,82,34,89,33,113,95,114,219,119,39,151,97,157,11,105,127,90,24,90,165,81,13,84,125,84,14,102,223,118,247,143,152,146,244,156,234,89,93,114,197,110,77,81,201,104,191,125,236,125,98,151,186,158,120,100,33,106,2,131,132,89,95,91,219,107,27,115,242,118,178,125,23,128,153,132,50,81,40,103,217,158,238,118,98,103,255,82,5,153,36,92,59,98,126,124,176,140,79,85,182,96,11,125,128,149,1,83,95,78,182,81,28,89,58,114,54,128,206,145,37,95,226,119,132,83,121,95,4,125,172,133,51,138,141,142,86,151,243,103,174,133,83,148,9,97,8,97,185,108,82,118,237,138,56,143,47,85,81,79,42,81,199,82,203,83,165,91,125,94,160,96,130,97,214,99,9,103,218,103,103,110,140,109,54,115,55,115,49,117,80,121,213,136,152,138,74,144,145,144,245,144,196,150,141,135,21,89,136,78,89,79,14,78,137,138,63,143,16,152,173,80,124,94,150,89,185,91,184,94,218,99,250,99,193,100,220,102,74,105,216,105,11,109,182,110,148,113,40,117,175,122,138,127,0,128,73,132,201,132,129,137,33,139,10,142,101,144,125,150,10,153,126,97,145,98,50,107,131,108,116,109,204,127,252,127,192,109,133,127,186,135,248,136,101,103,177,131,60,152,247,150,27,109,97,125,61,132,106,145,113,78,117,83,80,93,4,107,235,111,205,133,45,134,167,137,41,82,15,84,101,92,78,103,168,104,6,116,131,116,226,117,207,136,225,136,204,145,226,150,120,150,139,95,135,115,203,122,78,132,160,99,101,117,137,82,65,109,156,110,9,116,89,117,107,120,146,124,134,150,220,122,141,159,182,79,110,97,197,101,92,134,134,78,174,78,218,80,33,78,204,81,238,91,153,101,129,104,188,109,31,115,66,118,173,119,28,122,231,124,111,130,210,138,124,144,207,145,117,150,24,152,155,82,209,125,43,80,152,83,151,103,203,109,208,113,51,116,232,129,42,143,163,150,87,156,159,158,96,116,65,88,153,109,47,125,94,152,228,78,54,79,139,79,183,81,177,82,186,93,28,96,178,115,60,121,211,130,52,146,183,150,246,150,10,151,151,158,98,159,166,102,116,107,23,82,163,82,200,112,194,136,201,94,75,96,144,97,35,111,73,113,62,124,244,125,111,128,238,132,35,144,44,147,66,84,111,155,211,106,137,112,194,140,239,141,50,151,180,82,65,90,202,94,4,95,23,103,124,105,148,105,106,109,15,111,98,114,252,114,237,123,1,128,126,128,75,135,206,144,109,81,147,158,132,121,139,128,50,147,214,138,45,80,140,84,113,138,106,107,196,140,7,129,209,96,160,103,242,157,153,78,152,78,16,156,107,138,193,133,104,133,0,105,126,110,151,120,85,129,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,95,16,78,21,78,42,78,49,78,54,78,60,78,63,78,66,78,86,78,88,78,130,78,133,78,107,140,138,78,18,130,13,95,142,78,158,78,159,78,160,78,162,78,176,78,179,78,182,78,206,78,205,78,196,78,198,78,194,78,215,78,222,78,237,78,223,78,247,78,9,79,90,79,48,79,91,79,93,79,87,79,71,79,118,79,136,79,143,79,152,79,123,79,105,79,112,79,145,79,111,79,134,79,150,79,24,81,212,79,223,79,206,79,216,79,219,79,209,79,218,79,208,79,228,79,229,79,26,80,40,80,20,80,42,80,37,80,5,80,28,79,246,79,33,80,41,80,44,80,254,79,239,79,17,80,6,80,67,80,71,80,3,103,85,80,80,80,72,80,90,80,86,80,108,80,120,80,128,80,154,80,133,80,180,80,178,80,201,80,202,80,179,80,194,80,214,80,222,80,229,80,237,80,227,80,238,80,249,80,245,80,9,81,1,81,2,81,22,81,21,81,20,81,26,81,33,81,58,81,55,81,60,81,59,81,63,81,64,81,82,81,76,81,84,81,98,81,248,122,105,81,106,81,110,81,128,81,130,81,216,86,140,81,137,81,143,81,145,81,147,81,149,81,150,81,164,81,166,81,162,81,169,81,170,81,171,81,179,81,177,81,178,81,176,81,181,81,189,81,197,81,201,81,219,81,224,81,85,134,233,81,237,81,240,81,245,81,254,81,4,82,11,82,20,82,14,82,39,82,42,82,46,82,51,82,57,82,79,82,68,82,75,82,76,82,94,82,84,82,106,82,116,82,105,82,115,82,127,82,125,82,141,82,148,82,146,82,113,82,136,82,145,82,168,143,167,143,172,82,173,82,188,82,181,82,193,82,205,82,215,82,222,82,227,82,230,82,237,152,224,82,243,82,245,82,248,82,249,82,6,83,8,83,56,117,13,83,16,83,15,83,21,83,26,83,35,83,47,83,49,83,51,83,56,83,64,83,70,83,69,83,23,78,73,83,77,83,214,81,94,83,105,83,110,83,24,89,123,83,119,83,130,83,150,83,160,83,166,83,165,83,174,83,176,83,182,83,195,83,18,124,217,150,223,83,252,102,238,113,238,83,232,83,237,83,250,83,1,84,61,84,64,84,44,84,45,84,60,84,46,84,54,84,41,84,29,84,78,84,143,84,117,84,142,84,95,84,113,84,119,84,112,84,146,84,123,84,128,84,118,84,132,84,144,84,134,84,199,84,162,84,184,84,165,84,172,84,196,84,200,84,168,84,171,84,194,84,164,84,190,84,188,84,216,84,229,84,230,84,15,85,20,85,253,84,238,84,237,84,250,84,226,84,57,85,64,85,99,85,76,85,46,85,92,85,69,85,86,85,87,85,56,85,51,85,93,85,153,85,128,85,175,84,138,85,159,85,123,85,126,85,152,85,158,85,174,85,124,85,131,85,169,85,135,85,168,85,218,85,197,85,223,85,196,85,220,85,228,85,212,85,20,86,247,85,22,86,254,85,253,85,27,86,249,85,78,86,80,86,223,113,52,86,54,86,50,86,56,86,107,86,100,86,47,86,108,86,106,86,134,86,128,86,138,86,160,86,148,86,143,86,165,86,174,86,182,86,180,86,194,86,188,86,193,86,195,86,192,86,200,86,206,86,209,86,211,86,215,86,238,86,249,86,0,87,255,86,4,87,9,87,8,87,11,87,13,87,19,87,24,87,22,87,199,85,28,87,38,87,55,87,56,87,78,87,59,87,64,87,79,87,105,87,192,87,136,87,97,87,127,87,137,87,147,87,160,87,179,87,164,87,170,87,176,87,195,87,198,87,212,87,210,87,211,87,10,88,214,87,227,87,11,88,25,88,29,88,114,88,33,88,98,88,75,88,112,88,192,107,82,88,61,88,121,88,133,88,185,88,159,88,171,88,186,88,222,88,187,88,184,88,174,88,197,88,211,88,209,88,215,88,217,88,216,88,229,88,220,88,228,88,223,88,239,88,250,88,249,88,251,88,252,88,253,88,2,89,10,89,16,89,27,89,166,104,37,89,44,89,45,89,50,89,56,89,62,89,210,122,85,89,80,89,78,89,90,89,88,89,98,89,96,89,103,89,108,89,105,89,120,89,129,89,157,89,94,79,171,79,163,89,178,89,198,89,232,89,220,89,141,89,217,89,218,89,37,90,31,90,17,90,28,90,9,90,26,90,64,90,108,90,73,90,53,90,54,90,98,90,106,90,154,90,188,90,190,90,203,90,194,90,189,90,227,90,215,90,230,90,233,90,214,90,250,90,251,90,12,91,11,91,22,91,50,91,208,90,42,91,54,91,62,91,67,91,69,91,64,91,81,91,85,91,90,91,91,91,101,91,105,91,112,91,115,91,117,91,120,91,136,101,122,91,128,91,131,91,166,91,184,91,195,91,199,91,201,91,212,91,208,91,228,91,230,91,226,91,222,91,229,91,235,91,240,91,246,91,243,91,5,92,7,92,8,92,13,92,19,92,32,92,34,92,40,92,56,92,57,92,65,92,70,92,78,92,83,92,80,92,79,92,113,91,108,92,110,92,98,78,118,92,121,92,140,92,145,92,148,92,155,89,171,92,187,92,182,92,188,92,183,92,197,92,190,92,199,92,217,92,233,92,253,92,250,92,237,92,140,93,234,92,11,93,21,93,23,93,92,93,31,93,27,93,17,93,20,93,34,93,26,93,25,93,24,93,76,93,82,93,78,93,75,93,108,93,115,93,118,93,135,93,132,93,130,93,162,93,157,93,172,93,174,93,189,93,144,93,183,93,188,93,201,93,205,93,211,93,210,93,214,93,219,93,235,93,242,93,245,93,11,94,26,94,25,94,17,94,27,94,54,94,55,94,68,94,67,94,64,94,78,94,87,94,84,94,95,94,98,94,100,94,71,94,117,94,118,94,122,94,188,158,127,94,160,94,193,94,194,94,200,94,208,94,207,94,214,94,227,94,221,94,218,94,219,94,226,94,225,94,232,94,233,94,236,94,241,94,243,94,240,94,244,94,248,94,254,94,3,95,9,95,93,95,92,95,11,95,17,95,22,95,41,95,45,95,56,95,65,95,72,95,76,95,78,95,47,95,81,95,86,95,87,95,89,95,97,95,109,95,115,95,119,95,131,95,130,95,127,95,138,95,136,95,145,95,135,95,158,95,153,95,152,95,160,95,168,95,173,95,188,95,214,95,251,95,228,95,248,95,241,95,221,95,179,96,255,95,33,96,96,96,25,96,16,96,41,96,14,96,49,96,27,96,21,96,43,96,38,96,15,96,58,96,90,96,65,96,106,96,119,96,95,96,74,96,70,96,77,96,99,96,67,96,100,96,66,96,108,96,107,96,89,96,129,96,141,96,231,96,131,96,154,96,132,96,155,96,150,96,151,96,146,96,167,96,139,96,225,96,184,96,224,96,211,96,180,96,240,95,189,96,198,96,181,96,216,96,77,97,21,97,6,97,246,96,247,96,0,97,244,96,250,96,3,97,33,97,251,96,241,96,13,97,14,97,71,97,62,97,40,97,39,97,74,97,63,97,60,97,44,97,52,97,61,97,66,97,68,97,115,97,119,97,88,97,89,97,90,97,107,97,116,97,111,97,101,97,113,97,95,97,93,97,83,97,117,97,153,97,150,97,135,97,172,97,148,97,154,97,138,97,145,97,171,97,174,97,204,97,202,97,201,97,247,97,200,97,195,97,198,97,186,97,203,97,121,127,205,97,230,97,227,97,246,97,250,97,244,97,255,97,253,97,252,97,254,97,0,98,8,98,9,98,13,98,12,98,20,98,27,98,30,98,33,98,42,98,46,98,48,98,50,98,51,98,65,98,78,98,94,98,99,98,91,98,96,98,104,98,124,98,130,98,137,98,126,98,146,98,147,98,150,98,212,98,131,98,148,98,215,98,209,98,187,98,207,98,255,98,198,98,212,100,200,98,220,98,204,98,202,98,194,98,199,98,155,98,201,98,12,99,238,98,241,98,39,99,2,99,8,99,239,98,245,98,80,99,62,99,77,99,28,100,79,99,150,99,142,99,128,99,171,99,118,99,163,99,143,99,137,99,159,99,181,99,107,99,105,99,190,99,233,99,192,99,198,99,227,99,201,99,210,99,246,99,196,99,22,100,52,100,6,100,19,100,38,100,54,100,29,101,23,100,40,100,15,100,103,100,111,100,118,100,78,100,42,101,149,100,147,100,165,100,169,100,136,100,188,100,218,100,210,100,197,100,199,100,187,100,216,100,194,100,241,100,231,100,9,130,224,100,225,100,172,98,227,100,239,100,44,101,246,100,244,100,242,100,250,100,0,101,253,100,24,101,28,101,5,101,36,101,35,101,43,101,52,101,53,101,55,101,54,101,56,101,75,117,72,101,86,101,85,101,77,101,88,101,94,101,93,101,114,101,120,101,130,101,131,101,138,139,155,101,159,101,171,101,183,101,195,101,198,101,193,101,196,101,204,101,210,101,219,101,217,101,224,101,225,101,241,101,114,103,10,102,3,102,251,101,115,103,53,102,54,102,52,102,28,102,79,102,68,102,73,102,65,102,94,102,93,102,100,102,103,102,104,102,95,102,98,102,112,102,131,102,136,102,142,102,137,102,132,102,152,102,157,102,193,102,185,102,201,102,190,102,188,102,196,102,184,102,214,102,218,102,224,102,63,102,230,102,233,102,240,102,245,102,247,102,15,103,22,103,30,103,38,103,39,103,56,151,46,103,63,103,54,103,65,103,56,103,55,103,70,103,94,103,96,103,89,103,99,103,100,103,137,103,112,103,169,103,124,103,106,103,140,103,139,103,166,103,161,103,133,103,183,103,239,103,180,103,236,103,179,103,233,103,184,103,228,103,222,103,221,103,226,103,238,103,185,103,206,103,198,103,231,103,156,106,30,104,70,104,41,104,64,104,77,104,50,104,78,104,179,104,43,104,89,104,99,104,119,104,127,104,159,104,143,104,173,104,148,104,157,104,155,104,131,104,174,106,185,104,116,104,181,104,160,104,186,104,15,105,141,104,126,104,1,105,202,104,8,105,216,104,34,105,38,105,225,104,12,105,205,104,212,104,231,104,213,104,54,105,18,105,4,105,215,104,227,104,37,105,249,104,224,104,239,104,40,105,42,105,26,105,35,105,33,105,198,104,121,105,119,105,92,105,120,105,107,105,84,105,126,105,110,105,57,105,116,105,61,105,89,105,48,105,97,105,94,105,93,105,129,105,106,105,178,105,174,105,208,105,191,105,193,105,211,105,190,105,206,105,232,91,202,105,221,105,187,105,195,105,167,105,46,106,145,105,160,105,156,105,149,105,180,105,222,105,232,105,2,106,27,106,255,105,10,107,249,105,242,105,231,105,5,106,177,105,30,106,237,105,20,106,235,105,10,106,18,106,193,106,35,106,19,106,68,106,12,106,114,106,54,106,120,106,71,106,98,106,89,106,102,106,72,106,56,106,34,106,144,106,141,106,160,106,132,106,162,106,163,106,151,106,23,134,187,106,195,106,194,106,184,106,179,106,172,106,222,106,209,106,223,106,170,106,218,106,234,106,251,106,5,107,22,134,250,106,18,107,22,107,49,155,31,107,56,107,55,107,220,118,57,107,238,152,71,107,67,107,73,107,80,107,89,107,84,107,91,107,95,107,97,107,120,107,121,107,127,107,128,107,132,107,131,107,141,107,152,107,149,107,158,107,164,107,170,107,171,107,175,107,178,107,177,107,179,107,183,107,188,107,198,107,203,107,211,107,223,107,236,107,235,107,243,107,239,107,190,158,8,108,19,108,20,108,27,108,36,108,35,108,94,108,85,108,98,108,106,108,130,108,141,108,154,108,129,108,155,108,126,108,104,108,115,108,146,108,144,108,196,108,241,108,211,108,189,108,215,108,197,108,221,108,174,108,177,108,190,108,186,108,219,108,239,108,217,108,234,108,31,109,77,136,54,109,43,109,61,109,56,109,25,109,53,109,51,109,18,109,12,109,99,109,147,109,100,109,90,109,121,109,89,109,142,109,149,109,228,111,133,109,249,109,21,110,10,110,181,109,199,109,230,109,184,109,198,109,236,109,222,109,204,109,232,109,210,109,197,109,250,109,217,109,228,109,213,109,234,109,238,109,45,110,110,110,46,110,25,110,114,110,95,110,62,110,35,110,107,110,43,110,118,110,77,110,31,110,67,110,58,110,78,110,36,110,255,110,29,110,56,110,130,110,170,110,152,110,201,110,183,110,211,110,189,110,175,110,196,110,178,110,212,110,213,110,143,110,165,110,194,110,159,110,65,111,17,111,76,112,236,110,248,110,254,110,63,111,242,110,49,111,239,110,50,111,204,110,62,111,19,111,247,110,134,111,122,111,120,111,129,111,128,111,111,111,91,111,243,111,109,111,130,111,124,111,88,111,142,111,145,111,194,111,102,111,179,111,163,111,161,111,164,111,185,111,198,111,170,111,223,111,213,111,236,111,212,111,216,111,241,111,238,111,219,111,9,112,11,112,250,111,17,112,1,112,15,112,254,111,27,112,26,112,116,111,29,112,24,112,31,112,48,112,62,112,50,112,81,112,99,112,153,112,146,112,175,112,241,112,172,112,184,112,179,112,174,112,223,112,203,112,221,112,217,112,9,113,253,112,28,113,25,113,101,113,85,113,136,113,102,113,98,113,76,113,86,113,108,113,143,113,251,113,132,113,149,113,168,113,172,113,215,113,185,113,190,113,210,113,201,113,212,113,206,113,224,113,236,113,231,113,245,113,252,113,249,113,255,113,13,114,16,114,27,114,40,114,45,114,44,114,48,114,50,114,59,114,60,114,63,114,64,114,70,114,75,114,88,114,116,114,126,114,130,114,129,114,135,114,146,114,150,114,162,114,167,114,185,114,178,114,195,114,198,114,196,114,206,114,210,114,226,114,224,114,225,114,249,114,247,114,15,80,23,115,10,115,28,115,22,115,29,115,52,115,47,115,41,115,37,115,62,115,78,115,79,115,216,158,87,115,106,115,104,115,112,115,120,115,117,115,123,115,122,115,200,115,179,115,206,115,187,115,192,115,229,115,238,115,222,115,162,116,5,116,111,116,37,116,248,115,50,116,58,116,85,116,63,116,95,116,89,116,65,116,92,116,105,116,112,116,99,116,106,116,118,116,126,116,139,116,158,116,167,116,202,116,207,116,212,116,241,115,224,116,227,116,231,116,233,116,238,116,242,116,240,116,241,116,248,116,247,116,4,117,3,117,5,117,12,117,14,117,13,117,21,117,19,117,30,117,38,117,44,117,60,117,68,117,77,117,74,117,73,117,91,117,70,117,90,117,105,117,100,117,103,117,107,117,109,117,120,117,118,117,134,117,135,117,116,117,138,117,137,117,130,117,148,117,154,117,157,117,165,117,163,117,194,117,179,117,195,117,181,117,189,117,184,117,188,117,177,117,205,117,202,117,210,117,217,117,227,117,222,117,254,117,255,117,252,117,1,118,240,117,250,117,242,117,243,117,11,118,13,118,9,118,31,118,39,118,32,118,33,118,34,118,36,118,52,118,48,118,59,118,71,118,72,118,70,118,92,118,88,118,97,118,98,118,104,118,105,118,106,118,103,118,108,118,112,118,114,118,118,118,120,118,124,118,128,118,131,118,136,118,139,118,142,118,150,118,147,118,153,118,154,118,176,118,180,118,184,118,185,118,186,118,194,118,205,118,214,118,210,118,222,118,225,118,229,118,231,118,234,118,47,134,251,118,8,119,7,119,4,119,41,119,36,119,30,119,37,119,38,119,27,119,55,119,56,119,71,119,90,119,104,119,107,119,91,119,101,119,127,119,126,119,121,119,142,119,139,119,145,119,160,119,158,119,176,119,182,119,185,119,191,119,188,119,189,119,187,119,199,119,205,119,215,119,218,119,220,119,227,119,238,119,252,119,12,120,18,120,38,121,32,120,42,121,69,120,142,120,116,120,134,120,124,120,154,120,140,120,163,120,181,120,170,120,175,120,209,120,198,120,203,120,212,120,190,120,188,120,197,120,202,120,236,120,231,120,218,120,253,120,244,120,7,121,18,121,17,121,25,121,44,121,43,121,64,121,96,121,87,121,95,121,90,121,85,121,83,121,122,121,127,121,138,121,157,121,167,121,75,159,170,121,174,121,179,121,185,121,186,121,201,121,213,121,231,121,236,121,225,121,227,121,8,122,13,122,24,122,25,122,32,122,31,122,128,121,49,122,59,122,62,122,55,122,67,122,87,122,73,122,97,122,98,122,105,122,157,159,112,122,121,122,125,122,136,122,151,122,149,122,152,122,150,122,169,122,200,122,176,122,182,122,197,122,196,122,191,122,131,144,199,122,202,122,205,122,207,122,213,122,211,122,217,122,218,122,221,122,225,122,226,122,230,122,237,122,240,122,2,123,15,123,10,123,6,123,51,123,24,123,25,123,30,123,53,123,40,123,54,123,80,123,122,123,4,123,77,123,11,123,76,123,69,123,117,123,101,123,116,123,103,123,112,123,113,123,108,123,110,123,157,123,152,123,159,123,141,123,156,123,154,123,139,123,146,123,143,123,93,123,153,123,203,123,193,123,204,123,207,123,180,123,198,123,221,123,233,123,17,124,20,124,230,123,229,123,96,124,0,124,7,124,19,124,243,123,247,123,23,124,13,124,246,123,35,124,39,124,42,124,31,124,55,124,43,124,61,124,76,124,67,124,84,124,79,124,64,124,80,124,88,124,95,124,100,124,86,124,101,124,108,124,117,124,131,124,144,124,164,124,173,124,162,124,171,124,161,124,168,124,179,124,178,124,177,124,174,124,185,124,189,124,192,124,197,124,194,124,216,124,210,124,220,124,226,124,59,155,239,124,242,124,244,124,246,124,250,124,6,125,2,125,28,125,21,125,10,125,69,125,75,125,46,125,50,125,63,125,53,125,70,125,115,125,86,125,78,125,114,125,104,125,110,125,79,125,99,125,147,125,137,125,91,125,143,125,125,125,155,125,186,125,174,125,163,125,181,125,199,125,189,125,171,125,61,126,162,125,175,125,220,125,184,125,159,125,176,125,216,125,221,125,228,125,222,125,251,125,242,125,225,125,5,126,10,126,35,126,33,126,18,126,49,126,31,126,9,126,11,126,34,126,70,126,102,126,59,126,53,126,57,126,67,126,55,126,50,126,58,126,103,126,93,126,86,126,94,126,89,126,90,126,121,126,106,126,105,126,124,126,123,126,131,126,213,125,125,126,174,143,127,126,136,126,137,126,140,126,146,126,144,126,147,126,148,126,150,126,142,126,155,126,156,126,56,127,58,127,69,127,76,127,77,127,78,127,80,127,81,127,85,127,84,127,88,127,95,127,96,127,104,127,105,127,103,127,120,127,130,127,134,127,131,127,136,127,135,127,140,127,148,127,158,127,157,127,154,127,163,127,175,127,178,127,185,127,174,127,182,127,184,127,113,139,197,127,198,127,202,127,213,127,212,127,225,127,230,127,233,127,243,127,249,127,220,152],"i8",ALLOC_NONE,Runtime.GLOBAL_BASE+210108),
	allocate([6,128,4,128,11,128,18,128,24,128,25,128,28,128,33,128,40,128,63,128,59,128,74,128,70,128,82,128,88,128,90,128,95,128,98,128,104,128,115,128,114,128,112,128,118,128,121,128,125,128,127,128,132,128,134,128,133,128,155,128,147,128,154,128,173,128,144,81,172,128,219,128,229,128,217,128,221,128,196,128,218,128,214,128,9,129,239,128,241,128,27,129,41,129,35,129,47,129,75,129,139,150,70,129,62,129,83,129,81,129,252,128,113,129,110,129,101,129,102,129,116,129,131,129,136,129,138,129,128,129,130,129,160,129,149,129,164,129,163,129,95,129,147,129,169,129,176,129,181,129,190,129,184,129,189,129,192,129,194,129,186,129,201,129,205,129,209,129,217,129,216,129,200,129,218,129,223,129,224,129,231,129,250,129,251,129,254,129,1,130,2,130,5,130,7,130,10,130,13,130,16,130,22,130,41,130,43,130,56,130,51,130,64,130,89,130,88,130,93,130,90,130,95,130,100,130,98,130,104,130,106,130,107,130,46,130,113,130,119,130,120,130,126,130,141,130,146,130,171,130,159,130,187,130,172,130,225,130,227,130,223,130,210,130,244,130,243,130,250,130,147,131,3,131,251,130,249,130,222,130,6,131,220,130,9,131,217,130,53,131,52,131,22,131,50,131,49,131,64,131,57,131,80,131,69,131,47,131,43,131,23,131,24,131,133,131,154,131,170,131,159,131,162,131,150,131,35,131,142,131,135,131,138,131,124,131,181,131,115,131,117,131,160,131,137,131,168,131,244,131,19,132,235,131,206,131,253,131,3,132,216,131,11,132,193,131,247,131,7,132,224,131,242,131,13,132,34,132,32,132,189,131,56,132,6,133,251,131,109,132,42,132,60,132,90,133,132,132,119,132,107,132,173,132,110,132,130,132,105,132,70,132,44,132,111,132,121,132,53,132,202,132,98,132,185,132,191,132,159,132,217,132,205,132,187,132,218,132,208,132,193,132,198,132,214,132,161,132,33,133,255,132,244,132,23,133,24,133,44,133,31,133,21,133,20,133,252,132,64,133,99,133,88,133,72,133,65,133,2,134,75,133,85,133,128,133,164,133,136,133,145,133,138,133,168,133,109,133,148,133,155,133,234,133,135,133,156,133,119,133,126,133,144,133,201,133,186,133,207,133,185,133,208,133,213,133,221,133,229,133,220,133,249,133,10,134,19,134,11,134,254,133,250,133,6,134,34,134,26,134,48,134,63,134,77,134,85,78,84,134,95,134,103,134,113,134,147,134,163,134,169,134,170,134,139,134,140,134,182,134,175,134,196,134,198,134,176,134,201,134,35,136,171,134,212,134,222,134,233,134,236,134,223,134,219,134,239,134,18,135,6,135,8,135,0,135,3,135,251,134,17,135,9,135,13,135,249,134,10,135,52,135,63,135,55,135,59,135,37,135,41,135,26,135,96,135,95,135,120,135,76,135,78,135,116,135,87,135,104,135,110,135,89,135,83,135,99,135,106,135,5,136,162,135,159,135,130,135,175,135,203,135,189,135,192,135,208,135,214,150,171,135,196,135,179,135,199,135,198,135,187,135,239,135,242,135,224,135,15,136,13,136,254,135,246,135,247,135,14,136,210,135,17,136,22,136,21,136,34,136,33,136,49,136,54,136,57,136,39,136,59,136,68,136,66,136,82,136,89,136,94,136,98,136,107,136,129,136,126,136,158,136,117,136,125,136,181,136,114,136,130,136,151,136,146,136,174,136,153,136,162,136,141,136,164,136,176,136,191,136,177,136,195,136,196,136,212,136,216,136,217,136,221,136,249,136,2,137,252,136,244,136,232,136,242,136,4,137,12,137,10,137,19,137,67,137,30,137,37,137,42,137,43,137,65,137,68,137,59,137,54,137,56,137,76,137,29,137,96,137,94,137,102,137,100,137,109,137,106,137,111,137,116,137,119,137,126,137,131,137,136,137,138,137,147,137,152,137,161,137,169,137,166,137,172,137,175,137,178,137,186,137,189,137,191,137,192,137,218,137,220,137,221,137,231,137,244,137,248,137,3,138,22,138,16,138,12,138,27,138,29,138,37,138,54,138,65,138,91,138,82,138,70,138,72,138,124,138,109,138,108,138,98,138,133,138,130,138,132,138,168,138,161,138,145,138,165,138,166,138,154,138,163,138,196,138,205,138,194,138,218,138,235,138,243,138,231,138,228,138,241,138,20,139,224,138,226,138,247,138,222,138,219,138,12,139,7,139,26,139,225,138,22,139,16,139,23,139,32,139,51,139,171,151,38,139,43,139,62,139,40,139,65,139,76,139,79,139,78,139,73,139,86,139,91,139,90,139,107,139,95,139,108,139,111,139,116,139,125,139,128,139,140,139,142,139,146,139,147,139,150,139,153,139,154,139,58,140,65,140,63,140,72,140,76,140,78,140,80,140,85,140,98,140,108,140,120,140,122,140,130,140,137,140,133,140,138,140,141,140,142,140,148,140,124,140,152,140,29,98,173,140,170,140,189,140,178,140,179,140,174,140,182,140,200,140,193,140,228,140,227,140,218,140,253,140,250,140,251,140,4,141,5,141,10,141,7,141,15,141,13,141,16,141,78,159,19,141,205,140,20,141,22,141,103,141,109,141,113,141,115,141,129,141,153,141,194,141,190,141,186,141,207,141,218,141,214,141,204,141,219,141,203,141,234,141,235,141,223,141,227,141,252,141,8,142,9,142,255,141,29,142,30,142,16,142,31,142,66,142,53,142,48,142,52,142,74,142,71,142,73,142,76,142,80,142,72,142,89,142,100,142,96,142,42,142,99,142,85,142,118,142,114,142,124,142,129,142,135,142,133,142,132,142,139,142,138,142,147,142,145,142,148,142,153,142,170,142,161,142,172,142,176,142,198,142,177,142,190,142,197,142,200,142,203,142,219,142,227,142,252,142,251,142,235,142,254,142,10,143,5,143,21,143,18,143,25,143,19,143,28,143,31,143,27,143,12,143,38,143,51,143,59,143,57,143,69,143,66,143,62,143,76,143,73,143,70,143,78,143,87,143,92,143,98,143,99,143,100,143,156,143,159,143,163,143,173,143,175,143,183,143,218,143,229,143,226,143,234,143,239,143,135,144,244,143,5,144,249,143,250,143,17,144,21,144,33,144,13,144,30,144,22,144,11,144,39,144,54,144,53,144,57,144,248,143,79,144,80,144,81,144,82,144,14,144,73,144,62,144,86,144,88,144,94,144,104,144,111,144,118,144,168,150,114,144,130,144,125,144,129,144,128,144,138,144,137,144,143,144,168,144,175,144,177,144,181,144,226,144,228,144,72,98,219,144,2,145,18,145,25,145,50,145,48,145,74,145,86,145,88,145,99,145,101,145,105,145,115,145,114,145,139,145,137,145,130,145,162,145,171,145,175,145,170,145,181,145,180,145,186,145,192,145,193,145,201,145,203,145,208,145,214,145,223,145,225,145,219,145,252,145,245,145,246,145,30,146,255,145,20,146,44,146,21,146,17,146,94,146,87,146,69,146,73,146,100,146,72,146,149,146,63,146,75,146,80,146,156,146,150,146,147,146,155,146,90,146,207,146,185,146,183,146,233,146,15,147,250,146,68,147,46,147,25,147,34,147,26,147,35,147,58,147,53,147,59,147,92,147,96,147,124,147,110,147,86,147,176,147,172,147,173,147,148,147,185,147,214,147,215,147,232,147,229,147,216,147,195,147,221,147,208,147,200,147,228,147,26,148,20,148,19,148,3,148,7,148,16,148,54,148,43,148,53,148,33,148,58,148,65,148,82,148,68,148,91,148,96,148,98,148,94,148,106,148,41,146,112,148,117,148,119,148,125,148,90,148,124,148,126,148,129,148,127,148,130,149,135,149,138,149,148,149,150,149,152,149,153,149,160,149,168,149,167,149,173,149,188,149,187,149,185,149,190,149,202,149,246,111,195,149,205,149,204,149,213,149,212,149,214,149,220,149,225,149,229,149,226,149,33,150,40,150,46,150,47,150,66,150,76,150,79,150,75,150,119,150,92,150,94,150,93,150,95,150,102,150,114,150,108,150,141,150,152,150,149,150,151,150,170,150,167,150,177,150,178,150,176,150,180,150,182,150,184,150,185,150,206,150,203,150,201,150,205,150,77,137,220,150,13,151,213,150,249,150,4,151,6,151,8,151,19,151,14,151,17,151,15,151,22,151,25,151,36,151,42,151,48,151,57,151,61,151,62,151,68,151,70,151,72,151,66,151,73,151,92,151,96,151,100,151,102,151,104,151,210,82,107,151,113,151,121,151,133,151,124,151,129,151,122,151,134,151,139,151,143,151,144,151,156,151,168,151,166,151,163,151,179,151,180,151,195,151,198,151,200,151,203,151,220,151,237,151,79,159,242,151,223,122,246,151,245,151,15,152,12,152,56,152,36,152,33,152,55,152,61,152,70,152,79,152,75,152,107,152,111,152,112,152,113,152,116,152,115,152,170,152,175,152,177,152,182,152,196,152,195,152,198,152,233,152,235,152,3,153,9,153,18,153,20,153,24,153,33,153,29,153,30,153,36,153,32,153,44,153,46,153,61,153,62,153,66,153,73,153,69,153,80,153,75,153,81,153,82,153,76,153,85,153,151,153,152,153,165,153,173,153,174,153,188,153,223,153,219,153,221,153,216,153,209,153,237,153,238,153,241,153,242,153,251,153,248,153,1,154,15,154,5,154,226,153,25,154,43,154,55,154,69,154,66,154,64,154,67,154,62,154,85,154,77,154,91,154,87,154,95,154,98,154,101,154,100,154,105,154,107,154,106,154,173,154,176,154,188,154,192,154,207,154,209,154,211,154,212,154,222,154,223,154,226,154,227,154,230,154,239,154,235,154,238,154,244,154,241,154,247,154,251,154,6,155,24,155,26,155,31,155,34,155,35,155,37,155,39,155,40,155,41,155,42,155,46,155,47,155,50,155,68,155,67,155,79,155,77,155,78,155,81,155,88,155,116,155,147,155,131,155,145,155,150,155,151,155,159,155,160,155,168,155,180,155,192,155,202,155,185,155,198,155,207,155,209,155,210,155,227,155,226,155,228,155,212,155,225,155,58,156,242,155,241,155,240,155,21,156,20,156,9,156,19,156,12,156,6,156,8,156,18,156,10,156,4,156,46,156,27,156,37,156,36,156,33,156,48,156,71,156,50,156,70,156,62,156,90,156,96,156,103,156,118,156,120,156,231,156,236,156,240,156,9,157,8,157,235,156,3,157,6,157,42,157,38,157,175,157,35,157,31,157,68,157,21,157,18,157,65,157,63,157,62,157,70,157,72,157,93,157,94,157,100,157,81,157,80,157,89,157,114,157,137,157,135,157,171,157,111,157,122,157,154,157,164,157,169,157,178,157,196,157,193,157,187,157,184,157,186,157,198,157,207,157,194,157,217,157,211,157,248,157,230,157,237,157,239,157,253,157,26,158,27,158,30,158,117,158,121,158,125,158,129,158,136,158,139,158,140,158,146,158,149,158,145,158,157,158,165,158,169,158,184,158,170,158,173,158,97,151,204,158,206,158,207,158,208,158,212,158,220,158,222,158,221,158,224,158,229,158,232,158,239,158,244,158,246,158,247,158,249,158,251,158,252,158,253,158,7,159,8,159,183,118,21,159,33,159,44,159,62,159,74,159,82,159,84,159,99,159,95,159,96,159,97,159,102,159,103,159,108,159,106,159,119,159,114,159,118,159,149,159,156,159,160,159,47,88,199,105,89,144,100,116,220,81,153,113,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,78,4,78,5,78,6,78,15,78,18,78,23,78,31,78,32,78,33,78,35,78,38,78,41,78,46,78,47,78,49,78,51,78,53,78,55,78,60,78,64,78,65,78,66,78,68,78,70,78,74,78,81,78,85,78,87,78,90,78,91,78,98,78,99,78,100,78,101,78,103,78,104,78,106,78,107,78,108,78,109,78,110,78,111,78,114,78,116,78,117,78,118,78,119,78,120,78,121,78,122,78,123,78,124,78,125,78,127,78,128,78,129,78,130,78,131,78,132,78,133,78,135,78,138,78,144,78,150,78,151,78,153,78,156,78,157,78,158,78,163,78,170,78,175,78,176,78,177,78,180,78,182,78,183,78,184,78,185,78,188,78,189,78,190,78,200,78,204,78,207,78,208,78,210,78,218,78,219,78,220,78,224,78,226,78,230,78,231,78,233,78,237,78,238,78,239,78,241,78,244,78,248,78,249,78,250,78,252,78,254,78,0,79,2,79,3,79,4,79,5,79,6,79,7,79,8,79,11,79,12,79,18,79,19,79,20,79,21,79,22,79,28,79,29,79,33,79,35,79,40,79,41,79,44,79,45,79,46,79,49,79,51,79,53,79,55,79,57,79,59,79,62,79,63,79,64,79,65,79,66,79,68,79,69,79,71,79,72,79,73,79,74,79,75,79,76,79,82,79,84,79,86,79,97,79,98,79,102,79,104,79,106,79,107,79,109,79,110,79,113,79,114,79,117,79,119,79,120,79,121,79,122,79,125,79,128,79,129,79,130,79,133,79,134,79,135,79,138,79,140,79,142,79,144,79,146,79,147,79,149,79,150,79,152,79,153,79,154,79,156,79,158,79,159,79,161,79,162,79,164,79,171,79,173,79,176,79,177,79,178,79,179,79,180,79,182,79,183,79,184,79,185,79,186,79,187,79,188,79,189,79,190,79,192,79,193,79,194,79,198,79,199,79,200,79,201,79,203,79,204,79,205,79,210,79,211,79,212,79,213,79,214,79,217,79,219,79,224,79,226,79,228,79,229,79,231,79,235,79,236,79,240,79,242,79,244,79,245,79,246,79,247,79,249,79,251,79,252,79,253,79,255,79,0,80,1,80,2,80,3,80,4,80,5,80,6,80,7,80,8,80,9,80,10,80,11,80,14,80,16,80,17,80,19,80,21,80,22,80,23,80,27,80,29,80,30,80,32,80,34,80,35,80,36,80,39,80,43,80,47,80,48,80,49,80,50,80,51,80,52,80,53,80,54,80,55,80,56,80,57,80,59,80,61,80,63,80,64,80,65,80,66,80,68,80,69,80,70,80,73,80,74,80,75,80,77,80,80,80,81,80,82,80,83,80,84,80,86,80,87,80,88,80,89,80,91,80,93,80,94,80,95,80,96,80,97,80,98,80,99,80,100,80,102,80,103,80,104,80,105,80,106,80,107,80,109,80,110,80,111,80,112,80,113,80,114,80,115,80,116,80,117,80,120,80,121,80,122,80,124,80,125,80,129,80,130,80,131,80,132,80,134,80,135,80,137,80,138,80,139,80,140,80,142,80,143,80,144,80,145,80,146,80,147,80,148,80,149,80,150,80,151,80,152,80,153,80,154,80,155,80,156,80,157,80,158,80,159,80,160,80,161,80,162,80,164,80,166,80,170,80,171,80,173,80,174,80,175,80,176,80,177,80,179,80,180,80,181,80,182,80,183,80,184,80,185,80,188,80,189,80,190,80,191,80,192,80,193,80,194,80,195,80,196,80,197,80,198,80,199,80,200,80,201,80,202,80,203,80,204,80,205,80,206,80,208,80,209,80,210,80,211,80,212,80,213,80,215,80,216,80,217,80,219,80,220,80,221,80,222,80,223,80,224,80,225,80,226,80,227,80,228,80,229,80,232,80,233,80,234,80,235,80,239,80,240,80,241,80,242,80,244,80,246,80,247,80,248,80,249,80,250,80,252,80,253,80,254,80,255,80,0,81,1,81,2,81,3,81,4,81,5,81,8,81,9,81,10,81,12,81,13,81,14,81,15,81,16,81,17,81,19,81,20,81,21,81,22,81,23,81,24,81,25,81,26,81,27,81,28,81,29,81,30,81,31,81,32,81,34,81,35,81,36,81,37,81,38,81,39,81,40,81,41,81,42,81,43,81,44,81,45,81,46,81,47,81,48,81,49,81,50,81,51,81,52,81,53,81,54,81,55,81,56,81,57,81,58,81,59,81,60,81,61,81,62,81,66,81,71,81,74,81,76,81,78,81,79,81,80,81,82,81,83,81,87,81,88,81,89,81,91,81,93,81,94,81,95,81,96,81,97,81,99,81,100,81,102,81,103,81,105,81,106,81,111,81,114,81,122,81,126,81,127,81,131,81,132,81,134,81,135,81,138,81,139,81,142,81,143,81,144,81,145,81,147,81,148,81,152,81,154,81,157,81,158,81,159,81,161,81,163,81,166,81,167,81,168,81,169,81,170,81,173,81,174,81,180,81,184,81,185,81,186,81,190,81,191,81,193,81,194,81,195,81,197,81,200,81,202,81,205,81,206,81,208,81,210,81,211,81,212,81,213,81,214,81,215,81,216,81,217,81,218,81,220,81,222,81,223,81,226,81,227,81,229,81,230,81,231,81,232,81,233,81,234,81,236,81,238,81,241,81,242,81,244,81,247,81,254,81,4,82,5,82,9,82,11,82,12,82,15,82,16,82,19,82,20,82,21,82,28,82,30,82,31,82,33,82,34,82,35,82,37,82,38,82,39,82,42,82,44,82,47,82,49,82,50,82,52,82,53,82,60,82,62,82,68,82,69,82,70,82,71,82,72,82,73,82,75,82,78,82,79,82,82,82,83,82,85,82,87,82,88,82,89,82,90,82,91,82,93,82,95,82,96,82,98,82,99,82,100,82,102,82,104,82,107,82,108,82,109,82,110,82,112,82,113,82,115,82,116,82,117,82,118,82,119,82,120,82,121,82,122,82,123,82,124,82,126,82,128,82,131,82,132,82,133,82,134,82,135,82,137,82,138,82,139,82,140,82,141,82,142,82,143,82,145,82,146,82,148,82,149,82,150,82,151,82,152,82,153,82,154,82,156,82,164,82,165,82,166,82,167,82,174,82,175,82,176,82,180,82,181,82,182,82,183,82,184,82,185,82,186,82,187,82,188,82,189,82,192,82,193,82,194,82,196,82,197,82,198,82,200,82,202,82,204,82,205,82,206,82,207,82,209,82,211,82,212,82,213,82,215,82,217,82,218,82,219,82,220,82,221,82,222,82,224,82,225,82,226,82,227,82,229,82,230,82,231,82,232,82,233,82,234,82,235,82,236,82,237,82,238,82,239,82,241,82,242,82,243,82,244,82,245,82,246,82,247,82,248,82,251,82,252,82,253,82,1,83,2,83,3,83,4,83,7,83,9,83,10,83,11,83,12,83,14,83,17,83,18,83,19,83,20,83,24,83,27,83,28,83,30,83,31,83,34,83,36,83,37,83,39,83,40,83,41,83,43,83,44,83,45,83,47,83,48,83,49,83,50,83,51,83,52,83,53,83,54,83,55,83,56,83,60,83,61,83,64,83,66,83,68,83,70,83,75,83,76,83,77,83,80,83,84,83,88,83,89,83,91,83,93,83,101,83,104,83,106,83,108,83,109,83,114,83,118,83,121,83,123,83,124,83,125,83,126,83,128,83,129,83,131,83,135,83,136,83,138,83,142,83,143,83,144,83,145,83,146,83,147,83,148,83,150,83,151,83,153,83,155,83,156,83,158,83,160,83,161,83,164,83,167,83,170,83,171,83,172,83,173,83,175,83,176,83,177,83,178,83,179,83,180,83,181,83,183,83,184,83,185,83,186,83,188,83,189,83,190,83,192,83,195,83,196,83,197,83,198,83,199,83,206,83,207,83,208,83,210,83,211,83,213,83,218,83,220,83,221,83,222,83,225,83,226,83,231,83,244,83,250,83,254,83,255,83,0,84,2,84,5,84,7,84,11,84,20,84,24,84,25,84,26,84,28,84,34,84,36,84,37,84,42,84,48,84,51,84,54,84,55,84,58,84,61,84,63,84,65,84,66,84,68,84,69,84,71,84,73,84,76,84,77,84,78,84,79,84,81,84,90,84,93,84,94,84,95,84,96,84,97,84,99,84,101,84,103,84,105,84,106,84,107,84,108,84,109,84,110,84,111,84,112,84,116,84,121,84,122,84,126,84,127,84,129,84,131,84,133,84,135,84,136,84,137,84,138,84,141,84,145,84,147,84,151,84,152,84,156,84,158,84,159,84,160,84,161,84,162,84,165,84,174,84,176,84,178,84,181,84,182,84,183,84,185,84,186,84,188,84,190,84,195,84,197,84,202,84,203,84,214,84,216,84,219,84,224,84,225,84,226,84,227,84,228,84,235,84,236,84,239,84,240,84,241,84,244,84,245,84,246,84,247,84,248,84,249,84,251,84,254,84,0,85,2,85,3,85,4,85,5,85,8,85,10,85,11,85,12,85,13,85,14,85,18,85,19,85,21,85,22,85,23,85,24,85,25,85,26,85,28,85,29,85,30,85,31,85,33,85,37,85,38,85,40,85,41,85,43,85,45,85,50,85,52,85,53,85,54,85,56,85,57,85,58,85,59,85,61,85,64,85,66,85,69,85,71,85,72,85,75,85,76,85,77,85,78,85,79,85,81,85,82,85,83,85,84,85,87,85,88,85,89,85,90,85,91,85,93,85,94,85,95,85,96,85,98,85,99,85,104,85,105,85,107,85,111,85,112,85,113,85,114,85,115,85,116,85,121,85,122,85,125,85,127,85,133,85,134,85,140,85,141,85,142,85,144,85,146,85,147,85,149,85,150,85,151,85,154,85,155,85,158,85,160,85,161,85,162,85,163,85,164,85,165,85,166,85,168,85,169,85,170,85,171,85,172,85,173,85,174,85,175,85,176,85,178,85,180,85,182,85,184,85,186,85,188,85,191,85,192,85,193,85,194,85,195,85,198,85,199,85,200,85,202,85,203,85,206,85,207,85,208,85,213,85,215,85,216,85,217,85,218,85,219,85,222,85,224,85,226,85,231,85,233,85,237,85,238,85,240,85,241,85,244,85,246,85,248,85,249,85,250,85,251,85,252,85,255,85,2,86,3,86,4,86,5,86,6,86,7,86,10,86,11,86,13,86,16,86,17,86,18,86,19,86,20,86,21,86,22,86,23,86,25,86,26,86,28,86,29,86,32,86,33,86,34,86,37,86,38,86,40,86,41,86,42,86,43,86,46,86,47,86,48,86,51,86,53,86,55,86,56,86,58,86,60,86,61,86,62,86,64,86,65,86,66,86,67,86,68,86,69,86,70,86,71,86,72,86,73,86,74,86,75,86,79,86,80,86,81,86,82,86,83,86,85,86,86,86,90,86,91,86,93,86,94,86,95,86,96,86,97,86,99,86,101,86,102,86,103,86,109,86,110,86,111,86,112,86,114,86,115,86,116,86,117,86,119,86,120,86,121,86,122,86,125,86,126,86,127,86,128,86,129,86,130,86,131,86,132,86,135,86,136,86,137,86,138,86,139,86,140,86,141,86,144,86,145,86,146,86,148,86,149,86,150,86,151,86,152,86,153,86,154,86,155,86,156,86,157,86,158,86,159,86,160,86,161,86,162,86,164,86,165,86,166,86,167,86,168,86,169,86,170,86,171,86,172,86,173,86,174,86,176,86,177,86,178,86,179,86,180,86,181,86,182,86,184,86,185,86,186,86,187,86,189,86,190,86,191,86,192,86,193,86,194,86,195,86,196,86,197,86,198,86,199,86,200,86,201,86,203,86,204,86,205,86,206,86,207,86,208,86,209,86,210,86,211,86,213,86,214,86,216,86,217,86,220,86,227,86,229,86,230,86,231,86,232,86,233,86,234,86,236,86,238,86,239,86,242,86,243,86,246,86,247,86,248,86,251,86,252,86,0,87,1,87,2,87,5,87,7,87,11,87,12,87,13,87,14,87,15,87,16,87,17,87,18,87,19,87,20,87,21,87,22,87,23,87,24,87,25,87,26,87,27,87,29,87,30,87,32,87,33,87,34,87,36,87,37,87,38,87,39,87,43,87,49,87,50,87,52,87,53,87,54,87,55,87,56,87,60,87,61,87,63,87,65,87,67,87,68,87,69,87,70,87,72,87,73,87,75,87,82,87,83,87,84,87,85,87,86,87,88,87,89,87,98,87,99,87,101,87,103,87,108,87,110,87,112,87,113,87,114,87,116,87,117,87,120,87,121,87,122,87,125,87,126,87,127,87,128,87,129,87,135,87,136,87,137,87,138,87,141,87,142,87,143,87,144,87,145,87,148,87,149,87,150,87,151,87,152,87,153,87,154,87,156,87,157,87,158,87,159,87,165,87,168,87,170,87,172,87,175,87,176,87,177,87,179,87,181,87,182,87,183,87,185,87,186,87,187,87,188,87,189,87,190,87,191,87,192,87,193,87,196,87,197,87,198,87,199,87,200,87,201,87,202,87,204,87,205,87,208,87,209,87,211,87,214,87,215,87,219,87,220,87,222,87,225,87,226,87,227,87,229,87,230,87,231,87,232,87,233,87,234,87,235,87,236,87,238,87,240,87,241,87,242,87,243,87,245,87,246,87,247,87,251,87,252,87,254,87,255,87,1,88,3,88,4,88,5,88,8,88,9,88,10,88,12,88,14,88,15,88,16,88,18,88,19,88,20,88,22,88,23,88,24,88,26,88,27,88,28,88,29,88,31,88,34,88,35,88,37,88,38,88,39,88,40,88,41,88,43,88,44,88,45,88,46,88,47,88,49,88,50,88,51,88,52,88,54,88,55,88,56,88,57,88,58,88,59,88,60,88,61,88,62,88,63,88,64,88,65,88,66,88,67,88,69,88,70,88,71,88,72,88,73,88,74,88,75,88,78,88,79,88,80,88,82,88,83,88,85,88,86,88,87,88,89,88,90,88,91,88,92,88,93,88,95,88,96,88,97,88,98,88,99,88,100,88,102,88,103,88,104,88,105,88,106,88,109,88,110,88,111,88,112,88,113,88,114,88,115,88,116,88,117,88,118,88,119,88,120,88,121,88,122,88,123,88,124,88,125,88,127,88,130,88,132,88,134,88,135,88,136,88,138,88,139,88,140,88,141,88,142,88,143,88,144,88,145,88,148,88,149,88,150,88,151,88,152,88,155,88,156,88,157,88,160,88,161,88,162,88,163,88,164,88,165,88,166,88,167,88,170,88,171,88,172,88,173,88,174,88,175,88,176,88,177,88,178,88,179,88,180,88,181,88,182,88,183,88,184,88,185,88,186,88,187,88,189,88,190,88,191,88,192,88,194,88,195,88,196,88,198,88,199,88,200,88,201,88,202,88,203,88,204,88,205,88,206,88,207,88,208,88,210,88,211,88,212,88,214,88,215,88,216,88,217,88,218,88,219,88,220,88,221,88,222,88,223,88,224,88,225,88,226,88,227,88,229,88,230,88,231,88,232,88,233,88,234,88,237,88,239,88,241,88,242,88,244,88,245,88,247,88,248,88,250,88,251,88,252,88,253,88,254,88,255,88,0,89,1,89,3,89,5,89,6,89,8,89,9,89,10,89,11,89,12,89,14,89,16,89,17,89,18,89,19,89,23,89,24,89,27,89,29,89,30,89,32,89,33,89,34,89,35,89,38,89,40,89,44,89,48,89,50,89,51,89,53,89,54,89,59,89,61,89,62,89,63,89,64,89,67,89,69,89,70,89,74,89,76,89,77,89,80,89,82,89,83,89,89,89,91,89,92,89,93,89,94,89,95,89,97,89,99,89,100,89,102,89,103,89,104,89,105,89,106,89,107,89,108,89,109,89,110,89,111,89,112,89,113,89,114,89,117,89,119,89,122,89,123,89,124,89,126,89,127,89,128,89,133,89,137,89,139,89,140,89,142,89,143,89,144,89,145,89,148,89,149,89,152,89,154,89,155,89,156,89,157,89,159,89,160,89,161,89,162,89,166,89,167,89,172,89,173,89,176,89,177,89,179,89,180,89,181,89,182,89,183,89,184,89,186,89,188,89,189,89,191,89,192,89,193,89,194,89,195,89,196,89,197,89,199,89,200,89,201,89,204,89,205,89,206,89,207,89,213,89,214,89,217,89,219,89,222,89,223,89,224,89,225,89,226,89,228,89,230,89,231,89,233,89,234,89,235,89,237,89,238,89,239,89,240,89,241,89,242,89,243,89,244,89,245,89,246,89,247,89,248,89,250,89,252,89,253,89,254,89,0,90,2,90,10,90,11,90,13,90,14,90,15,90,16,90,18,90,20,90,21,90,22,90,23,90,25,90,26,90,27,90,29,90,30,90,33,90,34,90,36,90,38,90,39,90,40,90,42,90,43,90,44,90,45,90,46,90,47,90,48,90,51,90,53,90,55,90,56,90,57,90,58,90,59,90,61,90,62,90,63,90,65,90,66,90,67,90,68,90,69,90,71,90,72,90,75,90,76,90,77,90,78,90,79,90,80,90,81,90,82,90,83,90,84,90,86,90,87,90,88,90,89,90,91,90,92,90,93,90,94,90,95,90,96,90,97,90,99,90,100,90,101,90,102,90,104,90,105,90,107,90,108,90,109,90,110,90,111,90,112,90,113,90,114,90,115,90,120,90,121,90,123,90,124,90,125,90,126,90,128,90,129,90,130,90,131,90,132,90,133,90,134,90,135,90,136,90,137,90,138,90,139,90,140,90,141,90,142,90,143,90,144,90,145,90,147,90,148,90,149,90,150,90,151,90,152,90,153,90,156,90,157,90,158,90,159,90,160,90,161,90,162,90,163,90,164,90,165,90,166,90,167,90,168,90,169,90,171,90,172,90,173,90,174,90,175,90,176,90,177,90,180,90,182,90,183,90,185,90,186,90,187,90,188,90,189,90,191,90,192,90,195,90,196,90,197,90,198,90,199,90,200,90,202,90,203,90,205,90,206,90,207,90,208,90,209,90,211,90,213,90,215,90,217,90,218,90,219,90,221,90,222,90,223,90,226,90,228,90,229,90,231,90,232,90,234,90,236,90,237,90,238,90,239,90,240,90,242,90,243,90,244,90,245,90,246,90,247,90,248,90,249,90,250,90,251,90,252,90,253,90,254,90,255,90,0,91,1,91,2,91,3,91,4,91,5,91,6,91,7,91,8,91,10,91,11,91,12,91,13,91,14,91,15,91,16,91,17,91,18,91,19,91,20,91,21,91,24,91,25,91,26,91,27,91,28,91,29,91,30,91,31,91,32,91,33,91,34,91,35,91,36,91,37,91,38,91,39,91,40,91,41,91,42,91,43,91,44,91,45,91,46,91,47,91,48,91,49,91,51,91,53,91,54,91,56,91,57,91,58,91,59,91,60,91,61,91,62,91,63,91,65,91,66,91,67,91,68,91,69,91,70,91,71,91,72,91,73,91,74,91,75,91,76,91,77,91,78,91,79,91,82,91,86,91,94,91,96,91,97,91,103,91,104,91,107,91,109,91,110,91,111,91,114,91,116,91,118,91,119,91,120,91,121,91,123,91,124,91,126,91,127,91,130,91,134,91,138,91,141,91,142,91,144,91,145,91,146,91,148,91,150,91,159,91,167,91,168,91,169,91,172,91,173,91,174,91,175,91,177,91,178,91,183,91,186,91,187,91,188,91,192,91,193,91,195,91,200,91,201,91,202,91,203,91,205,91,206,91,207,91,209,91,212,91,213,91,214,91,215,91,216,91,217,91,218,91,219,91,220,91,224,91,226,91,227,91,230,91,231,91,233,91,234,91,235,91,236,91,237,91,239,91,241,91,242,91,243,91,244,91,245,91,246,91,247,91,253,91,254,91,0,92,2,92,3,92,5,92,7,92,8,92,11,92,12,92,13,92,14,92,16,92,18,92,19,92,23,92,25,92,27,92,30,92,31,92,32,92,33,92,35,92,38,92,40,92,41,92,42,92,43,92,45,92,46,92,47,92,48,92,50,92,51,92,53,92,54,92,55,92,67,92,68,92,70,92,71,92,76,92,77,92,82,92,83,92,84,92,86,92,87,92,88,92,90,92,91,92,92,92,93,92,95,92,98,92,100,92,103,92,104,92,105,92,106,92,107,92,108,92,109,92,112,92,114,92,115,92,116,92,117,92,118,92,119,92,120,92,123,92,124,92,125,92,126,92,128,92,131,92,132,92,133,92,134,92,135,92,137,92,138,92,139,92,142,92,143,92,146,92,147,92,149,92,157,92,158,92,159,92,160,92,161,92,164,92,165,92,166,92,167,92,168,92,170,92,174,92,175,92,176,92,178,92,180,92,182,92,185,92,186,92,187,92,188,92,190,92,192,92,194,92,195,92,197,92,198,92,199,92,200,92,201,92,202,92,204,92,205,92,206,92,207,92,208,92,209,92,211,92,212,92,213,92,214,92,215,92,216,92,218,92,219,92,220,92,221,92,222,92,223,92,224,92,226,92,227,92,231,92,233,92,235,92,236,92,238,92,239,92,241,92,242,92,243,92,244,92,245,92,246,92,247,92,248,92,249,92,250,92,252,92,253,92,254,92,255,92,0,93,1,93,4,93,5,93,8,93,9,93,10,93,11,93,12,93,13,93,15,93,16,93,17,93,18,93,19,93,21,93,23,93,24,93,25,93,26,93,28,93,29,93,31,93,32,93,33,93,34,93,35,93,37,93,40,93,42,93,43,93,44,93,47,93,48,93,49,93,50,93,51,93,53,93,54,93,55,93,56,93,57,93,58,93,59,93,60,93,63,93,64,93,65,93,66,93,67,93,68,93,69,93,70,93,72,93,73,93,77,93,78,93,79,93,80,93,81,93,82,93,83,93,84,93,85,93,86,93,87,93,89,93,90,93,92,93,94,93,95,93,96,93,97,93,98,93,99,93,100,93,101,93,102,93,103,93,104,93,106,93,109,93,110,93,112,93,113,93,114,93,115,93,117,93,118,93,119,93,120,93,121,93,122,93,123,93,124,93,125,93,126,93,127,93,128,93,129,93,131,93,132,93,133,93,134,93,135,93,136,93,137,93,138,93,139,93,140,93,141,93,142,93,143,93,144,93,145,93,146,93,147,93,148,93,149,93,150,93,151,93,152,93,154,93,155,93,156,93,158,93,159,93,160,93,161,93,162,93,163,93,164,93,165,93,166,93,167,93,168,93,169,93,170,93,171,93,172,93,173,93,174,93,175,93,176,93,177,93,178,93,179,93,180,93,181,93,182,93,184,93,185,93,186,93,187,93,188,93,189,93,190,93,191,93,192,93,193,93,194,93,195,93,196,93,198,93,199,93,200,93,201,93,202,93,203,93,204,93,206,93,207,93,208,93,209,93,210,93,211,93,212,93,213,93,214,93,215,93,216,93,217,93,218,93,220,93,223,93,224,93,227,93,228,93,234,93,236,93,237,93,240,93,245,93,246,93,248,93,249,93,250,93,251,93,252,93,255,93,0,94,4,94,7,94,9,94,10,94,11,94,13,94,14,94,18,94,19,94,23,94,30,94,31,94,32,94,33,94,34,94,35,94,36,94,37,94,40,94,41,94,42,94,43,94,44,94,47,94,48,94,50,94,51,94,52,94,53,94,54,94,57,94,58,94,62,94,63,94,64,94,65,94,67,94,70,94,71,94,72,94,73,94,74,94,75,94,77,94,78,94,79,94,80,94,81,94,82,94,83,94,86,94,87,94,88,94,89,94,90,94,92,94,93,94,95,94,96,94,99,94,100,94,101,94,102,94,103,94,104,94,105,94,106,94,107,94,108,94,109,94,110,94,111,94,112,94,113,94,117,94,119,94,121,94,126,94,129,94,130,94,131,94,133,94,136,94,137,94,140,94,141,94,142,94,146,94,152,94,155,94,157,94,161,94,162,94,163,94,164,94,168,94,169,94,170,94,171,94,172,94,174,94,175,94,176,94,177,94,178,94,180,94,186,94,187,94,188,94,189,94,191,94,192,94,193,94,194,94,195,94,196,94,197,94,198,94,199,94,200,94,203,94,204,94,205,94,206,94,207,94,208,94,212,94,213,94,215,94,216,94,217,94,218,94,220,94,221,94,222,94,223,94,224,94,225,94,226,94,227,94,228,94,229,94,230,94,231,94,233,94,235,94,236,94,237,94,238,94,239,94,240,94,241,94,242,94,243,94,245,94,248,94,249,94,251,94,252,94,253,94,5,95,6,95,7,95,9,95,12,95,13,95,14,95,16,95,18,95,20,95,22,95,25,95,26,95,28,95,29,95,30,95,33,95,34,95,35,95,36,95,40,95,43,95,44,95,46,95,48,95,50,95,51,95,52,95,53,95,54,95,55,95,56,95,59,95,61,95,62,95,63,95,65,95,66,95,67,95,68,95,69,95,70,95,71,95,72,95,73,95,74,95,75,95,76,95,77,95,78,95,79,95,81,95,84,95,89,95,90,95,91,95,92,95,94,95,95,95,96,95,99,95,101,95,103,95,104,95,107,95,110,95,111,95,114,95,116,95,117,95,118,95,120,95,122,95,125,95,126,95,127,95,131,95,134,95,141,95,142,95,143,95,145,95,147,95,148,95,150,95,154,95,155,95,157,95,158,95,159,95,160,95,162,95,163,95,164,95,165,95,166,95,167,95,169,95,171,95,172,95,175,95,176,95,177,95,178,95,179,95,180,95,182,95,184,95,185,95,186,95,187,95,190,95,191,95,192,95,193,95,194,95,199,95,200,95,202,95,203,95,206,95,211,95,212,95,213,95,218,95,219,95,220,95,222,95,223,95,226,95,227,95,229,95,230,95,232,95,233,95,236,95,239,95,240,95,242,95,243,95,244,95,246,95,247,95,249,95,250,95,252,95,7,96,8,96,9,96,11,96,12,96,16,96,17,96,19,96,23,96,24,96,26,96,30,96,31,96,34,96,35,96,36,96,44,96,45,96,46,96,48,96,49,96,50,96,51,96,52,96,54,96,55,96,56,96,57,96,58,96,61,96,62,96,64,96,68,96,69,96,70,96,71,96,72,96,73,96,74,96,76,96,78,96,79,96,81,96,83,96,84,96,86,96,87,96,88,96,91,96,92,96,94,96,95,96,96,96,97,96,101,96,102,96,110,96,113,96,114,96,116,96,117,96,119,96,126,96,128,96,129,96,130,96,133,96,134,96,135,96,136,96,138,96,139,96,142,96,143,96,144,96,145,96,147,96,149,96,151,96,152,96,153,96,156,96,158,96,161,96,162,96,164,96,165,96,167,96,169,96,170,96,174,96,176,96,179,96,181,96,182,96,183,96,185,96,186,96,189,96,190,96,191,96,192,96,193,96,194,96,195,96,196,96,199,96,200,96,201,96,204,96,205,96,206,96,207,96,208,96,210,96,211,96,212,96,214,96,215,96,217,96,219,96,222,96,225,96,226,96,227,96,228,96,229,96,234,96,241,96,242,96,245,96,247,96,248,96,251,96,252,96,253,96,254,96,255,96,2,97,3,97,4,97,5,97,7,97,10,97,11,97,12,97,16,97,17,97,18,97,19,97,20,97,22,97,23,97,24,97,25,97,27,97,28,97,29,97,30,97,33,97,34,97,37,97,40,97,41,97,42,97,44,97,45,97,46,97,47,97,48,97,49,97,50,97,51,97,52,97,53,97,54,97,55,97,56,97,57,97,58,97,59,97,60,97,61,97,62,97,64,97,65,97,66,97,67,97,68,97,69,97,70,97,71,97,73,97,75,97,77,97,79,97,80,97,82,97,83,97,84,97,86,97,87,97,88,97,89,97,90,97,91,97,92,97,94,97,95,97,96,97,97,97,99,97,100,97,101,97,102,97,105,97,106,97,107,97,108,97,109,97,110,97,111,97,113,97,114,97,115,97,116,97,118,97,120,97,121,97,122,97,123,97,124,97,125,97,126,97,127,97,128,97,129,97,130,97,131,97,132,97,133,97,134,97,135,97,136,97,137,97,138,97,140,97,141,97,143,97,144,97,145,97,146,97,147,97,149,97,150,97,151,97,152,97,153,97,154,97,155,97,156,97,158,97,159,97,160,97,161,97,162,97,163,97,164,97,165,97,166,97,170,97,171,97,173,97,174,97,175,97,176,97,177,97,178,97,179,97,180,97,181,97,182,97,184,97,185,97,186,97,187,97,188,97,189,97,191,97,192,97,193,97,195,97,196,97,197,97,198,97,199,97,201,97,204,97,205,97,206,97,207,97,208,97,211,97,213,97,214,97,215,97,216,97,217,97,218,97,219,97,220,97,221,97,222,97,223,97,224,97,225,97,226,97,227,97,228,97,229,97,231,97,232,97,233,97,234,97,235,97,236,97,237,97,238,97,239,97,240,97,241,97,242,97,243,97,244,97,246,97,247,97,248,97,249,97,250,97,251,97,252,97,253,97,254,97,0,98,1,98,2,98,3,98,4,98,5,98,7,98,9,98,19,98,20,98,25,98,28,98,29,98,30,98,32,98,35,98,38,98,39,98,40,98,41,98,43,98,45,98,47,98,48,98,49,98,50,98,53,98,54,98,56,98,57,98,58,98,59,98,60,98,66,98,68,98,69,98,70,98,74,98,79,98,80,98,85,98,86,98,87,98,89,98,90,98,92,98,93,98,94,98,95,98,96,98,97,98,98,98,100,98,101,98,104,98,113,98,114,98,116,98,117,98,119,98,120,98,122,98,123,98,125,98,129,98,130,98,131,98,133,98,134,98,135,98,136,98,139,98,140,98,141,98,142,98,143,98,144,98,148,98,153,98,156,98,157,98,158,98,163,98,166,98,167,98,169,98,170,98,173,98,174,98,175,98,176,98,178,98,179,98,180,98,182,98,183,98,184,98,186,98,190,98,192,98,193,98,195,98,203,98,207,98,209,98,213,98,221,98,222,98,224,98,225,98,228,98,234,98,235,98,240,98,242,98,245,98,248,98,249,98,250,98,251,98,0,99,3,99,4,99,5,99,6,99,10,99,11,99,12,99,13,99,15,99,16,99,18,99,19,99,20,99,21,99,23,99,24,99,25,99,28,99,38,99,39,99,41,99,44,99,45,99,46,99,48,99,49,99,51,99,52,99,53,99,54,99,55,99,56,99,59,99,60,99,62,99,63,99,64,99,65,99,68,99,71,99,72,99,74,99,81,99,82,99,83,99,84,99,86,99,87,99,88,99,89,99,90,99,91,99,92,99,93,99,96,99,100,99,101,99,102,99,104,99,106,99,107,99,108,99,111,99,112,99,114,99,115,99,116,99,117,99,120,99,121,99,124,99,125,99,126,99,127,99,129,99,131,99,132,99,133,99,134,99,139,99,141,99,145,99,147,99,148,99,149,99,151,99,153,99,154,99,155,99,156,99,157,99,158,99,159,99,161,99,164,99,166,99,171,99,175,99,177,99,178,99,181,99,182,99,185,99,187,99,189,99,191,99,192,99,193,99,194,99,195,99,197,99,199,99,200,99,202,99,203,99,204,99,209,99,211,99,212,99,213,99,215,99,216,99,217,99,218,99,219,99,220,99,221,99,223,99,226,99,228,99,229,99,230,99,231,99,232,99,235,99,236,99,238,99,239,99,240,99,241,99,243,99,245,99,247,99,249,99,250,99,251,99,252,99,254,99,3,100,4,100,6,100,7,100,8,100,9,100,10,100,13,100,14,100,17,100,18,100,21,100,22,100,23,100,24,100,25,100,26,100,29,100,31,100,34,100,35,100,36,100,37,100,39,100,40,100,41,100,43,100,46,100,47,100,48,100,49,100,50,100,51,100,53,100,54,100,55,100,56,100,57,100,59,100,60,100,62,100,64,100,66,100,67,100,73,100,75,100,76,100,77,100,78,100,79,100,80,100,81,100,83,100,85,100,86,100,87,100,89,100,90,100,91,100,92,100,93,100,95,100,96,100,97,100,98,100,99,100,100,100,101,100,102,100,104,100,106,100,107,100,108,100,110,100,111,100,112,100,113,100,114,100,115,100,116,100,117,100,118,100,119,100,123,100,124,100,125,100,126,100,127,100,128,100,129,100,131,100,134,100,136,100,137,100,138,100,139,100,140,100,141,100,142,100,143,100,144,100,147,100,148,100,151,100,152,100,154,100,155,100,156,100,157,100,159,100,160,100,161,100,162,100,163,100,165,100,166,100,167,100,168,100,170,100,171,100,175,100,177,100,178,100,179,100,180,100,182,100,185,100,187,100,189,100,190,100,191,100,193,100,195,100,196,100,198,100,199,100,200,100,201,100,202,100,203,100,204,100,207,100,209,100,211,100,212,100,213,100,214,100,217,100,218,100,219,100,220,100,221,100,223,100,224,100,225,100,227,100,229,100,231,100,232,100,233,100,234,100,235,100,236,100,237,100,238,100,239,100,240,100,241,100,242,100,243,100,244,100,245,100,246,100,247,100,248,100,249,100,250,100,251,100,252,100,253,100,254,100,255,100,1,101,2,101,3,101,4,101,5,101,6,101,7,101,8,101,10,101,11,101,12,101,13,101,14,101,15,101,16,101,17,101,19,101,20,101,21,101,22,101,23,101,25,101,26,101,27,101,28,101,29,101,30,101,31,101,32,101,33,101,34,101,35,101,36,101,38,101,39,101,40,101,41,101,42,101,44,101,45,101,48,101,49,101,50,101,51,101,55,101,58,101,60,101,61,101,64,101,65,101,66,101,67,101,68,101,70,101,71,101,74,101,75,101,77,101,78,101,80,101,82,101,83,101,84,101,87,101,88,101,90,101,92,101,95,101,96,101,97,101,100,101,101,101,103,101,104,101,105,101,106,101,109,101,110,101,111,101,113,101,115,101,117,101,118,101,120,101,121,101,122,101,123,101,124,101,125,101,126,101,127,101,128,101,129,101,130,101,131,101,132,101,133,101,134,101,136,101,137,101,138,101,141,101,142,101,143,101,146,101,148,101,149,101,150,101,152,101,154,101,157,101],"i8",ALLOC_NONE,Runtime.GLOBAL_BASE+220348),
	allocate([158,101,160,101,162,101,163,101,166,101,168,101,170,101,172,101,174,101,177,101,178,101,179,101,180,101,181,101,182,101,183,101,184,101,186,101,187,101,190,101,191,101,192,101,194,101,199,101,200,101,201,101,202,101,205,101,208,101,209,101,211,101,212,101,213,101,216,101,217,101,218,101,219,101,220,101,221,101,222,101,223,101,225,101,227,101,228,101,234,101,235,101,242,101,243,101,244,101,245,101,248,101,249,101,251,101,252,101,253,101,254,101,255,101,1,102,4,102,5,102,7,102,8,102,9,102,11,102,13,102,16,102,17,102,18,102,22,102,23,102,24,102,26,102,27,102,28,102,30,102,33,102,34,102,35,102,36,102,38,102,41,102,42,102,43,102,44,102,46,102,48,102,50,102,51,102,55,102,56,102,57,102,58,102,59,102,61,102,63,102,64,102,66,102,68,102,69,102,70,102,71,102,72,102,73,102,74,102,77,102,78,102,80,102,81,102,88,102,89,102,91,102,92,102,93,102,94,102,96,102,98,102,99,102,101,102,103,102,105,102,106,102,107,102,108,102,109,102,113,102,114,102,115,102,117,102,120,102,121,102,123,102,124,102,125,102,127,102,128,102,129,102,131,102,133,102,134,102,136,102,137,102,138,102,139,102,141,102,142,102,143,102,144,102,146,102,147,102,148,102,149,102,152,102,153,102,154,102,155,102,156,102,158,102,159,102,160,102,161,102,162,102,163,102,164,102,165,102,166,102,169,102,170,102,171,102,172,102,173,102,175,102,176,102,177,102,178,102,179,102,181,102,182,102,183,102,184,102,186,102,187,102,188,102,189,102,191,102,192,102,193,102,194,102,195,102,196,102,197,102,198,102,199,102,200,102,201,102,202,102,203,102,204,102,205,102,206,102,207,102,208,102,209,102,210,102,211,102,212,102,213,102,214,102,215,102,216,102,218,102,222,102,223,102,224,102,225,102,226,102,227,102,228,102,229,102,231,102,232,102,234,102,235,102,236,102,237,102,238,102,239,102,241,102,245,102,246,102,248,102,250,102,251,102,253,102,1,103,2,103,3,103,4,103,5,103,6,103,7,103,12,103,14,103,15,103,17,103,18,103,19,103,22,103,24,103,25,103,26,103,28,103,30,103,32,103,33,103,34,103,35,103,36,103,37,103,39,103,41,103,46,103,48,103,50,103,51,103,54,103,55,103,56,103,57,103,59,103,60,103,62,103,63,103,65,103,68,103,69,103,71,103,74,103,75,103,77,103,82,103,84,103,85,103,87,103,88,103,89,103,90,103,91,103,93,103,98,103,99,103,100,103,102,103,103,103,107,103,108,103,110,103,113,103,116,103,118,103,120,103,121,103,122,103,123,103,125,103,128,103,130,103,131,103,133,103,134,103,136,103,138,103,140,103,141,103,142,103,143,103,145,103,146,103,147,103,148,103,150,103,153,103,155,103,159,103,160,103,161,103,164,103,166,103,169,103,172,103,174,103,177,103,178,103,180,103,185,103,186,103,187,103,188,103,189,103,190,103,191,103,192,103,194,103,197,103,198,103,199,103,200,103,201,103,202,103,203,103,204,103,205,103,206,103,213,103,214,103,215,103,219,103,223,103,225,103,227,103,228,103,230,103,231,103,232,103,234,103,235,103,237,103,238,103,242,103,245,103,246,103,247,103,248,103,249,103,250,103,251,103,252,103,254,103,1,104,2,104,3,104,4,104,6,104,13,104,16,104,18,104,20,104,21,104,24,104,25,104,26,104,27,104,28,104,30,104,31,104,32,104,34,104,35,104,36,104,37,104,38,104,39,104,40,104,43,104,44,104,45,104,46,104,47,104,48,104,49,104,52,104,53,104,54,104,58,104,59,104,63,104,71,104,75,104,77,104,79,104,82,104,86,104,87,104,88,104,89,104,90,104,91,104,92,104,93,104,94,104,95,104,106,104,108,104,109,104,110,104,111,104,112,104,113,104,114,104,115,104,117,104,120,104,121,104,122,104,123,104,124,104,125,104,126,104,127,104,128,104,130,104,132,104,135,104,136,104,137,104,138,104,139,104,140,104,141,104,142,104,144,104,145,104,146,104,148,104,149,104,150,104,152,104,153,104,154,104,155,104,156,104,157,104,158,104,159,104,160,104,161,104,163,104,164,104,165,104,169,104,170,104,171,104,172,104,174,104,177,104,178,104,180,104,182,104,183,104,184,104,185,104,186,104,187,104,188,104,189,104,190,104,191,104,193,104,195,104,196,104,197,104,198,104,199,104,200,104,202,104,204,104,206,104,207,104,208,104,209,104,211,104,212,104,214,104,215,104,217,104,219,104,220,104,221,104,222,104,223,104,225,104,226,104,228,104,229,104,230,104,231,104,232,104,233,104,234,104,235,104,236,104,237,104,239,104,242,104,243,104,244,104,246,104,247,104,248,104,251,104,253,104,254,104,255,104,0,105,2,105,3,105,4,105,6,105,7,105,8,105,9,105,10,105,12,105,15,105,17,105,19,105,20,105,21,105,22,105,23,105,24,105,25,105,26,105,27,105,28,105,29,105,30,105,33,105,34,105,35,105,37,105,38,105,39,105,40,105,41,105,42,105,43,105,44,105,46,105,47,105,49,105,50,105,51,105,53,105,54,105,55,105,56,105,58,105,59,105,60,105,62,105,64,105,65,105,67,105,68,105,69,105,70,105,71,105,72,105,73,105,74,105,75,105,76,105,77,105,78,105,79,105,80,105,81,105,82,105,83,105,85,105,86,105,88,105,89,105,91,105,92,105,95,105,97,105,98,105,100,105,101,105,103,105,104,105,105,105,106,105,108,105,109,105,111,105,112,105,114,105,115,105,116,105,117,105,118,105,122,105,123,105,125,105,126,105,127,105,129,105,131,105,133,105,138,105,139,105,140,105,142,105,143,105,144,105,145,105,146,105,147,105,150,105,151,105,153,105,154,105,157,105,158,105,159,105,160,105,161,105,162,105,163,105,164,105,165,105,166,105,169,105,170,105,172,105,174,105,175,105,176,105,178,105,179,105,181,105,182,105,184,105,185,105,186,105,188,105,189,105,190,105,191,105,192,105,194,105,195,105,196,105,197,105,198,105,199,105,200,105,201,105,203,105,205,105,207,105,209,105,210,105,211,105,213,105,214,105,215,105,216,105,217,105,218,105,220,105,221,105,222,105,225,105,226,105,227,105,228,105,229,105,230,105,231,105,232,105,233,105,234,105,235,105,236,105,238,105,239,105,240,105,241,105,243,105,244,105,245,105,246,105,247,105,248,105,249,105,250,105,251,105,252,105,254,105,0,106,1,106,2,106,3,106,4,106,5,106,6,106,7,106,8,106,9,106,11,106,12,106,13,106,14,106,15,106,16,106,17,106,18,106,19,106,20,106,21,106,22,106,25,106,26,106,27,106,28,106,29,106,30,106,32,106,34,106,35,106,36,106,37,106,38,106,39,106,41,106,43,106,44,106,45,106,46,106,48,106,50,106,51,106,52,106,54,106,55,106,56,106,57,106,58,106,59,106,60,106,63,106,64,106,65,106,66,106,67,106,69,106,70,106,72,106,73,106,74,106,75,106,76,106,77,106,78,106,79,106,81,106,82,106,83,106,84,106,85,106,86,106,87,106,90,106,92,106,93,106,94,106,95,106,96,106,98,106,99,106,100,106,102,106,103,106,104,106,105,106,106,106,107,106,108,106,109,106,110,106,111,106,112,106,114,106,115,106,116,106,117,106,118,106,119,106,120,106,122,106,123,106,125,106,126,106,127,106,129,106,130,106,131,106,133,106,134,106,135,106,136,106,137,106,138,106,139,106,140,106,141,106,143,106,146,106,147,106,148,106,149,106,150,106,152,106,153,106,154,106,155,106,156,106,157,106,158,106,159,106,161,106,162,106,163,106,164,106,165,106,166,106,167,106,168,106,170,106,173,106,174,106,175,106,176,106,177,106,178,106,179,106,180,106,181,106,182,106,183,106,184,106,185,106,186,106,187,106,188,106,189,106,190,106,191,106,192,106,193,106,194,106,195,106,196,106,197,106,198,106,199,106,200,106,201,106,202,106,203,106,204,106,205,106,206,106,207,106,208,106,209,106,210,106,211,106,212,106,213,106,214,106,215,106,216,106,217,106,218,106,219,106,220,106,221,106,222,106,223,106,224,106,225,106,226,106,227,106,228,106,229,106,230,106,231,106,232,106,233,106,234,106,235,106,236,106,237,106,238,106,239,106,240,106,241,106,242,106,243,106,244,106,245,106,246,106,247,106,248,106,249,106,250,106,251,106,252,106,253,106,254,106,255,106,0,107,1,107,2,107,3,107,4,107,5,107,6,107,7,107,8,107,9,107,10,107,11,107,12,107,13,107,14,107,15,107,16,107,17,107,18,107,19,107,20,107,21,107,22,107,23,107,24,107,25,107,26,107,27,107,28,107,29,107,30,107,31,107,37,107,38,107,40,107,41,107,42,107,43,107,44,107,45,107,46,107,47,107,48,107,49,107,51,107,52,107,53,107,54,107,56,107,59,107,60,107,61,107,63,107,64,107,65,107,66,107,68,107,69,107,72,107,74,107,75,107,77,107,78,107,79,107,80,107,81,107,82,107,83,107,84,107,85,107,86,107,87,107,88,107,90,107,91,107,92,107,93,107,94,107,95,107,96,107,97,107,104,107,105,107,107,107,108,107,109,107,110,107,111,107,112,107,113,107,114,107,115,107,116,107,117,107,118,107,119,107,120,107,122,107,125,107,126,107,127,107,128,107,133,107,136,107,140,107,142,107,143,107,144,107,145,107,148,107,149,107,151,107,152,107,153,107,156,107,157,107,158,107,159,107,160,107,162,107,163,107,164,107,165,107,166,107,167,107,168,107,169,107,171,107,172,107,173,107,174,107,175,107,176,107,177,107,178,107,182,107,184,107,185,107,186,107,187,107,188,107,189,107,190,107,192,107,195,107,196,107,198,107,199,107,200,107,201,107,202,107,204,107,206,107,208,107,209,107,216,107,218,107,220,107,221,107,222,107,223,107,224,107,226,107,227,107,228,107,229,107,230,107,231,107,232,107,233,107,236,107,237,107,238,107,240,107,241,107,242,107,244,107,246,107,247,107,248,107,250,107,251,107,252,107,254,107,255,107,0,108,1,108,2,108,3,108,4,108,8,108,9,108,10,108,11,108,12,108,14,108,18,108,23,108,28,108,29,108,30,108,32,108,35,108,37,108,43,108,44,108,45,108,49,108,51,108,54,108,55,108,57,108,58,108,59,108,60,108,62,108,63,108,67,108,68,108,69,108,72,108,75,108,76,108,77,108,78,108,79,108,81,108,82,108,83,108,86,108,88,108,89,108,90,108,98,108,99,108,101,108,102,108,103,108,107,108,108,108,109,108,110,108,111,108,113,108,115,108,117,108,119,108,120,108,122,108,123,108,124,108,127,108,128,108,132,108,135,108,138,108,139,108,141,108,142,108,145,108,146,108,149,108,150,108,151,108,152,108,154,108,156,108,157,108,158,108,160,108,162,108,168,108,172,108,175,108,176,108,180,108,181,108,182,108,183,108,186,108,192,108,193,108,194,108,195,108,198,108,199,108,200,108,203,108,205,108,206,108,207,108,209,108,210,108,216,108,217,108,218,108,220,108,221,108,223,108,228,108,230,108,231,108,233,108,236,108,237,108,242,108,244,108,249,108,255,108,0,109,2,109,3,109,5,109,6,109,8,109,9,109,10,109,13,109,15,109,16,109,17,109,19,109,20,109,21,109,22,109,24,109,28,109,29,109,31,109,32,109,33,109,34,109,35,109,36,109,38,109,40,109,41,109,44,109,45,109,47,109,48,109,52,109,54,109,55,109,56,109,58,109,63,109,64,109,66,109,68,109,73,109,76,109,80,109,85,109,86,109,87,109,88,109,91,109,93,109,95,109,97,109,98,109,100,109,101,109,103,109,104,109,107,109,108,109,109,109,112,109,113,109,114,109,115,109,117,109,118,109,121,109,122,109,123,109,125,109,126,109,127,109,128,109,129,109,131,109,132,109,134,109,135,109,138,109,139,109,141,109,143,109,144,109,146,109,150,109,151,109,152,109,153,109,154,109,156,109,162,109,165,109,172,109,173,109,176,109,177,109,179,109,180,109,182,109,183,109,185,109,186,109,187,109,188,109,189,109,190,109,193,109,194,109,195,109,200,109,201,109,202,109,205,109,206,109,207,109,208,109,210,109,211,109,212,109,213,109,215,109,218,109,219,109,220,109,223,109,226,109,227,109,229,109,231,109,232,109,233,109,234,109,237,109,239,109,240,109,242,109,244,109,245,109,246,109,248,109,250,109,253,109,254,109,255,109,0,110,1,110,2,110,3,110,4,110,6,110,7,110,8,110,9,110,11,110,15,110,18,110,19,110,21,110,24,110,25,110,27,110,28,110,30,110,31,110,34,110,38,110,39,110,40,110,42,110,44,110,46,110,48,110,49,110,51,110,53,110,54,110,55,110,57,110,59,110,60,110,61,110,62,110,63,110,64,110,65,110,66,110,69,110,70,110,71,110,72,110,73,110,74,110,75,110,76,110,79,110,80,110,81,110,82,110,85,110,87,110,89,110,90,110,92,110,93,110,94,110,96,110,97,110,98,110,99,110,100,110,101,110,102,110,103,110,104,110,105,110,106,110,108,110,109,110,111,110,112,110,113,110,114,110,115,110,116,110,117,110,118,110,119,110,120,110,121,110,122,110,123,110,124,110,125,110,128,110,129,110,130,110,132,110,135,110,136,110,138,110,139,110,140,110,141,110,142,110,145,110,146,110,147,110,148,110,149,110,150,110,151,110,153,110,154,110,155,110,157,110,158,110,160,110,161,110,163,110,164,110,166,110,168,110,169,110,171,110,172,110,173,110,174,110,176,110,179,110,181,110,184,110,185,110,188,110,190,110,191,110,192,110,195,110,196,110,197,110,198,110,200,110,201,110,202,110,204,110,205,110,206,110,208,110,210,110,214,110,216,110,217,110,219,110,220,110,221,110,227,110,231,110,234,110,235,110,236,110,237,110,238,110,239,110,240,110,241,110,242,110,243,110,245,110,246,110,247,110,248,110,250,110,251,110,252,110,253,110,254,110,255,110,0,111,1,111,3,111,4,111,5,111,7,111,8,111,10,111,11,111,12,111,13,111,14,111,16,111,17,111,18,111,22,111,23,111,24,111,25,111,26,111,27,111,28,111,29,111,30,111,31,111,33,111,34,111,35,111,37,111,38,111,39,111,40,111,44,111,46,111,48,111,50,111,52,111,53,111,55,111,56,111,57,111,58,111,59,111,60,111,61,111,63,111,64,111,65,111,66,111,67,111,68,111,69,111,72,111,73,111,74,111,76,111,78,111,79,111,80,111,81,111,82,111,83,111,84,111,85,111,86,111,87,111,89,111,90,111,91,111,93,111,95,111,96,111,97,111,99,111,100,111,101,111,103,111,104,111,105,111,106,111,107,111,108,111,111,111,112,111,113,111,115,111,117,111,118,111,119,111,121,111,123,111,125,111,126,111,127,111,128,111,129,111,130,111,131,111,133,111,134,111,135,111,138,111,139,111,143,111,144,111,145,111,146,111,147,111,148,111,149,111,150,111,151,111,152,111,153,111,154,111,155,111,157,111,158,111,159,111,160,111,162,111,163,111,164,111,165,111,166,111,168,111,169,111,170,111,171,111,172,111,173,111,174,111,175,111,176,111,177,111,178,111,180,111,181,111,183,111,184,111,186,111,187,111,188,111,189,111,190,111,191,111,193,111,195,111,196,111,197,111,198,111,199,111,200,111,202,111,203,111,204,111,205,111,206,111,207,111,208,111,211,111,212,111,213,111,214,111,215,111,216,111,217,111,218,111,219,111,220,111,221,111,223,111,226,111,227,111,228,111,229,111,230,111,231,111,232,111,233,111,234,111,235,111,236,111,237,111,240,111,241,111,242,111,243,111,244,111,245,111,246,111,247,111,248,111,249,111,250,111,251,111,252,111,253,111,254,111,255,111,0,112,1,112,2,112,3,112,4,112,5,112,6,112,7,112,8,112,9,112,10,112,11,112,12,112,13,112,14,112,15,112,16,112,18,112,19,112,20,112,21,112,22,112,23,112,24,112,25,112,28,112,29,112,30,112,31,112,32,112,33,112,34,112,36,112,37,112,38,112,39,112,40,112,41,112,42,112,43,112,44,112,45,112,46,112,47,112,48,112,49,112,50,112,51,112,52,112,54,112,55,112,56,112,58,112,59,112,60,112,61,112,62,112,63,112,64,112,65,112,66,112,67,112,68,112,69,112,70,112,71,112,72,112,73,112,74,112,75,112,77,112,78,112,80,112,81,112,82,112,83,112,84,112,85,112,86,112,87,112,88,112,89,112,90,112,91,112,92,112,93,112,95,112,96,112,97,112,98,112,99,112,100,112,101,112,102,112,103,112,104,112,105,112,106,112,110,112,113,112,114,112,115,112,116,112,119,112,121,112,122,112,123,112,125,112,129,112,130,112,131,112,132,112,134,112,135,112,136,112,139,112,140,112,141,112,143,112,144,112,145,112,147,112,151,112,152,112,154,112,155,112,158,112,159,112,160,112,161,112,162,112,163,112,164,112,165,112,166,112,167,112,168,112,169,112,170,112,176,112,178,112,180,112,181,112,182,112,186,112,190,112,191,112,196,112,197,112,198,112,199,112,201,112,203,112,204,112,205,112,206,112,207,112,208,112,209,112,210,112,211,112,212,112,213,112,214,112,215,112,218,112,220,112,221,112,222,112,224,112,225,112,226,112,227,112,229,112,234,112,238,112,240,112,241,112,242,112,243,112,244,112,245,112,246,112,248,112,250,112,251,112,252,112,254,112,255,112,0,113,1,113,2,113,3,113,4,113,5,113,6,113,7,113,8,113,11,113,12,113,13,113,14,113,15,113,17,113,18,113,20,113,23,113,27,113,28,113,29,113,30,113,31,113,32,113,33,113,34,113,35,113,36,113,37,113,39,113,40,113,41,113,42,113,43,113,44,113,45,113,46,113,50,113,51,113,52,113,53,113,55,113,56,113,57,113,58,113,59,113,60,113,61,113,62,113,63,113,64,113,65,113,66,113,67,113,68,113,70,113,71,113,72,113,73,113,75,113,77,113,79,113,80,113,81,113,82,113,83,113,84,113,85,113,86,113,87,113,88,113,89,113,90,113,91,113,93,113,95,113,96,113,97,113,98,113,99,113,101,113,105,113,106,113,107,113,108,113,109,113,111,113,112,113,113,113,116,113,117,113,118,113,119,113,121,113,123,113,124,113,126,113,127,113,128,113,129,113,130,113,131,113,133,113,134,113,135,113,136,113,137,113,139,113,140,113,141,113,142,113,144,113,145,113,146,113,147,113,149,113,150,113,151,113,154,113,155,113,156,113,157,113,158,113,161,113,162,113,163,113,164,113,165,113,166,113,167,113,169,113,170,113,171,113,173,113,174,113,175,113,176,113,177,113,178,113,180,113,182,113,183,113,184,113,186,113,187,113,188,113,189,113,190,113,191,113,192,113,193,113,194,113,196,113,197,113,198,113,199,113,200,113,201,113,202,113,203,113,204,113,205,113,207,113,208,113,209,113,210,113,211,113,214,113,215,113,216,113,217,113,218,113,219,113,220,113,221,113,222,113,223,113,225,113,226,113,227,113,228,113,230,113,232,113,233,113,234,113,235,113,236,113,237,113,239,113,240,113,241,113,242,113,243,113,244,113,245,113,246,113,247,113,248,113,250,113,251,113,252,113,253,113,254,113,255,113,0,114,1,114,2,114,3,114,4,114,5,114,7,114,8,114,9,114,10,114,11,114,12,114,13,114,14,114,15,114,16,114,17,114,18,114,19,114,20,114,21,114,22,114,23,114,24,114,25,114,26,114,27,114,28,114,30,114,31,114,32,114,33,114,34,114,35,114,36,114,37,114,38,114,39,114,41,114,43,114,45,114,46,114,47,114,50,114,51,114,52,114,58,114,60,114,62,114,64,114,65,114,66,114,67,114,68,114,69,114,70,114,73,114,74,114,75,114,78,114,79,114,80,114,81,114,83,114,84,114,85,114,87,114,88,114,90,114,92,114,94,114,96,114,99,114,100,114,101,114,104,114,106,114,107,114,108,114,109,114,112,114,113,114,115,114,116,114,118,114,119,114,120,114,123,114,124,114,125,114,130,114,131,114,133,114,134,114,135,114,136,114,137,114,140,114,142,114,144,114,145,114,147,114,148,114,149,114,150,114,151,114,152,114,153,114,154,114,155,114,156,114,157,114,158,114,160,114,161,114,162,114,163,114,164,114,165,114,166,114,167,114,168,114,169,114,170,114,171,114,174,114,177,114,178,114,179,114,181,114,186,114,187,114,188,114,189,114,190,114,191,114,192,114,197,114,198,114,199,114,201,114,202,114,203,114,204,114,207,114,209,114,211,114,212,114,213,114,214,114,216,114,218,114,219,114,198,228,199,228,200,228,201,228,202,228,203,228,204,228,205,228,206,228,207,228,208,228,209,228,210,228,211,228,212,228,213,228,214,228,215,228,216,228,217,228,218,228,219,228,220,228,221,228,222,228,223,228,224,228,225,228,226,228,227,228,228,228,229,228,230,228,231,228,232,228,233,228,234,228,235,228,236,228,237,228,238,228,239,228,240,228,241,228,242,228,243,228,244,228,245,228,246,228,247,228,248,228,249,228,250,228,251,228,252,228,253,228,254,228,255,228,0,229,1,229,2,229,3,229,4,229,5,229,6,229,7,229,8,229,9,229,10,229,11,229,12,229,13,229,14,229,15,229,16,229,17,229,18,229,19,229,20,229,21,229,22,229,23,229,24,229,25,229,26,229,27,229,28,229,29,229,30,229,31,229,32,229,33,229,34,229,35,229,36,229,37,229,0,48,1,48,2,48,183,0,201,2,199,2,168,0,3,48,5,48,20,32,94,255,22,32,38,32,24,32,25,32,28,32,29,32,20,48,21,48,8,48,9,48,10,48,11,48,12,48,13,48,14,48,15,48,22,48,23,48,16,48,17,48,177,0,215,0,247,0,54,34,39,34,40,34,17,34,15,34,42,34,41,34,8,34,55,34,26,34,165,34,37,34,32,34,18,35,153,34,43,34,46,34,97,34,76,34,72,34,61,34,29,34,96,34,110,34,111,34,100,34,101,34,30,34,53,34,52,34,66,38,64,38,176,0,50,32,51,32,3,33,4,255,164,0,224,255,225,255,48,32,167,0,22,33,6,38,5,38,203,37,207,37,206,37,199,37,198,37,161,37,160,37,179,37,178,37,59,32,146,33,144,33,145,33,147,33,19,48,38,229,39,229,40,229,41,229,42,229,43,229,44,229,45,229,46,229,47,229,48,229,49,229,50,229,51,229,52,229,53,229,54,229,55,229,56,229,57,229,58,229,59,229,60,229,61,229,62,229,63,229,64,229,65,229,66,229,67,229,68,229,69,229,70,229,71,229,72,229,73,229,74,229,75,229,76,229,77,229,78,229,79,229,80,229,81,229,82,229,83,229,84,229,85,229,86,229,87,229,88,229,89,229,90,229,91,229,92,229,93,229,94,229,95,229,96,229,97,229,98,229,99,229,100,229,101,229,102,229,103,229,104,229,105,229,106,229,107,229,108,229,109,229,110,229,111,229,112,229,113,229,114,229,115,229,116,229,117,229,118,229,119,229,120,229,121,229,122,229,123,229,124,229,125,229,126,229,127,229,128,229,129,229,130,229,131,229,132,229,133,229,112,33,113,33,114,33,115,33,116,33,117,33,118,33,119,33,120,33,121,33,102,231,103,231,104,231,105,231,106,231,107,231,136,36,137,36,138,36,139,36,140,36,141,36,142,36,143,36,144,36,145,36,146,36,147,36,148,36,149,36,150,36,151,36,152,36,153,36,154,36,155,36,116,36,117,36,118,36,119,36,120,36,121,36,122,36,123,36,124,36,125,36,126,36,127,36,128,36,129,36,130,36,131,36,132,36,133,36,134,36,135,36,96,36,97,36,98,36,99,36,100,36,101,36,102,36,103,36,104,36,105,36,172,32,109,231,32,50,33,50,34,50,35,50,36,50,37,50,38,50,39,50,40,50,41,50,110,231,111,231,96,33,97,33,98,33,99,33,100,33,101,33,102,33,103,33,104,33,105,33,106,33,107,33,112,231,113,231,134,229,135,229,136,229,137,229,138,229,139,229,140,229,141,229,142,229,143,229,144,229,145,229,146,229,147,229,148,229,149,229,150,229,151,229,152,229,153,229,154,229,155,229,156,229,157,229,158,229,159,229,160,229,161,229,162,229,163,229,164,229,165,229,166,229,167,229,168,229,169,229,170,229,171,229,172,229,173,229,174,229,175,229,176,229,177,229,178,229,179,229,180,229,181,229,182,229,183,229,184,229,185,229,186,229,187,229,188,229,189,229,190,229,191,229,192,229,193,229,194,229,195,229,196,229,197,229,198,229,199,229,200,229,201,229,202,229,203,229,204,229,205,229,206,229,207,229,208,229,209,229,210,229,211,229,212,229,213,229,214,229,215,229,216,229,217,229,218,229,219,229,220,229,221,229,222,229,223,229,224,229,225,229,226,229,227,229,228,229,229,229,1,255,2,255,3,255,229,255,5,255,6,255,7,255,8,255,9,255,10,255,11,255,12,255,13,255,14,255,15,255,16,255,17,255,18,255,19,255,20,255,21,255,22,255,23,255,24,255,25,255,26,255,27,255,28,255,29,255,30,255,31,255,32,255,33,255,34,255,35,255,36,255,37,255,38,255,39,255,40,255,41,255,42,255,43,255,44,255,45,255,46,255,47,255,48,255,49,255,50,255,51,255,52,255,53,255,54,255,55,255,56,255,57,255,58,255,59,255,60,255,61,255,62,255,63,255,64,255,65,255,66,255,67,255,68,255,69,255,70,255,71,255,72,255,73,255,74,255,75,255,76,255,77,255,78,255,79,255,80,255,81,255,82,255,83,255,84,255,85,255,86,255,87,255,88,255,89,255,90,255,91,255,92,255,93,255,227,255,230,229,231,229,232,229,233,229,234,229,235,229,236,229,237,229,238,229,239,229,240,229,241,229,242,229,243,229,244,229,245,229,246,229,247,229,248,229,249,229,250,229,251,229,252,229,253,229,254,229,255,229,0,230,1,230,2,230,3,230,4,230,5,230,6,230,7,230,8,230,9,230,10,230,11,230,12,230,13,230,14,230,15,230,16,230,17,230,18,230,19,230,20,230,21,230,22,230,23,230,24,230,25,230,26,230,27,230,28,230,29,230,30,230,31,230,32,230,33,230,34,230,35,230,36,230,37,230,38,230,39,230,40,230,41,230,42,230,43,230,44,230,45,230,46,230,47,230,48,230,49,230,50,230,51,230,52,230,53,230,54,230,55,230,56,230,57,230,58,230,59,230,60,230,61,230,62,230,63,230,64,230,65,230,66,230,67,230,68,230,69,230,65,48,66,48,67,48,68,48,69,48,70,48,71,48,72,48,73,48,74,48,75,48,76,48,77,48,78,48,79,48,80,48,81,48,82,48,83,48,84,48,85,48,86,48,87,48,88,48,89,48,90,48,91,48,92,48,93,48,94,48,95,48,96,48,97,48,98,48,99,48,100,48,101,48,102,48,103,48,104,48,105,48,106,48,107,48,108,48,109,48,110,48,111,48,112,48,113,48,114,48,115,48,116,48,117,48,118,48,119,48,120,48,121,48,122,48,123,48,124,48,125,48,126,48,127,48,128,48,129,48,130,48,131,48,132,48,133,48,134,48,135,48,136,48,137,48,138,48,139,48,140,48,141,48,142,48,143,48,144,48,145,48,146,48,147,48,114,231,115,231,116,231,117,231,118,231,119,231,120,231,121,231,122,231,123,231,124,231,70,230,71,230,72,230,73,230,74,230,75,230,76,230,77,230,78,230,79,230,80,230,81,230,82,230,83,230,84,230,85,230,86,230,87,230,88,230,89,230,90,230,91,230,92,230,93,230,94,230,95,230,96,230,97,230,98,230,99,230,100,230,101,230,102,230,103,230,104,230,105,230,106,230,107,230,108,230,109,230,110,230,111,230,112,230,113,230,114,230,115,230,116,230,117,230,118,230,119,230,120,230,121,230,122,230,123,230,124,230,125,230,126,230,127,230,128,230,129,230,130,230,131,230,132,230,133,230,134,230,135,230,136,230,137,230,138,230,139,230,140,230,141,230,142,230,143,230,144,230,145,230,146,230,147,230,148,230,149,230,150,230,151,230,152,230,153,230,154,230,155,230,156,230,157,230,158,230,159,230,160,230,161,230,162,230,163,230,164,230,165,230,161,48,162,48,163,48,164,48,165,48,166,48,167,48,168,48,169,48,170,48,171,48,172,48,173,48,174,48,175,48,176,48,177,48,178,48,179,48,180,48,181,48,182,48,183,48,184,48,185,48,186,48,187,48,188,48,189,48,190,48,191,48,192,48,193,48,194,48,195,48,196,48,197,48,198,48,199,48,200,48,201,48,202,48,203,48,204,48,205,48,206,48,207,48,208,48,209,48,210,48,211,48,212,48,213,48,214,48,215,48,216,48,217,48,218,48,219,48,220,48,221,48,222,48,223,48,224,48,225,48,226,48,227,48,228,48,229,48,230,48,231,48,232,48,233,48,234,48,235,48,236,48,237,48,238,48,239,48,240,48,241,48,242,48,243,48,244,48,245,48,246,48,125,231,126,231,127,231,128,231,129,231,130,231,131,231,132,231,166,230,167,230,168,230,169,230,170,230,171,230,172,230,173,230,174,230,175,230,176,230,177,230,178,230,179,230,180,230,181,230,182,230,183,230,184,230,185,230,186,230,187,230,188,230,189,230,190,230,191,230,192,230,193,230,194,230,195,230,196,230,197,230,198,230,199,230,200,230,201,230,202,230,203,230,204,230,205,230,206,230,207,230,208,230,209,230,210,230,211,230,212,230,213,230,214,230,215,230,216,230,217,230,218,230,219,230,220,230,221,230,222,230,223,230,224,230,225,230,226,230,227,230,228,230,229,230,230,230,231,230,232,230,233,230,234,230,235,230,236,230,237,230,238,230,239,230,240,230,241,230,242,230,243,230,244,230,245,230,246,230,247,230,248,230,249,230,250,230,251,230,252,230,253,230,254,230,255,230,0,231,1,231,2,231,3,231,4,231,5,231,145,3,146,3,147,3,148,3,149,3,150,3,151,3,152,3,153,3,154,3,155,3,156,3,157,3,158,3,159,3,160,3,161,3,163,3,164,3,165,3,166,3,167,3,168,3,169,3,133,231,134,231,135,231,136,231,137,231,138,231,139,231,140,231,177,3,178,3,179,3,180,3,181,3,182,3,183,3,184,3,185,3,186,3,187,3,188,3,189,3,190,3,191,3,192,3,193,3,195,3,196,3,197,3,198,3,199,3,200,3,201,3,141,231,142,231,143,231,144,231,145,231,146,231,147,231,53,254,54,254,57,254,58,254,63,254,64,254,61,254,62,254,65,254,66,254,67,254,68,254,148,231,149,231,59,254,60,254,55,254,56,254,49,254,150,231,51,254,52,254,151,231,152,231,153,231,154,231,155,231,156,231,157,231,158,231,159,231,6,231,7,231,8,231,9,231,10,231,11,231,12,231,13,231,14,231,15,231,16,231,17,231,18,231,19,231,20,231,21,231,22,231,23,231,24,231,25,231,26,231,27,231,28,231,29,231,30,231,31,231,32,231,33,231,34,231,35,231,36,231,37,231,38,231,39,231,40,231,41,231,42,231,43,231,44,231,45,231,46,231,47,231,48,231,49,231,50,231,51,231,52,231,53,231,54,231,55,231,56,231,57,231,58,231,59,231,60,231,61,231,62,231,63,231,64,231,65,231,66,231,67,231,68,231,69,231,70,231,71,231,72,231,73,231,74,231,75,231,76,231,77,231,78,231,79,231,80,231,81,231,82,231,83,231,84,231,85,231,86,231,87,231,88,231,89,231,90,231,91,231,92,231,93,231,94,231,95,231,96,231,97,231,98,231,99,231,100,231,101,231,16,4,17,4,18,4,19,4,20,4,21,4,1,4,22,4,23,4,24,4,25,4,26,4,27,4,28,4,29,4,30,4,31,4,32,4,33,4,34,4,35,4,36,4,37,4,38,4,39,4,40,4,41,4,42,4,43,4,44,4,45,4,46,4,47,4,160,231,161,231,162,231,163,231,164,231,165,231,166,231,167,231,168,231,169,231,170,231,171,231,172,231,173,231,174,231,48,4,49,4,50,4,51,4,52,4,53,4,81,4,54,4,55,4,56,4,57,4,58,4,59,4,60,4,61,4,62,4,63,4,64,4,65,4,66,4,67,4,68,4,69,4,70,4,71,4,72,4,73,4,74,4,75,4,76,4,77,4,78,4,79,4,175,231,176,231,177,231,178,231,179,231,180,231,181,231,182,231,183,231,184,231,185,231,186,231,187,231,202,2,203,2,217,2,19,32,21,32,37,32,53,32,5,33,9,33,150,33,151,33,152,33,153,33,21,34,31,34,35,34,82,34,102,34,103,34,191,34,80,37,81,37,82,37,83,37,84,37,85,37,86,37,87,37,88,37,89,37,90,37,91,37,92,37,93,37,94,37,95,37,96,37,97,37,98,37,99,37,100,37,101,37,102,37,103,37,104,37,105,37,106,37,107,37,108,37,109,37,110,37,111,37,112,37,113,37,114,37,115,37,129,37,130,37,131,37,132,37,133,37,134,37,135,37,136,37,137,37,138,37,139,37,140,37,141,37,142,37,143,37,147,37,148,37,149,37,188,37,189,37,226,37,227,37,228,37,229,37,9,38,149,34,18,48,29,48,30,48,188,231,189,231,190,231,191,231,192,231,193,231,194,231,195,231,196,231,197,231,198,231,1,1,225,0,206,1,224,0,19,1,233,0,27,1,232,0,43,1,237,0,208,1,236,0,77,1,243,0,210,1,242,0,107,1,250,0,212,1,249,0,214,1,216,1,218,1,220,1,252,0,234,0,81,2,199,231,68,1,72,1,249,1,97,2,201,231,202,231,203,231,204,231,5,49,6,49,7,49,8,49,9,49,10,49,11,49,12,49,13,49,14,49,15,49,16,49,17,49,18,49,19,49,20,49,21,49,22,49,23,49,24,49,25,49,26,49,27,49,28,49,29,49,30,49,31,49,32,49,33,49,34,49,35,49,36,49,37,49,38,49,39,49,40,49,41,49,205,231,206,231,207,231,208,231,209,231,210,231,211,231,212,231,213,231,214,231,215,231,216,231,217,231,218,231,219,231,220,231,221,231,222,231,223,231,224,231,225,231,33,48,34,48,35,48,36,48,37,48,38,48,39,48,40,48,41,48,163,50,142,51,143,51,156,51,157,51,158,51,161,51,196,51,206,51,209,51,210,51,213,51,48,254,226,255,228,255,226,231,33,33,49,50,227,231,16,32,228,231,229,231,230,231,252,48,155,48,156,48,253,48,254,48,6,48,157,48,158,48,73,254,74,254,75,254,76,254,77,254,78,254,79,254,80,254,81,254,82,254,84,254,85,254,86,254,87,254,89,254,90,254,91,254,92,254,93,254,94,254,95,254,96,254,97,254,98,254,99,254,100,254,101,254,102,254,104,254,105,254,106,254,107,254,62,48,240,47,241,47,242,47,243,47,244,47,245,47,246,47,247,47,248,47,249,47,250,47,251,47,7,48,244,231,245,231,246,231,247,231,248,231,249,231,250,231,251,231,252,231,253,231,254,231,255,231,0,232,0,37,1,37,2,37,3,37,4,37,5,37,6,37,7,37,8,37,9,37,10,37,11,37,12,37,13,37,14,37,15,37,16,37,17,37,18,37,19,37,20,37,21,37,22,37,23,37,24,37,25,37,26,37,27,37,28,37,29,37,30,37,31,37,32,37,33,37,34,37,35,37,36,37,37,37,38,37,39,37,40,37,41,37,42,37,43,37,44,37,45,37,46,37,47,37,48,37,49,37,50,37,51,37,52,37,53,37,54,37,55,37,56,37,57,37,58,37,59,37,60,37,61,37,62,37,63,37,64,37,65,37,66,37,67,37,68,37,69,37,70,37,71,37,72,37,73,37,74,37,75,37,1,232,2,232,3,232,4,232,5,232,6,232,7,232,8,232,9,232,10,232,11,232,12,232,13,232,14,232,15,232,220,114,221,114,223,114,226,114,227,114,228,114,229,114,230,114,231,114,234,114,235,114,245,114,246,114,249,114,253,114,254,114,255,114,0,115,2,115,4,115,5,115,6,115,7,115,8,115,9,115,11,115,12,115,13,115,15,115,16,115,17,115,18,115,20,115,24,115,25,115,26,115,31,115,32,115,35,115,36,115,38,115,39,115,40,115,45,115,47,115,48,115,50,115,51,115,53,115,54,115,58,115,59,115,60,115,61,115,64,115,65,115,66,115,67,115,68,115,69,115,70,115,71,115,72,115,73,115,74,115,75,115,76,115,78,115,79,115,81,115,83,115,84,115,85,115,86,115,88,115,89,115,90,115,91,115,92,115,93,115,94,115,95,115,97,115,98,115,99,115,100,115,101,115,102,115,103,115,104,115,105,115,106,115,107,115,110,115,112,115,113,115,0,224,1,224,2,224,3,224,4,224,5,224,6,224,7,224,8,224,9,224,10,224,11,224,12,224,13,224,14,224,15,224,16,224,17,224,18,224,19,224,20,224,21,224,22,224,23,224,24,224,25,224,26,224,27,224,28,224,29,224,30,224,31,224,32,224,33,224,34,224,35,224,36,224,37,224,38,224,39,224,40,224,41,224,42,224,43,224,44,224,45,224,46,224,47,224,48,224,49,224,50,224,51,224,52,224,53,224,54,224,55,224,56,224,57,224,58,224,59,224,60,224,61,224,62,224,63,224,64,224,65,224,66,224,67,224,68,224,69,224,70,224,71,224,72,224,73,224,74,224,75,224,76,224,77,224,78,224,79,224,80,224,81,224,82,224,83,224,84,224,85,224,86,224,87,224,88,224,89,224,90,224,91,224,92,224,93,224,114,115,115,115,116,115,117,115,118,115,119,115,120,115,121,115,122,115,123,115,124,115,125,115,127,115,128,115,129,115,130,115,131,115,133,115,134,115,136,115,138,115,140,115,141,115,143,115,144,115,146,115,147,115,148,115,149,115,151,115,152,115,153,115,154,115,156,115,157,115,158,115,160,115,161,115,163,115,164,115,165,115,166,115,167,115,168,115,170,115,172,115,173,115,177,115,180,115,181,115,182,115,184,115,185,115,188,115,189,115,190,115,191,115,193,115,195,115,196,115,197,115,198,115,199,115,203,115,204,115,206,115,210,115,211,115,212,115,213,115,214,115,215,115,216,115,218,115,219,115,220,115,221,115,223,115,225,115,226,115,227,115,228,115,230,115,232,115,234,115,235,115,236,115,238,115,239,115,240,115,241,115,243,115,244,115,245,115,246,115,247,115,94,224,95,224,96,224,97,224,98,224,99,224,100,224,101,224,102,224,103,224,104,224,105,224,106,224,107,224,108,224,109,224,110,224,111,224,112,224,113,224,114,224,115,224,116,224,117,224,118,224,119,224,120,224,121,224,122,224,123,224,124,224,125,224,126,224,127,224,128,224,129,224,130,224,131,224,132,224,133,224,134,224,135,224,136,224,137,224,138,224,139,224,140,224,141,224,142,224,143,224,144,224,145,224,146,224,147,224,148,224,149,224,150,224,151,224,152,224,153,224,154,224,155,224,156,224,157,224,158,224,159,224,160,224,161,224,162,224,163,224,164,224,165,224,166,224,167,224,168,224,169,224,170,224,171,224,172,224,173,224,174,224,175,224,176,224,177,224,178,224,179,224,180,224,181,224,182,224,183,224,184,224,185,224,186,224,187,224,248,115,249,115,250,115,251,115,252,115,253,115,254,115,255,115,0,116,1,116,2,116,4,116,7,116,8,116,11,116,12,116,13,116,14,116,17,116,18,116,19,116,20,116,21,116,22,116,23,116,24,116,25,116,28,116,29,116,30,116,31,116,32,116,33,116,35,116,36,116,39,116,41,116,43,116,45,116,47,116,49,116,50,116,55,116,56,116,57,116,58,116,59,116,61,116,62,116,63,116,64,116,66,116,67,116,68,116,69,116,70,116,71,116,72,116,73,116,74,116,75,116,76,116,77,116,78,116,79,116,80,116,81,116,82,116,83,116,84,116,86,116,88,116,93,116,96,116,97,116,98,116,99,116,100,116,101,116,102,116,103,116,104,116,105,116,106,116,107,116,108,116,110,116,111,116,113,116,114,116,115,116,116,116,117,116,120,116,121,116,122,116,188,224,189,224,190,224,191,224,192,224,193,224,194,224,195,224,196,224,197,224,198,224,199,224,200,224,201,224,202,224,203,224,204,224,205,224,206,224,207,224,208,224,209,224,210,224,211,224,212,224,213,224,214,224,215,224,216,224,217,224,218,224,219,224,220,224,221,224,222,224,223,224,224,224,225,224,226,224,227,224,228,224,229,224,230,224,231,224,232,224,233,224,234,224,235,224,236,224,237,224,238,224,239,224,240,224,241,224,242,224,243,224,244,224,245,224,246,224,247,224,248,224,249,224,250,224,251,224,252,224,253,224,254,224,255,224,0,225,1,225,2,225,3,225,4,225,5,225,6,225,7,225,8,225,9,225,10,225,11,225,12,225,13,225,14,225,15,225,16,225,17,225,18,225,19,225,20,225,21,225,22,225,23,225,24,225,25,225,123,116,124,116,125,116,127,116,130,116,132,116,133,116,134,116,136,116,137,116,138,116,140,116,141,116,143,116,145,116,146,116,147,116,148,116,149,116,150,116,151,116,152,116,153,116,154,116,155,116,157,116,159,116,160,116,161,116,162,116,163,116,164,116,165,116,166,116,170,116,171,116,172,116,173,116,174,116,175,116,176,116,177,116,178,116,179,116,180,116,181,116,182,116,183,116,184,116,185,116,187,116,188,116,189,116,190,116,191,116,192,116,193,116,194,116,195,116,196,116,197,116,198,116,199,116,200,116,201,116,202,116,203,116,204,116,205,116,206,116,207,116,208,116,209,116,211,116,212,116,213,116,214,116,215,116,216,116,217,116,218,116,219,116,221,116,223,116,225,116,229,116,231,116,232,116,233,116,234,116,235,116,236,116,237,116,240,116,241,116,242,116,26,225,27,225,28,225,29,225,30,225,31,225,32,225,33,225,34,225,35,225,36,225,37,225,38,225,39,225,40,225,41,225,42,225,43,225,44,225,45,225,46,225,47,225,48,225,49,225,50,225,51,225,52,225,53,225,54,225,55,225,56,225,57,225,58,225,59,225,60,225,61,225,62,225,63,225,64,225,65,225,66,225,67,225,68,225,69,225,70,225,71,225,72,225,73,225,74,225,75,225,76,225,77,225,78,225,79,225,80,225,81,225,82,225,83,225,84,225,85,225,86,225,87,225,88,225,89,225,90,225,91,225,92,225,93,225,94,225,95,225,96,225,97,225,98,225,99,225,100,225,101,225,102,225,103,225,104,225,105,225,106,225,107,225,108,225,109,225,110,225,111,225,112,225,113,225,114,225,115,225,116,225,117,225,118,225,119,225,243,116,245,116,248,116,249,116,250,116,251,116,252,116,253,116,254,116,0,117,1,117,2,117,3,117,5,117,6,117,7,117,8,117,9,117,10,117,11,117,12,117,14,117,16,117,18,117,20,117,21,117,22,117,23,117,27,117,29,117,30,117,32,117,33,117,34,117,35,117,36,117,38,117,39,117,42,117,46,117,52,117,54,117,57,117,60,117,61,117,63,117,65,117,66,117,67,117,68,117,70,117,71,117,73,117,74,117,77,117,80,117,81,117,82,117,83,117,85,117,86,117,87,117,88,117,93,117,94,117,95,117,96,117,97,117,98,117,99,117,100,117,103,117,104,117,105,117,107,117,108,117,109,117,110,117,111,117,112,117,113,117,115,117,117,117,118,117,119,117,122,117,123,117,124,117,125,117,126,117,128,117,129,117,130,117,132,117,133,117,135,117,120,225,121,225,122,225,123,225,124,225,125,225,126,225,127,225,128,225,129,225,130,225,131,225,132,225,133,225,134,225,135,225,136,225,137,225,138,225,139,225,140,225,141,225,142,225,143,225,144,225,145,225,146,225,147,225,148,225,149,225,150,225,151,225,152,225,153,225,154,225,155,225,156,225,157,225,158,225,159,225,160,225,161,225,162,225,163,225,164,225,165,225,166,225,167,225,168,225,169,225,170,225,171,225,172,225,173,225,174,225,175,225,176,225,177,225,178,225,179,225,180,225,181,225,182,225,183,225,184,225,185,225,186,225,187,225,188,225,189,225,190,225,191,225,192,225,193,225,194,225,195,225,196,225,197,225,198,225,199,225,200,225,201,225,202,225,203,225,204,225,205,225,206,225,207,225,208,225,209,225,210,225,211,225,212,225,213,225,136,117,137,117,138,117,140,117,141,117,142,117,144,117,147,117,149,117,152,117,155,117,156,117,158,117,162,117,166,117,167,117,168,117,169,117,170,117,173,117,182,117,183,117,186,117,187,117,191,117,192,117,193,117,198,117,203,117,204,117,206,117,207,117,208,117,209,117,211,117,215,117,217,117,218,117,220,117,221,117,223,117,224,117,225,117,229,117,233,117,236,117,237,117,238,117,239,117,242,117,243,117,245,117,246,117,247,117,248,117,250,117,251,117,253,117,254,117,2,118,4,118,6,118,7,118,8,118,9,118,11,118,13,118,14,118,15,118,17,118,18,118,19,118,20,118,22,118,26,118,28,118,29,118,30,118,33,118,35,118,39,118,40,118,44,118,46,118,47,118,49,118,50,118,54,118,55,118,57,118,58,118,59,118,61,118,65,118,66,118,68,118,214,225,215,225,216,225,217,225,218,225,219,225,220,225,221,225,222,225,223,225,224,225,225,225,226,225,227,225,228,225,229,225,230,225,231,225,232,225,233,225,234,225,235,225,236,225,237,225,238,225,239,225,240,225,241,225,242,225,243,225,244,225,245,225,246,225,247,225,248,225,249,225,250,225,251,225],"i8",ALLOC_NONE,Runtime.GLOBAL_BASE+230588),
	allocate([252,225,253,225,254,225,255,225,0,226,1,226,2,226,3,226,4,226,5,226,6,226,7,226,8,226,9,226,10,226,11,226,12,226,13,226,14,226,15,226,16,226,17,226,18,226,19,226,20,226,21,226,22,226,23,226,24,226,25,226,26,226,27,226,28,226,29,226,30,226,31,226,32,226,33,226,34,226,35,226,36,226,37,226,38,226,39,226,40,226,41,226,42,226,43,226,44,226,45,226,46,226,47,226,48,226,49,226,50,226,51,226,69,118,70,118,71,118,72,118,73,118,74,118,75,118,78,118,79,118,80,118,81,118,82,118,83,118,85,118,87,118,88,118,89,118,90,118,91,118,93,118,95,118,96,118,97,118,98,118,100,118,101,118,102,118,103,118,104,118,105,118,106,118,108,118,109,118,110,118,112,118,113,118,114,118,115,118,116,118,117,118,118,118,119,118,121,118,122,118,124,118,127,118,128,118,129,118,131,118,133,118,137,118,138,118,140,118,141,118,143,118,144,118,146,118,148,118,149,118,151,118,152,118,154,118,155,118,156,118,157,118,158,118,159,118,160,118,161,118,162,118,163,118,165,118,166,118,167,118,168,118,169,118,170,118,171,118,172,118,173,118,175,118,176,118,179,118,181,118,182,118,183,118,184,118,185,118,186,118,187,118,188,118,189,118,190,118,192,118,193,118,195,118,74,85,63,150,195,87,40,99,206,84,9,85,192,84,145,118,76,118,60,133,238,119,126,130,141,120,49,114,152,150,141,151,40,108,137,91,250,79,9,99,151,102,184,92,250,128,72,104,174,128,2,102,206,118,249,81,86,101,172,113,241,127,132,136,178,80,101,89,202,97,179,111,173,130,76,99,82,98,237,83,39,84,6,123,107,81,164,117,244,93,212,98,203,141,118,151,138,98,25,128,93,87,56,151,98,127,56,114,125,118,207,103,126,118,70,100,112,79,37,141,220,98,23,122,145,101,237,115,44,100,115,98,44,130,129,152,127,103,72,114,110,98,204,98,52,79,227,116,74,83,158,82,202,126,166,144,46,94,134,104,156,105,128,129,209,126,210,104,197,120,140,134,81,149,141,80,36,140,222,130,222,128,5,83,18,137,101,82,196,118,199,118,201,118,203,118,204,118,211,118,213,118,217,118,218,118,220,118,221,118,222,118,224,118,225,118,226,118,227,118,228,118,230,118,231,118,232,118,233,118,234,118,235,118,236,118,237,118,240,118,243,118,245,118,246,118,247,118,250,118,251,118,253,118,255,118,0,119,2,119,3,119,5,119,6,119,10,119,12,119,14,119,15,119,16,119,17,119,18,119,19,119,20,119,21,119,22,119,23,119,24,119,27,119,28,119,29,119,30,119,33,119,35,119,36,119,37,119,39,119,42,119,43,119,44,119,46,119,48,119,49,119,50,119,51,119,52,119,57,119,59,119,61,119,62,119,63,119,66,119,68,119,69,119,70,119,72,119,73,119,74,119,75,119,76,119,77,119,78,119,79,119,82,119,83,119,84,119,85,119,86,119,87,119,88,119,89,119,92,119,132,133,249,150,221,79,33,88,113,153,157,91,177,98,165,98,180,102,121,140,141,156,6,114,111,103,145,120,178,96,81,83,23,83,136,143,204,128,29,141,161,148,13,80,200,114,7,89,235,96,25,113,171,136,84,89,239,130,44,103,40,123,41,93,247,126,45,117,245,108,102,142,248,143,60,144,59,159,212,107,25,145,20,123,124,95,167,120,214,132,61,133,213,107,217,107,214,107,1,94,135,94,249,117,237,149,93,101,10,95,197,95,159,143,193,88,194,129,127,144,91,150,173,151,185,143,22,127,44,141,65,98,191,79,216,83,94,83,168,143,169,143,171,143,77,144,7,104,106,95,152,129,104,136,214,156,139,97,43,82,42,118,108,95,140,101,210,111,232,110,190,91,72,100,117,81,176,81,196,103,25,78,201,121,124,153,179,112,93,119,94,119,95,119,96,119,100,119,103,119,105,119,106,119,109,119,110,119,111,119,112,119,113,119,114,119,115,119,116,119,117,119,118,119,119,119,120,119,122,119,123,119,124,119,129,119,130,119,131,119,134,119,135,119,136,119,137,119,138,119,139,119,143,119,144,119,147,119,148,119,149,119,150,119,151,119,152,119,153,119,154,119,155,119,156,119,157,119,158,119,161,119,163,119,164,119,166,119,168,119,171,119,173,119,174,119,175,119,177,119,178,119,180,119,182,119,183,119,184,119,185,119,186,119,188,119,190,119,192,119,193,119,194,119,195,119,196,119,197,119,198,119,199,119,200,119,201,119,202,119,203,119,204,119,206,119,207,119,208,119,209,119,210,119,211,119,212,119,213,119,214,119,216,119,217,119,218,119,221,119,222,119,223,119,224,119,225,119,228,119,197,117,118,94,187,115,224,131,173,100,232,98,181,148,226,108,90,83,195,82,15,100,194,148,148,123,47,79,27,94,54,130,22,129,138,129,36,110,202,108,115,154,85,99,92,83,250,84,101,136,224,87,13,78,3,94,101,107,63,124,232,144,22,96,230,100,28,115,193,136,80,103,77,98,34,141,108,119,41,142,199,145,105,95,220,131,33,133,16,153,194,83,149,134,139,107,237,96,232,96,127,112,205,130,49,130,211,78,167,108,207,133,205,100,217,124,253,105,249,102,73,131,149,83,86,123,167,79,140,81,75,109,66,92,109,142,210,99,201,83,44,131,54,131,229,103,180,120,61,100,223,91,148,92,238,93,231,139,198,98,244,103,122,140,0,100,186,99,73,135,139,153,23,140,32,127,242,148,167,78,16,150,164,152,12,102,22,115,230,119,232,119,234,119,239,119,240,119,241,119,242,119,244,119,245,119,247,119,249,119,250,119,251,119,252,119,3,120,4,120,5,120,6,120,7,120,8,120,10,120,11,120,14,120,15,120,16,120,19,120,21,120,25,120,27,120,30,120,32,120,33,120,34,120,36,120,40,120,42,120,43,120,46,120,47,120,49,120,50,120,51,120,53,120,54,120,61,120,63,120,65,120,66,120,67,120,68,120,70,120,72,120,73,120,74,120,75,120,77,120,79,120,81,120,83,120,84,120,88,120,89,120,90,120,91,120,92,120,94,120,95,120,96,120,97,120,98,120,99,120,100,120,101,120,102,120,103,120,104,120,105,120,111,120,112,120,113,120,114,120,115,120,116,120,117,120,118,120,120,120,121,120,122,120,123,120,125,120,126,120,127,120,128,120,129,120,130,120,131,120,58,87,29,92,56,94,127,149,127,80,160,128,130,83,94,101,69,117,49,85,33,80,133,141,132,98,158,148,29,103,50,86,110,111,226,93,53,84,146,112,102,143,111,98,164,100,163,99,123,95,136,111,244,144,227,129,176,143,24,92,104,102,241,95,137,108,72,150,129,141,108,136,145,100,240,121,206,87,89,106,16,98,72,84,88,78,11,122,233,96,132,111,218,139,127,98,30,144,139,154,228,121,3,84,244,117,1,99,25,83,96,108,223,143,27,95,112,154,59,128,127,159,136,79,58,92,100,141,197,127,165,101,189,112,69,81,178,81,107,134,7,93,160,91,189,98,108,145,116,117,12,142,32,122,1,97,121,123,199,78,248,126,133,119,17,78,237,129,29,82,250,81,113,106,168,83,135,142,4,149,207,150,193,110,100,150,90,105,132,120,133,120,134,120,136,120,138,120,139,120,143,120,144,120,146,120,148,120,149,120,150,120,153,120,157,120,158,120,160,120,162,120,164,120,166,120,168,120,169,120,170,120,171,120,172,120,173,120,174,120,175,120,181,120,182,120,183,120,184,120,186,120,187,120,188,120,189,120,191,120,192,120,194,120,195,120,196,120,198,120,199,120,200,120,204,120,205,120,206,120,207,120,209,120,210,120,211,120,214,120,215,120,216,120,218,120,219,120,220,120,221,120,222,120,223,120,224,120,225,120,226,120,227,120,228,120,229,120,230,120,231,120,233,120,234,120,235,120,237,120,238,120,239,120,240,120,241,120,243,120,245,120,246,120,248,120,249,120,251,120,252,120,253,120,254,120,255,120,0,121,2,121,3,121,4,121,6,121,7,121,8,121,9,121,10,121,11,121,12,121,64,120,168,80,215,119,16,100,230,137,4,89,227,99,221,93,127,122,61,105,32,79,57,130,152,85,50,78,174,117,151,122,98,94,138,94,239,149,27,82,57,84,138,112,118,99,36,149,130,87,37,102,63,105,135,145,7,85,243,109,175,126,34,136,51,98,240,126,181,117,40,131,193,120,204,150,158,143,72,97,247,116,205,139,100,107,58,82,80,141,33,107,106,128,113,132,241,86,6,83,206,78,27,78,209,81,151,124,139,145,7,124,195,79,127,142,225,123,156,122,103,100,20,93,172,80,6,129,1,118,185,124,236,109,224,127,81,103,88,91,248,91,203,120,174,100,19,100,170,99,43,99,25,149,45,100,190,143,84,123,41,118,83,98,39,89,70,84,121,107,163,80,52,98,38,94,134,107,227,78,55,141,139,136,133,95,46,144,13,121,14,121,15,121,16,121,17,121,18,121,20,121,21,121,22,121,23,121,24,121,25,121,26,121,27,121,28,121,29,121,31,121,32,121,33,121,34,121,35,121,37,121,38,121,39,121,40,121,41,121,42,121,43,121,44,121,45,121,46,121,47,121,48,121,49,121,50,121,51,121,53,121,54,121,55,121,56,121,57,121,61,121,63,121,66,121,67,121,68,121,69,121,71,121,74,121,75,121,76,121,77,121,78,121,79,121,80,121,81,121,82,121,84,121,85,121,88,121,89,121,97,121,99,121,100,121,102,121,105,121,106,121,107,121,108,121,110,121,112,121,113,121,114,121,115,121,116,121,117,121,118,121,121,121,123,121,124,121,125,121,126,121,127,121,130,121,131,121,134,121,135,121,136,121,137,121,139,121,140,121,141,121,142,121,144,121,145,121,146,121,32,96,61,128,197,98,57,78,85,83,248,144,184,99,198,128,230,101,46,108,70,79,238,96,225,109,222,139,57,95,203,134,83,95,33,99,90,81,97,131,99,104,0,82,99,99,72,142,18,80,155,92,119,121,252,91,48,82,59,122,188,96,83,144,215,118,183,95,151,95,132,118,108,142,111,112,123,118,73,123,170,119,243,81,147,144,36,88,78,79,244,110,234,143,76,101,27,123,196,114,164,109,223,127,225,90,181,98,149,94,48,87,130,132,44,123,29,94,31,95,18,144,20,127,160,152,130,99,199,110,152,120,185,112,120,81,91,151,171,87,53,117,67,79,56,117,151,94,230,96,96,89,192,109,191,107,137,120,252,83,213,150,203,81,1,82,137,99,10,84,147,148,3,140,204,141,57,114,159,120,118,135,237,143,13,140,224,83,147,121,148,121,149,121,150,121,151,121,152,121,153,121,155,121,156,121,157,121,158,121,159,121,160,121,161,121,162,121,163,121,164,121,165,121,166,121,168,121,169,121,170,121,171,121,172,121,173,121,174,121,175,121,176,121,177,121,178,121,180,121,181,121,182,121,183,121,184,121,188,121,191,121,194,121,196,121,197,121,199,121,200,121,202,121,204,121,206,121,207,121,208,121,211,121,212,121,214,121,215,121,217,121,218,121,219,121,220,121,221,121,222,121,224,121,225,121,226,121,229,121,232,121,234,121,236,121,238,121,241,121,242,121,243,121,244,121,245,121,246,121,247,121,249,121,250,121,252,121,254,121,255,121,1,122,4,122,5,122,7,122,8,122,9,122,10,122,12,122,15,122,16,122,17,122,18,122,19,122,21,122,22,122,24,122,25,122,27,122,28,122,1,78,239,118,238,83,137,148,118,152,14,159,45,149,154,91,162,139,34,78,28,78,172,81,99,132,194,97,168,82,11,104,151,79,107,96,187,81,30,109,92,81,150,98,151,101,97,150,70,140,23,144,216,117,253,144,99,119,210,107,138,114,236,114,251,139,53,88,121,119,76,141,92,103,64,149,154,128,166,94,33,110,146,89,239,122,237,119,59,149,181,107,173,101,14,127,6,88,81,81,31,150,249,91,169,88,40,84,114,142,102,101,127,152,228,86,157,148,254,118,65,144,135,99,198,84,26,89,58,89,155,87,178,142,53,103,250,141,53,130,65,82,240,96,21,88,254,134,232,92,69,158,196,79,157,152,185,139,37,90,118,96,132,83,124,98,79,144,2,145,127,153,105,96,12,128,63,81,51,128,20,92,117,153,49,109,140,78,29,122,31,122,33,122,34,122,36,122,37,122,38,122,39,122,40,122,41,122,42,122,43,122,44,122,45,122,46,122,47,122,48,122,49,122,50,122,52,122,53,122,54,122,56,122,58,122,62,122,64,122,65,122,66,122,67,122,68,122,69,122,71,122,72,122,73,122,74,122,75,122,76,122,77,122,78,122,79,122,80,122,82,122,83,122,84,122,85,122,86,122,88,122,89,122,90,122,91,122,92,122,93,122,94,122,95,122,96,122,97,122,98,122,99,122,100,122,101,122,102,122,103,122,104,122,105,122,106,122,107,122,108,122,109,122,110,122,111,122,113,122,114,122,115,122,117,122,123,122,124,122,125,122,126,122,130,122,133,122,135,122,137,122,138,122,139,122,140,122,142,122,143,122,144,122,147,122,148,122,153,122,154,122,155,122,158,122,161,122,162,122,48,141,209,83,90,127,79,123,16,79,79,78,0,150,213,108,208,115,233,133,6,94,106,117,251,127,10,106,254,119,146,148,65,126,225,81,230,112,205,83,212,143,3,131,41,141,175,114,109,153,219,108,74,87,179,130,185,101,170,128,63,98,50,150,168,89,255,78,191,139,186,126,62,101,242,131,94,151,97,85,222,152,165,128,42,83,253,139,32,84,186,128,159,94,184,108,57,141,172,130,90,145,41,84,27,108,6,82,183,126,95,87,26,113,126,108,137,124,75,89,253,78,255,95,36,97,170,124,48,78,1,92,171,103,2,135,240,92,11,149,206,152,175,117,253,112,34,144,175,81,29,127,189,139,73,89,228,81,91,79,38,84,43,89,119,101,164,128,117,91,118,98,194,98,144,143,69,94,31,108,38,123,15,79,216,79,13,103,163,122,164,122,167,122,169,122,170,122,171,122,174,122,175,122,176,122,177,122,178,122,180,122,181,122,182,122,183,122,184,122,185,122,186,122,187,122,188,122,189,122,190,122,192,122,193,122,194,122,195,122,196,122,197,122,198,122,199,122,200,122,201,122,202,122,204,122,205,122,206,122,207,122,208,122,209,122,210,122,211,122,212,122,213,122,215,122,216,122,218,122,219,122,220,122,221,122,225,122,226,122,228,122,231,122,232,122,233,122,234,122,235,122,236,122,238,122,240,122,241,122,242,122,243,122,244,122,245,122,246,122,247,122,248,122,251,122,252,122,254,122,0,123,1,123,2,123,5,123,7,123,9,123,12,123,13,123,14,123,16,123,18,123,19,123,22,123,23,123,24,123,26,123,28,123,29,123,31,123,33,123,34,123,35,123,39,123,41,123,45,123,110,109,170,109,143,121,177,136,23,95,43,117,154,98,133,143,239,79,220,145,167,101,47,129,81,129,156,94,80,129,116,141,111,82,134,137,75,141,13,89,133,80,216,78,28,150,54,114,121,129,31,141,204,91,163,139,68,150,135,89,26,127,144,84,118,86,14,86,229,139,57,101,130,105,153,148,214,118,137,110,114,94,24,117,70,103,209,103,255,122,157,128,118,141,31,97,198,121,98,101,99,141,136,81,26,82,162,148,56,127,155,128,178,126,151,92,47,110,96,103,217,123,139,118,216,154,143,129,148,127,213,124,30,100,80,149,63,122,74,84,229,84,76,107,1,100,8,98,61,158,243,128,153,117,114,82,105,151,91,132,60,104,228,134,1,150,148,150,236,148,42,78,4,84,217,126,57,104,223,141,21,128,244,102,154,94,185,127,47,123,48,123,50,123,52,123,53,123,54,123,55,123,57,123,59,123,61,123,63,123,64,123,65,123,66,123,67,123,68,123,70,123,72,123,74,123,77,123,78,123,83,123,85,123,87,123,89,123,92,123,94,123,95,123,97,123,99,123,100,123,101,123,102,123,103,123,104,123,105,123,106,123,107,123,108,123,109,123,111,123,112,123,115,123,116,123,118,123,120,123,122,123,124,123,125,123,127,123,129,123,130,123,131,123,132,123,134,123,135,123,136,123,137,123,138,123,139,123,140,123,142,123,143,123,145,123,146,123,147,123,150,123,152,123,153,123,154,123,155,123,158,123,159,123,160,123,163,123,164,123,165,123,174,123,175,123,176,123,178,123,179,123,181,123,182,123,183,123,185,123,186,123,187,123,188,123,189,123,190,123,191,123,192,123,194,123,195,123,196,123,194,87,63,128,151,104,229,93,59,101,159,82,109,96,154,159,155,79,172,142,108,81,171,91,19,95,233,93,94,108,241,98,33,141,113,81,169,148,254,82,159,108,223,130,215,114,162,87,132,103,45,141,31,89,156,143,199,131,149,84,141,123,48,79,189,108,100,91,209,89,19,159,228,83,202,134,168,154,55,140,161,128,69,101,126,152,250,86,199,150,46,82,220,116,80,82,225,91,2,99,2,137,86,78,208,98,42,96,250,104,115,81,152,91,160,81,194,137,161,123,134,153,80,127,239,96,76,112,47,141,73,81,127,94,27,144,112,116,196,137,45,87,69,120,82,95,159,159,250,149,104,143,60,155,225,139,120,118,66,104,220,103,234,141,53,141,61,82,138,143,218,110,205,104,5,149,237,144,253,86,156,103,249,136,199,143,200,84,197,123,200,123,201,123,202,123,203,123,205,123,206,123,207,123,208,123,210,123,212,123,213,123,214,123,215,123,216,123,219,123,220,123,222,123,223,123,224,123,226,123,227,123,228,123,231,123,232,123,233,123,235,123,236,123,237,123,239,123,240,123,242,123,243,123,244,123,245,123,246,123,248,123,249,123,250,123,251,123,253,123,255,123,0,124,1,124,2,124,3,124,4,124,5,124,6,124,8,124,9,124,10,124,13,124,14,124,16,124,17,124,18,124,19,124,20,124,21,124,23,124,24,124,25,124,26,124,27,124,28,124,29,124,30,124,32,124,33,124,34,124,35,124,36,124,37,124,40,124,41,124,43,124,44,124,45,124,46,124,47,124,48,124,49,124,50,124,51,124,52,124,53,124,54,124,55,124,57,124,58,124,59,124,60,124,61,124,62,124,66,124,184,154,105,91,119,109,38,108,165,78,179,91,135,154,99,145,168,97,175,144,233,151,43,84,181,109,210,91,253,81,138,85,85,127,240,127,188,100,77,99,241,101,190,97,141,96,10,113,87,108,73,108,47,89,109,103,42,130,213,88,142,86,106,140,235,107,221,144,125,89,23,128,247,83,105,109,117,84,157,85,119,131,207,131,56,104,190,121,140,84,85,79,8,84,210,118,137,140,2,150,179,108,184,109,107,141,16,137,100,158,58,141,63,86,209,158,213,117,136,95,224,114,104,96,252,84,168,78,42,106,97,136,82,96,112,143,196,84,216,112,121,134,63,158,42,109,143,91,24,95,162,126,137,85,175,79,52,115,60,84,154,83,25,80,14,84,124,84,78,78,253,95,90,116,246,88,107,132,225,128,116,135,208,114,202,124,86,110,67,124,68,124,69,124,70,124,71,124,72,124,73,124,74,124,75,124,76,124,78,124,79,124,80,124,81,124,82,124,83,124,84,124,85,124,86,124,87,124,88,124,89,124,90,124,91,124,92,124,93,124,94,124,95,124,96,124,97,124,98,124,99,124,100,124,101,124,102,124,103,124,104,124,105,124,106,124,107,124,108,124,109,124,110,124,111,124,112,124,113,124,114,124,117,124,118,124,119,124,120,124,121,124,122,124,126,124,127,124,128,124,129,124,130,124,131,124,132,124,133,124,134,124,135,124,136,124,138,124,139,124,140,124,141,124,142,124,143,124,144,124,147,124,148,124,150,124,153,124,154,124,155,124,160,124,161,124,163,124,166,124,167,124,168,124,169,124,171,124,172,124,173,124,175,124,176,124,180,124,181,124,182,124,183,124,184,124,186,124,187,124,39,95,78,134,44,85,164,98,146,78,170,108,55,98,177,130,215,84,78,83,62,115,209,110,59,117,18,82,22,83,221,139,208,105,138,95,0,96,238,109,79,87,34,107,175,115,83,104,216,143,19,127,98,99,163,96,36,85,234,117,98,140,21,113,163,109,166,91,123,94,82,131,76,97,196,158,250,120,87,135,39,124,135,118,240,81,246,96,76,113,67,102,76,94,77,96,14,140,112,112,37,99,137,143,189,95,98,96,212,134,222,86,193,107,148,96,103,97,73,83,224,96,102,102,63,141,253,121,26,79,233,112,71,108,179,139,242,139,216,126,100,131,15,102,90,90,66,155,81,109,247,109,65,140,59,109,25,79,107,112,183,131,22,98,209,96,13,151,39,141,120,121,251,81,62,87,250,87,58,103,120,117,61,122,239,121,149,123,191,124,192,124,194,124,195,124,196,124,198,124,201,124,203,124,206,124,207,124,208,124,209,124,210,124,211,124,212,124,216,124,218,124,219,124,221,124,222,124,225,124,226,124,227,124,228,124,229,124,230,124,231,124,233,124,234,124,235,124,236,124,237,124,238,124,240,124,241,124,242,124,243,124,244,124,245,124,246,124,247,124,249,124,250,124,252,124,253,124,254,124,255,124,0,125,1,125,2,125,3,125,4,125,5,125,6,125,7,125,8,125,9,125,11,125,12,125,13,125,14,125,15,125,16,125,17,125,18,125,19,125,20,125,21,125,22,125,23,125,24,125,25,125,26,125,27,125,28,125,29,125,30,125,31,125,33,125,35,125,36,125,37,125,38,125,40,125,41,125,42,125,44,125,45,125,46,125,48,125,49,125,50,125,51,125,52,125,53,125,54,125,140,128,101,153,249,143,192,111,165,139,33,158,236,89,233,126,9,127,9,84,129,103,216,104,145,143,77,124,198,150,202,83,37,96,190,117,114,108,115,83,201,90,167,126,36,99,224,81,10,129,241,93,223,132,128,98,128,81,99,91,14,79,109,121,66,82,184,96,78,109,196,91,194,91,161,139,176,139,226,101,204,95,69,150,147,89,231,126,170,126,9,86,183,103,57,89,115,79,182,91,160,82,90,131,138,152,62,141,50,117,190,148,71,80,60,122,247,78,182,103,126,154,193,90,124,107,209,118,90,87,22,92,58,123,244,149,78,113,124,81,169,128,112,130,120,89,4,127,39,131,192,104,236,103,177,120,119,120,227,98,97,99,128,123,237,79,106,82,207,81,80,131,219,105,116,146,245,141,49,141,193,137,46,149,173,123,246,78,55,125,56,125,57,125,58,125,59,125,60,125,61,125,62,125,63,125,64,125,65,125,66,125,67,125,68,125,69,125,70,125,71,125,72,125,73,125,74,125,75,125,76,125,77,125,78,125,79,125,80,125,81,125,82,125,83,125,84,125,85,125,86,125,87,125,88,125,89,125,90,125,91,125,92,125,93,125,94,125,95,125,96,125,97,125,98,125,99,125,100,125,101,125,102,125,103,125,104,125,105,125,106,125,107,125,108,125,109,125,111,125,112,125,113,125,114,125,115,125,116,125,117,125,118,125,120,125,121,125,122,125,123,125,124,125,125,125,126,125,127,125,128,125,129,125,130,125,131,125,132,125,133,125,134,125,135,125,136,125,137,125,138,125,139,125,140,125,141,125,142,125,143,125,144,125,145,125,146,125,147,125,148,125,149,125,150,125,151,125,152,125,101,80,48,130,81,82,111,153,16,110,133,110,167,109,250,94,245,80,220,89,6,92,70,109,95,108,134,117,139,132,104,104,86,89,178,139,32,83,113,145,77,150,73,133,18,105,1,121,38,113,246,128,164,78,202,144,71,109,132,154,7,90,188,86,5,100,240,148,235,119,165,79,26,129,225,114,210,137,122,153,52,127,222,126,127,82,89,101,117,145,127,143,131,143,235,83,150,122,237,99,165,99,134,118,248,121,87,136,54,150,42,98,171,82,130,130,84,104,112,103,119,99,107,119,237,122,1,109,211,126,227,137,208,89,18,98,201,133,165,130,76,117,31,80,203,78,165,117,235,139,74,92,254,93,75,123,164,101,209,145,202,78,37,109,95,137,39,125,38,149,197,78,40,140,219,143,115,151,75,102,129,121,209,143,236,112,120,109,153,125,154,125,155,125,156,125,157,125,158,125,159,125,160,125,161,125,162,125,163,125,164,125,165,125,167,125,168,125,169,125,170,125,171,125,172,125,173,125,175,125,176,125,177,125,178,125,179,125,180,125,181,125,182,125,183,125,184,125,185,125,186,125,187,125,188,125,189,125,190,125,191,125,192,125,193,125,194,125,195,125,196,125,197,125,198,125,199,125,200,125,201,125,202,125,203,125,204,125,205,125,206,125,207,125,208,125,209,125,210,125,211,125,212,125,213,125,214,125,215,125,216,125,217,125,218,125,219,125,220,125,221,125,222,125,223,125,224,125,225,125,226,125,227,125,228,125,229,125,230,125,231,125,232,125,233,125,234,125,235,125,236,125,237,125,238,125,239,125,240,125,241,125,242,125,243,125,244,125,245,125,246,125,247,125,248,125,249,125,250,125,61,92,178,82,70,131,98,81,14,131,91,119,118,102,184,156,172,78,202,96,190,124,179,124,207,126,149,78,102,139,111,102,136,152,89,151,131,88,108,101,92,149,132,95,201,117,86,151,223,122,222,122,192,81,175,112,152,122,234,99,118,122,160,126,150,115,237,151,69,78,120,112,93,78,82,145,169,83,81,101,231,101,252,129,5,130,142,84,49,92,154,117,160,151,216,98,217,114,189,117,69,92,121,154,202,131,64,92,128,84,233,119,62,78,174,108,90,128,210,98,110,99,232,93,119,81,221,141,30,142,47,149,241,79,229,83,231,96,172,112,103,82,80,99,67,158,31,90,38,80,55,119,119,83,226,126,133,100,43,101,137,98,152,99,20,80,53,114,201,137,179,81,192,139,221,126,71,87,204,131,167,148,155,81,27,84,251,92,251,125,252,125,253,125,254,125,255,125,0,126,1,126,2,126,3,126,4,126,5,126,6,126,7,126,8,126,9,126,10,126,11,126,12,126,13,126,14,126,15,126,16,126,17,126,18,126,19,126,20,126,21,126,22,126,23,126,24,126,25,126,26,126,27,126,28,126,29,126,30,126,31,126,32,126,33,126,34,126,35,126,36,126,37,126,38,126,39,126,40,126,41,126,42,126,43,126,44,126,45,126,46,126,47,126,48,126,49,126,50,126,51,126,52,126,53,126,54,126,55,126,56,126,57,126,58,126,60,126,61,126,62,126,63,126,64,126,66,126,67,126,68,126,69,126,70,126,72,126,73,126,74,126,75,126,76,126,77,126,78,126,79,126,80,126,81,126,82,126,83,126,84,126,85,126,86,126,87,126,88,126,89,126,90,126,91,126,92,126,93,126,202,79,227,122,90,109,225,144,143,154,128,85,150,84,97,83,175,84,0,95,233,99,119,105,239,81,104,97,10,82,42,88,216,82,78,87,13,120,11,119,183,94,119,97,224,124,91,98,151,98,162,78,149,112,3,128,247,98,228,112,96,151,119,87,219,130,239,103,245,104,213,120,151,152,209,121,243,88,179,84,239,83,52,110,75,81,59,82,162,91,254,139,175,128,67,85,166,87,115,96,81,87,45,84,122,122,80,96,84,91,167,99,160,98,227,83,99,98,199,91,175,103,237,84,159,122,230,130,119,145,147,94,228,136,56,89,174,87,14,99,232,141,239,128,87,87,119,123,169,79,235,95,189,91,62,107,33,83,80,123,194,114,70,104,255,119,54,119,247,101,181,81,143,78,212,118,191,92,165,122,117,132,78,89,65,155,128,80,94,126,95,126,96,126,97,126,98,126,99,126,100,126,101,126,102,126,103,126,104,126,105,126,106,126,107,126,108,126,109,126,110,126,111,126,112,126,113,126,114,126,115,126,116,126,117,126,118,126,119,126,120,126,121,126,122,126,123,126,124,126,125,126,126,126,127,126,128,126,129,126,131,126,132,126,133,126,134,126,135,126,136,126,137,126,138,126,139,126,140,126,141,126,142,126,143,126,144,126,145,126,146,126,147,126,148,126,149,126,150,126,151,126,152,126,153,126,154,126,156,126,157,126,158,126,174,126,180,126,187,126,188,126,214,126,228,126,236,126,249,126,10,127,16,127,30,127,55,127,57,127,59,127,60,127,61,127,62,127,63,127,64,127,65,127,67,127,70,127,71,127,72,127,73,127,74,127,75,127,76,127,77,127,78,127,79,127,82,127,83,127,136,153,39,97,131,110,100,87,6,102,70,99,240,86,236,98,105,98,211,94,20,150,131,87,201,98,135,85,33,135,74,129,163,143,102,85,177,131,101,103,86,141,221,132,106,90,15,104,230,98,238,123,17,150,112,81,156,111,48,140,253,99,200,137,210,97,6,127,194,112,229,110,5,116,148,105,252,114,202,94,206,144,23,103,106,109,94,99,179,82,98,114,1,128,108,79,229,89,106,145,217,112,157,109,210,82,80,78,247,150,109,149,126,133,202,120,47,125,33,81,146,87,194,100,139,128,123,124,234,108,241,104,94,105,183,81,152,83,168,104,129,114,206,158,241,123,248,114,187,121,19,111,6,116,78,103,204,145,164,156,60,121,137,131,84,131,15,84,23,104,61,78,137,83,177,82,62,120,134,83,41,82,136,80,139,79,208,79,86,127,89,127,91,127,92,127,93,127,94,127,96,127,99,127,100,127,101,127,102,127,103,127,107,127,108,127,109,127,111,127,112,127,115,127,117,127,118,127,119,127,120,127,122,127,123,127,124,127,125,127,127,127,128,127,130,127,131,127,132,127,133,127,134,127,135,127,136,127,137,127,139,127,141,127,143,127,144,127,145,127,146,127,147,127,149,127,150,127,151,127,152,127,153,127,155,127,156,127,160,127,162,127,163,127,165,127,166,127,168,127,169,127,170,127,171,127,172,127,173,127,174,127,177,127,179,127,180,127,181,127,182,127,183,127,186,127,187,127,190,127,192,127,194,127,195,127,196,127,198,127,199,127,200,127,201,127,203,127,205,127,207,127,208,127,209,127,210,127,211,127,214,127,215,127,217,127,218,127,219,127,220,127,221,127,222,127,226,127,227,127,226,117,203,122,146,124,165,108,182,150,155,82,131,116,233,84,233,79,84,128,178,131,222,143,112,149,201,94,28,96,159,109,24,94,91,101,56,129,254,148,75,96,188,112,195,126,174,124,201,81,129,104,177,124,111,130,36,78,134,143,207,145,126,102,174,78,5,140,169,100,74,128,218,80,151,117,206,113,229,91,189,143,102,111,134,78,130,100,99,149,214,94,153,101,23,82,194,136,200,112,163,82,14,115,51,116,151,103,247,120,22,151,52,78,187,144,222,156,203,109,219,81,65,141,29,84,206,98,178,115,241,131,246,150,132,159,195,148,54,79,154,127,204,81,117,112,117,150,173,92,134,152,230,83,228,78,156,110,9,116,180,105,107,120,143,153,89,117,24,82,36,118,65,109,243,103,109,81,153,159,75,128,153,84,60,123,191,122,228,127,231,127,232,127,234,127,235,127,236,127,237,127,239,127,242,127,244,127,245,127,246,127,247,127,248,127,249,127,250,127,253,127,254,127,255,127,2,128,7,128,8,128,9,128,10,128,14,128,15,128,17,128,19,128,26,128,27,128,29,128,30,128,31,128,33,128,35,128,36,128,43,128,44,128,45,128,46,128,47,128,48,128,50,128,52,128,57,128,58,128,60,128,62,128,64,128,65,128,68,128,69,128,71,128,72,128,73,128,78,128,79,128,80,128,81,128,83,128,85,128,86,128,87,128,89,128,91,128,92,128,93,128,94,128,95,128,96,128,97,128,98,128,99,128,100,128,101,128,102,128,103,128,104,128,107,128,108,128,109,128,110,128,111,128,112,128,114,128,115,128,116,128,117,128,118,128,119,128,120,128,121,128,122,128,123,128,124,128,125,128,134,150,132,87,226,98,71,150,124,105,4,90,2,100,211,123,15,111,75,150,166,130,98,83,133,152,144,94,137,112,179,99,100,83,79,134,129,156,147,158,140,120,50,151,239,141,66,141,127,158,94,111,132,121,85,95,70,150,46,98,116,154,21,84,221,148,163,79,197,101,101,92,97,92,21,127,81,134,47,108,139,95,135,115,228,110,255,126,230,92,27,99,106,91,230,110,117,83,113,78,160,99,101,117,161,98,110,143,38,79,209,78,166,108,182,126,186,139,29,132,186,135,87,127,59,144,35,149,169,123,161,154,248,136,61,132,27,109,134,154,220,126,136,89,187,158,155,115,1,120,130,134,108,154,130,154,27,86,23,84,203,87,112,78,166,158,86,83,200,143,9,129,146,119,146,153,238,134,225,110,19,133,252,102,98,97,43,111,126,128,129,128,130,128,133,128,136,128,138,128,141,128,142,128,143,128,144,128,145,128,146,128,148,128,149,128,151,128,153,128,158,128,163,128,166,128,167,128,168,128,172,128,176,128,179,128,181,128,182,128,184,128,185,128,187,128,197,128,199,128,200,128,201,128,202,128,203,128,207,128,208,128,209,128,210,128,211,128,212,128,213,128,216,128,223,128,224,128,226,128,227,128,230,128,238,128,245,128,247,128,249,128,251,128,254,128,255,128,0,129,1,129,3,129,4,129,5,129,7,129,8,129,11,129,12,129,21,129,23,129,25,129,27,129,28,129,29,129,31,129,32,129,33,129,34,129,35,129,36,129,37,129,38,129,39,129,40,129,41,129,42,129,43,129,45,129,46,129,48,129,51,129,52,129,53,129,55,129,57,129,58,129,59,129,60,129,61,129,63,129,41,140,146,130,43,131,242,118,19,108,217,95,189,131,43,115,5,131,26,149,219,107,219,119,198,148,111,83,2,131,146,81,61,94,140,140,56,141,72,78,171,115,154,103,133,104,118,145,9,151,100,113,161,108,9,119,146,90,65,149,207,107,142,127,39,102,208,91,185,89,154,90,232,149,247,149,236,78,12,132,153,132,172,106,223,118,48,149,27,115,166,104,95,91,47,119,154,145,97,151,220,124,247,143,28,140,37,95,115,124,216,121,197,137,204,108,28,135,198,91,66,94,201,104,32,119,245,126,149,81,77,81,201,82,41,90,5,127,98,151,215,130,207,99,132,119,208,133,210,121,58,110,153,94,153,89,17,133,109,112,17,108,191,98,191,118,79,101,175,96,253,149,14,102,159,135,35,158,237,148,13,84,125,84,44,140,120,100,64,129,65,129,66,129,67,129,68,129,69,129,71,129,73,129,77,129,78,129,79,129,82,129,86,129,87,129,88,129,91,129,92,129,93,129,94,129,95,129,97,129,98,129,99,129,100,129,102,129,104,129,106,129,107,129,108,129,111,129,114,129,115,129,117,129,118,129,119,129,120,129,129,129,131,129,132,129,133,129,134,129,135,129,137,129,139,129,140,129,141,129,142,129,144,129,146,129,147,129,148,129,149,129,150,129,151,129,153,129,154,129,158,129,159,129,160,129,161,129,162,129,164,129,165,129,167,129,169,129,171,129,172,129,173,129,174,129,175,129,176,129,177,129,178,129,180,129,181,129,182,129,183,129,184,129,185,129,188,129,189,129,190,129,191,129,196,129,197,129,199,129,200,129,201,129,203,129,205,129,206,129,207,129,208,129,209,129,210,129,211,129,121,100,17,134,33,106,156,129,232,120,105,100,84,155,185,98,43,103,171,131,168,88,216,158,171,108,32,111,222,91,76,150,11,140,95,114,208,103,199,98,97,114,169,78,198,89,205,107,147,88,174,102,85,94,223,82,85,97,40,103,238,118,102,119,103,114,70,122,255,98,234,84,80,84,160,148,163,144,28,90,179,126,22,108,67,78,118,89,16,128,72,89,87,83,55,117,190,150,202,86,32,99,17,129,124,96,249,149,214,109,98,84,129,153,133,81,233,90,253,128,174,89,19,151,42,80,229,108,60,92,223,98,96,79,63,83,123,129,6,144,186,110,43,133,200,98,116,94,190,120,181,100,123,99,245,95,24,90,127,145,31,158,63,92,79,99,66,128,125,91,110,85,74,149,77,149,133,109,168,96,224,103,222,114,221,81,129,91,212,129,213,129,214,129,215,129,216,129,217,129,218,129,219,129,220,129,221,129,222,129,223,129,224,129,225,129,226,129,228,129,229,129,230,129,232,129,233,129,235,129,238,129,239,129,240,129,241,129,242,129,245,129,246,129,247,129,248,129,249,129,250,129,253,129,255,129,3,130,7,130,8,130,9,130,10,130,11,130,14,130,15,130,17,130,19,130,21,130,22,130,23,130,24,130,25,130,26,130,29,130,32,130,36,130,37,130,38,130,39,130,41,130,46,130,50,130,58,130,60,130,61,130,63,130,64,130,65,130,66,130,67,130,69,130,70,130,72,130,74,130,76,130,77,130,78,130,80,130,81,130,82,130,83,130,84,130,85,130,86,130,87,130,89,130,91,130,92,130,93,130,94,130,96,130,97,130,98,130,99,130,100,130,101,130,102,130,103,130,105,130,231,98,222,108,91,114,109,98,174,148,189,126,19,129,83,109,156,81,4,95,116,89,170,82,18,96,115,89,150,102,80,134,159,117,42,99,230,97,239,124,250,139,230,84,39,107,37,158,180,107,213,133,85,84,118,80,164,108,106,85,180,141,44,114,21,94,21,96,54,116,205,98,146,99,76,114,152,95,67,110,62,109,0,101,88,111,216,118,208,120,252,118,84,117,36,82,219,83,83,78,158,94,193,101,42,128,214,128,155,98,134,84,40,82,174,112,141,136,209,141,225,108,120,84,218,128,249,87,244,136,84,141,106,150,77,145,105,79,155,108,183,85,198,118,48,120,168,98,249,112,142,111,109,95,236,132,218,104,124,120,247,123,168,129,11,103,79,158,103,99,176,120,111,87,18,120,57,151,121,98,171,98,136,82,53,116,215,107,106,130,107,130,108,130,109,130,113,130,117,130,118,130,119,130,120,130,123,130,124,130,128,130,129,130,131,130,133,130,134,130,135,130,137,130,140,130,144,130,147,130,148,130,149,130,150,130,154,130,155,130,158,130,160,130,162,130,163,130,167,130,178,130,181,130,182,130,186,130,187,130,188,130,191,130,192,130,194,130,195,130,197,130,198,130,201,130,208,130,214,130,217,130,218,130,221,130,226,130,231,130,232,130,233,130,234,130,236,130,237,130,238,130,240,130,242,130,243,130,245,130,246,130,248,130,250,130,252,130,253,130,254,130,255,130,0,131,10,131,11,131,13,131,16,131,18,131,19,131,22,131,24,131,25,131,29,131,30,131,31,131,32,131,33,131,34,131,35,131,36,131,37,131,38,131,41,131,42,131,46,131,48,131,50,131,55,131,59,131,61,131,100,85,62,129,178,117,174,118,57,83,222,117,251,80,65,92,108,139,199,123,79,80,71,114,151,154,216,152,2,111,226,116,104,121,135,100,165,119,252,98,145,152,43,141,193,84,88,128,82,78,106,87,249,130,13,132,115,94,237,81,246,116,196,139,79,92,97,87,252,108,135,152,70,90,52,120,68,155,235,143,149,124,86,82,81,98,250,148,198,78,134,131,97,132,233,131,178,132,212,87,52,103,3,87,110,102,102,109,49,140,221,102,17,112,31,103,58,107,22,104,26,98,187,89,3,78,196,81,6,111,210,103,143,108,118,81,203,104,71,89,103,107,102,117,14,93,16,129,80,159,215,101,72,121,65,121,145,154,119,141,130,92,94,78,1,79,47,84,81,89,12,120,104,86,20,108,196,143,3,95,125,108,227,108,171,139,144,99,62,131,63,131,65,131,66,131,68,131,69,131,72,131,74,131,75,131,76,131,77,131,78,131,83,131,85,131,86,131,87,131,88,131,89,131,93,131,98,131,112,131,113,131,114,131,115,131,116,131,117,131,118,131,121,131,122,131,126,131,127,131,128,131,129,131,130,131,131,131,132,131,135,131,136,131,138,131,139,131,140,131,141,131,143,131,144,131,145,131,148,131,149,131,150,131,151,131,153,131,154,131,157,131,159,131,161,131,162,131,163,131,164,131,165,131,166,131,167,131,172,131,173,131,174,131,175,131,181,131,187,131,190,131,191,131,194,131,195,131,196,131,198,131,200,131,201,131,203,131,205,131,206,131,208,131,209,131,210,131,211,131,213,131,215,131,217,131,218,131,219,131,222,131,226,131,227,131,228,131,230,131,231,131,232,131,235,131,236,131,237,131,112,96,61,109,117,114,102,98,142,148,197,148,67,83,193,143,126,123,223,78,38,140,126,78,212,158,177,148,179,148,77,82,92,111,99,144,69,109,52,140,17,88,76,93,32,107,73,107,170,103,91,84,84,129,140,127,153,88,55,133,58,95,162,98,71,106,57,149,114,101,132,96,101,104,167,119,84,78,168,79,231,93,152,151,172,100,216,127,237,92,207,79,141,122,7,82,4,131,20,78,47,96,131,122,166,148,181,79,178,78,230,121,52,116,228,82,185,130,210,100,189,121,221,91,129,108,82,151,123,143,34,108,62,80,127,83,5,110,206,100,116,102,48,108,197,96,119,152,247,139,134,94,60,116,119,122,203,121,24,78,177,144,3,116,66,108,218,86,75,145,197,108,139,141,58,83,198,134,242,102,175,142,72,92,113,154,32,110,238,131,239,131,243,131,244,131,245,131,246,131,247,131,250,131,251,131,252,131,254,131,255,131,0,132,2,132,5,132,7,132,8,132,9,132,10,132,16,132,18,132,19,132,20,132,21,132,22,132,23,132,25,132,26,132,27,132,30,132,31,132,32,132,33,132,34,132,35,132,41,132,42,132,43,132,44,132,45,132,46,132,47,132,48,132,50,132,51,132,52,132,53,132,54,132,55,132,57,132,58,132,59,132,62,132,63,132,64,132,65,132,66,132,67,132,68,132,69,132,71,132,72,132,73,132,74,132,75,132,76,132,77,132,78,132,79,132,80,132,82,132,83,132,84,132,85,132,86,132,88,132,93,132,94,132,95,132,96,132,98,132,100,132,101,132,102,132,103,132,104,132,106,132,110,132,111,132,112,132,114,132,116,132,119,132,121,132,123,132,124,132,214,83,54,90,139,159,163,141,187,83,8,87,167,152,67,103,155,145,201,108,104,81,202,117,243,98,172,114,56,82,157,82,58,127,148,112,56,118,116,83,74,158,183,105,110,120,192,150,217,136,164,127,54,113,195,113,137,81,211,103,228,116,228,88,24,101,183,86,169,139,118,153,112,98,213,126,249,96,237,112,236,88,193,78,186,78,205,95,231,151,251,78,164,139,3,82,138,89,171,126,84,98,205,78,229,101,14,98,56,131,201,132,99,131,141,135,148,113,182,110,185,91,210,126,151,81,201,99,212,103,137,128,57,131,21,136,18,81,122,91,130,89,177,143,115,78,93,108,101,81,37,137,111,143,46,150,74,133,94,116,16,149,240,149,166,109,229,130,49,95,146,100,18,109,40,132,110,129,195,156,94,88,91,141,9,78,193,83,125,132,126,132,127,132,128,132,129,132,131,132,132,132,133,132,134,132,138,132,141,132,143,132,144,132,145,132,146,132,147,132,148,132,149,132,150,132,152,132,154,132,155,132,157,132,158,132,159,132,160,132,162,132,163,132,164,132,165,132,166,132,167,132,168,132,169,132,170,132,171,132,172,132,173,132,174,132,176,132,177,132,179,132,181,132,182,132,183,132,187,132,188,132,190,132,192,132,194,132,195,132,197,132,198,132,199,132,200,132,203,132,204,132,206,132,207,132,210,132,212,132,213,132,215,132,216,132,217,132,218,132,219,132,220,132,222,132,225,132,226,132,228,132,231,132,232,132,233,132,234,132,235,132,237,132,238,132,239,132,241,132,242,132,243,132,244,132,245,132,246,132,247,132,248,132,249,132,250,132,251,132,253,132,254,132,0,133,1,133,2,133,30,79,99,101,81,104,211,85,39,78,20,100,154,154,107,98,194,90,95,116,114,130,169,109,238,104,231,80,142,131,2,120,64,103,57,82,153,108,177,126,187,80,101,85,94,113,91,123,82,102,202,115,235,130,73,103,113,92,32,82,125,113,107,136,234,149,85,150,197,100,97,141,179,129,132,85,85,108,71,98,46,127,146,88,36,79,70,85,79,141,76,102,10,78,26,92,243,136,162,104,78,99,13,122,231,112,141,130,250,82,246,151,17,92,232,84,181,144,205,126,98,89,74,141,199,134,12,130,13,130,102,141,68,100,4,92,81,97,137,109,62,121,190,139,55,120,51,117,123,84,56,79,171,142,241,109,32,90,197,126,94,121,136,108,161,91,118,90,26,117,190,128,78,97,23,110,240,88,31,117,37,117,114,114,71,83,243,126,3,133,4,133,5,133,6,133,7,133,8,133,9,133,10,133,11,133,13,133,14,133,15,133,16,133,18,133,20,133,21,133,22,133,24,133,25,133,27,133,28,133,29,133,30,133,32,133,34,133,35,133,36,133,37,133,38,133,39,133,40,133,41,133,42,133,45,133,46,133,47,133,48,133,49,133,50,133,51,133,52,133,53,133,54,133,62,133,63,133,64,133,65,133,66,133,68,133,69,133,70,133,71,133,75,133,76,133,77,133,78,133,79,133,80,133,81,133,82,133,83,133,84,133,85,133,87,133,88,133,90,133,91,133,92,133,93,133,95,133,96,133,97,133,98,133,99,133,101,133,102,133,103,133,105,133,106,133,107,133,108,133,109,133,110,133,111,133,112,133,113,133,115,133,117,133,118,133,119,133,120,133,124,133,125,133,127,133,128,133,129,133,1,119,219,118,105,82,220,128,35,87,8,94,49,89,238,114,189,101,127,110,215,139,56,92,113,134,65,83,243,119,254,98,246,101,192,78,223,152,128,134,158,91,198,139,242,83,226,119,127,79,78,92,118,154,203,89],"i8",ALLOC_NONE,Runtime.GLOBAL_BASE+240828),
	allocate([15,95,58,121,235,88,22,78,255,103,139,78,237,98,147,138,29,144,191,82,47,102,220,85,108,86,2,144,213,78,141,79,202,145,112,153,15,108,2,94,67,96,164,91,198,137,213,139,54,101,75,98,150,153,136,91,255,91,136,99,46,85,215,83,38,118,125,81,44,133,162,103,179,104,138,107,146,98,147,143,212,83,18,130,209,109,143,117,102,78,78,141,112,91,159,113,175,133,145,102,217,102,114,127,0,135,205,158,32,159,94,92,47,103,240,143,17,104,95,103,13,98,214,122,133,88,182,94,112,101,49,111,130,133,131,133,134,133,136,133,137,133,138,133,139,133,140,133,141,133,142,133,144,133,145,133,146,133,147,133,148,133,149,133,150,133,151,133,152,133,153,133,154,133,157,133,158,133,159,133,160,133,161,133,162,133,163,133,165,133,166,133,167,133,169,133,171,133,172,133,173,133,177,133,178,133,179,133,180,133,181,133,182,133,184,133,186,133,187,133,188,133,189,133,190,133,191,133,192,133,194,133,195,133,196,133,197,133,198,133,199,133,200,133,202,133,203,133,204,133,205,133,206,133,209,133,210,133,212,133,214,133,215,133,216,133,217,133,218,133,219,133,221,133,222,133,223,133,224,133,225,133,226,133,227,133,229,133,230,133,231,133,232,133,234,133,235,133,236,133,237,133,238,133,239,133,240,133,241,133,242,133,243,133,244,133,245,133,246,133,247,133,248,133,85,96,55,82,13,128,84,100,112,136,41,117,5,94,19,104,244,98,28,151,204,83,61,114,1,140,52,108,97,119,14,122,46,84,172,119,122,152,28,130,244,139,85,120,20,103,193,112,175,101,149,100,54,86,29,96,193,121,248,83,29,78,123,107,134,128,250,91,227,85,219,86,58,79,60,79,114,153,243,93,126,103,56,128,2,96,130,152,1,144,139,91,188,139,245,139,28,100,88,130,222,100,253,85,207,130,101,145,215,79,32,125,31,144,159,124,243,80,81,88,175,110,191,91,201,139,131,128,120,145,156,132,151,123,125,134,139,150,143,150,229,126,211,154,142,120,129,92,87,122,66,144,167,150,95,121,89,91,95,99,11,123,209,132,173,104,6,85,41,127,16,116,34,125,1,149,64,98,76,88,214,78,131,91,121,89,84,88,249,133,250,133,252,133,253,133,254,133,0,134,1,134,2,134,3,134,4,134,6,134,7,134,8,134,9,134,10,134,11,134,12,134,13,134,14,134,15,134,16,134,18,134,19,134,20,134,21,134,23,134,24,134,25,134,26,134,27,134,28,134,29,134,30,134,31,134,32,134,33,134,34,134,35,134,36,134,37,134,38,134,40,134,42,134,43,134,44,134,45,134,46,134,47,134,48,134,49,134,50,134,51,134,52,134,53,134,54,134,55,134,57,134,58,134,59,134,61,134,62,134,63,134,64,134,65,134,66,134,67,134,68,134,69,134,70,134,71,134,72,134,73,134,74,134,75,134,76,134,82,134,83,134,85,134,86,134,87,134,88,134,89,134,91,134,92,134,93,134,95,134,96,134,97,134,99,134,100,134,101,134,102,134,103,134,104,134,105,134,106,134,109,115,30,99,75,142,15,142,206,128,212,130,172,98,240,83,240,108,94,145,42,89,1,96,112,108,77,87,74,100,42,141,43,118,233,110,91,87,128,106,240,117,109,111,45,140,8,140,102,87,239,107,146,136,179,120,162,99,249,83,173,112,100,108,88,88,42,100,2,88,224,104,155,129,16,85,214,124,24,80,186,142,204,109,159,141,235,112,143,99,155,109,212,110,230,126,4,132,67,104,3,144,216,109,118,150,168,139,87,89,121,114,228,133,126,129,188,117,138,138,175,104,84,82,34,142,17,149,208,99,152,152,68,142,124,85,83,79,255,102,143,86,213,96,149,109,67,82,73,92,41,89,251,109,107,88,48,117,28,117,108,96,20,130,70,129,17,99,97,103,226,143,58,119,243,141,52,141,193,148,22,94,133,83,44,84,195,112,109,134,111,134,112,134,114,134,115,134,116,134,117,134,118,134,119,134,120,134,131,134,132,134,133,134,134,134,135,134,136,134,137,134,142,134,143,134,144,134,145,134,146,134,148,134,150,134,151,134,152,134,153,134,154,134,155,134,158,134,159,134,160,134,161,134,162,134,165,134,166,134,171,134,173,134,174,134,178,134,179,134,183,134,184,134,185,134,187,134,188,134,189,134,190,134,191,134,193,134,194,134,195,134,197,134,200,134,204,134,205,134,210,134,211,134,213,134,214,134,215,134,218,134,220,134,221,134,224,134,225,134,226,134,227,134,229,134,230,134,231,134,232,134,234,134,235,134,236,134,239,134,245,134,246,134,247,134,250,134,251,134,252,134,253,134,255,134,1,135,4,135,5,135,6,135,11,135,12,135,14,135,15,135,16,135,17,135,20,135,22,135,64,108,247,94,92,80,173,78,173,94,58,99,71,130,26,144,80,104,110,145,179,119,12,84,220,148,100,95,229,122,118,104,69,99,82,123,223,126,219,117,119,80,149,98,52,89,15,144,248,81,195,121,129,122,254,86,146,95,20,144,130,109,96,92,31,87,16,84,84,81,77,110,226,86,168,99,147,152,127,129,21,135,42,137,0,144,30,84,111,92,192,129,214,98,88,98,49,129,53,158,64,150,110,154,124,154,45,105,165,89,211,98,62,85,22,99,199,84,217,134,60,109,3,90,230,116,156,136,106,107,22,89,76,140,47,95,126,110,169,115,125,152,56,78,247,112,140,91,151,120,61,99,90,102,150,118,203,96,155,91,73,90,7,78,85,129,106,108,139,115,161,78,137,103,81,127,128,95,250,101,27,103,216,95,132,89,1,90,25,135,27,135,29,135,31,135,32,135,36,135,38,135,39,135,40,135,42,135,43,135,44,135,45,135,47,135,48,135,50,135,51,135,53,135,54,135,56,135,57,135,58,135,60,135,61,135,64,135,65,135,66,135,67,135,68,135,69,135,70,135,74,135,75,135,77,135,79,135,80,135,81,135,82,135,84,135,85,135,86,135,88,135,90,135,91,135,92,135,93,135,94,135,95,135,97,135,98,135,102,135,103,135,104,135,105,135,106,135,107,135,108,135,109,135,111,135,113,135,114,135,115,135,117,135,119,135,120,135,121,135,122,135,127,135,128,135,129,135,132,135,134,135,135,135,137,135,138,135,140,135,142,135,143,135,144,135,145,135,146,135,148,135,149,135,150,135,152,135,153,135,154,135,155,135,156,135,157,135,158,135,160,135,161,135,162,135,163,135,164,135,205,93,174,95,113,83,230,151,221,143,69,104,244,86,47,85,223,96,58,78,77,111,244,126,199,130,14,132,212,89,31,79,42,79,62,92,172,126,42,103,26,133,115,84,79,117,195,128,130,85,79,155,77,79,45,110,19,140,9,92,112,97,107,83,31,118,41,110,138,134,135,101,251,149,185,126,59,84,51,122,10,125,238,149,225,85,193,127,238,116,29,99,23,135,161,109,157,122,17,98,161,101,103,83,225,99,131,108,235,93,92,84,168,148,76,78,97,108,236,139,75,92,224,101,156,130,167,104,62,84,52,84,203,107,102,107,148,78,66,99,72,83,30,130,13,79,174,79,94,87,10,98,254,150,100,102,105,114,255,82,161,82,159,96,239,139,20,102,153,113,144,103,127,137,82,120,253,119,112,102,59,86,56,84,33,149,122,114,165,135,166,135,167,135,169,135,170,135,174,135,176,135,177,135,178,135,180,135,182,135,183,135,184,135,185,135,187,135,188,135,190,135,191,135,193,135,194,135,195,135,196,135,197,135,199,135,200,135,201,135,204,135,205,135,206,135,207,135,208,135,212,135,213,135,214,135,215,135,216,135,217,135,218,135,220,135,221,135,222,135,223,135,225,135,226,135,227,135,228,135,230,135,231,135,232,135,233,135,235,135,236,135,237,135,239,135,240,135,241,135,242,135,243,135,244,135,245,135,246,135,247,135,248,135,250,135,251,135,252,135,253,135,255,135,0,136,1,136,2,136,4,136,5,136,6,136,7,136,8,136,9,136,11,136,12,136,13,136,14,136,15,136,16,136,17,136,18,136,20,136,23,136,24,136,25,136,26,136,28,136,29,136,30,136,31,136,32,136,35,136,0,122,111,96,12,94,137,96,157,129,21,89,220,96,132,113,239,112,170,110,80,108,128,114,132,106,173,136,45,94,96,78,179,90,156,85,227,148,23,109,251,124,153,150,15,98,198,126,142,119,126,134,35,83,30,151,150,143,135,102,225,92,160,79,237,114,11,78,166,83,15,89,19,84,128,99,40,149,72,81,217,78,156,156,164,126,184,84,36,141,84,136,55,130,242,149,142,109,38,95,204,90,62,102,105,150,176,115,46,115,191,83,122,129,133,153,161,127,170,91,119,150,80,150,191,126,248,118,162,83,118,149,153,153,177,123,68,137,88,110,97,78,212,127,101,121,230,139,243,96,205,84,171,78,121,152,247,93,97,106,207,80,17,84,97,140,39,132,93,120,4,151,74,82,238,84,163,86,0,149,136,109,181,91,198,109,83,102,36,136,37,136,38,136,39,136,40,136,41,136,42,136,43,136,44,136,45,136,46,136,47,136,48,136,49,136,51,136,52,136,53,136,54,136,55,136,56,136,58,136,59,136,61,136,62,136,63,136,65,136,66,136,67,136,70,136,71,136,72,136,73,136,74,136,75,136,78,136,79,136,80,136,81,136,82,136,83,136,85,136,86,136,88,136,90,136,91,136,92,136,93,136,94,136,95,136,96,136,102,136,103,136,106,136,109,136,111,136,113,136,115,136,116,136,117,136,118,136,120,136,121,136,122,136,123,136,124,136,128,136,131,136,134,136,135,136,137,136,138,136,140,136,142,136,143,136,144,136,145,136,147,136,148,136,149,136,151,136,152,136,153,136,154,136,155,136,157,136,158,136,159,136,160,136,161,136,163,136,165,136,166,136,167,136,168,136,169,136,170,136,15,92,93,91,33,104,150,128,120,85,17,123,72,101,84,105,155,78,71,107,78,135,139,151,79,83,31,99,58,100,170,144,156,101,193,128,16,140,153,81,176,104,120,83,249,135,200,97,196,108,251,108,34,140,81,92,170,133,175,130,12,149,35,107,155,143,176,101,251,95,195,95,225,79,69,136,31,102,101,129,41,115,250,96,116,81,17,82,139,87,98,95,162,144,76,136,146,145,120,94,79,103,39,96,211,89,68,81,246,81,248,128,8,83,121,108,196,150,138,113,17,79,238,79,158,127,61,103,197,85,8,149,192,121,150,136,227,126,159,88,12,98,0,151,90,134,24,86,123,152,144,95,184,139,196,132,87,145,217,83,237,101,143,94,92,117,100,96,110,125,127,90,234,126,237,126,105,143,167,85,163,91,172,96,203,101,132,115,172,136,174,136,175,136,176,136,178,136,179,136,180,136,181,136,182,136,184,136,185,136,186,136,187,136,189,136,190,136,191,136,192,136,195,136,196,136,199,136,200,136,202,136,203,136,204,136,205,136,207,136,208,136,209,136,211,136,214,136,215,136,218,136,219,136,220,136,221,136,222,136,224,136,225,136,230,136,231,136,233,136,234,136,235,136,236,136,237,136,238,136,239,136,242,136,245,136,246,136,247,136,250,136,251,136,253,136,255,136,0,137,1,137,3,137,4,137,5,137,6,137,7,137,8,137,9,137,11,137,12,137,13,137,14,137,15,137,17,137,20,137,21,137,22,137,23,137,24,137,28,137,29,137,30,137,31,137,32,137,34,137,35,137,36,137,38,137,39,137,40,137,41,137,44,137,45,137,46,137,47,137,49,137,50,137,51,137,53,137,55,137,9,144,99,118,41,119,218,126,116,151,155,133,102,91,116,122,234,150,64,136,203,82,143,113,170,95,236,101,226,139,251,91,111,154,225,93,137,107,91,108,173,139,175,139,10,144,197,143,139,83,188,98,38,158,45,158,64,84,43,78,189,130,89,114,156,134,22,93,89,136,175,109,197,150,209,84,154,78,182,139,9,113,189,84,9,150,223,112,249,109,208,118,37,78,20,120,18,135,169,92,246,94,0,138,156,152,14,150,142,112,191,108,68,89,169,99,60,119,77,136,20,111,115,130,48,88,213,113,140,83,26,120,193,150,1,85,102,95,48,113,180,91,26,140,140,154,131,107,46,89,47,158,231,121,104,103,108,98,111,79,161,117,138,127,11,109,51,150,39,108,240,78,210,117,123,81,55,104,62,111,128,144,112,129,150,89,118,116,56,137,57,137,58,137,59,137,60,137,61,137,62,137,63,137,64,137,66,137,67,137,69,137,70,137,71,137,72,137,73,137,74,137,75,137,76,137,77,137,78,137,79,137,80,137,81,137,82,137,83,137,84,137,85,137,86,137,87,137,88,137,89,137,90,137,91,137,92,137,93,137,96,137,97,137,98,137,99,137,100,137,101,137,103,137,104,137,105,137,106,137,107,137,108,137,109,137,110,137,111,137,112,137,113,137,114,137,115,137,116,137,117,137,118,137,119,137,120,137,121,137,122,137,124,137,125,137,126,137,128,137,130,137,132,137,133,137,135,137,136,137,137,137,138,137,139,137,140,137,141,137,142,137,143,137,144,137,145,137,146,137,147,137,148,137,149,137,150,137,151,137,152,137,153,137,154,137,155,137,156,137,157,137,158,137,159,137,160,137,161,137,71,100,39,92,101,144,145,122,35,140,218,89,172,84,0,130,111,131,129,137,0,128,48,105,78,86,54,128,55,114,206,145,182,81,95,78,117,152,150,99,26,78,246,83,243,102,75,129,28,89,178,109,0,78,249,88,59,83,214,99,241,148,157,79,10,79,99,136,144,152,55,89,87,144,251,121,234,78,240,128,145,117,130,108,156,91,232,89,93,95,5,105,129,134,26,80,242,93,89,78,227,119,229,78,122,130,145,98,19,102,145,144,121,92,191,78,121,95,198,129,56,144,132,128,171,117,166,78,212,136,15,97,197,107,198,95,73,78,202,118,162,110,227,139,174,139,10,140,209,139,2,95,252,127,204,127,206,126,53,131,107,131,224,86,183,107,243,151,52,150,251,89,31,84,246,148,235,109,197,91,110,153,57,92,21,95,144,150,162,137,163,137,164,137,165,137,166,137,167,137,168,137,169,137,170,137,171,137,172,137,173,137,174,137,175,137,176,137,177,137,178,137,179,137,180,137,181,137,182,137,183,137,184,137,185,137,186,137,187,137,188,137,189,137,190,137,191,137,192,137,195,137,205,137,211,137,212,137,213,137,215,137,216,137,217,137,219,137,221,137,223,137,224,137,225,137,226,137,228,137,231,137,232,137,233,137,234,137,236,137,237,137,238,137,240,137,241,137,242,137,244,137,245,137,246,137,247,137,248,137,249,137,250,137,251,137,252,137,253,137,254,137,255,137,1,138,2,138,3,138,4,138,5,138,6,138,8,138,9,138,10,138,11,138,12,138,13,138,14,138,15,138,16,138,17,138,18,138,19,138,20,138,21,138,22,138,23,138,24,138,25,138,26,138,27,138,28,138,29,138,112,83,241,130,49,106,116,90,112,158,148,94,40,127,185,131,36,132,37,132,103,131,71,135,206,143,98,141,200,118,113,95,150,152,108,120,32,102,223,84,229,98,99,79,195,129,200,117,184,94,205,150,10,142,249,134,143,84,243,108,140,109,56,108,127,96,199,82,40,117,125,94,24,79,160,96,231,95,36,92,49,117,174,144,192,148,185,114,185,108,56,110,73,145,9,103,203,83,243,83,81,79,201,145,241,139,200,83,124,94,194,143,228,109,142,78,194,118,134,105,94,134,26,97,6,130,89,79,222,79,62,144,124,156,9,97,29,110,20,110,133,150,136,78,49,90,232,150,14,78,127,92,185,121,135,91,237,139,189,127,137,115,223,87,139,130,193,144,1,84,71,144,187,85,234,92,161,95,8,97,50,107,241,114,178,128,137,138,30,138,31,138,32,138,33,138,34,138,35,138,36,138,37,138,38,138,39,138,40,138,41,138,42,138,43,138,44,138,45,138,46,138,47,138,48,138,49,138,50,138,51,138,52,138,53,138,54,138,55,138,56,138,57,138,58,138,59,138,60,138,61,138,63,138,64,138,65,138,66,138,67,138,68,138,69,138,70,138,71,138,73,138,74,138,75,138,76,138,77,138,78,138,79,138,80,138,81,138,82,138,83,138,84,138,85,138,86,138,87,138,88,138,89,138,90,138,91,138,92,138,93,138,94,138,95,138,96,138,97,138,98,138,99,138,100,138,101,138,102,138,103,138,104,138,105,138,106,138,107,138,108,138,109,138,110,138,111,138,112,138,113,138,114,138,115,138,116,138,117,138,118,138,119,138,120,138,122,138,123,138,124,138,125,138,126,138,127,138,128,138,116,109,211,91,213,136,132,152,107,140,109,154,51,158,10,110,164,81,67,81,163,87,129,136,159,83,244,99,149,143,237,86,88,84,6,87,63,115,144,110,24,127,220,143,209,130,63,97,40,96,98,150,240,102,166,126,138,141,195,141,165,148,179,92,164,124,8,103,166,96,5,150,24,128,145,78,231,144,0,83,104,150,65,81,208,143,116,133,93,145,85,102,245,151,85,91,29,83,56,120,66,103,61,104,201,84,126,112,176,91,125,143,141,81,40,87,177,84,18,101,130,102,94,141,67,141,15,129,108,132,109,144,223,124,255,81,251,133,163,103,233,101,161,111,164,134,129,142,106,86,32,144,130,118,118,112,229,113,35,141,233,98,25,82,253,108,60,141,14,96,158,88,142,97,254,102,96,141,78,98,179,85,35,110,45,103,103,143,129,138,130,138,131,138,132,138,133,138,134,138,135,138,136,138,139,138,140,138,141,138,142,138,143,138,144,138,145,138,146,138,148,138,149,138,150,138,151,138,152,138,153,138,154,138,155,138,156,138,157,138,158,138,159,138,160,138,161,138,162,138,163,138,164,138,165,138,166,138,167,138,168,138,169,138,170,138,171,138,172,138,173,138,174,138,175,138,176,138,177,138,178,138,179,138,180,138,181,138,182,138,183,138,184,138,185,138,186,138,187,138,188,138,189,138,190,138,191,138,192,138,193,138,194,138,195,138,196,138,197,138,198,138,199,138,200,138,201,138,202,138,203,138,204,138,205,138,206,138,207,138,208,138,209,138,210,138,211,138,212,138,213,138,214,138,215,138,216,138,217,138,218,138,219,138,220,138,221,138,222,138,223,138,224,138,225,138,226,138,227,138,225,148,248,149,40,119,5,104,168,105,139,84,77,78,184,112,200,139,88,100,139,101,133,91,132,122,58,80,232,91,187,119,225,107,121,138,152,124,190,108,207,118,169,101,151,143,45,93,85,92,56,134,8,104,96,83,24,98,217,122,91,110,253,126,31,106,224,122,112,95,51,111,32,95,140,99,168,109,86,103,8,78,16,94,38,141,215,78,192,128,52,118,156,150,219,98,45,102,126,98,188,108,117,141,103,113,105,127,70,81,135,128,236,83,110,144,152,98,242,84,240,134,153,143,5,128,23,149,23,133,217,143,89,109,205,115,159,101,31,119,4,117,39,120,251,129,30,141,136,148,166,79,149,103,185,117,202,139,7,151,47,99,71,149,53,150,184,132,35,99,65,119,129,95,240,114,137,78,20,96,116,101,239,98,99,107,63,101,228,138,229,138,230,138,231,138,232,138,233,138,234,138,235,138,236,138,237,138,238,138,239,138,240,138,241,138,242,138,243,138,244,138,245,138,246,138,247,138,248,138,249,138,250,138,251,138,252,138,253,138,254,138,255,138,0,139,1,139,2,139,3,139,4,139,5,139,6,139,8,139,9,139,10,139,11,139,12,139,13,139,14,139,15,139,16,139,17,139,18,139,19,139,20,139,21,139,22,139,23,139,24,139,25,139,26,139,27,139,28,139,29,139,30,139,31,139,32,139,33,139,34,139,35,139,36,139,37,139,39,139,40,139,41,139,42,139,43,139,44,139,45,139,46,139,47,139,48,139,49,139,50,139,51,139,52,139,53,139,54,139,55,139,56,139,57,139,58,139,59,139,60,139,61,139,62,139,63,139,64,139,65,139,66,139,67,139,68,139,69,139,39,94,199,117,209,144,193,139,157,130,157,103,47,101,49,84,24,135,229,119,162,128,2,129,65,108,75,78,199,126,76,128,244,118,13,105,150,107,103,98,60,80,132,79,64,87,7,99,98,107,190,141,234,83,232,101,184,126,215,95,26,99,183,99,243,129,244,129,110,127,28,94,217,92,54,82,122,102,233,121,26,122,40,141,153,112,212,117,222,110,187,108,146,122,45,78,197,118,224,95,159,148,119,136,200,126,205,121,191,128,205,145,242,78,23,79,31,130,104,84,222,93,50,109,204,139,165,124,116,143,152,128,26,94,146,84,177,118,153,91,60,102,164,154,224,115,42,104,219,134,49,103,42,115,248,139,219,139,16,144,249,122,219,112,110,113,196,98,169,119,49,86,59,78,87,132,241,103,169,82,192,134,46,141,248,148,81,123,70,139,71,139,72,139,73,139,74,139,75,139,76,139,77,139,78,139,79,139,80,139,81,139,82,139,83,139,84,139,85,139,86,139,87,139,88,139,89,139,90,139,91,139,92,139,93,139,94,139,95,139,96,139,97,139,98,139,99,139,100,139,101,139,103,139,104,139,105,139,106,139,107,139,109,139,110,139,111,139,112,139,113,139,114,139,115,139,116,139,117,139,118,139,119,139,120,139,121,139,122,139,123,139,124,139,125,139,126,139,127,139,128,139,129,139,130,139,131,139,132,139,133,139,134,139,135,139,136,139,137,139,138,139,139,139,140,139,141,139,142,139,143,139,144,139,145,139,146,139,147,139,148,139,149,139,150,139,151,139,152,139,153,139,154,139,155,139,156,139,157,139,158,139,159,139,172,139,177,139,187,139,199,139,208,139,234,139,9,140,30,140,79,79,232,108,93,121,123,154,147,98,42,114,253,98,19,78,22,120,108,143,176,100,90,141,198,123,105,104,132,94,197,136,134,89,158,100,238,88,182,114,14,105,37,149,253,143,88,141,96,87,0,127,6,140,198,81,73,99,217,98,83,83,76,104,34,116,1,131,76,145,68,85,64,119,124,112,74,109,121,81,168,84,68,141,255,89,203,110,196,109,92,91,43,125,212,78,125,124,211,110,80,91,234,129,13,110,87,91,3,155,213,104,42,142,151,91,252,126,59,96,181,126,185,144,112,141,79,89,205,99,223,121,179,141,82,83,207,101,86,121,197,139,59,150,196,126,187,148,130,126,52,86,137,145,0,103,106,127,10,92,117,144,40,102,230,93,80,79,222,103,90,80,92,79,80,87,167,94,16,232,17,232,18,232,19,232,20,232,56,140,57,140,58,140,59,140,60,140,61,140,62,140,63,140,64,140,66,140,67,140,68,140,69,140,72,140,74,140,75,140,77,140,78,140,79,140,80,140,81,140,82,140,83,140,84,140,86,140,87,140,88,140,89,140,91,140,92,140,93,140,94,140,95,140,96,140,99,140,100,140,101,140,102,140,103,140,104,140,105,140,108,140,109,140,110,140,111,140,112,140,113,140,114,140,116,140,117,140,118,140,119,140,123,140,124,140,125,140,126,140,127,140,128,140,129,140,131,140,132,140,134,140,135,140,136,140,139,140,141,140,142,140,143,140,144,140,145,140,146,140,147,140,149,140,150,140,151,140,153,140,154,140,155,140,156,140,157,140,158,140,159,140,160,140,161,140,162,140,163,140,164,140,165,140,166,140,167,140,168,140,169,140,170,140,171,140,172,140,173,140,141,78,12,78,64,81,16,78,255,94,69,83,21,78,152,78,30,78,50,155,108,91,105,86,40,78,186,121,63,78,21,83,71,78,45,89,59,114,110,83,16,108,223,86,228,128,151,153,211,107,126,119,23,159,54,78,159,78,16,159,92,78,105,78,147,78,136,130,91,91,108,85,15,86,196,78,141,83,157,83,163,83,165,83,174,83,101,151,93,141,26,83,245,83,38,83,46,83,62,83,92,141,102,83,99,83,2,82,8,82,14,82,45,82,51,82,63,82,64,82,76,82,94,82,97,82,92,82,175,132,125,82,130,82,129,82,144,82,147,82,130,81,84,127,187,78,195,78,201,78,194,78,232,78,225,78,235,78,222,78,27,79,243,78,34,79,100,79,245,78,37,79,39,79,9,79,43,79,94,79,103,79,56,101,90,79,93,79,174,140,175,140,176,140,177,140,178,140,179,140,180,140,181,140,182,140,183,140,184,140,185,140,186,140,187,140,188,140,189,140,190,140,191,140,192,140,193,140,194,140,195,140,196,140,197,140,198,140,199,140,200,140,201,140,202,140,203,140,204,140,205,140,206,140,207,140,208,140,209,140,210,140,211,140,212,140,213,140,214,140,215,140,216,140,217,140,218,140,219,140,220,140,221,140,222,140,223,140,224,140,225,140,226,140,227,140,228,140,229,140,230,140,231,140,232,140,233,140,234,140,235,140,236,140,237,140,238,140,239,140,240,140,241,140,242,140,243,140,244,140,245,140,246,140,247,140,248,140,249,140,250,140,251,140,252,140,253,140,254,140,255,140,0,141,1,141,2,141,3,141,4,141,5,141,6,141,7,141,8,141,9,141,10,141,11,141,12,141,13,141,95,79,87,79,50,79,61,79,118,79,116,79,145,79,137,79,131,79,143,79,126,79,123,79,170,79,124,79,172,79,148,79,230,79,232,79,234,79,197,79,218,79,227,79,220,79,209,79,223,79,248,79,41,80,76,80,243,79,44,80,15,80,46,80,45,80,254,79,28,80,12,80,37,80,40,80,126,80,67,80,85,80,72,80,78,80,108,80,123,80,165,80,167,80,169,80,186,80,214,80,6,81,237,80,236,80,230,80,238,80,7,81,11,81,221,78,61,108,88,79,101,79,206,79,160,159,70,108,116,124,110,81,253,93,201,158,152,153,129,81,20,89,249,82,13,83,7,138,16,83,235,81,25,89,85,81,160,78,86,81,179,78,110,136,164,136,181,78,20,129,210,136,128,121,52,91,3,136,184,127,171,81,177,81,189,81,188,81,14,141,15,141,16,141,17,141,18,141,19,141,20,141,21,141,22,141,23,141,24,141,25,141,26,141,27,141,28,141,32,141,81,141,82,141,87,141,95,141,101,141,104,141,105,141,106,141,108,141,110,141,111,141,113,141,114,141,120,141,121,141,122,141,123,141,124,141,125,141,126,141,127,141,128,141,130,141,131,141,134,141,135,141,136,141,137,141,140,141,141,141,142,141,143,141,144,141,146,141,147,141,149,141,150,141,151,141,152,141,153,141,154,141,155,141,156,141,157,141,158,141,160,141,161,141,162,141,164,141,165,141,166,141,167,141,168,141,169,141,170,141,171,141,172,141,173,141,174,141,175,141,176,141,178,141,182,141,183,141,185,141,187,141,189,141,192,141,193,141,194,141,197,141,199,141,200,141,201,141,202,141,205,141,208,141,210,141,211,141,212,141,199,81,150,81,162,81,165,81,160,139,166,139,167,139,170,139,180,139,181,139,183,139,194,139,195,139,203,139,207,139,206,139,210,139,211,139,212,139,214,139,216,139,217,139,220,139,223,139,224,139,228,139,232,139,233,139,238,139,240,139,243,139,246,139,249,139,252,139,255,139,0,140,2,140,4,140,7,140,12,140,15,140,17,140,18,140,20,140,21,140,22,140,25,140,27,140,24,140,29,140,31,140,32,140,33,140,37,140,39,140,42,140,43,140,46,140,47,140,50,140,51,140,53,140,54,140,105,83,122,83,29,150,34,150,33,150,49,150,42,150,61,150,60,150,66,150,73,150,84,150,95,150,103,150,108,150,114,150,116,150,136,150,141,150,151,150,176,150,151,144,155,144,157,144,153,144,172,144,161,144,180,144,179,144,182,144,186,144,213,141,216,141,217,141,220,141,224,141,225,141,226,141,229,141,230,141,231,141,233,141,237,141,238,141,240,141,241,141,242,141,244,141,246,141,252,141,254,141,255,141,0,142,1,142,2,142,3,142,4,142,6,142,7,142,8,142,11,142,13,142,14,142,16,142,17,142,18,142,19,142,21,142,22,142,23,142,24,142,25,142,26,142,27,142,28,142,32,142,33,142,36,142,37,142,38,142,39,142,40,142,43,142,45,142,48,142,50,142,51,142,52,142,54,142,55,142,56,142,59,142,60,142,62,142,63,142,67,142,69,142,70,142,76,142,77,142,78,142,79,142,80,142,83,142,84,142,85,142,86,142,87,142,88,142,90,142,91,142,92,142,93,142,94,142,95,142,96,142,97,142,98,142,99,142,100,142,101,142,103,142,104,142,106,142,107,142,110,142,113,142,184,144,176,144,207,144,197,144,190,144,208,144,196,144,199,144,211,144,230,144,226,144,220,144,215,144,219,144,235,144,239,144,254,144,4,145,34,145,30,145,35,145,49,145,47,145,57,145,67,145,70,145,13,82,66,89,162,82,172,82,173,82,190,82,255,84,208,82,214,82,240,82,223,83,238,113,205,119,244,94,245,81,252,81,47,155,182,83,1,95,90,117,239,93,76,87,169,87,161,87,126,88,188,88,197,88,209,88,41,87,44,87,42,87,51,87,57,87,46,87,47,87,92,87,59,87,66,87,105,87,133,87,107,87,134,87,124,87,123,87,104,87,109,87,118,87,115,87,173,87,164,87,140,87,178,87,207,87,167,87,180,87,147,87,160,87,213,87,216,87,218,87,217,87,210,87,184,87,244,87,239,87,248,87,228,87,221,87,115,142,117,142,119,142,120,142,121,142,122,142,123,142,125,142,126,142,128,142,130,142,131,142,132,142,134,142,136,142,137,142,138,142,139,142,140,142,141,142,142,142,145,142,146,142,147,142,149,142,150,142,151,142,152,142,153,142,154,142,155,142,157,142,159,142,160,142,161,142,162,142,163,142,164,142,165,142,166,142,167,142,168,142,169,142,170,142,173,142,174,142,176,142,177,142,179,142,180,142,181,142,182,142,183,142,184,142,185,142,187,142,188,142,189,142,190,142,191,142,192,142,193,142,194,142,195,142,196,142,197,142,198,142,199,142,200,142,201,142,202,142,203,142,204,142,205,142,207,142,208,142,209,142,210,142,211,142,212,142,213,142,214,142,215,142,216,142,217,142,218,142,219,142,220,142,221,142,222,142,223,142,224,142,225,142,226,142,227,142,228,142,11,88,13,88,253,87,237,87,0,88,30,88,25,88,68,88,32,88,101,88,108,88,129,88,137,88,154,88,128,88,168,153,25,159,255,97,121,130,125,130,127,130,143,130,138,130,168,130,132,130,142,130,145,130,151,130,153,130,171,130,184,130,190,130,176,130,200,130,202,130,227,130,152,130,183,130,174,130,203,130,204,130,193,130,169,130,180,130,161,130,170,130,159,130,196,130,206,130,164,130,225,130,9,131,247,130,228,130,15,131,7,131,220,130,244,130,210,130,216,130,12,131,251,130,211,130,17,131,26,131,6,131,20,131,21,131,224,130,213,130,28,131,81,131,91,131,92,131,8,131,146,131,60,131,52,131,49,131,155,131,94,131,47,131,79,131,71,131,67,131,95,131,64,131,23,131,96,131,45,131,58,131,51,131,102,131,101,131,229,142,230,142,231,142,232,142,233,142,234,142,235,142,236,142,237,142,238,142,239,142,240,142,241,142,242,142,243,142,244,142,245,142,246,142,247,142,248,142,249,142,250,142,251,142,252,142,253,142,254,142,255,142,0,143,1,143,2,143,3,143,4,143,5,143,6,143,7,143,8,143,9,143,10,143,11,143,12,143,13,143,14,143,15,143,16,143,17,143,18,143,19,143,20,143,21,143,22,143,23,143,24,143,25,143,26,143,27,143,28,143,29,143,30,143,31,143,32,143,33,143,34,143,35,143,36,143,37,143,38,143,39,143,40,143,41,143,42,143,43,143,44,143,45,143,46,143,47,143,48,143,49,143,50,143,51,143,52,143,53,143,54,143,55,143,56,143,57,143,58,143,59,143,60,143,61,143,62,143,63,143,64,143,65,143,66,143,67,143,68,143,104,131,27,131,105,131,108,131,106,131,109,131,110,131,176,131,120,131,179,131,180,131,160,131,170,131,147,131,156,131,133,131,124,131,182,131,169,131,125,131,184,131,123,131,152,131,158,131,168,131,186,131,188,131,193,131,1,132,229,131,216,131,7,88,24,132,11,132,221,131,253,131,214,131,28,132,56,132,17,132,6,132,212,131,223,131,15,132,3,132,248,131,249,131,234,131,197,131,192,131,38,132,240,131,225,131,92,132,81,132,90,132,89,132,115,132,135,132,136,132,122,132,137,132,120,132,60,132,70,132,105,132,118,132,140,132,142,132,49,132,109,132,193,132,205,132,208,132,230,132,189,132,211,132,202,132,191,132,186,132,224,132,161,132,185,132,180,132,151,132,229,132,227,132,12,133,13,117,56,133,240,132,57,133,31,133,58,133,69,143,70,143,71,143,72,143,73,143,74,143,75,143,76,143,77,143,78,143,79,143,80,143,81,143,82,143,83,143,84,143,85,143,86,143,87,143,88,143,89,143,90,143,91,143,92,143,93,143,94,143,95,143,96,143,97,143,98,143,99,143,100,143,101,143,106,143,128,143,140,143,146,143,157,143,160,143,161,143,162,143,164,143,165,143,166,143,167,143,170,143,172,143,173,143,174,143,175,143,178,143,179,143,180,143,181,143,183,143,184,143,186,143,187,143,188,143,191,143,192,143,195,143,198,143,201,143,202,143,203,143,204,143,205,143,207,143,210,143,214,143,215,143,218,143,224,143,225,143,227,143,231,143,236,143,239,143,241,143,242,143,244,143,245,143,246,143,250,143,251,143,252,143,254,143,255,143,7,144,8,144,12,144,14,144,19,144,21,144,24,144,86,133,59,133,255,132,252,132,89,133,72,133,104,133,100,133,94,133,122,133,162,119,67,133,114,133,123,133,164,133,168,133,135,133,143,133,121,133,174,133,156,133,133,133,185,133,183,133,176,133,211,133,193,133,220,133,255,133,39,134,5,134,41,134,22,134,60,134,254,94,8,95,60,89,65,89,55,128,85,89,90,89,88,89,15,83,34,92,37,92,44,92,52,92,76,98,106,98,159,98,187,98,202,98,218,98,215,98,238,98,34,99,246,98,57,99,75,99,67,99,173,99,246,99,113,99,122,99,142,99,180,99,109,99,172,99,138,99,105,99,174,99,188,99,242,99,248,99,224,99,255,99,196,99,222,99,206,99,82,100,198,99,190,99,69,100,65,100,11,100,27,100,32,100,12,100,38,100,33,100,94,100,132,100,109,100,150,100,25,144,28,144,35,144,36,144,37,144,39,144,40,144,41,144,42,144,43,144,44,144,48,144,49,144,50,144,51,144,52,144,55,144,57,144,58,144,61,144,63,144,64,144,67,144,69,144,70,144,72,144,73,144,74,144,75,144,76,144,78,144,84,144,85,144,86,144,89,144,90,144,92,144,93,144,94,144,95,144,96,144,97,144,100,144,102,144,103,144,105,144,106,144,107,144,108,144,111,144,112,144,113,144,114,144,115,144,118,144,119,144,120,144,121,144,122,144,123,144,124,144,126,144,129,144,132,144,133,144,134,144,135,144,137,144,138,144,140,144,141,144,142,144,143,144,144,144,146,144,148,144,150,144,152,144,154,144,156,144,158,144,159,144,160,144,164,144,165,144,167,144,168,144,169,144,171,144,173,144,178,144,183,144,188,144,189,144,191,144,192,144,122,100,183,100,184,100,153,100,186,100,192,100,208,100,215,100,228,100,226,100,9,101,37,101,46,101,11,95,210,95,25,117,17,95,95,83,241,83,253,83,233,83,232,83,251,83,18,84,22,84,6,84,75,84,82,84,83,84,84,84,86,84,67,84,33,84,87,84,89,84,35,84,50,84,130,84,148,84,119,84,113,84,100,84,154,84,155,84,132,84,118,84,102,84,157,84,208,84,173,84,194,84,180,84,210,84,167,84,166,84,211,84,212,84,114,84,163,84,213,84,187,84,191,84,204,84,217,84,218,84,220,84,169,84,170,84,164,84,221,84,207,84,222,84,27,85,231,84,32,85,253,84,20,85,243,84,34,85,35,85,15,85,17,85,39,85,42,85,103,85,143,85,181,85,73,85,109,85,65,85,85,85,63,85,80,85,60,85,194,144,195,144,198,144,200,144,201,144,203,144,204,144,205,144,210,144,212,144,213,144,214,144,216,144,217,144,218,144,222,144,223,144,224,144,227,144,228,144,229,144,233,144,234,144,236,144,238,144,240,144,241,144,242,144,243,144,245,144,246,144,247,144,249,144,250,144,251,144,252,144,255,144,0,145,1,145,3,145,5,145,6,145,7,145,8,145,9,145,10,145,11,145,12,145,13,145,14,145,15,145,16,145,17,145,18,145,19,145,20,145,21,145,22,145,23,145,24,145,26,145,27,145,28,145,29,145,31,145,32,145,33,145,36,145,37,145,38,145,39,145,40,145,41,145,42,145,43,145,44,145,45,145,46,145,48,145,50,145,51,145,52,145,53,145,54,145,55,145,56,145,58,145,59,145,60,145,61,145,62,145,63,145,64,145,65,145,66,145,68,145,55,85,86,85,117,85,118,85,119,85,51,85,48,85,92,85,139,85,210,85,131,85,177,85,185,85,136,85,129,85,159,85,126,85,214,85,145,85,123,85,223,85,189,85,190,85,148,85,153,85,234,85,247,85,201,85,31,86,209,85,235,85,236,85,212,85,230,85,221,85,196,85,239,85,229,85,242,85,243,85,204,85,205,85,232,85,245,85,228,85,148,143,30,86,8,86,12,86,1,86,36,86,35,86,254,85,0,86,39,86,45,86,88,86,57,86,87,86,44,86,77,86,98,86,89,86,92,86,76,86,84,86,134,86,100,86,113,86,107,86,123,86,124,86,133,86,147,86,175,86,212,86,215,86,221,86,225,86,245,86,235,86,249,86,255,86,4,87,10,87,9,87,28,87,15,94,25,94,20,94,17,94,49,94,59,94,60,94,69,145,71,145,72,145,81,145,83,145,84,145,85,145,86,145,88,145,89,145,91,145,92,145,95,145,96,145,102,145,103,145,104,145,107,145,109,145,115,145,122,145,123,145,124,145,128,145,129,145,130,145,131,145,132,145,134,145,136,145,138,145,142,145,143,145,147,145,148,145,149,145,150,145,151,145,152,145,153,145,156,145,157,145,158,145,159,145,160,145,161,145,164,145,165,145,166,145,167,145,168,145,169,145,171,145,172,145,176,145,177,145,178,145,179,145,182,145,183,145,184,145,185,145,187,145,188,145,189,145,190,145,191,145,192,145,193,145,194,145,195,145,196,145,197,145,198,145,200,145,203,145,208,145,210,145,211,145,212,145,213,145,214,145,215,145,216,145,217,145,218,145,219,145,221,145,222,145,223,145,224,145,225,145,226,145,227,145,228,145,229,145,55,94,68,94,84,94,91,94,94,94,97,94,140,92,122,92,141,92,144,92,150,92,136,92,152,92,153,92,145,92,154,92,156,92,181,92,162,92,189,92,172,92,171,92,177,92,163,92,193,92,183,92,196,92,210,92,228,92,203,92,229,92,2,93,3,93,39,93,38,93,46,93,36,93,30,93,6,93,27,93,88,93,62,93,52,93,61,93,108,93,91,93,111,93,93,93,107,93,75,93,74,93,105,93,116,93,130,93,153,93,157,93,115,140,183,93,197,93,115,95,119,95,130,95,135,95,137,95,140,95,149,95,153,95,156,95,168,95,173,95,181,95,188,95,98,136,97,95,173,114,176,114,180,114,183,114,184,114,195,114,193,114,206,114,205,114,210,114,232,114,239,114,233,114,242,114,244,114,247,114,1,115,243,114,3,115,250,114,230,145,231,145,232,145,233,145,234,145,235,145,236,145,237,145,238,145,239,145,240,145,241,145,242,145,243,145,244,145,245,145,246,145,247,145,248,145,249,145,250,145,251,145,252,145,253,145,254,145,255,145,0,146,1,146,2,146,3,146,4,146,5,146,6,146,7,146,8,146,9,146,10,146,11,146,12,146,13,146,14,146,15,146,16,146,17,146,18,146,19,146,20,146,21,146,22,146,23,146,24,146,25,146,26,146,27,146,28,146,29,146,30,146,31,146,32,146,33,146,34,146,35,146,36,146,37,146,38,146,39,146,40,146,41,146,42,146,43,146,44,146,45,146,46,146,47,146,48,146,49,146,50,146,51,146,52,146,53,146,54,146,55,146,56,146,57,146,58,146,59,146,60,146,61,146,62,146,63,146,64,146,65,146,66,146,67,146,68,146,69,146,251,114,23,115,19,115,33,115,10,115,30,115,29,115,21,115,34,115,57,115,37,115,44,115,56,115,49,115,80,115,77,115,87,115,96,115,108,115,111,115,126,115,27,130,37,89,231,152,36,89,2,89,99,153,103,153,104,153,105,153,106,153,107,153,108,153,116,153,119,153,125,153,128,153,132,153,135,153,138,153,141,153,144,153,145,153,147,153,148,153,149,153,128,94,145,94,139,94,150,94,165,94,160,94,185,94,181,94,190,94,179,94,83,141,210,94,209,94,219,94,232,94,234,94,186,129,196,95,201,95,214,95,207,95,3,96,238,95,4,96,225,95,228,95,254,95,5,96,6,96,234,95,237,95,248,95,25,96,53,96,38,96,27,96,15,96,13,96,41,96,43,96,10,96,63,96,33,96,120,96,121,96,123,96,122,96,66,96,70,146,71,146,72,146,73,146,74,146,75,146,76,146,77,146,78,146,79,146,80,146,81,146,82,146,83,146,84,146,85,146,86,146,87,146,88,146,89,146,90,146,91,146,92,146,93,146,94,146,95,146,96,146,97,146,98,146,99,146,100,146,101,146,102,146,103,146,104,146,105,146,106,146,107,146,108,146,109,146,110,146,111,146,112,146,113,146,114,146,115,146,117,146,118,146,119,146,120,146,121,146,122,146,123,146,124,146,125,146,126,146,127,146,128,146,129,146,130,146,131,146,132,146,133,146,134,146,135,146,136,146,137,146,138,146,139,146,140,146,141,146,143,146,144,146,145,146,146,146,147,146,148,146,149,146,150,146,151,146,152,146,153,146,154,146,155,146,156,146,157,146,158,146,159,146,160,146,161,146,162,146,163,146,164,146,165,146,166,146,167,146,106,96,125,96,150,96,154,96,173,96,157,96,131,96,146,96,140,96,155,96,236,96,187,96,177,96,221,96,216,96,198,96,218,96,180,96,32,97,38,97,21,97,35,97,244,96,0,97,14,97,43,97,74,97,117,97,172,97,148,97,167,97,183,97,212,97,245,97,221,95,179,150,233,149,235,149,241,149,243,149,245,149,246,149,252,149,254,149,3,150,4,150,6,150,8,150,10,150,11,150,12,150,13,150,15,150,18,150,21,150,22,150,23,150,25,150,26,150,44,78,63,114,21,98,53,108,84,108,92,108,74,108,163,108,133,108,144,108,148,108,140,108,104,108,105,108,116,108,118,108,134,108,169,108,208,108,212,108,173,108,247,108,248,108,241,108,215,108,178,108,224,108,214,108,250,108,235,108,238,108,177,108,211,108,239,108,254,108,168,146,169,146,170,146,171,146,172,146,173,146,175,146,176,146,177,146,178,146,179,146,180,146,181,146,182,146,183,146,184,146,185,146,186,146,187,146,188,146,189,146,190,146,191,146,192,146,193,146,194,146,195,146,196,146,197,146,198,146,199,146,201,146,202,146,203,146,204,146,205,146,206,146,207,146,208,146,209,146,210,146,211,146,212,146,213,146,214,146,215,146,216,146,217,146,218,146,219,146,220,146,221,146,222,146,223,146,224,146,225,146,226,146,227,146,228,146,229,146,230,146,231,146,232,146,233,146,234,146,235,146,236,146,237,146,238,146,239,146,240,146,241,146,242,146,243,146,244,146,245,146,246,146,247,146,248,146,249,146,250,146,251,146,252,146,253,146,254,146,255,146,0,147,1,147,2,147,3,147,4,147,5,147,6,147,7,147,8,147,9,147,57,109,39,109,12,109,67,109,72,109,7,109,4,109,25,109,14,109,43,109,77,109,46,109,53,109,26,109,79,109,82,109,84,109,51,109,145,109,111,109,158,109,160,109,94,109,147,109,148,109,92,109,96,109,124,109,99,109,26,110,199,109,197,109,222,109,14,110,191,109,224,109,17,110,230,109,221,109,217,109,22,110,171,109,12,110,174,109,43,110,110,110,78,110,107,110,178,110,95,110,134,110,83,110,84,110,50,110,37,110,68,110,223,110,177,110,152,110,224,110,45,111,226,110,165,110,167,110,189,110,187,110,183,110,215,110,180,110,207,110,143,110,194,110,159,110,98,111,70,111,71,111,36,111,21,111,249,110,47,111,54,111,75,111,116,111,42,111,9,111,41,111,137,111,141,111,140,111,120,111,114,111,124,111,122,111,209,111,10,147,11,147,12,147,13,147,14,147,15,147,16,147,17,147,18,147,19,147,20,147,21,147,22,147,23,147,24,147,25,147,26,147,27,147,28,147,29,147,30,147,31,147,32,147,33,147,34,147,35,147,36,147,37,147,38,147,39,147,40,147,41,147,42,147,43,147,44,147,45,147,46,147,47,147,48,147,49,147,50,147,51,147,52,147,53,147,54,147,55,147,56,147,57,147,58,147,59,147,60,147,61,147,63,147,64,147,65,147,66,147,67,147,68,147,69,147,70,147,71,147,72,147,73,147,74,147,75,147,76,147,77,147,78,147,79,147,80,147,81,147,82,147,83,147,84,147,85,147,86,147,87,147,88,147,89,147,90,147,91,147,92,147,93,147,94,147,95,147,96,147,97,147,98,147,99,147,100,147,101,147,102,147,103,147,104,147,105,147,107,147,201,111,167,111,185,111,182,111,194,111,225,111,238,111,222,111,224,111,239,111,26,112,35,112,27,112,57,112,53,112,79,112,94,112,128,91],"i8",ALLOC_NONE,Runtime.GLOBAL_BASE+251068),
	allocate([132,91,149,91,147,91,165,91,184,91,47,117,158,154,52,100,228,91,238,91,48,137,240,91,71,142,7,139,182,143,211,143,213,143,229,143,238,143,228,143,233,143,230,143,243,143,232,143,5,144,4,144,11,144,38,144,17,144,13,144,22,144,33,144,53,144,54,144,45,144,47,144,68,144,81,144,82,144,80,144,104,144,88,144,98,144,91,144,185,102,116,144,125,144,130,144,136,144,131,144,139,144,80,95,87,95,86,95,88,95,59,92,171,84,80,92,89,92,113,91,99,92,102,92,188,127,42,95,41,95,45,95,116,130,60,95,59,155,110,92,129,89,131,89,141,89,169,89,170,89,163,89,108,147,109,147,110,147,111,147,112,147,113,147,114,147,115,147,116,147,117,147,118,147,119,147,120,147,121,147,122,147,123,147,124,147,125,147,126,147,127,147,128,147,129,147,130,147,131,147,132,147,133,147,134,147,135,147,136,147,137,147,138,147,139,147,140,147,141,147,142,147,144,147,145,147,146,147,147,147,148,147,149,147,150,147,151,147,152,147,153,147,154,147,155,147,156,147,157,147,158,147,159,147,160,147,161,147,162,147,163,147,164,147,165,147,166,147,167,147,168,147,169,147,170,147,171,147,172,147,173,147,174,147,175,147,176,147,177,147,178,147,179,147,180,147,181,147,182,147,183,147,184,147,185,147,186,147,187,147,188,147,189,147,190,147,191,147,192,147,193,147,194,147,195,147,196,147,197,147,198,147,199,147,200,147,201,147,203,147,204,147,205,147,151,89,202,89,171,89,158,89,164,89,210,89,178,89,175,89,215,89,190,89,5,90,6,90,221,89,8,90,227,89,216,89,249,89,12,90,9,90,50,90,52,90,17,90,35,90,19,90,64,90,103,90,74,90,85,90,60,90,98,90,117,90,236,128,170,90,155,90,119,90,122,90,190,90,235,90,178,90,210,90,212,90,184,90,224,90,227,90,241,90,214,90,230,90,216,90,220,90,9,91,23,91,22,91,50,91,55,91,64,91,21,92,28,92,90,91,101,91,115,91,81,91,83,91,98,91,117,154,119,154,120,154,122,154,127,154,125,154,128,154,129,154,133,154,136,154,138,154,144,154,146,154,147,154,150,154,152,154,155,154,156,154,157,154,159,154,160,154,162,154,163,154,165,154,167,154,159,126,161,126,163,126,165,126,168,126,169,126,206,147,207,147,208,147,209,147,210,147,211,147,212,147,213,147,215,147,216,147,217,147,218,147,219,147,220,147,221,147,222,147,223,147,224,147,225,147,226,147,227,147,228,147,229,147,230,147,231,147,232,147,233,147,234,147,235,147,236,147,237,147,238,147,239,147,240,147,241,147,242,147,243,147,244,147,245,147,246,147,247,147,248,147,249,147,250,147,251,147,252,147,253,147,254,147,255,147,0,148,1,148,2,148,3,148,4,148,5,148,6,148,7,148,8,148,9,148,10,148,11,148,12,148,13,148,14,148,15,148,16,148,17,148,18,148,19,148,20,148,21,148,22,148,23,148,24,148,25,148,26,148,27,148,28,148,29,148,30,148,31,148,32,148,33,148,34,148,35,148,36,148,37,148,38,148,39,148,40,148,41,148,42,148,43,148,44,148,45,148,46,148,173,126,176,126,190,126,192,126,193,126,194,126,201,126,203,126,204,126,208,126,212,126,215,126,219,126,224,126,225,126,232,126,235,126,238,126,239,126,241,126,242,126,13,127,246,126,250,126,251,126,254,126,1,127,2,127,3,127,7,127,8,127,11,127,12,127,15,127,17,127,18,127,23,127,25,127,28,127,27,127,31,127,33,127,34,127,35,127,36,127,37,127,38,127,39,127,42,127,43,127,44,127,45,127,47,127,48,127,49,127,50,127,51,127,53,127,122,94,127,117,219,93,62,117,149,144,142,115,145,115,174,115,162,115,159,115,207,115,194,115,209,115,183,115,179,115,192,115,201,115,200,115,229,115,217,115,124,152,10,116,233,115,231,115,222,115,186,115,242,115,15,116,42,116,91,116,38,116,37,116,40,116,48,116,46,116,44,116,47,148,48,148,49,148,50,148,51,148,52,148,53,148,54,148,55,148,56,148,57,148,58,148,59,148,60,148,61,148,63,148,64,148,65,148,66,148,67,148,68,148,69,148,70,148,71,148,72,148,73,148,74,148,75,148,76,148,77,148,78,148,79,148,80,148,81,148,82,148,83,148,84,148,85,148,86,148,87,148,88,148,89,148,90,148,91,148,92,148,93,148,94,148,95,148,96,148,97,148,98,148,99,148,100,148,101,148,102,148,103,148,104,148,105,148,106,148,108,148,109,148,110,148,111,148,112,148,113,148,114,148,115,148,116,148,117,148,118,148,119,148,120,148,121,148,122,148,123,148,124,148,125,148,126,148,127,148,128,148,129,148,130,148,131,148,132,148,145,148,150,148,152,148,199,148,207,148,211,148,212,148,218,148,230,148,251,148,28,149,32,149,27,116,26,116,65,116,92,116,87,116,85,116,89,116,119,116,109,116,126,116,156,116,142,116,128,116,129,116,135,116,139,116,158,116,168,116,169,116,144,116,167,116,210,116,186,116,234,151,235,151,236,151,76,103,83,103,94,103,72,103,105,103,165,103,135,103,106,103,115,103,152,103,167,103,117,103,168,103,158,103,173,103,139,103,119,103,124,103,240,103,9,104,216,103,10,104,233,103,176,103,12,104,217,103,181,103,218,103,179,103,221,103,0,104,195,103,184,103,226,103,14,104,193,103,253,103,50,104,51,104,96,104,97,104,78,104,98,104,68,104,100,104,131,104,29,104,85,104,102,104,65,104,103,104,64,104,62,104,74,104,73,104,41,104,181,104,143,104,116,104,119,104,147,104,107,104,194,104,110,105,252,104,31,105,32,105,249,104,39,149,51,149,61,149,67,149,72,149,75,149,85,149,90,149,96,149,110,149,116,149,117,149,119,149,120,149,121,149,122,149,123,149,124,149,125,149,126,149,128,149,129,149,130,149,131,149,132,149,133,149,134,149,135,149,136,149,137,149,138,149,139,149,140,149,141,149,142,149,143,149,144,149,145,149,146,149,147,149,148,149,149,149,150,149,151,149,152,149,153,149,154,149,155,149,156,149,157,149,158,149,159,149,160,149,161,149,162,149,163,149,164,149,165,149,166,149,167,149,168,149,169,149,170,149,171,149,172,149,173,149,174,149,175,149,176,149,177,149,178,149,179,149,180,149,181,149,182,149,183,149,184,149,185,149,186,149,187,149,188,149,189,149,190,149,191,149,192,149,193,149,194,149,195,149,196,149,197,149,198,149,199,149,200,149,201,149,202,149,203,149,36,105,240,104,11,105,1,105,87,105,227,104,16,105,113,105,57,105,96,105,66,105,93,105,132,105,107,105,128,105,152,105,120,105,52,105,204,105,135,105,136,105,206,105,137,105,102,105,99,105,121,105,155,105,167,105,187,105,171,105,173,105,212,105,177,105,193,105,202,105,223,105,149,105,224,105,141,105,255,105,47,106,237,105,23,106,24,106,101,106,242,105,68,106,62,106,160,106,80,106,91,106,53,106,142,106,121,106,61,106,40,106,88,106,124,106,145,106,144,106,169,106,151,106,171,106,55,115,82,115,129,107,130,107,135,107,132,107,146,107,147,107,141,107,154,107,155,107,161,107,170,107,107,143,109,143,113,143,114,143,115,143,117,143,118,143,120,143,119,143,121,143,122,143,124,143,126,143,129,143,130,143,132,143,135,143,139,143,204,149,205,149,206,149,207,149,208,149,209,149,210,149,211,149,212,149,213,149,214,149,215,149,216,149,217,149,218,149,219,149,220,149,221,149,222,149,223,149,224,149,225,149,226,149,227,149,228,149,229,149,230,149,231,149,236,149,255,149,7,150,19,150,24,150,27,150,30,150,32,150,35,150,36,150,37,150,38,150,39,150,40,150,41,150,43,150,44,150,45,150,47,150,48,150,55,150,56,150,57,150,58,150,62,150,65,150,67,150,74,150,78,150,79,150,81,150,82,150,83,150,86,150,87,150,88,150,89,150,90,150,92,150,93,150,94,150,96,150,99,150,101,150,102,150,107,150,109,150,110,150,111,150,112,150,113,150,115,150,120,150,121,150,122,150,123,150,124,150,125,150,126,150,127,150,128,150,129,150,130,150,131,150,132,150,135,150,137,150,138,150,141,143,142,143,143,143,152,143,154,143,206,142,11,98,23,98,27,98,31,98,34,98,33,98,37,98,36,98,44,98,231,129,239,116,244,116,255,116,15,117,17,117,19,117,52,101,238,101,239,101,240,101,10,102,25,102,114,103,3,102,21,102,0,102,133,112,247,102,29,102,52,102,49,102,54,102,53,102,6,128,95,102,84,102,65,102,79,102,86,102,97,102,87,102,119,102,132,102,140,102,167,102,157,102,190,102,219,102,220,102,230,102,233,102,50,141,51,141,54,141,59,141,61,141,64,141,69,141,70,141,72,141,73,141,71,141,77,141,85,141,89,141,199,137,202,137,203,137,204,137,206,137,207,137,208,137,209,137,110,114,159,114,93,114,102,114,111,114,126,114,127,114,132,114,139,114,141,114,143,114,146,114,8,99,50,99,176,99,140,150,142,150,145,150,146,150,147,150,149,150,150,150,154,150,155,150,157,150,158,150,159,150,160,150,161,150,162,150,163,150,164,150,165,150,166,150,168,150,169,150,170,150,171,150,172,150,173,150,174,150,175,150,177,150,178,150,180,150,181,150,183,150,184,150,186,150,187,150,191,150,194,150,195,150,200,150,202,150,203,150,208,150,209,150,211,150,212,150,214,150,215,150,216,150,217,150,218,150,219,150,220,150,221,150,222,150,223,150,225,150,226,150,227,150,228,150,229,150,230,150,231,150,235,150,236,150,237,150,238,150,240,150,241,150,242,150,244,150,245,150,248,150,250,150,251,150,252,150,253,150,255,150,2,151,3,151,5,151,10,151,11,151,12,151,16,151,17,151,18,151,20,151,21,151,23,151,24,151,25,151,26,151,27,151,29,151,31,151,32,151,63,100,216,100,4,128,234,107,243,107,253,107,245,107,249,107,5,108,7,108,6,108,13,108,21,108,24,108,25,108,26,108,33,108,41,108,36,108,42,108,50,108,53,101,85,101,107,101,77,114,82,114,86,114,48,114,98,134,22,82,159,128,156,128,147,128,188,128,10,103,189,128,177,128,171,128,173,128,180,128,183,128,231,128,232,128,233,128,234,128,219,128,194,128,196,128,217,128,205,128,215,128,16,103,221,128,235,128,241,128,244,128,237,128,13,129,14,129,242,128,252,128,21,103,18,129,90,140,54,129,30,129,44,129,24,129,50,129,72,129,76,129,83,129,116,129,89,129,90,129,113,129,96,129,105,129,124,129,125,129,109,129,103,129,77,88,181,90,136,129,130,129,145,129,213,110,163,129,170,129,204,129,38,103,202,129,187,129,33,151,34,151,35,151,36,151,37,151,38,151,39,151,40,151,41,151,43,151,44,151,46,151,47,151,49,151,51,151,52,151,53,151,54,151,55,151,58,151,59,151,60,151,61,151,63,151,64,151,65,151,66,151,67,151,68,151,69,151,70,151,71,151,72,151,73,151,74,151,75,151,76,151,77,151,78,151,79,151,80,151,81,151,84,151,85,151,87,151,88,151,90,151,92,151,93,151,95,151,99,151,100,151,102,151,103,151,104,151,106,151,107,151,108,151,109,151,110,151,111,151,112,151,113,151,114,151,117,151,119,151,120,151,121,151,122,151,123,151,125,151,126,151,127,151,128,151,129,151,130,151,131,151,132,151,134,151,135,151,136,151,137,151,138,151,140,151,142,151,143,151,144,151,147,151,149,151,150,151,151,151,153,151,154,151,155,151,156,151,157,151,193,129,166,129,36,107,55,107,57,107,67,107,70,107,89,107,209,152,210,152,211,152,213,152,217,152,218,152,179,107,64,95,194,107,243,137,144,101,81,159,147,101,188,101,198,101,196,101,195,101,204,101,206,101,210,101,214,101,128,112,156,112,150,112,157,112,187,112,192,112,183,112,171,112,177,112,232,112,202,112,16,113,19,113,22,113,47,113,49,113,115,113,92,113,104,113,69,113,114,113,74,113,120,113,122,113,152,113,179,113,181,113,168,113,160,113,224,113,212,113,231,113,249,113,29,114,40,114,108,112,24,113,102,113,185,113,62,98,61,98,67,98,72,98,73,98,59,121,64,121,70,121,73,121,91,121,92,121,83,121,90,121,98,121,87,121,96,121,111,121,103,121,122,121,133,121,138,121,154,121,167,121,179,121,209,95,208,95,158,151,159,151,161,151,162,151,164,151,165,151,166,151,167,151,168,151,169,151,170,151,172,151,174,151,176,151,177,151,179,151,181,151,182,151,183,151,184,151,185,151,186,151,187,151,188,151,189,151,190,151,191,151,192,151,193,151,194,151,195,151,196,151,197,151,198,151,199,151,200,151,201,151,202,151,203,151,204,151,205,151,206,151,207,151,208,151,209,151,210,151,211,151,212,151,213,151,214,151,215,151,216,151,217,151,218,151,219,151,220,151,221,151,222,151,223,151,224,151,225,151,226,151,227,151,228,151,229,151,232,151,238,151,239,151,240,151,241,151,242,151,244,151,247,151,248,151,249,151,250,151,251,151,252,151,253,151,254,151,255,151,0,152,1,152,2,152,3,152,4,152,5,152,6,152,7,152,8,152,9,152,10,152,11,152,12,152,13,152,14,152,60,96,93,96,90,96,103,96,65,96,89,96,99,96,171,96,6,97,13,97,93,97,169,97,157,97,203,97,209,97,6,98,128,128,127,128,147,108,246,108,252,109,246,119,248,119,0,120,9,120,23,120,24,120,17,120,171,101,45,120,28,120,29,120,57,120,58,120,59,120,31,120,60,120,37,120,44,120,35,120,41,120,78,120,109,120,86,120,87,120,38,120,80,120,71,120,76,120,106,120,155,120,147,120,154,120,135,120,156,120,161,120,163,120,178,120,185,120,165,120,212,120,217,120,201,120,236,120,242,120,5,121,244,120,19,121,36,121,30,121,52,121,155,159,249,158,251,158,252,158,241,118,4,119,13,119,249,118,7,119,8,119,26,119,34,119,25,119,45,119,38,119,53,119,56,119,80,119,81,119,71,119,67,119,90,119,104,119,15,152,16,152,17,152,18,152,19,152,20,152,21,152,22,152,23,152,24,152,25,152,26,152,27,152,28,152,29,152,30,152,31,152,32,152,33,152,34,152,35,152,36,152,37,152,38,152,39,152,40,152,41,152,42,152,43,152,44,152,45,152,46,152,47,152,48,152,49,152,50,152,51,152,52,152,53,152,54,152,55,152,56,152,57,152,58,152,59,152,60,152,61,152,62,152,63,152,64,152,65,152,66,152,67,152,68,152,69,152,70,152,71,152,72,152,73,152,74,152,75,152,76,152,77,152,78,152,79,152,80,152,81,152,82,152,83,152,84,152,85,152,86,152,87,152,88,152,89,152,90,152,91,152,92,152,93,152,94,152,95,152,96,152,97,152,98,152,99,152,100,152,101,152,102,152,103,152,104,152,105,152,106,152,107,152,108,152,109,152,110,152,98,119,101,119,127,119,141,119,125,119,128,119,140,119,145,119,159,119,160,119,176,119,181,119,189,119,58,117,64,117,78,117,75,117,72,117,91,117,114,117,121,117,131,117,88,127,97,127,95,127,72,138,104,127,116,127,113,127,121,127,129,127,126,127,205,118,229,118,50,136,133,148,134,148,135,148,139,148,138,148,140,148,141,148,143,148,144,148,148,148,151,148,149,148,154,148,155,148,156,148,163,148,164,148,171,148,170,148,173,148,172,148,175,148,176,148,178,148,180,148,182,148,183,148,184,148,185,148,186,148,188,148,189,148,191,148,196,148,200,148,201,148,202,148,203,148,204,148,205,148,206,148,208,148,209,148,210,148,213,148,214,148,215,148,217,148,216,148,219,148,222,148,223,148,224,148,226,148,228,148,229,148,231,148,232,148,234,148,111,152,112,152,113,152,114,152,115,152,116,152,139,152,142,152,146,152,149,152,153,152,163,152,168,152,169,152,170,152,171,152,172,152,173,152,174,152,175,152,176,152,177,152,178,152,179,152,180,152,181,152,182,152,183,152,184,152,185,152,186,152,187,152,188,152,189,152,190,152,191,152,192,152,193,152,194,152,195,152,196,152,197,152,198,152,199,152,200,152,201,152,202,152,203,152,204,152,205,152,207,152,208,152,212,152,214,152,215,152,219,152,220,152,221,152,224,152,225,152,226,152,227,152,228,152,229,152,230,152,233,152,234,152,235,152,236,152,237,152,238,152,239,152,240,152,241,152,242,152,243,152,244,152,245,152,246,152,247,152,248,152,249,152,250,152,251,152,252,152,253,152,254,152,255,152,0,153,1,153,2,153,3,153,4,153,5,153,6,153,7,153,233,148,235,148,238,148,239,148,243,148,244,148,245,148,247,148,249,148,252,148,253,148,255,148,3,149,2,149,6,149,7,149,9,149,10,149,13,149,14,149,15,149,18,149,19,149,20,149,21,149,22,149,24,149,27,149,29,149,30,149,31,149,34,149,42,149,43,149,41,149,44,149,49,149,50,149,52,149,54,149,55,149,56,149,60,149,62,149,63,149,66,149,53,149,68,149,69,149,70,149,73,149,76,149,78,149,79,149,82,149,83,149,84,149,86,149,87,149,88,149,89,149,91,149,94,149,95,149,93,149,97,149,98,149,100,149,101,149,102,149,103,149,104,149,105,149,106,149,107,149,108,149,111,149,113,149,114,149,115,149,58,149,231,119,236,119,201,150,213,121,237,121,227,121,235,121,6,122,71,93,3,122,2,122,30,122,20,122,8,153,9,153,10,153,11,153,12,153,14,153,15,153,17,153,18,153,19,153,20,153,21,153,22,153,23,153,24,153,25,153,26,153,27,153,28,153,29,153,30,153,31,153,32,153,33,153,34,153,35,153,36,153,37,153,38,153,39,153,40,153,41,153,42,153,43,153,44,153,45,153,47,153,48,153,49,153,50,153,51,153,52,153,53,153,54,153,55,153,56,153,57,153,58,153,59,153,60,153,61,153,62,153,63,153,64,153,65,153,66,153,67,153,68,153,69,153,70,153,71,153,72,153,73,153,74,153,75,153,76,153,77,153,78,153,79,153,80,153,81,153,82,153,83,153,86,153,87,153,88,153,89,153,90,153,91,153,92,153,93,153,94,153,95,153,96,153,97,153,98,153,100,153,102,153,115,153,120,153,121,153,123,153,126,153,130,153,131,153,137,153,57,122,55,122,81,122,207,158,165,153,112,122,136,118,142,118,147,118,153,118,164,118,222,116,224,116,44,117,32,158,34,158,40,158,41,158,42,158,43,158,44,158,50,158,49,158,54,158,56,158,55,158,57,158,58,158,62,158,65,158,66,158,68,158,70,158,71,158,72,158,73,158,75,158,76,158,78,158,81,158,85,158,87,158,90,158,91,158,92,158,94,158,99,158,102,158,103,158,104,158,105,158,106,158,107,158,108,158,113,158,109,158,115,158,146,117,148,117,150,117,160,117,157,117,172,117,163,117,179,117,180,117,184,117,196,117,177,117,176,117,195,117,194,117,214,117,205,117,227,117,232,117,230,117,228,117,235,117,231,117,3,118,241,117,252,117,255,117,16,118,0,118,5,118,12,118,23,118,10,118,37,118,24,118,21,118,25,118,140,153,142,153,154,153,155,153,156,153,157,153,158,153,159,153,160,153,161,153,162,153,163,153,164,153,166,153,167,153,169,153,170,153,171,153,172,153,173,153,174,153,175,153,176,153,177,153,178,153,179,153,180,153,181,153,182,153,183,153,184,153,185,153,186,153,187,153,188,153,189,153,190,153,191,153,192,153,193,153,194,153,195,153,196,153,197,153,198,153,199,153,200,153,201,153,202,153,203,153,204,153,205,153,206,153,207,153,208,153,209,153,210,153,211,153,212,153,213,153,214,153,215,153,216,153,217,153,218,153,219,153,220,153,221,153,222,153,223,153,224,153,225,153,226,153,227,153,228,153,229,153,230,153,231,153,232,153,233,153,234,153,235,153,236,153,237,153,238,153,239,153,240,153,241,153,242,153,243,153,244,153,245,153,246,153,247,153,248,153,249,153,27,118,60,118,34,118,32,118,64,118,45,118,48,118,63,118,53,118,67,118,62,118,51,118,77,118,94,118,84,118,92,118,86,118,107,118,111,118,202,127,230,122,120,122,121,122,128,122,134,122,136,122,149,122,166,122,160,122,172,122,168,122,173,122,179,122,100,136,105,136,114,136,125,136,127,136,130,136,162,136,198,136,183,136,188,136,201,136,226,136,206,136,227,136,229,136,241,136,26,137,252,136,232,136,254,136,240,136,33,137,25,137,19,137,27,137,10,137,52,137,43,137,54,137,65,137,102,137,123,137,139,117,229,128,178,118,180,118,220,119,18,128,20,128,22,128,28,128,32,128,34,128,37,128,38,128,39,128,41,128,40,128,49,128,11,128,53,128,67,128,70,128,77,128,82,128,105,128,113,128,131,137,120,152,128,152,131,152,250,153,251,153,252,153,253,153,254,153,255,153,0,154,1,154,2,154,3,154,4,154,5,154,6,154,7,154,8,154,9,154,10,154,11,154,12,154,13,154,14,154,15,154,16,154,17,154,18,154,19,154,20,154,21,154,22,154,23,154,24,154,25,154,26,154,27,154,28,154,29,154,30,154,31,154,32,154,33,154,34,154,35,154,36,154,37,154,38,154,39,154,40,154,41,154,42,154,43,154,44,154,45,154,46,154,47,154,48,154,49,154,50,154,51,154,52,154,53,154,54,154,55,154,56,154,57,154,58,154,59,154,60,154,61,154,62,154,63,154,64,154,65,154,66,154,67,154,68,154,69,154,70,154,71,154,72,154,73,154,74,154,75,154,76,154,77,154,78,154,79,154,80,154,81,154,82,154,83,154,84,154,85,154,86,154,87,154,88,154,89,154,137,152,140,152,141,152,143,152,148,152,154,152,155,152,158,152,159,152,161,152,162,152,165,152,166,152,77,134,84,134,108,134,110,134,127,134,122,134,124,134,123,134,168,134,141,134,139,134,172,134,157,134,167,134,163,134,170,134,147,134,169,134,182,134,196,134,181,134,206,134,176,134,186,134,177,134,175,134,201,134,207,134,180,134,233,134,241,134,242,134,237,134,243,134,208,134,19,135,222,134,244,134,223,134,216,134,209,134,3,135,7,135,248,134,8,135,10,135,13,135,9,135,35,135,59,135,30,135,37,135,46,135,26,135,62,135,72,135,52,135,49,135,41,135,55,135,63,135,130,135,34,135,125,135,126,135,123,135,96,135,112,135,76,135,110,135,139,135,83,135,99,135,124,135,100,135,89,135,101,135,147,135,175,135,168,135,210,135,90,154,91,154,92,154,93,154,94,154,95,154,96,154,97,154,98,154,99,154,100,154,101,154,102,154,103,154,104,154,105,154,106,154,107,154,114,154,131,154,137,154,141,154,142,154,148,154,149,154,153,154,166,154,169,154,170,154,171,154,172,154,173,154,174,154,175,154,178,154,179,154,180,154,181,154,185,154,187,154,189,154,190,154,191,154,195,154,196,154,198,154,199,154,200,154,201,154,202,154,205,154,206,154,207,154,208,154,210,154,212,154,213,154,214,154,215,154,217,154,218,154,219,154,220,154,221,154,222,154,224,154,226,154,227,154,228,154,229,154,231,154,232,154,233,154,234,154,236,154,238,154,240,154,241,154,242,154,243,154,244,154,245,154,246,154,247,154,248,154,250,154,252,154,253,154,254,154,255,154,0,155,1,155,2,155,4,155,5,155,6,155,198,135,136,135,133,135,173,135,151,135,131,135,171,135,229,135,172,135,181,135,179,135,203,135,211,135,189,135,209,135,192,135,202,135,219,135,234,135,224,135,238,135,22,136,19,136,254,135,10,136,27,136,33,136,57,136,60,136,54,127,66,127,68,127,69,127,16,130,250,122,253,122,8,123,3,123,4,123,21,123,10,123,43,123,15,123,71,123,56,123,42,123,25,123,46,123,49,123,32,123,37,123,36,123,51,123,62,123,30,123,88,123,90,123,69,123,117,123,76,123,93,123,96,123,110,123,123,123,98,123,114,123,113,123,144,123,166,123,167,123,184,123,172,123,157,123,168,123,133,123,170,123,156,123,162,123,171,123,180,123,209,123,193,123,204,123,221,123,218,123,229,123,230,123,234,123,12,124,254,123,252,123,15,124,22,124,11,124,7,155,9,155,10,155,11,155,12,155,13,155,14,155,16,155,17,155,18,155,20,155,21,155,22,155,23,155,24,155,25,155,26,155,27,155,28,155,29,155,30,155,32,155,33,155,34,155,36,155,37,155,38,155,39,155,40,155,41,155,42,155,43,155,44,155,45,155,46,155,48,155,49,155,51,155,52,155,53,155,54,155,55,155,56,155,57,155,58,155,61,155,62,155,63,155,64,155,70,155,74,155,75,155,76,155,78,155,80,155,82,155,83,155,85,155,86,155,87,155,88,155,89,155,90,155,91,155,92,155,93,155,94,155,95,155,96,155,97,155,98,155,99,155,100,155,101,155,102,155,103,155,104,155,105,155,106,155,107,155,108,155,109,155,110,155,111,155,112,155,113,155,114,155,115,155,116,155,117,155,118,155,119,155,120,155,121,155,122,155,123,155,31,124,42,124,38,124,56,124,65,124,64,124,254,129,1,130,2,130,4,130,236,129,68,136,33,130,34,130,35,130,45,130,47,130,40,130,43,130,56,130,59,130,51,130,52,130,62,130,68,130,73,130,75,130,79,130,90,130,95,130,104,130,126,136,133,136,136,136,216,136,223,136,94,137,157,127,159,127,167,127,175,127,176,127,178,127,124,124,73,101,145,124,157,124,156,124,158,124,162,124,178,124,188,124,189,124,193,124,199,124,204,124,205,124,200,124,197,124,215,124,232,124,110,130,168,102,191,127,206,127,213,127,229,127,225,127,230,127,233,127,238,127,243,127,248,124,119,125,166,125,174,125,71,126,155,126,184,158,180,158,115,141,132,141,148,141,145,141,177,141,103,141,109,141,71,140,73,140,74,145,80,145,78,145,79,145,100,145,124,155,125,155,126,155,127,155,128,155,129,155,130,155,131,155,132,155,133,155,134,155,135,155,136,155,137,155,138,155,139,155,140,155,141,155,142,155,143,155,144,155,145,155,146,155,147,155,148,155,149,155,150,155,151,155,152,155,153,155,154,155,155,155,156,155,157,155,158,155,159,155,160,155,161,155,162,155,163,155,164,155,165,155,166,155,167,155,168,155,169,155,170,155,171,155,172,155,173,155,174,155,175,155,176,155,177,155,178,155,179,155,180,155,181,155,182,155,183,155,184,155,185,155,186,155,187,155,188,155,189,155,190,155,191,155,192,155,193,155,194,155,195,155,196,155,197,155,198,155,199,155,200,155,201,155,202,155,203,155,204,155,205,155,206,155,207,155,208,155,209,155,210,155,211,155,212,155,213,155,214,155,215,155,216,155,217,155,218,155,219,155,98,145,97,145,112,145,105,145,111,145,125,145,126,145,114,145,116,145,121,145,140,145,133,145,144,145,141,145,145,145,162,145,163,145,170,145,173,145,174,145,175,145,181,145,180,145,186,145,85,140,126,158,184,141,235,141,5,142,89,142,105,142,181,141,191,141,188,141,186,141,196,141,214,141,215,141,218,141,222,141,206,141,207,141,219,141,198,141,236,141,247,141,248,141,227,141,249,141,251,141,228,141,9,142,253,141,20,142,29,142,31,142,44,142,46,142,35,142,47,142,58,142,64,142,57,142,53,142,61,142,49,142,73,142,65,142,66,142,81,142,82,142,74,142,112,142,118,142,124,142,111,142,116,142,133,142,143,142,148,142,144,142,156,142,158,142,120,140,130,140,138,140,133,140,152,140,148,140,155,101,214,137,222,137,218,137,220,137,220,155,221,155,222,155,223,155,224,155,225,155,226,155,227,155,228,155,229,155,230,155,231,155,232,155,233,155,234,155,235,155,236,155,237,155,238,155,239,155,240,155,241,155,242,155,243,155,244,155,245,155,246,155,247,155,248,155,249,155,250,155,251,155,252,155,253,155,254,155,255,155,0,156,1,156,2,156,3,156,4,156,5,156,6,156,7,156,8,156,9,156,10,156,11,156,12,156,13,156,14,156,15,156,16,156,17,156,18,156,19,156,20,156,21,156,22,156,23,156,24,156,25,156,26,156,27,156,28,156,29,156,30,156,31,156,32,156,33,156,34,156,35,156,36,156,37,156,38,156,39,156,40,156,41,156,42,156,43,156,44,156,45,156,46,156,47,156,48,156,49,156,50,156,51,156,52,156,53,156,54,156,55,156,56,156,57,156,58,156,59,156,229,137,235,137,239,137,62,138,38,139,83,151,233,150,243,150,239,150,6,151,1,151,8,151,15,151,14,151,42,151,45,151,48,151,62,151,128,159,131,159,133,159,134,159,135,159,136,159,137,159,138,159,140,159,254,158,11,159,13,159,185,150,188,150,189,150,206,150,210,150,191,119,224,150,142,146,174,146,200,146,62,147,106,147,202,147,143,147,62,148,107,148,127,156,130,156,133,156,134,156,135,156,136,156,35,122,139,156,142,156,144,156,145,156,146,156,148,156,149,156,154,156,155,156,158,156,159,156,160,156,161,156,162,156,163,156,165,156,166,156,167,156,168,156,169,156,171,156,173,156,174,156,176,156,177,156,178,156,179,156,180,156,181,156,182,156,183,156,186,156,187,156,188,156,189,156,196,156,197,156,198,156,199,156,202,156,203,156,60,156,61,156,62,156,63,156,64,156,65,156,66,156,67,156,68,156,69,156,70,156,71,156,72,156,73,156,74,156,75,156,76,156,77,156,78,156,79,156,80,156,81,156,82,156,83,156,84,156,85,156,86,156,87,156,88,156,89,156,90,156,91,156,92,156,93,156,94,156,95,156,96,156,97,156,98,156,99,156,100,156,101,156,102,156,103,156,104,156,105,156,106,156,107,156,108,156,109,156,110,156,111,156,112,156,113,156,114,156,115,156,116,156,117,156,118,156,119,156,120,156,121,156,122,156,123,156,125,156,126,156,128,156,131,156,132,156,137,156,138,156,140,156,143,156,147,156,150,156,151,156,152,156,153,156,157,156,170,156,172,156,175,156,185,156,190,156,191,156,192,156,193,156,194,156,200,156,201,156,209,156,210,156,218,156,219,156,224,156,225,156,204,156,205,156,206,156,207,156,208,156,211,156,212,156,213,156,215,156,216,156,217,156,220,156,221,156,223,156,226,156,124,151,133,151,145,151,146,151,148,151,175,151,171,151,163,151,178,151,180,151,177,154,176,154,183,154,88,158,182,154,186,154,188,154,193,154,192,154,197,154,194,154,203,154,204,154,209,154,69,155,67,155,71,155,73,155,72,155,77,155,81,155,232,152,13,153,46,153,85,153,84,153,223,154,225,154,230,154,239,154,235,154,251,154,237,154,249,154,8,155,15,155,19,155,31,155,35,155,189,158,190,158,59,126,130,158,135,158,136,158,139,158,146,158,214,147,157,158,159,158,219,158,220,158,221,158,224,158,223,158,226,158,233,158,231,158,229,158,234,158,239,158,34,159,44,159,47,159,57,159,55,159,61,159,62,159,68,159,227,156,228,156,229,156,230,156,231,156,232,156,233,156,234,156,235,156,236,156,237,156,238,156,239,156,240,156,241,156,242,156,243,156,244,156,245,156,246,156,247,156,248,156,249,156,250,156,251,156,252,156,253,156,254,156,255,156,0,157,1,157,2,157,3,157,4,157,5,157,6,157,7,157,8,157,9,157,10,157,11,157,12,157,13,157,14,157,15,157,16,157,17,157,18,157,19,157,20,157,21,157,22,157,23,157,24,157,25,157,26,157,27,157,28,157,29,157,30,157,31,157,32,157,33,157,34,157,35,157,36,157,37,157,38,157,39,157,40,157,41,157,42,157,43,157,44,157,45,157,46,157,47,157,48,157,49,157,50,157,51,157,52,157,53,157,54,157,55,157,56,157,57,157,58,157,59,157,60,157,61,157,62,157,63,157,64,157,65,157,66,157,52,226,53,226,54,226,55,226,56,226,57,226,58,226,59,226,60,226,61,226,62,226,63,226,64,226,65,226,66,226,67,226,68,226,69,226,70,226,71,226,72,226,73,226,74,226,75,226,76,226,77,226,78,226,79,226,80,226,81,226,82,226,83,226,84,226,85,226,86,226,87,226,88,226,89,226,90,226,91,226,92,226,93,226,94,226,95,226,96,226,97,226,98,226,99,226,100,226,101,226,102,226,103,226,104,226,105,226,106,226,107,226,108,226,109,226,110,226,111,226,112,226,113,226,114,226,115,226,116,226,117,226,118,226,119,226,120,226,121,226,122,226,123,226,124,226,125,226,126,226,127,226,128,226,129,226,130,226,131,226,132,226,133,226,134,226,135,226,136,226,137,226,138,226,139,226,140,226,141,226,142,226,143,226,144,226,145,226,67,157,68,157,69,157,70,157,71,157,72,157,73,157,74,157,75,157,76,157,77,157,78,157,79,157,80,157,81,157,82,157,83,157,84,157,85,157,86,157,87,157,88,157,89,157,90,157,91,157,92,157,93,157,94,157,95,157,96,157,97,157,98,157,99,157,100,157,101,157,102,157,103,157,104,157,105,157,106,157,107,157,108,157,109,157,110,157,111,157,112,157,113,157,114,157,115,157,116,157,117,157,118,157,119,157,120,157,121,157,122,157,123,157,124,157,125,157,126,157,127,157,128,157,129,157,130,157,131,157,132,157,133,157,134,157,135,157,136,157,137,157,138,157,139,157,140,157,141,157,142,157,143,157,144,157,145,157,146,157,147,157,148,157,149,157,150,157,151,157,152,157,153,157,154,157,155,157,156,157,157,157,158,157,159,157,160,157,161,157,162,157,146,226,147,226,148,226,149,226,150,226,151,226,152,226,153,226,154,226,155,226,156,226,157,226,158,226,159,226,160,226,161,226,162,226,163,226,164,226,165,226,166,226,167,226,168,226,169,226,170,226,171,226,172,226,173,226,174,226,175,226,176,226,177,226,178,226,179,226,180,226,181,226,182,226,183,226,184,226,185,226,186,226,187,226,188,226,189,226,190,226,191,226,192,226,193,226,194,226,195,226,196,226,197,226,198,226,199,226,200,226,201,226,202,226,203,226,204,226,205,226,206,226,207,226,208,226,209,226,210,226,211,226,212,226,213,226,214,226,215,226,216,226,217,226,218,226,219,226,220,226,221,226,222,226,223,226,224,226,225,226,226,226,227,226,228,226,229,226,230,226,231,226,232,226,233,226,234,226,235,226,236,226,237,226,238,226,239,226,163,157,164,157,165,157,166,157,167,157,168,157,169,157,170,157,171,157,172,157,173,157,174,157,175,157,176,157,177,157,178,157,179,157,180,157,181,157,182,157,183,157,184,157,185,157,186,157,187,157,188,157,189,157,190,157,191,157,192,157,193,157,194,157,195,157,196,157,197,157,198,157,199,157,200,157,201,157,202,157,203,157,204,157,205,157,206,157,207,157,208,157,209,157,210,157,211,157,212,157,213,157,214,157,215,157,216,157,217,157,218,157,219,157,220,157,221,157,222,157,223,157,224,157,225,157,226,157,227,157,228,157,229,157,230,157,231,157,232,157,233,157,234,157,235,157,236,157,237,157,238,157,239,157,240,157,241,157,242,157,243,157,244,157,245,157,246,157,247,157,248,157,249,157,250,157,251,157,252,157,253,157,254,157,255,157,0,158,1,158,2,158,240,226,241,226,242,226,243,226,244,226,245,226,246,226,247,226,248,226,249,226,250,226,251,226,252,226,253,226,254,226,255,226,0,227,1,227,2,227,3,227,4,227,5,227,6,227,7,227,8,227,9,227,10,227,11,227,12,227,13,227,14,227,15,227,16,227,17,227,18,227,19,227,20,227,21,227,22,227,23,227,24,227,25,227,26,227,27,227,28,227,29,227,30,227,31,227,32,227,33,227,34,227,35,227,36,227,37,227,38,227,39,227,40,227,41,227,42,227,43,227,44,227,45,227,46,227,47,227,48,227,49,227,50,227,51,227,52,227,53,227,54,227,55,227,56,227,57,227,58,227,59,227,60,227,61,227,62,227,63,227,64,227,65,227,66,227,67,227,68,227,69,227,70,227,71,227,72,227,73,227,74,227,75,227,76,227,77,227,3,158,4,158,5,158,6,158,7,158,8,158,9,158,10,158,11,158,12,158,13,158,14,158,15,158,16,158,17,158,18,158,19,158,20,158,21,158,22,158,23,158,24,158,25,158,26,158,27,158,28,158,29,158,30,158,36,158,39,158,46,158,48,158,52,158,59,158,60,158,64,158,77,158,80,158,82,158,83,158,84,158,86,158,89,158,93,158,95,158,96,158,97,158,98,158,101,158,110,158,111,158,114,158,116,158,117,158,118,158,119,158,120,158,121,158,122,158,123,158,124,158,125,158,128,158,129,158,131,158,132,158,133,158,134,158,137,158,138,158,140,158,141,158,142,158,143,158,144,158,145,158,148,158,149,158,150,158,151,158,152,158,153,158,154,158,155,158,156,158,158,158,160,158,161,158,162,158,163,158,164,158,165,158,167,158,168,158,169,158,170,158,78,227,79,227,80,227,81,227,82,227,83,227,84,227,85,227,86,227,87,227,88,227,89,227,90,227,91,227,92,227,93,227,94,227,95,227,96,227,97,227,98,227,99,227,100,227,101,227,102,227,103,227,104,227,105,227,106,227,107,227,108,227,109,227,110,227,111,227,112,227,113,227,114,227,115,227,116,227,117,227,118,227,119,227,120,227,121,227,122,227,123,227,124,227,125,227,126,227,127,227,128,227,129,227,130,227,131,227,132,227,133,227,134,227,135,227,136,227,137,227,138,227,139,227,140,227,141,227,142,227,143,227,144,227,145,227,146,227,147,227,148,227,149,227,150,227,151,227,152,227,153,227,154,227,155,227,156,227,157,227,158,227,159,227,160,227,161,227,162,227,163,227,164,227,165,227,166,227,167,227,168,227,169,227,170,227,171,227,171,158,172,158,173,158,174,158,175,158,176,158,177,158,178,158,179,158,181,158,182,158,183,158,185,158,186,158,188,158,191,158,192,158,193,158,194,158,195,158,197,158,198,158,199,158,200,158,202,158,203,158,204,158,208,158,210,158,211,158,213,158,214,158,215,158,217,158,218,158,222,158,225,158,227,158,228,158,230,158,232,158,235,158,236,158,237,158,238,158,240,158,241,158,242,158,243,158,244,158,245,158,246,158,247,158,248,158,250,158,253,158,255,158,0,159,1,159,2,159,3,159,4,159,5,159,6,159,7,159,8,159,9,159,10,159,12,159,15,159,17,159,18,159,20,159,21,159,22,159,24,159,26,159,27,159,28,159,29,159,30,159,31,159,33,159,35,159,36,159,37,159,38,159,39,159,40,159,41,159,42,159,43,159,45,159,46,159,48,159,49,159,172,227,173,227,174,227,175,227,176,227,177,227,178,227,179,227,180,227,181,227,182,227,183,227,184,227,185,227,186,227,187,227,188,227,189,227,190,227,191,227,192,227,193,227,194,227,195,227,196,227,197,227,198,227,199,227,200,227,201,227,202,227,203,227,204,227,205,227,206,227,207,227,208,227,209,227,210,227,211,227,212,227,213,227,214,227,215,227,216,227,217,227,218,227,219,227,220,227,221,227,222,227,223,227,224,227,225,227,226,227,227,227,228,227,229,227,230,227,231,227,232,227,233,227,234,227,235,227,236,227,237,227,238,227,239,227,240,227,241,227,242,227,243,227,244,227,245,227,246,227,247,227,248,227,249,227,250,227,251,227,252,227,253,227,254,227,255,227,0,228,1,228,2,228,3,228,4,228,5,228,6,228,7,228,8,228,9,228,50,159,51,159,52,159,53,159,54,159,56,159,58,159,60,159,63,159,64,159,65,159,66,159,67,159,69,159,70,159,71,159,72,159,73,159,74,159,75,159,76,159,77,159,78,159,79,159,82,159,83,159,84,159,85,159,86,159,87,159,88,159,89,159,90,159,91,159,92,159,93,159,94,159,95,159,96,159,97,159,98,159,99,159,100,159,101,159,102,159,103,159,104,159,105,159,106,159,107,159,108,159,109,159,110,159,111,159,112,159,113,159,114,159,115,159,116,159,117,159,118,159,119,159,120,159,121,159,122,159,123,159,124,159,125,159,126,159,129,159,130,159,141,159,142,159,143,159,144,159,145,159,146,159,147,159,148,159,149,159,150,159,151,159,152,159,156,159,157,159,158,159,161,159,162,159,163,159,164,159,165,159,44,249,121,249,149,249,231,249,241,249,10,228,11,228,12,228,13,228,14,228,15,228,16,228,17,228,18,228,19,228,20,228,21,228,22,228,23,228,24,228,25,228,26,228,27,228,28,228,29,228,30,228,31,228,32,228,33,228,34,228,35,228,36,228,37,228,38,228,39,228,40,228,41,228,42,228,43,228,44,228,45,228,46,228,47,228,48,228,49,228,50,228,51,228,52,228,53,228,54,228,55,228,56,228,57,228,58,228,59,228,60,228,61,228,62,228,63,228,64,228,65,228,66,228,67,228,68,228,69,228,70,228,71,228,72,228,73,228,74,228,75,228,76,228,77,228,78,228,79,228,80,228,81,228,82,228,83,228,84,228,85,228,86,228,87,228,88,228,89,228,90,228,91,228,92,228,93,228,94,228,95,228,96,228,97,228,98,228,99,228,100,228,101,228,102,228,103,228,12,250,13,250,14,250,15,250,17,250,19,250,20,250,24,250,31,250,32,250,33,250,35,250,36,250,39,250,40,250,41,250,129,46,22,232,23,232,24,232,132,46,115,52,71,52,136,46,139,46,30,232,158,53,26,54,14,54,140,46,151,46,110,57,24,57,38,232,207,57,223,57,115,58,208,57,43,232,44,232,78,59,110,60,224,60,167,46,49,232,50,232,170,46,86,64,95,65,174,46,55,67,179,46,182,46,183,46,59,232,177,67,172,67,187,46,221,67,214,68,97,70,76,70,67,232,35,71,41,71,124,71,141,71,202,46,71,73,122,73,125,73,130,73,131,73,133,73,134,73,159,73,155,73,183,73,182,73,84,232,85,232,163,76,159,76,160,76,161,76,119,76,162,76,19,77,20,77,21,77,22,77,23,77,24,77,25,77,174,77,100,232,104,228,105,228,106,228,107,228,108,228,109,228,110,228,111,228,112,228,113,228,114,228,115,228,116,228,117,228,118,228,119,228,120,228,121,228,122,228,123,228,124,228,125,228,126,228,127,228,128,228,129,228,130,228,131,228,132,228,133,228,134,228,135,228,136,228,137,228,138,228,139,228,140,228,141,228,142,228,143,228,144,228,145,228,146,228,147,228,148,228,149,228,150,228,151,228,152,228,153,228,154,228,155,228,156,228,157,228,158,228,159,228,160,228,161,228,162,228,163,228,164,228,165,228,166,228,167,228,168,228,169,228,170,228,171,228,172,228,173,228,174,228,175,228,176,228,177,228,178,228,179,228,180,228,181,228,182,228,183,228,184,228,185,228,186,228,187,228,188,228,189,228,190,228,191,228,192,228,193,228,194,228,195,228,196,228,197,228,240,67,50,76,3,70,166,69,120,69,103,114,119,77,179,69,177,124,226,76,197,124,149,59,54,71,68,71,71,76,64,76,191,66,23,54,82,115,139,110,210,112,87,76,81,163,79,71,218,69,133,76,108,124,7,77,164,74,161,70,35,107,37,114,84,90,99,26,6,62,97,63,77,102,251,86,0,0,149,125,29,89,185,139,244,61,52,151,239,123,219,91,94,29,164,90,37,54,176,158,209,90,183,91,252,92,110,103,147,133,69,153,97,116,157,116,117,56,83,29,158,54,33,96,236,62,222,88,245,58,252,122,151,159,97,65,13,137,234,49,138,10,94,50,10,67,132,132,150,159,47,148,48,73,19,134,150,88,74,151,24,146,208,121,50,122,96,102,41,106,157,136,76,116,197,123,130,103,44,122,79,82,70,144,230,52,196,115,185,93,198,116,199,159,179,87,47,73,76,84,49,65,142,54,24,88,114,122,101,123,143,139,174,70,136,110,129,65,153,93,174,123,188,36,200,159,193,36,201,36,204,36,201,159,4,133,187,53,180,64,202,159,225,68,255,173,193,98,110,112,203,159,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,49,193,49,194,49,195,49,196,49,12,1,197,49,209,0,205,0,198,49,199,49,203,0,232,31,200,49,202,0,201,49,202,49,203,49,204,49,14,1,205,49,206,49,0,1,193,0,205,1,192,0,18,1,201,0,26,1,200,0,76,1,211,0,209,1,210,0,0,220,190,30,4,220,192,30,202,0,1,1,225,0,206,1,224,0,81,2,19,1,233,0,27,1,232,0,43,1,237,0,208,1,236,0,77,1,243,0,210,1,242,0,107,1,250,0,212,1,249,0,214,1,216,1,218,1,220,1,252,0,8,220,191,30,12,220,193,30,234,0,97,2,218,35,219,35],"i8",ALLOC_NONE,Runtime.GLOBAL_BASE+261308),
	allocate([169,163,69,17,0,0,10,101,0,0,0,0,61,78,221,110,78,157,223,145,0,0,0,0,53,119,145,100,26,79,40,79,168,79,86,81,116,81,156,81,228,81,161,82,168,82,59,83,78,83,209,83,216,83,226,86,240,88,4,89,7,89,50,89,52,89,102,91,158,91,159,91,154,92,134,94,59,96,137,101,254,103,4,104,101,104,78,109,188,112,53,117,164,126,172,126,186,126,199,126,207,126,223,126,6,127,55,127,122,130,207,130,111,131,198,137,190,139,226,139,102,143,103,143,110,143,17,116,252,124,205,125,70,105,201,122,39,82,0,0,0,0,0,0,0,0,140,145,184,120,94,145,188,128,0,0,11,141,246,128,231,9,0,0,0,0,159,128,199,158,205,76,201,157,12,158,62,76,246,157,14,112,10,158,51,161,193,53,0,0,154,110,62,130,25,117,0,0,17,73,108,154,143,154,153,159,135,121,108,132,202,29,208,5,230,42,36,78,129,78,128,78,135,78,191,78,235,78,55,79,76,52,189,79,72,62,3,80,136,80,125,52,147,52,165,52,134,81,5,89,219,81,252,81,5,82,137,78,121,82,144,82,39,83,199,53,169,83,81,53,176,83,83,53,194,83,35,84,109,53,114,53,129,54,147,84,163,84,180,84,185,84,208,84,239,84,24,85,35,85,40,85,152,53,63,85,165,53,191,53,215,85,197,53,132,125,37,85,0,0,66,12,21,13,43,81,144,85,198,44,236,57,65,3,70,142,184,77,229,148,83,64,190,128,122,119,56,44,52,58,213,71,93,129,242,105,234,77,221,100,124,13,180,15,213,12,244,16,141,100,126,142,150,14,11,12,100,15,169,44,86,130,211,68,0,0,70,13,77,154,233,128,244,71,167,78,194,44,178,154,103,58,244,149,237,63,6,53,199,82,212,151,200,120,68,45,110,157,21,152,0,0,217,67,165,96,180,100,227,84,76,45,202,43,119,16,251,57,111,16,218,102,22,103,160,121,234,100,82,80,67,12,104,142,161,33,76,139,49,7,0,0,11,72,169,1,250,63,115,88,141,45,0,0,200,69,252,4,151,96,76,15,150,13,121,85,187,64,186,67,0,0,180,74,102,42,157,16,170,129,245,152,156,13,121,99,254,57,117,39,192,141,161,86,124,100,67,62,0,0,1,166,9,14,207,42,201,44,0,0,200,16,194,57,146,57,6,58,155,130,120,53,73,94,199,32,82,86,49,15,178,44,32,151,188,52,61,108,59,78,0,0,0,0,116,117,139,46,8,34,91,166,205,140,122,14,52,12,28,104,147,127,207,16,3,40,57,41,251,53,227,81,140,14,141,15,170,14,147,63,48,15,71,13,79,17,76,14,0,0,171,14,169,11,72,13,192,16,61,17,249,63,150,38,50,100,173,15,244,51,57,118,206,43,126,13,127,13,81,44,85,44,24,58,152,14,199,16,46,15,50,166,80,107,210,140,153,141,202,140,170,149,204,84,196,130,185,85,0,0,195,158,38,156,182,154,94,119,238,45,64,113,109,129,236,128,28,92,114,101,52,129,151,55,95,83,189,128,182,145,250,14,15,14,119,14,251,14,221,53,235,77,9,54,214,12,175,86,181,39,201,16,16,14,120,14,120,16,72,17,7,130,85,20,121,14,80,78,164,45,84,90,29,16,30,16,245,16,246,16,156,87,17,14,148,118,205,130,181,15,123,14,126,81,3,55,182,15,128,17,216,82,189,162,218,73,58,24,119,65,124,130,153,88,104,82,26,54,61,87,178,123,104,91,0,72,44,75,39,159,231,73,31,156,141,155,116,91,61,49,251,85,242,53,137,86,40,78,2,89,193,27,120,248,81,151,134,0,91,78,187,78,62,53,35,92,81,95,196,95,250,56,76,98,53,101,122,107,53,108,58,108,108,112,43,114,44,78,173,114,233,72,82,127,59,121,249,124,83,127,106,98,193,52,0,0,75,99,2,128,128,128,18,102,81,105,93,83,100,136,193,137,178,120,160,139,29,141,133,148,120,149,127,149,232,149,15,142,230,151,117,152,206,152,222,152,99,153,16,152,124,156,31,158,196,158,111,107,7,249,55,78,135,0,29,150,55,98,162,148,0,0,59,80,254,109,115,156,166,159,201,61,143,136,78,65,119,112,245,92,32,75,205,81,89,53,48,93,34,97,50,138,167,143,246,145,145,113,25,103,186,115,129,50,7,161,139,60,128,25,16,75,228,120,2,116,174,81,15,135,9,64,99,106,186,162,35,66,15,134,111,10,42,122,71,153,234,138,85,151,77,112,36,83,126,32,244,147,217,118,227,137,167,159,221,119,163,78,240,79,188,80,47,78,23,79,168,159,52,84,139,125,146,88,208,88,182,29,146,94,153,94,194,95,18,39,139,101,249,51,25,105,67,106,99,60,255,108,0,0,0,114,5,69,140,115,219,62,19,74,21,91,185,116,131,139,164,92,149,86,147,122,236,123,195,124,108,126,248,130,151,133,169,159,144,136,170,159,185,142,171,159,207,143,95,133,224,153,33,146,172,159,185,141,63,20,113,64,162,66,26,90,0,0,0,0,0,0,104,152,107,103,118,66,61,87,0,0,214,133,123,73,191,130,13,113,129,76,116,109,123,93,21,107,190,111,173,159,174,159,150,91,175,159,231,102,91,126,87,110,202,121,136,61,195,68,86,50,150,39,154,67,54,69,0,0,213,92,26,59,249,138,120,92,18,61,81,53,120,93,178,159,87,113,88,69,236,64,35,30,119,76,120,57,74,52,164,1,65,108,204,138,180,79,57,2,191,89,108,129,86,152,250,152,59,95,159,11,0,0,193,33,109,137,2,65,187,70,121,144,7,63,179,159,181,161,248,64,214,55,247,70,70,108,124,65,178,134,255,115,109,69,212,56,154,84,97,69,27,69,137,77,123,76,118,77,234,69,200,63,15,75,97,54,222,68,189,68,237,65,62,93,72,93,86,93,252,61,15,56,164,93,185,93,32,56,56,56,66,94,189,94,37,95,131,95,8,57,20,57,63,57,77,57,215,96,61,97,229,92,137,57,183,97,185,97,207,97,184,57,44,98,144,98,229,98,24,99,248,57,177,86,3,58,226,99,251,99,7,100,90,100,75,58,192,100,21,93,33,86,159,159,151,58,134,101,189,58,255,101,83,102,242,58,146,102,34,59,22,103,66,59,164,103,0,104,88,59,74,104,132,104,114,59,113,59,123,59,9,105,67,105,92,114,100,105,159,105,133,105,188,59,214,105,221,59,101,106,116,106,113,106,130,106,236,59,153,106,242,59,171,106,181,106,212,106,246,106,129,107,193,107,234,107,117,108,170,108,203,60,2,109,6,109,38,109,129,109,239,60,164,109,177,109,21,110,24,110,41,110,134,110,192,137,187,110,226,110,218,110,127,159,232,110,233,110,36,111,52,111,70,61,65,63,129,111,190,111,106,61,117,61,183,113,153,92,138,61,44,112,145,61,80,112,84,112,111,112,127,112,137,112,37,3,193,67,241,53,216,14,215,62,190,87,211,110,62,113,224,87,78,54,162,105,233,139,116,91,73,122,225,88,217,148,101,122,125,122,172,89,187,122,176,122,194,122,195,122,209,113,141,100,202,65,218,122,221,122,234,122,239,65,178,84,1,92,11,123,85,123,41,123,14,83,254,92,162,123,111,123,156,131,180,91,127,108,208,123,33,132,146,123,0,0,32,93,173,61,101,92,146,132,250,123,0,0,53,124,193,92,68,124,131,124,130,72,166,124,125,102,120,69,201,124,199,124,230,124,116,124,243,124,245,124,0,0,103,126,29,69,68,110,93,125,214,110,141,116,137,125,171,125,53,113,179,125,0,0,87,64,41,96,228,125,19,61,245,125,249,23,229,125,109,131,0,0,33,97,90,97,110,126,146,126,43,67,108,148,39,126,64,127,65,127,71,127,54,121,208,98,225,153,151,127,81,99,163,127,97,22,104,0,92,69,102,55,3,69,58,131,250,127,137,100,0,0,8,128,29,128,0,0,47,128,135,160,195,108,59,128,60,128,97,128,20,39,137,73,38,102,227,61,232,102,37,103,167,128,72,138,7,129,26,129,176,88,246,38,127,108,152,100,184,79,231,100,138,20,24,130,94,24,83,106,101,74,149,74,122,68,41,130,13,11,82,106,126,61,249,79,253,20,226,132,98,131,10,107,167,73,48,53,115,23,248,61,170,130,27,105,148,249,219,65,75,133,208,130,26,131,22,14,180,23,193,54,125,49,90,53,123,130,226,130,24,131,139,62,163,109,5,107,151,107,206,53,191,61,29,131,236,85,133,131,11,69,165,109,172,131,0,0,211,131,126,52,212,110,87,106,90,133,150,52,66,110,239,46,88,132,228,91,113,132,211,61,228,68,167,106,74,132,181,60,88,121,0,0,150,107,119,110,67,110,222,132,0,0,145,131,160,68,147,132,228,132,145,92,64,66,192,92,67,69,52,133,242,90,153,110,39,69,115,133,22,69,191,103,22,134,37,134,59,134,193,133,136,112,2,134,130,21,205,112,178,249,106,69,40,134,72,54,162,24,247,83,154,115,126,134,113,135,248,160,238,135,39,44,177,135,218,135,15,136,97,86,108,134,86,104,15,70,69,136,70,136,224,117,185,61,228,117,94,136,156,136,91,70,180,136,181,136,193,99,197,136,119,119,15,119,135,137,138,137,0,0,0,0,167,137,188,137,37,138,231,137,36,121,189,122,156,138,147,119,254,145,144,138,89,122,233,122,58,123,143,63,19,71,56,123,124,113,12,139,31,139,48,84,101,85,63,139,76,139,77,139,169,138,122,74,144,139,155,139,175,138,223,22,21,70,79,136,155,140,84,125,143,125,212,249,37,55,83,125,214,140,152,125,189,125,18,141,3,141,16,25,219,140,92,112,17,141,201,76,208,62,0,0,169,141,2,128,20,16,138,73,124,59,188,129,12,113,231,122,173,142,182,142,195,142,212,146,25,143,45,143,101,131,18,132,165,143,3,147,159,162,80,10,179,143,42,73,222,137,61,133,187,61,248,94,98,50,249,143,20,160,188,134,1,133,37,35,128,57,215,110,55,144,60,133,190,122,97,144,108,133,11,134,168,144,19,135,196,144,230,134,174,144,0,0,103,145,240,58,169,145,196,145,172,124,51,137,137,30,14,146,159,108,65,146,98,146,185,85,0,0,198,138,155,60,12,139,219,85,49,13,44,147,107,147,225,138,235,139,143,112,195,90,226,138,229,138,101,73,68,146,236,139,57,140,255,139,115,147,91,148,188,142,133,149,166,149,38,148,160,149,246,111,185,66,122,38,216,134,124,18,46,62,223,73,28,108,123,150,150,150,108,65,163,150,213,110,218,97,182,150,245,120,224,138,189,150,204,83,161,73,184,108,116,2,16,100,175,144,229,144,209,74,21,25,10,51,49,151,66,134,54,151,15,74,61,69,133,69,233,74,117,112,65,91,27,151,0,0,213,145,87,151,74,91,235,145,95,151,37,148,208,80,183,48,188,48,137,151,159,151,177,151,190,151,192,151,210,151,224,151,108,84,238,151,28,116,51,148,0,0,245,151,29,148,122,121,209,74,52,152,51,152,75,152,102,152,14,59,117,113,81,61,48,6,92,65,6,87,202,152,183,152,200,152,199,152,255,74,39,109,211,22,176,85,225,152,230,152,236,152,120,147,57,153,41,74,114,75,87,152,5,153,245,153,12,154,59,154,16,154,88,154,37,87,196,54,177,144,213,155,224,154,226,154,5,155,244,154,14,76,20,155,45,155,0,134,52,80,52,155,168,105,195,56,125,48,80,155,64,155,62,157,69,90,99,24,142,155,75,66,2,156,255,155,12,156,104,158,212,157,183,159,146,161,171,161,225,160,35,161,223,161,126,157,131,157,52,161,14,158,136,104,196,157,91,33,147,161,32,162,59,25,51,162,57,157,185,160,180,162,144,158,149,158,158,158,162,158,52,77,170,158,175,158,100,67,193,158,96,59,229,57,29,61,50,79,190,55,43,140,2,159,8,159,150,75,36,148,162,109,23,159,0,0,57,159,159,86,138,86,69,159,184,153,139,144,242,151,127,132,98,159,105,159,220,122,142,159,22,114,190,75,117,73,187,73,119,113,248,73,72,67,81,74,158,115,218,139,250,24,159,121,126,137,54,142,105,147,243,147,68,138,236,146,129,147,203,147,108,137,185,68,23,114,235,62,114,119,67,122,208,112,115,68,248,67,126,113,239,23,163,112,190,24,153,53,199,62,133,24,47,84,248,23,34,55,251,22,57,24,225,54,116,23,209,24,75,95,35,55,192,22,91,87,37,74,254,19,168,18,198,19,182,20,3,133,166,54,0,0,85,132,148,73,101,113,49,62,92,85,251,62,82,112,244,68,238,54,157,153,38,111,249,103,51,55,21,60,231,61,108,88,34,25,16,104,87,64,63,55,225,64,139,64,15,65,33,108,203,84,158,86,177,102,146,86,223,15,168,11,13,14,198,147,19,139,156,147,248,78,43,81,25,56,54,68,188,78,101,4,127,3,75,79,138,79,81,86,104,90,171,1,203,3,153,57,10,3,20,4,53,52,41,79,192,2,179,142,117,2,218,138,12,2,152,78,205,80,13,81,162,79,3,79,14,74,138,62,66,79,46,80,108,80,129,80,204,79,229,79,88,80,252,80,0,0,0,0,0,0,0,0,118,110,149,53,57,62,191,62,114,109,132,24,137,62,168,81,195,81,224,5,221,68,163,4,146,4,145,4,122,141,156,138,14,7,89,82,164,82,115,8,225,82,0,0,122,70,140,113,140,67,32,12,172,73,228,16,209,105,29,14,0,0,222,62,153,116,20,116,86,116,152,115,142,75,188,74,141,64,208,83,132,53,15,114,201,64,180,85,69,3,205,84,198,11,29,87,93,146,244,150,102,147,221,87,141,87,127,87,62,54,203,88,153,90,70,138,250,22,111,23,16,23,44,90,184,89,143,146,126,90,207,90,18,90,70,89,243,25,97,24,149,66,245,54,5,109,67,116,33,90,131,94,129,90,215,139,19,4,224,147,140,116,3,19,5,113,114,73,8,148,251,137,189,147,160,55,30,92,158,92,94,94,72,94,150,25,124,25,238,58,205,94,79,91,3,25,4,25,1,55,160,24,221,54,254,22,211,54,42,129,71,138,186,29,114,52,168,137,12,95,14,95,39,25,171,23,107,90,59,23,68,91,20,134,253,117,96,136,126,96,96,40,43,38,219,95,184,62,175,37,190,37,136,144,115,111,192,97,62,0,70,0,27,38,153,97,152,97,117,96,155,44,7,45,212,70,77,145,113,100,101,70,106,43,41,58,34,43,80,52,234,152,120,46,55,99,91,164,182,100,49,99,209,99,227,73,103,45,164,98,161,44,59,100,107,101,114,105,244,59,142,48,173,50,137,73,171,50,13,85,224,50,217,24,63,148,206,102,137,50,179,49,224,58,144,65,132,85,34,139,143,85,252,22,91,85,37,84,238,120,3,49,42,24,52,50,100,52,15,50,130,49,201,66,142,102,36,109,107,102,147,75,48,102,112,120,235,29,99,102,210,50,225,50,30,102,114,88,209,56,58,56,188,55,153,59,162,55,254,51,208,116,150,59,143,103,42,70,182,104,30,104,196,59,190,106,99,56,213,55,135,68,51,106,82,106,201,106,5,107,18,25,17,101,152,104,76,106,215,59,122,106,87,107,192,63,154,60,160,147,242,146,234,139,203,138,137,146,30,128,220,137,103,148,165,109,11,111,236,73,0,0,127,63,143,61,4,110,60,64,61,90,10,110,71,88,36,109,66,120,59,113,26,67,118,66,241,112,80,114,135,114,148,114,143,71,37,71,121,81,164,74,235,5,122,116,248,62,95,54,74,74,23,73,225,95,6,63,177,62,223,74,35,140,53,63,167,96,243,62,204,116,60,116,135,147,55,116,159,68,234,109,81,69,131,117,99,63,217,76,6,77,88,63,85,117,115,118,198,165,25,59,104,116,204,138,171,73,142,73,251,58,205,61,78,74,255,62,197,73,243,72,250,145,50,87,66,147,227,138,100,24,223,80,33,82,231,81,120,119,50,50,14,119,15,119,123,119,151,70,129,55,94,58,240,72,56,116,155,116,191,62,186,74,199,74,200,64,150,74,174,97,7,147,129,85,30,120,141,120,136,120,210,120,208,115,89,121,65,119,227,86,14,65,0,0,150,132,165,121,45,106,250,62,58,122,244,121,110,65,230,22,50,65,53,146,241,121,76,13,140,73,153,2,186,61,110,23,151,53,107,85,112,53,170,54,212,1,13,12,226,122,89,90,245,38,175,90,156,90,13,90,91,2,240,120,42,90,198,91,254,122,249,65,93,124,109,124,17,66,179,91,188,94,166,94,205,124,249,73,176,23,142,124,124,124,174,124,178,106,220,125,7,126,211,125,78,127,97,98,92,97,72,123,151,125,130,94,106,66,117,107,22,9,214,103,78,0,207,53,196,87,18,100,248,99,98,73,221,127,39,123,44,8,233,90,67,93,12,123,14,94,230,153,69,134,99,154,28,106,63,52,226,57,247,73,173,101,31,154,160,101,128,132,39,113,209,108,234,68,55,129,2,68,198,128,9,129,66,129,180,103,195,152,66,106,98,130,101,130,81,106,83,132,167,109,16,134,27,114,134,90,127,65,64,24,43,91,161,24,228,90,216,24,160,134,188,249,143,61,45,136,34,116,2,90,110,136,69,79,135,136,191,136,230,136,101,137,77,137,131,86,84,137,133,119,132,119,245,139,217,139,156,139,249,137,173,62,163,132,245,70,207,70,242,55,61,138,28,138,72,148,77,95,43,146,132,66,212,101,41,113,196,112,69,24,109,157,159,140,233,140,220,125,154,89,195,119,240,89,110,67,212,54,42,142,167,142,9,76,48,143,74,143,244,66,88,108,187,111,33,35,155,72,121,111,139,110,218,23,233,155,181,54,47,73,187,144,0,0,113,85,6,73,187,145,4,148,75,138,98,64,252,138,39,148,29,140,59,140,229,132,43,138,153,149,167,149,151,149,150,149,52,141,69,116,194,62,255,72,66,74,234,67,231,62,37,50,143,150,231,142,102,142,101,142,204,62,237,73,120,74,238,63,18,116,107,116,252,62,65,151,176,144,71,104,29,74,147,144,223,87,0,0,104,147,137,137,38,140,47,139,190,99,186,146,17,91,105,139,60,73,249,115,27,66,155,151,113,151,56,153,38,15,193,93,197,139,178,74,31,152,218,148,246,146,215,149,229,145,192,68,80,139,103,74,100,139,220,152,69,138,0,63,42,146,37,73,20,132,59,153,77,153,6,123,253,61,155,153,111,75,170,153,92,154,101,139,200,88,143,106,33,154,254,90,47,154,241,152,144,75,72,153,188,153,189,75,151,75,125,147,114,88,2,19,34,88,184,73,232,20,68,120,31,39,184,61,197,104,125,61,88,148,39,57,80,97,129,39,107,41,7,97,79,156,83,156,123,156,53,156,16,156,127,155,207,155,45,158,159,155,245,161,254,160,33,157,174,76,4,65,24,158,176,76,12,157,180,161,237,160,243,160,47,153,165,157,189,132,18,110,223,111,130,107,252,133,51,69,164,109,132,110,240,109,32,132,238,133,0,110,215,55,100,96,226,121,156,53,64,54,45,73,222,73,98,61,219,147,190,146,72,147,191,2,185,120,119,146,77,148,228,79,64,52,100,144,93,85,61,120,84,120,182,120,75,120,87,23,201,49,65,73,154,54,114,79,218,111,217,111,0,0,30,112,20,84,181,65,187,87,243,88,138,87,22,157,215,87,52,113,175,52,172,65,235,113,64,108,151,79,0,0,181,23,73,138,12,97,206,90,11,90,188,66,136,68,44,55,123,75,252,137,187,147,184,147,214,24,29,15,114,132,192,108,19,20,250,66,38,44,193,67,148,89,183,61,65,103,168,125,91,97,164,96,185,73,139,73,250,137,229,146,226,115,233,62,180,116,99,139,159,24,225,62,179,74,216,106,243,115,251,115,214,62,62,74,148,74,217,23,102,74,167,3,36,20,229,73,72,116,22,73,165,112,118,73,132,146,230,115,95,147,254,4,49,147,206,138,22,138,134,147,231,139,213,85,53,73,130,138,107,113,67,73,255,12,164,86,26,6,235,11,184,12,2,85,196,121,250,23,254,125,194,22,80,74,82,24,46,69,1,148,10,55,192,138,173,73,176,89,191,24,131,24,132,116,161,90,226,54,91,61,176,54,95,146,121,90,129,138,98,24,116,147,205,60,180,10,150,74,138,57,244,80,105,61,76,61,156,19,117,113,251,66,24,130,15,110,228,144,235,68,87,109,79,126,103,112,175,108,214,60,237,63,45,62,2,110,12,111,111,61,245,3,81,117,188,54,200,52,128,70,218,62,113,72,196,89,110,146,62,73,65,143,28,140,192,107,18,88,200,87,214,54,82,20,254,112,98,67,113,74,227,47,176,18,189,35,185,104,103,105,152,19,229,52,244,123,223,54,131,138,214,55,250,51,159,76,26,106,173,54,183,108,62,132,223,68,206,68,38,109,81,109,130,108,222,111,23,111,9,113,61,131,58,23,237,131,128,108,83,112,219,23,137,89,130,90,179,23,97,90,113,90,5,25,252,65,45,55,239,89,60,23,199,54,142,113,144,147,154,102,165,66,110,90,43,90,147,66,43,106,249,62,54,119,91,68,202,66,29,113,89,66,225,137,176,79,40,109,194,92,206,68,77,126,189,67,12,106,86,66,4,19,166,112,51,113,233,67,165,61,223,108,37,248,79,74,101,126,235,89,47,93,243,61,92,95,93,74,223,23,164,125,38,132,133,84,250,58,0,51,20,2,126,87,213,8,25,6,229,63,158,31,182,162,3,112,91,145,112,93,143,115,211,124,89,138,32,148,200,79,231,127,205,114,16,115,244,122,56,115,57,115,246,86,65,115,72,115,169,62,24,123,108,144,245,113,242,72,225,115,246,129,202,62,12,119,209,62,162,108,253,86,25,116,30,116,31,116,226,62,240,62,244,62,250,62,211,116,14,63,83,63,66,117,109,117,114,117,141,117,124,63,200,117,220,117,192,63,77,118,215,63,116,118,220,63,122,118,92,79,136,113,35,86,128,137,105,88,29,64,67,119,57,64,97,103,69,64,219,53,152,119,106,64,111,64,94,92,190,119,203,119,242,88,24,120,185,112,28,120,168,64,57,120,71,120,81,120,102,120,72,132,53,85,51,121,3,104,50,121,3,65,9,65,145,121,153,121,187,143,6,122,188,143,103,65,145,122,178,65,188,122,121,130,196,65,207,122,219,122,207,65,33,78,98,123,108,123,123,123,18,124,27,124,96,66,122,66,123,124,156,124,140,66,184,124,148,66,237,124,147,143,192,112,207,12,207,125,212,125,208,125,253,125,174,127,180,127,159,114,151,67,32,128,37,128,57,123,46,128,49,128,84,128,204,61,180,87,160,112,183,128,233,128,237,67,12,129,42,115,14,129,18,129,96,117,20,129,1,68,57,59,86,129,89,129,90,129,19,68,58,88,124,129,132,129,37,68,147,129,45,68,165,129,239,87,193,129,228,129,84,130,143,68,166,130,118,130,202,130,216,130,255,130,176,68,87,131,105,150,138,105,5,132,245,112,100,132,227,96,136,132,4,69,190,132,225,132,248,132,16,133,56,133,82,133,59,69,111,133,112,133,224,133,119,69,114,134,146,134,178,134,239,134,69,150,139,135,6,70,23,70,174,136,255,136,36,137,71,137,145,137,103,121,41,138,56,138,148,138,180,138,81,140,212,140,242,140,28,141,152,71,95,88,195,141,237,71,238,78,58,142,216,85,84,87,113,142,245,85,176,142,55,72,206,142,226,142,228,142,237,142,242,142,183,143,193,143,202,143,204,143,51,144,196,153,173,72,224,152,19,146,30,73,40,146,88,146,107,146,177,146,174,146,191,146,227,146,235,146,243,146,244,146,253,146,67,147,132,147,173,147,69,73,81,73,191,158,23,148,1,83,29,148,45,148,62,148,106,73,84,148,121,148,45,149,162,149,167,73,244,149,51,150,229,73,160,103,36,74,64,151,53,74,178,151,194,151,84,86,228,74,232,96,185,152,25,75,241,152,68,88,14,153,25,153,180,81,28,153,55,153,66,153,93,153,98,153,112,75,197,153,157,75,60,154,15,155,131,122,105,155,129,155,221,155,241,155,244,155,109,76,32,156,111,55,194,27,73,157,58,156,254,158,80,86,147,157,189,157,192,157,252,157,246,148,182,143,123,158,172,158,177,158,189,158,198,158,220,148,226,158,241,158,248,158,200,122,68,159,148,0,183,2,160,3,26,105,195,148,172,89,215,4,64,88,193,148,185,55,213,5,21,6,118,6,186,22,87,87,115,113,194,10,205,10,191,11,106,84,59,248,203,11,158,84,251,11,59,12,83,12,101,12,124,12,231,96,141,12,122,86,181,12,221,12,237,12,111,13,178,13,200,13,85,105,47,156,165,135,4,14,14,14,215,14,144,15,45,15,115,14,32,92,188,15,11,94,92,16,79,16,118,16,30,103,123,16,136,16,150,16,71,54,191,16,211,16,47,17,59,17,100,83,173,132,227,18,117,19,54,19,129,139,119,21,25,22,195,23,199,23,120,78,187,112,45,24,106,25,45,26,69,26,42,28,112,28,172,28,200,30,195,98,213,30,21,31,152,113,85,104,69,32,233,105,200,54,124,34,215,35,250,35,42,39,113,40,79,41,253,130,103,41,147,41,213,42,165,137,232,42,160,143,14,43,184,151,63,43,71,152,189,154,76,44,0,0,136,44,183,44,232,91,8,45,18,45,183,45,149,45,66,46,116,47,204,47,51,48,102,48,31,51,222,51,177,95,72,102,191,102,121,122,103,53,243,53,0,0,186,73,0,0,26,54,22,55,0,0,70,3,181,88,14,103,24,105,167,58,87,118,226,95,17,62,185,62,254,117,154,32,208,72,184,74,25,65,154,138,238,66,13,67,59,64,52,67,150,67,69,74,202,5,210,81,17,6,159,89,168,30,190,59,255,60,4,68,214,68,136,87,116,70,155,57,47,71,232,133,201,153,98,55,195,33,94,139,78,139,0,0,18,72,251,72,21,74,9,114,192,74,120,12,101,89,165,78,134,79,121,7,218,142,44,80,143,82,63,87,113,113,153,82,25,84,74,63,167,74,188,85,70,84,110,84,82,107,0,0,115,52,63,85,50,118,94,85,24,71,98,85,102,85,199,87,63,73,93,88,102,80,251,52,204,51,0,0,3,89,124,71,72,137,174,90,137,91,6,92,144,29,161,87,81,113,0,0,2,97,18,124,86,144,178,97,154,79,98,139,2,100,74,100,91,93,247,107,0,0,132,100,28,25,234,138,246,73,136,100,239,63,18,101,192,75,191,101,181,102,27,39,101,148,225,87,149,97,39,90,205,248,0,0,185,86,33,69,252,102,106,78,52,73,86,150,143,109,189,108,24,54,119,137,153,103,110,104,17,100,94,104,0,0,199,104,66,123,192,144,17,10,38,105,0,0,57,105,69,122,0,0,250,105,38,154,45,106,95,54,105,100,33,0,131,121,52,106,91,107,44,93,25,53,0,0,157,107,208,70,164,108,59,117,101,136,174,109,182,88,28,55,141,37,75,112,205,113,84,60,128,114,133,114,129,146,122,33,139,114,48,147,230,114,208,73,57,108,159,148,80,116,248,14,39,136,245,136,38,41,115,132,177,23,184,110,42,74,32,24,164,57,185,54,0,0,0,0,63,69,182,102,173,156,164,152,67,137,204,119,88,120,214,86,223,64,10,22,161,57,47,55,232,128,197,19,173,113,102,131,221,121,168,145,0,0,183,76,175,112,171,137,253,121,10,122,11,123,102,125,122,65,67,123,126,121,9,128,181,111,223,162,3,106,24,131,162,83,7,110,191,147,54,104,93,151,111,129,35,128,181,105,237,19,47,50,72,128,133,93,48,140,131,128,21,87,35,152,73,137,171,93,136,73,190,101,213,105,210,83,165,74,129,63,17,60,54,103,144,128,244,128,46,129,161,31,79,129,137,129,175,129,26,130,6,131,47,131,138,131,202,53,104,132,170,134,250,72,230,99,86,137,8,120,85,146,184,137,242,67,231,137,223,67,232,137,70,139,212,139,248,89,9,140,0,0,197,143,236,144,0,0,16,145,60,145,247,61,94,145,202,74,208,143,143,114,139,86,231,148,233,149,176,149,184,149,50,151,209,152,73,153,106,153,195,153,40,154,14,155,90,157,155,157,159,126,248,158,35,159,164,76,71,149,147,162,162,113,255,162,145,77,18,144,203,165,156,77,156,12,190,143,193,85,186,143,176,36,185,143,147,74,9,69,127,126,86,111,177,106,234,78,228,52,44,139,157,120,58,55,128,142,245,23,36,128,108,139,153,139,62,122,175,102,235,61,85,118,183,60,53,86,86,89,154,78,129,94,88,98,191,86,109,14,14,142,109,91,136,62,158,76,222,99,0,0,246,23,123,24,48,101,45,86,74,92,26,84,17,83,198,61,152,157,125,76,34,86,30,86,73,127,216,94,117,89,64,61,112,135,28,78,234,15,73,13,186,54,23,129,94,157,24,141,59,118,69,156,78,118,185,119,69,147,50,84,72,129,247,130,37,86,50,129,24,132,189,128,234,85,98,121,67,86,22,84,157,14,206,53,5,86,241,85,241,102,226,130,45,54,52,117,240,85,186,85,151,84,114,85,65,12,150,12,208,94,72,81,118,14,98,44,162,14,171,158,90,125,222,85,117,16,157,98,109,151,148,84,205,140,246,113,118,145,252,99,185,99,254,99,105,85,67,43,114,156,179,46,154,81,223,52,167,13,167,81,77,84,30,85,19,85,102,118,45,142,138,104,177,117,182,128,4,136,134,135,199,136,182,129,28,132,193,16,236,68,4,115,6,71,144,91,11,131,147,104,123,86,244,38,47,125,163,65,115,125,208,110,182,114,112,145,217,17,8,146,252,60,169,166,172,14,249,14,102,114,162,28,78,71,194,79,249,127,235,15,250,64,93,156,31,101,160,45,243,72,224,71,124,157,236,15,10,14,0,0,163,117,237,15,0,0,72,96,135,17,163,113,142,126,80,157,26,78,4,78,119,53,13,91,178,108,103,83,172,54,220,57,125,83,165,54,24,70,154,88,110,75,45,130,75,84,170,87,149,90,121,9,0,0,82,58,101,36,116,115,172,158,9,77,237,155,254,60,48,159,91,76,169,79,158,149,222,159,92,132,182,61,178,114,179,103,32,55,46,99,37,125,247,62,44,62,42,58,8,144,204,82,116,62,122,54,233,69,142,4,64,118,240,90,182,14,122,120,46,127,167,88,191,64,124,86,139,155,116,93,84,118,52,164,133,158,225,76,0,0,251,55,25,97,218,48,242,67,0,0,93,86,169,18,167,87,99,73,6,158,52,82,174,112,173,53,0,0,124,157,86,124,57,155,222,87,108,23,83,92,211,100,208,148,53,99,100,113,173,134,40,13,34,109,226,74,113,13,0,0,254,81,15,31,142,93,3,151,209,29,129,158,76,144,31,123,2,155,209,92,163,123,104,98,53,99,255,154,207,123,42,155,126,124,0,0,66,124,134,124,21,156,252,123,9,155,0,0,27,156,62,73,90,159,115,85,195,91,253,79,152,158,242,79,96,82,6,62,209,82,103,87,86,80,183,89,18,94,200,151,171,157,92,143,105,84,180,151,64,153,186,151,44,83,48,97,44,105,218,83,10,156,2,157,59,76,65,150,128,105,166,80,70,117,109,23,218,153,115,82,0,0,89,145,129,150,92,145,0,0,81,145,151,142,127,99,35,109,202,106,17,86,142,145,122,117,133,98,252,3,79,115,112,124,33,92,253,60,0,0,25,73,214,118,157,155,42,78,212,12,190,131,66,136,0,0,74,92,192,105,0,0,122,87,31,82,245,93,206,78,49,108,242,1,57,79,156,84,218,84,154,82,130,141,254,53,0,0,243,53,0,0,82,107,124,145,165,159,151,155,46,152,180,152,186,154,168,158,132,158,122,113,20,123,0,0,250,107,24,136,120,127,0,0,32,86,74,166,119,142,83,159,0,0,212,141,79,142,28,158,1,142,130,98,125,131,40,142,117,142,211,122,119,74,62,122,216,120,234,108,103,138,7,118,90,138,38,159,206,108,214,135,195,117,178,162,83,120,64,248,12,141,226,114,113,115,45,139,2,115,241,116,235,140,187,74,47,134,186,95,160,136,183,68,0,0,59,24,5,110,0,0,126,138,27,37,0,0,253,96,103,118,215,154,68,157,110,147,143,155,245,135,0,0,0,0,247,140,44,115,33,151,176,155,214,53,178,114,7,76,81,124,74,153,89,97,89,97,4,76,150,158,125,97,0,0,95,87,111,97,166,98,57,98,0,0,92,58,226,97,170,83,245,51,100,99,2,104,210,53,87,93,194,139,218,143,57,142,0,0,217,80,70,29,6,121,50,83,56,150,59,15,101,64,0,0,254,119,0,0,194,124,26,95,218,124,45,122,102,128,99,128,77,125,5,117,242,116,148,137,26,130,12,103,98,128,134,116,91,128,240,116,3,129,36,119,137,137,204,103,83,117,209,110,169,135,206,135,200,129,140,135,73,138,173,140,67,139,43,119,248,116,218,132,53,54,178,105,166,141,0,0,169,137,0,0,185,109,193,135,17,64,231,116,219,61,118,113,164,96,156,97,209,60,0,0,119,96,0,0,113,127,45,139,0,0,233,96,126,75,32,82,24,60,199,60,215,94,86,118,49,85,68,25,254,18,3,153,220,109,173,112,193,92,173,97,15,138,119,54,238,0,70,104,14,79,98,69,31,91,76,99,80,159,166,158,107,98,71,5,219,146,223,5,197,63,76,133,181,66,239,115,181,81,73,54,66,73,228,137,68,147,219,25,238,130,200,60,60,120,68,103,223,98,51,73,170,137,160,2,179,107,5,19,171,79,237,36,8,80,41,109,132,122,0,54,177,74,19,37,0,0,126,3,164,95,128,3,71,3,219,110,31,4,0,0,1,81,122,52,14,81,108,152,67,55,22,132,164,73,135,4,96,81,180,51,106,81,255,11,252,32,229,2,48,37,142,5,51,50,131,25,130,91,125,135,179,5,153,60,178,81,184,81,52,157,201,81,207,81,209,81,220,60,211,81,166,74,179,81,226,81,66,83,237,81,205,131,62,105,45,55,123,95,11,82,38,82,60,82,181,82,87,82,148,82,185,82,197,82,21,124,66,133,224,82,13,134,19,107,0,0,222,138,73,85,217,110,128,63,84,9,236,63,51,83,0,0,226,11,203,108,38,23,27,104,213,115,74,96,170,62,204,56,232,22,221,113,162,68,109,83,116,83,171,134,126,83,0,0,150,21,19,22,230,119,147,83,155,138,160,83,171,83,174,83,167,115,114,87,89,63,156,115,193,83,197,83,73,108,73,78,254,87,217,83,171,58,143,11,224,83,235,63,163,45,246,83,119,12,19,84,121,112,43,85,87,102,91,109,109,84,83,107,116,13,93,85,143,84,164,84,166,71,13,23,221,14,180,61,77,13,188,137,152,38,71,85,237,76,47,84,23,116,134,85,169,85,0,0,215,24,58,64,82,69,53,68,179,102,180,16,55,86,205,102,138,50,164,102,173,102,77,86,79,86,241,120,241,86,135,151,254,83,0,87,239,86,237,86,102,139,35,54,79,18,70,87,165,65,110,108,139,112,66,87,177,54,126,108,230,87,22,20,3,88,84,20,99,67,38,88,245,75,92,88,170,88,97,53,224,88,220,88,60,18,251,88,255,91,67,87,80,161,120,66,211,147,161,53,31,89,166,104,195,54,89,110,62,22,36,90,83,85,146,22,5,133,201,89,78,13,129,108,42,109,220,23,217,89,251,23,178,23,166,109,113,109,40,24,213,22,249,89,69,110,171,90,99,90,230,54,169,73,0,0,8,55,150,90,101,116,211,90,161,111,84,37,133,61,17,25,50,55,184,22,131,94,208,82,118,91,136,101,124,91,14,122,4,64,93,72,4,2,213,91,96,97,52,26,204,89,165,5,243,91,157,91,16,77,5,92,68,27,19,92,206,115,20,92,165,28,40,107,73,92,221,72,133,92,233,92,239,92,139,93,249,29,55,30,16,93,24,93,70,93,164,30,186,92,215,93,252,130,45,56,1,73,73,32,115,33,135,130,54,56,194,59,46,94,138,106,0,0,122,94,188,68,211,12,166,83,183,78,0,0,168,83,113,23,9,94,244,94,130,132,249,94,251,94,160,56,252,94,62,104,27,148,13,95,193,1,148,248,222,58,174,72,58,19,58,95,136,104,208,35,0,0,113,36,99,95,189,151,110,110,114,95,64,147,54,138,167,95,182,93,95,61,80,82,106,31,248,112,104,38,214,145,158,2,41,138,49,96,133,102,119,24,99,57,199,61,57,54,144,87,180,39,113,121,64,62,158,96,0,0,179,96,130,73,143,73,83,122,164,116,225,80,160,90,100,97,36,132,66,97,166,248,210,110,129,97,244,81,86,6,135,97,170,91,183,63,95,40,211,97,157,139,93,153,208,97,50,57,128,41,193,40,35,96,92,97,30,101,139,99,24,1,197,98,112,23,213,98,13,46,108,99,223,73,23,58,56,100,248,99,142,19,252,23,0,0,138,111,54,46,20,152,140,64,29,87,225,100,229,100,123,148,102,58,58,100,87,58,77,101,22,111,40,74,35,74,133,101,109,101,95,101,126,48,181,101,64,73,55,75,209,101,216,64,41,24,224,101,227,101,223,95,0,52,24,102,247,49,248,49,68,102,164,49,165,49,75,102,117,14,103,102,230,81,115,102,0,0,61,30,49,50,244,133,200,49,19,83,197,119,247,40,164,153,2,103,156,67,33,74,43,59,250,105,194,55,0,0,103,103,98,103,205,65,237,144,215,103,233,68,34,104,80,110,60,146,1,104,230,51,160,109,93,104,111,52,225,105,11,106,223,138,115,105,195,104,205,53,1,105,0,105,50,61,1,58,60,54,128,59,172,103,97,105,74,138,252,66,54,105,152,105,161,59,201,3,99,131,144,80,249,105,89,54,42,33,69,106,3,55,157,106,243,59,177,103,200,106,156,145,13,60,29,107,35,9,222,96,53,107,116,107,205,39,181,110,219,58,181,3,88,25,64,55,33,84,90,59,225,107,252,62,220,107,55,108,139,36,241,72,81,107,90,108,38,130,121,108,188,61,197,68,189,61,164,65,12,73,0,73,201,60,229,54,235,60,50,13,131,155,249,49,145,36,143,127,55,104,37,109,161,109,235,109,150,109,92,109,124,110,4,111,127,73,133,64,114,110,51,133,116,111,199,81,0,0,0,0,46,132,33,139,0,0,47,62,83,116,130,63,204,121,79,110,145,90,75,48,248,111,13,55,157,111,48,62,250,110,151,20,61,64,85,69,240,147,68,111,92,111,78,61,116,111,112,145,59,61,159,111,68,65,211,111,145,64,85,65,57,64,240,63,180,63,63,65,223,81,86,65,87,65,64,65,221,97,75,112,126,112,167,112,129,112,204,112,213,112,214,112,223,112,4,65,232,61,180,113,150,113,119,66,43,113,69,113,136,90,74,113,0,0,156,92,101,67,79,113,98,147,193,66,44,113,90,68,39,74,34,74,186,113,232,139,189,112,14,114,66,148,21,114,17,89,67,148,36,114,65,147,5,86,46,114,64,114,116,73,189,104,85,114,87,114,85,62,68,48,13,104,61,111,130,114,0,0,43,115,35,72,43,136,237,72,4,136,40,115,46,115,207,115,170,115,58,12,46,106,201,115,73,116,226,65,231,22,36,74,35,102,197,54,183,73,141,73,251,73,247,115,21,116,3,105,38,74,57,116,195,5,215,62,0,0,173,40,96,116,178,142,71,116,228,115,118,116,185,131,108,116,48,55,116,116,241,147,44,106,130,116,83,73,140,74,95,65,121,74,143,139,70,91,3,140,158,24,200,116,136,25,14,117,0,0,30,117,217,142,75,26,215,91,172,142,133,147,77,117,74,117,103,117,110,117,130,79,4,63,19,77,142,117,93,116,158,117,180,117,2,118,44,118,81,118,79,118,111,118,118,118,245,99,144,118,239,129,248,55,17,105,14,105,161,118,165,118,183,118,204,118,159,111,98,132,157,80,125,81,28,30,30,119,38,119,64,119,175,100,32,82,88,119,172,50,175,119,100,137,104,137,193,22,244,119,0,0,118,19,18,74,202,104,175,120,199,120,211,120,165,150,46,121,224,85,215,120,52,121,177,120,12,118,184,143,132,136,43,139,131,96,28,38,134,121,0,137,2,105,128,121,87,88,157,121,57,123,60,121,169,121,42,110,38,113,168,62,198,121,13,145,212,121,32,5,95,68,15,82,130,184,248,0,0,64,32,169,78,4,0,0,0,0,52,11,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,64,0,0,0,0,0,0,0,0,4,88,0,60,0,0,0,0,0,128,92,173,220,243,187,201,67,238,237,164,15,38,193,155,118,242,239,222,251,250,247,15,50,68,175,254,239,253,254,17,96,176,0,0,33,25,129,32,16,136,168,96,33,105,36,0,68,137,196,0,0,3,64,53,0,67,132,49,81,147,104,2,2,0,0,0,0,0,0,0,0,0,0,0,64,0,1,128,172,100,130,64,140,161,144,4,80,96,212,0,210,42,24,157,104,53,151,79,216,248,32,196,130,28,40,130,117,148,2,56,64,160,161,197,16,113,77,196,13,152,185,94,91,1,67,159,153,3,120,32,226,31,8,137,1,201,64,7,3,13,154,144,82,209,79,124,3,2,33,32,192,110,19,131,181,219,245,229,119,144,79,23,154,54,23,12,0,110,186,9,47,96,84,0,30,120,104,34,112,86,158,37,243,142,183,23,11,239,230,119,23,91,27,193,16,152,141,18,24,182,207,1,49,114,26,91,44,182,192,32,226,195,92,130,27,224,218,206,133,214,64,169,84,11,208,15,72,68,64,16,9,212,64,174,59,100,30,68,43,23,8,134,130,54,24,160,137,231,156,91,8,132,3,2,218,144,236,219,135,133,191,162,173,157,142,157,152,32,37,70,0,70,159,127,227,213,201,132,244,214,77,6,227,182,24,18,9,0,0,0,4,0,0,32,0,0,0,0,2,0,0,0,0,0,0,0,0,0,32,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,142,120,110,95,63,126,221,61,247,252,155,252,174,210,255,143,107,241,231,191,186,174,110,23,239,220,167,62,182,181,119,201,146,215,165,182,74,110,155,185,129,77,103,254,84,241,155,98,254,111,82,215,54,254,191,41,69,129,249,189,101,166,66,57,0,0,66,96,143,0,148,64,64,210,175,215,209,219,0,160,152,178,123,6,82,32,152,22,200,61,9,0,0,1,0,0,0,1,10,178,8,128,0,0,0,4,136,32,20,16,76,0,0,4,0,161,68,16,0,65,1,0,8,64,240,223,79,54,88,241,245,181,128,245,103,128,64,0,80,78,65,200,132,0,90,96,216,1,43,1,80,161,22,196,64,242,110,17,172,32,57,196,192,8,7,12,9,152,150,196,155,16,28,152,108,134,42,166,1,70,17,109,229,203,196,192,146,16,33,22,18,157,114,244,105,14,23,42,162,129,244,123,0,8,164,11,144,16,44,204,57,74,1,240,22,11,10,64,12,29,234,12,68,14,69,2,0,8,4,4,8,4,4,8,2,4,0,0,0,0,0,0,0,195,138,204,132,195,138,204,140,195,170,204,132,195,170,204,140,0,0,0,0,0,0,0,0,0,48,12,255,1,48,2,48,14,255,39,32,27,255,26,255,31,255,1,255,48,254,38,32,37,32,80,254,81,254,82,254,183,0,84,254,85,254,86,254,87,254,92,255,19,32,49,254,20,32,51,254,116,37,52,254,79,254,8,255,9,255,53,254,54,254,91,255,93,255,55,254,56,254,20,48,21,48,57,254,58,254,16,48,17,48,59,254,60,254,10,48,11,48,61,254,62,254,8,48,9,48,63,254,64,254,12,48,13,48,65,254,66,254,14,48,15,48,67,254,68,254,89,254,90,254,91,254,92,254,93,254,94,254,24,32,25,32,28,32,29,32,29,48,30,48,53,32,50,32,3,255,6,255,10,255,59,32,167,0,3,48,203,37,207,37,179,37,178,37,206,37,6,38,5,38,199,37,198,37,161,37,160,37,189,37,188,37,163,50,5,33,175,0,227,255,63,255,205,2,73,254,74,254,77,254,78,254,75,254,76,254,95,254,96,254,97,254,11,255,13,255,215,0,247,0,177,0,26,34,28,255,30,255,29,255,102,34,103,34,96,34,30,34,82,34,97,34,98,254,99,254,100,254,101,254,102,254,94,255,41,34,42,34,165,34,32,34,31,34,191,34,210,51,209,51,43,34,46,34,53,34,52,34,64,38,66,38,149,34,153,34,145,33,147,33,144,33,146,33,150,33,151,33,153,33,152,33,37,34,35,34,15,255,60,255,21,34,104,254,4,255,229,255,18,48,224,255,225,255,5,255,32,255,3,33,9,33,105,254,106,254,107,254,213,51,156,51,157,51,158,51,206,51,161,51,142,51,143,51,196,51,176,0,89,81,91,81,94,81,93,81,97,81,99,81,231,85,233,116,206,124,129,37,130,37,131,37,132,37,133,37,134,37,135,37,136,37,143,37,142,37,141,37,140,37,139,37,138,37,137,37,60,37,52,37,44,37,36,37,28,37,148,37,0,37,2,37,149,37,12,37,16,37,20,37,24,37,109,37,110,37,112,37,111,37,80,37,94,37,106,37,97,37,226,37,227,37,229,37,228,37,113,37,114,37,115,37,16,255,17,255,18,255,19,255,20,255,21,255,22,255,23,255],"i8",ALLOC_NONE,Runtime.GLOBAL_BASE+271588),
	allocate([24,255,25,255,96,33,97,33,98,33,99,33,100,33,101,33,102,33,103,33,104,33,105,33,33,48,34,48,35,48,36,48,37,48,38,48,39,48,40,48,41,48,65,83,68,83,69,83,33,255,34,255,35,255,36,255,37,255,38,255,39,255,40,255,41,255,42,255,43,255,44,255,45,255,46,255,47,255,48,255,49,255,50,255,51,255,52,255,53,255,54,255,55,255,56,255,57,255,58,255,65,255,66,255,67,255,68,255,69,255,70,255,71,255,72,255,73,255,74,255,75,255,76,255,77,255,78,255,79,255,80,255,81,255,82,255,83,255,84,255,85,255,86,255,87,255,88,255,89,255,90,255,145,3,146,3,147,3,148,3,149,3,150,3,151,3,152,3,153,3,154,3,155,3,156,3,157,3,158,3,159,3,160,3,161,3,163,3,164,3,165,3,166,3,167,3,168,3,169,3,177,3,178,3,179,3,180,3,181,3,182,3,183,3,184,3,185,3,186,3,187,3,188,3,189,3,190,3,191,3,192,3,193,3,195,3,196,3,197,3,198,3,199,3,200,3,201,3,5,49,6,49,7,49,8,49,9,49,10,49,11,49,12,49,13,49,14,49,15,49,16,49,17,49,18,49,19,49,20,49,21,49,22,49,23,49,24,49,25,49,26,49,27,49,28,49,29,49,30,49,31,49,32,49,33,49,34,49,35,49,36,49,37,49,38,49,39,49,40,49,41,49,217,2,201,2,202,2,199,2,203,2,0,36,1,36,2,36,3,36,4,36,5,36,6,36,7,36,8,36,9,36,10,36,11,36,12,36,13,36,14,36,15,36,16,36,17,36,18,36,19,36,20,36,21,36,22,36,23,36,24,36,25,36,26,36,27,36,28,36,29,36,30,36,31,36,33,36,172,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,78,89,78,1,78,3,78,67,78,93,78,134,78,140,78,186,78,63,81,101,81,107,81,224,81,0,82,1,82,155,82,21,83,65,83,92,83,200,83,9,78,11,78,8,78,10,78,43,78,56,78,225,81,69,78,72,78,95,78,94,78,142,78,161,78,64,81,3,82,250,82,67,83,201,83,227,83,31,87,235,88,21,89,39,89,115,89,80,91,81,91,83,91,248,91,15,92,34,92,56,92,113,92,221,93,229,93,241,93,242,93,243,93,254,93,114,94,254,94,11,95,19,95,77,98,17,78,16,78,13,78,45,78,48,78,57,78,75,78,57,92,136,78,145,78,149,78,146,78,148,78,162,78,193,78,192,78,195,78,198,78,199,78,205,78,202,78,203,78,196,78,67,81,65,81,103,81,109,81,110,81,108,81,151,81,246,81,6,82,7,82,8,82,251,82,254,82,255,82,22,83,57,83,72,83,71,83,69,83,94,83,132,83,203,83,202,83,205,83,236,88,41,89,43,89,42,89,45,89,84,91,17,92,36,92,58,92,111,92,244,93,123,94,255,94,20,95,21,95,195,95,8,98,54,98,75,98,78,98,47,101,135,101,151,101,164,101,185,101,229,101,240,102,8,103,40,103,32,107,98,107,121,107,203,107,212,107,219,107,15,108,52,108,107,112,42,114,54,114,59,114,71,114,89,114,91,114,172,114,139,115,25,78,22,78,21,78,20,78,24,78,59,78,77,78,79,78,78,78,229,78,216,78,212,78,213,78,214,78,215,78,227,78,228,78,217,78,222,78,69,81,68,81,137,81,138,81,172,81,249,81,250,81,248,81,10,82,160,82,159,82,5,83,6,83,23,83,29,83,223,78,74,83,73,83,97,83,96,83,111,83,110,83,187,83,239,83,228,83,243,83,236,83,238,83,233,83,232,83,252,83,248,83,245,83,235,83,230,83,234,83,242,83,241,83,240,83,229,83,237,83,251,83,219,86,218,86,22,89,46,89,49,89,116,89,118,89,85,91,131,91,60,92,232,93,231,93,230,93,2,94,3,94,115,94,124,94,1,95,24,95,23,95,197,95,10,98,83,98,84,98,82,98,81,98,165,101,230,101,46,103,44,103,42,103,43,103,45,103,99,107,205,107,17,108,16,108,56,108,65,108,64,108,62,108,175,114,132,115,137,115,220,116,230,116,24,117,31,117,40,117,41,117,48,117,49,117,50,117,51,117,139,117,125,118,174,118,191,118,238,118,219,119,226,119,243,119,58,121,190,121,116,122,203,122,30,78,31,78,82,78,83,78,105,78,153,78,164,78,166,78,165,78,255,78,9,79,25,79,10,79,21,79,13,79,16,79,17,79,15,79,242,78,246,78,251,78,240,78,243,78,253,78,1,79,11,79,73,81,71,81,70,81,72,81,104,81,113,81,141,81,176,81,23,82,17,82,18,82,14,82,22,82,163,82,8,83,33,83,32,83,112,83,113,83,9,84,15,84,12,84,10,84,16,84,1,84,11,84,4,84,17,84,13,84,8,84,3,84,14,84,6,84,18,84,224,86,222,86,221,86,51,87,48,87,40,87,45,87,44,87,47,87,41,87,25,89,26,89,55,89,56,89,132,89,120,89,131,89,125,89,121,89,130,89,129,89,87,91,88,91,135,91,136,91,133,91,137,91,250,91,22,92,121,92,222,93,6,94,118,94,116,94,15,95,27,95,217,95,214,95,14,98,12,98,13,98,16,98,99,98,91,98,88,98,54,101,233,101,232,101,236,101,237,101,242,102,243,102,9,103,61,103,52,103,49,103,53,103,33,107,100,107,123,107,22,108,93,108,87,108,89,108,95,108,96,108,80,108,85,108,97,108,91,108,77,108,78,108,112,112,95,114,93,114,126,118,249,122,115,124,248,124,54,127,138,127,189,127,1,128,3,128,12,128,18,128,51,128,127,128,137,128,139,128,140,128,227,129,234,129,243,129,252,129,12,130,27,130,31,130,110,130,114,130,126,130,107,134,64,136,76,136,99,136,127,137,33,150,50,78,168,78,77,79,79,79,71,79,87,79,94,79,52,79,91,79,85,79,48,79,80,79,81,79,61,79,58,79,56,79,67,79,84,79,60,79,70,79,99,79,92,79,96,79,47,79,78,79,54,79,89,79,93,79,72,79,90,79,76,81,75,81,77,81,117,81,182,81,183,81,37,82,36,82,41,82,42,82,40,82,171,82,169,82,170,82,172,82,35,83,115,83,117,83,29,84,45,84,30,84,62,84,38,84,78,84,39,84,70,84,67,84,51,84,72,84,66,84,27,84,41,84,74,84,57,84,59,84,56,84,46,84,53,84,54,84,32,84,60,84,64,84,49,84,43,84,31,84,44,84,234,86,240,86,228,86,235,86,74,87,81,87,64,87,77,87,71,87,78,87,62,87,80,87,79,87,59,87,239,88,62,89,157,89,146,89,168,89,158,89,163,89,153,89,150,89,141,89,164,89,147,89,138,89,165,89,93,91,92,91,90,91,91,91,140,91,139,91,143,91,44,92,64,92,65,92,63,92,62,92,144,92,145,92,148,92,140,92,235,93,12,94,143,94,135,94,138,94,247,94,4,95,31,95,100,95,98,95,119,95,121,95,216,95,204,95,215,95,205,95,241,95,235,95,248,95,234,95,18,98,17,98,132,98,151,98,150,98,128,98,118,98,137,98,109,98,138,98,124,98,126,98,121,98,115,98,146,98,111,98,152,98,110,98,149,98,147,98,145,98,134,98,57,101,59,101,56,101,241,101,244,102,95,103,78,103,79,103,80,103,81,103,92,103,86,103,94,103,73,103,70,103,96,103,83,103,87,103,101,107,207,107,66,108,94,108,153,108,129,108,136,108,137,108,133,108,155,108,106,108,122,108,144,108,112,108,140,108,104,108,150,108,146,108,125,108,131,108,114,108,126,108,116,108,134,108,118,108,141,108,148,108,152,108,130,108,118,112,124,112,125,112,120,112,98,114,97,114,96,114,196,114,194,114,150,115,44,117,43,117,55,117,56,117,130,118,239,118,227,119,193,121,192,121,191,121,118,122,251,124,85,127,150,128,147,128,157,128,152,128,155,128,154,128,178,128,111,130,146,130,139,130,141,130,139,137,210,137,0,138,55,140,70,140,85,140,157,140,100,141,112,141,179,141,171,142,202,142,155,143,176,143,194,143,198,143,197,143,196,143,225,93,145,144,162,144,170,144,166,144,163,144,73,145,198,145,204,145,50,150,46,150,49,150,42,150,44,150,38,78,86,78,115,78,139,78,155,78,158,78,171,78,172,78,111,79,157,79,141,79,115,79,127,79,108,79,155,79,139,79,134,79,131,79,112,79,117,79,136,79,105,79,123,79,150,79,126,79,143,79,145,79,122,79,84,81,82,81,85,81,105,81,119,81,118,81,120,81,189,81,253,81,59,82,56,82,55,82,58,82,48,82,46,82,54,82,65,82,190,82,187,82,82,83,84,83,83,83,81,83,102,83,119,83,120,83,121,83,214,83,212,83,215,83,115,84,117,84,150,84,120,84,149,84,128,84,123,84,119,84,132,84,146,84,134,84,124,84,144,84,113,84,118,84,140,84,154,84,98,84,104,84,139,84,125,84,142,84,250,86,131,87,119,87,106,87,105,87,97,87,102,87,100,87,124,87,28,89,73,89,71,89,72,89,68,89,84,89,190,89,187,89,212,89,185,89,174,89,209,89,198,89,208,89,205,89,203,89,211,89,202,89,175,89,179,89,210,89,197,89,95,91,100,91,99,91,151,91,154,91,152,91,156,91,153,91,155,91,26,92,72,92,69,92,70,92,183,92,161,92,184,92,169,92,171,92,177,92,179,92,24,94,26,94,22,94,21,94,27,94,17,94,120,94,154,94,151,94,156,94,149,94,150,94,246,94,38,95,39,95,41,95,128,95,129,95,127,95,124,95,221,95,224,95,253,95,245,95,255,95,15,96,20,96,47,96,53,96,22,96,42,96,21,96,33,96,39,96,41,96,43,96,27,96,22,98,21,98,63,98,62,98,64,98,127,98,201,98,204,98,196,98,191,98,194,98,185,98,210,98,219,98,171,98,211,98,212,98,203,98,200,98,168,98,189,98,188,98,208,98,217,98,199,98,205,98,181,98,218,98,177,98,216,98,214,98,215,98,198,98,172,98,206,98,62,101,167,101,188,101,250,101,20,102,19,102,12,102,6,102,2,102,14,102,0,102,15,102,21,102,10,102,7,102,13,103,11,103,109,103,139,103,149,103,113,103,156,103,115,103,119,103,135,103,157,103,151,103,111,103,112,103,127,103,137,103,126,103,144,103,117,103,154,103,147,103,124,103,106,103,114,103,35,107,102,107,103,107,127,107,19,108,27,108,227,108,232,108,243,108,177,108,204,108,229,108,179,108,189,108,190,108,188,108,226,108,171,108,213,108,211,108,184,108,196,108,185,108,193,108,174,108,215,108,197,108,241,108,191,108,187,108,225,108,219,108,202,108,172,108,239,108,220,108,214,108,224,108,149,112,142,112,146,112,138,112,153,112,44,114,45,114,56,114,72,114,103,114,105,114,192,114,206,114,217,114,215,114,208,114,169,115,168,115,159,115,171,115,165,115,61,117,157,117,153,117,154,117,132,118,194,118,242,118,244,118,229,119,253,119,62,121,64,121,65,121,201,121,200,121,122,122,121,122,250,122,254,124,84,127,140,127,139,127,5,128,186,128,165,128,162,128,177,128,161,128,171,128,169,128,180,128,170,128,175,128,229,129,254,129,13,130,179,130,157,130,153,130,173,130,189,130,159,130,185,130,177,130,172,130,165,130,175,130,184,130,163,130,176,130,190,130,183,130,78,134,113,134,29,82,104,136,203,142,206,143,212,143,209,143,181,144,184,144,177,144,182,144,199,145,209,145,119,149,128,149,28,150,64,150,63,150,59,150,68,150,66,150,185,150,232,150,82,151,94,151,159,78,173,78,174,78,225,79,181,79,175,79,191,79,224,79,209,79,207,79,221,79,195,79,182,79,216,79,223,79,202,79,215,79,174,79,208,79,196,79,194,79,218,79,206,79,222,79,183,79,87,81,146,81,145,81,160,81,78,82,67,82,74,82,77,82,76,82,75,82,71,82,199,82,201,82,195,82,193,82,13,83,87,83,123,83,154,83,219,83,172,84,192,84,168,84,206,84,201,84,184,84,166,84,179,84,199,84,194,84,189,84,170,84,193,84,196,84,200,84,175,84,171,84,177,84,187,84,169,84,167,84,191,84,255,86,130,87,139,87,160,87,163,87,162,87,206,87,174,87,147,87,85,89,81,89,79,89,78,89,80,89,220,89,216,89,255,89,227,89,232,89,3,90,229,89,234,89,218,89,230,89,1,90,251,89,105,91,163,91,166,91,164,91,162,91,165,91,1,92,78,92,79,92,77,92,75,92,217,92,210,92,247,93,29,94,37,94,31,94,125,94,160,94,166,94,250,94,8,95,45,95,101,95,136,95,133,95,138,95,139,95,135,95,140,95,137,95,18,96,29,96,32,96,37,96,14,96,40,96,77,96,112,96,104,96,98,96,70,96,67,96,108,96,107,96,106,96,100,96,65,98,220,98,22,99,9,99,252,98,237,98,1,99,238,98,253,98,7,99,241,98,247,98,239,98,236,98,254,98,244,98,17,99,2,99,63,101,69,101,171,101,189,101,226,101,37,102,45,102,32,102,39,102,47,102,31,102,40,102,49,102,36,102,247,102,255,103,211,103,241,103,212,103,208,103,236,103,182,103,175,103,245,103,233,103,239,103,196,103,209,103,180,103,218,103,229,103,184,103,207,103,222,103,243,103,176,103,217,103,226,103,221,103,210,103,106,107,131,107,134,107,181,107,210,107,215,107,31,108,201,108,11,109,50,109,42,109,65,109,37,109,12,109,49,109,30,109,23,109,59,109,61,109,62,109,54,109,27,109,245,108,57,109,39,109,56,109,41,109,46,109,53,109,14,109,43,109,171,112,186,112,179,112,172,112,175,112,173,112,184,112,174,112,164,112,48,114,114,114,111,114,116,114,233,114,224,114,225,114,183,115,202,115,187,115,178,115,205,115,192,115,179,115,26,117,45,117,79,117,76,117,78,117,75,117,171,117,164,117,165,117,162,117,163,117,120,118,134,118,135,118,136,118,200,118,198,118,195,118,197,118,1,119,249,118,248,118,9,119,11,119,254,118,252,118,7,119,220,119,2,120,20,120,12,120,13,120,70,121,73,121,72,121,71,121,185,121,186,121,209,121,210,121,203,121,127,122,129,122,255,122,253,122,125,124,2,125,5,125,0,125,9,125,7,125,4,125,6,125,56,127,142,127,191,127,4,128,16,128,13,128,17,128,54,128,214,128,229,128,218,128,195,128,196,128,204,128,225,128,219,128,206,128,222,128,228,128,221,128,244,129,34,130,231,130,3,131,5,131,227,130,219,130,230,130,4,131,229,130,2,131,9,131,210,130,215,130,241,130,1,131,220,130,212,130,209,130,222,130,211,130,223,130,239,130,6,131,80,134,121,134,123,134,122,134,77,136,107,136,129,137,212,137,8,138,2,138,3,138,158,140,160,140,116,141,115,141,180,141,205,142,204,142,240,143,230,143,226,143,234,143,229,143,237,143,235,143,228,143,232,143,202,144,206,144,193,144,195,144,75,145,74,145,205,145,130,149,80,150,75,150,76,150,77,150,98,151,105,151,203,151,237,151,243,151,1,152,168,152,219,152,223,152,150,153,153,153,88,78,179,78,12,80,13,80,35,80,239,79,38,80,37,80,248,79,41,80,22,80,6,80,60,80,31,80,26,80,18,80,17,80,250,79,0,80,20,80,40,80,241,79,33,80,11,80,25,80,24,80,243,79,238,79,45,80,42,80,254,79,43,80,9,80,124,81,164,81,165,81,162,81,205,81,204,81,198,81,203,81,86,82,92,82,84,82,91,82,93,82,42,83,127,83,159,83,157,83,223,83,232,84,16,85,1,85,55,85,252,84,229,84,242,84,6,85,250,84,20,85,233,84,237,84,225,84,9,85,238,84,234,84,230,84,39,85,7,85,253,84,15,85,3,87,4,87,194,87,212,87,203,87,195,87,9,88,15,89,87,89,88,89,90,89,17,90,24,90,28,90,31,90,27,90,19,90,236,89,32,90,35,90,41,90,37,90,12,90,9,90,107,91,88,92,176,91,179,91,182,91,180,91,174,91,181,91,185,91,184,91,4,92,81,92,85,92,80,92,237,92,253,92,251,92,234,92,232,92,240,92,246,92,1,93,244,92,238,93,45,94,43,94,171,94,173,94,167,94,49,95,146,95,145,95,144,95,89,96,99,96,101,96,80,96,85,96,109,96,105,96,111,96,132,96,159,96,154,96,141,96,148,96,140,96,133,96,150,96,71,98,243,98,8,99,255,98,78,99,62,99,47,99,85,99,66,99,70,99,79,99,73,99,58,99,80,99,61,99,42,99,43,99,40,99,77,99,76,99,72,101,73,101,153,101,193,101,197,101,66,102,73,102,79,102,67,102,82,102,76,102,69,102,65,102,248,102,20,103,21,103,23,103,33,104,56,104,72,104,70,104,83,104,57,104,66,104,84,104,41,104,179,104,23,104,76,104,81,104,61,104,244,103,80,104,64,104,60,104,67,104,42,104,69,104,19,104,24,104,65,104,138,107,137,107,183,107,35,108,39,108,40,108,38,108,36,108,240,108,106,109,149,109,136,109,135,109,102,109,120,109,119,109,89,109,147,109,108,109,137,109,110,109,90,109,116,109,105,109,140,109,138,109,121,109,133,109,101,109,148,109,202,112,216,112,228,112,217,112,200,112,207,112,57,114,121,114,252,114,249,114,253,114,248,114,247,114,134,115,237,115,9,116,238,115,224,115,234,115,222,115,84,117,93,117,92,117,90,117,89,117,190,117,197,117,199,117,178,117,179,117,189,117,188,117,185,117,194,117,184,117,139,118,176,118,202,118,205,118,206,118,41,119,31,119,32,119,40,119,233,119,48,120,39,120,56,120,29,120,52,120,55,120,37,120,45,120,32,120,31,120,50,120,85,121,80,121,96,121,95,121,86,121,94,121,93,121,87,121,90,121,228,121,227,121,231,121,223,121,230,121,233,121,216,121,132,122,136,122,217,122,6,123,17,123,137,124,33,125,23,125,11,125,10,125,32,125,34,125,20,125,16,125,21,125,26,125,28,125,13,125,25,125,27,125,58,127,95,127,148,127,197,127,193,127,6,128,24,128,21,128,25,128,23,128,61,128,63,128,241,128,2,129,240,128,5,129,237,128,244,128,6,129,248,128,243,128,8,129,253,128,10,129,252,128,239,128,237,129,236,129,0,130,16,130,42,130,43,130,40,130,44,130,187,130,43,131,82,131,84,131,74,131,56,131,80,131,73,131,53,131,52,131,79,131,50,131,57,131,54,131,23,131,64,131,49,131,40,131,67,131,84,134,138,134,170,134,147,134,164,134,169,134,140,134,163,134,156,134,112,136,119,136,129,136,130,136,125,136,121,136,24,138,16,138,14,138,12,138,21,138,10,138,23,138,19,138,22,138,15,138,17,138,72,140,122,140,121,140,161,140,162,140,119,141,172,142,210,142,212,142,207,142,177,143,1,144,6,144,247,143,0,144,250,143,244,143,3,144,253,143,5,144,248,143,149,144,225,144,221,144,226,144,82,145,77,145,76,145,216,145,221,145,215,145,220,145,217,145,131,149,98,150,99,150,97,150,91,150,93,150,100,150,88,150,94,150,187,150,226,152,172,153,168,154,216,154,37,155,50,155,60,155,126,78,122,80,125,80,92,80,71,80,67,80,76,80,90,80,73,80,101,80,118,80,78,80,85,80,117,80,116,80,119,80,79,80,15,80,111,80,109,80,92,81,149,81,240,81,106,82,111,82,210,82,217,82,216,82,213,82,16,83,15,83,25,83,63,83,64,83,62,83,195,83,252,102,70,85,106,85,102,85,68,85,94,85,97,85,67,85,74,85,49,85,86,85,79,85,85,85,47,85,100,85,56,85,46,85,92,85,44,85,99,85,51,85,65,85,87,85,8,87,11,87,9,87,223,87,5,88,10,88,6,88,224,87,228,87,250,87,2,88,53,88,247,87,249,87,32,89,98,89,54,90,65,90,73,90,102,90,106,90,64,90,60,90,98,90,90,90,70,90,74,90,112,91,199,91,197,91,196,91,194,91,191,91,198,91,9,92,8,92,7,92,96,92,92,92,93,92,7,93,6,93,14,93,27,93,22,93,34,93,17,93,41,93,20,93,25,93,36,93,39,93,23,93,226,93,56,94,54,94,51,94,55,94,183,94,184,94,182,94,181,94,190,94,53,95,55,95,87,95,108,95,105,95,107,95,151,95,153,95,158,95,152,95,161,95,160,95,156,95,127,96,163,96,137,96,160,96,168,96,203,96,180,96,230,96,189,96,197,96,187,96,181,96,220,96,188,96,216,96,213,96,198,96,223,96,184,96,218,96,199,96,26,98,27,98,72,98,160,99,167,99,114,99,150,99,162,99,165,99,119,99,103,99,152,99,170,99,113,99,169,99,137,99,131,99,155,99,107,99,168,99,132,99,136,99,153,99,161,99,172,99,146,99,143,99,128,99,123,99,105,99,104,99,122,99,93,101,86,101,81,101,89,101,87,101,95,85,79,101,88,101,85,101,84,101,156,101,155,101,172,101,207,101,203,101,204,101,206,101,93,102,90,102,100,102,104,102,102,102,94,102,249,102,215,82,27,103,129,104,175,104,162,104,147,104,181,104,127,104,118,104,177,104,167,104,151,104,176,104,131,104,196,104,173,104,134,104,133,104,148,104,157,104,168,104,159,104,161,104,130,104,50,107,186,107,235,107,236,107,43,108,142,109,188,109,243,109,217,109,178,109,225,109,204,109,228,109,251,109,250,109,5,110,199,109,203,109,175,109,209,109,174,109,222,109,249,109,184,109,247,109,245,109,197,109,210,109,26,110,181,109,218,109,235,109,216,109,234,109,241,109,238,109,232,109,198,109,196,109,170,109,236,109,191,109,230,109,249,112,9,113,10,113,253,112,239,112,61,114,125,114,129,114,28,115,27,115,22,115,19,115,25,115,135,115,5,116,10,116,3,116,6,116,254,115,13,116,224,116,246,116,247,116,28,117,34,117,101,117,102,117,98,117,112,117,143,117,212,117,213,117,181,117,202,117,205,117,142,118,212,118,210,118,219,118,55,119,62,119,60,119,54,119,56,119,58,119,107,120,67,120,78,120,101,121,104,121,109,121,251,121,146,122,149,122,32,123,40,123,27,123,44,123,38,123,25,123,30,123,46,123,146,124,151,124,149,124,70,125,67,125,113,125,46,125,57,125,60,125,64,125,48,125,51,125,68,125,47,125,66,125,50,125,49,125,61,127,158,127,154,127,204,127,206,127,210,127,28,128,74,128,70,128,47,129,22,129,35,129,43,129,41,129,48,129,36,129,2,130,53,130,55,130,54,130,57,130,142,131,158,131,152,131,120,131,162,131,150,131,189,131,171,131,146,131,138,131,147,131,137,131,160,131,119,131,123,131,124,131,134,131,167,131,85,134,106,95,199,134,192,134,182,134,196,134,181,134,198,134,203,134,177,134,175,134,201,134,83,136,158,136,136,136,171,136,146,136,150,136,141,136,139,136,147,137,143,137,42,138,29,138,35,138,37,138,49,138,45,138,31,138,27,138,34,138,73,140,90,140,169,140,172,140,171,140,168,140,170,140,167,140,103,141,102,141,190,141,186,141,219,142,223,142,25,144,13,144,26,144,23,144,35,144,31,144,29,144,16,144,21,144,30,144,32,144,15,144,34,144,22,144,27,144,20,144,232,144,237,144,253,144,87,145,206,145,245,145,230,145,227,145,231,145,237,145,233,145,137,149,106,150,117,150,115,150,120,150,112,150,116,150,118,150,119,150,108,150,192,150,234,150,233,150,224,122,223,122,2,152,3,152,90,155,229,156,117,158,127,158,165,158,187,158,162,80,141,80,133,80,153,80,145,80,128,80,150,80,152,80,154,80,0,103,241,81,114,82,116,82,117,82,105,82,222,82,221,82,219,82,90,83,165,83,123,85,128,85,167,85,124,85,138,85,157,85,152,85,130,85,156,85,170,85,148,85,135,85,139,85,131,85,179,85,174,85,159,85,62,85,178,85,154,85,187,85,172,85,177,85,126,85,137,85,171,85,153,85,13,87,47,88,42,88,52,88,36,88,48,88,49,88,33,88,29,88,32,88,249,88,250,88,96,89,119,90,154,90,127,90,146,90,155,90,167,90,115,91,113,91,210,91,204,91,211,91,208,91,10,92,11,92,49,92,76,93,80,93,52,93,71,93,253,93,69,94,61,94,64,94,67,94,126,94,202,94,193,94,194,94,196,94,60,95,109,95,169,95,170,95,168,95,209,96,225,96,178,96,182,96,224,96,28,97,35,97,250,96,21,97,240,96,251,96,244,96,104,97,241,96,14,97,246,96,9,97,0,97,18,97,31,98,73,98,163,99,140,99,207,99,192,99,233,99,201,99,198,99,205,99,210,99,227,99,208,99,225,99,214,99,237,99,238,99,118,99,244,99,234,99,219,99,82,100,218,99,249,99,94,101,102,101,98,101,99,101,145,101,144,101,175,101,110,102,112,102,116,102,118,102,111,102,145,102,122,102,126,102,119,102,254,102,255,102,31,103,29,103,250,104,213,104,224,104,216,104,215,104,5,105,223,104,245,104,238,104,231,104,249,104,210,104,242,104,227,104,203,104,205,104,13,105,18,105,14,105,201,104,218,104,110,105,251,104,62,107,58,107,61,107,152,107,150,107,188,107,239,107,46,108,47,108,44,108,47,110,56,110,84,110,33,110,50,110,103,110,74,110,32,110,37,110,35,110,27,110,91,110,88,110,36,110,86,110,110,110,45,110,38,110,111,110,52,110,77,110,58,110,44,110,67,110,29,110,62,110,203,110,137,110,25,110,78,110,99,110,68,110,114,110,105,110,95,110,25,113,26,113,38,113,48,113,33,113,54,113,110,113,28,113,76,114,132,114,128,114,54,115,37,115,52,115,41,115,58,116,42,116,51,116,34,116,37,116,53,116,54,116,52,116,47,116,27,116,38,116,40,116,37,117,38,117,107,117,106,117,226,117,219,117,227,117,217,117,216,117,222,117,224,117,123,118,124,118,150,118,147,118,180,118,220,118,79,119,237,119,93,120,108,120,111,120,13,122,8,122,11,122,5,122,0,122,152,122,151,122,150,122,229,122,227,122,73,123,86,123,70,123,80,123,82,123,84,123,77,123,75,123,79,123,81,123,159,124,165,124,94,125,80,125,104,125,85,125,43,125,110,125,114,125,97,125,102,125,98,125,112,125,115,125,132,85,212,127,213,127,11,128,82,128,133,128,85,129,84,129,75,129,81,129,78,129,57,129,70,129,62,129,76,129,83,129,116,129,18,130,28,130,233,131,3,132,248,131,13,132,224,131,197,131,11,132,193,131,239,131,241,131,244,131,87,132,10,132,240,131,12,132,204,131,253,131,242,131,202,131,56,132,14,132,4,132,220,131,7,132,212,131,223,131,91,134,223,134,217,134,237,134,212,134,219,134,228,134,208,134,222,134,87,136,193,136,194,136,177,136,131,137,150,137,59,138,96,138,85,138,94,138,60,138,65,138,84,138,91,138,80,138,70,138,52,138,58,138,54,138,86,138,97,140,130,140,175,140,188,140,179,140,189,140,193,140,187,140,192,140,180,140,183,140,182,140,191,140,184,140,138,141,133,141,129,141,206,141,221,141,203,141,218,141,209,141,204,141,219,141,198,141,251,142,248,142,252,142,156,143,46,144,53,144,49,144,56,144,50,144,54,144,2,145,245,144,9,145,254,144,99,145,101,145,207,145,20,146,21,146,35,146,9,146,30,146,13,146,16,146,7,146,17,146,148,149,143,149,139,149,145,149,147,149,146,149,142,149,138,150,142,150,139,150,125,150,133,150,134,150,141,150,114,150,132,150,193,150,197,150,196,150,198,150,199,150,239,150,242,150,204,151,5,152,6,152,8,152,231,152,234,152,239,152,233,152,242,152,237,152,174,153,173,153,195,158,205,158,209,158,130,78,173,80,181,80,178,80,179,80,197,80,190,80,172,80,183,80,187,80,175,80,199,80,127,82,119,82,125,82,223,82,230,82,228,82,226,82,227,82,47,83,223,85,232,85,211,85,230,85,206,85,220,85,199,85,209,85,227,85,228,85,239,85,218,85,225,85,197,85,198,85,229,85,201,85,18,87,19,87,94,88,81,88,88,88,87,88,90,88,84,88,107,88,76,88,109,88,74,88,98,88,82,88,75,88,103,89,193,90,201,90,204,90,190,90,189,90,188,90,179,90,194,90,178,90,105,93,111,93,76,94,121,94,201,94,200,94,18,95,89,95,172,95,174,95,26,97,15,97,72,97,31,97,243,96,27,97,249,96,1,97,8,97,78,97,76,97,68,97,77,97,62,97,52,97,39,97,13,97,6,97,55,97,33,98,34,98,19,100,62,100,30,100,42,100,45,100,61,100,44,100,15,100,28,100,20,100,13,100,54,100,22,100,23,100,6,100,108,101,159,101,176,101,151,102,137,102,135,102,136,102,150,102,132,102,152,102,141,102,3,103,148,105,109,105,90,105,119,105,96,105,84,105,117,105,48,105,130,105,74,105,104,105,107,105,94,105,83,105,121,105,134,105,93,105,99,105,91,105,71,107,114,107,192,107,191,107,211,107,253,107,162,110,175,110,211,110,182,110,194,110,144,110,157,110,199,110,197,110,165,110,152,110,188,110,186,110,171,110,209,110,150,110,156,110,196,110,212,110,170,110,167,110,180,110,78,113,89,113,105,113,100,113,73,113,103,113,92,113,108,113,102,113,76,113,101,113,94,113,70,113,104,113,86,113,58,114,82,114,55,115,69,115,63,115,62,115,111,116,90,116,85,116,95,116,94,116,65,116,63,116,89,116,91,116,92,116,118,117,120,117,0,118,240,117,1,118,242,117,241,117,250,117,255,117,244,117,243,117,222,118,223,118,91,119,107,119,102,119,94,119,99,119,121,119,106,119,108,119,92,119,101,119,104,119,98,119,238,119,142,120,176,120,151,120,152,120,140,120,137,120,124,120,145,120,147,120,127,120,122,121,127,121,129,121,44,132,189,121,28,122,26,122,32,122,20,122,31,122,30,122,159,122,160,122,119,123,192,123,96,123,110,123,103,123,177,124,179,124,181,124,147,125,121,125,145,125,129,125,143,125,91,125,110,127,105,127,106,127,114,127,169,127,168,127,164,127,86,128,88,128,134,128,132,128,113,129,112,129,120,129,101,129,110,129,115,129,107,129,121,129,122,129,102,129,5,130,71,130,130,132,119,132,61,132,49,132,117,132,102,132,107,132,73,132,108,132,91,132,60,132,53,132,97,132,99,132,105,132,109,132,70,132,94,134,92,134,95,134,249,134,19,135,8,135,7,135,0,135,254,134,251,134,2,135,3,135,6,135,10,135,89,136,223,136,212,136,217,136,220,136,216,136,221,136,225,136,202,136,213,136,210,136,156,137,227,137,107,138,114,138,115,138,102,138,105,138,112,138,135,138,124,138,99,138,160,138,113,138,133,138,109,138,98,138,110,138,108,138,121,138,123,138,62,138,104,138,98,140,138,140,137,140,202,140,199,140,200,140,196,140,178,140,195,140,194,140,197,140,225,141,223,141,232,141,239,141,243,141,250,141,234,141,228,141,230,141,178,142,3,143,9,143,254,142,10,143,159,143,178,143,75,144,74,144,83,144,66,144,84,144,60,144,85,144,80,144,71,144,79,144,78,144,77,144,81,144,62,144,65,144,18,145,23,145,108,145,106,145,105,145,201,145,55,146,87,146,56,146,61,146,64,146,62,146,91,146,75,146,100,146,81,146,52,146,73,146,77,146,69,146,57,146,63,146,90,146,152,149,152,150,148,150,149,150,205,150,203,150,201,150,202,150,247,150,251,150,249,150,246,150,86,151,116,151,118,151,16,152,17,152,19,152,10,152,18,152,12,152,252,152,244,152,253,152,254,152,179,153,177,153,180,153,225,154,233,156,130,158,14,159,19,159,32,159,231,80,238,80,229,80,214,80,237,80,218,80,213,80,207,80,209,80,241,80,206,80,233,80,98,81,243,81,131,82,130,82,49,83,173,83,254,85,0,86,27,86,23,86,253,85,20,86,6,86,9,86,13,86,14,86,247,85,22,86,31,86,8,86,16,86,246,85,24,87,22,87,117,88,126,88,131,88,147,88,138,88,121,88,133,88,125,88,253,88,37,89,34,89,36,89,106,89,105,89,225,90,230,90,233,90,215,90,214,90,216,90,227,90,117,91,222,91,231,91,225,91,229,91,230,91,232,91,226,91,228,91,223,91,13,92,98,92,132,93,135,93,91,94,99,94,85,94,87,94,84,94,211,94,214,94,10,95,70,95,112,95,185,95,71,97,63,97,75,97,119,97,98,97,99,97,95,97,90,97,88,97,117,97,42,98,135,100,88,100,84,100,164,100,120,100,95,100,122,100,81,100,103,100,52,100,109,100,123,100,114,101,161,101,215,101,214,101,162,102,168,102,157,102,156,105,168,105,149,105,193,105,174,105,211,105,203,105,155,105,183,105,187,105,171,105,180,105,208,105,205,105,173,105,204,105,166,105,195,105,163,105,73,107,76,107,51,108,51,111,20,111,254,110,19,111,244,110,41,111,62,111,32,111,44,111,15,111,2,111,34,111,255,110,239,110,6,111,49,111,56,111,50,111,35,111,21,111,43,111,47,111,136,111,42,111,236,110,1,111,242,110,204,110,247,110,148,113,153,113,125,113,138,113,132,113,146,113,62,114,146,114,150,114,68,115,80,115,100,116,99,116,106,116,112,116,109,116,4,117,145,117,39,118,13,118,11,118,9,118,19,118,225,118,227,118,132,119,125,119,127,119,97,119,193,120,159,120,167,120,179,120,169,120,163,120,142,121,143,121,141,121,46,122,49,122,170,122,169,122,237,122,239,122,161,123,149,123,139,123,117,123,151,123,157,123,148,123,143,123,184,123,135,123,132,123,185,124,189,124,190,124,187,125,176,125,156,125,189,125,190,125,160,125,202,125,180,125,178,125,177,125,186,125,162,125,191,125,181,125,184,125,173,125,210,125,199,125,172,125,112,127,224,127,225,127,223,127,94,128,90,128,135,128,80,129,128,129,143,129,136,129,138,129,127,129,130,129,231,129,250,129,7,130,20,130,30,130,75,130,201,132,191,132,198,132,196,132,153,132,158,132,178,132,156,132,203,132,184,132,192,132,211,132,144,132,188,132,209,132,202,132,63,135,28,135,59,135,34,135,37,135,52,135,24,135,85,135,55,135,41,135,243,136,2,137,244,136,249,136,248,136,253,136,232,136,26,137,239,136,166,138,140,138,158,138,163,138,141,138,161,138,147,138,164,138,170,138,165,138,168,138,152,138,145,138,154,138,167,138,106,140,141,140,140,140,211,140,209,140,210,140,107,141,153,141,149,141,252,141,20,143,18,143,21,143,19,143,163,143,96,144,88,144,92,144,99,144,89,144,94,144,98,144,93,144,91,144,25,145,24,145,30,145,117,145,120,145,119,145,116,145,120,146,128,146,133,146,152,146,150,146,123,146,147,146,156,146,168,146,124,146,145,146,161,149,168,149,169,149,163,149,165,149,164,149,153,150,156,150,155,150,204,150,210,150,0,151,124,151,133,151,246,151,23,152,24,152,175,152,177,152,3,153,5,153,12,153,9,153,193,153,175,154,176,154,230,154,65,155,66,155,244,156,246,156,243,156,188,158,59,159,74,159,4,81,0,81,251,80,245,80,249,80,2,81,8,81,9,81,5,81,220,81,135,82,136,82,137,82,141,82,138,82,240,82,178,83,46,86,59,86,57,86,50,86,63,86,52,86,41,86,83,86,78,86,87,86,116,86,54,86,47,86,48,86,128,88,159,88,158,88,179,88,156,88,174,88,169,88,166,88,109,89,9,91,251,90,11,91,245,90,12,91,8,91,238,91,236,91,233,91,235,91,100,92,101,92,157,93,148,93,98,94,95,94,97,94,226,94,218,94,223,94,221,94,227,94,224,94,72,95,113,95,183,95,181,95,118,97,103,97,110,97,93,97,85,97,130,97,124,97,112,97,107,97,126,97,167,97,144,97,171,97,142,97,172,97,154,97,164,97,148,97,174,97,46,98,105,100,111,100,121,100,158,100,178,100,136,100,144,100,176,100,165,100,147,100,149,100,169,100,146,100,174,100,173,100,171,100,154,100,172,100,153,100,162,100,179,100,117,101,119,101,120,101,174,102,171,102,180,102,177,102,35,106,31,106,232,105,1,106,30,106,25,106,253,105,33,106,19,106,10,106,243,105,2,106,5,106,237,105,17,106,80,107,78,107,164,107,197,107,198,107,63,111,124,111,132,111,81,111,102,111,84,111,134,111,109,111,91,111,120,111,110,111,142,111,122,111,112,111,100,111,151,111,88,111,213,110,111,111,96,111,95,111,159,113,172,113,177,113,168,113,86,114,155,114,78,115,87,115,105,116,139,116,131,116,126,116,128,116,127,117,32,118,41,118,31,118,36,118,38,118,33,118,34,118,154,118,186,118,228,118,142,119,135,119,140,119,145,119,139,119,203,120,197,120,186,120,202,120,190,120,213,120,188,120,208,120,63,122,60,122,64,122,61,122,55,122,59,122,175,122,174,122,173,123,177,123,196,123,180,123,198,123,199,123,193,123,160,123,204,123,202,124,224,125,244,125,239,125,251,125,216,125,236,125,221,125,232,125,227,125,218,125,222,125,233,125,158,125,217,125,242,125,249,125,117,127,119,127,175,127,233,127,38,128,155,129,156,129,157,129,160,129,154,129,152,129,23,133,61,133,26,133,238,132,44,133,45,133,19,133,17,133,35,133,33,133,20,133,236,132,37,133,255,132,6,133,130,135,116,135,118,135,96,135,102,135,120,135,104,135,89,135,87,135,76,135,83,135,91,136,93,136,16,137,7,137,18,137,19,137,21,137,10,137,188,138,210,138,199,138,196,138,149,138,203,138,248,138,178,138,201,138,194,138,191,138,176,138,214,138,205,138,182,138,185,138,219,138,76,140,78,140,108,140,224,140,222,140,230,140,228,140,236,140,237,140,226,140,227,140,220,140,234,140,225,140,109,141,159,141,163,141,43,142,16,142,29,142,34,142,15,142,41,142,31,142,33,142,30,142,186,142,29,143,27,143,31,143,41,143,38,143,42,143,28,143,30,143,37,143,105,144,110,144,104,144,109,144,119,144,48,145,45,145,39,145,49,145,135,145,137,145,139,145,131,145,197,146,187,146,183,146,234,146,172,146,228,146,193,146,179,146,188,146,210,146,199,146,240,146,178,146,173,149,177,149,4,151,6,151,7,151,9,151,96,151,141,151,139,151,143,151,33,152,43,152,28,152,179,152,10,153,19,153,18,153,24,153,221,153,208,153,223,153,219,153,209,153,213,153,210,153,217,153,183,154,238,154,239,154,39,155,69,155,68,155,119,155,111,155,6,157,9,157,3,157,169,158,190,158,206,158,168,88,82,159,18,81,24,81,20,81,16,81,21,81,128,81,170,81,221,81,145,82,147,82,243,82,89,86,107,86,121,86,105,86,100,86,120,86,106,86,104,86,101,86,113,86,111,86,108,86,98,86,118,86,193,88,190,88,199,88,197,88,110,89,29,91,52,91,120,91,240,91,14,92,74,95,178,97,145,97,169,97,138,97,205,97,182,97,190,97,202,97,200,97,48,98,197,100,193,100,203,100,187,100,188,100,218,100,196,100,199,100,194,100,205,100,191,100,210,100,212,100,190,100,116,101,198,102,201,102,185,102,196,102,199,102,184,102,61,106,56,106,58,106,89,106,107,106,88,106,57,106,68,106,98,106,97,106,75,106,71,106,53,106,95,106,72,106,89,107,119,107,5,108,194,111,177,111,161,111,195,111,164,111,193,111,167,111,179,111,192,111,185,111,182,111,166,111,160,111,180,111,190,113,201,113,208,113,210,113,200,113,213,113,185,113,206,113,217,113,220,113,195,113,196,113,104,115,156,116,163,116,152,116,159,116,158,116,226,116,12,117,13,117,52,118,56,118,58,118,231,118,229,118,160,119,158,119,159,119,165,119,232,120,218,120,236,120,231,120,166,121,77,122,78,122,70,122,76,122,75,122,186,122,217,123,17,124,201,123,228,123,219,123,225,123,233,123,230,123,213,124,214,124,10,126,17,126,8,126,27,126,35,126,30,126,29,126,9,126,16,126,121,127,178,127,240,127,241,127,238,127,40,128,179,129,169,129,168,129,251,129,8,130,88,130,89,130,74,133,89,133,72,133,104,133,105,133,67,133,73,133,109,133,106,133,94,133,131,135,159,135,158,135,162,135,141,135,97,136,42,137,50,137,37,137,43,137,33,137,170,137,166,137,230,138,250,138,235,138,241,138,0,139,220,138,231,138,238,138,254,138,1,139,2,139,247,138,237,138,243,138,246,138,252,138,107,140,109,140,147,140,244,140,68,142,49,142,52,142,66,142,57,142,53,142,59,143,47,143,56,143,51,143,168,143,166,143,117,144,116,144,120,144,114,144,124,144,122,144,52,145,146,145,32,147,54,147,248,146,51,147,47,147,34,147,252,146,43,147,4,147,26,147,16,147,38,147,33,147,21,147,46,147,25,147,187,149,167,150,168,150,170,150,213,150,14,151,17,151,22,151,13,151,19,151,15,151,91,151,92,151,102,151,152,151,48,152,56,152,59,152,55,152,45,152,57,152,36,152,16,153,40,153,30,153,27,153,33,153,26,153,237,153,226,153,241,153,184,154,188,154,251,154,237,154,40,155,145,155,21,157,35,157,38,157,40,157,18,157,27,157,216,158,212,158,141,159,156,159,42,81,31,81,33,81,50,81,245,82,142,86,128,86,144,86,133,86,135,86,143,86,213,88,211,88,209,88,206,88,48,91,42,91,36,91,122,91,55,92,104,92,188,93,186,93,189,93,184,93,107,94,76,95,189,95,201,97,194,97,199,97,230,97,203,97,50,98,52,98,206,100,202,100,216,100,224,100,240,100,230,100,236,100,241,100,226,100,237,100,130,101,131,101,217,102,214,102,128,106,148,106,132,106,162,106,156,106,219,106,163,106,126,106,151,106,144,106,160,106,92,107,174,107,218,107,8,108,216,111,241,111,223,111,224,111,219,111,228,111,235,111,239,111,128,111,236,111,225,111,233,111,213,111,238,111,240,111,231,113,223,113,238,113,230,113,229,113,237,113,236,113,244,113,224,113,53,114,70,114,112,115,114,115,169,116,176,116,166,116,168,116,70,118,66,118,76,118,234,118,179,119,170,119,176,119,172,119,167,119,173,119,239,119,247,120,250,120,244,120,239,120,1,121,167,121,170,121,87,122,191,122,7,124,13,124,254,123,247,123,12,124,224,123,224,124,220,124,222,124,226,124,223,124,217,124,221,124,46,126,62,126,70,126,55,126,50,126,67,126,43,126,61,126,49,126,69,126,65,126,52,126,57,126,72,126,53,126,63,126,47,126,68,127,243,127,252,127,113,128,114,128,112,128,111,128,115,128,198,129,195,129,186,129,194,129,192,129,191,129,189,129,201,129,190,129,232,129,9,130,113,130,170,133,132,133,126,133,156,133,145,133,148,133,175,133,155,133,135,133,168,133,138,133,103,134,192,135,209,135,179,135,210,135,198,135,171,135,187,135,186,135,200,135,203,135,59,137,54,137,68,137,56,137,61,137,172,137,14,139,23,139,25,139,27,139,10,139,32,139,29,139,4,139,16,139,65,140,63,140,115,140,250,140,253,140,252,140,248,140,251,140,168,141,73,142,75,142,72,142,74,142,68,143,62,143,66,143,69,143,63,143,127,144,125,144,132,144,129,144,130,144,128,144,57,145,163,145,158,145,156,145,77,147,130,147,40,147,117,147,74,147,101,147,75,147,24,147,126,147,108,147,91,147,112,147,90,147,84,147,202,149,203,149,204,149,200,149,198,149,177,150,184,150,214,150,28,151,30,151,160,151,211,151,70,152,182,152,53,153,1,154,255,153,174,155,171,155,170,155,173,155,59,157,63,157,139,158,207,158,222,158,220,158,221,158,219,158,62,159,75,159,226,83,149,86,174,86,217,88,216,88,56,91,93,95,227,97,51,98,244,100,242,100,254,100,6,101,250,100,251,100,247,100,183,101,220,102,38,103,179,106,172,106,195,106,187,106,184,106,194,106,174,106,175,106,95,107,120,107,175,107,9,112,11,112,254,111,6,112,250,111,17,112,15,112,251,113,252,113,254,113,248,113,119,115,117,115,167,116,191,116,21,117,86,118,88,118,82,118,189,119,191,119,187,119,188,119,14,121,174,121,97,122,98,122,96,122,196,122,197,122,43,124,39,124,42,124,30,124,35,124,33,124,231,124,84,126,85,126,94,126,90,126,97,126,82,126,89,126,72,127,249,127,251,127,119,128,118,128,205,129,207,129,10,130,207,133,169,133,205,133,208,133,201,133,176,133,186,133,185,133,166,133,239,135,236,135,242,135,224,135,134,137,178,137,244,137,40,139,57,139,44,139,43,139,80,140,5,141,89,142,99,142,102,142,100,142,95,142,85,142,192,142,73,143,77,143,135,144,131,144,136,144,171,145,172,145,208,145,148,147,138,147,150,147,162,147,179,147,174,147,172,147,176,147,152,147,154,147,151,147,212,149,214,149,208,149,213,149,226,150,220,150,217,150,219,150,222,150,36,151,163,151,166,151,173,151,249,151,77,152,79,152,76,152,78,152,83,152,186,152,62,153,63,153,61,153,46,153,165,153,14,154,193,154,3,155,6,155,79,155,78,155,77,155,202,155,201,155,253,155,200,155],"i8",ALLOC_NONE,Runtime.GLOBAL_BASE+281828),
	allocate([192,155,81,157,93,157,96,157,224,158,21,159,44,159,51,81,165,86,222,88,223,88,226,88,245,91,144,159,236,94,242,97,247,97,246,97,245,97,0,101,15,101,224,102,221,102,229,106,221,106,218,106,211,106,27,112,31,112,40,112,26,112,29,112,21,112,24,112,6,114,13,114,88,114,162,114,120,115,122,115,189,116,202,116,227,116,135,117,134,117,95,118,97,118,199,119,25,121,177,121,107,122,105,122,62,124,63,124,56,124,61,124,55,124,64,124,107,126,109,126,121,126,105,126,106,126,133,127,115,126,182,127,185,127,184,127,216,129,233,133,221,133,234,133,213,133,228,133,229,133,247,133,251,135,5,136,13,136,249,135,254,135,96,137,95,137,86,137,94,137,65,139,92,139,88,139,73,139,90,139,78,139,79,139,70,139,89,139,8,141,10,141,124,142,114,142,135,142,118,142,108,142,122,142,116,142,84,143,78,143,173,143,138,144,139,144,177,145,174,145,225,147,209,147,223,147,195,147,200,147,220,147,221,147,214,147,226,147,205,147,216,147,228,147,215,147,232,147,220,149,180,150,227,150,42,151,39,151,97,151,220,151,251,151,94,152,88,152,91,152,188,152,69,153,73,153,22,154,25,154,13,155,232,155,231,155,214,155,219,155,137,157,97,157,114,157,106,157,108,157,146,158,151,158,147,158,180,158,248,82,168,86,183,86,182,86,180,86,188,86,228,88,64,91,67,91,125,91,246,91,201,93,248,97,250,97,24,101,20,101,25,101,230,102,39,103,236,106,62,112,48,112,50,112,16,114,123,115,207,116,98,118,101,118,38,121,42,121,44,121,43,121,199,122,246,122,76,124,67,124,77,124,239,124,240,124,174,143,125,126,124,126,130,126,76,127,0,128,218,129,102,130,251,133,249,133,17,134,250,133,6,134,11,134,7,134,10,134,20,136,21,136,100,137,186,137,248,137,112,139,108,139,102,139,111,139,95,139,107,139,15,141,13,141,137,142,129,142,133,142,130,142,180,145,203,145,24,148,3,148,253,147,225,149,48,151,196,152,82,153,81,153,168,153,43,154,48,154,55,154,53,154,19,156,13,156,121,158,181,158,232,158,47,159,95,159,99,159,97,159,55,81,56,81,193,86,192,86,194,86,20,89,108,92,205,93,252,97,254,97,29,101,28,101,149,101,233,102,251,106,4,107,250,106,178,107,76,112,27,114,167,114,214,116,212,116,105,118,211,119,80,124,143,126,140,126,188,127,23,134,45,134,26,134,35,136,34,136,33,136,31,136,106,137,108,137,189,137,116,139,119,139,125,139,19,141,138,142,141,142,139,142,95,143,175,143,186,145,46,148,51,148,53,148,58,148,56,148,50,148,43,148,226,149,56,151,57,151,50,151,255,151,103,152,101,152,87,153,69,154,67,154,64,154,62,154,207,154,84,155,81,155,45,156,37,156,175,157,180,157,194,157,184,157,157,158,239,158,25,159,92,159,102,159,103,159,60,81,59,81,200,86,202,86,201,86,127,91,212,93,210,93,78,95,255,97,36,101,10,107,97,107,81,112,88,112,128,115,228,116,138,117,110,118,108,118,179,121,96,124,95,124,126,128,125,128,223,129,114,137,111,137,252,137,128,139,22,141,23,141,145,142,147,142,97,143,72,145,68,148,81,148,82,148,61,151,62,151,195,151,193,151,107,152,85,153,85,154,77,154,210,154,26,155,73,156,49,156,62,156,59,156,211,157,215,157,52,159,108,159,106,159,148,159,204,86,214,93,0,98,35,101,43,101,42,101,236,102,16,107,218,116,202,122,100,124,99,124,101,124,147,126,150,126,148,126,226,129,56,134,63,134,49,136,138,139,144,144,143,144,99,148,96,148,100,148,104,151,111,152,92,153,90,154,91,154,87,154,211,154,212,154,209,154,84,156,87,156,86,156,229,157,159,158,244,158,209,86,233,88,44,101,94,112,113,118,114,118,215,119,80,127,136,127,54,136,57,136,98,136,147,139,146,139,150,139,119,130,27,141,192,145,106,148,66,151,72,151,68,151,198,151,112,152,95,154,34,155,88,155,95,156,249,157,250,157,124,158,125,158,7,159,119,159,114,159,243,94,22,107,99,112,108,124,110,124,59,136,192,137,161,142,193,145,114,148,112,148,113,152,94,153,214,154,35,155,204,158,100,112,218,119,154,139,119,148,201,151,98,154,101,154,156,126,156,139,170,142,197,145,125,148,126,148,124,148,119,156,120,156,247,158,84,140,127,148,26,158,40,114,106,154,49,155,27,158,30,158,114,124,96,36,97,36,98,36,99,36,100,36,101,36,102,36,103,36,104,36,105,36,116,36,117,36,118,36,119,36,120,36,121,36,122,36,123,36,124,36,125,36,112,33,113,33,114,33,115,33,116,33,117,33,118,33,119,33,120,33,121,33,54,78,63,78,133,78,160,78,130,81,150,81,171,81,249,82,56,83,105,83,182,83,10,89,128,91,219,93,122,94,127,94,244,94,80,95,97,95,52,101,224,101,146,117,118,118,181,143,182,150,168,0,198,2,253,48,254,48,157,48,158,48,0,0,0,0,5,48,6,48,7,48,252,48,59,255,61,255,61,39,65,48,66,48,67,48,68,48,69,48,70,48,71,48,72,48,73,48,74,48,75,48,76,48,77,48,78,48,79,48,80,48,81,48,82,48,83,48,84,48,85,48,86,48,87,48,88,48,89,48,90,48,91,48,92,48,93,48,94,48,95,48,96,48,97,48,98,48,99,48,100,48,101,48,102,48,103,48,104,48,105,48,106,48,107,48,108,48,109,48,110,48,111,48,112,48,113,48,114,48,115,48,116,48,117,48,118,48,119,48,120,48,121,48,122,48,123,48,124,48,125,48,126,48,127,48,128,48,129,48,130,48,131,48,132,48,133,48,134,48,135,48,136,48,137,48,138,48,139,48,140,48,141,48,142,48,143,48,144,48,145,48,146,48,147,48,161,48,162,48,163,48,164,48,165,48,166,48,167,48,168,48,169,48,170,48,171,48,172,48,173,48,174,48,175,48,176,48,177,48,178,48,179,48,180,48,181,48,182,48,183,48,184,48,185,48,186,48,187,48,188,48,189,48,190,48,191,48,192,48,193,48,194,48,195,48,196,48,197,48,198,48,199,48,200,48,201,48,202,48,203,48,204,48,205,48,206,48,207,48,208,48,209,48,210,48,211,48,212,48,213,48,214,48,215,48,216,48,217,48,218,48,219,48,220,48,221,48,222,48,223,48,224,48,225,48,226,48,227,48,228,48,229,48,230,48,231,48,232,48,233,48,234,48,235,48,236,48,237,48,238,48,239,48,240,48,241,48,242,48,243,48,244,48,245,48,246,48,16,4,17,4,18,4,19,4,20,4,21,4,1,4,22,4,23,4,24,4,25,4,26,4,27,4,28,4,29,4,30,4,31,4,32,4,33,4,34,4,35,4,36,4,37,4,38,4,39,4,40,4,41,4,42,4,43,4,44,4,45,4,46,4,47,4,48,4,49,4,50,4,51,4,52,4,53,4,81,4,54,4,55,4,56,4,57,4,58,4,59,4,60,4,61,4,62,4,63,4,64,4,65,4,66,4,67,4,68,4,69,4,70,4,71,4,72,4,73,4,74,4,75,4,76,4,77,4,78,4,79,4,231,33,184,33,185,33,207,49,204,0,90,78,138,0,2,82,145,68,176,159,136,81,177,159,7,118,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,226,255,228,255,7,255,2,255,49,50,22,33,33,33,155,48,156,48,128,46,132,46,134,46,135,46,136,46,138,46,140,46,141,46,149,46,156,46,157,46,165,46,167,46,170,46,172,46,174,46,182,46,188,46,190,46,198,46,202,46,204,46,205,46,207,46,214,46,215,46,222,46,227,46,0,0,0,0,0,0,131,2,80,2,91,2,84,2,117,2,83,1,248,0,75,1,138,2,106,2,66,78,92,78,245,81,26,83,130,83,7,78,12,78,71,78,141,78,215,86,12,250,110,92,115,95,15,78,135,81,14,78,46,78,147,78,194,78,201,78,200,78,152,81,252,82,108,83,185,83,32,87,3,89,44,89,16,92,255,93,225,101,179,107,204,107,20,108,63,114,49,78,60,78,232,78,220,78,233,78,225,78,221,78,218,78,12,82,28,83,76,83,34,87,35,87,23,89,47,89,129,91,132,91,18,92,59,92,116,92,115,92,4,94,128,94,130,94,201,95,9,98,80,98,21,108,54,108,67,108,63,108,59,108,174,114,176,114,138,115,184,121,138,128,30,150,14,79,24,79,44,79,245,78,20,79,241,78,0,79,247,78,8,79,29,79,2,79,5,79,34,79,19,79,4,79,244,78,18,79,177,81,19,82,9,82,16,82,166,82,34,83,31,83,77,83,138,83,7,84,225,86,223,86,46,87,42,87,52,87,60,89,128,89,124,89,133,89,123,89,126,89,119,89,127,89,86,91,21,92,37,92,124,92,122,92,123,92,126,92,223,93,117,94,132,94,2,95,26,95,116,95,213,95,212,95,207,95,92,98,94,98,100,98,97,98,102,98,98,98,89,98,96,98,90,98,101,98,239,101,238,101,62,103,57,103,56,103,59,103,58,103,63,103,60,103,51,103,24,108,70,108,82,108,92,108,79,108,74,108,84,108,75,108,76,108,113,112,94,114,180,114,181,114,142,115,42,117,127,118,117,122,81,127,120,130,124,130,128,130,125,130,127,130,77,134,126,137,153,144,151,144,152,144,155,144,148,144,34,150,36,150,32,150,35,150,86,79,59,79,98,79,73,79,83,79,100,79,62,79,103,79,82,79,95,79,65,79,88,79,45,79,51,79,63,79,97,79,143,81,185,81,28,82,30,82,33,82,173,82,174,82,9,83,99,83,114,83,142,83,143,83,48,84,55,84,42,84,84,84,69,84,25,84,28,84,37,84,24,84,61,84,79,84,65,84,40,84,36,84,71,84,238,86,231,86,229,86,65,87,69,87,76,87,73,87,75,87,82,87,6,89,64,89,166,89,152,89,160,89,151,89,142,89,162,89,144,89,143,89,167,89,161,89,142,91,146,91,40,92,42,92,141,92,143,92,136,92,139,92,137,92,146,92,138,92,134,92,147,92,149,92,224,93,10,94,14,94,139,94,137,94,140,94,136,94,141,94,5,95,29,95,120,95,118,95,210,95,209,95,208,95,237,95,232,95,238,95,243,95,225,95,228,95,227,95,250,95,239,95,247,95,251,95,0,96,244,95,58,98,131,98,140,98,142,98,143,98,148,98,135,98,113,98,123,98,122,98,112,98,129,98,136,98,119,98,125,98,114,98,116,98,55,101,240,101,244,101,243,101,242,101,245,101,69,103,71,103,89,103,85,103,76,103,72,103,93,103,77,103,90,103,75,103,208,107,25,108,26,108,120,108,103,108,107,108,132,108,139,108,143,108,113,108,111,108,105,108,154,108,109,108,135,108,149,108,156,108,102,108,115,108,101,108,123,108,142,108,116,112,122,112,99,114,191,114,189,114,195,114,198,114,193,114,186,114,197,114,149,115,151,115,147,115,148,115,146,115,58,117,57,117,148,117,149,117,129,118,61,121,52,128,149,128,153,128,144,128,146,128,156,128,144,130,143,130,133,130,142,130,145,130,147,130,138,130,131,130,132,130,120,140,201,143,191,143,159,144,161,144,165,144,158,144,167,144,160,144,48,150,40,150,47,150,45,150,51,78,152,79,124,79,133,79,125,79,128,79,135,79,118,79,116,79,137,79,132,79,119,79,76,79,151,79,106,79,154,79,121,79,129,79,120,79,144,79,156,79,148,79,158,79,146,79,130,79,149,79,107,79,110,79,158,81,188,81,190,81,53,82,50,82,51,82,70,82,49,82,188,82,10,83,11,83,60,83,146,83,148,83,135,84,127,84,129,84,145,84,130,84,136,84,107,84,122,84,126,84,101,84,108,84,116,84,102,84,141,84,111,84,97,84,96,84,152,84,99,84,103,84,100,84,247,86,249,86,111,87,114,87,109,87,107,87,113,87,112,87,118,87,128,87,117,87,123,87,115,87,116,87,98,87,104,87,125,87,12,89,69,89,181,89,186,89,207,89,206,89,178,89,204,89,193,89,182,89,188,89,195,89,214,89,177,89,189,89,192,89,200,89,180,89,199,89,98,91,101,91,147,91,149,91,68,92,71,92,174,92,164,92,160,92,181,92,175,92,168,92,172,92,159,92,163,92,173,92,162,92,170,92,167,92,157,92,165,92,182,92,176,92,166,92,23,94,20,94,25,94,40,95,34,95,35,95,36,95,84,95,130,95,126,95,125,95,222,95,229,95,45,96,38,96,25,96,50,96,11,96,52,96,10,96,23,96,51,96,26,96,30,96,44,96,34,96,13,96,16,96,46,96,19,96,17,96,12,96,9,96,28,96,20,98,61,98,173,98,180,98,209,98,190,98,170,98,182,98,202,98,174,98,179,98,175,98,187,98,169,98,176,98,184,98,61,101,168,101,187,101,9,102,252,101,4,102,18,102,8,102,251,101,3,102,11,102,13,102,5,102,253,101,17,102,16,102,246,102,10,103,133,103,108,103,142,103,146,103,118,103,123,103,152,103,134,103,132,103,116,103,141,103,140,103,122,103,159,103,145,103,153,103,131,103,125,103,129,103,120,103,121,103,148,103,37,107,128,107,126,107,222,107,29,108,147,108,236,108,235,108,238,108,217,108,182,108,212,108,173,108,231,108,183,108,208,108,194,108,186,108,195,108,198,108,237,108,242,108,210,108,221,108,180,108,138,108,157,108,128,108,222,108,192,108,48,109,205,108,199,108,176,108,249,108,207,108,233,108,209,108,148,112,152,112,133,112,147,112,134,112,132,112,145,112,150,112,130,112,154,112,131,112,106,114,214,114,203,114,216,114,201,114,220,114,210,114,212,114,218,114,204,114,209,114,164,115,161,115,173,115,166,115,162,115,160,115,172,115,157,115,221,116,232,116,63,117,64,117,62,117,140,117,152,117,175,118,243,118,241,118,240,118,245,118,248,119,252,119,249,119,251,119,250,119,247,119,66,121,63,121,197,121,120,122,123,122,251,122,117,124,253,124,53,128,143,128,174,128,163,128,184,128,181,128,173,128,32,130,160,130,192,130,171,130,154,130,152,130,155,130,181,130,167,130,174,130,188,130,158,130,186,130,180,130,168,130,161,130,169,130,194,130,164,130,195,130,182,130,162,130,112,134,111,134,109,134,110,134,86,140,210,143,203,143,211,143,205,143,214,143,213,143,215,143,178,144,180,144,175,144,179,144,176,144,57,150,61,150,60,150,58,150,67,150,205,79,197,79,211,79,178,79,201,79,203,79,193,79,212,79,220,79,217,79,187,79,179,79,219,79,199,79,214,79,186,79,192,79,185,79,236,79,68,82,73,82,192,82,194,82,61,83,124,83,151,83,150,83,153,83,152,83,186,84,161,84,173,84,165,84,207,84,195,84,13,131,183,84,174,84,214,84,182,84,197,84,198,84,160,84,112,84,188,84,162,84,190,84,114,84,222,84,176,84,181,87,158,87,159,87,164,87,140,87,151,87,157,87,155,87,148,87,152,87,143,87,153,87,165,87,154,87,149,87,244,88,13,89,83,89,225,89,222,89,238,89,0,90,241,89,221,89,250,89,253,89,252,89,246,89,228,89,242,89,247,89,219,89,233,89,243,89,245,89,224,89,254,89,244,89,237,89,168,91,76,92,208,92,216,92,204,92,215,92,203,92,219,92,222,92,218,92,201,92,199,92,202,92,214,92,211,92,212,92,207,92,200,92,198,92,206,92,223,92,248,92,249,93,33,94,34,94,35,94,32,94,36,94,176,94,164,94,162,94,155,94,163,94,165,94,7,95,46,95,86,95,134,95,55,96,57,96,84,96,114,96,94,96,69,96,83,96,71,96,73,96,91,96,76,96,64,96,66,96,95,96,36,96,68,96,88,96,102,96,110,96,66,98,67,98,207,98,13,99,11,99,245,98,14,99,3,99,235,98,249,98,15,99,12,99,248,98,246,98,0,99,19,99,20,99,250,98,21,99,251,98,240,98,65,101,67,101,170,101,191,101,54,102,33,102,50,102,53,102,28,102,38,102,34,102,51,102,43,102,58,102,29,102,52,102,57,102,46,102,15,103,16,103,193,103,242,103,200,103,186,103,220,103,187,103,248,103,216,103,192,103,183,103,197,103,235,103,228,103,223,103,181,103,205,103,179,103,247,103,246,103,238,103,227,103,194,103,185,103,206,103,231,103,240,103,178,103,252,103,198,103,237,103,204,103,174,103,230,103,219,103,250,103,201,103,202,103,195,103,234,103,203,103,40,107,130,107,132,107,182,107,214,107,216,107,224,107,32,108,33,108,40,109,52,109,45,109,31,109,60,109,63,109,18,109,10,109,218,108,51,109,4,109,25,109,58,109,26,109,17,109,0,109,29,109,66,109,1,109,24,109,55,109,3,109,15,109,64,109,7,109,32,109,44,109,8,109,34,109,9,109,16,109,183,112,159,112,190,112,177,112,176,112,161,112,180,112,181,112,169,112,65,114,73,114,74,114,108,114,112,114,115,114,110,114,202,114,228,114,232,114,235,114,223,114,234,114,230,114,227,114,133,115,204,115,194,115,200,115,197,115,185,115,182,115,181,115,180,115,235,115,191,115,199,115,190,115,195,115,198,115,184,115,203,115,236,116,238,116,46,117,71,117,72,117,167,117,170,117,121,118,196,118,8,119,3,119,4,119,5,119,10,119,247,118,251,118,250,118,231,119,232,119,6,120,17,120,18,120,5,120,16,120,15,120,14,120,9,120,3,120,19,120,74,121,76,121,75,121,69,121,68,121,213,121,205,121,207,121,214,121,206,121,128,122,126,122,209,122,0,123,1,123,122,124,120,124,121,124,127,124,128,124,129,124,3,125,8,125,1,125,88,127,145,127,141,127,190,127,7,128,14,128,15,128,20,128,55,128,216,128,199,128,224,128,209,128,200,128,194,128,208,128,197,128,227,128,217,128,220,128,202,128,213,128,201,128,207,128,215,128,230,128,205,128,255,129,33,130,148,130,217,130,254,130,249,130,7,131,232,130,0,131,213,130,58,131,235,130,214,130,244,130,236,130,225,130,242,130,245,130,12,131,251,130,246,130,240,130,234,130,228,130,224,130,250,130,243,130,237,130,119,134,116,134,124,134,115,134,65,136,78,136,103,136,106,136,105,136,211,137,4,138,7,138,114,141,227,143,225,143,238,143,224,143,241,144,189,144,191,144,213,144,197,144,190,144,199,144,203,144,200,144,212,145,211,145,84,150,79,150,81,150,83,150,74,150,78,150,30,80,5,80,7,80,19,80,34,80,48,80,27,80,245,79,244,79,51,80,55,80,44,80,246,79,247,79,23,80,28,80,32,80,39,80,53,80,47,80,49,80,14,80,90,81,148,81,147,81,202,81,196,81,197,81,200,81,206,81,97,82,90,82,82,82,94,82,95,82,85,82,98,82,205,82,14,83,158,83,38,85,226,84,23,85,18,85,231,84,243,84,228,84,26,85,255,84,4,85,8,85,235,84,17,85,5,85,241,84,10,85,251,84,247,84,248,84,224,84,14,85,3,85,11,85,1,87,2,87,204,87,50,88,213,87,210,87,186,87,198,87,189,87,188,87,184,87,182,87,191,87,199,87,208,87,185,87,193,87,14,89,74,89,25,90,22,90,45,90,46,90,21,90,15,90,23,90,10,90,30,90,51,90,108,91,167,91,173,91,172,91,3,92,86,92,84,92,236,92,255,92,238,92,241,92,247,92,0,93,249,92,41,94,40,94,168,94,174,94,170,94,172,94,51,95,48,95,103,95,93,96,90,96,103,96,65,96,162,96,136,96,128,96,146,96,129,96,157,96,131,96,149,96,155,96,151,96,135,96,156,96,142,96,25,98,70,98,242,98,16,99,86,99,44,99,68,99,69,99,54,99,67,99,228,99,57,99,75,99,74,99,60,99,41,99,65,99,52,99,88,99,84,99,89,99,45,99,71,99,51,99,90,99,81,99,56,99,87,99,64,99,72,99,74,101,70,101,198,101,195,101,196,101,194,101,74,102,95,102,71,102,81,102,18,103,19,103,31,104,26,104,73,104,50,104,51,104,59,104,75,104,79,104,22,104,49,104,28,104,53,104,43,104,45,104,47,104,78,104,68,104,52,104,29,104,18,104,20,104,38,104,40,104,46,104,77,104,58,104,37,104,32,104,44,107,47,107,45,107,49,107,52,107,109,107,130,128,136,107,230,107,228,107,232,107,227,107,226,107,231,107,37,108,122,109,99,109,100,109,118,109,13,109,97,109,146,109,88,109,98,109,109,109,111,109,145,109,141,109,239,109,127,109,134,109,94,109,103,109,96,109,151,109,112,109,124,109,95,109,130,109,152,109,47,109,104,109,139,109,126,109,128,109,132,109,22,109,131,109,123,109,125,109,117,109,144,109,220,112,211,112,209,112,221,112,203,112,57,127,226,112,215,112,210,112,222,112,224,112,212,112,205,112,197,112,198,112,199,112,218,112,206,112,225,112,66,114,120,114,119,114,118,114,0,115,250,114,244,114,254,114,246,114,243,114,251,114,1,115,211,115,217,115,229,115,214,115,188,115,231,115,227,115,233,115,220,115,210,115,219,115,212,115,221,115,218,115,215,115,216,115,232,115,222,116,223,116,244,116,245,116,33,117,91,117,95,117,176,117,193,117,187,117,196,117,192,117,191,117,182,117,186,117,138,118,201,118,29,119,27,119,16,119,19,119,18,119,35,119,17,119,21,119,25,119,26,119,34,119,39,119,35,120,44,120,34,120,53,120,47,120,40,120,46,120,43,120,33,120,41,120,51,120,42,120,49,120,84,121,91,121,79,121,92,121,83,121,82,121,81,121,235,121,236,121,224,121,238,121,237,121,234,121,220,121,222,121,221,121,134,122,137,122,133,122,139,122,140,122,138,122,135,122,216,122,16,123,4,123,19,123,5,123,15,123,8,123,10,123,14,123,9,123,18,123,132,124,145,124,138,124,140,124,136,124,141,124,133,124,30,125,29,125,17,125,14,125,24,125,22,125,19,125,31,125,18,125,15,125,12,125,92,127,97,127,94,127,96,127,93,127,91,127,150,127,146,127,195,127,194,127,192,127,22,128,62,128,57,128,250,128,242,128,249,128,245,128,1,129,251,128,0,129,1,130,47,130,37,130,51,131,45,131,68,131,25,131,81,131,37,131,86,131,63,131,65,131,38,131,28,131,34,131,66,131,78,131,27,131,42,131,8,131,60,131,77,131,22,131,36,131,32,131,55,131,47,131,41,131,71,131,69,131,76,131,83,131,30,131,44,131,75,131,39,131,72,131,83,134,82,134,162,134,168,134,150,134,141,134,145,134,158,134,135,134,151,134,134,134,139,134,154,134,133,134,165,134,153,134,161,134,167,134,149,134,152,134,142,134,157,134,144,134,148,134,67,136,68,136,109,136,117,136,118,136,114,136,128,136,113,136,127,136,111,136,131,136,126,136,116,136,124,136,18,138,71,140,87,140,123,140,164,140,163,140,118,141,120,141,181,141,183,141,182,141,209,142,211,142,254,143,245,143,2,144,255,143,251,143,4,144,252,143,246,143,214,144,224,144,217,144,218,144,227,144,223,144,229,144,216,144,219,144,215,144,220,144,228,144,80,145,78,145,79,145,213,145,226,145,218,145,92,150,95,150,188,150,227,152,223,154,47,155,127,78,112,80,106,80,97,80,94,80,96,80,83,80,75,80,93,80,114,80,72,80,77,80,65,80,91,80,74,80,98,80,21,80,69,80,95,80,105,80,107,80,99,80,100,80,70,80,64,80,110,80,115,80,87,80,81,80,208,81,107,82,109,82,108,82,110,82,214,82,211,82,45,83,156,83,117,85,118,85,60,85,77,85,80,85,52,85,42,85,81,85,98,85,54,85,53,85,48,85,82,85,69,85,12,85,50,85,101,85,78,85,57,85,72,85,45,85,59,85,64,85,75,85,10,87,7,87,251,87,20,88,226,87,246,87,220,87,244,87,0,88,237,87,253,87,8,88,248,87,11,88,243,87,207,87,7,88,238,87,227,87,242,87,229,87,236,87,225,87,14,88,252,87,16,88,231,87,1,88,12,88,241,87,233,87,240,87,13,88,4,88,92,89,96,90,88,90,85,90,103,90,94,90,56,90,53,90,109,90,80,90,95,90,101,90,108,90,83,90,100,90,87,90,67,90,93,90,82,90,68,90,91,90,72,90,142,90,62,90,77,90,57,90,76,90,112,90,105,90,71,90,81,90,86,90,66,90,92,90,114,91,110,91,193,91,192,91,89,92,30,93,11,93,29,93,26,93,32,93,12,93,40,93,13,93,38,93,37,93,15,93,48,93,18,93,35,93,31,93,46,93,62,94,52,94,177,94,180,94,185,94,178,94,179,94,54,95,56,95,155,95,150,95,159,95,138,96,144,96,134,96,190,96,176,96,186,96,211,96,212,96,207,96,228,96,217,96,221,96,200,96,177,96,219,96,183,96,202,96,191,96,195,96,205,96,192,96,50,99,101,99,138,99,130,99,125,99,189,99,158,99,173,99,157,99,151,99,171,99,142,99,111,99,135,99,144,99,110,99,175,99,117,99,156,99,109,99,174,99,124,99,164,99,59,99,159,99,120,99,133,99,129,99,145,99,141,99,112,99,83,101,205,101,101,102,97,102,91,102,89,102,92,102,98,102,24,103,121,104,135,104,144,104,156,104,109,104,110,104,174,104,171,104,86,105,111,104,163,104,172,104,169,104,117,104,116,104,178,104,143,104,119,104,146,104,124,104,107,104,114,104,170,104,128,104,113,104,126,104,155,104,150,104,139,104,160,104,137,104,164,104,120,104,123,104,145,104,140,104,138,104,125,104,54,107,51,107,55,107,56,107,145,107,143,107,141,107,142,107,140,107,42,108,192,109,171,109,180,109,179,109,116,110,172,109,233,109,226,109,183,109,246,109,212,109,0,110,200,109,224,109,223,109,214,109,190,109,229,109,220,109,221,109,219,109,244,109,202,109,189,109,237,109,240,109,186,109,213,109,194,109,207,109,201,109,208,109,242,109,211,109,253,109,215,109,205,109,227,109,187,109,250,112,13,113,247,112,23,113,244,112,12,113,240,112,4,113,243,112,16,113,252,112,255,112,6,113,19,113,0,113,248,112,246,112,11,113,2,113,14,113,126,114,123,114,124,114,127,114,29,115,23,115,7,115,17,115,24,115,10,115,8,115,255,114,15,115,30,115,136,115,246,115,248,115,245,115,4,116,1,116,253,115,7,116,0,116,250,115,252,115,255,115,12,116,11,116,244,115,8,116,100,117,99,117,206,117,210,117,207,117,203,117,204,117,209,117,208,117,143,118,137,118,211,118,57,119,47,119,45,119,49,119,50,119,52,119,51,119,61,119,37,119,59,119,53,119,72,120,82,120,73,120,77,120,74,120,76,120,38,120,69,120,80,120,100,121,103,121,105,121,106,121,99,121,107,121,97,121,187,121,250,121,248,121,246,121,247,121,143,122,148,122,144,122,53,123,71,123,52,123,37,123,48,123,34,123,36,123,51,123,24,123,42,123,29,123,49,123,43,123,45,123,47,123,50,123,56,123,26,123,35,123,148,124,152,124,150,124,163,124,53,125,61,125,56,125,54,125,58,125,69,125,44,125,41,125,65,125,71,125,62,125,63,125,74,125,59,125,40,125,99,127,149,127,156,127,157,127,155,127,202,127,203,127,205,127,208,127,209,127,199,127,207,127,201,127,31,128,30,128,27,128,71,128,67,128,72,128,24,129,37,129,25,129,27,129,45,129,31,129,44,129,30,129,33,129,21,129,39,129,29,129,34,129,17,130,56,130,51,130,58,130,52,130,50,130,116,130,144,131,163,131,168,131,141,131,122,131,115,131,164,131,116,131,143,131,129,131,149,131,153,131,117,131,148,131,169,131,125,131,131,131,140,131,157,131,155,131,170,131,139,131,126,131,165,131,175,131,136,131,151,131,176,131,127,131,166,131,135,131,174,131,118,131,154,131,89,134,86,134,191,134,183,134,194,134,193,134,197,134,186,134,176,134,200,134,185,134,179,134,184,134,204,134,180,134,187,134,188,134,195,134,189,134,190,134,82,136,137,136,149,136,168,136,162,136,170,136,154,136,145,136,161,136,159,136,152,136,167,136,153,136,155,136,151,136,164,136,172,136,140,136,147,136,142,136,130,137,214,137,217,137,213,137,48,138,39,138,44,138,30,138,57,140,59,140,92,140,93,140,125,140,165,140,125,141,123,141,121,141,188,141,194,141,185,141,191,141,193,141,216,142,222,142,221,142,220,142,215,142,224,142,225,142,36,144,11,144,17,144,28,144,12,144,33,144,239,144,234,144,240,144,244,144,242,144,243,144,212,144,235,144,236,144,233,144,86,145,88,145,90,145,83,145,85,145,236,145,244,145,241,145,243,145,248,145,228,145,249,145,234,145,235,145,247,145,232,145,238,145,122,149,134,149,136,149,124,150,109,150,107,150,113,150,111,150,191,150,106,151,4,152,229,152,151,153,155,80,149,80,148,80,158,80,139,80,163,80,131,80,140,80,142,80,157,80,104,80,156,80,146,80,130,80,135,80,95,81,212,81,18,83,17,83,164,83,167,83,145,85,168,85,165,85,173,85,119,85,69,86,162,85,147,85,136,85,143,85,181,85,129,85,163,85,146,85,164,85,125,85,140,85,166,85,127,85,149,85,161,85,142,85,12,87,41,88,55,88,25,88,30,88,39,88,35,88,40,88,245,87,72,88,37,88,28,88,27,88,51,88,63,88,54,88,46,88,57,88,56,88,45,88,44,88,59,88,97,89,175,90,148,90,159,90,122,90,162,90,158,90,120,90,166,90,124,90,165,90,172,90,149,90,174,90,55,90,132,90,138,90,151,90,131,90,139,90,169,90,123,90,125,90,140,90,156,90,143,90,147,90,157,90,234,91,205,91,203,91,212,91,209,91,202,91,206,91,12,92,48,92,55,93,67,93,107,93,65,93,75,93,63,93,53,93,81,93,78,93,85,93,51,93,58,93,82,93,61,93,49,93,89,93,66,93,57,93,73,93,56,93,60,93,50,93,54,93,64,93,69,93,68,94,65,94,88,95,166,95,165,95,171,95,201,96,185,96,204,96,226,96,206,96,196,96,20,97,242,96,10,97,22,97,5,97,245,96,19,97,248,96,252,96,254,96,193,96,3,97,24,97,29,97,16,97,255,96,4,97,11,97,74,98,148,99,177,99,176,99,206,99,229,99,232,99,239,99,195,99,157,100,243,99,202,99,224,99,246,99,213,99,242,99,245,99,97,100,223,99,190,99,221,99,220,99,196,99,216,99,211,99,194,99,199,99,204,99,203,99,200,99,240,99,215,99,217,99,50,101,103,101,106,101,100,101,92,101,104,101,101,101,140,101,157,101,158,101,174,101,208,101,210,101,124,102,108,102,123,102,128,102,113,102,121,102,106,102,114,102,1,103,12,105,211,104,4,105,220,104,42,105,236,104,234,104,241,104,15,105,214,104,247,104,235,104,228,104,246,104,19,105,16,105,243,104,225,104,7,105,204,104,8,105,112,105,180,104,17,105,239,104,198,104,20,105,248,104,208,104,253,104,252,104,232,104,11,105,10,105,23,105,206,104,200,104,221,104,222,104,230,104,244,104,209,104,6,105,212,104,233,104,21,105,37,105,199,104,57,107,59,107,63,107,60,107,148,107,151,107,153,107,149,107,189,107,240,107,242,107,243,107,48,108,252,109,70,110,71,110,31,110,73,110,136,110,60,110,61,110,69,110,98,110,43,110,63,110,65,110,93,110,115,110,28,110,51,110,75,110,64,110,81,110,59,110,3,110,46,110,94,110,104,110,92,110,97,110,49,110,40,110,96,110,113,110,107,110,57,110,34,110,48,110,83,110,101,110,39,110,120,110,100,110,119,110,85,110,121,110,82,110,102,110,53,110,54,110,90,110,32,113,30,113,47,113,251,112,46,113,49,113,35,113,37,113,34,113,50,113,31,113,40,113,58,113,27,113,75,114,90,114,136,114,137,114,134,114,133,114,139,114,18,115,11,115,48,115,34,115,49,115,51,115,39,115,50,115,45,115,38,115,35,115,53,115,12,115,46,116,44,116,48,116,43,116,22,116,26,116,33,116,45,116,49,116,36,116,35,116,29,116,41,116,32,116,50,116,251,116,47,117,111,117,108,117,231,117,218,117,225,117,230,117,221,117,223,117,228,117,215,117,149,118,146,118,218,118,70,119,71,119,68,119,77,119,69,119,74,119,78,119,75,119,76,119,222,119,236,119,96,120,100,120,101,120,92,120,109,120,113,120,106,120,110,120,112,120,105,120,104,120,94,120,98,120,116,121,115,121,114,121,112,121,2,122,10,122,3,122,12,122,4,122,153,122,230,122,228,122,74,123,59,123,68,123,72,123,76,123,78,123,64,123,88,123,69,123,162,124,158,124,168,124,161,124,88,125,111,125,99,125,83,125,86,125,103,125,106,125,79,125,109,125,92,125,107,125,82,125,84,125,105,125,81,125,95,125,78,125,62,127,63,127,101,127,102,127,162,127,160,127,161,127,215,127,81,128,79,128,80,128,254,128,212,128,67,129,74,129,82,129,79,129,71,129,61,129,77,129,58,129,230,129,238,129,247,129,248,129,249,129,4,130,60,130,61,130,63,130,117,130,59,131,207,131,249,131,35,132,192,131,232,131,18,132,231,131,228,131,252,131,246,131,16,132,198,131,200,131,235,131,227,131,191,131,1,132,221,131,229,131,216,131,255,131,225,131,203,131,206,131,214,131,245,131,201,131,9,132,15,132,222,131,17,132,6,132,194,131,243,131,213,131,250,131,199,131,209,131,234,131,19,132,195,131,236,131,238,131,196,131,251,131,215,131,226,131,27,132,219,131,254,131,216,134,226,134,230,134,211,134,227,134,218,134,234,134,221,134,235,134,220,134,236,134,233,134,215,134,232,134,209,134,72,136,86,136,85,136,186,136,215,136,185,136,184,136,192,136,190,136,182,136,188,136,183,136,189,136,178,136,1,137,201,136,149,137,152,137,151,137,221,137,218,137,219,137,78,138,77,138,57,138,89,138,64,138,87,138,88,138,68,138,69,138,82,138,72,138,81,138,74,138,76,138,79,138,95,140,129,140,128,140,186,140,190,140,176,140,185,140,181,140,132,141,128,141,137,141,216,141,211,141,205,141,199,141,214,141,220,141,207,141,213,141,217,141,200,141,215,141,197,141,239,142,247,142,250,142,249,142,230,142,238,142,229,142,245,142,231,142,232,142,246,142,235,142,241,142,236,142,244,142,233,142,45,144,52,144,47,144,6,145,44,145,4,145,255,144,252,144,8,145,249,144,251,144,1,145,0,145,7,145,5,145,3,145,97,145,100,145,95,145,98,145,96,145,1,146,10,146,37,146,3,146,26,146,38,146,15,146,12,146,0,146,18,146,255,145,253,145,6,146,4,146,39,146,2,146,28,146,36,146,25,146,23,146,5,146,22,146,123,149,141,149,140,149,144,149,135,150,126,150,136,150,137,150,131,150,128,150,194,150,200,150,195,150,241,150,240,150,108,151,112,151,110,151,7,152,169,152,235,152,230,156,249,158,131,78,132,78,182,78,189,80,191,80,198,80,174,80,196,80,202,80,180,80,200,80,194,80,176,80,193,80,186,80,177,80,203,80,201,80,182,80,184,80,215,81,122,82,120,82,123,82,124,82,195,85,219,85,204,85,208,85,203,85,202,85,221,85,192,85,212,85,196,85,233,85,191,85,210,85,141,85,207,85,213,85,226,85,214,85,200,85,242,85,205,85,217,85,194,85,20,87,83,88,104,88,100,88,79,88,77,88,73,88,111,88,85,88,78,88,93,88,89,88,101,88,91,88,61,88,99,88,113,88,252,88,199,90,196,90,203,90,186,90,184,90,177,90,181,90,176,90,191,90,200,90,187,90,198,90,183,90,192,90,202,90,180,90,182,90,205,90,185,90,144,90,214,91,216,91,217,91,31,92,51,92,113,93,99,93,74,93,101,93,114,93,108,93,94,93,104,93,103,93,98,93,240,93,79,94,78,94,74,94,77,94,75,94,197,94,204,94,198,94,203,94,199,94,64,95,175,95,173,95,247,96,73,97,74,97,43,97,69,97,54,97,50,97,46,97,70,97,47,97,79,97,41,97,64,97,32,98,104,145,35,98,37,98,36,98,197,99,241,99,235,99,16,100,18,100,9,100,32,100,36,100,51,100,67,100,31,100,21,100,24,100,57,100,55,100,34,100,35,100,12,100,38,100,48,100,40,100,65,100,53,100,47,100,10,100,26,100,64,100,37,100,39,100,11,100,231,99,27,100,46,100,33,100,14,100,111,101,146,101,211,101,134,102,140,102,149,102,144,102,139,102,138,102,153,102,148,102,120,102,32,103,102,105,95,105,56,105,78,105,98,105,113,105,63,105,69,105,106,105,57,105,66,105,87,105,89,105,122,105,72,105,73,105,53,105,108,105,51,105,61,105,101,105,240,104,120,105,52,105,105,105,64,105,111,105,68,105,118,105,88,105,65,105,116,105,76,105,59,105,75,105,55,105,92,105,79,105,81,105,50,105,82,105,47,105,123,105,60,105,70,107,69,107,67,107,66,107,72,107,65,107,155,107,13,250,251,107,252,107,249,107,247,107,248,107,155,110,214,110,200,110,143,110,192,110,159,110,147,110,148,110,160,110,177,110,185,110,198,110,210,110,189,110,193,110,158,110,201,110,183,110,176,110,205,110,166,110,207,110,178,110,190,110,195,110,220,110,216,110,153,110,146,110,142,110,141,110,164,110,161,110,191,110,179,110,208,110,202,110,151,110,174,110,163,110,71,113,84,113,82,113,99,113,96,113,65,113,93,113,98,113,114,113,120,113,106,113,97,113,66,113,88,113,67,113,75,113,112,113,95,113,80,113,83,113,68,113,77,113,90,113,79,114,141,114,140,114,145,114,144,114,142,114,60,115,66,115,59,115,58,115,64,115,74,115,73,115,68,116,74,116,75,116,82,116,81,116,87,116,64,116,79,116,80,116,78,116,66,116,70,116,77,116,84,116,225,116,255,116,254,116,253,116,29,117,121,117,119,117,131,105,239,117,15,118,3,118,247,117,254,117,252,117,249,117,248,117,16,118,251,117,246,117,237,117,245,117,253,117,153,118,181,118,221,118,85,119,95,119,96,119,82,119,86,119,90,119,105,119,103,119,84,119,89,119,109,119,224,119,135,120,154,120,148,120,143,120,132,120,149,120,133,120,134,120,161,120,131,120,121,120,153,120,128,120,150,120,123,120,124,121,130,121,125,121,121,121,17,122,24,122,25,122,18,122,23,122,21,122,34,122,19,122,27,122,16,122,163,122,162,122,158,122,235,122,102,123,100,123,109,123,116,123,105,123,114,123,101,123,115,123,113,123,112,123,97,123,120,123,118,123,99,123,178,124,180,124,175,124,136,125,134,125,128,125,141,125,127,125,133,125,122,125,142,125,123,125,131,125,124,125,140,125,148,125,132,125,125,125,146,125,109,127,107,127,103,127,104,127,108,127,166,127,165,127,167,127,219,127,220,127,33,128,100,129,96,129,119,129,92,129,105,129,91,129,98,129,114,129,33,103,94,129,118,129,103,129,111,129,68,129,97,129,29,130,73,130,68,130,64,130,66,130,69,130,241,132,63,132,86,132,118,132,121,132,143,132,141,132,101,132,81,132,64,132,134,132,103,132,48,132,77,132,125,132,90,132,89,132,116,132,115,132,93,132,7,133,94,132,55,132,58,132,52,132,122,132,67,132,120,132,50,132,69,132,41,132,217,131,75,132,47,132,66,132,45,132,95,132,112,132,57,132,78,132,76,132,82,132,111,132,197,132,142,132,59,132,71,132,54,132,51,132,104,132,126,132,68,132,43,132,96,132,84,132,110,132,80,132,11,135,4,135,247,134,12,135,250,134,214,134,245,134,77,135,248,134,14,135,9,135,1,135,246,134,13,135,5,135,214,136,203,136,205,136,206,136,222,136,219,136,218,136,204,136,208,136,133,137,155,137,223,137,229,137,228,137,225,137,224,137,226,137,220,137,230,137,118,138,134,138,127,138,97,138,63,138,119,138,130,138,132,138,117,138,131,138,129,138,116,138,122,138,60,140,75,140,74,140,101,140,100,140,102,140,134,140,132,140,133,140,204,140,104,141,105,141,145,141,140,141,142,141,143,141,141,141,147,141,148,141,144,141,146,141,240,141,224,141,236,141,241,141,238,141,208,141,233,141,227,141,226,141,231,141,242,141,235,141,244,141,6,143,255,142,1,143,0,143,5,143,7,143,8,143,2,143,11,143,82,144,63,144,68,144,73,144,61,144,16,145,13,145,15,145,17,145,22,145,20,145,11,145,14,145,110,145,111,145,72,146,82,146,48,146,58,146,102,146,51,146,101,146,94,146,131,146,46,146,74,146,70,146,109,146,108,146,79,146,96,146,103,146,111,146,54,146,97,146,112,146,49,146,84,146,99,146,80,146,114,146,78,146,83,146,76,146,86,146,50,146,159,149,156,149,158,149,155,149,146,150,147,150,145,150,151,150,206,150,250,150,253,150,248,150,245,150,115,151,119,151,120,151,114,151,15,152,13,152,14,152,172,152,246,152,249,152,175,153,178,153,176,153,181,153,173,154,171,154,91,155,234,156,237,156,231,156,128,158,253,158,230,80,212,80,215,80,232,80,243,80,219,80,234,80,221,80,228,80,211,80,236,80,240,80,239,80,227,80,224,80,216,81,128,82,129,82,233,82,235,82,48,83,172,83,39,86,21,86,12,86,18,86,252,85,15,86,28,86,1,86,19,86,2,86,250,85,29,86,4,86,255,85,249,85,137,88,124,88,144,88,152,88,134,88,129,88,127,88,116,88,139,88,122,88,135,88,145,88,142,88,118,88,130,88,136,88,123,88,148,88,143,88,254,88,107,89,220,90,238,90,229,90,213,90,234,90,218,90,237,90,235,90,243,90,226,90,224,90,219,90,236,90,222,90,221,90,217,90,232,90,223,90,119,91,224,91,227,91,99,92,130,93,128,93,125,93,134,93,122,93,129,93,119,93,138,93,137,93,136,93,126,93,124,93,141,93,121,93,127,93,88,94,89,94,83,94,216,94,209,94,215,94,206,94,220,94,213,94,217,94,210,94,212,94,68,95,67,95,111,95,182,95,44,97,40,97,65,97,94,97,113,97,115,97,82,97,83,97,114,97,108,97,128,97,116,97,84,97,122,97,91,97,101,97,59,97,106,97,97,97,86,97,41,98,39,98,43,98,43,100,77,100,91,100,93,100,116,100,118,100,114,100,115,100,125,100,117,100,102,100,166,100,78,100,130,100,94,100,92,100,75,100,83,100,96,100,80,100,127,100,63,100,108,100,107,100,89,100,101,100,119,100,115,101,160,101,161,102,160,102,159,102,5,103,4,103,34,103,177,105,182,105,201,105,160,105,206,105,150,105,176,105,172,105,188,105,145,105,153,105,142,105,167,105,141,105,169,105,190,105,175,105,191,105,196,105,189,105,164,105,212,105,185,105,202,105,154,105,207,105,179,105,147,105,170,105,161,105,158,105,217,105,151,105,144,105,194,105,181,105,165,105,198,105,74,107,77,107,75,107,158,107,159,107,160,107,195,107,196,107,254,107,206,110,245,110,241,110,3,111,37,111,248,110,55,111,251,110,46,111,9,111,78,111,25,111,26,111,39,111,24,111,59,111,18,111,237,110,10,111,54,111,115,111,249,110,238,110,45,111,64,111,48,111,60,111,53,111,235,110,7,111,14,111,67,111,5,111,253,110,246,110,57,111,28,111,252,110,58,111,31,111,13,111,30,111,8,111,33,111,135,113,144,113,137,113,128,113,133,113,130,113,143,113,123,113,134,113,129,113,151,113,68,114,83,114,151,114,149,114,147,114,67,115,77,115,81,115,76,115,98,116,115,116,113,116,117,116,114,116,103,116,110,116,0,117,2,117,3,117,125,117,144,117,22,118,8,118,12,118,21,118,17,118,10,118,20,118,184,118,129,119,124,119,133,119,130,119,110,119,128,119,111,119,126,119,131,119,178,120,170,120,180,120,173,120,168,120,126,120,171,120,158,120,165,120,160,120,172,120,162,120,164,120,152,121,138,121,139,121,150,121,149,121,148,121,147,121,151,121,136,121,146,121,144,121,43,122,74,122,48,122,47,122,40,122,38,122,168,122,171,122,172,122,238,122,136,123,156,123,138,123,145,123,144,123,150,123,141,123,140,123,155,123,142,123,133,123,152,123,132,82,153,123,164,123,130,123,187,124,191,124,188,124,186,124,167,125,183,125,194,125,163,125,170,125,193,125,192,125,197,125,157,125,206,125,196,125,198,125,203,125,204,125,175,125,185,125,150,125,188,125,159,125,166,125,174,125,169,125,161,125,201,125,115,127,226,127,227,127,229,127,222,127,36,128,93,128,92,128,137,129,134,129,131,129,135,129,141,129,140,129,139,129,21,130,151,132,164,132,161,132,159,132,186,132,206,132,194,132,172,132,174,132,171,132,185,132,180,132,193,132,205,132,170,132,154,132,177,132,208,132,157,132,167,132,187,132,162,132,148,132,199,132,204,132,155,132,169,132,175,132,168,132,214,132,152,132,182,132,207,132,160,132,215,132,212,132,210,132,219,132,176,132,145,132,97,134,51,135,35,135,40,135,107,135,64,135],"i8",ALLOC_NONE,Runtime.GLOBAL_BASE+292068),
	allocate([46,135,30,135,33,135,25,135,27,135,67,135,44,135,65,135,62,135,70,135,32,135,50,135,42,135,45,135,60,135,18,135,58,135,49,135,53,135,66,135,38,135,39,135,56,135,36,135,26,135,48,135,17,135,247,136,231,136,241,136,242,136,250,136,254,136,238,136,252,136,246,136,251,136,240,136,236,136,235,136,157,137,161,137,159,137,158,137,233,137,235,137,232,137,171,138,153,138,139,138,146,138,143,138,150,138,61,140,104,140,105,140,213,140,207,140,215,140,150,141,9,142,2,142,255,141,13,142,253,141,10,142,3,142,7,142,6,142,5,142,254,141,0,142,4,142,16,143,17,143,14,143,13,143,35,145,28,145,32,145,34,145,31,145,29,145,26,145,36,145,33,145,27,145,122,145,114,145,121,145,115,145,165,146,164,146,118,146,155,146,122,146,160,146,148,146,170,146,141,146,166,146,154,146,171,146,121,146,151,146,127,146,163,146,238,146,142,146,130,146,149,146,162,146,125,146,136,146,161,146,138,146,134,146,140,146,153,146,167,146,126,146,135,146,169,146,157,146,139,146,45,146,158,150,161,150,255,150,88,151,125,151,122,151,126,151,131,151,128,151,130,151,123,151,132,151,129,151,127,151,206,151,205,151,22,152,173,152,174,152,2,153,0,153,7,153,157,153,156,153,195,153,185,153,187,153,186,153,194,153,189,153,199,153,177,154,227,154,231,154,62,155,63,155,96,155,97,155,95,155,241,156,242,156,245,156,167,158,255,80,3,81,48,81,248,80,6,81,7,81,246,80,254,80,11,81,12,81,253,80,10,81,139,82,140,82,241,82,239,82,72,86,66,86,76,86,53,86,65,86,74,86,73,86,70,86,88,86,90,86,64,86,51,86,61,86,44,86,62,86,56,86,42,86,58,86,26,87,171,88,157,88,177,88,160,88,163,88,175,88,172,88,165,88,161,88,255,88,255,90,244,90,253,90,247,90,246,90,3,91,248,90,2,91,249,90,1,91,7,91,5,91,15,91,103,92,153,93,151,93,159,93,146,93,162,93,147,93,149,93,160,93,156,93,161,93,154,93,158,93,105,94,93,94,96,94,92,94,243,125,219,94,222,94,225,94,73,95,178,95,139,97,131,97,121,97,177,97,176,97,162,97,137,97,155,97,147,97,175,97,173,97,159,97,146,97,170,97,161,97,141,97,102,97,179,97,45,98,110,100,112,100,150,100,160,100,133,100,151,100,156,100,143,100,139,100,138,100,140,100,163,100,159,100,104,100,177,100,152,100,118,101,122,101,121,101,123,101,178,101,179,101,181,102,176,102,169,102,178,102,183,102,170,102,175,102,0,106,6,106,23,106,229,105,248,105,21,106,241,105,228,105,32,106,255,105,236,105,226,105,27,106,29,106,254,105,39,106,242,105,238,105,20,106,247,105,231,105,64,106,8,106,230,105,251,105,13,106,252,105,235,105,9,106,4,106,24,106,37,106,15,106,246,105,38,106,7,106,244,105,22,106,81,107,165,107,163,107,162,107,166,107,1,108,0,108,255,107,2,108,65,111,38,111,126,111,135,111,198,111,146,111,141,111,137,111,140,111,98,111,79,111,133,111,90,111,150,111,118,111,108,111,130,111,85,111,114,111,82,111,80,111,87,111,148,111,147,111,93,111,0,111,97,111,107,111,125,111,103,111,144,111,83,111,139,111,105,111,127,111,149,111,99,111,119,111,106,111,123,111,178,113,175,113,155,113,176,113,160,113,154,113,169,113,181,113,157,113,165,113,158,113,164,113,161,113,170,113,156,113,167,113,179,113,152,114,154,114,88,115,82,115,94,115,95,115,96,115,93,115,91,115,97,115,90,115,89,115,98,115,135,116,137,116,138,116,134,116,129,116,125,116,133,116,136,116,124,116,121,116,8,117,7,117,126,117,37,118,30,118,25,118,29,118,28,118,35,118,26,118,40,118,27,118,156,118,157,118,158,118,155,118,141,119,143,119,137,119,136,119,205,120,187,120,207,120,204,120,209,120,206,120,212,120,200,120,195,120,196,120,201,120,154,121,161,121,160,121,156,121,162,121,155,121,118,107,57,122,178,122,180,122,179,122,183,123,203,123,190,123,172,123,206,123,175,123,185,123,202,123,181,123,197,124,200,124,204,124,203,124,247,125,219,125,234,125,231,125,215,125,225,125,3,126,250,125,230,125,246,125,241,125,240,125,238,125,223,125,118,127,172,127,176,127,173,127,237,127,235,127,234,127,236,127,230,127,232,127,100,128,103,128,163,129,159,129,158,129,149,129,162,129,153,129,151,129,22,130,79,130,83,130,82,130,80,130,78,130,81,130,36,133,59,133,15,133,0,133,41,133,14,133,9,133,13,133,31,133,10,133,39,133,28,133,251,132,43,133,250,132,8,133,12,133,244,132,42,133,242,132,21,133,247,132,235,132,243,132,252,132,18,133,234,132,233,132,22,133,254,132,40,133,29,133,46,133,2,133,253,132,30,133,246,132,49,133,38,133,231,132,232,132,240,132,239,132,249,132,24,133,32,133,48,133,11,133,25,133,47,133,98,134,86,135,99,135,100,135,119,135,225,135,115,135,88,135,84,135,91,135,82,135,97,135,90,135,81,135,94,135,109,135,106,135,80,135,78,135,95,135,93,135,111,135,108,135,122,135,110,135,92,135,101,135,79,135,123,135,117,135,98,135,103,135,105,135,90,136,5,137,12,137,20,137,11,137,23,137,24,137,25,137,6,137,22,137,17,137,14,137,9,137,162,137,164,137,163,137,237,137,240,137,236,137,207,138,198,138,184,138,211,138,209,138,212,138,213,138,187,138,215,138,190,138,192,138,197,138,216,138,195,138,186,138,189,138,217,138,62,140,77,140,143,140,229,140,223,140,217,140,232,140,218,140,221,140,231,140,160,141,156,141,161,141,155,141,32,142,35,142,37,142,36,142,46,142,21,142,27,142,22,142,17,142,25,142,38,142,39,142,20,142,18,142,24,142,19,142,28,142,23,142,26,142,44,143,36,143,24,143,26,143,32,143,35,143,22,143,23,143,115,144,112,144,111,144,103,144,107,144,47,145,43,145,41,145,42,145,50,145,38,145,46,145,133,145,134,145,138,145,129,145,130,145,132,145,128,145,208,146,195,146,196,146,192,146,217,146,182,146,207,146,241,146,223,146,216,146,233,146,215,146,221,146,204,146,239,146,194,146,232,146,202,146,200,146,206,146,230,146,205,146,213,146,201,146,224,146,222,146,231,146,209,146,211,146,181,146,225,146,198,146,180,146,124,149,172,149,171,149,174,149,176,149,164,150,162,150,211,150,5,151,8,151,2,151,90,151,138,151,142,151,136,151,208,151,207,151,30,152,29,152,38,152,41,152,40,152,32,152,27,152,39,152,178,152,8,153,250,152,17,153,20,153,22,153,23,153,21,153,220,153,205,153,207,153,211,153,212,153,206,153,201,153,214,153,216,153,203,153,215,153,204,153,179,154,236,154,235,154,243,154,242,154,241,154,70,155,67,155,103,155,116,155,113,155,102,155,118,155,117,155,112,155,104,155,100,155,108,155,252,156,250,156,253,156,255,156,247,156,7,157,0,157,249,156,251,156,8,157,5,157,4,157,131,158,211,158,15,159,16,159,28,81,19,81,23,81,26,81,17,81,222,81,52,83,225,83,112,86,96,86,110,86,115,86,102,86,99,86,109,86,114,86,94,86,119,86,28,87,27,87,200,88,189,88,201,88,191,88,186,88,194,88,188,88,198,88,23,91,25,91,27,91,33,91,20,91,19,91,16,91,22,91,40,91,26,91,32,91,30,91,239,91,172,93,177,93,169,93,167,93,181,93,176,93,174,93,170,93,168,93,178,93,173,93,175,93,180,93,103,94,104,94,102,94,111,94,233,94,231,94,230,94,232,94,229,94,75,95,188,95,157,97,168,97,150,97,197,97,180,97,198,97,193,97,204,97,186,97,191,97,184,97,140,97,215,100,214,100,208,100,207,100,201,100,189,100,137,100,195,100,219,100,243,100,217,100,51,101,127,101,124,101,162,101,200,102,190,102,192,102,202,102,203,102,207,102,189,102,187,102,186,102,204,102,35,103,52,106,102,106,73,106,103,106,50,106,104,106,62,106,93,106,109,106,118,106,91,106,81,106,40,106,90,106,59,106,63,106,65,106,106,106,100,106,80,106,79,106,84,106,111,106,105,106,96,106,60,106,94,106,86,106,85,106,77,106,78,106,70,106,85,107,84,107,86,107,167,107,170,107,171,107,200,107,199,107,4,108,3,108,6,108,173,111,203,111,163,111,199,111,188,111,206,111,200,111,94,111,196,111,189,111,158,111,202,111,168,111,4,112,165,111,174,111,186,111,172,111,170,111,207,111,191,111,184,111,162,111,201,111,171,111,205,111,175,111,178,111,176,111,197,113,194,113,191,113,184,113,214,113,192,113,193,113,203,113,212,113,202,113,199,113,207,113,189,113,216,113,188,113,198,113,218,113,219,113,157,114,158,114,105,115,102,115,103,115,108,115,101,115,107,115,106,115,127,116,154,116,160,116,148,116,146,116,149,116,161,116,11,117,128,117,47,118,45,118,49,118,61,118,51,118,60,118,53,118,50,118,48,118,187,118,230,118,154,119,157,119,161,119,156,119,155,119,162,119,163,119,149,119,153,119,151,119,221,120,233,120,229,120,234,120,222,120,227,120,219,120,225,120,226,120,237,120,223,120,224,120,164,121,68,122,72,122,71,122,182,122,184,122,181,122,177,122,183,122,222,123,227,123,231,123,221,123,213,123,229,123,218,123,232,123,249,123,212,123,234,123,226,123,220,123,235,123,216,123,223,123,210,124,212,124,215,124,208,124,209,124,18,126,33,126,23,126,12,126,31,126,32,126,19,126,14,126,28,126,21,126,26,126,34,126,11,126,15,126,22,126,13,126,20,126,37,126,36,126,67,127,123,127,124,127,122,127,177,127,239,127,42,128,41,128,108,128,177,129,166,129,174,129,185,129,181,129,171,129,176,129,172,129,180,129,178,129,183,129,167,129,242,129,85,130,86,130,87,130,86,133,69,133,107,133,77,133,83,133,97,133,88,133,64,133,70,133,100,133,65,133,98,133,68,133,81,133,71,133,99,133,62,133,91,133,113,133,78,133,110,133,117,133,85,133,103,133,96,133,140,133,102,133,93,133,84,133,101,133,108,133,99,134,101,134,100,134,155,135,143,135,151,135,147,135,146,135,136,135,129,135,150,135,152,135,121,135,135,135,163,135,133,135,144,135,145,135,157,135,132,135,148,135,156,135,154,135,137,135,30,137,38,137,48,137,45,137,46,137,39,137,49,137,34,137,41,137,35,137,47,137,44,137,31,137,241,137,224,138,226,138,242,138,244,138,245,138,221,138,20,139,228,138,223,138,240,138,200,138,222,138,225,138,232,138,255,138,239,138,251,138,145,140,146,140,144,140,245,140,238,140,241,140,240,140,243,140,108,141,110,141,165,141,167,141,51,142,62,142,56,142,64,142,69,142,54,142,60,142,61,142,65,142,48,142,63,142,189,142,54,143,46,143,53,143,50,143,57,143,55,143,52,143,118,144,121,144,123,144,134,144,250,144,51,145,53,145,54,145,147,145,144,145,145,145,141,145,143,145,39,147,30,147,8,147,31,147,6,147,15,147,122,147,56,147,60,147,27,147,35,147,18,147,1,147,70,147,45,147,14,147,13,147,203,146,29,147,250,146,37,147,19,147,249,146,247,146,52,147,2,147,36,147,255,146,41,147,57,147,53,147,42,147,20,147,12,147,11,147,254,146,9,147,0,147,251,146,22,147,188,149,205,149,190,149,185,149,186,149,182,149,191,149,181,149,189,149,169,150,212,150,11,151,18,151,16,151,153,151,151,151,148,151,240,151,248,151,53,152,47,152,50,152,36,153,31,153,39,153,41,153,158,153,238,153,236,153,229,153,228,153,240,153,227,153,234,153,233,153,231,153,185,154,191,154,180,154,187,154,246,154,250,154,249,154,247,154,51,155,128,155,133,155,135,155,124,155,126,155,123,155,130,155,147,155,146,155,144,155,122,155,149,155,125,155,136,155,37,157,23,157,32,157,30,157,20,157,41,157,29,157,24,157,34,157,16,157,25,157,31,157,136,158,134,158,135,158,174,158,173,158,213,158,214,158,250,158,18,159,61,159,38,81,37,81,34,81,36,81,32,81,41,81,244,82,147,86,140,86,141,86,134,86,132,86,131,86,126,86,130,86,127,86,129,86,214,88,212,88,207,88,210,88,45,91,37,91,50,91,35,91,44,91,39,91,38,91,47,91,46,91,123,91,241,91,242,91,183,93,108,94,106,94,190,95,187,95,195,97,181,97,188,97,231,97,224,97,229,97,228,97,232,97,222,97,239,100,233,100,227,100,235,100,228,100,232,100,129,101,128,101,182,101,218,101,210,102,141,106,150,106,129,106,165,106,137,106,159,106,155,106,161,106,158,106,135,106,147,106,142,106,149,106,131,106,168,106,164,106,145,106,127,106,166,106,154,106,133,106,140,106,146,106,91,107,173,107,9,108,204,111,169,111,244,111,212,111,227,111,220,111,237,111,231,111,230,111,222,111,242,111,221,111,226,111,232,111,225,113,241,113,232,113,242,113,228,113,240,113,226,113,115,115,110,115,111,115,151,116,178,116,171,116,144,116,170,116,173,116,177,116,165,116,175,116,16,117,17,117,18,117,15,117,132,117,67,118,72,118,73,118,71,118,164,118,233,118,181,119,171,119,178,119,183,119,182,119,180,119,177,119,168,119,240,119,243,120,253,120,2,121,251,120,252,120,242,120,5,121,249,120,254,120,4,121,171,121,168,121,92,122,91,122,86,122,88,122,84,122,90,122,190,122,192,122,193,122,5,124,15,124,242,123,0,124,255,123,251,123,14,124,244,123,11,124,243,123,2,124,9,124,3,124,1,124,248,123,253,123,6,124,240,123,241,123,16,124,10,124,232,124,45,126,60,126,66,126,51,126,72,152,56,126,42,126,73,126,64,126,71,126,41,126,76,126,48,126,59,126,54,126,68,126,58,126,69,127,127,127,126,127,125,127,244,127,242,127,44,128,187,129,196,129,204,129,202,129,197,129,199,129,188,129,233,129,91,130,90,130,92,130,131,133,128,133,143,133,167,133,149,133,160,133,139,133,163,133,123,133,164,133,154,133,158,133,119,133,124,133,137,133,161,133,122,133,120,133,87,133,142,133,150,133,134,133,141,133,153,133,157,133,129,133,162,133,130,133,136,133,133,133,121,133,118,133,152,133,144,133,159,133,104,134,190,135,170,135,173,135,197,135,176,135,172,135,185,135,181,135,188,135,174,135,201,135,195,135,194,135,204,135,183,135,175,135,196,135,202,135,180,135,182,135,191,135,184,135,189,135,222,135,178,135,53,137,51,137,60,137,62,137,65,137,82,137,55,137,66,137,173,137,175,137,174,137,242,137,243,137,30,139,24,139,22,139,17,139,5,139,11,139,34,139,15,139,18,139,21,139,7,139,13,139,8,139,6,139,28,139,19,139,26,139,79,140,112,140,114,140,113,140,111,140,149,140,148,140,249,140,111,141,78,142,77,142,83,142,80,142,76,142,71,142,67,143,64,143,133,144,126,144,56,145,154,145,162,145,155,145,153,145,159,145,161,145,157,145,160,145,161,147,131,147,175,147,100,147,86,147,71,147,124,147,88,147,92,147,118,147,73,147,80,147,81,147,96,147,109,147,143,147,76,147,106,147,121,147,87,147,85,147,82,147,79,147,113,147,119,147,123,147,97,147,94,147,99,147,103,147,128,147,78,147,89,147,199,149,192,149,201,149,195,149,197,149,183,149,174,150,176,150,172,150,32,151,31,151,24,151,29,151,25,151,154,151,161,151,156,151,158,151,157,151,213,151,212,151,241,151,65,152,68,152,74,152,73,152,69,152,67,152,37,153,43,153,44,153,42,153,51,153,50,153,47,153,45,153,49,153,48,153,152,153,163,153,161,153,2,154,250,153,244,153,247,153,249,153,248,153,246,153,251,153,253,153,254,153,252,153,3,154,190,154,254,154,253,154,1,155,252,154,72,155,154,155,168,155,158,155,155,155,166,155,161,155,165,155,164,155,134,155,162,155,160,155,175,155,51,157,65,157,103,157,54,157,46,157,47,157,49,157,56,157,48,157,69,157,66,157,67,157,62,157,55,157,64,157,61,157,245,127,45,157,138,158,137,158,141,158,176,158,200,158,218,158,251,158,255,158,36,159,35,159,34,159,84,159,160,159,49,81,45,81,46,81,152,86,156,86,151,86,154,86,157,86,153,86,112,89,60,91,105,92,106,92,192,93,109,94,110,94,216,97,223,97,237,97,238,97,241,97,234,97,240,97,235,97,214,97,233,97,255,100,4,101,253,100,248,100,1,101,3,101,252,100,148,101,219,101,218,102,219,102,216,102,197,106,185,106,189,106,225,106,198,106,186,106,182,106,183,106,199,106,180,106,173,106,94,107,201,107,11,108,7,112,12,112,13,112,1,112,5,112,20,112,14,112,255,111,0,112,251,111,38,112,252,111,247,111,10,112,1,114,255,113,249,113,3,114,253,113,118,115,184,116,192,116,181,116,193,116,190,116,182,116,187,116,194,116,20,117,19,117,92,118,100,118,89,118,80,118,83,118,87,118,90,118,166,118,189,118,236,118,194,119,186,119,255,120,12,121,19,121,20,121,9,121,16,121,18,121,17,121,173,121,172,121,95,122,28,124,41,124,25,124,32,124,31,124,45,124,29,124,38,124,40,124,34,124,37,124,48,124,92,126,80,126,86,126,99,126,88,126,98,126,95,126,81,126,96,126,87,126,83,126,181,127,179,127,247,127,248,127,117,128,209,129,210,129,208,129,95,130,94,130,180,133,198,133,192,133,195,133,194,133,179,133,181,133,189,133,199,133,196,133,191,133,203,133,206,133,200,133,197,133,177,133,182,133,210,133,36,134,184,133,183,133,190,133,105,134,231,135,230,135,226,135,219,135,235,135,234,135,229,135,223,135,243,135,228,135,212,135,220,135,211,135,237,135,216,135,227,135,164,135,215,135,217,135,1,136,244,135,232,135,221,135,83,137,75,137,79,137,76,137,70,137,80,137,81,137,73,137,42,139,39,139,35,139,51,139,48,139,53,139,71,139,47,139,60,139,62,139,49,139,37,139,55,139,38,139,54,139,46,139,36,139,59,139,61,139,58,139,66,140,117,140,153,140,152,140,151,140,254,140,4,141,2,141,0,141,92,142,98,142,96,142,87,142,86,142,94,142,101,142,103,142,91,142,90,142,97,142,93,142,105,142,84,142,70,143,71,143,72,143,75,143,40,145,58,145,59,145,62,145,168,145,165,145,167,145,175,145,170,145,181,147,140,147,146,147,183,147,155,147,157,147,137,147,167,147,142,147,170,147,158,147,166,147,149,147,136,147,153,147,159,147,141,147,177,147,145,147,178,147,164,147,168,147,180,147,163,147,165,147,210,149,211,149,209,149,179,150,215,150,218,150,194,93,223,150,216,150,221,150,35,151,34,151,37,151,172,151,174,151,168,151,171,151,164,151,170,151,162,151,165,151,215,151,217,151,214,151,216,151,250,151,80,152,81,152,82,152,184,152,65,153,60,153,58,153,15,154,11,154,9,154,13,154,4,154,17,154,10,154,5,154,7,154,6,154,192,154,220,154,8,155,4,155,5,155,41,155,53,155,74,155,76,155,75,155,199,155,198,155,195,155,191,155,193,155,181,155,184,155,211,155,182,155,196,155,185,155,189,155,92,157,83,157,79,157,74,157,91,157,75,157,89,157,86,157,76,157,87,157,82,157,84,157,95,157,88,157,90,157,142,158,140,158,223,158,1,159,0,159,22,159,37,159,43,159,42,159,41,159,40,159,76,159,85,159,52,81,53,81,150,82,247,82,180,83,171,86,173,86,166,86,167,86,170,86,172,86,218,88,221,88,219,88,18,89,61,91,62,91,63,91,195,93,112,94,191,95,251,97,7,101,16,101,13,101,9,101,12,101,14,101,132,101,222,101,221,101,222,102,231,106,224,106,204,106,209,106,217,106,203,106,223,106,220,106,208,106,235,106,207,106,205,106,222,106,96,107,176,107,12,108,25,112,39,112,32,112,22,112,43,112,33,112,34,112,35,112,41,112,23,112,36,112,28,112,42,112,12,114,10,114,7,114,2,114,5,114,165,114,166,114,164,114,163,114,161,114,203,116,197,116,183,116,195,116,22,117,96,118,201,119,202,119,196,119,241,119,29,121,27,121,33,121,28,121,23,121,30,121,176,121,103,122,104,122,51,124,60,124,57,124,44,124,59,124,236,124,234,124,118,126,117,126,120,126,112,126,119,126,111,126,122,126,114,126,116,126,104,126,75,127,74,127,131,127,134,127,183,127,253,127,254,127,120,128,215,129,213,129,100,130,97,130,99,130,235,133,241,133,237,133,217,133,225,133,232,133,218,133,215,133,236,133,242,133,248,133,216,133,223,133,227,133,220,133,209,133,240,133,230,133,239,133,222,133,226,133,0,136,250,135,3,136,246,135,247,135,9,136,12,136,11,136,6,136,252,135,8,136,255,135,10,136,2,136,98,137,90,137,91,137,87,137,97,137,92,137,88,137,93,137,89,137,136,137,183,137,182,137,246,137,80,139,72,139,74,139,64,139,83,139,86,139,84,139,75,139,85,139,81,139,66,139,82,139,87,139,67,140,119,140,118,140,154,140,6,141,7,141,9,141,172,141,170,141,173,141,171,141,109,142,120,142,115,142,106,142,111,142,123,142,194,142,82,143,81,143,79,143,80,143,83,143,180,143,64,145,63,145,176,145,173,145,222,147,199,147,207,147,194,147,218,147,208,147,249,147,236,147,204,147,217,147,169,147,230,147,202,147,212,147,238,147,227,147,213,147,196,147,206,147,192,147,210,147,231,147,125,149,218,149,219,149,225,150,41,151,43,151,44,151,40,151,38,151,179,151,183,151,182,151,221,151,222,151,223,151,92,152,89,152,93,152,87,152,191,152,189,152,187,152,190,152,72,153,71,153,67,153,166,153,167,153,26,154,21,154,37,154,29,154,36,154,27,154,34,154,32,154,39,154,35,154,30,154,28,154,20,154,194,154,11,155,10,155,14,155,12,155,55,155,234,155,235,155,224,155,222,155,228,155,230,155,226,155,240,155,212,155,215,155,236,155,220,155,217,155,229,155,213,155,225,155,218,155,119,157,129,157,138,157,132,157,136,157,113,157,128,157,120,157,134,157,139,157,140,157,125,157,107,157,116,157,117,157,112,157,105,157,133,157,115,157,123,157,130,157,111,157,121,157,127,157,135,157,104,157,148,158,145,158,192,158,252,158,45,159,64,159,65,159,77,159,86,159,87,159,88,159,55,83,178,86,181,86,179,86,227,88,69,91,198,93,199,93,238,94,239,94,192,95,193,95,249,97,23,101,22,101,21,101,19,101,223,101,232,102,227,102,228,102,243,106,240,106,234,106,232,106,249,106,241,106,238,106,239,106,60,112,53,112,47,112,55,112,52,112,49,112,66,112,56,112,63,112,58,112,57,112,64,112,59,112,51,112,65,112,19,114,20,114,168,114,125,115,124,115,186,116,171,118,170,118,190,118,237,118,204,119,206,119,207,119,205,119,242,119,37,121,35,121,39,121,40,121,36,121,41,121,178,121,110,122,108,122,109,122,247,122,73,124,72,124,74,124,71,124,69,124,238,124,123,126,126,126,129,126,128,126,186,127,255,127,121,128,219,129,217,129,11,130,104,130,105,130,34,134,255,133,1,134,254,133,27,134,0,134,246,133,4,134,9,134,5,134,12,134,253,133,25,136,16,136,17,136,23,136,19,136,22,136,99,137,102,137,185,137,247,137,96,139,106,139,93,139,104,139,99,139,101,139,103,139,109,139,174,141,134,142,136,142,132,142,89,143,86,143,87,143,85,143,88,143,90,143,141,144,67,145,65,145,183,145,181,145,178,145,179,145,11,148,19,148,251,147,32,148,15,148,20,148,254,147,21,148,16,148,40,148,25,148,13,148,245,147,0,148,247,147,7,148,14,148,22,148,18,148,250,147,9,148,248,147,10,148,255,147,252,147,12,148,246,147,17,148,6,148,222,149,224,149,223,149,46,151,47,151,185,151,187,151,253,151,254,151,96,152,98,152,99,152,95,152,193,152,194,152,80,153,78,153,89,153,76,153,75,153,83,153,50,154,52,154,49,154,44,154,42,154,54,154,41,154,46,154,56,154,45,154,199,154,202,154,198,154,16,155,18,155,17,155,11,156,8,156,247,155,5,156,18,156,248,155,64,156,7,156,14,156,6,156,23,156,20,156,9,156,159,157,153,157,164,157,157,157,146,157,152,157,144,157,155,157,160,157,148,157,156,157,170,157,151,157,161,157,154,157,162,157,168,157,158,157,163,157,191,157,169,157,150,157,166,157,167,157,153,158,155,158,154,158,229,158,228,158,231,158,230,158,48,159,46,159,91,159,96,159,94,159,93,159,89,159,145,159,58,81,57,81,152,82,151,82,195,86,189,86,190,86,72,91,71,91,203,93,207,93,241,94,253,97,27,101,2,107,252,106,3,107,248,106,0,107,67,112,68,112,74,112,72,112,73,112,69,112,70,112,29,114,26,114,25,114,126,115,23,117,106,118,208,119,45,121,49,121,47,121,84,124,83,124,242,124,138,126,135,126,136,126,139,126,134,126,141,126,77,127,187,127,48,128,221,129,24,134,42,134,38,134,31,134,35,134,28,134,25,134,39,134,46,134,33,134,32,134,41,134,30,134,37,134,41,136,29,136,27,136,32,136,36,136,28,136,43,136,74,136,109,137,105,137,110,137,107,137,250,137,121,139,120,139,69,139,122,139,123,139,16,141,20,141,175,141,142,142,140,142,94,143,91,143,93,143,70,145,68,145,69,145,185,145,63,148,59,148,54,148,41,148,61,148,60,148,48,148,57,148,42,148,55,148,44,148,64,148,49,148,229,149,228,149,227,149,53,151,58,151,191,151,225,151,100,152,201,152,198,152,192,152,88,153,86,153,57,154,61,154,70,154,68,154,66,154,65,154,58,154,63,154,205,154,21,155,23,155,24,155,22,155,58,155,82,155,43,156,29,156,28,156,44,156,35,156,40,156,41,156,36,156,33,156,183,157,182,157,188,157,193,157,199,157,202,157,207,157,190,157,197,157,195,157,187,157,181,157,206,157,185,157,186,157,172,157,200,157,177,157,173,157,204,157,179,157,205,157,178,157,122,158,156,158,235,158,238,158,237,158,27,159,24,159,26,159,49,159,78,159,101,159,100,159,146,159,185,78,198,86,197,86,203,86,113,89,75,91,76,91,213,93,209,93,242,94,33,101,32,101,38,101,34,101,11,107,8,107,9,107,13,108,85,112,86,112,87,112,82,112,30,114,31,114,169,114,127,115,216,116,213,116,217,116,215,116,109,118,173,118,53,121,180,121,112,122,113,122,87,124,92,124,89,124,91,124,90,124,244,124,241,124,145,126,79,127,135,127,222,129,107,130,52,134,53,134,51,134,44,134,50,134,54,134,44,136,40,136,38,136,42,136,37,136,113,137,191,137,190,137,251,137,126,139,132,139,130,139,134,139,133,139,127,139,21,141,149,142,148,142,154,142,146,142,144,142,150,142,151,142,96,143,98,143,71,145,76,148,80,148,74,148,75,148,79,148,71,148,69,148,72,148,73,148,70,148,63,151,227,151,106,152,105,152,203,152,84,153,91,153,78,154,83,154,84,154,76,154,79,154,72,154,74,154,73,154,82,154,80,154,208,154,25,155,43,155,59,155,86,155,85,155,70,156,72,156,63,156,68,156,57,156,51,156,65,156,60,156,55,156,52,156,50,156,61,156,54,156,219,157,210,157,222,157,218,157,203,157,208,157,220,157,209,157,223,157,233,157,217,157,216,157,214,157,245,157,213,157,221,157,182,158,240,158,53,159,51,159,50,159,66,159,107,159,149,159,162,159,61,81,153,82,232,88,231,88,114,89,77,91,216,93,47,136,79,95,1,98,3,98,4,98,41,101,37,101,150,101,235,102,17,107,18,107,15,107,202,107,91,112,90,112,34,114,130,115,129,115,131,115,112,118,212,119,103,124,102,124,149,126,108,130,58,134,64,134,57,134,60,134,49,134,59,134,62,134,48,136,50,136,46,136,51,136,118,137,116,137,115,137,254,137,140,139,142,139,139,139,136,139,69,140,25,141,152,142,100,143,99,143,188,145,98,148,85,148,93,148,87,148,94,148,196,151,197,151,0,152,86,154,89,154,30,155,31,155,32,155,82,156,88,156,80,156,74,156,77,156,75,156,85,156,89,156,76,156,78,156,251,157,247,157,239,157,227,157,235,157,248,157,228,157,246,157,225,157,238,157,230,157,242,157,240,157,226,157,236,157,244,157,243,157,232,157,237,157,194,158,208,158,242,158,243,158,6,159,28,159,56,159,55,159,54,159,67,159,79,159,113,159,112,159,110,159,111,159,211,86,205,86,78,91,109,92,45,101,237,102,238,102,19,107,95,112,97,112,93,112,96,112,35,114,219,116,229,116,213,119,56,121,183,121,182,121,106,124,151,126,137,127,109,130,67,134,56,136,55,136,53,136,75,136,148,139,149,139,158,142,159,142,160,142,157,142,190,145,189,145,194,145,107,148,104,148,105,148,229,150,70,151,67,151,71,151,199,151,229,151,94,154,213,154,89,155,99,156,103,156,102,156,98,156,94,156,96,156,2,158,254,157,7,158,3,158,6,158,5,158,0,158,1,158,9,158,255,157,253,157,4,158,160,158,30,159,70,159,116,159,117,159,118,159,212,86,46,101,184,101,24,107,25,107,23,107,26,107,98,112,38,114,170,114,216,119,217,119,57,121,105,124,107,124,246,124,154,126,152,126,155,126,153,126,224,129,225,129,70,134,71,134,72,134,121,137,122,137,124,137,123,137,255,137,152,139,153,139,165,142,164,142,163,142,110,148,109,148,111,148,113,148,115,148,73,151,114,152,95,153,104,156,110,156,109,156,11,158,13,158,16,158,15,158,18,158,17,158,161,158,245,158,9,159,71,159,120,159,123,159,122,159,121,159,30,87,102,112,111,124,60,136,178,141,166,142,195,145,116,148,120,148,118,148,117,148,96,154,116,156,115,156,113,156,117,156,20,158,19,158,246,158,10,159,164,159,104,112,101,112,247,124,106,134,62,136,61,136,63,136,158,139,156,140,169,142,201,142,75,151,115,152,116,152,204,152,97,153,171,153,100,154,102,154,103,154,36,155,21,158,23,158,72,159,7,98,30,107,39,114,76,134,168,142,130,148,128,148,129,148,105,154,104,154,46,155,25,158,41,114,75,134,159,139,131,148,121,156,183,158,117,118,107,154,122,156,29,158,105,112,106,112,164,158,126,159,73,159,152,159,129,120,185,146,207,136,187,88,82,96,167,124,250,90,84,37,102,37,87,37,96,37,108,37,99,37,90,37,105,37,93,37,82,37,100,37,85,37,94,37,106,37,97,37,88,37,103,37,91,37,83,37,101,37,86,37,95,37,107,37,98,37,89,37,104,37,92,37,81,37,80,37,109,37,110,37,112,37,111,37,147,37,0,0,0,0,0,0,0,48,1,48,2,48,183,0,37,32,38,32,168,0,3,48,173,0,21,32,37,34,60,255,60,34,24,32,25,32,28,32,29,32,20,48,21,48,8,48,9,48,10,48,11,48,12,48,13,48,14,48,15,48,16,48,17,48,177,0,215,0,247,0,96,34,100,34,101,34,30,34,52,34,176,0,50,32,51,32,3,33,43,33,224,255,225,255,229,255,66,38,64,38,32,34,165,34,18,35,2,34,7,34,97,34,82,34,167,0,59,32,6,38,5,38,203,37,207,37,206,37,199,37,198,37,161,37,160,37,179,37,178,37,189,37,188,37,146,33,144,33,145,33,147,33,148,33,19,48,106,34,107,34,26,34,61,34,29,34,53,34,43,34,44,34,8,34,11,34,134,34,135,34,130,34,131,34,42,34,41,34,39,34,40,34,226,255,210,33,212,33,0,34,3,34,180,0,94,255,199,2,216,2,221,2,218,2,217,2,184,0,219,2,161,0,191,0,208,2,46,34,17,34,15,34,164,0,9,33,48,32,193,37,192,37,183,37,182,37,100,38,96,38,97,38,101,38,103,38,99,38,153,34,200,37,163,37,208,37,209,37,146,37,164,37,165,37,168,37,167,37,166,37,169,37,104,38,15,38,14,38,28,38,30,38,182,0,32,32,33,32,149,33,151,33,153,33,150,33,152,33,109,38,105,38,106,38,108,38,127,50,28,50,22,33,199,51,34,33,194,51,216,51,33,33,172,32,174,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,255,2,255,3,255,4,255,5,255,6,255,7,255,8,255,9,255,10,255,11,255,12,255,13,255,14,255,15,255,16,255,17,255,18,255,19,255,20,255,21,255,22,255,23,255,24,255,25,255,26,255,27,255,28,255,29,255,30,255,31,255,32,255,33,255,34,255,35,255,36,255,37,255,38,255,39,255,40,255,41,255,42,255,43,255,44,255,45,255,46,255,47,255,48,255,49,255,50,255,51,255,52,255,53,255,54,255,55,255,56,255,57,255,58,255,59,255,230,255,61,255,62,255,63,255,64,255,65,255,66,255,67,255,68,255,69,255,70,255,71,255,72,255,73,255,74,255,75,255,76,255,77,255,78,255,79,255,80,255,81,255,82,255,83,255,84,255,85,255,86,255,87,255,88,255,89,255,90,255,91,255,92,255,93,255,227,255,49,49,50,49,51,49,52,49,53,49,54,49,55,49,56,49,57,49,58,49,59,49,60,49,61,49,62,49,63,49,64,49,65,49,66,49,67,49,68,49,69,49,70,49,71,49,72,49,73,49,74,49,75,49,76,49,77,49,78,49,79,49,80,49,81,49,82,49,83,49,84,49,85,49,86,49,87,49,88,49,89,49,90,49,91,49,92,49,93,49,94,49,95,49,96,49,97,49,98,49,99,49,100,49,101,49,102,49,103,49,104,49,105,49,106,49,107,49,108,49,109,49,110,49,111,49,112,49,113,49,114,49,115,49,116,49,117,49,118,49,119,49,120,49,121,49,122,49,123,49,124,49,125,49,126,49,127,49,128,49,129,49,130,49,131,49,132,49,133,49,134,49,135,49,136,49,137,49,138,49,139,49,140,49,141,49,142,49,112,33,113,33,114,33,115,33,116,33,117,33,118,33,119,33,120,33,121,33,0,0,0,0,0,0,0,0,0,0,96,33,97,33,98,33,99,33,100,33,101,33,102,33,103,33,104,33,105,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,3,146,3,147,3,148,3,149,3,150,3,151,3,152,3,153,3,154,3,155,3,156,3,157,3,158,3,159,3,160,3,161,3,163,3,164,3,165,3,166,3,167,3,168,3,169,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,177,3,178,3,179,3,180,3,181,3,182,3,183,3,184,3,185,3,186,3,187,3,188,3,189,3,190,3,191,3,192,3,193,3,195,3,196,3,197,3,198,3,199,3,200,3,201,3,0,0,0,0,0,0,0,0,0,0,0,0,0,37,2,37,12,37,16,37,24,37,20,37,28,37,44,37,36,37,52,37,60,37,1,37,3,37,15,37,19,37,27,37,23,37,35,37,51,37,43,37,59,37,75,37,32,37,47,37,40,37,55,37,63,37,29,37,48,37,37,37,56,37,66,37,18,37,17,37,26,37,25,37,22,37,21,37,14,37,13,37,30,37,31,37,33,37,34,37,38,37,39,37,41,37,42,37,45,37,46,37,49,37,50,37,53,37,54,37,57,37,58,37,61,37,62,37,64,37,65,37,67,37,68,37,69,37,70,37,71,37,72,37,73,37,74,37,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,149,51,150,51,151,51,19,33,152,51,196,51,163,51,164,51,165,51,166,51,153,51,154,51,155,51,156,51,157,51,158,51,159,51,160,51,161,51,162,51,202,51,141,51,142,51,143,51,207,51,136,51,137,51,200,51,167,51,168,51,176,51,177,51,178,51,179,51,180,51,181,51,182,51,183,51,184,51,185,51,128,51,129,51,130,51,131,51,132,51,186,51,187,51,188,51,189,51,190,51,191,51,144,51,145,51,146,51,147,51,148,51,38,33,192,51,193,51,138,51,139,51,140,51,214,51,197,51,173,51,174,51,175,51,219,51,169,51,170,51,171,51,172,51,221,51,208,51,211,51,195,51,201,51,220,51,198,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,198,0,208,0,170,0,38,1,0,0,50,1,0,0,63,1,65,1,216,0,82,1,186,0,222,0,102,1,74,1,0,0,96,50,97,50,98,50,99,50,100,50,101,50,102,50,103,50,104,50,105,50,106,50,107,50,108,50,109,50,110,50,111,50,112,50,113,50,114,50,115,50,116,50,117,50,118,50,119,50,120,50,121,50,122,50,123,50,208,36,209,36,210,36,211,36,212,36,213,36,214,36,215,36,216,36,217,36,218,36,219,36,220,36,221,36,222,36,223,36,224,36,225,36,226,36,227,36,228,36,229,36,230,36,231,36,232,36,233,36,96,36,97,36,98,36,99,36,100,36,101,36,102,36,103,36,104,36,105,36,106,36,107,36,108,36,109,36,110,36,189,0,83,33,84,33,188,0,190,0,91,33,92,33,93,33,94,33,230,0,17,1,240,0,39,1,49,1,51,1,56,1,64,1,66,1,248,0,83,1,223,0,254,0,103,1,75,1,73,1,0,50,1,50,2,50,3,50,4,50,5,50,6,50,7,50,8,50,9,50,10,50,11,50,12,50,13,50,14,50,15,50,16,50,17,50,18,50,19,50,20,50,21,50,22,50,23,50,24,50,25,50,26,50,27,50,156,36,157,36,158,36,159,36,160,36,161,36,162,36,163,36,164,36,165,36,166,36,167,36,168,36,169,36,170,36,171,36,172,36,173,36,174,36,175,36,176,36,177,36,178,36,179,36,180,36,181,36,116,36,117,36,118,36,119,36,120,36,121,36,122,36,123,36,124,36,125,36,126,36,127,36,128,36,129,36,130,36,185,0,178,0,179,0,116,32,127,32,129,32,130,32,131,32,132,32,65,48,66,48,67,48,68,48,69,48,70,48,71,48,72,48,73,48,74,48,75,48,76,48,77,48,78,48,79,48,80,48,81,48,82,48,83,48,84,48,85,48,86,48,87,48,88,48,89,48,90,48,91,48,92,48,93,48,94,48,95,48,96,48,97,48,98,48,99,48,100,48,101,48,102,48,103,48,104,48,105,48,106,48,107,48,108,48,109,48,110,48,111,48,112,48,113,48,114,48,115,48,116,48,117,48,118,48,119,48,120,48,121,48,122,48,123,48,124,48,125,48,126,48,127,48,128,48,129,48,130,48,131,48,132,48,133,48,134,48,135,48,136,48,137,48,138,48,139,48,140,48,141,48,142,48,143,48,144,48,145,48,146,48,147,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,161,48,162,48,163,48,164,48,165,48,166,48,167,48,168,48,169,48,170,48,171,48,172,48,173,48,174,48,175,48,176,48,177,48,178,48,179,48,180,48,181,48,182,48,183,48,184,48,185,48,186,48,187,48,188,48,189,48,190,48,191,48,192,48,193,48,194,48,195,48,196,48,197,48,198,48,199,48,200,48,201,48,202,48,203,48,204,48,205,48,206,48,207,48,208,48,209,48,210,48,211,48,212,48,213,48,214,48,215,48,216,48,217,48,218,48,219,48,220,48,221,48,222,48,223,48,224,48,225,48,226,48,227,48,228,48,229,48,230,48,231,48,232,48,233,48,234,48,235,48,236,48,237,48,238,48,239,48,240,48,241,48,242,48,243,48,244,48,245,48,246,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,4,17,4,18,4,19,4,20,4,21,4,1,4,22,4,23,4,24,4,25,4,26,4,27,4,28,4,29,4,30,4,31,4,32,4,33,4,34,4,35,4,36,4,37,4,38,4,39,4,40,4,41,4,42,4,43,4,44,4,45,4,46,4,47,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,4,49,4,50,4,51,4,52,4,53,4,81,4,54,4,55,4,56,4,57,4,58,4,59,4,60,4,61,4,62,4,63,4,64,4,65,4,66,4,67,4,68,4,69,4,70,4,71,4,72,4,73,4,74,4,75,4,76,4,77,4,78,4,79,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,172,1,172,4,172,7,172,8,172,9,172,10,172,16,172,17,172,18,172,19,172,20,172,21,172,22,172,23,172,25,172,26,172,27,172,28,172,29,172,32,172,36,172,44,172,45,172,47,172,48,172,49,172,56,172,57,172,60,172,64,172,75,172,77,172,84,172,88,172,92,172,112,172,113,172,116,172,119,172,120,172,122,172,128,172,129,172,131,172,132,172,133,172,134,172,137,172,138,172,139,172,140,172,144,172,148,172,156,172,157,172,159,172,160,172,161,172,168,172,169,172,170,172,172,172,175,172,176,172,184,172,185,172,187,172,188,172,189,172,193,172,196,172,200,172,204,172,213,172,215,172,224,172,225,172,228,172,231,172,232,172,234,172,236,172,239,172,240,172,241,172,243,172,245,172,246,172,252,172,253,172,0,173,4,173,6,173,12,173,13,173,15,173,17,173,24,173,28,173,32,173,41,173,44,173,45,173,52,173,53,173,56,173,60,173,68,173,69,173,71,173,73,173,80,173,84,173,88,173,97,173,99,173,108,173,109,173,112,173,115,173,116,173,117,173,118,173,123,173,124,173,125,173,127,173,129,173,130,173,136,173,137,173,140,173,144,173,156,173,157,173,164,173,183,173,192,173,193,173,196,173,200,173,208,173,209,173,211,173,220,173,224,173,228,173,248,173,249,173,252,173,255,173,0,174,1,174,8,174,9,174,11,174,13,174,20,174,48,174,49,174,52,174,55,174,56,174,58,174,64,174,65,174,67,174,69,174,70,174,74,174,76,174,77,174,78,174,80,174,84,174,86,174,92,174,93,174,95,174,96,174,97,174,101,174,104,174,105,174,108,174,112,174,120,174,121,174,123,174,124,174,125,174,132,174,133,174,140,174,188,174,189,174,190,174,192,174,196,174,204,174,205,174,207,174,208,174,209,174,216,174,217,174,220,174,232,174,235,174,237,174,244,174,248,174,252,174,7,175,8,175],"i8",ALLOC_NONE,Runtime.GLOBAL_BASE+302308),
	allocate([13,175,16,175,44,175,45,175,48,175,50,175,52,175,60,175,61,175,63,175,65,175,66,175,67,175,72,175,73,175,80,175,92,175,93,175,100,175,101,175,121,175,128,175,132,175,136,175,144,175,145,175,149,175,156,175,184,175,185,175,188,175,192,175,199,175,200,175,201,175,203,175,205,175,206,175,212,175,220,175,232,175,233,175,240,175,241,175,244,175,248,175,0,176,1,176,4,176,12,176,16,176,20,176,28,176,29,176,40,176,68,176,69,176,72,176,74,176,76,176,78,176,83,176,84,176,85,176,87,176,89,176,93,176,124,176,125,176,128,176,132,176,140,176,141,176,143,176,145,176,152,176,153,176,154,176,156,176,159,176,160,176,161,176,162,176,168,176,169,176,171,176,172,176,173,176,174,176,175,176,177,176,179,176,180,176,181,176,184,176,188,176,196,176,197,176,199,176,200,176,201,176,208,176,209,176,212,176,216,176,224,176,229,176,8,177,9,177,11,177,12,177,16,177,18,177,19,177,24,177,25,177,27,177,28,177,29,177,35,177,36,177,37,177,40,177,44,177,52,177,53,177,55,177,56,177,57,177,64,177,65,177,68,177,72,177,80,177,81,177,84,177,85,177,88,177,92,177,96,177,120,177,121,177,124,177,128,177,130,177,136,177,137,177,139,177,141,177,146,177,147,177,148,177,152,177,156,177,168,177,204,177,208,177,212,177,220,177,221,177,223,177,232,177,233,177,236,177,240,177,249,177,251,177,253,177,4,178,5,178,8,178,11,178,12,178,20,178,21,178,23,178,25,178,32,178,52,178,60,178,88,178,92,178,96,178,104,178,105,178,116,178,117,178,124,178,132,178,133,178,137,178,144,178,145,178,148,178,152,178,153,178,154,178,160,178,161,178,163,178,165,178,166,178,170,178,172,178,176,178,180,178,200,178,201,178,204,178,208,178,210,178,216,178,217,178,219,178,221,178,226,178,228,178,229,178,230,178,232,178,235,178,236,178,237,178,238,178,239,178,243,178,244,178,245,178,247,178,248,178,249,178,250,178,251,178,255,178,0,179,1,179,4,179,8,179,16,179,17,179,19,179,20,179,21,179,28,179,84,179,85,179,86,179,88,179,91,179,92,179,94,179,95,179,100,179,101,179,103,179,105,179,107,179,110,179,112,179,113,179,116,179,120,179,128,179,129,179,131,179,132,179,133,179,140,179,144,179,148,179,160,179,161,179,168,179,172,179,196,179,197,179,200,179,203,179,204,179,206,179,208,179,212,179,213,179,215,179,217,179,219,179,221,179,224,179,228,179,232,179,252,179,16,180,24,180,28,180,32,180,40,180,41,180,43,180,52,180,80,180,81,180,84,180,88,180,96,180,97,180,99,180,101,180,108,180,128,180,136,180,157,180,164,180,168,180,172,180,181,180,183,180,185,180,192,180,196,180,200,180,208,180,213,180,220,180,221,180,224,180,227,180,228,180,230,180,236,180,237,180,239,180,241,180,248,180,20,181,21,181,24,181,27,181,28,181,36,181,37,181,39,181,40,181,41,181,42,181,48,181,49,181,52,181,56,181,64,181,65,181,67,181,68,181,69,181,75,181,76,181,77,181,80,181,84,181,92,181,93,181,95,181,96,181,97,181,160,181,161,181,164,181,168,181,170,181,171,181,176,181,177,181,179,181,180,181,181,181,187,181,188,181,189,181,192,181,196,181,204,181,205,181,207,181,208,181,209,181,216,181,236,181,16,182,17,182,20,182,24,182,37,182,44,182,52,182,72,182,100,182,104,182,156,182,157,182,160,182,164,182,171,182,172,182,177,182,212,182,240,182,244,182,248,182,0,183,1,183,5,183,40,183,41,183,44,183,47,183,48,183,56,183,57,183,59,183,68,183,72,183,76,183,84,183,85,183,96,183,100,183,104,183,112,183,113,183,115,183,117,183,124,183,125,183,128,183,132,183,140,183,141,183,143,183,144,183,145,183,146,183,150,183,151,183,152,183,153,183,156,183,160,183,168,183,169,183,171,183,172,183,173,183,180,183,181,183,184,183,199,183,201,183,236,183,237,183,240,183,244,183,252,183,253,183,255,183,0,184,1,184,7,184,8,184,9,184,12,184,16,184,24,184,25,184,27,184,29,184,36,184,37,184,40,184,44,184,52,184,53,184,55,184,56,184,57,184,64,184,68,184,81,184,83,184,92,184,93,184,96,184,100,184,108,184,109,184,111,184,113,184,120,184,124,184,141,184,168,184,176,184,180,184,184,184,192,184,193,184,195,184,197,184,204,184,208,184,212,184,221,184,223,184,225,184,232,184,233,184,236,184,240,184,248,184,249,184,251,184,253,184,4,185,24,185,32,185,60,185,61,185,64,185,68,185,76,185,79,185,81,185,88,185,89,185,92,185,96,185,104,185,105,185,107,185,109,185,116,185,117,185,120,185,124,185,132,185,133,185,135,185,137,185,138,185,141,185,142,185,172,185,173,185,176,185,180,185,188,185,189,185,191,185,193,185,200,185,201,185,204,185,206,185,207,185,208,185,209,185,210,185,216,185,217,185,219,185,221,185,222,185,225,185,227,185,228,185,229,185,232,185,236,185,244,185,245,185,247,185,248,185,249,185,250,185,0,186,1,186,8,186,21,186,56,186,57,186,60,186,64,186,66,186,72,186,73,186,75,186,77,186,78,186,83,186,84,186,85,186,88,186,92,186,100,186,101,186,103,186,104,186,105,186,112,186,113,186,116,186,120,186,131,186,132,186,133,186,135,186,140,186,168,186,169,186,171,186,172,186,176,186,178,186,184,186,185,186,187,186,189,186,196,186,200,186,216,186,217,186,252,186,0,187,4,187,13,187,15,187,17,187,24,187,28,187,32,187,41,187,43,187,52,187,53,187,54,187,56,187,59,187,60,187,61,187,62,187,68,187,69,187,71,187,73,187,77,187,79,187,80,187,84,187,88,187,97,187,99,187,108,187,136,187,140,187,144,187,164,187,168,187,172,187,180,187,183,187,192,187,196,187,200,187,208,187,211,187,248,187,249,187,252,187,255,187,0,188,2,188,8,188,9,188,11,188,12,188,13,188,15,188,17,188,20,188,21,188,22,188,23,188,24,188,27,188,28,188,29,188,30,188,31,188,36,188,37,188,39,188,41,188,45,188,48,188,49,188,52,188,56,188,64,188,65,188,67,188,68,188,69,188,73,188,76,188,77,188,80,188,93,188,132,188,133,188,136,188,139,188,140,188,142,188,148,188,149,188,151,188,153,188,154,188,160,188,161,188,164,188,167,188,168,188,176,188,177,188,179,188,180,188,181,188,188,188,189,188,192,188,196,188,205,188,207,188,208,188,209,188,213,188,216,188,220,188,244,188,245,188,246,188,248,188,252,188,4,189,5,189,7,189,9,189,16,189,20,189,36,189,44,189,64,189,72,189,73,189,76,189,80,189,88,189,89,189,100,189,104,189,128,189,129,189,132,189,135,189,136,189,137,189,138,189,144,189,145,189,147,189,149,189,153,189,154,189,156,189,164,189,176,189,184,189,212,189,213,189,216,189,220,189,233,189,240,189,244,189,248,189,0,190,3,190,5,190,12,190,13,190,16,190,20,190,28,190,29,190,31,190,68,190,69,190,72,190,76,190,78,190,84,190,85,190,87,190,89,190,90,190,91,190,96,190,97,190,100,190,104,190,106,190,112,190,113,190,115,190,116,190,117,190,123,190,124,190,125,190,128,190,132,190,140,190,141,190,143,190,144,190,145,190,152,190,153,190,168,190,208,190,209,190,212,190,215,190,216,190,224,190,227,190,228,190,229,190,236,190,1,191,8,191,9,191,24,191,25,191,27,191,28,191,29,191,64,191,65,191,68,191,72,191,80,191,81,191,85,191,148,191,176,191,197,191,204,191,205,191,208,191,212,191,220,191,223,191,225,191,60,192,81,192,88,192,92,192,96,192,104,192,105,192,144,192,145,192,148,192,152,192,160,192,161,192,163,192,165,192,172,192,173,192,175,192,176,192,179,192,180,192,181,192,182,192,188,192,189,192,191,192,192,192,193,192,197,192,200,192,201,192,204,192,208,192,216,192,217,192,219,192,220,192,221,192,228,192,229,192,232,192,236,192,244,192,245,192,247,192,249,192,0,193,4,193,8,193,16,193,21,193,28,193,29,193,30,193,31,193,32,193,35,193,36,193,38,193,39,193,44,193,45,193,47,193,48,193,49,193,54,193,56,193,57,193,60,193,64,193,72,193,73,193,75,193,76,193,77,193,84,193,85,193,88,193,92,193,100,193,101,193,103,193,104,193,105,193,112,193,116,193,120,193,133,193,140,193,141,193,142,193,144,193,148,193,150,193,156,193,157,193,159,193,161,193,165,193,168,193,169,193,172,193,176,193,189,193,196,193,200,193,204,193,212,193,215,193,216,193,224,193,228,193,232,193,240,193,241,193,243,193,252,193,253,193,0,194,4,194,12,194,13,194,15,194,17,194,24,194,25,194,28,194,31,194,32,194,40,194,41,194,43,194,45,194,47,194,49,194,50,194,52,194,72,194,80,194,81,194,84,194,88,194,96,194,101,194,108,194,109,194,112,194,116,194,124,194,125,194,127,194,129,194,136,194,137,194,144,194,152,194,155,194,157,194,164,194,165,194,168,194,172,194,173,194,180,194,181,194,183,194,185,194,220,194,221,194,224,194,227,194,228,194,235,194,236,194,237,194,239,194,241,194,246,194,248,194,249,194,251,194,252,194,0,195,8,195,9,195,12,195,13,195,19,195,20,195,21,195,24,195,28,195,36,195,37,195,40,195,41,195,69,195,104,195,105,195,108,195,112,195,114,195,120,195,121,195,124,195,125,195,132,195,136,195,140,195,192,195,216,195,217,195,220,195,223,195,224,195,226,195,232,195,233,195,237,195,244,195,245,195,248,195,8,196,16,196,36,196,44,196,48,196,52,196,60,196,61,196,72,196,100,196,101,196,104,196,108,196,116,196,117,196,121,196,128,196,148,196,156,196,184,196,188,196,233,196,240,196,241,196,244,196,248,196,250,196,255,196,0,197,1,197,12,197,16,197,20,197,28,197,40,197,41,197,44,197,48,197,56,197,57,197,59,197,61,197,68,197,69,197,72,197,73,197,74,197,76,197,77,197,78,197,83,197,84,197,85,197,87,197,88,197,89,197,93,197,94,197,96,197,97,197,100,197,104,197,112,197,113,197,115,197,116,197,117,197,124,197,125,197,128,197,132,197,135,197,140,197,141,197,143,197,145,197,149,197,151,197,152,197,156,197,160,197,169,197,180,197,181,197,184,197,185,197,187,197,188,197,189,197,190,197,196,197,197,197,198,197,199,197,200,197,201,197,202,197,204,197,206,197,208,197,209,197,212,197,216,197,224,197,225,197,227,197,229,197,236,197,237,197,238,197,240,197,244,197,246,197,247,197,252,197,253,197,254,197,255,197,0,198,1,198,5,198,6,198,7,198,8,198,12,198,16,198,24,198,25,198,27,198,28,198,36,198,37,198,40,198,44,198,45,198,46,198,48,198,51,198,52,198,53,198,55,198,57,198,59,198,64,198,65,198,68,198,72,198,80,198,81,198,83,198,84,198,85,198,92,198,93,198,96,198,108,198,111,198,113,198,120,198,121,198,124,198,128,198,136,198,137,198,139,198,141,198,148,198,149,198,152,198,156,198,164,198,165,198,167,198,169,198,176,198,177,198,180,198,184,198,185,198,186,198,192,198,193,198,195,198,197,198,204,198,205,198,208,198,212,198,220,198,221,198,224,198,225,198,232,198,233,198,236,198,240,198,248,198,249,198,253,198,4,199,5,199,8,199,12,199,20,199,21,199,23,199,25,199,32,199,33,199,36,199,40,199,48,199,49,199,51,199,53,199,55,199,60,199,61,199,64,199,68,199,74,199,76,199,77,199,79,199,81,199,82,199,83,199,84,199,85,199,86,199,87,199,88,199,92,199,96,199,104,199,107,199,116,199,117,199,120,199,124,199,125,199,126,199,131,199,132,199,133,199,135,199,136,199,137,199,138,199,142,199,144,199,145,199,148,199,150,199,151,199,152,199,154,199,160,199,161,199,163,199,164,199,165,199,166,199,172,199,173,199,176,199,180,199,188,199,189,199,191,199,192,199,193,199,200,199,201,199,204,199,206,199,208,199,216,199,221,199,228,199,232,199,236,199,0,200,1,200,4,200,8,200,10,200,16,200,17,200,19,200,21,200,22,200,28,200,29,200,32,200,36,200,44,200,45,200,47,200,49,200,56,200,60,200,64,200,72,200,73,200,76,200,77,200,84,200,112,200,113,200,116,200,120,200,122,200,128,200,129,200,131,200,133,200,134,200,135,200,139,200,140,200,141,200,148,200,157,200,159,200,161,200,168,200,188,200,189,200,196,200,200,200,204,200,212,200,213,200,215,200,217,200,224,200,225,200,228,200,245,200,252,200,253,200,0,201,4,201,5,201,6,201,12,201,13,201,15,201,17,201,24,201,44,201,52,201,80,201,81,201,84,201,88,201,96,201,97,201,99,201,108,201,112,201,116,201,124,201,136,201,137,201,140,201,144,201,152,201,153,201,155,201,157,201,192,201,193,201,196,201,199,201,200,201,202,201,208,201,209,201,211,201,213,201,214,201,217,201,218,201,220,201,221,201,224,201,226,201,228,201,231,201,236,201,237,201,239,201,240,201,241,201,248,201,249,201,252,201,0,202,8,202,9,202,11,202,12,202,13,202,20,202,24,202,41,202,76,202,77,202,80,202,84,202,92,202,93,202,95,202,96,202,97,202,104,202,125,202,132,202,152,202,188,202,189,202,192,202,196,202,204,202,205,202,207,202,209,202,211,202,216,202,217,202,224,202,236,202,244,202,8,203,16,203,20,203,24,203,32,203,33,203,65,203,72,203,73,203,76,203,80,203,88,203,89,203,93,203,100,203,120,203,121,203,156,203,184,203,212,203,228,203,231,203,233,203,12,204,13,204,16,204,20,204,28,204,29,204,33,204,34,204,39,204,40,204,41,204,44,204,46,204,48,204,56,204,57,204,59,204,60,204,61,204,62,204,68,204,69,204,72,204,76,204,84,204,85,204,87,204,88,204,89,204,96,204,100,204,102,204,104,204,112,204,117,204,152,204,153,204,156,204,160,204,168,204,169,204,171,204,172,204,173,204,180,204,181,204,184,204,188,204,196,204,197,204,199,204,201,204,208,204,212,204,228,204,236,204,240,204,1,205,8,205,9,205,12,205,16,205,24,205,25,205,27,205,29,205,36,205,40,205,44,205,57,205,92,205,96,205,100,205,108,205,109,205,111,205,113,205,120,205,136,205,148,205,149,205,152,205,156,205,164,205,165,205,167,205,169,205,176,205,196,205,204,205,208,205,232,205,236,205,240,205,248,205,249,205,251,205,253,205,4,206,8,206,12,206,20,206,25,206,32,206,33,206,36,206,40,206,48,206,49,206,51,206,53,206,88,206,89,206,92,206,95,206,96,206,97,206,104,206,105,206,107,206,109,206,116,206,117,206,120,206,124,206,132,206,133,206,135,206,137,206,144,206,145,206,148,206,152,206,160,206,161,206,163,206,164,206,165,206,172,206,173,206,193,206,228,206,229,206,232,206,235,206,236,206,244,206,245,206,247,206,248,206,249,206,0,207,1,207,4,207,8,207,16,207,17,207,19,207,21,207,28,207,32,207,36,207,44,207,45,207,47,207,48,207,49,207,56,207,84,207,85,207,88,207,92,207,100,207,101,207,103,207,105,207,112,207,113,207,116,207,120,207,128,207,133,207,140,207,161,207,168,207,176,207,196,207,224,207,225,207,228,207,232,207,240,207,241,207,243,207,245,207,252,207,0,208,4,208,17,208,24,208,45,208,52,208,53,208,56,208,60,208,68,208,69,208,71,208,73,208,80,208,84,208,88,208,96,208,108,208,109,208,112,208,116,208,124,208,125,208,129,208,164,208,165,208,168,208,172,208,180,208,181,208,183,208,185,208,192,208,193,208,196,208,200,208,201,208,208,208,209,208,211,208,212,208,213,208,220,208,221,208,224,208,228,208,236,208,237,208,239,208,240,208,241,208,248,208,13,209,48,209,49,209,52,209,56,209,58,209,64,209,65,209,67,209,68,209,69,209,76,209,77,209,80,209,84,209,92,209,93,209,95,209,97,209,104,209,108,209,124,209,132,209,136,209,160,209,161,209,164,209,168,209,176,209,177,209,179,209,181,209,186,209,188,209,192,209,216,209,244,209,248,209,7,210,9,210,16,210,44,210,45,210,48,210,52,210,60,210,61,210,63,210,65,210,72,210,92,210,100,210,128,210,129,210,132,210,136,210,144,210,145,210,149,210,156,210,160,210,164,210,172,210,177,210,184,210,185,210,188,210,191,210,192,210,194,210,200,210,201,210,203,210,212,210,216,210,220,210,228,210,229,210,240,210,241,210,244,210,248,210,0,211,1,211,3,211,5,211,12,211,13,211,14,211,16,211,20,211,22,211,28,211,29,211,31,211,32,211,33,211,37,211,40,211,41,211,44,211,48,211,56,211,57,211,59,211,60,211,61,211,68,211,69,211,124,211,125,211,128,211,132,211,140,211,141,211,143,211,144,211,145,211,152,211,153,211,156,211,160,211,168,211,169,211,171,211,173,211,180,211,184,211,188,211,196,211,197,211,200,211,201,211,208,211,216,211,225,211,227,211,236,211,237,211,240,211,244,211,252,211,253,211,255,211,1,212,8,212,29,212,64,212,68,212,92,212,96,212,100,212,109,212,111,212,120,212,121,212,124,212,127,212,128,212,130,212,136,212,137,212,139,212,141,212,148,212,169,212,204,212,208,212,212,212,220,212,223,212,232,212,236,212,240,212,248,212,251,212,253,212,4,213,8,213,12,213,20,213,21,213,23,213,60,213,61,213,64,213,68,213,76,213,77,213,79,213,81,213,88,213,89,213,92,213,96,213,101,213,104,213,105,213,107,213,109,213,116,213,117,213,120,213,124,213,132,213,133,213,135,213,136,213,137,213,144,213,165,213,200,213,201,213,204,213,208,213,210,213,216,213,217,213,219,213,221,213,228,213,229,213,232,213,236,213,244,213,245,213,247,213,249,213,0,214,1,214,4,214,8,214,16,214,17,214,19,214,20,214,21,214,28,214,32,214,36,214,45,214,56,214,57,214,60,214,64,214,69,214,72,214,73,214,75,214,77,214,81,214,84,214,85,214,88,214,92,214,103,214,105,214,112,214,113,214,116,214,131,214,133,214,140,214,141,214,144,214,148,214,157,214,159,214,161,214,168,214,172,214,176,214,185,214,187,214,196,214,197,214,200,214,204,214,209,214,212,214,215,214,217,214,224,214,228,214,232,214,240,214,245,214,252,214,253,214,0,215,4,215,17,215,24,215,25,215,28,215,32,215,40,215,41,215,43,215,45,215,52,215,53,215,56,215,60,215,68,215,71,215,73,215,80,215,81,215,84,215,86,215,87,215,88,215,89,215,96,215,97,215,99,215,101,215,105,215,108,215,112,215,116,215,124,215,125,215,129,215,136,215,137,215,140,215,144,215,152,215,153,215,155,215,157,215,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,61,79,115,79,71,80,249,80,160,82,239,83,117,84,229,84,9,86,193,90,182,91,135,102,182,103,183,103,239,103,76,107,194,115,194,117,60,122,219,130,4,131,87,136,136,136,54,138,200,140,207,141,251,142,230,143,213,153,59,82,116,83,4,84,106,96,100,97,188,107,207,115,26,129,186,137,210,137,163,149,131,79,10,82,190,88,120,89,230,89,114,94,121,94,199,97,192,99,70,103,236,103,127,104,151,111,78,118,11,119,245,120,8,122,255,122,33,124,157,128,110,130,113,130,235,138,147,149,107,78,157,85,247,102,52,110,163,120,237,122,91,132,16,137,78,135,168,151,216,82,78,87,42,88,76,93,31,97,190,97,33,98,98,101,209,103,68,106,27,110,24,117,179,117,227,118,176,119,58,125,175,144,81,148,82,148,149,159,35,83,172,92,50,117,219,128,64,146,152,149,91,82,8,88,220,89,161,92,23,93,183,94,58,95,74,95,119,97,95,108,122,117,134,117,224,124,115,125,177,125,140,127,84,129,33,130,145,133,65,137,27,139,252,146,77,150,71,156,203,78,247,78,11,80,241,81,79,88,55,97,62,97,104,97,57,101,234,105,17,111,165,117,134,118,214,118,135,123,165,130,203,132,0,249,167,147,139,149,128,85,162,91,81,87,1,249,179,124,185,127,181,145,40,80,187,83,69,92,232,93,210,98,110,99,218,100,231,100,32,110,172,112,91,121,221,141,30,142,2,249,125,144,69,146,248,146,126,78,246,78,101,80,254,93,250,94,6,97,87,105,113,129,84,134,71,142,117,147,43,154,94,78,145,80,112,103,64,104,9,81,141,82,146,82,162,106,188,119,16,146,212,158,171,82,47,96,242,143,72,80,169,97,237,99,202,100,60,104,132,106,192,111,136,129,161,137,148,150,5,88,125,114,172,114,4,117,121,125,109,126,169,128,139,137,116,139,99,144,81,157,137,98,122,108,84,111,80,125,58,127,35,138,124,81,74,97,157,123,25,139,87,146,140,147,172,78,211,79,30,80,190,80,6,81,193,82,205,82,127,83,112,87,131,88,154,94,145,95,118,97,172,97,206,100,108,101,111,102,187,102,244,102,151,104,135,109,133,112,241,112,159,116,165,116,202,116,217,117,108,120,236,120,223,122,246,122,69,125,147,125,21,128,63,128,27,129,150,131,102,139,21,143,21,144,225,147,3,152,56,152,90,154,232,155,194,79,83,85,58,88,81,89,99,91,70,92,184,96,18,98,66,104,176,104,232,104,170,110,76,117,120,118,206,120,61,122,251,124,107,126,124,126,8,138,161,138,63,140,142,150,196,157,228,83,233,83,74,84,113,84,250,86,209,89,100,91,59,92,171,94,247,98,55,101,69,101,114,101,160,102,175,103,193,105,189,108,252,117,144,118,126,119,63,122,148,127,3,128,161,128,143,129,230,130,253,130,240,131,193,133,49,136,180,136,165,138,3,249,156,143,46,147,199,150,103,152,216,154,19,159,237,84,155,101,242,102,143,104,64,122,55,140,96,157,240,86,100,87,17,93,6,102,177,104,205,104,254,110,40,116,158,136,228,155,104,108,4,249,168,154,155,79,108,81,113,81,159,82,84,91,229,93,80,96,109,96,241,98,167,99,59,101,217,115,122,122,163,134,162,140,143,151,50,78,225,91,8,98,156,103,220,116,209,121,211,131,135,138,178,138,232,141,78,144,75,147,70,152,211,94,232,105,255,133,237,144,5,249,160,81,152,91,236,91,99,97,250,104,62,107,76,112,47,116,216,116,161,123,80,127,197,131,192,137,171,140,220,149,40,153,46,82,93,96,236,98,2,144,138,79,73,81,33,83,217,88,227,94,224,102,56,109,154,112,194,114,214,115,80,123,241,128,91,148,102,83,155,99,107,127,86,78,128,80,74,88,222,88,42,96,39,97,208,98,208,105,65,155,143,91,24,125,177,128,95,143,164,78,209,80,172,84,172,85,12,91,160,93,231,93,42,101,78,101,33,104,75,106,225,114,142,118,239,119,94,125,249,127,160,129,78,133,223,134,3,143,78,143,202,144,3,153,85,154,171,155,24,78,69,78,93,78,199,78,241,79,119,81,254,82,64,83,227,83,229,83,142,84,20,86,117,87,162,87,199,91,135,93,208,94,252,97,216,98,81,101,184,103,233,103,203,105,80,107,198,107,236,107,66,108,157,110,120,112,215,114,150,115,3,116,191,119,233,119,118,122,127,125,9,128,252,129,5,130,10,130,223,130,98,136,51,139,252,140,192,142,17,144,177,144,100,146,182,146,210,153,69,154,233,156,215,157,156,159,11,87,64,92,202,131,160,151,171,151,180,158,27,84,152,122,164,127,217,136,205,142,225,144,0,88,72,92,152,99,159,122,174,91,19,95,121,122,174,122,142,130,172,142,38,80,56,82,248,82,119,83,8,87,243,98,114,99,10,107,195,109,55,119,165,83,87,115,104,133,118,142,213,149,58,103,195,106,112,111,109,138,204,142,75,153,6,249,119,102,120,107,180,140,60,155,7,249,235,83,45,87,78,89,198,99,251,105,234,115,69,120,186,122,197,122,254,124,117,132,143,137,115,141,53,144,168,149,251,82,71,87,71,117,96,123,204,131,30,146,8,249,88,106,75,81,75,82,135,82,31,98,216,104,117,105,153,150,197,80,164,82,228,82,195,97,164,101,57,104,255,105,126,116,75,123,185,130,235,131,178,137,57,139,209,143,73,153,9,249,202,78,151,89,210,100,17,102,142,106,52,116,129,121,189,121,169,130,126,136,127,136,95,137,10,249,38,147,11,79,202,83,37,96,113,98,114,108,26,125,102,125,152,78,98,81,220,119,175,128,1,79,14,79,118,81,128,81,220,85,104,86,59,87,250,87,252,87,20,89,71,89,147,89,196,91,144,92,14,93,241,93,126,94,204,95,128,98,215,101,227,101,30,103,31,103,94,103,203,104,196,104,95,106,58,107,35,108,125,108,130,108,199,109,152,115,38,116,42,116,130,116,163,116,120,117,127,117,129,120,239,120,65,121,71,121,72,121,122,121,149,123,0,125,186,125,136,127,6,128,45,128,140,128,24,138,79,139,72,140,119,141,33,147,36,147,226,152,81,153,14,154,15,154,101,154,146,158,202,125,118,79,9,84,238,98,84,104,209,145,171,85,58,81,11,249,12,249,28,90,230,97,13,249,207,98,255,98,14,249,15,249,16,249,17,249,18,249,19,249,163,144,20,249,21,249,22,249,23,249,24,249,254,138,25,249,26,249,27,249,28,249,150,102,29,249,86,113,30,249,31,249,227,150,32,249,79,99,122,99,87,83,33,249,143,103,96,105,115,110,34,249,55,117,35,249,36,249,37,249,13,125,38,249,39,249,114,136,202,86,24,90,40,249,41,249,42,249,43,249,44,249,67,78,45,249,103,81,72,89,240,103,16,128,46,249,115,89,116,94,154,100,202,121,245,95,108,96,200,98,123,99,231,91,215,91,170,82,47,249,116,89,41,95,18,96,48,249,49,249,50,249,89,116,51,249,52,249,53,249,54,249,55,249,56,249,209,153,57,249,58,249,59,249,60,249,61,249,62,249,63,249,64,249,65,249,66,249,67,249,195,111,68,249,69,249,191,129,178,143,241,96,70,249,71,249,102,129,72,249,73,249,63,92,74,249,75,249,76,249,77,249,78,249,79,249,80,249,81,249,233,90,37,138,123,103,16,125,82,249,83,249,84,249,85,249,86,249,87,249,253,128,88,249,89,249,60,92,229,108,63,83,186,110,26,89,54,131,57,78,182,78,70,79,174,85,24,87,199,88,86,95,183,101,230,101,128,106,181,107,77,110,237,119,239,122,30,124,222,125,203,134,146,136,50,145,91,147,187,100,190,111,122,115,184,117,84,144,86,85,77,87,186,97,212,100,199,102,225,109,91,110,109,111,185,111,240,117,67,128,189,129,65,133,131,137,199,138,90,139,31,147,147,108,83,117,84,123,15,142,93,144,16,85,2,88,88,88,98,94,7,98,158,100,224,104,118,117,214,124,179,135,232,158,227,78,136,87,110,87,39,89,13,92,177,92,54,94,133,95,52,98,225,100,179,115,250,129,139,136,184,140,138,150,219,158,133,91,183,95,179,96,18,80,0,82,48,82,22,87,53,88,87,88,14,92,96,92,246,92,139,93,166,94,146,95,188,96,17,99,137,99,23,100,67,104,249,104,194,106,216,109,33,110,212,110,228,111,254,113,220,118,121,119,177,121,59,122,4,132,169,137,237,140,243,141,72,142,3,144,20,144,83,144,253,144,77,147,118,150,220,151,210,107,6,112,88,114,162,114,104,115,99,119,191,121,228,123,155,126,128,139,169,88,199,96,102,101,253,101,190,102,140,108,30,113,201,113,90,140,19,152,109,78,129,122,221,78,172,81,205,81,213,82,12,84,167,97,113,103,80,104,223,104,30,109,124,111,188,117,179,119,229,122,244,128,99,132,133,146,92,81,151,101,92,103,147,103,216,117,199,122,115,131,90,249,70,140,23,144,45,152,111,92,192,129,154,130,65,144,111,144,13,146,151,95,157,93,89,106,200,113,123,118,73,123,228,133,4,139,39,145,48,154,135,85,246,97,91,249,105,118,133,127,63,134,186,135,248,136,143,144,92,249,27,109,217,112,222,115,97,125,61,132,93,249,106,145,241,153,94,249,130,78,117,83,4,107,18,107,62,112,27,114,45,134,30,158,76,82,163,143,80,93,229,100,44,101,22,107,235,111,67,124,156,126,205,133,100,137,189,137,201,98,216,129,31,136,202,94,23,103,106,109,252,114,5,116,111,116,130,135,222,144,134,79,13,93,160,95,10,132,183,81,160,99,101,117,174,78,6,80,105,81,201,81,129,104,17,106,174,124,177,124,231,124,111,130,210,138,27,143,207,145,182,79,55,81,245,82,66,84,236,94,110,97,62,98,197,101,218,106,254,111,42,121,220,133,35,136,173,149,98,154,106,154,151,158,206,158,155,82,198,102,119,107,29,112,43,121,98,143,66,151,144,97,0,98,35,101,35,111,73,113,137,116,244,125,111,128,238,132,38,143,35,144,74,147,189,81,23,82,163,82,12,109,200,112,194,136,201,94,130,101,174,107,194,111,62,124,117,115,228,78,54,79,249,86,95,249,186,92,186,93,28,96,178,115,45,123,154,127,206,127,70,128,30,144,52,146,246,150,72,151,24,152,97,159,139,79,167,111,174,121,180,145,183,150,222,82,96,249,136,100,196,100,211,106,94,111,24,112,16,114,231,118,1,128,6,134,92,134,239,141,5,143,50,151,111,155,250,157,117,158,140,120,127,121,160,125,201,131,4,147,127,158,147,158,214,138,223,88,4,95,39,103,39,112,207,116,96,124,126,128,33,81,40,112,98,114,202,120,194,140,218,140,244,140,247,150,134,78,218,80,238,91,214,94,153,101,206,113,66,118,173,119,74,128,252,132,124,144,39,155,141,159,216,88,65,90,98,92,19,106,218,109,15,111,59,118,47,125,55,126,30,133,56,137,228,147,75,150,137,82,210,101,243,103,180,105,65,109,156,110,15,112,9,116,96,116,89,117,36,118,107,120,44,139,94,152,109,81,46,98,120,150,150,79,43,80,25,93,234,109,184,125,42,143,139,95,68,97,23,104,97,249,134,150,210,82,139,128,220,81,204,81,94,105,28,122,190,125,241,131,117,150,218,79,41,82,152,83,15,84,14,85,101,92,167,96,78,103,168,104,108,109,129,114,248,114,6,116,131,116,98,249,226,117,108,124,121,127,184,127,137,131,207,136,225,136,204,145,208,145,226,150,201,155,29,84,126,111,208,113,152,116,250,133,170,142,163,150,87,156,159,158,151,103,203,109,51,116,232,129,22,151,44,120,203,122,32,123,146,124,105,100,106,116,242,117,188,120,232,120,172,153,84,155,187,158,222,91,85,94,32,111,156,129,171,131,136,144,7,78,77,83,41,90,210,93,78,95,98,97,61,99,105,102,252,102,255,110,43,111,99,112,158,119,44,132,19,133,59,136,19,143,69,153,59,156,28,85,185,98,43,103,171,108,9,131,106,137,122,151,161,78,132,89,216,95,217,95,27,103,178,125,84,127,146,130,43,131,189,131,30,143,153,144,203,87,185,89,146,90,208,91,39,102,154,103,133,104,207,107,100,113,117,127,183,140,227,140,129,144,69,155,8,129,138,140,76,150,64,154,165,158,95,91,19,108,27,115,242,118,223,118,12,132,170,81,147,137,77,81,149,81,201,82,201,104,148,108,4,119,32,119,191,125,236,125,98,151,181,158,197,110,17,133,165,81,13,84,125,84,14,102,157,102,39,105,159,110,191,118,145,119,23,131,194,132,159,135,105,145,152,146,244,156,130,136,174,79,146,81,223,82,198,89,61,94,85,97,120,100,121,100,174,102,208,103,33,106,205,107,219,107,95,114,97,114,65,116,56,119,219,119,23,128,188,130,5,131,0,139,40,139,140,140,40,103,144,108,103,114,238,118,102,119,70,122,169,157,127,107,146,108,34,89,38,103,153,132,111,83,147,88,153,89,223,94,207,99,52,102,115,103,58,110,43,115,215,122,215,130,40,147,217,82,235,93,174,97,203,97,10,98,199,98,171,100,224,101,89,105,102,107,203,107,33,113,247,115,93,117,70,126,30,130,2,131,106,133,163,138,191,140,39,151,97,157,168,88,216,158,17,80,14,82,59,84,79,85,135,101,118,108,10,125,11,125,94,128,138,134,128,149,239,150,255,82,149,108,105,114,115,84,154,90,62,92,75,93,76,95,174,95,42,103,182,104,99,105,60,110,68,110,9,119,115,124,142,127,135,133,14,139,247,143,97,151,244,158,183,92,182,96,13,97,171,97,79,101,251,101,252,101,17,108,239,108,159,115,201,115,225,125,148,149,198,91,28,135,16,139,93,82,90,83,205,98,15,100,178,100,52,103,56,106,202,108,192,115,158,116,148,123,149,124,27,126,138,129,54,130,132,133,235,143,249,150,193,153,52,79,74,83,205,83,219,83,204,98,44,100,0,101,145,101,195,105,238,108,88,111,237,115,84,117,34,118,228,118,252,118,208,120,251,120,44,121,70,125,44,130,224,135,212,143,18,152,239,152,195,82,212,98,165,100,36,110,81,111,124,118,203,141,177,145,98,146,238,154,67,155,35,80,141,80,74,87,168,89,40,92,71,94,119,95,63,98,62,101,185,101,193,101,9,102,139,103,156,105,194,110,197,120,33,125,170,128,128,129,43,130,179,130,161,132,140,134,42,138,23,139,166,144,50,150,144,159,13,80,243,79,99,249,249,87,152,95,220,98,146,99,111,103,67,110,25,113,195,118,204,128,218,128,244,136,245,136,25,137,224,140,41,143,77,145,106,150,47,79,112,79,27,94,207,103,34,104,125,118,126,118,68,155,97,94,10,106,105,113,212,113,106,117,100,249,65,126,67,133,233,133,220,152,16,79,79,123,112,127,165,149,225,81,6,94,181,104,62,108,78,108,219,108,175,114,196,123,3,131,213,108,58,116,251,80,136,82,193,88,216,100,151,106,167,116,86,118,167,120,23,134,226,149,57,151,101,249,94,83,1,95,138,139,168,143,175,143,138,144,37,82,165,119,73,156,8,159,25,78,2,80,117,81,91,92,119,94,30,102,58,102,196,103,197,104,179,112,1,117,197,117,201,121,221,122,39,143,32,153,8,154,221,79,33,88,49,88,246,91,110,102,101,107,17,109,122,110,125,111,228,115,43,117,233,131,220,136,19,137,92,139,20,143,15,79,213,80,16,83,92,83,147,91,169,95,13,103,143,121,121,129,47,131,20,133,7,137,134,137,57,143,59,143,165,153,18,156,44,103,118,78,248,79,73,89,1,92,239,92,240,92,103,99,210,104,253,112,162,113,43,116,43,126,236,132,2,135,34,144,210,146,243,156,13,78,216,78,239,79,133,80,86,82,111,82,38,84,144,84,224,87,43,89,102,90,90,91,117,91,204,91,156,94,102,249,118,98,119,101,167,101,110,109,165,110,54,114,38,123,63,124,54,127,80,129,81,129,154,129,64,130,153,130,169,131,3,138,160,140,230,140,251,140,116,141,186,141,232,144,220,145,28,150,68,150,217,153,231,156,23,83,6,82,41,84,116,86,179,88,84,89,110,89,255,95,164,97,110,98,16,102,126,108,26,113,198,118,137,124,222,124,27,125,172,130,193,140,240,150,103,249,91,79,23,95,127,95,194,98,41,93,11,103,218,104,124,120,67,126,108,157,21,78,153,80,21,83,42,83,81,83,131,89,98,90,135,94,178,96,138,97,73,98,121,98,144,101,135,103,167,105,212,107,214,107,215,107,216,107,184,108,104,249,53,116,250,117,18,120,145,120,213,121,216,121,131,124,203,125,225,127,165,128,62,129,194,129,242,131,26,135,232,136,185,138,108,139,187,140,25,145,94,151,219,152,59,159,172,86,42,91,108,95,140,101,179,106,175,107,92,109,241,111,21,112,93,114,173,115,167,140,211,140,59,152,145,97,55,108,88,128,1,154,77,78,139,78,155,78,213,78,58,79,60,79,127,79,223,79,255,80,242,83,248,83,6,85,227,85,219,86,235,88,98,89,17,90,235,91,250,91,4,92,243,93,43,94,153,95,29,96,104,99,156,101,175,101,246,103,251,103,173,104,123,107,153,108,215,108,35,110,9,112,69,115,2,120,62,121,64,121,96,121,193,121,233,123,23,125,114,125,134,128,13,130,142,131,209,132,199,134,223,136,80,138,94,138,29,139,220,140,102,141,173,143,170,144,252,152,223,153,157,158,74,82,105,249,20,103,106,249,152,80,42,82,113,92,99,101,85,108,202,115,35,117,157,117,151,123,156,132,120,145,48,151,119,78,146,100,186,107,94,113,169,133,9,78,107,249,73,103,238,104,23,110,159,130,24,133,107,136,247,99,129,111,18,146,175,152,10,78,183,80,207,80,31,81,70,85,170,85,23,86,64,91,25,92,224,92,56,94,138,94,160,94,194,94,243,96,81,104,97,106,88,110,61,114,64,114,192,114,248,118,101,121,177,123,212,127,243,136,244,137,115,138,97,140,222,140,28,151,94,88,189,116,253,140,199,85,108,249,97,122,34,125,114,130,114,114,31,117,37,117,109,249,25,123,133,88,251,88,188,93,143,94,182,94,144,95,85,96,146,98,127,99,77,101,145,102,217,102,248,102,22,104,242,104,128,114,94,116,110,123,110,125,214,125,114,127,229,128,18,130,175,133,127,137,147,138,29,144,228,146,205,158,32,159,21,89,109,89,45,94,220,96,20,102,115,102,144,103,80,108,197,109,95,111,243,119,169,120,198,132,203,145,43,147,217,78,202,80,72,81,132,85,11,91,163,91,71,98,126,101,203,101,50,110,125,113,1,116,68,116,135,116,191,116,108,118,170,121,218,125,85,126,168,127,122,129,179,129,57,130,26,134,236,135,117,138,227,141,120,144,145,146,37,148,77,153,174,155,104,83,81,92,84,105,196,108,41,109,43,110,12,130,155,133,59,137,45,138,170,138,234,150,103,159,97,82,185,102,178,107,150,126,254,135,13,141,131,149,93,150,29,101,137,109,238,113,110,249,206,87,211,89,172,91,39,96,250,96,16,98,31,102,95,102,41,115,249,115,219,118,1,119,108,123,86,128,114,128,101,129,160,138,146,145,22,78,226,82,114,107,23,109,5,122,57,123,48,125,111,249,176,140,236,83,47,86,81,88,181,91,15,92,17,92,226,93,64,98,131,99,20,100,45,102,179,104,188,108,136,109,175,110,31,112,164,112,210,113,38,117,143,117,142,117,25,118,17,123,224,123,43,124,32,125,57,125,44,133,109,133,7,134,52,138,13,144,97,144,181,144,183,146,246,151,55,154,215,79,108,92,95,103,145,109,159,124,140,126,22,139,22,141,31,144,107,91,253,93,13,100,192,132,92,144,225,152,135,115,139,91,154,96,126,103,222,109,31,138,166,138,1,144,12,152,55,82,112,249,81,112,142,120,150,147,112,136,215,145,238,79,215,83,253,85,218,86,130,87,253,88,194,90,136,91,171,92,192,92,37,94,1,97,13,98,75,98,136,99,28,100,54,101,120,101,57,106,138,107,52,108,25,109,49,111,231,113,233,114,120,115,7,116,178,116,38,118,97,119,192,121,87,122,234,122,185,124,143,125,172,125,97,126,158,127,41,129,49,131,144,132,218,132,234,133,150,136,176,138,144,139,56,143,66,144,131,144,108,145,150,146,185,146,139,150,167,150,168,150,214,150,0,151,8,152,150,153,211,154,26,155,212,83,126,88,25,89,112,91,191,91,209,109,90,111,159,113,33,116,185,116,133,128,253,131,225,93,135,95,170,95,66,96,236,101,18,104,111,105,83,106,137,107,53,109,243,109,227,115,254,118,172,119,77,123,20,125,35,129,28,130,64,131,244,132,99,133,98,138,196,138,135,145,30,147,6,152,180,153,12,98,83,136,240,143,101,146,7,93,39,93,105,93,95,116,157,129,104,135,213,111,254,98,210,127,54,137,114,137,30,78,88,78,231,80,221,82,71,83,127,98,7,102,105,126,5,136,94,150,141,79,25,83,54,86,203,89,164,90,56,92,78,92,77,92,2,94,17,95,67,96,189,101,47,102,66,102,190,103,244,103,28,115,226,119,58,121,197,127,148,132,205,132,150,137,102,138,105,138,225,138,85,140,122,140,244,87,212,91,15,95,111,96,237,98,13,105,150,107,92,110,132,113,210,123,85,135,88,139,254,142,223,152,254,152,56,79,129,79,225,79,123,84,32,90,184,91,60,97,176,101,104,102,252,113,51,117,94,121,51,125,78,129,227,129,152,131,170,133,206,133,3,135,10,138,171,142,155,143,113,249,197,143,49,89,164,91,230,91,137,96,233,91,11,92,195,95,129,108,114,249,241,109,11,112,26,117,175,130,246,138,192,78,65,83,115,249,217,150,15,108,158,78,196,79,82,81,94,85,37,90,232,92,17,98,89,114,189,130,170,131,254,134,89,136,29,138,63,150,197,150,19,153,9,157,93,157,10,88,179,92,189,93,68,94,225,96,21,97,225,99,2,106,37,110,2,145,84,147,78,152,16,156,119,159,137,91,184,92,9,99,79,102,72,104,60,119,193,150,141,151,84,152,159,155,161,101,1,139,203,142,188,149,53,85,169,92,214,93,181,94,151,102,76,118,244,131,199,149,211,88,188,98,206,114,40,157,240,78,46,89,15,96,59,102,131,107,231,121,38,157,147,83,192,84,195,87,22,93,27,97,214,102,175,109,141,120,126,130,152,150,68,151,132,83,124,98,150,99,178,109,10,126,75,129,77,152,251,106,76,127,175,157,26,158,95,78,59,80,182,81,28,89,249,96,246,99,48,105,58,114,54,128,116,249,206,145,49,95,117,249,118,249,4,125,229,130,111,132,187,132,229,133,141,142,119,249,111,79,120,249,121,249,228,88,67,91,89,96,218,99,24,101,109,101,152,102,122,249,74,105,35,106,11,109,1,112,108,113,210,117,13,118,179,121,112,122,123,249,138,127,124,249,68,137,125,249,147,139,192,145,125,150,126,249,10,153,4,87,161,95,188,101,1,111,0,118,166,121,158,138,173,153,90,155,108,159,4,81,182,97,145,98,141,106,198,129,67,80,48,88,102,95,9,113,0,138,250,138,124,91,22,134,250,79,60,81,180,86,68,89,169,99,249,109,170,93,109,105,134,81,136,78,89,79,127,249,128,249,129,249,130,89,130,249,131,249,95,107,93,108,132,249,181,116,22,121,133,249,7,130,69,130,57,131,63,143,93,143,134,249,24,153,135,249,136,249,137,249,166,78,138,249,223,87,121,95,19,102,139,249,140,249,171,117,121,126,111,139,141,249,6,144,91,154,165,86,39,88,248,89,31,90,180,91,142,249,246,94,143,249,144,249,80,99,59,99,145,249,61,105,135,108,191,108,142,109,147,109,245,109,20,111,146,249,223,112,54,113,89,113,147,249,195,113,213,113,148,249,79,120,111,120,149,249,117,123,227,125,150,249,47,126,151,249,77,136,223,142,152,249,153,249,154,249,91,146,155,249,246,156,156,249,157,249,158,249,133,96,133,109,159,249,177,113,160,249,161,249,177,149,173,83,162,249,163,249,164,249,211,103,165,249,142,112,48,113,48,116,118,130,210,130,166,249,187,149,229,154,125,158,196,102,167,249,193,113,73,132,168,249,169,249,75,88,170,249,171,249,184,93,113,95,172,249,32,102,142,102,121,105,174,105,56,108,243,108,54,110,65,111,218,111,27,112,47,112,80,113,223,113,112,115,173,249,91,116,174,249,212,116,200,118,78,122,147,126,175,249,176,249,241,130,96,138,206,143,177,249,72,147,178,249,25,151,179,249,180,249,66,78,42,80,181,249,8,82,225,83,243,102,109,108,202,111,10,115,127,119,98,122,174,130,221,133,2,134,182,249,212,136,99,138,125,139,107,140,183,249,179,146,184,249,19,151,16,152,148,78,13,79,201,79,178,80,72,83,62,84,51,84,218,85,98,88,186,88,103,89,27,90,228,91,159,96,185,249,202,97,86,101,255,101,100,102,167,104,90,108,179,111,207,112,172,113,82,115,125,123,8,135,164,138,50,156,7,159,75,92,131,108,68,115,137,115,58,146,171,110,101,116,31,118,105,122,21,126,10,134,64,81,197,88,193,100,238,116,21,117,112,118,193,127,149,144,205,150,84,153,38,110,230,116,169,122,170,122,229,129,217,134,120,135,27,138,73,90,140,91,155,91,161,104,0,105,99,109,169,115,19,116,44,116,151,120,233,125,235,127,24,129,85,129,158,131,76,140,46,150,17,152,240,102,128,95,250,101,137,103,106,108,139,115,45,80,3,90,106,107,238,119,22,89,108,93,205,93,37,115,79,117,186,249,187,249],"i8",ALLOC_NONE,Runtime.GLOBAL_BASE+312548),
	allocate([229,80,249,81,47,88,45,89,150,89,218,89,229,91,188,249,189,249,162,93,215,98,22,100,147,100,254,100,190,249,220,102,191,249,72,106,192,249,255,113,100,116,193,249,136,122,175,122,71,126,94,126,0,128,112,129,194,249,239,135,129,137,32,139,89,144,195,249,128,144,82,153,126,97,50,107,116,109,31,126,37,137,177,143,209,79,173,80,151,81,199,82,199,87,137,88,185,91,184,94,66,97,149,105,140,109,103,110,182,110,148,113,98,116,40,117,44,117,115,128,56,131,201,132,10,142,148,147,222,147,196,249,142,78,81,79,118,80,42,81,200,83,203,83,243,83,135,91,211,91,36,92,26,97,130,97,244,101,91,114,151,115,64,116,194,118,80,121,145,121,185,121,6,125,189,127,139,130,213,133,94,134,194,143,71,144,245,144,234,145,133,150,232,150,233,150,214,82,103,95,237,101,49,102,47,104,92,113,54,122,193,144,10,152,145,78,197,249,82,106,158,107,144,111,137,113,24,128,184,130,83,133,75,144,149,150,242,150,251,151,26,133,49,155,144,78,138,113,196,150,67,81,159,83,225,84,19,87,18,87,163,87,155,90,196,90,195,91,40,96,63,97,244,99,133,108,57,109,114,110,144,110,48,114,63,115,87,116,209,130,129,136,69,143,96,144,198,249,98,150,88,152,27,157,8,103,138,141,94,146,77,79,73,80,222,80,113,83,13,87,212,89,1,90,9,92,112,97,144,102,45,110,50,114,75,116,239,125,195,128,14,132,102,132,63,133,95,135,91,136,24,137,2,139,85,144,203,151,79,155,115,78,145,79,18,81,106,81,199,249,47,85,169,85,122,91,165,91,124,94,125,94,190,94,160,96,223,96,8,97,9,97,196,99,56,101,9,103,200,249,212,103,218,103,201,249,97,105,98,105,185,108,39,109,202,249,56,110,203,249,225,111,54,115,55,115,204,249,92,116,49,117,205,249,82,118,206,249,207,249,173,125,254,129,56,132,213,136,152,138,219,138,237,138,48,142,66,142,74,144,62,144,122,144,73,145,201,145,110,147,208,249,209,249,9,88,210,249,211,107,137,128,178,128,211,249,212,249,65,81,107,89,57,92,213,249,214,249,100,111,167,115,228,128,7,141,215,249,23,146,143,149,216,249,217,249,218,249,219,249,127,128,14,98,28,112,104,125,141,135,220,249,160,87,105,96,71,97,183,107,190,138,128,146,177,150,89,78,31,84,235,109,45,133,112,150,243,151,238,152,214,99,227,108,145,144,221,81,201,97,186,129,249,157,157,79,26,80,0,81,156,91,15,97,255,97,236,100,5,105,197,107,145,117,227,119,169,127,100,130,143,133,251,135,99,136,188,138,112,139,171,145,140,78,229,78,10,79,221,249,222,249,55,89,232,89,223,249,242,93,27,95,91,95,33,96,224,249,225,249,226,249,227,249,62,114,229,115,228,249,112,117,205,117,229,249,251,121,230,249,12,128,51,128,132,128,225,130,81,131,231,249,232,249,189,140,179,140,135,144,233,249,234,249,244,152,12,153,235,249,236,249,55,112,202,118,202,127,204,127,252,127,26,139,186,78,193,78,3,82,112,83,237,249,189,84,224,86,251,89,197,91,21,95,205,95,110,110,238,249,239,249,106,125,53,131,240,249,147,134,141,138,241,249,109,151,119,151,242,249,243,249,0,78,90,79,126,79,249,88,229,101,162,110,56,144,176,147,185,153,251,78,236,88,138,89,217,89,65,96,244,249,245,249,20,122,246,249,79,131,195,140,101,81,68,83,247,249,248,249,249,249,205,78,105,82,85,91,191,130,212,78,58,82,168,84,201,89,255,89,80,91,87,91,92,91,99,96,72,97,203,110,153,112,110,113,134,115,247,116,181,117,193,120,43,125,5,128,234,129,40,131,23,133,201,133,238,138,199,140,204,150,92,79,250,82,188,86,171,101,40,102,124,112,184,112,53,114,189,125,141,130,76,145,192,150,114,157,113,91,231,104,152,107,122,111,222,118,145,92,171,102,91,111,180,123,42,124,54,136,220,150,8,78,215,78,32,83,52,88,187,88,239,88,108,89,7,92,51,94,132,94,53,95,140,99,178,102,86,103,31,106,163,106,12,107,63,111,70,114,250,249,80,115,139,116,224,122,167,124,120,129,223,129,231,129,138,131,108,132,35,133,148,133,207,133,221,136,19,141,172,145,119,149,156,150,141,81,201,84,40,87,176,91,77,98,80,103,61,104,147,104,61,110,211,110,125,112,33,126,193,136,161,140,9,143,75,159,78,159,45,114,143,123,205,138,26,147,71,79,78,79,50,81,128,84,208,89,149,94,181,98,117,103,110,105,23,106,174,108,26,110,217,114,42,115,189,117,184,123,53,125,231,130,249,131,87,132,247,133,91,138,175,140,135,142,25,144,184,144,206,150,95,159,227,82,10,84,225,90,194,91,88,100,117,101,244,110,196,114,251,249,132,118,77,122,27,123,77,124,62,126,223,127,123,131,43,139,202,140,100,141,225,141,95,142,234,143,249,143,105,144,209,147,67,79,122,79,179,80,104,81,120,81,77,82,106,82,97,88,124,88,96,89,8,92,85,92,219,94,155,96,48,98,19,104,191,107,8,108,177,111,78,113,32,116,48,117,56,117,81,117,114,118,76,123,139,123,173,123,198,123,143,126,110,138,62,143,73,143,63,146,147,146,34,147,43,148,251,150,90,152,107,152,30,153,7,82,42,98,152,98,89,109,100,118,202,122,192,123,118,125,96,83,190,92,151,94,56,111,185,112,152,124,17,151,142,155,222,158,165,99,122,100,118,135,1,78,149,78,173,78,92,80,117,80,72,84,195,89,154,91,64,94,173,94,247,94,129,95,197,96,58,99,63,101,116,101,204,101,118,102,120,102,254,103,104,105,137,106,99,107,64,108,192,109,232,109,31,110,94,110,30,112,161,112,142,115,253,115,58,117,91,119,135,120,142,121,11,122,125,122,190,124,142,125,71,130,2,138,234,138,158,140,45,145,74,145,216,145,102,146,204,146,32,147,6,151,86,151,92,151,2,152,14,159,54,82,145,82,124,85,36,88,29,94,31,95,140,96,208,99,175,104,223,111,109,121,44,123,205,129,186,133,253,136,248,138,68,142,141,145,100,150,155,150,61,151,76,152,74,159,206,79,70,81,203,81,169,82,50,86,20,95,107,95,170,99,205,100,233,101,65,102,250,102,249,102,29,103,157,104,215,104,253,105,21,111,110,111,103,113,229,113,42,114,170,116,58,119,86,121,90,121,223,121,32,122,149,122,151,124,223,124,68,125,112,126,135,128,251,133,164,134,84,138,191,138,153,141,129,142,32,144,109,144,227,145,59,150,213,150,229,156,207,101,7,124,179,141,195,147,88,91,10,92,82,83,217,98,29,115,39,80,151,91,158,95,176,96,107,97,213,104,217,109,46,116,46,122,66,125,156,125,49,126,107,129,42,142,53,142,126,147,24,148,80,79,80,87,230,93,167,94,43,99,106,127,59,78,79,79,143,79,90,80,221,89,196,128,106,84,104,84,254,85,79,89,153,91,222,93,218,94,93,102,49,103,241,103,42,104,232,108,50,109,74,110,141,111,183,112,224,115,135,117,76,124,2,125,44,125,162,125,31,130,219,134,59,138,133,138,112,141,138,142,51,143,49,144,78,145,82,145,68,148,208,153,249,122,165,124,202,79,1,81,198,81,200,87,239,91,251,92,89,102,61,106,90,109,150,110,236,111,12,113,111,117,227,122,34,136,33,144,117,144,203,150,255,153,1,131,45,78,242,78,70,136,205,145,125,83,219,106,107,105,65,108,122,132,158,88,142,97,254,102,239,98,221,112,17,117,199,117,82,126,184,132,73,139,8,141,75,78,234,83,171,84,48,87,64,87,215,95,1,99,7,99,111,100,47,101,232,101,122,102,157,103,179,103,98,107,96,108,154,108,44,111,229,119,37,120,73,121,87,121,25,125,162,128,2,129,243,129,157,130,183,130,24,135,140,138,252,249,4,141,190,141,114,144,244,118,25,122,55,122,84,126,119,128,7,85,212,85,117,88,47,99,34,100,73,102,75,102,109,104,155,105,132,107,37,109,177,110,205,115,104,116,161,116,91,117,185,117,225,118,30,119,139,119,230,121,9,126,29,126,251,129,47,133,151,136,58,138,209,140,235,142,176,143,50,144,173,147,99,150,115,150,7,151,132,79,241,83,234,89,201,90,25,94,78,104,198,116,190,117,233,121,146,122,163,129,237,134,234,140,204,141,237,143,159,101,21,103,253,249,247,87,87,111,221,125,47,143,246,147,198,150,181,95,242,97,132,111,20,78,152,79,31,80,201,83,223,85,111,93,238,93,33,107,100,107,203,120,154,123,254,249,73,142,202,142,110,144,73,99,62,100,64,119,132,122,47,147,127,148,106,159,176,100,175,111,230,113,168,116,218,116,196,122,18,124,130,126,178,124,152,126,154,139,10,141,125,148,16,153,76,153,57,82,223,91,230,100,45,103,46,125,237,80,195,83,121,88,88,97,89,97,250,97,172,101,217,122,146,139,150,139,9,80,33,80,117,82,49,85,60,90,224,94,112,95,52,97,94,101,12,102,54,102,162,102,205,105,196,110,50,111,22,115,33,118,147,122,57,129,89,130,214,131,188,132,181,80,240,87,192,91,232,91,105,95,161,99,38,120,181,125,220,131,33,133,199,145,245,145,138,81,245,103,86,123,172,140,196,81,187,89,189,96,85,134,28,80,255,249,84,82,58,92,125,97,26,98,211,98,242,100,165,101,204,110,32,118,10,129,96,142,95,150,187,150,223,78,67,83,152,85,41,89,221,93,197,100,201,108,250,109,148,115,127,122,27,130,166,133,228,140,16,142,119,144,231,145,225,149,33,150,198,151,248,81,242,84,134,85,185,95,164,100,136,111,180,125,31,143,77,143,53,148,201,80,22,92,190,108,251,109,27,117,187,119,61,124,100,124,121,138,194,138,30,88,190,89,22,94,119,99,82,114,138,117,107,119,220,138,188,140,18,143,243,94,116,102,248,109,125,128,193,131,203,138,81,151,214,155,0,250,67,82,255,102,149,109,239,110,224,125,230,138,46,144,94,144,212,154,29,82,127,82,232,84,148,97,132,98,219,98,162,104,18,105,90,105,53,106,146,112,38,113,93,120,1,121,14,121,210,121,13,122,150,128,120,130,213,130,73,131,73,133,130,140,133,141,98,145,139,145,174,145,195,79,209,86,237,113,215,119,0,135,248,137,248,91,214,95,81,103,168,144,226,83,90,88,245,91,164,96,129,97,96,100,61,126,112,128,37,133,131,146,174,100,172,80,20,93,0,103,156,88,189,98,168,99,14,105,120,105,30,106,107,110,186,118,203,121,187,130,41,132,207,138,168,141,253,143,18,145,75,145,156,145,16,147,24,147,154,147,219,150,54,154,13,156,17,78,92,117,93,121,250,122,81,123,201,123,46,126,196,132,89,142,116,142,248,142,16,144,37,102,63,105,67,116,250,81,46,103,220,158,69,81,224,95,150,108,242,135,93,136,119,136,180,96,181,129,3,132,5,141,214,83,57,84,52,86,54,90,49,92,138,112,224,127,90,128,6,129,237,129,163,141,137,145,95,154,242,157,116,80,196,78,160,83,251,96,44,110,100,92,136,79,36,80,228,85,217,92,95,94,101,96,148,104,187,108,196,109,190,113,212,117,244,117,97,118,26,122,73,122,199,125,251,125,110,127,244,129,169,134,28,143,201,150,179,153,82,159,71,82,197,82,237,152,170,137,3,78,210,103,6,111,181,79,226,91,149,103,136,108,120,109,27,116,39,120,221,145,124,147,196,135,228,121,49,122,235,95,214,78,164,84,62,85,174,88,165,89,240,96,83,98,214,98,54,103,85,105,53,130,64,150,177,153,221,153,44,80,83,83,68,85,124,87,1,250,88,98,2,250,226,100,107,102,221,103,193,111,239,111,34,116,56,116,23,138,56,148,81,84,6,86,102,87,72,95,154,97,78,107,88,112,173,112,187,125,149,138,106,89,43,129,162,99,8,119,61,128,170,140,84,88,45,100,187,105,149,91,17,94,111,110,3,250,105,133,76,81,240,83,42,89,32,96,75,97,134,107,112,108,240,108,30,123,206,128,212,130,198,141,176,144,177,152,4,250,199,100,164,111,145,100,4,101,78,81,16,84,31,87,14,138,95,97,118,104,5,250,219,117,82,123,113,125,26,144,6,88,204,105,127,129,42,137,0,144,57,152,120,80,87,89,172,89,149,98,15,144,42,155,93,97,121,114,214,149,97,87,70,90,244,93,138,98,173,100,250,100,119,103,226,108,62,109,44,114,54,116,52,120,119,127,173,130,219,141,23,152,36,82,66,87,127,103,72,114,227,116,169,140,166,143,17,146,42,150,107,81,237,83,76,99,105,79,4,85,150,96,87,101,155,108,127,109,76,114,253,114,23,122,135,137,157,140,109,95,142,111,249,112,168,129,14,97,191,79,79,80,65,98,71,114,199,123,232,125,233,127,77,144,173,151,25,154,182,140,106,87,115,94,176,103,13,132,85,138,32,84,22,91,99,94,226,94,10,95,131,101,186,128,61,133,137,149,91,150,72,79,5,83,13,83,15,83,134,84,250,84,3,87,3,94,22,96,155,98,177,98,85,99,6,250,225,108,102,109,177,117,50,120,222,128,47,129,222,130,97,132,178,132,141,136,18,137,11,144,234,146,253,152,145,155,69,94,180,102,221,102,17,112,6,114,7,250,245,79,125,82,106,95,83,97,83,103,25,106,2,111,226,116,104,121,104,136,121,140,199,152,196,152,67,154,193,84,31,122,83,105,247,138,74,140,168,152,174,153,124,95,171,98,178,117,174,118,171,136,127,144,66,150,57,83,60,95,197,95,204,108,204,115,98,117,139,117,70,123,254,130,157,153,79,78,60,144,11,78,85,79,166,83,15,89,200,94,48,102,179,108,85,116,119,131,102,135,192,140,80,144,30,151,21,156,209,88,120,91,80,134,20,139,180,157,210,91,104,96,141,96,241,101,87,108,34,111,163,111,26,112,85,127,240,127,145,149,146,149,80,150,211,151,114,82,68,143,253,81,43,84,184,84,99,85,138,85,187,106,181,109,216,125,102,130,156,146,119,150,121,158,8,84,200,84,210,118,228,134,164,149,212,149,92,150,162,78,9,79,238,89,230,90,247,93,82,96,151,98,109,103,65,104,134,108,47,110,56,127,155,128,42,130,8,250,9,250,5,152,165,78,85,80,179,84,147,87,90,89,105,91,179,91,200,97,119,105,119,109,35,112,249,135,227,137,114,138,231,138,130,144,237,153,184,154,190,82,56,104,22,80,120,94,79,103,71,131,76,136,171,78,17,84,174,86,230,115,21,145,255,151,9,153,87,153,153,153,83,86,159,88,91,134,49,138,178,97,246,106,123,115,210,142,71,107,170,150,87,154,85,89,0,114,107,141,105,151,212,79,244,92,38,95,248,97,91,102,235,108,171,112,132,115,185,115,254,115,41,119,77,119,67,125,98,125,35,126,55,130,82,136,10,250,226,140,73,146,111,152,81,91,116,122,64,136,1,152,204,90,224,79,84,83,62,89,253,92,62,99,121,109,249,114,5,129,7,129,162,131,207,146,48,152,168,78,68,81,17,82,139,87,98,95,194,108,206,110,5,112,80,112,175,112,146,113,233,115,105,116,74,131,162,135,97,136,8,144,162,144,163,147,168,153,110,81,87,95,224,96,103,97,179,102,89,133,74,142,175,145,139,151,78,78,146,78,124,84,213,88,250,88,125,89,181,92,39,95,54,98,72,98,10,102,103,102,235,107,105,109,207,109,86,110,248,110,148,111,224,111,233,111,93,112,208,114,37,116,90,116,224,116,147,118,92,121,202,124,30,126,225,128,166,130,107,132,191,132,78,134,95,134,116,135,119,139,106,140,172,147,0,152,101,152,209,96,22,98,119,145,90,90,15,102,247,109,62,110,63,116,66,155,253,95,218,96,15,123,196,84,24,95,94,108,211,108,42,109,216,112,5,125,121,134,12,138,59,157,22,83,140,84,5,91,58,106,107,112,117,117,141,121,190,121,177,130,239,131,113,138,65,139,168,140,116,151,11,250,244,100,43,101,186,120,187,120,107,122,56,78,154,85,80,89,166,91,123,94,163,96,219,99,97,107,101,102,83,104,25,110,101,113,176,116,8,125,132,144,105,154,37,156,59,109,209,110,62,115,65,140,202,149,240,81,76,94,168,95,77,96,246,96,48,97,76,97,67,102,68,102,165,105,193,108,95,110,201,110,98,111,76,113,156,116,135,118,193,123,39,124,82,131,87,135,81,144,141,150,195,158,47,83,222,86,251,94,138,95,98,96,148,96,247,97,102,102,3,103,156,106,238,109,174,111,112,112,106,115,106,126,190,129,52,131,212,134,168,138,196,140,131,82,114,115,150,91,107,106,4,148,238,84,134,86,93,91,72,101,133,101,201,102,159,104,141,109,198,109,59,114,180,128,117,145,77,154,175,79,25,80,154,83,14,84,60,84,137,85,197,85,63,94,140,95,61,103,102,113,221,115,5,144,219,82,243,82,100,88,206,88,4,113,143,113,251,113,176,133,19,138,136,102,168,133,167,85,132,102,74,113,49,132,73,83,153,85,193,107,89,95,189,95,238,99,137,102,71,113,241,138,29,143,190,158,17,79,58,100,203,112,102,117,103,134,100,96,78,139,248,157,71,81,246,81,8,83,54,109,248,128,209,158,21,102,35,107,152,112,213,117,3,84,121,92,7,125,22,138,32,107,61,107,70,107,56,84,112,96,61,109,213,127,8,130,214,80,222,81,156,85,107,86,205,86,236,89,9,91,12,94,153,97,152,97,49,98,94,102,230,102,153,113,185,113,186,113,167,114,167,121,0,122,178,127,112,138,0,0,0,0,0,0,1,0,160,0,167,0,168,0,169,0,175,0,176,0,178,0,183,0,184,0,198,0,215,0,216,0,230,0,247,0,248,0,0,1,1,1,2,1,3,1,4,1,5,1,6,1,7,1,8,1,9,1,10,1,11,1,12,1,13,1,14,1,15,1,16,1,17,1,18,1,19,1,22,1,23,1,24,1,25,1,26,1,27,1,28,1,29,1,30,1,31,1,32,1,33,1,34,1,35,1,36,1,37,1,38,1,39,1,40,1,41,1,42,1,43,1,46,1,47,1,48,1,49,1,52,1,53,1,54,1,55,1,56,1,57,1,58,1,59,1,60,1,61,1,62,1,65,1,66,1,67,1,68,1,69,1,70,1,71,1,72,1,74,1,75,1,76,1,77,1,80,1,81,1,82,1,83,1,84,1,85,1,86,1,87,1,88,1,89,1,90,1,91,1,92,1,93,1,94,1,95,1,96,1,97,1,98,1,99,1,100,1,101,1,102,1,103,1,104,1,105,1,106,1,107,1,108,1,109,1,110,1,111,1,112,1,113,1,114,1,115,1,116,1,117,1,118,1,119,1,120,1,121,1,122,1,123,1,124,1,125,1,126,1,146,1,160,1,161,1,175,1,176,1,24,2,25,2,26,2,27,2,198,2,199,2,216,2,217,2,219,2,220,2,221,2,0,3,1,3,3,3,9,3,35,3,122,3,132,3,133,3,134,3,136,3,137,3,138,3,140,3,142,3,143,3,144,3,145,3,146,3,147,3,148,3,149,3,150,3,151,3,152,3,153,3,154,3,155,3,156,3,157,3,158,3,159,3,160,3,161,3,163,3,164,3,165,3,166,3,167,3,168,3,169,3,170,3,171,3,172,3,173,3,174,3,175,3,176,3,177,3,178,3,179,3,180,3,181,3,182,3,183,3,184,3,185,3,186,3,187,3,188,3,189,3,190,3,191,3,192,3,193,3,194,3,195,3,196,3,197,3,198,3,199,3,200,3,201,3,202,3,203,3,204,3,205,3,206,3,1,4,2,4,3,4,4,4,5,4,6,4,7,4,8,4,9,4,10,4,11,4,12,4,14,4,15,4,16,4,17,4,18,4,19,4,20,4,21,4,22,4,23,4,24,4,25,4,26,4,27,4,28,4,29,4,30,4,31,4,32,4,33,4,34,4,35,4,36,4,37,4,38,4,39,4,40,4,41,4,42,4,43,4,44,4,45,4,46,4,47,4,48,4,49,4,50,4,51,4,52,4,53,4,54,4,55,4,56,4,57,4,58,4,59,4,60,4,61,4,62,4,63,4,64,4,65,4,66,4,67,4,68,4,69,4,70,4,71,4,72,4,73,4,74,4,75,4,76,4,77,4,78,4,79,4,81,4,82,4,83,4,84,4,85,4,86,4,87,4,88,4,89,4,90,4,91,4,92,4,94,4,95,4,144,4,145,4,176,5,177,5,178,5,179,5,180,5,181,5,182,5,183,5,184,5,185,5,187,5,188,5,189,5,190,5,191,5,192,5,193,5,194,5,195,5,208,5,209,5,210,5,211,5,212,5,213,5,214,5,215,5,216,5,217,5,218,5,219,5,220,5,221,5,222,5,223,5,224,5,225,5,226,5,227,5,228,5,229,5,230,5,231,5,232,5,233,5,234,5,240,5,241,5,242,5,243,5,244,5,12,6,27,6,31,6,33,6,34,6,35,6,36,6,37,6,38,6,39,6,40,6,41,6,42,6,43,6,44,6,45,6,46,6,47,6,48,6,49,6,50,6,51,6,52,6,53,6,54,6,55,6,56,6,57,6,58,6,64,6,65,6,66,6,67,6,68,6,69,6,70,6,71,6,72,6,73,6,74,6,75,6,76,6,77,6,78,6,79,6,80,6,81,6,82,6,121,6,126,6,134,6,136,6,145,6,152,6,169,6,175,6,186,6,190,6,193,6,210,6,1,14,2,14,3,14,4,14,5,14,6,14,7,14,8,14,9,14,10,14,11,14,12,14,13,14,14,14,15,14,16,14,17,14,18,14,19,14,20,14,21,14,22,14,23,14,24,14,25,14,26,14,27,14,28,14,29,14,30,14,31,14,32,14,33,14,34,14,35,14,36,14,37,14,38,14,39,14,40,14,41,14,42,14,43,14,44,14,45,14,46,14,47,14,48,14,49,14,50,14,51,14,52,14,53,14,54,14,55,14,56,14,57,14,58,14,63,14,64,14,65,14,66,14,67,14,68,14,69,14,70,14,71,14,72,14,73,14,74,14,75,14,76,14,77,14,78,14,79,14,80,14,81,14,82,14,83,14,84,14,85,14,86,14,87,14,88,14,89,14,90,14,91,14,2,30,3,30,10,30,11,30,30,30,31,30,64,30,65,30,86,30,87,30,96,30,97,30,106,30,107,30,128,30,129,30,130,30,131,30,132,30,133,30,242,30,243,30,12,32,13,32,14,32,15,32,19,32,20,32,21,32,23,32,24,32,25,32,26,32,28,32,29,32,30,32,32,32,33,32,34,32,38,32,48,32,57,32,58,32,170,32,171,32,172,32,175,32,22,33,34,33,25,34,26,34,72,34,100,34,101,34,32,35,33,35,0,37,2,37,12,37,16,37,20,37,24,37,28,37,36,37,44,37,52,37,60,37,80,37,81,37,82,37,83,37,84,37,85,37,86,37,87,37,88,37,89,37,90,37,91,37,92,37,93,37,94,37,95,37,96,37,97,37,98,37,99,37,100,37,101,37,102,37,103,37,104,37,105,37,106,37,107,37,108,37,128,37,132,37,136,37,140,37,144,37,145,37,146,37,147,37,160,37,0,0,2,0,0,192,3,0,0,192,4,0,0,192,5,0,0,192,6,0,0,192,7,0,0,192,8,0,0,192,9,0,0,192,10,0,0,192,11,0,0,192,12,0,0,192,13,0,0,192,14,0,0,192,15,0,0,192,16,0,0,192,17,0,0,192,18,0,0,192,19,0,0,192,20,0,0,192,21,0,0,192,22,0,0,192,23,0,0,192,24,0,0,192,25,0,0,192,26,0,0,192,27,0,0,192,28,0,0,192,29,0,0,192,30,0,0,192,31,0,0,192,0,0,0,179,1,0,0,195,2,0,0,195,3,0,0,195,4,0,0,195,5,0,0,195,6,0,0,195,7,0,0,195,8,0,0,195,9,0,0,195,10,0,0,195,11,0,0,195,12,0,0,195,13,0,0,211,14,0,0,195,15,0,0,195,0,0,12,187,1,0,12,195,2,0,12,195,3,0,12,195,4,0,12,211,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,0,1,2,3,4,5,6,7,8,9,255,255,255,255,255,255,255,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,255,255,255,255,255,255,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,0,0,0,0,0,0,0,0,1,2,4,7,3,6,5,0,0,0,0,0,0,0,0,105,110,102,105,110,105,116,121,0,0,0,0,0,0,0,0,110,97,110,0,0,0,0,0,95,112,137,0,255,9,47,15,10,0,0,0,100,0,0,0,232,3,0,0,16,39,0,0,160,134,1,0,64,66,15,0,128,150,152,0,0,225,245,5,17,0,10,0,17,17,17,0,0,0,0,5,0,0,0,0,0,0,9,0,0,0,0,11,0,0,0,0,0,0,0,0,17,0,15,10,17,17,17,3,10,7,0,1,19,9,11,11,0,0,9,6,11,0,0,11,0,6,17,0,0,0,17,17,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,11,0,0,0,0,0,0,0,0,17,0,10,10,17,17,17,0,10,0,0,2,0,9,11,0,0,0,9,0,11,0,0,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,0,0,0,0,0,0,0,0,0,0,0,12,0,0,0,0,12,0,0,0,0,9,12,0,0,0,0,0,12,0,0,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,0,0,0,0,0,0,0,0,0,0,0,13,0,0,0,4,13,0,0,0,0,9,14,0,0,0,0,0,14,0,0,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,15,0,0,0,0,15,0,0,0,0,9,16,0,0,0,0,0,16,0,0,16,0,0,18,0,0,0,18,18,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,0,0,0,18,18,18,0,0,0,0,0,0,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,11,0,0,0,0,0,0,0,0,0,0,0,10,0,0,0,0,10,0,0,0,0,9,11,0,0,0,0,0,11,0,0,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,0,0,0,0,0,0,0,0,0,0,0,12,0,0,0,0,12,0,0,0,0,9,12,0,0,0,0,0,12,0,0,12,0,0,45,43,32,32,32,48,88,48,120,0,0,0,0,0,0,0,40,110,117,108,108,41,0,0,45,48,88,43,48,88,32,48,88,45,48,120,43,48,120,32,48,120,0,0,0,0,0,0,105,110,102,0,0,0,0,0,73,78,70,0,0,0,0,0,110,97,110,0,0,0,0,0,78,65,78,0,0,0,0,0,48,49,50,51,52,53,54,55,56,57,65,66,67,68,69,70,46,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,194,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0],"i8",ALLOC_NONE,Runtime.GLOBAL_BASE+322788);var tempDoublePtr=Runtime.alignMemory(allocate(12,"i8",ALLOC_STATIC),8);assert(tempDoublePtr%8==0),Module._i64Subtract=_i64Subtract,Module._bitshift64Ashr=_bitshift64Ashr;var ERRNO_CODES={EPERM:1,ENOENT:2,ESRCH:3,EINTR:4,EIO:5,ENXIO:6,E2BIG:7,ENOEXEC:8,EBADF:9,ECHILD:10,EAGAIN:11,EWOULDBLOCK:11,ENOMEM:12,EACCES:13,EFAULT:14,ENOTBLK:15,EBUSY:16,EEXIST:17,EXDEV:18,ENODEV:19,ENOTDIR:20,EISDIR:21,EINVAL:22,ENFILE:23,EMFILE:24,ENOTTY:25,ETXTBSY:26,EFBIG:27,ENOSPC:28,ESPIPE:29,EROFS:30,EMLINK:31,EPIPE:32,EDOM:33,ERANGE:34,ENOMSG:42,EIDRM:43,ECHRNG:44,EL2NSYNC:45,EL3HLT:46,EL3RST:47,ELNRNG:48,EUNATCH:49,ENOCSI:50,EL2HLT:51,EDEADLK:35,ENOLCK:37,EBADE:52,EBADR:53,EXFULL:54,ENOANO:55,EBADRQC:56,EBADSLT:57,EDEADLOCK:35,EBFONT:59,ENOSTR:60,ENODATA:61,ETIME:62,ENOSR:63,ENONET:64,ENOPKG:65,EREMOTE:66,ENOLINK:67,EADV:68,ESRMNT:69,ECOMM:70,EPROTO:71,EMULTIHOP:72,EDOTDOT:73,EBADMSG:74,ENOTUNIQ:76,EBADFD:77,EREMCHG:78,ELIBACC:79,ELIBBAD:80,ELIBSCN:81,ELIBMAX:82,ELIBEXEC:83,ENOSYS:38,ENOTEMPTY:39,ENAMETOOLONG:36,ELOOP:40,EOPNOTSUPP:95,EPFNOSUPPORT:96,ECONNRESET:104,ENOBUFS:105,EAFNOSUPPORT:97,EPROTOTYPE:91,ENOTSOCK:88,ENOPROTOOPT:92,ESHUTDOWN:108,ECONNREFUSED:111,EADDRINUSE:98,ECONNABORTED:103,ENETUNREACH:101,ENETDOWN:100,ETIMEDOUT:110,EHOSTDOWN:112,EHOSTUNREACH:113,EINPROGRESS:115,EALREADY:114,EDESTADDRREQ:89,EMSGSIZE:90,EPROTONOSUPPORT:93,ESOCKTNOSUPPORT:94,EADDRNOTAVAIL:99,ENETRESET:102,EISCONN:106,ENOTCONN:107,ETOOMANYREFS:109,EUSERS:87,EDQUOT:122,ESTALE:116,ENOTSUP:95,ENOMEDIUM:123,EILSEQ:84,EOVERFLOW:75,ECANCELED:125,ENOTRECOVERABLE:131,EOWNERDEAD:130,ESTRPIPE:86},ERRNO_MESSAGES={0:"Success",1:"Not super-user",2:"No such file or directory",3:"No such process",4:"Interrupted system call",5:"I/O error",6:"No such device or address",7:"Arg list too long",8:"Exec format error",9:"Bad file number",10:"No children",11:"No more processes",12:"Not enough core",13:"Permission denied",14:"Bad address",15:"Block device required",16:"Mount device busy",17:"File exists",18:"Cross-device link",19:"No such device",20:"Not a directory",21:"Is a directory",22:"Invalid argument",23:"Too many open files in system",24:"Too many open files",25:"Not a typewriter",26:"Text file busy",27:"File too large",28:"No space left on device",29:"Illegal seek",30:"Read only file system",31:"Too many links",32:"Broken pipe",33:"Math arg out of domain of func",34:"Math result not representable",35:"File locking deadlock error",36:"File or path name too long",37:"No record locks available",38:"Function not implemented",39:"Directory not empty",40:"Too many symbolic links",42:"No message of desired type",43:"Identifier removed",44:"Channel number out of range",45:"Level 2 not synchronized",46:"Level 3 halted",47:"Level 3 reset",48:"Link number out of range",49:"Protocol driver not attached",50:"No CSI structure available",51:"Level 2 halted",52:"Invalid exchange",53:"Invalid request descriptor",54:"Exchange full",55:"No anode",56:"Invalid request code",57:"Invalid slot",59:"Bad font file fmt",60:"Device not a stream",61:"No data (for no delay io)",62:"Timer expired",63:"Out of streams resources",64:"Machine is not on the network",65:"Package not installed",66:"The object is remote",67:"The link has been severed",68:"Advertise error",69:"Srmount error",70:"Communication error on send",71:"Protocol error",72:"Multihop attempted",73:"Cross mount point (not really error)",74:"Trying to read unreadable message",75:"Value too large for defined data type",76:"Given log. name not unique",77:"f.d. invalid for this operation",78:"Remote address changed",79:"Can   access a needed shared lib",80:"Accessing a corrupted shared lib",81:".lib section in a.out corrupted",82:"Attempting to link in too many libs",83:"Attempting to exec a shared library",84:"Illegal byte sequence",86:"Streams pipe error",87:"Too many users",88:"Socket operation on non-socket",89:"Destination address required",90:"Message too long",91:"Protocol wrong type for socket",92:"Protocol not available",93:"Unknown protocol",94:"Socket type not supported",95:"Not supported",96:"Protocol family not supported",97:"Address family not supported by protocol family",98:"Address already in use",99:"Address not available",100:"Network interface is not configured",101:"Network is unreachable",102:"Connection reset by network",103:"Connection aborted",104:"Connection reset by peer",105:"No buffer space available",106:"Socket is already connected",107:"Socket is not connected",108:"Can't send after socket shutdown",109:"Too many references",110:"Connection timed out",111:"Connection refused",112:"Host is down",113:"Host is unreachable",114:"Socket already connected",115:"Connection already in progress",116:"Stale file handle",122:"Quota exceeded",123:"No medium (in tape drive)",125:"Operation canceled",130:"Previous owner died",131:"State not recoverable"},___errno_state=0,PATH={splitPath:function(e){var i=/^(\/?|)([\s\S]*?)((?:\.{1,2}|[^\/]+?|)(\.[^.\/]*|))(?:[\/]*)$/;return i.exec(e).slice(1)},normalizeArray:function(e,i){for(var r=0,n=e.length-1;n>=0;n--){var f=e[n];"."===f?e.splice(n,1):".."===f?(e.splice(n,1),r++):r&&(e.splice(n,1),r--)}if(i)for(;r--;r)e.unshift("..");return e},normalize:function(e){var i="/"===e.charAt(0),r="/"===e.substr(-1);return e=PATH.normalizeArray(e.split("/").filter(function(e){return!!e}),!i).join("/"),e||i||(e="."),e&&r&&(e+="/"),(i?"/":"")+e},dirname:function(e){var i=PATH.splitPath(e),r=i[0],n=i[1];return r||n?(n&&(n=n.substr(0,n.length-1)),r+n):"."},basename:function(e){if("/"===e)return"/";var i=e.lastIndexOf("/");return i===-1?e:e.substr(i+1)},extname:function(e){return PATH.splitPath(e)[3]},join:function(){var e=Array.prototype.slice.call(arguments,0);return PATH.normalize(e.join("/"))},join2:function(e,i){return PATH.normalize(e+"/"+i)},resolve:function(){for(var e="",i=!1,r=arguments.length-1;r>=-1&&!i;r--){var n=r>=0?arguments[r]:FS.cwd();if("string"!=typeof n)throw new TypeError("Arguments to path.resolve must be strings");if(!n)return"";e=n+"/"+e,i="/"===n.charAt(0)}return e=PATH.normalizeArray(e.split("/").filter(function(e){return!!e}),!i).join("/"),(i?"/":"")+e||"."},relative:function(e,i){function r(e){for(var i=0;i<e.length&&""===e[i];i++);for(var r=e.length-1;r>=0&&""===e[r];r--);return i>r?[]:e.slice(i,r-i+1)}e=PATH.resolve(e).substr(1),i=PATH.resolve(i).substr(1);for(var n=r(e.split("/")),f=r(i.split("/")),t=Math.min(n.length,f.length),u=t,a=0;a<t;a++)if(n[a]!==f[a]){u=a;break}for(var o=[],a=u;a<n.length;a++)o.push("..");return o=o.concat(f.slice(u)),o.join("/")}},TTY={ttys:[],init:function(){},shutdown:function(){},register:function(e,i){TTY.ttys[e]={input:[],output:[],ops:i},FS.registerDevice(e,TTY.stream_ops)},stream_ops:{open:function(e){var i=TTY.ttys[e.node.rdev];if(!i)throw new FS.ErrnoError(ERRNO_CODES.ENODEV);e.tty=i,e.seekable=!1},close:function(e){e.tty.ops.flush(e.tty)},flush:function(e){e.tty.ops.flush(e.tty)},read:function(e,i,r,n,f){if(!e.tty||!e.tty.ops.get_char)throw new FS.ErrnoError(ERRNO_CODES.ENXIO);for(var t=0,u=0;u<n;u++){var a;try{a=e.tty.ops.get_char(e.tty)}catch(e){throw new FS.ErrnoError(ERRNO_CODES.EIO)}if(void 0===a&&0===t)throw new FS.ErrnoError(ERRNO_CODES.EAGAIN);if(null===a||void 0===a)break;t++,i[r+u]=a}return t&&(e.node.timestamp=Date.now()),t},write:function(e,i,r,n,f){if(!e.tty||!e.tty.ops.put_char)throw new FS.ErrnoError(ERRNO_CODES.ENXIO);for(var t=0;t<n;t++)try{e.tty.ops.put_char(e.tty,i[r+t])}catch(e){throw new FS.ErrnoError(ERRNO_CODES.EIO)}return n&&(e.node.timestamp=Date.now()),t}},default_tty_ops:{get_char:function(e){if(!e.input.length){var i=null;if("undefined"!=typeof window&&"function"==typeof window.prompt?(i=window.prompt("Input: "),null!==i&&(i+="\n")):"function"==typeof readline&&(i=readline(),null!==i&&(i+="\n")),!i)return null;e.input=intArrayFromString(i,!0)}return e.input.shift()},flush:function(e){e.output&&e.output.length>0&&(Module.print(e.output.join("")),e.output=[])},put_char:function(e,i){null===i||10===i?(Module.print(e.output.join("")),e.output=[]):e.output.push(TTY.utf8.processCChar(i))}},default_tty1_ops:{put_char:function(e,i){null===i||10===i?(Module.printErr(e.output.join("")),e.output=[]):e.output.push(TTY.utf8.processCChar(i))},flush:function(e){e.output&&e.output.length>0&&(Module.printErr(e.output.join("")),e.output=[])}}},MEMFS={ops_table:null,mount:function(e){return MEMFS.createNode(null,"/",16895,0)},createNode:function(e,i,r,n){if(FS.isBlkdev(r)||FS.isFIFO(r))throw new FS.ErrnoError(ERRNO_CODES.EPERM);MEMFS.ops_table||(MEMFS.ops_table={dir:{node:{getattr:MEMFS.node_ops.getattr,setattr:MEMFS.node_ops.setattr,lookup:MEMFS.node_ops.lookup,mknod:MEMFS.node_ops.mknod,rename:MEMFS.node_ops.rename,unlink:MEMFS.node_ops.unlink,rmdir:MEMFS.node_ops.rmdir,readdir:MEMFS.node_ops.readdir,symlink:MEMFS.node_ops.symlink},stream:{llseek:MEMFS.stream_ops.llseek}},file:{node:{getattr:MEMFS.node_ops.getattr,setattr:MEMFS.node_ops.setattr},stream:{llseek:MEMFS.stream_ops.llseek,read:MEMFS.stream_ops.read,write:MEMFS.stream_ops.write,allocate:MEMFS.stream_ops.allocate,mmap:MEMFS.stream_ops.mmap}},link:{node:{getattr:MEMFS.node_ops.getattr,setattr:MEMFS.node_ops.setattr,readlink:MEMFS.node_ops.readlink},stream:{}},chrdev:{node:{getattr:MEMFS.node_ops.getattr,setattr:MEMFS.node_ops.setattr},stream:FS.chrdev_stream_ops}});var f=FS.createNode(e,i,r,n);return FS.isDir(f.mode)?(f.node_ops=MEMFS.ops_table.dir.node,f.stream_ops=MEMFS.ops_table.dir.stream,f.contents={}):FS.isFile(f.mode)?(f.node_ops=MEMFS.ops_table.file.node,f.stream_ops=MEMFS.ops_table.file.stream,f.usedBytes=0,f.contents=null):FS.isLink(f.mode)?(f.node_ops=MEMFS.ops_table.link.node,f.stream_ops=MEMFS.ops_table.link.stream):FS.isChrdev(f.mode)&&(f.node_ops=MEMFS.ops_table.chrdev.node,
	f.stream_ops=MEMFS.ops_table.chrdev.stream),f.timestamp=Date.now(),e&&(e.contents[i]=f),f},getFileDataAsRegularArray:function(e){if(e.contents&&e.contents.subarray){for(var i=[],r=0;r<e.usedBytes;++r)i.push(e.contents[r]);return i}return e.contents},getFileDataAsTypedArray:function(e){return e.contents?e.contents.subarray?e.contents.subarray(0,e.usedBytes):new Uint8Array(e.contents):new Uint8Array},expandFileStorage:function(e,i){if(e.contents&&e.contents.subarray&&i>e.contents.length&&(e.contents=MEMFS.getFileDataAsRegularArray(e),e.usedBytes=e.contents.length),!e.contents||e.contents.subarray){var r=e.contents?e.contents.buffer.byteLength:0;if(r>=i)return;var n=1048576;i=Math.max(i,r*(r<n?2:1.125)|0),0!=r&&(i=Math.max(i,256));var f=e.contents;return e.contents=new Uint8Array(i),void(e.usedBytes>0&&e.contents.set(f.subarray(0,e.usedBytes),0))}for(!e.contents&&i>0&&(e.contents=[]);e.contents.length<i;)e.contents.push(0)},resizeFileStorage:function(e,i){if(e.usedBytes!=i){if(0==i)return e.contents=null,void(e.usedBytes=0);if(!e.contents||e.contents.subarray){var r=e.contents;return e.contents=new Uint8Array(new ArrayBuffer(i)),r&&e.contents.set(r.subarray(0,Math.min(i,e.usedBytes))),void(e.usedBytes=i)}if(e.contents||(e.contents=[]),e.contents.length>i)e.contents.length=i;else for(;e.contents.length<i;)e.contents.push(0);e.usedBytes=i}},node_ops:{getattr:function(e){var i={};return i.dev=FS.isChrdev(e.mode)?e.id:1,i.ino=e.id,i.mode=e.mode,i.nlink=1,i.uid=0,i.gid=0,i.rdev=e.rdev,FS.isDir(e.mode)?i.size=4096:FS.isFile(e.mode)?i.size=e.usedBytes:FS.isLink(e.mode)?i.size=e.link.length:i.size=0,i.atime=new Date(e.timestamp),i.mtime=new Date(e.timestamp),i.ctime=new Date(e.timestamp),i.blksize=4096,i.blocks=Math.ceil(i.size/i.blksize),i},setattr:function(e,i){void 0!==i.mode&&(e.mode=i.mode),void 0!==i.timestamp&&(e.timestamp=i.timestamp),void 0!==i.size&&MEMFS.resizeFileStorage(e,i.size)},lookup:function(e,i){throw FS.genericErrors[ERRNO_CODES.ENOENT]},mknod:function(e,i,r,n){return MEMFS.createNode(e,i,r,n)},rename:function(e,i,r){if(FS.isDir(e.mode)){var n;try{n=FS.lookupNode(i,r)}catch(e){}if(n)for(var f in n.contents)throw new FS.ErrnoError(ERRNO_CODES.ENOTEMPTY)}delete e.parent.contents[e.name],e.name=r,i.contents[r]=e,e.parent=i},unlink:function(e,i){delete e.contents[i]},rmdir:function(e,i){var r=FS.lookupNode(e,i);for(var n in r.contents)throw new FS.ErrnoError(ERRNO_CODES.ENOTEMPTY);delete e.contents[i]},readdir:function(e){var i=[".",".."];for(var r in e.contents)e.contents.hasOwnProperty(r)&&i.push(r);return i},symlink:function(e,i,r){var n=MEMFS.createNode(e,i,41471,0);return n.link=r,n},readlink:function(e){if(!FS.isLink(e.mode))throw new FS.ErrnoError(ERRNO_CODES.EINVAL);return e.link}},stream_ops:{read:function(e,i,r,n,f){var t=e.node.contents;if(f>=e.node.usedBytes)return 0;var u=Math.min(e.node.usedBytes-f,n);if(assert(u>=0),u>8&&t.subarray)i.set(t.subarray(f,f+u),r);else for(var a=0;a<u;a++)i[r+a]=t[f+a];return u},write:function(e,i,r,n,f,t){if(!n)return 0;var u=e.node;if(u.timestamp=Date.now(),i.subarray&&(!u.contents||u.contents.subarray)){if(t)return u.contents=i.subarray(r,r+n),u.usedBytes=n,n;if(0===u.usedBytes&&0===f)return u.contents=new Uint8Array(i.subarray(r,r+n)),u.usedBytes=n,n;if(f+n<=u.usedBytes)return u.contents.set(i.subarray(r,r+n),f),n}if(MEMFS.expandFileStorage(u,f+n),u.contents.subarray&&i.subarray)u.contents.set(i.subarray(r,r+n),f);else for(var a=0;a<n;a++)u.contents[f+a]=i[r+a];return u.usedBytes=Math.max(u.usedBytes,f+n),n},llseek:function(e,i,r){var n=i;if(1===r?n+=e.position:2===r&&FS.isFile(e.node.mode)&&(n+=e.node.usedBytes),n<0)throw new FS.ErrnoError(ERRNO_CODES.EINVAL);return n},allocate:function(e,i,r){MEMFS.expandFileStorage(e.node,i+r),e.node.usedBytes=Math.max(e.node.usedBytes,i+r)},mmap:function(e,i,r,n,f,t,u){if(!FS.isFile(e.node.mode))throw new FS.ErrnoError(ERRNO_CODES.ENODEV);var a,o,c=e.node.contents;if(2&u||c.buffer!==i&&c.buffer!==i.buffer){if((f>0||f+n<e.node.usedBytes)&&(c=c.subarray?c.subarray(f,f+n):Array.prototype.slice.call(c,f,f+n)),o=!0,a=_malloc(n),!a)throw new FS.ErrnoError(ERRNO_CODES.ENOMEM);i.set(c,a)}else o=!1,a=c.byteOffset;return{ptr:a,allocated:o}}}},IDBFS={dbs:{},indexedDB:function(){if("undefined"!=typeof indexedDB)return indexedDB;var e=null;return"object"==typeof window&&(e=window.indexedDB||window.mozIndexedDB||window.webkitIndexedDB||window.msIndexedDB),assert(e,"IDBFS used, but indexedDB not supported"),e},DB_VERSION:21,DB_STORE_NAME:"FILE_DATA",mount:function(e){return MEMFS.mount.apply(null,arguments)},syncfs:function(e,i,r){IDBFS.getLocalSet(e,function(n,f){return n?r(n):void IDBFS.getRemoteSet(e,function(e,n){if(e)return r(e);var t=i?n:f,u=i?f:n;IDBFS.reconcile(t,u,r)})})},getDB:function(e,i){var r=IDBFS.dbs[e];if(r)return i(null,r);var n;try{n=IDBFS.indexedDB().open(e,IDBFS.DB_VERSION)}catch(e){return i(e)}n.onupgradeneeded=function(e){var i,r=e.target.result,n=e.target.transaction;i=r.objectStoreNames.contains(IDBFS.DB_STORE_NAME)?n.objectStore(IDBFS.DB_STORE_NAME):r.createObjectStore(IDBFS.DB_STORE_NAME),i.createIndex("timestamp","timestamp",{unique:!1})},n.onsuccess=function(){r=n.result,IDBFS.dbs[e]=r,i(null,r)},n.onerror=function(){i(this.error)}},getLocalSet:function(e,i){function r(e){return"."!==e&&".."!==e}function n(e){return function(i){return PATH.join2(e,i)}}for(var f={},t=FS.readdir(e.mountpoint).filter(r).map(n(e.mountpoint));t.length;){var u,a=t.pop();try{u=FS.stat(a)}catch(e){return i(e)}FS.isDir(u.mode)&&t.push.apply(t,FS.readdir(a).filter(r).map(n(a))),f[a]={timestamp:u.mtime}}return i(null,{type:"local",entries:f})},getRemoteSet:function(e,i){var r={};IDBFS.getDB(e.mountpoint,function(e,n){if(e)return i(e);var f=n.transaction([IDBFS.DB_STORE_NAME],"readonly");f.onerror=function(){i(this.error)};var t=f.objectStore(IDBFS.DB_STORE_NAME),u=t.index("timestamp");u.openKeyCursor().onsuccess=function(e){var f=e.target.result;return f?(r[f.primaryKey]={timestamp:f.key},void f.continue()):i(null,{type:"remote",db:n,entries:r})}})},loadLocalEntry:function(e,i){var r,n;try{var f=FS.lookupPath(e);n=f.node,r=FS.stat(e)}catch(e){return i(e)}return FS.isDir(r.mode)?i(null,{timestamp:r.mtime,mode:r.mode}):FS.isFile(r.mode)?(n.contents=MEMFS.getFileDataAsTypedArray(n),i(null,{timestamp:r.mtime,mode:r.mode,contents:n.contents})):i(new Error("node type not supported"))},storeLocalEntry:function(e,i,r){try{if(FS.isDir(i.mode))FS.mkdir(e,i.mode);else{if(!FS.isFile(i.mode))return r(new Error("node type not supported"));FS.writeFile(e,i.contents,{encoding:"binary",canOwn:!0})}FS.chmod(e,i.mode),FS.utime(e,i.timestamp,i.timestamp)}catch(e){return r(e)}r(null)},removeLocalEntry:function(e,i){try{var r=(FS.lookupPath(e),FS.stat(e));FS.isDir(r.mode)?FS.rmdir(e):FS.isFile(r.mode)&&FS.unlink(e)}catch(e){return i(e)}i(null)},loadRemoteEntry:function(e,i,r){var n=e.get(i);n.onsuccess=function(e){r(null,e.target.result)},n.onerror=function(){r(this.error)}},storeRemoteEntry:function(e,i,r,n){var f=e.put(r,i);f.onsuccess=function(){n(null)},f.onerror=function(){n(this.error)}},removeRemoteEntry:function(e,i,r){var n=e.delete(i);n.onsuccess=function(){r(null)},n.onerror=function(){r(this.error)}},reconcile:function(e,i,r){function n(e){if(e){if(!n.errored)return n.errored=!0,r(e)}else if(++a>=f)return r(null)}var f=0,t=[];Object.keys(e.entries).forEach(function(r){var n=e.entries[r],u=i.entries[r];(!u||n.timestamp>u.timestamp)&&(t.push(r),f++)});var u=[];if(Object.keys(i.entries).forEach(function(r){var n=(i.entries[r],e.entries[r]);n||(u.push(r),f++)}),!f)return r(null);var a=0,o="remote"===e.type?e.db:i.db,c=o.transaction([IDBFS.DB_STORE_NAME],"readwrite"),l=c.objectStore(IDBFS.DB_STORE_NAME);c.onerror=function(){n(this.error)},t.sort().forEach(function(e){"local"===i.type?IDBFS.loadRemoteEntry(l,e,function(i,r){return i?n(i):void IDBFS.storeLocalEntry(e,r,n)}):IDBFS.loadLocalEntry(e,function(i,r){return i?n(i):void IDBFS.storeRemoteEntry(l,e,r,n)})}),u.sort().reverse().forEach(function(e){"local"===i.type?IDBFS.removeLocalEntry(e,n):IDBFS.removeRemoteEntry(l,e,n)})}},NODEFS={isWindows:!1,staticInit:function(){NODEFS.isWindows=!!process.platform.match(/^win/)},mount:function(e){return assert(!1),NODEFS.createNode(null,"/",NODEFS.getMode(e.opts.root),0)},createNode:function(e,i,r,n){if(!FS.isDir(r)&&!FS.isFile(r)&&!FS.isLink(r))throw new FS.ErrnoError(ERRNO_CODES.EINVAL);var f=FS.createNode(e,i,r);return f.node_ops=NODEFS.node_ops,f.stream_ops=NODEFS.stream_ops,f},getMode:function(e){var i;try{i=fs.lstatSync(e),NODEFS.isWindows&&(i.mode=i.mode|(146&i.mode)>>1)}catch(e){if(!e.code)throw e;throw new FS.ErrnoError(ERRNO_CODES[e.code])}return i.mode},realPath:function(e){for(var i=[];e.parent!==e;)i.push(e.name),e=e.parent;return i.push(e.mount.opts.root),i.reverse(),PATH.join.apply(null,i)},flagsToPermissionStringMap:{0:"r",1:"r+",2:"r+",64:"r",65:"r+",66:"r+",129:"rx+",193:"rx+",514:"w+",577:"w",578:"w+",705:"wx",706:"wx+",1024:"a",1025:"a",1026:"a+",1089:"a",1090:"a+",1153:"ax",1154:"ax+",1217:"ax",1218:"ax+",4096:"rs",4098:"rs+"},flagsToPermissionString:function(e){return e in NODEFS.flagsToPermissionStringMap?NODEFS.flagsToPermissionStringMap[e]:e},node_ops:{getattr:function(e){var i,r=NODEFS.realPath(e);try{i=fs.lstatSync(r)}catch(e){if(!e.code)throw e;throw new FS.ErrnoError(ERRNO_CODES[e.code])}return NODEFS.isWindows&&!i.blksize&&(i.blksize=4096),NODEFS.isWindows&&!i.blocks&&(i.blocks=(i.size+i.blksize-1)/i.blksize|0),{dev:i.dev,ino:i.ino,mode:i.mode,nlink:i.nlink,uid:i.uid,gid:i.gid,rdev:i.rdev,size:i.size,atime:i.atime,mtime:i.mtime,ctime:i.ctime,blksize:i.blksize,blocks:i.blocks}},setattr:function(e,i){var r=NODEFS.realPath(e);try{if(void 0!==i.mode&&(fs.chmodSync(r,i.mode),e.mode=i.mode),void 0!==i.timestamp){var n=new Date(i.timestamp);fs.utimesSync(r,n,n)}void 0!==i.size&&fs.truncateSync(r,i.size)}catch(e){if(!e.code)throw e;throw new FS.ErrnoError(ERRNO_CODES[e.code])}},lookup:function(e,i){var r=PATH.join2(NODEFS.realPath(e),i),n=NODEFS.getMode(r);return NODEFS.createNode(e,i,n)},mknod:function(e,i,r,n){var f=NODEFS.createNode(e,i,r,n),t=NODEFS.realPath(f);try{FS.isDir(f.mode)?fs.mkdirSync(t,f.mode):fs.writeFileSync(t,"",{mode:f.mode})}catch(e){if(!e.code)throw e;throw new FS.ErrnoError(ERRNO_CODES[e.code])}return f},rename:function(e,i,r){var n=NODEFS.realPath(e),f=PATH.join2(NODEFS.realPath(i),r);try{fs.renameSync(n,f)}catch(e){if(!e.code)throw e;throw new FS.ErrnoError(ERRNO_CODES[e.code])}},unlink:function(e,i){var r=PATH.join2(NODEFS.realPath(e),i);try{fs.unlinkSync(r)}catch(e){if(!e.code)throw e;throw new FS.ErrnoError(ERRNO_CODES[e.code])}},rmdir:function(e,i){var r=PATH.join2(NODEFS.realPath(e),i);try{fs.rmdirSync(r)}catch(e){if(!e.code)throw e;throw new FS.ErrnoError(ERRNO_CODES[e.code])}},readdir:function(e){var i=NODEFS.realPath(e);try{return fs.readdirSync(i)}catch(e){if(!e.code)throw e;throw new FS.ErrnoError(ERRNO_CODES[e.code])}},symlink:function(e,i,r){var n=PATH.join2(NODEFS.realPath(e),i);try{fs.symlinkSync(r,n)}catch(e){if(!e.code)throw e;throw new FS.ErrnoError(ERRNO_CODES[e.code])}},readlink:function(e){var i=NODEFS.realPath(e);try{return fs.readlinkSync(i)}catch(e){if(!e.code)throw e;throw new FS.ErrnoError(ERRNO_CODES[e.code])}}},stream_ops:{open:function(e){var i=NODEFS.realPath(e.node);try{FS.isFile(e.node.mode)&&(e.nfd=fs.openSync(i,NODEFS.flagsToPermissionString(e.flags)))}catch(e){if(!e.code)throw e;throw new FS.ErrnoError(ERRNO_CODES[e.code])}},close:function(e){try{FS.isFile(e.node.mode)&&e.nfd&&fs.closeSync(e.nfd)}catch(e){if(!e.code)throw e;throw new FS.ErrnoError(ERRNO_CODES[e.code])}},read:function(e,i,r,n,f){if(0===n)return 0;var t,u=new Buffer(n);try{t=fs.readSync(e.nfd,u,0,n,f)}catch(e){throw new FS.ErrnoError(ERRNO_CODES[e.code])}if(t>0)for(var a=0;a<t;a++)i[r+a]=u[a];return t},write:function(e,i,r,n,f){var t,u=new Buffer(i.subarray(r,r+n));try{t=fs.writeSync(e.nfd,u,0,n,f)}catch(e){throw new FS.ErrnoError(ERRNO_CODES[e.code])}return t},llseek:function(e,i,r){var n=i;if(1===r)n+=e.position;else if(2===r&&FS.isFile(e.node.mode))try{var f=fs.fstatSync(e.nfd);n+=f.size}catch(e){throw new FS.ErrnoError(ERRNO_CODES[e.code])}if(n<0)throw new FS.ErrnoError(ERRNO_CODES.EINVAL);return n}}},_stdin=allocate(1,"i32*",ALLOC_STATIC),_stdout=allocate(1,"i32*",ALLOC_STATIC),_stderr=allocate(1,"i32*",ALLOC_STATIC),FS={root:null,mounts:[],devices:[null],streams:[],nextInode:1,nameTable:null,currentPath:"/",initialized:!1,ignorePermissions:!0,trackingDelegate:{},tracking:{openFlags:{READ:1,WRITE:2}},ErrnoError:null,genericErrors:{},handleFSError:function(e){if(!(e instanceof FS.ErrnoError))throw e+" : "+stackTrace();return ___setErrNo(e.errno)},lookupPath:function(e,i){if(e=PATH.resolve(FS.cwd(),e),i=i||{},!e)return{path:"",node:null};var r={follow_mount:!0,recurse_count:0};for(var n in r)void 0===i[n]&&(i[n]=r[n]);if(i.recurse_count>8)throw new FS.ErrnoError(ERRNO_CODES.ELOOP);for(var f=PATH.normalizeArray(e.split("/").filter(function(e){return!!e}),!1),t=FS.root,u="/",a=0;a<f.length;a++){var o=a===f.length-1;if(o&&i.parent)break;if(t=FS.lookupNode(t,f[a]),u=PATH.join2(u,f[a]),FS.isMountpoint(t)&&(!o||o&&i.follow_mount)&&(t=t.mounted.root),!o||i.follow)for(var c=0;FS.isLink(t.mode);){var l=FS.readlink(u);u=PATH.resolve(PATH.dirname(u),l);var s=FS.lookupPath(u,{recurse_count:i.recurse_count});if(t=s.node,c++>40)throw new FS.ErrnoError(ERRNO_CODES.ELOOP)}}return{path:u,node:t}},getPath:function(e){for(var i;;){if(FS.isRoot(e)){var r=e.mount.mountpoint;return i?"/"!==r[r.length-1]?r+"/"+i:r+i:r}i=i?e.name+"/"+i:e.name,e=e.parent}},hashName:function(e,i){for(var r=0,n=0;n<i.length;n++)r=(r<<5)-r+i.charCodeAt(n)|0;return(e+r>>>0)%FS.nameTable.length},hashAddNode:function(e){var i=FS.hashName(e.parent.id,e.name);e.name_next=FS.nameTable[i],FS.nameTable[i]=e},hashRemoveNode:function(e){var i=FS.hashName(e.parent.id,e.name);if(FS.nameTable[i]===e)FS.nameTable[i]=e.name_next;else for(var r=FS.nameTable[i];r;){if(r.name_next===e){r.name_next=e.name_next;break}r=r.name_next}},lookupNode:function(e,i){var r=FS.mayLookup(e);if(r)throw new FS.ErrnoError(r,e);for(var n=FS.hashName(e.id,i),f=FS.nameTable[n];f;f=f.name_next){var t=f.name;if(f.parent.id===e.id&&t===i)return f}return FS.lookup(e,i)},createNode:function(e,i,r,n){if(!FS.FSNode){FS.FSNode=function(e,i,r,n){e||(e=this),this.parent=e,this.mount=e.mount,this.mounted=null,this.id=FS.nextInode++,this.name=i,this.mode=r,this.node_ops={},this.stream_ops={},this.rdev=n},FS.FSNode.prototype={};var f=365,t=146;Object.defineProperties(FS.FSNode.prototype,{read:{get:function(){return(this.mode&f)===f},set:function(e){e?this.mode|=f:this.mode&=~f}},write:{get:function(){return(this.mode&t)===t},set:function(e){e?this.mode|=t:this.mode&=~t}},isFolder:{get:function(){return FS.isDir(this.mode)}},isDevice:{get:function(){return FS.isChrdev(this.mode)}}})}var u=new FS.FSNode(e,i,r,n);return FS.hashAddNode(u),u},destroyNode:function(e){FS.hashRemoveNode(e)},isRoot:function(e){return e===e.parent},isMountpoint:function(e){return!!e.mounted},isFile:function(e){return 32768===(61440&e)},isDir:function(e){return 16384===(61440&e)},isLink:function(e){return 40960===(61440&e)},isChrdev:function(e){return 8192===(61440&e)},isBlkdev:function(e){return 24576===(61440&e)},isFIFO:function(e){return 4096===(61440&e)},isSocket:function(e){return 49152===(49152&e)},flagModes:{r:0,rs:1052672,"r+":2,w:577,wx:705,xw:705,"w+":578,"wx+":706,"xw+":706,a:1089,ax:1217,xa:1217,"a+":1090,"ax+":1218,"xa+":1218},modeStringToFlags:function(e){var i=FS.flagModes[e];if("undefined"==typeof i)throw new Error("Unknown file open mode: "+e);return i},flagsToPermissionString:function(e){var i=2097155&e,r=["r","w","rw"][i];return 512&e&&(r+="w"),r},nodePermissions:function(e,i){return FS.ignorePermissions?0:(i.indexOf("r")===-1||292&e.mode)&&(i.indexOf("w")===-1||146&e.mode)&&(i.indexOf("x")===-1||73&e.mode)?0:ERRNO_CODES.EACCES},mayLookup:function(e){var i=FS.nodePermissions(e,"x");return i?i:e.node_ops.lookup?0:ERRNO_CODES.EACCES},mayCreate:function(e,i){try{FS.lookupNode(e,i);return ERRNO_CODES.EEXIST}catch(e){}return FS.nodePermissions(e,"wx")},mayDelete:function(e,i,r){var n;try{n=FS.lookupNode(e,i)}catch(e){return e.errno}var f=FS.nodePermissions(e,"wx");if(f)return f;if(r){if(!FS.isDir(n.mode))return ERRNO_CODES.ENOTDIR;if(FS.isRoot(n)||FS.getPath(n)===FS.cwd())return ERRNO_CODES.EBUSY}else if(FS.isDir(n.mode))return ERRNO_CODES.EISDIR;return 0},mayOpen:function(e,i){return e?FS.isLink(e.mode)?ERRNO_CODES.ELOOP:FS.isDir(e.mode)&&(0!==(2097155&i)||512&i)?ERRNO_CODES.EISDIR:FS.nodePermissions(e,FS.flagsToPermissionString(i)):ERRNO_CODES.ENOENT},MAX_OPEN_FDS:4096,nextfd:function(e,i){e=e||0,i=i||FS.MAX_OPEN_FDS;for(var r=e;r<=i;r++)if(!FS.streams[r])return r;throw new FS.ErrnoError(ERRNO_CODES.EMFILE)},getStream:function(e){return FS.streams[e]},createStream:function(e,i,r){FS.FSStream||(FS.FSStream=function(){},FS.FSStream.prototype={},Object.defineProperties(FS.FSStream.prototype,{object:{get:function(){return this.node},set:function(e){this.node=e}},isRead:{get:function(){return 1!==(2097155&this.flags)}},isWrite:{get:function(){return 0!==(2097155&this.flags)}},isAppend:{get:function(){return 1024&this.flags}}}));var n=new FS.FSStream;for(var f in e)n[f]=e[f];e=n;var t=FS.nextfd(i,r);return e.fd=t,FS.streams[t]=e,e},closeStream:function(e){FS.streams[e]=null},getStreamFromPtr:function(e){return FS.streams[e-1]},getPtrForStream:function(e){return e?e.fd+1:0},chrdev_stream_ops:{open:function(e){var i=FS.getDevice(e.node.rdev);e.stream_ops=i.stream_ops,e.stream_ops.open&&e.stream_ops.open(e)},llseek:function(){throw new FS.ErrnoError(ERRNO_CODES.ESPIPE)}},major:function(e){return e>>8},minor:function(e){return 255&e},makedev:function(e,i){return e<<8|i},registerDevice:function(e,i){FS.devices[e]={stream_ops:i}},getDevice:function(e){return FS.devices[e]},getMounts:function(e){for(var i=[],r=[e];r.length;){var n=r.pop();i.push(n),r.push.apply(r,n.mounts)}return i},syncfs:function(e,i){function r(e){if(e){if(!r.errored)return r.errored=!0,i(e)}else++f>=n.length&&i(null)}"function"==typeof e&&(i=e,e=!1);var n=FS.getMounts(FS.root.mount),f=0;n.forEach(function(i){return i.type.syncfs?void i.type.syncfs(i,e,r):r(null)})},mount:function(e,i,r){var n,f="/"===r,t=!r;if(f&&FS.root)throw new FS.ErrnoError(ERRNO_CODES.EBUSY);if(!f&&!t){var u=FS.lookupPath(r,{follow_mount:!1});if(r=u.path,n=u.node,FS.isMountpoint(n))throw new FS.ErrnoError(ERRNO_CODES.EBUSY);if(!FS.isDir(n.mode))throw new FS.ErrnoError(ERRNO_CODES.ENOTDIR)}var a={type:e,opts:i,mountpoint:r,mounts:[]},o=e.mount(a);return o.mount=a,a.root=o,f?FS.root=o:n&&(n.mounted=a,n.mount&&n.mount.mounts.push(a)),o},unmount:function(e){var i=FS.lookupPath(e,{follow_mount:!1});if(!FS.isMountpoint(i.node))throw new FS.ErrnoError(ERRNO_CODES.EINVAL);var r=i.node,n=r.mounted,f=FS.getMounts(n);Object.keys(FS.nameTable).forEach(function(e){for(var i=FS.nameTable[e];i;){var r=i.name_next;f.indexOf(i.mount)!==-1&&FS.destroyNode(i),i=r}}),r.mounted=null;var t=r.mount.mounts.indexOf(n);assert(t!==-1),r.mount.mounts.splice(t,1)},lookup:function(e,i){return e.node_ops.lookup(e,i)},mknod:function(e,i,r){var n=FS.lookupPath(e,{parent:!0}),f=n.node,t=PATH.basename(e);if(!t||"."===t||".."===t)throw new FS.ErrnoError(ERRNO_CODES.EINVAL);var u=FS.mayCreate(f,t);if(u)throw new FS.ErrnoError(u);if(!f.node_ops.mknod)throw new FS.ErrnoError(ERRNO_CODES.EPERM);return f.node_ops.mknod(f,t,i,r)},create:function(e,i){return i=void 0!==i?i:438,i&=4095,i|=32768,FS.mknod(e,i,0)},mkdir:function(e,i){return i=void 0!==i?i:511,i&=1023,i|=16384,FS.mknod(e,i,0)},mkdev:function(e,i,r){return"undefined"==typeof r&&(r=i,i=438),i|=8192,FS.mknod(e,i,r)},symlink:function(e,i){if(!PATH.resolve(e))throw new FS.ErrnoError(ERRNO_CODES.ENOENT);var r=FS.lookupPath(i,{parent:!0}),n=r.node;if(!n)throw new FS.ErrnoError(ERRNO_CODES.ENOENT);var f=PATH.basename(i),t=FS.mayCreate(n,f);if(t)throw new FS.ErrnoError(t);if(!n.node_ops.symlink)throw new FS.ErrnoError(ERRNO_CODES.EPERM);return n.node_ops.symlink(n,f,e)},rename:function(e,i){var r,n,f,t=PATH.dirname(e),u=PATH.dirname(i),a=PATH.basename(e),o=PATH.basename(i);try{r=FS.lookupPath(e,{parent:!0}),n=r.node,r=FS.lookupPath(i,{parent:!0}),f=r.node}catch(e){throw new FS.ErrnoError(ERRNO_CODES.EBUSY)}if(!n||!f)throw new FS.ErrnoError(ERRNO_CODES.ENOENT);if(n.mount!==f.mount)throw new FS.ErrnoError(ERRNO_CODES.EXDEV);var c=FS.lookupNode(n,a),l=PATH.relative(e,u);if("."!==l.charAt(0))throw new FS.ErrnoError(ERRNO_CODES.EINVAL);if(l=PATH.relative(i,t),"."!==l.charAt(0))throw new FS.ErrnoError(ERRNO_CODES.ENOTEMPTY);var s;try{s=FS.lookupNode(f,o)}catch(e){}if(c!==s){var b=FS.isDir(c.mode),k=FS.mayDelete(n,a,b);if(k)throw new FS.ErrnoError(k);if(k=s?FS.mayDelete(f,o,b):FS.mayCreate(f,o))throw new FS.ErrnoError(k);if(!n.node_ops.rename)throw new FS.ErrnoError(ERRNO_CODES.EPERM);if(FS.isMountpoint(c)||s&&FS.isMountpoint(s))throw new FS.ErrnoError(ERRNO_CODES.EBUSY);if(f!==n&&(k=FS.nodePermissions(n,"w")))throw new FS.ErrnoError(k);try{FS.trackingDelegate.willMovePath&&FS.trackingDelegate.willMovePath(e,i)}catch(r){console.log("FS.trackingDelegate['willMovePath']('"+e+"', '"+i+"') threw an exception: "+r.message)}FS.hashRemoveNode(c);try{n.node_ops.rename(c,f,o)}catch(e){throw e}finally{FS.hashAddNode(c)}try{FS.trackingDelegate.onMovePath&&FS.trackingDelegate.onMovePath(e,i)}catch(r){console.log("FS.trackingDelegate['onMovePath']('"+e+"', '"+i+"') threw an exception: "+r.message)}}},rmdir:function(e){var i=FS.lookupPath(e,{parent:!0}),r=i.node,n=PATH.basename(e),f=FS.lookupNode(r,n),t=FS.mayDelete(r,n,!0);if(t)throw new FS.ErrnoError(t);if(!r.node_ops.rmdir)throw new FS.ErrnoError(ERRNO_CODES.EPERM);if(FS.isMountpoint(f))throw new FS.ErrnoError(ERRNO_CODES.EBUSY);try{FS.trackingDelegate.willDeletePath&&FS.trackingDelegate.willDeletePath(e)}catch(i){console.log("FS.trackingDelegate['willDeletePath']('"+e+"') threw an exception: "+i.message)}r.node_ops.rmdir(r,n),FS.destroyNode(f);try{FS.trackingDelegate.onDeletePath&&FS.trackingDelegate.onDeletePath(e)}catch(i){console.log("FS.trackingDelegate['onDeletePath']('"+e+"') threw an exception: "+i.message)}},readdir:function(e){var i=FS.lookupPath(e,{follow:!0}),r=i.node;if(!r.node_ops.readdir)throw new FS.ErrnoError(ERRNO_CODES.ENOTDIR);return r.node_ops.readdir(r)},unlink:function(e){var i=FS.lookupPath(e,{parent:!0}),r=i.node,n=PATH.basename(e),f=FS.lookupNode(r,n),t=FS.mayDelete(r,n,!1);if(t)throw t===ERRNO_CODES.EISDIR&&(t=ERRNO_CODES.EPERM),new FS.ErrnoError(t);if(!r.node_ops.unlink)throw new FS.ErrnoError(ERRNO_CODES.EPERM);if(FS.isMountpoint(f))throw new FS.ErrnoError(ERRNO_CODES.EBUSY);try{FS.trackingDelegate.willDeletePath&&FS.trackingDelegate.willDeletePath(e)}catch(i){console.log("FS.trackingDelegate['willDeletePath']('"+e+"') threw an exception: "+i.message)}r.node_ops.unlink(r,n),FS.destroyNode(f);try{FS.trackingDelegate.onDeletePath&&FS.trackingDelegate.onDeletePath(e)}catch(i){console.log("FS.trackingDelegate['onDeletePath']('"+e+"') threw an exception: "+i.message)}},readlink:function(e){var i=FS.lookupPath(e),r=i.node;if(!r)throw new FS.ErrnoError(ERRNO_CODES.ENOENT);if(!r.node_ops.readlink)throw new FS.ErrnoError(ERRNO_CODES.EINVAL);return r.node_ops.readlink(r)},stat:function(e,i){var r=FS.lookupPath(e,{follow:!i}),n=r.node;if(!n)throw new FS.ErrnoError(ERRNO_CODES.ENOENT);if(!n.node_ops.getattr)throw new FS.ErrnoError(ERRNO_CODES.EPERM);return n.node_ops.getattr(n)},lstat:function(e){return FS.stat(e,!0)},chmod:function(e,i,r){var n;if("string"==typeof e){var f=FS.lookupPath(e,{follow:!r});n=f.node}else n=e;if(!n.node_ops.setattr)throw new FS.ErrnoError(ERRNO_CODES.EPERM);n.node_ops.setattr(n,{mode:4095&i|n.mode&-4096,timestamp:Date.now()})},lchmod:function(e,i){FS.chmod(e,i,!0)},fchmod:function(e,i){var r=FS.getStream(e);if(!r)throw new FS.ErrnoError(ERRNO_CODES.EBADF);FS.chmod(r.node,i)},chown:function(e,i,r,n){var f;if("string"==typeof e){var t=FS.lookupPath(e,{follow:!n});f=t.node}else f=e;if(!f.node_ops.setattr)throw new FS.ErrnoError(ERRNO_CODES.EPERM);f.node_ops.setattr(f,{timestamp:Date.now()})},lchown:function(e,i,r){FS.chown(e,i,r,!0)},fchown:function(e,i,r){var n=FS.getStream(e);if(!n)throw new FS.ErrnoError(ERRNO_CODES.EBADF);FS.chown(n.node,i,r)},truncate:function(e,i){if(i<0)throw new FS.ErrnoError(ERRNO_CODES.EINVAL);var r;if("string"==typeof e){var n=FS.lookupPath(e,{follow:!0});r=n.node}else r=e;if(!r.node_ops.setattr)throw new FS.ErrnoError(ERRNO_CODES.EPERM);if(FS.isDir(r.mode))throw new FS.ErrnoError(ERRNO_CODES.EISDIR);if(!FS.isFile(r.mode))throw new FS.ErrnoError(ERRNO_CODES.EINVAL);var f=FS.nodePermissions(r,"w");if(f)throw new FS.ErrnoError(f);r.node_ops.setattr(r,{size:i,timestamp:Date.now()})},ftruncate:function(e,i){var r=FS.getStream(e);if(!r)throw new FS.ErrnoError(ERRNO_CODES.EBADF);if(0===(2097155&r.flags))throw new FS.ErrnoError(ERRNO_CODES.EINVAL);FS.truncate(r.node,i)},utime:function(e,i,r){var n=FS.lookupPath(e,{follow:!0}),f=n.node;f.node_ops.setattr(f,{timestamp:Math.max(i,r)})},open:function(e,i,r,n,f){if(""===e)throw new FS.ErrnoError(ERRNO_CODES.ENOENT);i="string"==typeof i?FS.modeStringToFlags(i):i,r="undefined"==typeof r?438:r,r=64&i?4095&r|32768:0;var t;if("object"==typeof e)t=e;else{e=PATH.normalize(e);try{var u=FS.lookupPath(e,{follow:!(131072&i)});t=u.node}catch(e){}}var a=!1;if(64&i)if(t){if(128&i)throw new FS.ErrnoError(ERRNO_CODES.EEXIST)}else t=FS.mknod(e,r,0),a=!0;if(!t)throw new FS.ErrnoError(ERRNO_CODES.ENOENT);if(FS.isChrdev(t.mode)&&(i&=-513),!a){var o=FS.mayOpen(t,i);if(o)throw new FS.ErrnoError(o)}512&i&&FS.truncate(t,0),i&=-641;var c=FS.createStream({node:t,path:FS.getPath(t),flags:i,seekable:!0,position:0,stream_ops:t.stream_ops,ungotten:[],error:!1},n,f);c.stream_ops.open&&c.stream_ops.open(c),!Module.logReadFiles||1&i||(FS.readFiles||(FS.readFiles={}),e in FS.readFiles||(FS.readFiles[e]=1,Module.printErr("read file: "+e)));try{if(FS.trackingDelegate.onOpenFile){var l=0;1!==(2097155&i)&&(l|=FS.tracking.openFlags.READ),0!==(2097155&i)&&(l|=FS.tracking.openFlags.WRITE),FS.trackingDelegate.onOpenFile(e,l)}}catch(i){console.log("FS.trackingDelegate['onOpenFile']('"+e+"', flags) threw an exception: "+i.message)}return c},close:function(e){try{e.stream_ops.close&&e.stream_ops.close(e)}catch(e){throw e}finally{FS.closeStream(e.fd)}},llseek:function(e,i,r){if(!e.seekable||!e.stream_ops.llseek)throw new FS.ErrnoError(ERRNO_CODES.ESPIPE);return e.position=e.stream_ops.llseek(e,i,r),e.ungotten=[],e.position},read:function(e,i,r,n,f){if(n<0||f<0)throw new FS.ErrnoError(ERRNO_CODES.EINVAL);if(1===(2097155&e.flags))throw new FS.ErrnoError(ERRNO_CODES.EBADF);if(FS.isDir(e.node.mode))throw new FS.ErrnoError(ERRNO_CODES.EISDIR);if(!e.stream_ops.read)throw new FS.ErrnoError(ERRNO_CODES.EINVAL);var t=!0;if("undefined"==typeof f)f=e.position,t=!1;else if(!e.seekable)throw new FS.ErrnoError(ERRNO_CODES.ESPIPE);var u=e.stream_ops.read(e,i,r,n,f);return t||(e.position+=u),u},write:function(e,i,r,n,f,t){if(n<0||f<0)throw new FS.ErrnoError(ERRNO_CODES.EINVAL);if(0===(2097155&e.flags))throw new FS.ErrnoError(ERRNO_CODES.EBADF);if(FS.isDir(e.node.mode))throw new FS.ErrnoError(ERRNO_CODES.EISDIR);if(!e.stream_ops.write)throw new FS.ErrnoError(ERRNO_CODES.EINVAL);1024&e.flags&&FS.llseek(e,0,2);var u=!0;if("undefined"==typeof f)f=e.position,u=!1;else if(!e.seekable)throw new FS.ErrnoError(ERRNO_CODES.ESPIPE);var a=e.stream_ops.write(e,i,r,n,f,t);u||(e.position+=a);try{e.path&&FS.trackingDelegate.onWriteToFile&&FS.trackingDelegate.onWriteToFile(e.path)}catch(e){console.log("FS.trackingDelegate['onWriteToFile']('"+path+"') threw an exception: "+e.message)}return a},allocate:function(e,i,r){if(i<0||r<=0)throw new FS.ErrnoError(ERRNO_CODES.EINVAL);if(0===(2097155&e.flags))throw new FS.ErrnoError(ERRNO_CODES.EBADF);if(!FS.isFile(e.node.mode)&&!FS.isDir(node.mode))throw new FS.ErrnoError(ERRNO_CODES.ENODEV);if(!e.stream_ops.allocate)throw new FS.ErrnoError(ERRNO_CODES.EOPNOTSUPP);e.stream_ops.allocate(e,i,r)},mmap:function(e,i,r,n,f,t,u){if(1===(2097155&e.flags))throw new FS.ErrnoError(ERRNO_CODES.EACCES);if(!e.stream_ops.mmap)throw new FS.ErrnoError(ERRNO_CODES.ENODEV);return e.stream_ops.mmap(e,i,r,n,f,t,u)},ioctl:function(e,i,r){if(!e.stream_ops.ioctl)throw new FS.ErrnoError(ERRNO_CODES.ENOTTY);return e.stream_ops.ioctl(e,i,r)},readFile:function(e,i){if(i=i||{},i.flags=i.flags||"r",i.encoding=i.encoding||"binary","utf8"!==i.encoding&&"binary"!==i.encoding)throw new Error('Invalid encoding type "'+i.encoding+'"');var r,n=FS.open(e,i.flags),f=FS.stat(e),t=f.size,u=new Uint8Array(t);if(FS.read(n,u,0,t,0),"utf8"===i.encoding){r="";for(var a=new Runtime.UTF8Processor,o=0;o<t;o++)r+=a.processCChar(u[o])}else"binary"===i.encoding&&(r=u);return FS.close(n),r},writeFile:function(e,i,r){if(r=r||{},r.flags=r.flags||"w",r.encoding=r.encoding||"utf8","utf8"!==r.encoding&&"binary"!==r.encoding)throw new Error('Invalid encoding type "'+r.encoding+'"');var n=FS.open(e,r.flags,r.mode);if("utf8"===r.encoding){var f=new Runtime.UTF8Processor,t=new Uint8Array(f.processJSString(i));FS.write(n,t,0,t.length,0,r.canOwn)}else"binary"===r.encoding&&FS.write(n,i,0,i.length,0,r.canOwn);FS.close(n)},cwd:function(){return FS.currentPath},chdir:function(e){var i=FS.lookupPath(e,{follow:!0});if(!FS.isDir(i.node.mode))throw new FS.ErrnoError(ERRNO_CODES.ENOTDIR);var r=FS.nodePermissions(i.node,"x");if(r)throw new FS.ErrnoError(r);FS.currentPath=i.path},createDefaultDirectories:function(){FS.mkdir("/tmp"),FS.mkdir("/home"),FS.mkdir("/home/web_user")},createDefaultDevices:function(){FS.mkdir("/dev"),FS.registerDevice(FS.makedev(1,3),{read:function(){return 0},write:function(){return 0}}),FS.mkdev("/dev/null",FS.makedev(1,3)),TTY.register(FS.makedev(5,0),TTY.default_tty_ops),TTY.register(FS.makedev(6,0),TTY.default_tty1_ops),FS.mkdev("/dev/tty",FS.makedev(5,0)),FS.mkdev("/dev/tty1",FS.makedev(6,0));var e;if("undefined"!=typeof crypto){var i=new Uint8Array(1);e=function(){return crypto.getRandomValues(i),i[0]}}else e=function(){return 256*Math.random()|0};FS.createDevice("/dev","random",e),FS.createDevice("/dev","urandom",e),FS.mkdir("/dev/shm"),FS.mkdir("/dev/shm/tmp")},createStandardStreams:function(){Module.stdin?FS.createDevice("/dev","stdin",Module.stdin):FS.symlink("/dev/tty","/dev/stdin"),Module.stdout?FS.createDevice("/dev","stdout",null,Module.stdout):FS.symlink("/dev/tty","/dev/stdout"),Module.stderr?FS.createDevice("/dev","stderr",null,Module.stderr):FS.symlink("/dev/tty1","/dev/stderr");var e=FS.open("/dev/stdin","r");HEAP32[_stdin>>2]=FS.getPtrForStream(e),assert(0===e.fd,"invalid handle for stdin ("+e.fd+")");var i=FS.open("/dev/stdout","w");HEAP32[_stdout>>2]=FS.getPtrForStream(i),assert(1===i.fd,"invalid handle for stdout ("+i.fd+")");var r=FS.open("/dev/stderr","w");HEAP32[_stderr>>2]=FS.getPtrForStream(r),assert(2===r.fd,"invalid handle for stderr ("+r.fd+")")},ensureErrnoError:function(){FS.ErrnoError||(FS.ErrnoError=function(e,i){this.node=i,this.setErrno=function(e){this.errno=e;for(var i in ERRNO_CODES)if(ERRNO_CODES[i]===e){this.code=i;break}},this.setErrno(e),this.message=ERRNO_MESSAGES[e]},FS.ErrnoError.prototype=new Error,FS.ErrnoError.prototype.constructor=FS.ErrnoError,[ERRNO_CODES.ENOENT].forEach(function(e){FS.genericErrors[e]=new FS.ErrnoError(e),FS.genericErrors[e].stack="<generic error, no stack>"}))},staticInit:function(){FS.ensureErrnoError(),FS.nameTable=new Array(4096),FS.mount(MEMFS,{},"/"),FS.createDefaultDirectories(),FS.createDefaultDevices()},init:function(e,i,r){assert(!FS.init.initialized,"FS.init was previously called. If you want to initialize later with custom parameters, remove any earlier calls (note that one is automatically added to the generated code)"),FS.init.initialized=!0,FS.ensureErrnoError(),Module.stdin=e||Module.stdin,Module.stdout=i||Module.stdout,Module.stderr=r||Module.stderr,FS.createStandardStreams()},quit:function(){FS.init.initialized=!1;
	for(var e=0;e<FS.streams.length;e++){var i=FS.streams[e];i&&FS.close(i)}},getMode:function(e,i){var r=0;return e&&(r|=365),i&&(r|=146),r},joinPath:function(e,i){var r=PATH.join.apply(null,e);return i&&"/"==r[0]&&(r=r.substr(1)),r},absolutePath:function(e,i){return PATH.resolve(i,e)},standardizePath:function(e){return PATH.normalize(e)},findObject:function(e,i){var r=FS.analyzePath(e,i);return r.exists?r.object:(___setErrNo(r.error),null)},analyzePath:function(e,i){try{var r=FS.lookupPath(e,{follow:!i});e=r.path}catch(e){}var n={isRoot:!1,exists:!1,error:0,name:null,path:null,object:null,parentExists:!1,parentPath:null,parentObject:null};try{var r=FS.lookupPath(e,{parent:!0});n.parentExists=!0,n.parentPath=r.path,n.parentObject=r.node,n.name=PATH.basename(e),r=FS.lookupPath(e,{follow:!i}),n.exists=!0,n.path=r.path,n.object=r.node,n.name=r.node.name,n.isRoot="/"===r.path}catch(e){n.error=e.errno}return n},createFolder:function(e,i,r,n){var f=PATH.join2("string"==typeof e?e:FS.getPath(e),i),t=FS.getMode(r,n);return FS.mkdir(f,t)},createPath:function(e,i,r,n){e="string"==typeof e?e:FS.getPath(e);for(var f=i.split("/").reverse();f.length;){var t=f.pop();if(t){var u=PATH.join2(e,t);try{FS.mkdir(u)}catch(e){}e=u}}return u},createFile:function(e,i,r,n,f){var t=PATH.join2("string"==typeof e?e:FS.getPath(e),i),u=FS.getMode(n,f);return FS.create(t,u)},createDataFile:function(e,i,r,n,f,t){var u=i?PATH.join2("string"==typeof e?e:FS.getPath(e),i):e,a=FS.getMode(n,f),o=FS.create(u,a);if(r){if("string"==typeof r){for(var c=new Array(r.length),l=0,s=r.length;l<s;++l)c[l]=r.charCodeAt(l);r=c}FS.chmod(o,146|a);var b=FS.open(o,"w");FS.write(b,r,0,r.length,0,t),FS.close(b),FS.chmod(o,a)}return o},createDevice:function(e,i,r,n){var f=PATH.join2("string"==typeof e?e:FS.getPath(e),i),t=FS.getMode(!!r,!!n);FS.createDevice.major||(FS.createDevice.major=64);var u=FS.makedev(FS.createDevice.major++,0);return FS.registerDevice(u,{open:function(e){e.seekable=!1},close:function(e){n&&n.buffer&&n.buffer.length&&n(10)},read:function(e,i,n,f,t){for(var u=0,a=0;a<f;a++){var o;try{o=r()}catch(e){throw new FS.ErrnoError(ERRNO_CODES.EIO)}if(void 0===o&&0===u)throw new FS.ErrnoError(ERRNO_CODES.EAGAIN);if(null===o||void 0===o)break;u++,i[n+a]=o}return u&&(e.node.timestamp=Date.now()),u},write:function(e,i,r,f,t){for(var u=0;u<f;u++)try{n(i[r+u])}catch(e){throw new FS.ErrnoError(ERRNO_CODES.EIO)}return f&&(e.node.timestamp=Date.now()),u}}),FS.mkdev(f,t,u)},createLink:function(e,i,r,n,f){var t=PATH.join2("string"==typeof e?e:FS.getPath(e),i);return FS.symlink(r,t)},forceLoadFile:function(e){if(e.isDevice||e.isFolder||e.link||e.contents)return!0;var i=!0;if("undefined"!=typeof XMLHttpRequest)throw new Error("Lazy loading should have been performed (contents set) in createLazyFile, but it was not. Lazy loading only works in web workers. Use --embed-file or --preload-file in emcc on the main thread.");if(!Module.read)throw new Error("Cannot load without read() or XMLHttpRequest.");try{e.contents=intArrayFromString(Module.read(e.url),!0),e.usedBytes=e.contents.length}catch(e){i=!1}return i||___setErrNo(ERRNO_CODES.EIO),i},createLazyFile:function(e,i,r,n,f){function t(){this.lengthKnown=!1,this.chunks=[]}if(t.prototype.get=function(e){if(!(e>this.length-1||e<0)){var i=e%this.chunkSize,r=e/this.chunkSize|0;return this.getter(r)[i]}},t.prototype.setDataGetter=function(e){this.getter=e},t.prototype.cacheLength=function(){var e=new XMLHttpRequest;if(e.open("HEAD",r,!1),e.send(null),!(e.status>=200&&e.status<300||304===e.status))throw new Error("Couldn't load "+r+". Status: "+e.status);var i,n=Number(e.getResponseHeader("Content-length")),f=(i=e.getResponseHeader("Accept-Ranges"))&&"bytes"===i,t=1048576;f||(t=n);var u=function(e,i){if(e>i)throw new Error("invalid range ("+e+", "+i+") or no bytes requested!");if(i>n-1)throw new Error("only "+n+" bytes available! programmer error!");var f=new XMLHttpRequest;if(f.open("GET",r,!1),n!==t&&f.setRequestHeader("Range","bytes="+e+"-"+i),"undefined"!=typeof Uint8Array&&(f.responseType="arraybuffer"),f.overrideMimeType&&f.overrideMimeType("text/plain; charset=x-user-defined"),f.send(null),!(f.status>=200&&f.status<300||304===f.status))throw new Error("Couldn't load "+r+". Status: "+f.status);return void 0!==f.response?new Uint8Array(f.response||[]):intArrayFromString(f.responseText||"",!0)},a=this;a.setDataGetter(function(e){var i=e*t,r=(e+1)*t-1;if(r=Math.min(r,n-1),"undefined"==typeof a.chunks[e]&&(a.chunks[e]=u(i,r)),"undefined"==typeof a.chunks[e])throw new Error("doXHR failed!");return a.chunks[e]}),this._length=n,this._chunkSize=t,this.lengthKnown=!0},"undefined"!=typeof XMLHttpRequest){throw"Cannot do synchronous binary XHRs outside webworkers in modern browsers. Use --embed-file or --preload-file in emcc";var u}else var u={isDevice:!1,url:r};var a=FS.createFile(e,i,u,n,f);u.contents?a.contents=u.contents:u.url&&(a.contents=null,a.url=u.url),Object.defineProperty(a,"usedBytes",{get:function(){return this.contents.length}});var o={},c=Object.keys(a.stream_ops);return c.forEach(function(e){var i=a.stream_ops[e];o[e]=function(){if(!FS.forceLoadFile(a))throw new FS.ErrnoError(ERRNO_CODES.EIO);return i.apply(null,arguments)}}),o.read=function(e,i,r,n,f){if(!FS.forceLoadFile(a))throw new FS.ErrnoError(ERRNO_CODES.EIO);var t=e.node.contents;if(f>=t.length)return 0;var u=Math.min(t.length-f,n);if(assert(u>=0),t.slice)for(var o=0;o<u;o++)i[r+o]=t[f+o];else for(var o=0;o<u;o++)i[r+o]=t.get(f+o);return u},a.stream_ops=o,a},createPreloadedFile:function(e,i,r,n,f,t,u,a,o){function c(r){function c(r){a||FS.createDataFile(e,i,r,n,f,o),t&&t(),removeRunDependency("cp "+l)}var s=!1;Module.preloadPlugins.forEach(function(e){s||e.canHandle(l)&&(e.handle(r,l,c,function(){u&&u(),removeRunDependency("cp "+l)}),s=!0)}),s||c(r)}Browser.init();var l=i?PATH.resolve(PATH.join2(e,i)):e;addRunDependency("cp "+l),"string"==typeof r?Browser.asyncLoad(r,function(e){c(e)},u):c(r)},indexedDB:function(){return window.indexedDB||window.mozIndexedDB||window.webkitIndexedDB||window.msIndexedDB},DB_NAME:function(){return"EM_FS_"+window.location.pathname},DB_VERSION:20,DB_STORE_NAME:"FILE_DATA",saveFilesToDB:function(e,i,r){i=i||function(){},r=r||function(){};var n=FS.indexedDB();try{var f=n.open(FS.DB_NAME(),FS.DB_VERSION)}catch(e){return r(e)}f.onupgradeneeded=function(){console.log("creating db");var e=f.result;e.createObjectStore(FS.DB_STORE_NAME)},f.onsuccess=function(){function n(){0==c?i():r()}var t=f.result,u=t.transaction([FS.DB_STORE_NAME],"readwrite"),a=u.objectStore(FS.DB_STORE_NAME),o=0,c=0,l=e.length;e.forEach(function(e){var i=a.put(FS.analyzePath(e).object.contents,e);i.onsuccess=function(){o++,o+c==l&&n()},i.onerror=function(){c++,o+c==l&&n()}}),u.onerror=r},f.onerror=r},loadFilesFromDB:function(e,i,r){i=i||function(){},r=r||function(){};var n=FS.indexedDB();try{var f=n.open(FS.DB_NAME(),FS.DB_VERSION)}catch(e){return r(e)}f.onupgradeneeded=r,f.onsuccess=function(){function n(){0==c?i():r()}var t=f.result;try{var u=t.transaction([FS.DB_STORE_NAME],"readonly")}catch(e){return void r(e)}var a=u.objectStore(FS.DB_STORE_NAME),o=0,c=0,l=e.length;e.forEach(function(e){var i=a.get(e);i.onsuccess=function(){FS.analyzePath(e).exists&&FS.unlink(e),FS.createDataFile(PATH.dirname(e),PATH.basename(e),i.result,!0,!0,!0),o++,o+c==l&&n()},i.onerror=function(){c++,o+c==l&&n()}}),u.onerror=r},f.onerror=r}},SOCKFS={mount:function(e){return Module.websocket=Module.websocket&&"object"==typeof Module.websocket?Module.websocket:{},Module.websocket._callbacks={},Module.websocket.on=function(e,i){return"function"==typeof i&&(this._callbacks[e]=i),this},Module.websocket.emit=function(e,i){"function"==typeof this._callbacks[e]&&this._callbacks[e].call(this,i)},FS.createNode(null,"/",16895,0)},createSocket:function(e,i,r){var n=1==i;r&&assert(n==(6==r));var f={family:e,type:i,protocol:r,server:null,error:null,peers:{},pending:[],recv_queue:[],sock_ops:SOCKFS.websocket_sock_ops},t=SOCKFS.nextname(),u=FS.createNode(SOCKFS.root,t,49152,0);u.sock=f;var a=FS.createStream({path:t,node:u,flags:FS.modeStringToFlags("r+"),seekable:!1,stream_ops:SOCKFS.stream_ops});return f.stream=a,f},getSocket:function(e){var i=FS.getStream(e);return i&&FS.isSocket(i.node.mode)?i.node.sock:null},stream_ops:{poll:function(e){var i=e.node.sock;return i.sock_ops.poll(i)},ioctl:function(e,i,r){var n=e.node.sock;return n.sock_ops.ioctl(n,i,r)},read:function(e,i,r,n,f){var t=e.node.sock,u=t.sock_ops.recvmsg(t,n);return u?(i.set(u.buffer,r),u.buffer.length):0},write:function(e,i,r,n,f){var t=e.node.sock;return t.sock_ops.sendmsg(t,i,r,n)},close:function(e){var i=e.node.sock;i.sock_ops.close(i)}},nextname:function(){return SOCKFS.nextname.current||(SOCKFS.nextname.current=0),"socket["+SOCKFS.nextname.current++ +"]"},websocket_sock_ops:{createPeer:function(e,i,r){var n;if("object"==typeof i&&(n=i,i=null,r=null),n)if(n._socket)i=n._socket.remoteAddress,r=n._socket.remotePort;else{var f=/ws[s]?:\/\/([^:]+):(\d+)/.exec(n.url);if(!f)throw new Error("WebSocket URL must be in the format ws(s)://address:port");i=f[1],r=parseInt(f[2],10)}else try{var t=Module.websocket&&"object"==typeof Module.websocket,u="ws:#".replace("#","//");if(t&&"string"==typeof Module.websocket.url&&(u=Module.websocket.url),"ws://"===u||"wss://"===u){var a=i.split("/");u=u+a[0]+":"+r+"/"+a.slice(1).join("/")}var o="binary";t&&"string"==typeof Module.websocket.subprotocol&&(o=Module.websocket.subprotocol),o=o.replace(/^ +| +$/g,"").split(/ *, */);var c=o,l=window.WebSocket;n=new l(u,c),n.binaryType="arraybuffer"}catch(e){throw new FS.ErrnoError(ERRNO_CODES.EHOSTUNREACH)}var s={addr:i,port:r,socket:n,dgram_send_queue:[]};return SOCKFS.websocket_sock_ops.addPeer(e,s),SOCKFS.websocket_sock_ops.handlePeerEvents(e,s),2===e.type&&"undefined"!=typeof e.sport&&s.dgram_send_queue.push(new Uint8Array([255,255,255,255,"p".charCodeAt(0),"o".charCodeAt(0),"r".charCodeAt(0),"t".charCodeAt(0),(65280&e.sport)>>8,255&e.sport])),s},getPeer:function(e,i,r){return e.peers[i+":"+r]},addPeer:function(e,i){e.peers[i.addr+":"+i.port]=i},removePeer:function(e,i){delete e.peers[i.addr+":"+i.port]},handlePeerEvents:function(e,i){function r(r){assert("string"!=typeof r&&void 0!==r.byteLength),r=new Uint8Array(r);var f=n;if(n=!1,f&&10===r.length&&255===r[0]&&255===r[1]&&255===r[2]&&255===r[3]&&r[4]==="p".charCodeAt(0)&&r[5]==="o".charCodeAt(0)&&r[6]==="r".charCodeAt(0)&&r[7]==="t".charCodeAt(0)){var t=r[8]<<8|r[9];return SOCKFS.websocket_sock_ops.removePeer(e,i),i.port=t,void SOCKFS.websocket_sock_ops.addPeer(e,i)}e.recv_queue.push({addr:i.addr,port:i.port,data:r}),Module.websocket.emit("message",e.stream.fd)}var n=!0,f=function(){Module.websocket.emit("open",e.stream.fd);try{for(var r=i.dgram_send_queue.shift();r;)i.socket.send(r),r=i.dgram_send_queue.shift()}catch(e){i.socket.close()}};i.socket.onopen=f,i.socket.onclose=function(){Module.websocket.emit("close",e.stream.fd)},i.socket.onmessage=function(e){r(e.data)},i.socket.onerror=function(i){e.error=ERRNO_CODES.ECONNREFUSED,Module.websocket.emit("error",[e.stream.fd,e.error,"ECONNREFUSED: Connection refused"])}},poll:function(e){if(1===e.type&&e.server)return e.pending.length?65:0;var i=0,r=1===e.type?SOCKFS.websocket_sock_ops.getPeer(e,e.daddr,e.dport):null;return(e.recv_queue.length||!r||r&&r.socket.readyState===r.socket.CLOSING||r&&r.socket.readyState===r.socket.CLOSED)&&(i|=65),(!r||r&&r.socket.readyState===r.socket.OPEN)&&(i|=4),(r&&r.socket.readyState===r.socket.CLOSING||r&&r.socket.readyState===r.socket.CLOSED)&&(i|=16),i},ioctl:function(e,i,r){switch(i){case 21531:var n=0;return e.recv_queue.length&&(n=e.recv_queue[0].data.length),HEAP32[r>>2]=n,0;default:return ERRNO_CODES.EINVAL}},close:function(e){if(e.server){try{e.server.close()}catch(e){}e.server=null}for(var i=Object.keys(e.peers),r=0;r<i.length;r++){var n=e.peers[i[r]];try{n.socket.close()}catch(e){}SOCKFS.websocket_sock_ops.removePeer(e,n)}return 0},bind:function(e,i,r){if("undefined"!=typeof e.saddr||"undefined"!=typeof e.sport)throw new FS.ErrnoError(ERRNO_CODES.EINVAL);if(e.saddr=i,e.sport=r||_mkport(),2===e.type){e.server&&(e.server.close(),e.server=null);try{e.sock_ops.listen(e,0)}catch(e){if(!(e instanceof FS.ErrnoError))throw e;if(e.errno!==ERRNO_CODES.EOPNOTSUPP)throw e}}},connect:function(e,i,r){if(e.server)throw new FS.ErrnoError(ERRNO_CODES.EOPNOTSUPP);if("undefined"!=typeof e.daddr&&"undefined"!=typeof e.dport){var n=SOCKFS.websocket_sock_ops.getPeer(e,e.daddr,e.dport);if(n)throw n.socket.readyState===n.socket.CONNECTING?new FS.ErrnoError(ERRNO_CODES.EALREADY):new FS.ErrnoError(ERRNO_CODES.EISCONN)}var f=SOCKFS.websocket_sock_ops.createPeer(e,i,r);throw e.daddr=f.addr,e.dport=f.port,new FS.ErrnoError(ERRNO_CODES.EINPROGRESS)},listen:function(e,i){throw new FS.ErrnoError(ERRNO_CODES.EOPNOTSUPP)},accept:function(e){if(!e.server)throw new FS.ErrnoError(ERRNO_CODES.EINVAL);var i=e.pending.shift();return i.stream.flags=e.stream.flags,i},getname:function(e,i){var r,n;if(i){if(void 0===e.daddr||void 0===e.dport)throw new FS.ErrnoError(ERRNO_CODES.ENOTCONN);r=e.daddr,n=e.dport}else r=e.saddr||0,n=e.sport||0;return{addr:r,port:n}},sendmsg:function(e,i,r,n,f,t){if(2===e.type){if(void 0!==f&&void 0!==t||(f=e.daddr,t=e.dport),void 0===f||void 0===t)throw new FS.ErrnoError(ERRNO_CODES.EDESTADDRREQ)}else f=e.daddr,t=e.dport;var u=SOCKFS.websocket_sock_ops.getPeer(e,f,t);if(1===e.type){if(!u||u.socket.readyState===u.socket.CLOSING||u.socket.readyState===u.socket.CLOSED)throw new FS.ErrnoError(ERRNO_CODES.ENOTCONN);if(u.socket.readyState===u.socket.CONNECTING)throw new FS.ErrnoError(ERRNO_CODES.EAGAIN)}var a;if(a=i instanceof Array||i instanceof ArrayBuffer?i.slice(r,r+n):i.buffer.slice(i.byteOffset+r,i.byteOffset+r+n),2===e.type&&(!u||u.socket.readyState!==u.socket.OPEN))return u&&u.socket.readyState!==u.socket.CLOSING&&u.socket.readyState!==u.socket.CLOSED||(u=SOCKFS.websocket_sock_ops.createPeer(e,f,t)),u.dgram_send_queue.push(a),n;try{return u.socket.send(a),n}catch(e){throw new FS.ErrnoError(ERRNO_CODES.EINVAL)}},recvmsg:function(e,i){if(1===e.type&&e.server)throw new FS.ErrnoError(ERRNO_CODES.ENOTCONN);var r=e.recv_queue.shift();if(!r){if(1===e.type){var n=SOCKFS.websocket_sock_ops.getPeer(e,e.daddr,e.dport);if(n){if(n.socket.readyState===n.socket.CLOSING||n.socket.readyState===n.socket.CLOSED)return null;throw new FS.ErrnoError(ERRNO_CODES.EAGAIN)}throw new FS.ErrnoError(ERRNO_CODES.ENOTCONN)}throw new FS.ErrnoError(ERRNO_CODES.EAGAIN)}var f=r.data.byteLength||r.data.length,t=r.data.byteOffset||0,u=r.data.buffer||r.data,a=Math.min(i,f),o={buffer:new Uint8Array(u,t,a),addr:r.addr,port:r.port};if(1===e.type&&a<f){var c=f-a;r.data=new Uint8Array(u,t+a,c),e.recv_queue.unshift(r)}return o}}};Module._strlen=_strlen,Module._strcat=_strcat,Module._bitshift64Shl=_bitshift64Shl,Module._strncpy=_strncpy,Module._i64Add=_i64Add;var _fabs=Math_abs,_floor=Math_floor;Module._memset=_memset;var Browser={mainLoop:{scheduler:null,method:"",currentlyRunningMainloop:0,func:null,arg:0,timingMode:0,timingValue:0,currentFrameNumber:0,queue:[],pause:function(){Browser.mainLoop.scheduler=null,Browser.mainLoop.currentlyRunningMainloop++},resume:function(){Browser.mainLoop.currentlyRunningMainloop++;var e=Browser.mainLoop.timingMode,i=Browser.mainLoop.timingValue,r=Browser.mainLoop.func;Browser.mainLoop.func=null,_emscripten_set_main_loop(r,0,!1,Browser.mainLoop.arg),_emscripten_set_main_loop_timing(e,i)},updateStatus:function(){if(Module.setStatus){var e=Module.statusMessage||"Please wait...",i=Browser.mainLoop.remainingBlockers,r=Browser.mainLoop.expectedBlockers;i?i<r?Module.setStatus(e+" ("+(r-i)+"/"+r+")"):Module.setStatus(e):Module.setStatus("")}},runIter:function(e){if(!ABORT){if(Module.preMainLoop){var i=Module.preMainLoop();if(i===!1)return}try{e()}catch(e){if(e instanceof ExitStatus)return;throw e&&"object"==typeof e&&e.stack&&Module.printErr("exception thrown: "+[e,e.stack]),e}Module.postMainLoop&&Module.postMainLoop()}}},isFullScreen:!1,pointerLock:!1,moduleContextCreatedCallbacks:[],workers:[],init:function(){function e(){Browser.pointerLock=document.pointerLockElement===n||document.mozPointerLockElement===n||document.webkitPointerLockElement===n||document.msPointerLockElement===n}if(Module.preloadPlugins||(Module.preloadPlugins=[]),!Browser.initted){Browser.initted=!0;try{new Blob,Browser.hasBlobConstructor=!0}catch(e){Browser.hasBlobConstructor=!1,console.log("warning: no blob constructor, cannot create blobs with mimetypes")}Browser.BlobBuilder="undefined"!=typeof MozBlobBuilder?MozBlobBuilder:"undefined"!=typeof WebKitBlobBuilder?WebKitBlobBuilder:Browser.hasBlobConstructor?null:console.log("warning: no BlobBuilder"),Browser.URLObject="undefined"!=typeof window?window.URL?window.URL:window.webkitURL:void 0,Module.noImageDecoding||"undefined"!=typeof Browser.URLObject||(console.log("warning: Browser does not support creating object URLs. Built-in browser image decoding will not be available."),Module.noImageDecoding=!0);var i={};i.canHandle=function(e){return!Module.noImageDecoding&&/\.(jpg|jpeg|png|bmp)$/i.test(e)},i.handle=function(e,i,r,n){var f=null;if(Browser.hasBlobConstructor)try{f=new Blob([e],{type:Browser.getMimetype(i)}),f.size!==e.length&&(f=new Blob([new Uint8Array(e).buffer],{type:Browser.getMimetype(i)}))}catch(e){Runtime.warnOnce("Blob constructor present but fails: "+e+"; falling back to blob builder")}if(!f){var t=new Browser.BlobBuilder;t.append(new Uint8Array(e).buffer),f=t.getBlob()}var u=Browser.URLObject.createObjectURL(f),a=new Image;a.onload=function(){assert(a.complete,"Image "+i+" could not be decoded");var n=document.createElement("canvas");n.width=a.width,n.height=a.height;var f=n.getContext("2d");f.drawImage(a,0,0),Module.preloadedImages[i]=n,Browser.URLObject.revokeObjectURL(u),r&&r(e)},a.onerror=function(e){console.log("Image "+u+" could not be decoded"),n&&n()},a.src=u},Module.preloadPlugins.push(i);var r={};r.canHandle=function(e){return!Module.noAudioDecoding&&e.substr(-4)in{".ogg":1,".wav":1,".mp3":1}},r.handle=function(e,i,r,n){function f(n){u||(u=!0,Module.preloadedAudios[i]=n,r&&r(e))}function t(){u||(u=!0,Module.preloadedAudios[i]=new Audio,n&&n())}var u=!1;if(!Browser.hasBlobConstructor)return t();try{var a=new Blob([e],{type:Browser.getMimetype(i)})}catch(e){return t()}var o=Browser.URLObject.createObjectURL(a),c=new Audio;c.addEventListener("canplaythrough",function(){f(c)},!1),c.onerror=function(r){function n(e){for(var i="ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/",r="=",n="",f=0,t=0,u=0;u<e.length;u++)for(f=f<<8|e[u],t+=8;t>=6;){var a=f>>t-6&63;t-=6,n+=i[a]}return 2==t?(n+=i[(3&f)<<4],n+=r+r):4==t&&(n+=i[(15&f)<<2],n+=r),n}u||(console.log("warning: browser could not fully decode audio "+i+", trying slower base64 approach"),c.src="data:audio/x-"+i.substr(-3)+";base64,"+n(e),f(c))},c.src=o,Browser.safeSetTimeout(function(){f(c)},1e4)},Module.preloadPlugins.push(r);var n=Module.canvas;n&&(n.requestPointerLock=n.requestPointerLock||n.mozRequestPointerLock||n.webkitRequestPointerLock||n.msRequestPointerLock||function(){},n.exitPointerLock=document.exitPointerLock||document.mozExitPointerLock||document.webkitExitPointerLock||document.msExitPointerLock||function(){},n.exitPointerLock=n.exitPointerLock.bind(document),document.addEventListener("pointerlockchange",e,!1),document.addEventListener("mozpointerlockchange",e,!1),document.addEventListener("webkitpointerlockchange",e,!1),document.addEventListener("mspointerlockchange",e,!1),Module.elementPointerLock&&n.addEventListener("click",function(e){!Browser.pointerLock&&n.requestPointerLock&&(n.requestPointerLock(),e.preventDefault())},!1))}},createContext:function(e,i,r,n){if(i&&Module.ctx&&e==Module.canvas)return Module.ctx;var f,t;if(i){var u={antialias:!1,alpha:!1};if(n)for(var a in n)u[a]=n[a];t=GL.createContext(e,u),t&&(f=GL.getContext(t).GLctx),e.style.backgroundColor="black"}else f=e.getContext("2d");return f?(r&&(i||assert("undefined"==typeof GLctx,"cannot set in module if GLctx is used, but we are a non-GL context that would replace it"),Module.ctx=f,i&&GL.makeContextCurrent(t),Module.useWebGL=i,Browser.moduleContextCreatedCallbacks.forEach(function(e){e()}),Browser.init()),f):null},destroyContext:function(e,i,r){},fullScreenHandlersInstalled:!1,lockPointer:void 0,resizeCanvas:void 0,requestFullScreen:function(e,i){function r(){Browser.isFullScreen=!1;var e=n.parentNode;(document.webkitFullScreenElement||document.webkitFullscreenElement||document.mozFullScreenElement||document.mozFullscreenElement||document.fullScreenElement||document.fullscreenElement||document.msFullScreenElement||document.msFullscreenElement||document.webkitCurrentFullScreenElement)===e?(n.cancelFullScreen=document.cancelFullScreen||document.mozCancelFullScreen||document.webkitCancelFullScreen||document.msExitFullscreen||document.exitFullscreen||function(){},n.cancelFullScreen=n.cancelFullScreen.bind(document),Browser.lockPointer&&n.requestPointerLock(),Browser.isFullScreen=!0,Browser.resizeCanvas&&Browser.setFullScreenCanvasSize()):(e.parentNode.insertBefore(n,e),e.parentNode.removeChild(e),Browser.resizeCanvas&&Browser.setWindowedCanvasSize()),Module.onFullScreen&&Module.onFullScreen(Browser.isFullScreen),Browser.updateCanvasDimensions(n)}Browser.lockPointer=e,Browser.resizeCanvas=i,"undefined"==typeof Browser.lockPointer&&(Browser.lockPointer=!0),"undefined"==typeof Browser.resizeCanvas&&(Browser.resizeCanvas=!1);var n=Module.canvas;Browser.fullScreenHandlersInstalled||(Browser.fullScreenHandlersInstalled=!0,document.addEventListener("fullscreenchange",r,!1),document.addEventListener("mozfullscreenchange",r,!1),document.addEventListener("webkitfullscreenchange",r,!1),document.addEventListener("MSFullscreenChange",r,!1));var f=document.createElement("div");n.parentNode.insertBefore(f,n),f.appendChild(n),f.requestFullScreen=f.requestFullScreen||f.mozRequestFullScreen||f.msRequestFullscreen||(f.webkitRequestFullScreen?function(){f.webkitRequestFullScreen(Element.ALLOW_KEYBOARD_INPUT)}:null),f.requestFullScreen()},nextRAF:0,fakeRequestAnimationFrame:function(e){var i=Date.now();if(0===Browser.nextRAF)Browser.nextRAF=i+1e3/60;else for(;i+2>=Browser.nextRAF;)Browser.nextRAF+=1e3/60;var r=Math.max(Browser.nextRAF-i,0);setTimeout(e,r)},requestAnimationFrame:function(e){"undefined"==typeof window?Browser.fakeRequestAnimationFrame(e):(window.requestAnimationFrame||(window.requestAnimationFrame=window.requestAnimationFrame||window.mozRequestAnimationFrame||window.webkitRequestAnimationFrame||window.msRequestAnimationFrame||window.oRequestAnimationFrame||Browser.fakeRequestAnimationFrame),window.requestAnimationFrame(e))},safeCallback:function(e){return function(){if(!ABORT)return e.apply(null,arguments)}},safeRequestAnimationFrame:function(e){return Browser.requestAnimationFrame(function(){ABORT||e()})},safeSetTimeout:function(e,i){return Module.noExitRuntime=!0,setTimeout(function(){ABORT||e()},i)},safeSetInterval:function(e,i){return Module.noExitRuntime=!0,setInterval(function(){ABORT||e()},i)},getMimetype:function(e){return{jpg:"image/jpeg",jpeg:"image/jpeg",png:"image/png",bmp:"image/bmp",ogg:"audio/ogg",wav:"audio/wav",mp3:"audio/mpeg"}[e.substr(e.lastIndexOf(".")+1)]},getUserMedia:function(e){window.getUserMedia||(window.getUserMedia=navigator.getUserMedia||navigator.mozGetUserMedia),window.getUserMedia(e)},getMovementX:function(e){return e.movementX||e.mozMovementX||e.webkitMovementX||0},getMovementY:function(e){return e.movementY||e.mozMovementY||e.webkitMovementY||0},getMouseWheelDelta:function(e){var i=0;switch(e.type){case"DOMMouseScroll":i=e.detail;break;case"mousewheel":i=e.wheelDelta;break;case"wheel":i=e.deltaY;break;default:throw"unrecognized mouse wheel event: "+e.type}return i},mouseX:0,mouseY:0,mouseMovementX:0,mouseMovementY:0,touches:{},lastTouches:{},calculateMouseEvent:function(e){if(Browser.pointerLock)"mousemove"!=e.type&&"mozMovementX"in e?Browser.mouseMovementX=Browser.mouseMovementY=0:(Browser.mouseMovementX=Browser.getMovementX(e),Browser.mouseMovementY=Browser.getMovementY(e)),"undefined"!=typeof SDL?(Browser.mouseX=SDL.mouseX+Browser.mouseMovementX,Browser.mouseY=SDL.mouseY+Browser.mouseMovementY):(Browser.mouseX+=Browser.mouseMovementX,Browser.mouseY+=Browser.mouseMovementY);else{var i=Module.canvas.getBoundingClientRect(),r=Module.canvas.width,n=Module.canvas.height,f="undefined"!=typeof window.scrollX?window.scrollX:window.pageXOffset,t="undefined"!=typeof window.scrollY?window.scrollY:window.pageYOffset;if("touchstart"===e.type||"touchend"===e.type||"touchmove"===e.type){var u=e.touch;if(void 0===u)return;var a=u.pageX-(f+i.left),o=u.pageY-(t+i.top);a*=r/i.width,o*=n/i.height;var c={x:a,y:o};return void("touchstart"===e.type?(Browser.lastTouches[u.identifier]=c,Browser.touches[u.identifier]=c):"touchend"!==e.type&&"touchmove"!==e.type||(Browser.lastTouches[u.identifier]=Browser.touches[u.identifier],Browser.touches[u.identifier]={x:a,y:o}))}var l=e.pageX-(f+i.left),s=e.pageY-(t+i.top);l*=r/i.width,s*=n/i.height,Browser.mouseMovementX=l-Browser.mouseX,Browser.mouseMovementY=s-Browser.mouseY,Browser.mouseX=l,Browser.mouseY=s}},xhrLoad:function(e,i,r){var n=new XMLHttpRequest;n.open("GET",e,!0),n.responseType="arraybuffer",n.onload=function(){200==n.status||0==n.status&&n.response?i(n.response):r()},n.onerror=r,n.send(null)},asyncLoad:function(e,i,r,n){Browser.xhrLoad(e,function(r){assert(r,'Loading data file "'+e+'" failed (no arrayBuffer).'),i(new Uint8Array(r)),n||removeRunDependency("al "+e)},function(i){if(!r)throw'Loading data file "'+e+'" failed.';r()}),n||addRunDependency("al "+e)},resizeListeners:[],updateResizeListeners:function(){var e=Module.canvas;Browser.resizeListeners.forEach(function(i){i(e.width,e.height)})},setCanvasSize:function(e,i,r){var n=Module.canvas;Browser.updateCanvasDimensions(n,e,i),r||Browser.updateResizeListeners()},windowedWidth:0,windowedHeight:0,setFullScreenCanvasSize:function(){if("undefined"!=typeof SDL){var e=HEAPU32[SDL.screen+0*Runtime.QUANTUM_SIZE>>2];e|=8388608,HEAP32[SDL.screen+0*Runtime.QUANTUM_SIZE>>2]=e}Browser.updateResizeListeners()},setWindowedCanvasSize:function(){if("undefined"!=typeof SDL){var e=HEAPU32[SDL.screen+0*Runtime.QUANTUM_SIZE>>2];e&=-8388609,HEAP32[SDL.screen+0*Runtime.QUANTUM_SIZE>>2]=e}Browser.updateResizeListeners()},updateCanvasDimensions:function(e,i,r){i&&r?(e.widthNative=i,e.heightNative=r):(i=e.widthNative,r=e.heightNative);var n=i,f=r;if(Module.forcedAspectRatio&&Module.forcedAspectRatio>0&&(n/f<Module.forcedAspectRatio?n=Math.round(f*Module.forcedAspectRatio):f=Math.round(n/Module.forcedAspectRatio)),(document.webkitFullScreenElement||document.webkitFullscreenElement||document.mozFullScreenElement||document.mozFullscreenElement||document.fullScreenElement||document.fullscreenElement||document.msFullScreenElement||document.msFullscreenElement||document.webkitCurrentFullScreenElement)===e.parentNode&&"undefined"!=typeof screen){var t=Math.min(screen.width/n,screen.height/f);n=Math.round(n*t),f=Math.round(f*t)}Browser.resizeCanvas?(e.width!=n&&(e.width=n),e.height!=f&&(e.height=f),"undefined"!=typeof e.style&&(e.style.removeProperty("width"),e.style.removeProperty("height"))):(e.width!=i&&(e.width=i),e.height!=r&&(e.height=r),"undefined"!=typeof e.style&&(n!=i||f!=r?(e.style.setProperty("width",n+"px","important"),e.style.setProperty("height",f+"px","important")):(e.style.removeProperty("width"),e.style.removeProperty("height"))))},wgetRequests:{},nextWgetRequestHandle:0,getNextWgetRequestHandle:function(){var e=Browser.nextWgetRequestHandle;return Browser.nextWgetRequestHandle++,e}};Module._bitshift64Lshr=_bitshift64Lshr;var _BDtoILow=!0,_BDtoIHigh=!0,_environ=allocate(1,"i32*",ALLOC_STATIC),___environ=_environ,ENV={},_labs=Math_abs;Module._memcpy=_memcpy;var _llvm_pow_f64=Math_pow;Module._memmove=_memmove;var _BItoD=!0;Module._strcpy=_strcpy;var ctlz_i8=allocate([8,7,6,6,5,5,5,5,4,4,4,4,4,4,4,4,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0],"i8",ALLOC_STATIC);Module._llvm_ctlz_i32=_llvm_ctlz_i32,FS.staticInit(),__ATINIT__.unshift({func:function(){Module.noFSInit||FS.init.initialized||FS.init()}}),__ATMAIN__.push({func:function(){FS.ignorePermissions=!1}}),__ATEXIT__.push({func:function(){FS.quit()}}),Module.FS_createFolder=FS.createFolder,Module.FS_createPath=FS.createPath,Module.FS_createDataFile=FS.createDataFile,Module.FS_createPreloadedFile=FS.createPreloadedFile,Module.FS_createLazyFile=FS.createLazyFile,Module.FS_createLink=FS.createLink,Module.FS_createDevice=FS.createDevice,___errno_state=Runtime.staticAlloc(4),HEAP32[___errno_state>>2]=0,__ATINIT__.unshift({func:function(){TTY.init()}}),__ATEXIT__.push({func:function(){TTY.shutdown()}}),TTY.utf8=new Runtime.UTF8Processor,__ATINIT__.push({func:function(){SOCKFS.root=FS.mount(SOCKFS,{},null)}}),_fgetc.ret=allocate([0],"i8",ALLOC_STATIC),_fputc.ret=allocate([0],"i8",ALLOC_STATIC),Module.requestFullScreen=function(e,i){Browser.requestFullScreen(e,i)},Module.requestAnimationFrame=function(e){Browser.requestAnimationFrame(e)},Module.setCanvasSize=function(e,i,r){Browser.setCanvasSize(e,i,r)},Module.pauseMainLoop=function(){Browser.mainLoop.pause()},Module.resumeMainLoop=function(){Browser.mainLoop.resume()},Module.getUserMedia=function(){Browser.getUserMedia()},___buildEnvironment(ENV),STACK_BASE=STACKTOP=Runtime.alignMemory(STATICTOP),staticSealed=!0,STACK_MAX=STACK_BASE+TOTAL_STACK,DYNAMIC_BASE=DYNAMICTOP=Runtime.alignMemory(STACK_MAX),assert(DYNAMIC_BASE<TOTAL_MEMORY,"TOTAL_MEMORY not big enough for stack");var cttz_i8=allocate([8,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,5,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,6,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,5,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,7,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,5,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,6,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,5,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0],"i8",ALLOC_DYNAMIC);Module.asmGlobalArg={Math:Math,Int8Array:Int8Array,Int16Array:Int16Array,Int32Array:Int32Array,Uint8Array:Uint8Array,Uint16Array:Uint16Array,Uint32Array:Uint32Array,Float32Array:Float32Array,Float64Array:Float64Array},Module.asmLibraryArg={abort:abort,assert:assert,min:Math_min,invoke_iiiiiiii:invoke_iiiiiiii,invoke_iiii:invoke_iiii,invoke_viiiiiii:invoke_viiiiiii,invoke_viiiii:invoke_viiiii,invoke_i:invoke_i,invoke_vi:invoke_vi,invoke_vii:invoke_vii,invoke_iiiiiii:invoke_iiiiiii,invoke_ii:invoke_ii,invoke_viii:invoke_viii,invoke_viiiiiiiii:invoke_viiiiiiiii,invoke_iiiii:invoke_iiiii,invoke_viiiiii:invoke_viiiiii,invoke_iii:invoke_iii,invoke_iiiiii:invoke_iiiiii,invoke_viiii:invoke_viiii,_fabs:_fabs,_llvm_pow_f64:_llvm_pow_f64,_send:_send,_getcwd:_getcwd,_fread:_fread,__reallyNegative:__reallyNegative,_vfprintf:_vfprintf,_emscripten_set_main_loop_timing:_emscripten_set_main_loop_timing,___assert_fail:___assert_fail,_floor:_floor,_fflush:_fflush,_llvm_ctlz_i64:_llvm_ctlz_i64,_pwrite:_pwrite,_strerror_r:_strerror_r,_fprintf:_fprintf,_open:_open,_sbrk:_sbrk,_emscripten_memcpy_big:_emscripten_memcpy_big,_fileno:_fileno,__formatString:__formatString,__exit:__exit,_close:_close,_ferror:_ferror,_munmap:_munmap,___buildEnvironment:___buildEnvironment,_pread:_pread,_printf:_printf,_fclose:_fclose,_write:_write,_fsync:_fsync,___errno_location:___errno_location,_stat:_stat,_recv:_recv,_fgetc:_fgetc,_getenv:_getenv,_sysconf:_sysconf,
	_read:_read,_fputc:_fputc,_emscripten_set_main_loop:_emscripten_set_main_loop,_abort:_abort,_fwrite:_fwrite,_time:_time,_mkport:_mkport,_strerror:_strerror,_gettimeofday:_gettimeofday,_fgets:_fgets,_mmap:_mmap,_fopen:_fopen,_exit:_exit,_labs:_labs,___setErrNo:___setErrNo,STACKTOP:STACKTOP,STACK_MAX:STACK_MAX,tempDoublePtr:tempDoublePtr,ABORT:ABORT,cttz_i8:cttz_i8,ctlz_i8:ctlz_i8,NaN:NaN,Infinity:1/0,_stderr:_stderr,_stdin:_stdin,_stdout:_stdout};var asm=function(e,i,r){"use asm";var n=new e.Int8Array(r);var f=new e.Int16Array(r);var t=new e.Int32Array(r);var u=new e.Uint8Array(r);var a=new e.Uint16Array(r);var o=new e.Uint32Array(r);var c=new e.Float32Array(r);var l=new e.Float64Array(r);var s=i.STACKTOP|0;var b=i.STACK_MAX|0;var k=i.tempDoublePtr|0;var h=i.ABORT|0;var w=i.cttz_i8|0;var d=i.ctlz_i8|0;var v=i._stderr|0;var m=i._stdin|0;var _=i._stdout|0;var p=0;var E=0;var S=0;var g=0;var y=+i.NaN,F=+i.Infinity;var O=0,A=0,M=0,R=0,N=0,T=0,L=0,D=0,C=0;var P=0;var B=0;var I=0;var H=0;var x=0;var U=0;var z=0;var j=0;var V=0;var q=0;var Y=e.Math.floor;var G=e.Math.abs;var W=e.Math.sqrt;var K=e.Math.pow;var X=e.Math.cos;var Z=e.Math.sin;var J=e.Math.tan;var Q=e.Math.acos;var $=e.Math.asin;var ee=e.Math.atan;var ie=e.Math.atan2;var re=e.Math.exp;var ne=e.Math.log;var fe=e.Math.ceil;var te=e.Math.imul;var ue=i.abort;var ae=i.assert;var oe=i.min;var ce=i.invoke_iiiiiiii;var le=i.invoke_iiii;var se=i.invoke_viiiiiii;var be=i.invoke_viiiii;var ke=i.invoke_i;var he=i.invoke_vi;var we=i.invoke_vii;var de=i.invoke_iiiiiii;var ve=i.invoke_ii;var me=i.invoke_viii;var _e=i.invoke_viiiiiiiii;var pe=i.invoke_iiiii;var Ee=i.invoke_viiiiii;var Se=i.invoke_iii;var ge=i.invoke_iiiiii;var ye=i.invoke_viiii;var Fe=i._fabs;var Oe=i._llvm_pow_f64;var Ae=i._send;var Me=i._getcwd;var Re=i._fread;var Ne=i.__reallyNegative;var Te=i._vfprintf;var Le=i._emscripten_set_main_loop_timing;var De=i.___assert_fail;var Ce=i._floor;var Pe=i._fflush;var Be=i._llvm_ctlz_i64;var Ie=i._pwrite;var He=i._strerror_r;var xe=i._fprintf;var Ue=i._open;var ze=i._sbrk;var je=i._emscripten_memcpy_big;var Ve=i._fileno;var qe=i.__formatString;var Ye=i.__exit;var Ge=i._close;var We=i._ferror;var Ke=i._munmap;var Xe=i.___buildEnvironment;var Ze=i._pread;var Je=i._printf;var Qe=i._fclose;var $e=i._write;var ei=i._fsync;var ii=i.___errno_location;var ri=i._stat;var ni=i._recv;var fi=i._fgetc;var ti=i._getenv;var ui=i._sysconf;var ai=i._read;var oi=i._fputc;var ci=i._emscripten_set_main_loop;var li=i._abort;var si=i._fwrite;var bi=i._time;var ki=i._mkport;var hi=i._strerror;var wi=i._gettimeofday;var di=i._fgets;var vi=i._mmap;var mi=i._fopen;var _i=i._exit;var pi=i._labs;var Ei=i.___setErrNo;var Si=0;function gi(e){e=e|0;var i=0,r=0,n=0,f=0,a=0,o=0,c=0,l=0,b=0,k=0;i=s;s=s+32|0;r=i+20|0;n=i+16|0;f=i+12|0;a=i+8|0;o=i+4|0;c=i;t[n>>2]=e;if((u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==60?(u[(t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]|0)+1>>0]|0|0)==47:0){e=(t[n>>2]|0)+200|0;t[e>>2]=(t[e>>2]|0)+2;e=(t[(t[n>>2]|0)+36>>2]|0)+16|0;t[e>>2]=(t[e>>2]|0)+2;e=(t[(t[n>>2]|0)+36>>2]|0)+32|0;t[e>>2]=(t[e>>2]|0)+2;t[f>>2]=QN(t[n>>2]|0)|0;if(!(t[f>>2]|0)){t[r>>2]=0;l=t[r>>2]|0;s=i;return l|0}jN(t[n>>2]|0)|0;if(9<=(u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)?(u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)<=10:0)b=10;else if((u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)!=13?32>(u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0):0)b=11;else b=10;if((b|0)==10)if((u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)!=62)b=11;else Op(t[n>>2]|0);e:do if((b|0)==11?(BN(t[n>>2]|0,73,95624,0,0),(t[(t[n>>2]|0)+288>>2]|0)!=0):0){while(1){k=t[n>>2]|0;if(!(u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0))break;e=(u[t[(t[k+36>>2]|0)+16>>2]>>0]|0|0)!=62;Op(t[n>>2]|0);if(!e)break e}Op(k)}while(0);do if((t[(t[n>>2]|0)+248>>2]|0)>0){if(((Xl(t[f>>2]|0,94240)|0)==0?(Xl(t[f>>2]|0,95648)|0)==0:0)?(Xl(t[f>>2]|0,95656)|0)==0:0)break;k=(t[n>>2]|0)+248|0;t[k>>2]=(t[k>>2]|0)+-1;t[r>>2]=0;l=t[r>>2]|0;s=i;return l|0}while(0);t[o>>2]=(t[(t[n>>2]|0)+188>>2]|0)-1;while(1){if((t[o>>2]|0)<0)break;if(Xl(t[f>>2]|0,t[(t[(t[n>>2]|0)+196>>2]|0)+(t[o>>2]<<2)>>2]|0)|0)break;t[o>>2]=(t[o>>2]|0)+-1}k=t[n>>2]|0;b=t[f>>2]|0;if((t[o>>2]|0)<0){BN(k,76,95664,b,0);t[r>>2]=0;l=t[r>>2]|0;s=i;return l|0}Hi(k,b);if(((Xl(t[f>>2]|0,t[(t[n>>2]|0)+184>>2]|0)|0)==0?(t[(t[n>>2]|0)+184>>2]|0)!=0:0)?(Xl(t[(t[n>>2]|0)+184>>2]|0,t[f>>2]|0)|0)==0:0)BN(t[n>>2]|0,76,95696,t[f>>2]|0,t[(t[n>>2]|0)+184>>2]|0);t[a>>2]=t[(t[n>>2]|0)+184>>2];if((t[a>>2]|0)!=0?(Xl(t[a>>2]|0,t[f>>2]|0)|0)!=0:0){if((t[t[n>>2]>>2]|0)!=0?(t[(t[t[n>>2]>>2]|0)+60>>2]|0)!=0:0)EAi[t[(t[t[n>>2]>>2]|0)+60>>2]&511](t[(t[n>>2]|0)+4>>2]|0,t[f>>2]|0);xi(t[n>>2]|0)|0;xN(t[n>>2]|0)|0;t[c>>2]=1}else t[c>>2]=0;t[r>>2]=t[c>>2];l=t[r>>2]|0;s=i;return l|0}BN(t[n>>2]|0,74,95584,0,0);t[r>>2]=0;l=t[r>>2]|0;s=i;return l|0}function yi(e){e=e|0;var i=0,r=0,f=0,a=0,o=0,c=0,l=0;i=s;s=s+112|0;r=i+8|0;f=i+4|0;a=i;o=i+12|0;t[f>>2]=e;t[a>>2]=0;if(!(65<=(u[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+1>>0]|0|0)?(u[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+1>>0]|0|0)<=90:0))c=3;do if((c|0)==3){if(97<=(u[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+1>>0]|0|0)?(u[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+1>>0]|0|0)<=122:0)break;if((u[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+1>>0]|0|0)!=95?(u[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+1>>0]|0|0)!=58:0){t[r>>2]=0;l=t[r>>2]|0;s=i;return l|0}}while(0);e:while(1){if((t[a>>2]|0)>=100)break;if(!(65<=(u[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+(1+(t[a>>2]|0))>>0]|0|0)?(u[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+(1+(t[a>>2]|0))>>0]|0|0)<=90:0))c=11;do if((c|0)==11){c=0;if(97<=(u[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+(1+(t[a>>2]|0))>>0]|0|0)?(u[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+(1+(t[a>>2]|0))>>0]|0|0)<=122:0)break;if(48<=(u[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+(1+(t[a>>2]|0))>>0]|0|0)?(u[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+(1+(t[a>>2]|0))>>0]|0|0)<=57:0)break;if(((u[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+(1+(t[a>>2]|0))>>0]|0|0)!=58?(u[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+(1+(t[a>>2]|0))>>0]|0|0)!=45:0)?(u[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+(1+(t[a>>2]|0))>>0]|0|0)!=95:0)break e}while(0);if((u[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+(1+(t[a>>2]|0))>>0]|0|0)>=65?(u[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+(1+(t[a>>2]|0))>>0]|0|0)<=90:0)n[o+(t[a>>2]|0)>>0]=(u[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+(1+(t[a>>2]|0))>>0]|0)+32;else n[o+(t[a>>2]|0)>>0]=n[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+(1+(t[a>>2]|0))>>0]|0;t[a>>2]=(t[a>>2]|0)+1}t[r>>2]=kz(t[(t[f>>2]|0)+296>>2]|0,o,t[a>>2]|0)|0;l=t[r>>2]|0;s=i;return l|0}function Fi(e){e=e|0;var i=0,r=0,f=0,a=0,o=0,c=0,l=0,b=0;i=s;s=s+1024|0;r=i+12|0;f=i+16|0;a=i+8|0;o=i+4|0;c=i;t[r>>2]=e;t[a>>2]=0;if(((t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)-(t[(t[(t[r>>2]|0)+36>>2]|0)+12>>2]|0)|0)>500?((t[(t[(t[r>>2]|0)+36>>2]|0)+20>>2]|0)-(t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)|0)<500:0)Fp(t[(t[r>>2]|0)+36>>2]|0);t[o>>2]=Ni(t[r>>2]|0,c)|0;e:while(1){if(!(9<=(t[o>>2]|0)&(t[o>>2]|0)<=10|(t[o>>2]|0)==13|32<=(t[o>>2]|0)))break;do if((t[o>>2]|0)==60?(u[(t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)+1>>0]|0|0)==47:0){e=t[r>>2]|0;if(t[(t[r>>2]|0)+288>>2]|0){l=t[e+184>>2]|0;b=(t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)+2|0;if(!($l(l,b,rs(t[(t[r>>2]|0)+184>>2]|0)|0)|0))break e;BN(t[r>>2]|0,76,95912,t[(t[r>>2]|0)+184>>2]|0,0);break}if((u[(t[(t[e+36>>2]|0)+16>>2]|0)+2>>0]|0|0)>=65?(u[(t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)+2>>0]|0|0)<=90:0)break e;if((u[(t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)+2>>0]|0|0)>=97?(u[(t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)+2>>0]|0|0)<=122:0)break e}while(0);if((t[c>>2]|0)==1){e=t[o>>2]&255;b=t[a>>2]|0;t[a>>2]=b+1;n[f+b>>0]=e}else{e=Np(t[c>>2]|0,f+(t[a>>2]|0)|0,t[o>>2]|0)|0;t[a>>2]=(t[a>>2]|0)+e}if((t[a>>2]|0)>=1e3){e=t[t[r>>2]>>2]|0;if(!(t[(t[t[r>>2]>>2]|0)+100>>2]|0)){if(t[e+68>>2]|0)yAi[t[(t[t[r>>2]>>2]|0)+68>>2]&511](t[(t[r>>2]|0)+4>>2]|0,f,t[a>>2]|0)}else yAi[t[e+100>>2]&511](t[(t[r>>2]|0)+4>>2]|0,f,t[a>>2]|0);t[a>>2]=0}if((t[(t[r>>2]|0)+292>>2]|0)==0?((t[(t[(t[r>>2]|0)+36>>2]|0)+20>>2]|0)-(t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)|0)<250:0)yp(t[(t[r>>2]|0)+36>>2]|0,250)|0;e=t[(t[r>>2]|0)+36>>2]|0;if((u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==10){b=e+28|0;t[b>>2]=(t[b>>2]|0)+1;t[(t[(t[r>>2]|0)+36>>2]|0)+32>>2]=1}else{b=e+32|0;t[b>>2]=(t[b>>2]|0)+1}t[(t[r>>2]|0)+176>>2]=0;b=(t[(t[r>>2]|0)+36>>2]|0)+16|0;t[b>>2]=(t[b>>2]|0)+(t[c>>2]|0);b=(t[r>>2]|0)+200|0;t[b>>2]=(t[b>>2]|0)+1;t[o>>2]=Ni(t[r>>2]|0,c)|0}do if(!(9<=(t[o>>2]|0)&(t[o>>2]|0)<=10|(t[o>>2]|0)==13|32<=(t[o>>2]|0))){if((t[o>>2]|0)==0?(t[(t[r>>2]|0)+292>>2]|0)!=0:0)break;IN(t[r>>2]|0,9,95944,t[o>>2]|0);if((t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)>>>0<(t[(t[(t[r>>2]|0)+36>>2]|0)+20>>2]|0)>>>0)Op(t[r>>2]|0)}while(0);if(!(t[a>>2]|0)){s=i;return}if(!(t[t[r>>2]>>2]|0)){s=i;return}if(t[(t[r>>2]|0)+212>>2]|0){s=i;return}o=t[t[r>>2]>>2]|0;if(t[(t[t[r>>2]>>2]|0)+100>>2]|0){yAi[t[o+100>>2]&511](t[(t[r>>2]|0)+4>>2]|0,f,t[a>>2]|0);s=i;return}if(!(t[o+68>>2]|0)){s=i;return}yAi[t[(t[t[r>>2]>>2]|0)+68>>2]&511](t[(t[r>>2]|0)+4>>2]|0,f,t[a>>2]|0);s=i;return}function Oi(e){e=e|0;var i=0,r=0,f=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0;i=s;s=s+48|0;r=i+32|0;f=i+28|0;a=i+36|0;o=i+24|0;c=i+20|0;l=i+16|0;b=i+12|0;k=i+8|0;h=i+4|0;w=i;t[r>>2]=e;if((u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)!=38){s=i;return}if((u[(t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)+1>>0]|0|0)==35){t[b>>2]=0;t[c>>2]=_N(t[r>>2]|0)|0;if(!(t[c>>2]|0)){s=i;return}e=t[c>>2]|0;do if((t[c>>2]|0)>>>0>=128){d=t[c>>2]|0;if(e>>>0<2048){v=t[b>>2]|0;t[b>>2]=v+1;n[a+v>>0]=d>>>6&31|192;t[l>>2]=0;break}v=t[c>>2]|0;if(d>>>0<65536){d=t[b>>2]|0;t[b>>2]=d+1;n[a+d>>0]=v>>>12&15|224;t[l>>2]=6;break}else{d=t[b>>2]|0;t[b>>2]=d+1;n[a+d>>0]=v>>>18&7|240;t[l>>2]=12;break}}else{v=t[b>>2]|0;t[b>>2]=v+1;n[a+v>>0]=e;t[l>>2]=-6}while(0);while(1){if((t[l>>2]|0)<0)break;e=((t[c>>2]|0)>>>(t[l>>2]|0)&63|128)&255;v=t[b>>2]|0;t[b>>2]=v+1;n[a+v>>0]=e;t[l>>2]=(t[l>>2]|0)-6}n[a+(t[b>>2]|0)>>0]=0;Ci(t[r>>2]|0)|0;if(!(t[t[r>>2]>>2]|0)){s=i;return}if(!(t[(t[t[r>>2]>>2]|0)+68>>2]|0)){s=i;return}yAi[t[(t[t[r>>2]>>2]|0)+68>>2]&511](t[(t[r>>2]|0)+4>>2]|0,a,t[b>>2]|0);s=i;return}t[f>>2]=mN(t[r>>2]|0,o)|0;if(!(t[o>>2]|0)){Ci(t[r>>2]|0)|0;if(!(t[t[r>>2]>>2]|0)){s=i;return}if(!(t[(t[t[r>>2]>>2]|0)+68>>2]|0)){s=i;return}yAi[t[(t[t[r>>2]>>2]|0)+68>>2]&511](t[(t[r>>2]|0)+4>>2]|0,95904,1);s=i;return}if((t[f>>2]|0)!=0?(t[t[f>>2]>>2]|0)>>>0>0:0){t[w>>2]=0;t[k>>2]=t[t[f>>2]>>2];f=t[k>>2]|0;do if((t[k>>2]|0)>>>0>=128){b=t[k>>2]|0;if(f>>>0<2048){l=t[w>>2]|0;t[w>>2]=l+1;n[a+l>>0]=b>>>6&31|192;t[h>>2]=0;break}l=t[k>>2]|0;if(b>>>0<65536){b=t[w>>2]|0;t[w>>2]=b+1;n[a+b>>0]=l>>>12&15|224;t[h>>2]=6;break}else{b=t[w>>2]|0;t[w>>2]=b+1;n[a+b>>0]=l>>>18&7|240;t[h>>2]=12;break}}else{l=t[w>>2]|0;t[w>>2]=l+1;n[a+l>>0]=f;t[h>>2]=-6}while(0);while(1){if((t[h>>2]|0)<0)break;f=((t[k>>2]|0)>>>(t[h>>2]|0)&63|128)&255;l=t[w>>2]|0;t[w>>2]=l+1;n[a+l>>0]=f;t[h>>2]=(t[h>>2]|0)-6}n[a+(t[w>>2]|0)>>0]=0;Ci(t[r>>2]|0)|0;if(!(t[t[r>>2]>>2]|0)){s=i;return}if(!(t[(t[t[r>>2]>>2]|0)+68>>2]|0)){s=i;return}yAi[t[(t[t[r>>2]>>2]|0)+68>>2]&511](t[(t[r>>2]|0)+4>>2]|0,a,t[w>>2]|0);s=i;return}Ci(t[r>>2]|0)|0;if(!(t[t[r>>2]>>2]|0)){s=i;return}if(!(t[(t[t[r>>2]>>2]|0)+68>>2]|0)){s=i;return}yAi[t[(t[t[r>>2]>>2]|0)+68>>2]&511](t[(t[r>>2]|0)+4>>2]|0,95904,1);w=t[(t[t[r>>2]>>2]|0)+68>>2]|0;a=t[(t[r>>2]|0)+4>>2]|0;r=t[o>>2]|0;h=rs(t[o>>2]|0)|0;yAi[w&511](a,r,h);s=i;return}function Ai(e){e=e|0;var i=0,r=0,f=0,a=0,o=0,c=0,l=0,b=0,k=0;i=s;s=s+1040|0;r=i+16|0;f=i+20|0;a=i+12|0;o=i+8|0;c=i+4|0;l=i;t[r>>2]=e;t[a>>2]=0;t[l>>2]=0;if(((t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)-(t[(t[(t[r>>2]|0)+36>>2]|0)+12>>2]|0)|0)>500?((t[(t[(t[r>>2]|0)+36>>2]|0)+20>>2]|0)-(t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)|0)<500:0)Fp(t[(t[r>>2]|0)+36>>2]|0);t[o>>2]=Ni(t[r>>2]|0,c)|0;while(1){if((t[o>>2]|0)==60?(t[(t[r>>2]|0)+176>>2]|0)!=60:0)break;if((t[o>>2]|0)!=38){if(!(t[o>>2]|0))break}else if(!((t[o>>2]|0)!=0?(t[(t[r>>2]|0)+176>>2]|0)==38:0))break;e=t[o>>2]|0;if((t[o>>2]|0)<256)if(9<=(e|0)&(t[o>>2]|0)<=10|(t[o>>2]|0)==13|32<=(t[o>>2]|0))b=16;else b=15;else if((!(256<=(e|0)&(t[o>>2]|0)<=55295)?!(57344<=(t[o>>2]|0)&(t[o>>2]|0)<=65533):0)?!(65536<=(t[o>>2]|0)&(t[o>>2]|0)<=1114111):0)b=15;else b=16;do if((b|0)==15){b=0;IN(t[r>>2]|0,9,95944,t[o>>2]|0)}else if((b|0)==16){b=0;if((t[c>>2]|0)==1){e=t[o>>2]&255;k=t[a>>2]|0;t[a>>2]=k+1;n[f+k>>0]=e;break}else{e=Np(t[c>>2]|0,f+(t[a>>2]|0)|0,t[o>>2]|0)|0;t[a>>2]=(t[a>>2]|0)+e;break}}while(0);if((t[a>>2]|0)>=1e3){do if((t[t[r>>2]>>2]|0)!=0?(t[(t[r>>2]|0)+212>>2]|0)==0:0){e=(Ui(t[r>>2]|0,f,t[a>>2]|0)|0)!=0;k=t[r>>2]|0;if(!e){Ci(k)|0;if(!(t[(t[t[r>>2]>>2]|0)+68>>2]|0))break;yAi[t[(t[t[r>>2]>>2]|0)+68>>2]&511](t[(t[r>>2]|0)+4>>2]|0,f,t[a>>2]|0);break}e=t[t[r>>2]>>2]|0;if(t[k+208>>2]|0){if(!(t[e+68>>2]|0))break;yAi[t[(t[t[r>>2]>>2]|0)+68>>2]&511](t[(t[r>>2]|0)+4>>2]|0,f,t[a>>2]|0);break}else{if(!(t[e+72>>2]|0))break;yAi[t[(t[t[r>>2]>>2]|0)+72>>2]&511](t[(t[r>>2]|0)+4>>2]|0,f,t[a>>2]|0);break}}while(0);t[a>>2]=0}e=t[(t[r>>2]|0)+36>>2]|0;if((u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==10){k=e+28|0;t[k>>2]=(t[k>>2]|0)+1;t[(t[(t[r>>2]|0)+36>>2]|0)+32>>2]=1}else{k=e+32|0;t[k>>2]=(t[k>>2]|0)+1}t[(t[r>>2]|0)+176>>2]=0;k=(t[(t[r>>2]|0)+36>>2]|0)+16|0;t[k>>2]=(t[k>>2]|0)+(t[c>>2]|0);k=(t[r>>2]|0)+200|0;t[k>>2]=(t[k>>2]|0)+1;t[l>>2]=(t[l>>2]|0)+1;if((t[l>>2]|0)>100){t[l>>2]=0;if(((t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)-(t[(t[(t[r>>2]|0)+36>>2]|0)+12>>2]|0)|0)>500?((t[(t[(t[r>>2]|0)+36>>2]|0)+20>>2]|0)-(t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)|0)<500:0)Fp(t[(t[r>>2]|0)+36>>2]|0);if((t[(t[r>>2]|0)+292>>2]|0)==0?((t[(t[(t[r>>2]|0)+36>>2]|0)+20>>2]|0)-(t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)|0)<250:0)yp(t[(t[r>>2]|0)+36>>2]|0,250)|0}t[o>>2]=Ni(t[r>>2]|0,c)|0;if(t[o>>2]|0)continue;if(((t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)-(t[(t[(t[r>>2]|0)+36>>2]|0)+12>>2]|0)|0)>500?((t[(t[(t[r>>2]|0)+36>>2]|0)+20>>2]|0)-(t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)|0)<500:0)Fp(t[(t[r>>2]|0)+36>>2]|0);if((t[(t[r>>2]|0)+292>>2]|0)==0?((t[(t[(t[r>>2]|0)+36>>2]|0)+20>>2]|0)-(t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)|0)<250:0)yp(t[(t[r>>2]|0)+36>>2]|0,250)|0;t[o>>2]=Ni(t[r>>2]|0,c)|0}if(!(t[a>>2]|0)){if(t[o>>2]|0){s=i;return}t[(t[r>>2]|0)+172>>2]=-1;s=i;return}n[f+(t[a>>2]|0)>>0]=0;if(!(t[t[r>>2]>>2]|0)){s=i;return}if(t[(t[r>>2]|0)+212>>2]|0){s=i;return}o=(Ui(t[r>>2]|0,f,t[a>>2]|0)|0)!=0;c=t[r>>2]|0;if(!o){Ci(c)|0;if(!(t[(t[t[r>>2]>>2]|0)+68>>2]|0)){s=i;return}yAi[t[(t[t[r>>2]>>2]|0)+68>>2]&511](t[(t[r>>2]|0)+4>>2]|0,f,t[a>>2]|0);s=i;return}o=t[t[r>>2]>>2]|0;if(t[c+208>>2]|0){if(!(t[o+68>>2]|0)){s=i;return}yAi[t[(t[t[r>>2]>>2]|0)+68>>2]&511](t[(t[r>>2]|0)+4>>2]|0,f,t[a>>2]|0);s=i;return}else{if(!(t[o+72>>2]|0)){s=i;return}yAi[t[(t[t[r>>2]>>2]|0)+72>>2]&511](t[(t[r>>2]|0)+4>>2]|0,f,t[a>>2]|0);s=i;return}}function Mi(e){e=e|0;var i=0,r=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if((t[(t[r>>2]|0)+52>>2]|0)!=0?(t[(t[r>>2]|0)+68>>2]|0)!=0:0){t[(t[(t[r>>2]|0)+448>>2]|0)+12>>2]=(t[(t[(t[r>>2]|0)+36>>2]|0)+36>>2]|0)+((t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)-(t[(t[(t[r>>2]|0)+36>>2]|0)+12>>2]|0));t[(t[(t[r>>2]|0)+448>>2]|0)+16>>2]=t[(t[(t[r>>2]|0)+36>>2]|0)+28>>2];t[t[(t[r>>2]|0)+448>>2]>>2]=t[(t[r>>2]|0)+52>>2];Vp(t[r>>2]|0,t[(t[r>>2]|0)+448>>2]|0);xi(t[r>>2]|0)|0}if(9<=(u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)?(u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)<=10:0){s=i;return}if((u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==13){s=i;return}if(32<=(u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)){s=i;return}UN(t[r>>2]|0);s=i;return}function Ri(e){e=e|0;var i=0,r=0,f=0,a=0,o=0,c=0;i=s;s=s+48|0;r=i+32|0;f=i+28|0;a=i+24|0;o=i+4|0;c=i;t[r>>2]=e;t[o+0>>2]=0;t[o+4>>2]=0;t[o+8>>2]=0;t[o+12>>2]=0;t[o+16>>2]=0;if((t[r>>2]|0)!=0?(t[(t[r>>2]|0)+36>>2]|0)!=0:0){if((t[(t[r>>2]|0)+172>>2]|0)==-1){s=i;return}if(t[(t[r>>2]|0)+68>>2]|0){t[o+4>>2]=(t[(t[(t[r>>2]|0)+36>>2]|0)+36>>2]|0)+((t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)-(t[(t[(t[r>>2]|0)+36>>2]|0)+12>>2]|0));t[o+8>>2]=t[(t[(t[r>>2]|0)+36>>2]|0)+28>>2]}t[c>>2]=HN(t[r>>2]|0)|0;t[f>>2]=t[(t[r>>2]|0)+184>>2];if((t[c>>2]|0)==-1|(t[f>>2]|0)==0){if((u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0)!=62){s=i;return}Op(t[r>>2]|0);s=i;return}t[a>>2]=kN(t[f>>2]|0)|0;if(!(t[a>>2]|0))BN(t[r>>2]|0,801,94576,t[f>>2]|0,0);if((u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0)==47?(u[(t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)+1>>0]|0)==62:0){c=(t[r>>2]|0)+200|0;t[c>>2]=(t[c>>2]|0)+2;c=(t[(t[r>>2]|0)+36>>2]|0)+16|0;t[c>>2]=(t[c>>2]|0)+2;c=(t[(t[r>>2]|0)+36>>2]|0)+32|0;t[c>>2]=(t[c>>2]|0)+2;if((t[t[r>>2]>>2]|0)!=0?(t[(t[t[r>>2]>>2]|0)+60>>2]|0)!=0:0)EAi[t[(t[t[r>>2]>>2]|0)+60>>2]&511](t[(t[r>>2]|0)+4>>2]|0,t[f>>2]|0);xN(t[r>>2]|0)|0;s=i;return}c=t[r>>2]|0;if((u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0)!=62){BN(c,73,94592,t[f>>2]|0,0);if(Xl(t[f>>2]|0,t[(t[r>>2]|0)+184>>2]|0)|0){nE(t[r>>2]|0)|0;xN(t[r>>2]|0)|0}if(t[(t[r>>2]|0)+68>>2]|0)Di(t[r>>2]|0,o)|0;Mi(t[r>>2]|0);s=i;return}Op(c);if((t[a>>2]|0)!=0?(n[(t[a>>2]|0)+7>>0]|0)!=0:0){if((t[t[r>>2]>>2]|0)!=0?(t[(t[t[r>>2]>>2]|0)+60>>2]|0)!=0:0)EAi[t[(t[t[r>>2]>>2]|0)+60>>2]&511](t[(t[r>>2]|0)+4>>2]|0,t[f>>2]|0);xN(t[r>>2]|0)|0;s=i;return}if(!(t[(t[r>>2]|0)+68>>2]|0)){s=i;return}Di(t[r>>2]|0,o)|0;s=i;return}BN(t[r>>2]|0,1,97568,0,0);s=i;return}function Ni(e,i){e=e|0;i=i|0;var r=0,f=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0;r=s;s=s+208|0;f=r;a=r+40|0;o=r+36|0;c=r+32|0;l=r+28|0;b=r+194|0;k=r+24|0;h=r+20|0;w=r+16|0;d=r+44|0;t[o>>2]=e;t[c>>2]=i;if((t[(t[o>>2]|0)+172>>2]|0)==-1){t[a>>2]=0;v=t[a>>2]|0;s=r;return v|0}if(t[(t[o>>2]|0)+176>>2]|0){t[t[c>>2]>>2]=0;t[a>>2]=t[(t[o>>2]|0)+176>>2];v=t[a>>2]|0;s=r;return v|0}if((t[(t[o>>2]|0)+256>>2]|0)!=1){t[t[c>>2]>>2]=1;i=t[o>>2]|0;if((u[t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)<128){t[a>>2]=u[t[(t[i+36>>2]|0)+16>>2]>>0];v=t[a>>2]|0;s=r;return v|0}t[h>>2]=zi(i)|0;i=t[o>>2]|0;do if(t[h>>2]|0){if(t[(t[i+36>>2]|0)+44>>2]|0)pAi[t[135736>>2]&511](t[(t[(t[o>>2]|0)+36>>2]|0)+44>>2]|0);t[(t[(t[o>>2]|0)+36>>2]|0)+44>>2]=t[h>>2];t[w>>2]=V_(t[h>>2]|0)|0;e=t[o>>2]|0;if(t[w>>2]|0){Lp(e,t[w>>2]|0)|0;break}else{BN(e,81,96008,t[h>>2]|0,0);break}}else Tp(i,10)|0;while(0);t[(t[o>>2]|0)+256>>2]=1;t[a>>2]=Ap(t[o>>2]|0,t[c>>2]|0)|0;v=t[a>>2]|0;s=r;return v|0}t[l>>2]=t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2];n[b>>0]=n[t[l>>2]>>0]|0;if(!((u[b>>0]|0)&128)){if((u[t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==0?(t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]|0)>>>0<(t[(t[(t[o>>2]|0)+36>>2]|0)+20>>2]|0)>>>0:0){IN(t[o>>2]|0,9,95976,0);t[t[c>>2]>>2]=1;t[a>>2]=32;v=t[a>>2]|0;s=r;return v|0}t[t[c>>2]>>2]=1;t[a>>2]=u[t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]>>0];v=t[a>>2]|0;s=r;return v|0}if(!(u[(t[l>>2]|0)+1>>0]|0)){yp(t[(t[o>>2]|0)+36>>2]|0,250)|0;t[l>>2]=t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]}e:do if(((u[(t[l>>2]|0)+1>>0]|0)&192|0)==128){do if(((u[b>>0]|0)&224|0)==224){if(!(u[(t[l>>2]|0)+2>>0]|0)){yp(t[(t[o>>2]|0)+36>>2]|0,250)|0;t[l>>2]=t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]}if(((u[(t[l>>2]|0)+2>>0]|0)&192|0)!=128)break e;if(((u[b>>0]|0)&240|0)!=240){t[t[c>>2]>>2]=3;t[k>>2]=((u[t[l>>2]>>0]|0)&15)<<12;t[k>>2]=t[k>>2]|((u[(t[l>>2]|0)+1>>0]|0)&63)<<6;t[k>>2]=t[k>>2]|(u[(t[l>>2]|0)+2>>0]|0)&63;break}if(!(u[(t[l>>2]|0)+3>>0]|0)){yp(t[(t[o>>2]|0)+36>>2]|0,250)|0;t[l>>2]=t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]}if(((u[b>>0]|0)&248|0)!=240)break e;if(((u[(t[l>>2]|0)+3>>0]|0)&192|0)!=128)break e;t[t[c>>2]>>2]=4;t[k>>2]=((u[t[l>>2]>>0]|0)&7)<<18;t[k>>2]=t[k>>2]|((u[(t[l>>2]|0)+1>>0]|0)&63)<<12;t[k>>2]=t[k>>2]|((u[(t[l>>2]|0)+2>>0]|0)&63)<<6;t[k>>2]=t[k>>2]|(u[(t[l>>2]|0)+3>>0]|0)&63}else{t[t[c>>2]>>2]=2;t[k>>2]=((u[t[l>>2]>>0]|0)&31)<<6;t[k>>2]=t[k>>2]|(u[(t[l>>2]|0)+1>>0]|0)&63}while(0);i=t[k>>2]|0;if((t[k>>2]|0)>>>0<256){if(!(9<=i>>>0&(t[k>>2]|0)>>>0<=10|(t[k>>2]|0)==13|32<=(t[k>>2]|0)>>>0))m=27}else if((!(256<=i>>>0&(t[k>>2]|0)>>>0<=55295)?!(57344<=(t[k>>2]|0)>>>0&(t[k>>2]|0)>>>0<=65533):0)?!(65536<=(t[k>>2]|0)>>>0&(t[k>>2]|0)>>>0<=1114111):0)m=27;if((m|0)==27)IN(t[o>>2]|0,9,95976,t[k>>2]|0);t[a>>2]=t[k>>2];v=t[a>>2]|0;s=r;return v|0}while(0);k=u[t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]>>0]|0;if(((t[(t[(t[o>>2]|0)+36>>2]|0)+20>>2]|0)-(t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]|0)|0)>=4){m=u[(t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]|0)+1>>0]|0;l=u[(t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]|0)+2>>0]|0;b=u[(t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]|0)+3>>0]|0;t[f>>2]=k;t[f+4>>2]=m;t[f+8>>2]=l;t[f+12>>2]=b;SY(d,149,96032,f)|0}else{t[f>>2]=k;SY(d,149,96072,f)|0}BN(t[o>>2]|0,81,96088,d,0);t[(t[o>>2]|0)+256>>2]=10;t[t[c>>2]>>2]=1;t[a>>2]=u[t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]>>0];v=t[a>>2]|0;s=r;return v|0}function Ti(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,a=0,o=0;r=s;s=s+16|0;n=r+8|0;f=r+4|0;a=r;t[n>>2]=e;t[f>>2]=i;t[a>>2]=0;if((((((Pq(u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0)|0)==83?(Pq(u[(t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]|0)+1>>0]|0)|0)==89:0)?(Pq(u[(t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]|0)+2>>0]|0)|0)==83:0)?(Pq(u[(t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]|0)+3>>0]|0)|0)==84:0)?(Pq(u[(t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]|0)+4>>0]|0)|0)==69:0)?(Pq(u[(t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]|0)+5>>0]|0)|0)==77:0){i=(t[n>>2]|0)+200|0;t[i>>2]=(t[i>>2]|0)+6;i=(t[(t[n>>2]|0)+36>>2]|0)+16|0;t[i>>2]=(t[i>>2]|0)+6;i=(t[(t[n>>2]|0)+36>>2]|0)+32|0;t[i>>2]=(t[i>>2]|0)+6;do if((u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)!=32){if(9<=(u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)?(u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)<=10:0)break;if((u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)!=13)BN(t[n>>2]|0,65,97056,0,0)}while(0);jN(t[n>>2]|0)|0;t[a>>2]=ji(t[n>>2]|0)|0;if(t[a>>2]|0){o=t[a>>2]|0;s=r;return o|0}BN(t[n>>2]|0,70,97088,0,0);o=t[a>>2]|0;s=r;return o|0}if((Pq(u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0)|0)!=80){o=t[a>>2]|0;s=r;return o|0}if((Pq(u[(t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]|0)+1>>0]|0)|0)!=85){o=t[a>>2]|0;s=r;return o|0}if((Pq(u[(t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]|0)+2>>0]|0)|0)!=66){o=t[a>>2]|0;s=r;return o|0}if((Pq(u[(t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]|0)+3>>0]|0)|0)!=76){o=t[a>>2]|0;s=r;return o|0}if((Pq(u[(t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]|0)+4>>0]|0)|0)!=73){o=t[a>>2]|0;s=r;return o|0}if((Pq(u[(t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]|0)+5>>0]|0)|0)!=67){o=t[a>>2]|0;s=r;return o|0}i=(t[n>>2]|0)+200|0;t[i>>2]=(t[i>>2]|0)+6;i=(t[(t[n>>2]|0)+36>>2]|0)+16|0;t[i>>2]=(t[i>>2]|0)+6;i=(t[(t[n>>2]|0)+36>>2]|0)+32|0;t[i>>2]=(t[i>>2]|0)+6;do if((u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)!=32){if(9<=(u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)?(u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)<=10:0)break;if((u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)!=13)BN(t[n>>2]|0,65,97128,0,0)}while(0);jN(t[n>>2]|0)|0;i=Vi(t[n>>2]|0)|0;t[t[f>>2]>>2]=i;if(!(t[t[f>>2]>>2]|0))BN(t[n>>2]|0,71,97160,0,0);jN(t[n>>2]|0)|0;if((u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)!=34?(u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)!=39:0){o=t[a>>2]|0;s=r;return o|0}t[a>>2]=ji(t[n>>2]|0)|0;o=t[a>>2]|0;s=r;return o|0}function Li(e,i,r,f,a,o){e=e|0;i=i|0;r=r|0;f=f|0;a=a|0;o=o|0;var c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0,S=0,g=0,y=0,F=0,O=0,A=0;c=s;s=s+48|0;l=c+36|0;b=c+32|0;k=c+43|0;h=c+42|0;w=c+41|0;d=c+28|0;v=c+24|0;m=c+20|0;_=c+16|0;p=c+12|0;E=c+8|0;S=c+4|0;g=c;y=c+40|0;t[b>>2]=e;n[k>>0]=i;n[h>>0]=r;n[w>>0]=f;t[d>>2]=a;t[v>>2]=o;t[S>>2]=0;t[g>>2]=0;n[y>>0]=0;t[p>>2]=t[(t[b>>2]|0)+36>>2];if(!(t[p>>2]|0)){t[l>>2]=-1;F=t[l>>2]|0;s=c;return F|0}t[m>>2]=(t[(t[p>>2]|0)+16>>2]|0)-(t[(t[p>>2]|0)+12>>2]|0);if((t[m>>2]|0)<0){t[l>>2]=-1;F=t[l>>2]|0;s=c;return F|0}if((t[(t[b>>2]|0)+204>>2]|0)>(t[m>>2]|0))t[m>>2]=t[(t[b>>2]|0)+204>>2];o=t[p>>2]|0;if(!(t[t[p>>2]>>2]|0)){t[E>>2]=t[o+12>>2];t[_>>2]=t[(t[p>>2]|0)+24>>2]}else{t[E>>2]=Os(t[(t[o>>2]|0)+16>>2]|0)|0;t[_>>2]=Ts(t[(t[t[p>>2]>>2]|0)+16>>2]|0)|0}if(!(n[w>>0]|0)){if(n[h>>0]|0)t[_>>2]=(t[_>>2]|0)+-1}else t[_>>2]=(t[_>>2]|0)-2;e:while(1){O=(t[S>>2]|0)!=0;if((t[m>>2]|0)>=(t[_>>2]|0)){A=45;break}if(((((!O?!((t[d>>2]|0)!=0?1:((t[m>>2]|0)+4|0)>=(t[_>>2]|0)):0)?(u[(t[E>>2]|0)+(t[m>>2]|0)>>0]|0)==60:0)?(u[(t[E>>2]|0)+((t[m>>2]|0)+1)>>0]|0)==33:0)?(u[(t[E>>2]|0)+((t[m>>2]|0)+2)>>0]|0)==45:0)?(u[(t[E>>2]|0)+((t[m>>2]|0)+3)>>0]|0)==45:0){t[S>>2]=1;t[m>>2]=(t[m>>2]|0)+2}do if(t[v>>2]|0){if((u[(t[E>>2]|0)+(t[m>>2]|0)>>0]|0)!=34?(u[(t[E>>2]|0)+(t[m>>2]|0)>>0]|0)!=39:0)if(t[g>>2]|0)break;else{A=30;break}o=n[(t[E>>2]|0)+(t[m>>2]|0)>>0]|0;if(!(t[g>>2]|0)){n[y>>0]=o;t[g>>2]=1;break}if((o&255|0)==(n[y>>0]|0))t[g>>2]=0;else A=30}else A=30;while(0);do if((A|0)==30){A=0;o=t[m>>2]|0;if(t[S>>2]|0){if((o+3|0)>(t[_>>2]|0)){A=32;break e}if((u[(t[E>>2]|0)+(t[m>>2]|0)>>0]|0)!=45)break;if((u[(t[E>>2]|0)+((t[m>>2]|0)+1)>>0]|0)!=45)break;if((u[(t[E>>2]|0)+((t[m>>2]|0)+2)>>0]|0)!=62)break;t[S>>2]=0;t[m>>2]=(t[m>>2]|0)+2;break}if((u[(t[E>>2]|0)+o>>0]|0)==(u[k>>0]|0))if(u[w>>0]|0){if((u[(t[E>>2]|0)+((t[m>>2]|0)+1)>>0]|0)!=(u[h>>0]|0))break;if((u[(t[E>>2]|0)+((t[m>>2]|0)+2)>>0]|0)!=(u[w>>0]|0))break;else{A=43;break e}}else{if(!(u[h>>0]|0)){A=43;break e}if((u[(t[E>>2]|0)+((t[m>>2]|0)+1)>>0]|0)!=(u[h>>0]|0))break;else{A=43;break e}}}while(0);t[m>>2]=(t[m>>2]|0)+1}if((A|0)==32){t[l>>2]=-1;F=t[l>>2]|0;s=c;return F|0}else if((A|0)==43){t[(t[b>>2]|0)+204>>2]=0;t[l>>2]=(t[m>>2]|0)-((t[(t[p>>2]|0)+16>>2]|0)-(t[(t[p>>2]|0)+12>>2]|0));F=t[l>>2]|0;s=c;return F|0}else if((A|0)==45){if(!(O|(t[g>>2]|0)!=0))t[(t[b>>2]|0)+204>>2]=t[m>>2];t[l>>2]=-1;F=t[l>>2]|0;s=c;return F|0}return 0}function Di(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0;r=s;s=s+16|0;n=r+8|0;f=r+4|0;u=r;t[f>>2]=e;t[u>>2]=i;if((t[(t[f>>2]|0)+452>>2]|0)>=(t[(t[f>>2]|0)+456>>2]|0)){if(!(t[(t[f>>2]|0)+456>>2]|0))t[(t[f>>2]|0)+456>>2]=5;i=(t[f>>2]|0)+456|0;t[i>>2]=t[i>>2]<<1;i=MAi[t[135760>>2]&511](t[(t[f>>2]|0)+460>>2]|0,(t[(t[f>>2]|0)+456>>2]|0)*20|0)|0;t[(t[f>>2]|0)+460>>2]=i;if(!(t[(t[f>>2]|0)+460>>2]|0)){CN(t[f>>2]|0,0);t[n>>2]=0;a=t[n>>2]|0;s=r;return a|0}}i=(t[(t[f>>2]|0)+460>>2]|0)+((t[(t[f>>2]|0)+452>>2]|0)*20|0)|0;e=t[u>>2]|0;t[i+0>>2]=t[e+0>>2];t[i+4>>2]=t[e+4>>2];t[i+8>>2]=t[e+8>>2];t[i+12>>2]=t[e+12>>2];t[i+16>>2]=t[e+16>>2];t[(t[f>>2]|0)+448>>2]=(t[(t[f>>2]|0)+460>>2]|0)+((t[(t[f>>2]|0)+452>>2]|0)*20|0);e=(t[f>>2]|0)+452|0;f=t[e>>2]|0;t[e>>2]=f+1;t[n>>2]=f;a=t[n>>2]|0;s=r;return a|0}function Ci(e){e=e|0;var i=0,r=0,n=0,f=0,u=0,a=0,o=0;i=s;s=s+16|0;r=i+12|0;n=i+8|0;f=i+4|0;u=i;t[n>>2]=e;if(!(t[n>>2]|0)){t[r>>2]=-1;a=t[r>>2]|0;s=i;return a|0}t[f>>2]=t[(t[n>>2]|0)+184>>2];if(!(t[f>>2]|0)){$N(t[n>>2]|0,96176);eT(t[n>>2]|0,96176);nT(t[n>>2]|0,96176)|0;if((t[t[n>>2]>>2]|0)!=0?(t[(t[t[n>>2]>>2]|0)+56>>2]|0)!=0:0)yAi[t[(t[t[n>>2]>>2]|0)+56>>2]&511](t[(t[n>>2]|0)+4>>2]|0,96176,0);t[r>>2]=1;a=t[r>>2]|0;s=i;return a|0}if(!(t[23702]|0)){t[r>>2]=0;a=t[r>>2]|0;s=i;return a|0}t[u>>2]=0;while(1){if(!(t[96184+(t[u>>2]<<2)>>2]|0)){o=18;break}if(Xl(t[f>>2]|0,t[96184+(t[u>>2]<<2)>>2]|0)|0)break;t[u>>2]=(t[u>>2]|0)+1}if((o|0)==18){t[r>>2]=0;a=t[r>>2]|0;s=i;return a|0}$N(t[n>>2]|0,96176);eT(t[n>>2]|0,96176);nT(t[n>>2]|0,96176)|0;if((t[t[n>>2]>>2]|0)!=0?(t[(t[t[n>>2]>>2]|0)+56>>2]|0)!=0:0)yAi[t[(t[t[n>>2]>>2]|0)+56>>2]&511](t[(t[n>>2]|0)+4>>2]|0,96176,0);t[r>>2]=1;a=t[r>>2]|0;s=i;return a|0}function Pi(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0;n=s;s=s+48|0;f=n+36|0;a=n+32|0;o=n+28|0;c=n+24|0;l=n+20|0;b=n+16|0;k=n+12|0;h=n+8|0;w=n+4|0;d=n;t[a>>2]=e;t[o>>2]=i;t[c>>2]=r;t[w>>2]=0;t[k>>2]=t[(t[a>>2]|0)+36>>2];if(!(t[k>>2]|0)){t[f>>2]=-1;v=t[f>>2]|0;s=n;return v|0}t[l>>2]=(t[(t[k>>2]|0)+16>>2]|0)-(t[(t[k>>2]|0)+12>>2]|0);if((t[l>>2]|0)<0){t[f>>2]=-1;v=t[f>>2]|0;s=n;return v|0}if((t[(t[a>>2]|0)+204>>2]|0)>(t[l>>2]|0))t[l>>2]=t[(t[a>>2]|0)+204>>2];r=t[k>>2]|0;if(!(t[t[k>>2]>>2]|0)){t[h>>2]=t[r+12>>2];t[b>>2]=t[(t[k>>2]|0)+24>>2]}else{t[h>>2]=Os(t[(t[r>>2]|0)+16>>2]|0)|0;t[b>>2]=Ts(t[(t[t[k>>2]>>2]|0)+16>>2]|0)|0}e:while(1){if((t[l>>2]|0)>=(t[b>>2]|0)){m=31;break}if((((((t[w>>2]|0)==0?((t[l>>2]|0)+4|0)<(t[b>>2]|0):0)?(u[(t[h>>2]|0)+(t[l>>2]|0)>>0]|0|0)==60:0)?(u[(t[h>>2]|0)+((t[l>>2]|0)+1)>>0]|0|0)==33:0)?(u[(t[h>>2]|0)+((t[l>>2]|0)+2)>>0]|0|0)==45:0)?(u[(t[h>>2]|0)+((t[l>>2]|0)+3)>>0]|0|0)==45:0){t[w>>2]=1;t[l>>2]=(t[l>>2]|0)+2}i:do if(t[w>>2]|0){if(((t[l>>2]|0)+3|0)>(t[b>>2]|0)){m=20;break e}if(((u[(t[h>>2]|0)+(t[l>>2]|0)>>0]|0|0)==45?(u[(t[h>>2]|0)+((t[l>>2]|0)+1)>>0]|0|0)==45:0)?(u[(t[h>>2]|0)+((t[l>>2]|0)+2)>>0]|0|0)==62:0){t[w>>2]=0;t[l>>2]=(t[l>>2]|0)+2}}else{t[d>>2]=0;while(1){if((t[d>>2]|0)>=(t[c>>2]|0))break i;if((u[(t[h>>2]|0)+(t[l>>2]|0)>>0]|0|0)==(u[(t[o>>2]|0)+(t[d>>2]|0)>>0]|0|0)){m=28;break e}t[d>>2]=(t[d>>2]|0)+1}}while(0);t[l>>2]=(t[l>>2]|0)+1}if((m|0)==20){t[f>>2]=-1;v=t[f>>2]|0;s=n;return v|0}else if((m|0)==28){t[(t[a>>2]|0)+204>>2]=0;t[f>>2]=(t[l>>2]|0)-((t[(t[k>>2]|0)+16>>2]|0)-(t[(t[k>>2]|0)+12>>2]|0));v=t[f>>2]|0;s=n;return v|0}else if((m|0)==31){t[(t[a>>2]|0)+204>>2]=t[l>>2];t[f>>2]=-1;v=t[f>>2]|0;s=n;return v|0}return 0}function Bi(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,a=0,o=0,c=0,l=0;r=s;s=s+32|0;n=r+20|0;f=r+16|0;a=r+12|0;o=r+8|0;c=r+4|0;l=r;t[n>>2]=e;t[f>>2]=i;if((t[n>>2]|0)==0|(t[f>>2]|0)==0){s=r;return}if(t[(t[n>>2]|0)+360>>2]&2097152){s=r;return}if(!((t[f>>2]|0)!=0?(t[(t[(t[n>>2]|0)+36>>2]|0)+44>>2]|0)==0:0)){s=r;return}while(1){if((u[t[f>>2]>>0]|0|0)!=32?(u[t[f>>2]>>0]|0|0)!=9:0)break;t[f>>2]=(t[f>>2]|0)+1}if(t[(t[(t[n>>2]|0)+36>>2]|0)+44>>2]|0)pAi[t[135736>>2]&511](t[(t[(t[n>>2]|0)+36>>2]|0)+44>>2]|0);i=Yl(t[f>>2]|0)|0;t[(t[(t[n>>2]|0)+36>>2]|0)+44>>2]=i;t[a>>2]=B_(t[f>>2]|0)|0;do if((t[a>>2]|0)==-1){t[o>>2]=V_(t[f>>2]|0)|0;i=t[n>>2]|0;if(t[o>>2]|0){Lp(i,t[o>>2]|0)|0;t[(t[n>>2]|0)+256>>2]=1;break}else{BN(i,32,94872,t[f>>2]|0,0);break}}else{if(((t[a>>2]|0)==2|(t[a>>2]|0)==3|(t[a>>2]|0)==4|(t[a>>2]|0)==5?(t[t[(t[n>>2]|0)+36>>2]>>2]|0)!=0:0)?(t[(t[t[(t[n>>2]|0)+36>>2]>>2]|0)+12>>2]|0)==0:0)BN(t[n>>2]|0,81,94832,0,0);else Tp(t[n>>2]|0,t[a>>2]|0)|0;t[(t[n>>2]|0)+256>>2]=1}while(0);if(!(t[t[(t[n>>2]|0)+36>>2]>>2]|0)){s=r;return}if(!(t[(t[t[(t[n>>2]|0)+36>>2]>>2]|0)+12>>2]|0)){s=r;return}if(!(t[(t[t[(t[n>>2]|0)+36>>2]>>2]|0)+20>>2]|0)){s=r;return}if(!(t[(t[t[(t[n>>2]|0)+36>>2]>>2]|0)+16>>2]|0)){s=r;return}t[l>>2]=(t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]|0)-(t[(t[(t[n>>2]|0)+36>>2]|0)+12>>2]|0);ys(t[(t[t[(t[n>>2]|0)+36>>2]>>2]|0)+16>>2]|0,t[l>>2]|0)|0;t[c>>2]=Y_(t[t[(t[n>>2]|0)+36>>2]>>2]|0,1)|0;if((t[c>>2]|0)<0)BN(t[n>>2]|0,81,94912,0,0);zs(t[(t[t[(t[n>>2]|0)+36>>2]>>2]|0)+16>>2]|0,t[(t[n>>2]|0)+36>>2]|0)|0;s=r;return}function Ii(e){e=e|0;var i=0,r=0,n=0,f=0;i=s;s=s+16|0;r=i+4|0;n=i;t[r>>2]=e;t[n>>2]=0;e=t[r>>2]|0;do if((u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==34){Op(e);t[n>>2]=qi(t[r>>2]|0,34)|0;f=t[r>>2]|0;if((u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)!=34){BN(f,40,97944,0,0);break}else{Op(f);break}}else{f=t[r>>2]|0;if((u[t[(t[e+36>>2]|0)+16>>2]>>0]|0|0)!=39){t[n>>2]=qi(f,0)|0;if(t[n>>2]|0)break;BN(t[r>>2]|0,41,97992,0,0);break}Op(f);t[n>>2]=qi(t[r>>2]|0,39)|0;f=t[r>>2]|0;if((u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)!=39){BN(f,40,97968,0,0);break}else{Op(f);break}}while(0);s=i;return t[n>>2]|0}function Hi(e,i){e=e|0;i=i|0;var r=0,f=0,u=0,a=0,o=0,c=0,l=0;r=s;s=s+32|0;f=r+16|0;u=r+12|0;a=r+8|0;o=r+4|0;c=r;t[f>>2]=e;t[u>>2]=i;t[c>>2]=Yi(t[u>>2]|0)|0;t[o>>2]=(t[(t[f>>2]|0)+188>>2]|0)-1;while(1){if((t[o>>2]|0)<0)break;if(Xl(t[u>>2]|0,t[(t[(t[f>>2]|0)+196>>2]|0)+(t[o>>2]<<2)>>2]|0)|0)break;i=Yi(t[(t[(t[f>>2]|0)+196>>2]|0)+(t[o>>2]<<2)>>2]|0)|0;if((i|0)>(t[c>>2]|0)){l=15;break}t[o>>2]=(t[o>>2]|0)+-1}if((l|0)==15){s=r;return}if((t[o>>2]|0)<0){s=r;return}while(1){if(!((Xl(t[u>>2]|0,t[(t[f>>2]|0)+184>>2]|0)|0)!=0^1))break;t[a>>2]=kN(t[(t[f>>2]|0)+184>>2]|0)|0;if((t[a>>2]|0)!=0?(n[(t[a>>2]|0)+5>>0]|0)==3:0)BN(t[f>>2]|0,76,95696,t[u>>2]|0,t[(t[f>>2]|0)+184>>2]|0);if((t[t[f>>2]>>2]|0)!=0?(t[(t[t[f>>2]>>2]|0)+60>>2]|0)!=0:0)EAi[t[(t[t[f>>2]>>2]|0)+60>>2]&511](t[(t[f>>2]|0)+4>>2]|0,t[(t[f>>2]|0)+184>>2]|0);xN(t[f>>2]|0)|0}s=r;return}function xi(e){e=e|0;var i=0,r=0,n=0,f=0;i=s;s=s+16|0;r=i+4|0;n=i;t[n>>2]=e;if((t[(t[n>>2]|0)+452>>2]|0)<=0){t[r>>2]=0;f=t[r>>2]|0;s=i;return f|0}e=(t[n>>2]|0)+452|0;t[e>>2]=(t[e>>2]|0)+-1;if((t[(t[n>>2]|0)+452>>2]|0)<0){t[r>>2]=0;f=t[r>>2]|0;s=i;return f|0}e=t[n>>2]|0;if((t[(t[n>>2]|0)+452>>2]|0)>0)t[(t[n>>2]|0)+448>>2]=(t[(t[n>>2]|0)+460>>2]|0)+(((t[e+452>>2]|0)-1|0)*20|0);else t[e+448>>2]=0;t[r>>2]=(t[(t[n>>2]|0)+460>>2]|0)+((t[(t[n>>2]|0)+452>>2]|0)*20|0);f=t[r>>2]|0;s=i;return f|0}function Ui(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0;n=s;s=s+32|0;f=n+28|0;a=n+24|0;o=n+20|0;c=n+16|0;l=n+12|0;b=n+8|0;k=n+4|0;h=n;t[a>>2]=e;t[o>>2]=i;t[c>>2]=r;t[b>>2]=0;
	e:while(1){if((t[b>>2]|0)>=(t[c>>2]|0))break;do if((u[(t[o>>2]|0)+(t[b>>2]|0)>>0]|0|0)!=32){if(9<=(u[(t[o>>2]|0)+(t[b>>2]|0)>>0]|0|0)?(u[(t[o>>2]|0)+(t[b>>2]|0)>>0]|0|0)<=10:0)break;if((u[(t[o>>2]|0)+(t[b>>2]|0)>>0]|0|0)!=13){w=7;break e}}while(0);t[b>>2]=(t[b>>2]|0)+1}if((w|0)==7){t[f>>2]=0;d=t[f>>2]|0;s=n;return d|0}if(!(u[t[(t[(t[a>>2]|0)+36>>2]|0)+16>>2]>>0]|0)){t[f>>2]=1;d=t[f>>2]|0;s=n;return d|0}if((u[t[(t[(t[a>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)!=60){t[f>>2]=0;d=t[f>>2]|0;s=n;return d|0}if(!(t[(t[a>>2]|0)+184>>2]|0)){t[f>>2]=1;d=t[f>>2]|0;s=n;return d|0}if(Xl(t[(t[a>>2]|0)+184>>2]|0,94240)|0){t[f>>2]=1;d=t[f>>2]|0;s=n;return d|0}if(Xl(t[(t[a>>2]|0)+184>>2]|0,95656)|0){t[f>>2]=1;d=t[f>>2]|0;s=n;return d|0}do if((((Xl(t[(t[a>>2]|0)+184>>2]|0,95648)|0)!=0?(t[(t[a>>2]|0)+8>>2]|0)!=0:0)?(t[h>>2]=Qg(t[(t[a>>2]|0)+8>>2]|0)|0,(t[h>>2]|0)!=0):0)?(t[(t[h>>2]|0)+52>>2]|0)!=0:0){if((Ql(t[(t[h>>2]|0)+52>>2]|0,96272)|0)!=0?(Ql(t[(t[h>>2]|0)+52>>2]|0,96304)|0)!=0:0)break;t[f>>2]=1;d=t[f>>2]|0;s=n;return d|0}while(0);if(!(t[(t[a>>2]|0)+52>>2]|0)){t[f>>2]=0;d=t[f>>2]|0;s=n;return d|0}t[k>>2]=Uy(t[(t[a>>2]|0)+52>>2]|0)|0;while(1){if(t[k>>2]|0)v=(t[(t[k>>2]|0)+4>>2]|0)==8;else v=0;m=t[k>>2]|0;if(!v)break;t[k>>2]=t[m+28>>2]}e:do if(!m){if((t[(t[(t[a>>2]|0)+52>>2]|0)+4>>2]|0)!=1?(t[(t[(t[a>>2]|0)+52>>2]|0)+40>>2]|0)!=0:0){t[f>>2]=0;d=t[f>>2]|0;s=n;return d|0}t[l>>2]=0;while(1){if((t[l>>2]|0)>>>0>=53)break e;if(Xl(t[(t[a>>2]|0)+184>>2]|0,t[96328+(t[l>>2]<<2)>>2]|0)|0)break;t[l>>2]=(t[l>>2]|0)+1}t[f>>2]=0;d=t[f>>2]|0;s=n;return d|0}else{if(pF(t[k>>2]|0)|0){t[f>>2]=0;d=t[f>>2]|0;s=n;return d|0}t[l>>2]=0;while(1){if((t[l>>2]|0)>>>0>=53)break e;if(Xl(t[(t[k>>2]|0)+8>>2]|0,t[96328+(t[l>>2]<<2)>>2]|0)|0)break;t[l>>2]=(t[l>>2]|0)+1}t[f>>2]=0;d=t[f>>2]|0;s=n;return d|0}while(0);t[f>>2]=1;d=t[f>>2]|0;s=n;return d|0}function zi(e){e=e|0;var i=0,r=0,n=0,f=0,a=0,o=0,c=0,l=0,b=0,k=0;i=s;s=s+32|0;r=i+16|0;n=i+12|0;f=i+8|0;a=i+4|0;o=i;t[n>>2]=e;if(((((t[n>>2]|0)!=0?(t[(t[n>>2]|0)+36>>2]|0)!=0:0)?(t[(t[(t[n>>2]|0)+36>>2]|0)+44>>2]|0)==0:0)?(t[t[(t[n>>2]|0)+36>>2]>>2]|0)!=0:0)?(t[(t[t[(t[n>>2]|0)+36>>2]>>2]|0)+12>>2]|0)==0:0){if((t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]|0)!=0?(t[(t[(t[n>>2]|0)+36>>2]|0)+20>>2]|0)!=0:0){t[f>>2]=t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2];t[o>>2]=t[(t[(t[n>>2]|0)+36>>2]|0)+20>>2];if(u[t[o>>2]>>0]|0){t[r>>2]=0;c=t[r>>2]|0;s=i;return c|0}t[a>>2]=ns(t[f>>2]|0,96136)|0;if(!(t[a>>2]|0)){t[r>>2]=0;c=t[r>>2]|0;s=i;return c|0}t[a>>2]=ns(t[a>>2]|0,96152)|0;if(!(t[a>>2]|0)){t[r>>2]=0;c=t[r>>2]|0;s=i;return c|0}t[a>>2]=ns(t[a>>2]|0,96160)|0;if(!(t[a>>2]|0)){t[r>>2]=0;c=t[r>>2]|0;s=i;return c|0}t[a>>2]=(t[a>>2]|0)+8;t[f>>2]=t[a>>2];while(1){if((u[t[a>>2]>>0]|0|0)>=65?(u[t[a>>2]>>0]|0|0)<=90:0)l=1;else b=21;do if((b|0)==21){b=0;if((u[t[a>>2]>>0]|0|0)>=97?(u[t[a>>2]>>0]|0|0)<=122:0){l=1;break}if((u[t[a>>2]>>0]|0|0)>=48?(u[t[a>>2]>>0]|0|0)<=57:0){l=1;break}if((u[t[a>>2]>>0]|0|0)!=45?(u[t[a>>2]>>0]|0|0)!=95:0){if((u[t[a>>2]>>0]|0|0)==58){l=1;break}l=(u[t[a>>2]>>0]|0|0)==47}else l=1}while(0);k=t[a>>2]|0;if(!l)break;t[a>>2]=k+1}if((k|0)==(t[f>>2]|0)){t[r>>2]=0;c=t[r>>2]|0;s=i;return c|0}else{t[r>>2]=ql(t[f>>2]|0,(t[a>>2]|0)-(t[f>>2]|0)|0)|0;c=t[r>>2]|0;s=i;return c|0}}t[r>>2]=0;c=t[r>>2]|0;s=i;return c|0}t[r>>2]=0;c=t[r>>2]|0;s=i;return c|0}function ji(e){e=e|0;var i=0,r=0,n=0,f=0,a=0,o=0,c=0,l=0,b=0,k=0;i=s;s=s+16|0;r=i+8|0;n=i+4|0;f=i;t[r>>2]=e;t[f>>2]=0;e=t[r>>2]|0;if((u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==34){Op(e);t[n>>2]=t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2];while(1){if(9<=(u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)?(u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)<=10:0)a=7;else if((u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)!=13?32>(u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0):0)o=0;else a=7;if((a|0)==7){a=0;o=(u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)!=34}c=t[r>>2]|0;if(!o)break;Op(c)}if(!(9<=(u[t[(t[c+36>>2]|0)+16>>2]>>0]|0|0)?(u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)<=10:0))a=12;if(((a|0)==12?(u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)!=13:0)?32>(u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0):0){BN(t[r>>2]|0,44,97280,0,0);l=t[f>>2]|0;s=i;return l|0}t[f>>2]=ql(t[n>>2]|0,(t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)-(t[n>>2]|0)|0)|0;Op(t[r>>2]|0);l=t[f>>2]|0;s=i;return l|0}c=t[r>>2]|0;if((u[t[(t[e+36>>2]|0)+16>>2]>>0]|0|0)!=39){BN(c,43,97312,0,0);l=t[f>>2]|0;s=i;return l|0}Op(c);t[n>>2]=t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2];while(1){if(9<=(u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)?(u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)<=10:0)a=22;else if((u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)!=13?32>(u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0):0)b=0;else a=22;if((a|0)==22){a=0;b=(u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)!=39}k=t[r>>2]|0;if(!b)break;Op(k)}if(!(9<=(u[t[(t[k+36>>2]|0)+16>>2]>>0]|0|0)?(u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)<=10:0))a=27;if(((a|0)==27?(u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)!=13:0)?32>(u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0):0){BN(t[r>>2]|0,44,97280,0,0);l=t[f>>2]|0;s=i;return l|0}t[f>>2]=ql(t[n>>2]|0,(t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)-(t[n>>2]|0)|0)|0;Op(t[r>>2]|0);l=t[f>>2]|0;s=i;return l|0}function Vi(e){e=e|0;var i=0,r=0,f=0,a=0,o=0,c=0,l=0,b=0;i=s;s=s+16|0;r=i+8|0;f=i+4|0;a=i;t[r>>2]=e;t[a>>2]=0;e=t[r>>2]|0;if((u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0)==34){Op(e);t[f>>2]=t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2];while(1){o=t[r>>2]|0;if(!(n[198696+(u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0)>>0]|0))break;Op(o)}if((u[t[(t[o+36>>2]|0)+16>>2]>>0]|0)!=34){BN(t[r>>2]|0,44,97216,0,0);c=t[a>>2]|0;s=i;return c|0}else{t[a>>2]=ql(t[f>>2]|0,(t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)-(t[f>>2]|0)|0)|0;Op(t[r>>2]|0);c=t[a>>2]|0;s=i;return c|0}}o=t[r>>2]|0;if((u[t[(t[e+36>>2]|0)+16>>2]>>0]|0)!=39){BN(o,43,97248,0,0);c=t[a>>2]|0;s=i;return c|0}Op(o);t[f>>2]=t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2];while(1){if(u[198696+(u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0)>>0]|0)l=(u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0)!=39;else l=0;b=t[r>>2]|0;if(!l)break;Op(b)}if((u[t[(t[b+36>>2]|0)+16>>2]>>0]|0)!=39){BN(t[r>>2]|0,44,97216,0,0);c=t[a>>2]|0;s=i;return c|0}else{t[a>>2]=ql(t[f>>2]|0,(t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)-(t[f>>2]|0)|0)|0;Op(t[r>>2]|0);c=t[a>>2]|0;s=i;return c|0}return 0}function qi(e,i){e=e|0;i=i|0;var r=0,f=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0,S=0,g=0,y=0,F=0,O=0,A=0,M=0,R=0,N=0,T=0,L=0,D=0,C=0,P=0,B=0;r=s;s=s+112|0;f=r+96|0;a=r+92|0;o=r+100|0;c=r+88|0;l=r+84|0;b=r+80|0;k=r+76|0;h=r+72|0;w=r+68|0;d=r+64|0;v=r+60|0;m=r+56|0;_=r+52|0;p=r+48|0;E=r+44|0;S=r+40|0;g=r+36|0;y=r+32|0;F=r+28|0;O=r+24|0;A=r+20|0;M=r+16|0;R=r+12|0;N=r+8|0;T=r+4|0;L=r;t[a>>2]=e;n[o>>0]=i;t[c>>2]=0;t[l>>2]=0;t[b>>2]=0;t[k>>2]=0;t[h>>2]=0;t[l>>2]=100;t[c>>2]=gAi[t[135752>>2]&511](t[l>>2]|0)|0;if(!(t[c>>2]|0)){CN(t[a>>2]|0,97424);t[f>>2]=0;D=t[f>>2]|0;s=r;return D|0}t[b>>2]=t[c>>2];e:while(1){if(!(u[t[(t[(t[a>>2]|0)+36>>2]|0)+16>>2]>>0]|0)){C=68;break}if((u[t[(t[(t[a>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==(u[o>>0]|0|0)){C=68;break}if((u[o>>0]|0|0)==0?(u[t[(t[(t[a>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==62:0){C=68;break}if(!(u[o>>0]|0)){if((u[t[(t[(t[a>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==32){C=68;break}if(9<=(u[t[(t[(t[a>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)?(u[t[(t[(t[a>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)<=10:0){C=68;break}if((u[t[(t[(t[a>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==13){C=68;break}}if((u[t[(t[(t[a>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)!=38){if(((t[b>>2]|0)-(t[c>>2]|0)|0)>((t[l>>2]|0)-100|0)){t[T>>2]=(t[b>>2]|0)-(t[c>>2]|0);t[l>>2]=t[l>>2]<<1;t[L>>2]=MAi[t[135760>>2]&511](t[c>>2]|0,t[l>>2]|0)|0;if(!(t[L>>2]|0)){C=56;break}t[c>>2]=t[L>>2];t[b>>2]=(t[c>>2]|0)+(t[T>>2]|0)}t[M>>2]=Ni(t[a>>2]|0,N)|0;i=t[M>>2]|0;do if((t[M>>2]|0)>>>0>=128){e=t[M>>2]|0;if(i>>>0<2048){P=t[b>>2]|0;t[b>>2]=P+1;n[P>>0]=e>>>6&31|192;t[R>>2]=0;break}P=t[M>>2]|0;if(e>>>0<65536){e=t[b>>2]|0;t[b>>2]=e+1;n[e>>0]=P>>>12&15|224;t[R>>2]=6;break}else{e=t[b>>2]|0;t[b>>2]=e+1;n[e>>0]=P>>>18&7|240;t[R>>2]=12;break}}else{P=t[b>>2]|0;t[b>>2]=P+1;n[P>>0]=i;t[R>>2]=-6}while(0);while(1){if((t[R>>2]|0)<0)break;i=((t[M>>2]|0)>>>(t[R>>2]|0)&63|128)&255;P=t[b>>2]|0;t[b>>2]=P+1;n[P>>0]=i;t[R>>2]=(t[R>>2]|0)-6}Op(t[a>>2]|0);continue}i=t[a>>2]|0;if((u[(t[(t[(t[a>>2]|0)+36>>2]|0)+16>>2]|0)+1>>0]|0|0)==35){t[d>>2]=_N(i)|0;P=t[d>>2]|0;do if((t[d>>2]|0)>>>0>=128){e=t[d>>2]|0;if(P>>>0<2048){B=t[b>>2]|0;t[b>>2]=B+1;n[B>>0]=e>>>6&31|192;t[v>>2]=0;break}B=t[d>>2]|0;if(e>>>0<65536){e=t[b>>2]|0;t[b>>2]=e+1;n[e>>0]=B>>>12&15|224;t[v>>2]=6;break}else{e=t[b>>2]|0;t[b>>2]=e+1;n[e>>0]=B>>>18&7|240;t[v>>2]=12;break}}else{B=t[b>>2]|0;t[b>>2]=B+1;n[B>>0]=P;t[v>>2]=-6}while(0);while(1){if((t[v>>2]|0)<0)break;P=((t[d>>2]|0)>>>(t[v>>2]|0)&63|128)&255;B=t[b>>2]|0;t[b>>2]=B+1;n[B>>0]=P;t[v>>2]=(t[v>>2]|0)-6}if(((t[b>>2]|0)-(t[c>>2]|0)|0)<=((t[l>>2]|0)-100|0))continue;t[m>>2]=(t[b>>2]|0)-(t[c>>2]|0);t[l>>2]=t[l>>2]<<1;t[_>>2]=MAi[t[135760>>2]&511](t[c>>2]|0,t[l>>2]|0)|0;if(!(t[_>>2]|0)){C=26;break}t[c>>2]=t[_>>2];t[b>>2]=(t[c>>2]|0)+(t[m>>2]|0);continue}t[w>>2]=mN(i,k)|0;if(!(t[k>>2]|0)){P=t[b>>2]|0;t[b>>2]=P+1;n[P>>0]=38;if(((t[b>>2]|0)-(t[c>>2]|0)|0)<=((t[l>>2]|0)-100|0))continue;t[p>>2]=(t[b>>2]|0)-(t[c>>2]|0);t[l>>2]=t[l>>2]<<1;t[E>>2]=MAi[t[135760>>2]&511](t[c>>2]|0,t[l>>2]|0)|0;if(!(t[E>>2]|0)){C=31;break}t[c>>2]=t[E>>2];t[b>>2]=(t[c>>2]|0)+(t[p>>2]|0);continue}P=t[b>>2]|0;if(!(t[w>>2]|0)){t[b>>2]=P+1;n[P>>0]=38;t[h>>2]=t[k>>2];while(1){if(!(u[t[h>>2]>>0]|0))continue e;if(((t[b>>2]|0)-(t[c>>2]|0)|0)>((t[l>>2]|0)-100|0)){t[S>>2]=(t[b>>2]|0)-(t[c>>2]|0);t[l>>2]=t[l>>2]<<1;t[g>>2]=MAi[t[135760>>2]&511](t[c>>2]|0,t[l>>2]|0)|0;if(!(t[g>>2]|0)){C=38;break e}t[c>>2]=t[g>>2];t[b>>2]=(t[c>>2]|0)+(t[S>>2]|0)}B=t[h>>2]|0;t[h>>2]=B+1;e=n[B>>0]|0;B=t[b>>2]|0;t[b>>2]=B+1;n[B>>0]=e}}if((P-(t[c>>2]|0)|0)>((t[l>>2]|0)-100|0)){t[O>>2]=(t[b>>2]|0)-(t[c>>2]|0);t[l>>2]=t[l>>2]<<1;t[A>>2]=MAi[t[135760>>2]&511](t[c>>2]|0,t[l>>2]|0)|0;if(!(t[A>>2]|0)){C=43;break}t[c>>2]=t[A>>2];t[b>>2]=(t[c>>2]|0)+(t[O>>2]|0)}t[y>>2]=t[t[w>>2]>>2];i=t[y>>2]|0;do if((t[y>>2]|0)>>>0>=128){e=t[y>>2]|0;if(i>>>0<2048){B=t[b>>2]|0;t[b>>2]=B+1;n[B>>0]=e>>>6&31|192;t[F>>2]=0;break}B=t[y>>2]|0;if(e>>>0<65536){e=t[b>>2]|0;t[b>>2]=e+1;n[e>>0]=B>>>12&15|224;t[F>>2]=6;break}else{e=t[b>>2]|0;t[b>>2]=e+1;n[e>>0]=B>>>18&7|240;t[F>>2]=12;break}}else{B=t[b>>2]|0;t[b>>2]=B+1;n[B>>0]=i;t[F>>2]=-6}while(0);while(1){if((t[F>>2]|0)<0)continue e;i=((t[y>>2]|0)>>>(t[F>>2]|0)&63|128)&255;P=t[b>>2]|0;t[b>>2]=P+1;n[P>>0]=i;t[F>>2]=(t[F>>2]|0)-6}}if((C|0)==26){CN(t[a>>2]|0,98024);pAi[t[135736>>2]&511](t[c>>2]|0);t[f>>2]=0;D=t[f>>2]|0;s=r;return D|0}else if((C|0)==31){CN(t[a>>2]|0,98024);pAi[t[135736>>2]&511](t[c>>2]|0);t[f>>2]=0;D=t[f>>2]|0;s=r;return D|0}else if((C|0)==38){CN(t[a>>2]|0,98024);pAi[t[135736>>2]&511](t[c>>2]|0);t[f>>2]=0;D=t[f>>2]|0;s=r;return D|0}else if((C|0)==43){CN(t[a>>2]|0,98024);pAi[t[135736>>2]&511](t[c>>2]|0);t[f>>2]=0;D=t[f>>2]|0;s=r;return D|0}else if((C|0)==56){CN(t[a>>2]|0,98024);pAi[t[135736>>2]&511](t[c>>2]|0);t[f>>2]=0;D=t[f>>2]|0;s=r;return D|0}else if((C|0)==68){n[t[b>>2]>>0]=0;t[f>>2]=t[c>>2];D=t[f>>2]|0;s=r;return D|0}return 0}function Yi(e){e=e|0;var i=0,r=0,n=0,f=0,u=0;i=s;s=s+16|0;r=i+4|0;n=i;t[r>>2]=e;t[n>>2]=0;while(1){if(t[95744+(t[n>>2]<<3)>>2]|0)f=(Xl(t[95744+(t[n>>2]<<3)>>2]|0,t[r>>2]|0)|0)!=0^1;else f=0;u=t[n>>2]|0;if(!f)break;t[n>>2]=u+1}s=i;return t[95748+(u<<3)>>2]|0}function Gi(e){e=e|0;var i=0,r=0,n=0,f=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0;i=s;s=s+32|0;r=i+28|0;n=i+24|0;f=i+20|0;a=i+16|0;o=i+12|0;c=i+8|0;l=i+4|0;b=i;t[n>>2]=e;if(!(t[n>>2]|0)){t[r>>2]=0;k=t[r>>2]|0;s=i;return k|0}t[f>>2]=t[(t[n>>2]|0)+12>>2];while(1){if(!(t[f>>2]|0)){h=11;break}if((t[(t[f>>2]|0)+4>>2]|0)==1?(t[(t[f>>2]|0)+8>>2]|0)!=0:0){if(Xl(t[(t[f>>2]|0)+8>>2]|0,120888)|0){h=11;break}if(Xl(t[(t[f>>2]|0)+8>>2]|0,120896)|0){h=22;break}if(Xl(t[(t[f>>2]|0)+8>>2]|0,120904)|0)break}t[f>>2]=t[(t[f>>2]|0)+24>>2]}e:do if((h|0)==11){if(!(t[f>>2]|0)){t[r>>2]=0;k=t[r>>2]|0;s=i;return k|0}t[f>>2]=t[(t[f>>2]|0)+12>>2];while(1){if(!(t[f>>2]|0))break;if((t[(t[f>>2]|0)+4>>2]|0)==1?(t[(t[f>>2]|0)+8>>2]|0)!=0:0){if(Xl(t[(t[f>>2]|0)+8>>2]|0,120896)|0)break;if(Xl(t[(t[f>>2]|0)+8>>2]|0,120904)|0)break e}t[f>>2]=t[(t[f>>2]|0)+24>>2]}if(!(t[f>>2]|0)){t[r>>2]=0;k=t[r>>2]|0;s=i;return k|0}else h=22}while(0);if((h|0)==22)t[f>>2]=t[(t[f>>2]|0)+12>>2];e:while(1){if(!(t[f>>2]|0)){h=41;break}i:do if(((t[(t[f>>2]|0)+4>>2]|0)==1?(t[(t[f>>2]|0)+8>>2]|0)!=0:0)?(Xl(t[(t[f>>2]|0)+8>>2]|0,120904)|0)!=0:0){t[c>>2]=t[(t[f>>2]|0)+44>>2];t[a>>2]=0;t[l>>2]=0;while(1){if(!(t[c>>2]|0))break i;if(((t[(t[c>>2]|0)+12>>2]|0)!=0?(t[(t[(t[c>>2]|0)+12>>2]|0)+4>>2]|0)==3:0)?(t[(t[(t[c>>2]|0)+12>>2]|0)+24>>2]|0)==0:0){t[b>>2]=t[(t[(t[c>>2]|0)+12>>2]|0)+40>>2];if((Ql(t[(t[c>>2]|0)+8>>2]|0,120912)|0)==0?(Ql(t[b>>2]|0,120928)|0)==0:0)t[l>>2]=1;else h=35;if(((h|0)==35?(h=0,(t[b>>2]|0)!=0):0)?(Ql(t[(t[c>>2]|0)+8>>2]|0,120944)|0)==0:0)t[a>>2]=t[b>>2];if((t[l>>2]|0)!=0&(t[a>>2]|0)!=0)break e}t[c>>2]=t[(t[c>>2]|0)+24>>2]}}while(0);t[f>>2]=t[(t[f>>2]|0)+24>>2]}if((h|0)==41){t[r>>2]=0;k=t[r>>2]|0;s=i;return k|0}t[o>>2]=is(t[a>>2]|0,120952)|0;if(!(t[o>>2]|0))t[o>>2]=is(t[a>>2]|0,120968)|0;if(!(t[o>>2]|0))t[o>>2]=is(t[a>>2]|0,120984)|0;if(!(t[o>>2]|0)){t[o>>2]=is(t[a>>2]|0,121e3)|0;if(!(t[o>>2]|0))t[o>>2]=is(t[a>>2]|0,121016)|0;if(!(t[o>>2]|0))t[o>>2]=is(t[a>>2]|0,121032)|0;if(t[o>>2]|0)t[o>>2]=(t[o>>2]|0)+9}else t[o>>2]=(t[o>>2]|0)+8;e:do if(t[o>>2]|0)while(1){if((u[t[o>>2]>>0]|0|0)!=32?(u[t[o>>2]>>0]|0|0)!=9:0)break e;t[o>>2]=(t[o>>2]|0)+1}while(0);t[r>>2]=t[o>>2];k=t[r>>2]|0;s=i;return k|0}function Wi(e,i){e=e|0;i=i|0;var r=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0;r=s;s=s+144|0;f=r;u=r+40|0;a=r+36|0;o=r+32|0;c=r+28|0;l=r+24|0;b=r+20|0;k=r+16|0;h=r+44|0;w=r+12|0;d=r+8|0;v=r+4|0;t[a>>2]=e;t[o>>2]=i;t[l>>2]=0;t[b>>2]=0;t[k>>2]=0;n[h>>0]=0;if(!(t[a>>2]|0)){t[u>>2]=-1;m=t[u>>2]|0;s=r;return m|0}if(!(Ql(t[o>>2]|0,120888)|0)){t[u>>2]=-1;m=t[u>>2]|0;s=r;return m|0}if(t[o>>2]|0){t[f>>2]=t[o>>2];SY(h,100,121048,f)|0;n[h+99>>0]=0}t[c>>2]=t[(t[a>>2]|0)+12>>2];while(1){if(!(t[c>>2]|0)){_=15;break}if((t[(t[c>>2]|0)+4>>2]|0)==1?(t[(t[c>>2]|0)+8>>2]|0)!=0:0){if(!(Ql(t[(t[c>>2]|0)+8>>2]|0,120888)|0)){_=15;break}if(!(Ql(t[(t[c>>2]|0)+8>>2]|0,120896)|0)){_=27;break}if(!(Ql(t[(t[c>>2]|0)+8>>2]|0,120904)|0)){_=29;break}}t[c>>2]=t[(t[c>>2]|0)+24>>2]}do if((_|0)==15){if(!(t[c>>2]|0)){t[u>>2]=-1;m=t[u>>2]|0;s=r;return m|0}t[c>>2]=t[(t[c>>2]|0)+12>>2];while(1){if(!(t[c>>2]|0))break;if((t[(t[c>>2]|0)+4>>2]|0)==1?(t[(t[c>>2]|0)+8>>2]|0)!=0:0){if(!(Ql(t[(t[c>>2]|0)+8>>2]|0,120896)|0))break;if(!(Ql(t[(t[c>>2]|0)+8>>2]|0,120904)|0)){_=23;break}}t[c>>2]=t[(t[c>>2]|0)+24>>2]}if((_|0)==23){t[b>>2]=t[(t[c>>2]|0)+20>>2];_=29;break}if(!(t[c>>2]|0)){t[u>>2]=-1;m=t[u>>2]|0;s=r;return m|0}else _=27}while(0);if((_|0)==27?(t[b>>2]=t[c>>2],(t[(t[c>>2]|0)+12>>2]|0)!=0):0){t[c>>2]=t[(t[c>>2]|0)+12>>2];_=29}e:do if((_|0)==29){while(1){_=0;if(!(t[c>>2]|0))break e;if(((t[(t[c>>2]|0)+4>>2]|0)==1?(t[(t[c>>2]|0)+8>>2]|0)!=0:0)?(Ql(t[(t[c>>2]|0)+8>>2]|0,120904)|0)==0:0){t[w>>2]=t[(t[c>>2]|0)+44>>2];t[k>>2]=0;t[d>>2]=0;while(1){if(!(t[w>>2]|0))break;if(((t[(t[w>>2]|0)+12>>2]|0)!=0?(t[(t[(t[w>>2]|0)+12>>2]|0)+4>>2]|0)==3:0)?(t[(t[(t[w>>2]|0)+12>>2]|0)+24>>2]|0)==0:0){t[v>>2]=t[(t[(t[w>>2]|0)+12>>2]|0)+40>>2];if((Ql(t[(t[w>>2]|0)+8>>2]|0,120912)|0)==0?(Ql(t[v>>2]|0,120928)|0)==0:0)t[d>>2]=1;else _=41;if(((_|0)==41?(_=0,(t[v>>2]|0)!=0):0)?(Ql(t[(t[w>>2]|0)+8>>2]|0,120944)|0)==0:0)t[k>>2]=t[v>>2];if((t[d>>2]|0)!=0&(t[k>>2]|0)!=0)break}t[w>>2]=t[(t[w>>2]|0)+24>>2]}if((t[d>>2]|0)!=0&(t[k>>2]|0)!=0)break}t[c>>2]=t[(t[c>>2]|0)+24>>2];_=29}t[l>>2]=t[c>>2]}while(0);c=t[o>>2]|0;do if(!(t[l>>2]|0)){if((c|0)!=0&(t[b>>2]|0)!=0){t[l>>2]=Sy(t[a>>2]|0,0,120904,0)|0;_=t[b>>2]|0;if(!(t[(t[b>>2]|0)+12>>2]|0))Hy(_,t[l>>2]|0)|0;else Py(t[_+12>>2]|0,t[l>>2]|0)|0;by(t[l>>2]|0,120912,120928)|0;by(t[l>>2]|0,120944,h)|0}}else{if(!c){iy(t[l>>2]|0);ry(t[l>>2]|0);break}if(!(ns(t[k>>2]|0,t[o>>2]|0)|0))_F(t[l>>2]|0,120944,h)|0}while(0);t[u>>2]=0;m=t[u>>2]|0;s=r;return m|0}function Ki(e){e=e|0;var i=0,r=0,n=0,f=0,u=0,a=0;i=s;s=s+16|0;r=i+8|0;n=i+4|0;f=i;t[n>>2]=e;t[f>>2]=0;while(1){if(!(t[121072+(t[f>>2]<<2)>>2]|0)){u=6;break}if(!(Ql(t[121072+(t[f>>2]<<2)>>2]|0,t[n>>2]|0)|0)){u=4;break}t[f>>2]=(t[f>>2]|0)+1}if((u|0)==4){t[r>>2]=1;a=t[r>>2]|0;s=i;return a|0}else if((u|0)==6){t[r>>2]=0;a=t[r>>2]|0;s=i;return a|0}return 0}function Xi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;var u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0;u=s;s=s+48|0;a=u+36|0;o=u+32|0;c=u+28|0;l=u+24|0;b=u+20|0;k=u+16|0;h=u+12|0;w=u+8|0;d=u+4|0;v=u;t[o>>2]=e;t[c>>2]=i;t[l>>2]=r;t[b>>2]=n;t[k>>2]=f;t[w>>2]=0;rS();if(((t[b>>2]|0)!=0?(t[v>>2]=B_(t[b>>2]|0)|0,(t[v>>2]|0)!=1):0)?(t[w>>2]=V_(t[b>>2]|0)|0,(t[w>>2]|0)==0):0)fr(1403,0,t[b>>2]|0);if(!(t[w>>2]|0))t[w>>2]=V_(121128)|0;if(!(t[w>>2]|0))t[w>>2]=V_(121136)|0;t[h>>2]=qO(t[o>>2]|0,t[w>>2]|0)|0;if(!(t[h>>2]|0)){t[a>>2]=0;m=t[a>>2]|0;s=u;return m|0}else{Zi(t[h>>2]|0,t[c>>2]|0,t[l>>2]|0,t[b>>2]|0,t[k>>2]|0);t[d>>2]=HO(t[h>>2]|0)|0;t[a>>2]=t[d>>2];m=t[a>>2]|0;s=u;return m|0}return 0}function Zi(e,i,r,f,a){e=e|0;i=i|0;r=r|0;f=f|0;a=a|0;var o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0;o=s;s=s+32|0;c=o+24|0;l=o+20|0;b=o+16|0;k=o+12|0;h=o+8|0;w=o+4|0;d=o;t[c>>2]=e;t[l>>2]=i;t[b>>2]=r;t[k>>2]=f;t[h>>2]=a;rS();if((t[b>>2]|0)==0|(t[c>>2]|0)==0){s=o;return}if((t[(t[b>>2]|0)+4>>2]|0)==14){s=o;return}if((t[(t[b>>2]|0)+4>>2]|0)!=13?(t[(t[b>>2]|0)+4>>2]|0)!=9:0){if((t[(t[b>>2]|0)+4>>2]|0)==2){tr(t[c>>2]|0,t[l>>2]|0,t[b>>2]|0,t[k>>2]|0);s=o;return}a=t[b>>2]|0;if((t[(t[b>>2]|0)+4>>2]|0)==3){if(!(t[a+40>>2]|0)){s=o;return}if(!((t[(t[b>>2]|0)+8>>2]|0)!=75104?(t[(t[b>>2]|0)+8>>2]|0)==75112:0))v=12;do if((v|0)==12){if(t[(t[b>>2]|0)+20>>2]|0){if(!(Ql(t[(t[(t[b>>2]|0)+20>>2]|0)+8>>2]|0,121144)|0))break;if(!(Ql(t[(t[(t[b>>2]|0)+20>>2]|0)+8>>2]|0,121152)|0))break}t[d>>2]=d_(t[l>>2]|0,t[(t[b>>2]|0)+40>>2]|0)|0;if(!(t[d>>2]|0)){s=o;return}iA(t[c>>2]|0,t[d>>2]|0)|0;pAi[t[135736>>2]&511](t[d>>2]|0);s=o;return}while(0);iA(t[c>>2]|0,t[(t[b>>2]|0)+40>>2]|0)|0;s=o;return}d=t[b>>2]|0;if((t[a+4>>2]|0)==8){if(!(t[d+40>>2]|0)){s=o;return}iA(t[c>>2]|0,121160)|0;iA(t[c>>2]|0,t[(t[b>>2]|0)+40>>2]|0)|0;iA(t[c>>2]|0,121168)|0;s=o;return}a=t[b>>2]|0;if((t[d+4>>2]|0)==7){if(!(t[a+8>>2]|0)){s=o;return}iA(t[c>>2]|0,121176)|0;iA(t[c>>2]|0,t[(t[b>>2]|0)+8>>2]|0)|0;if(t[(t[b>>2]|0)+40>>2]|0){iA(t[c>>2]|0,121184)|0;iA(t[c>>2]|0,t[(t[b>>2]|0)+40>>2]|0)|0}iA(t[c>>2]|0,121192)|0;s=o;return}if((t[a+4>>2]|0)==5){iA(t[c>>2]|0,121200)|0;iA(t[c>>2]|0,t[(t[b>>2]|0)+8>>2]|0)|0;iA(t[c>>2]|0,121208)|0;s=o;return}a=t[b>>2]|0;if((t[(t[b>>2]|0)+4>>2]|0)==4){if(!(t[a+40>>2]|0)){s=o;return}iA(t[c>>2]|0,t[(t[b>>2]|0)+40>>2]|0)|0;s=o;return}if(!(t[a+36>>2]|0))t[w>>2]=kN(t[(t[b>>2]|0)+8>>2]|0)|0;else t[w>>2]=0;iA(t[c>>2]|0,121216)|0;if((t[(t[b>>2]|0)+36>>2]|0)!=0?(t[(t[(t[b>>2]|0)+36>>2]|0)+12>>2]|0)!=0:0){iA(t[c>>2]|0,t[(t[(t[b>>2]|0)+36>>2]|0)+12>>2]|0)|0;iA(t[c>>2]|0,121224)|0}iA(t[c>>2]|0,t[(t[b>>2]|0)+8>>2]|0)|0;if(t[(t[b>>2]|0)+48>>2]|0)nV(t[c>>2]|0,t[(t[b>>2]|0)+48>>2]|0);if(t[(t[b>>2]|0)+44>>2]|0)ur(t[c>>2]|0,t[l>>2]|0,t[(t[b>>2]|0)+44>>2]|0,t[k>>2]|0);if((t[w>>2]|0)!=0?(n[(t[w>>2]|0)+7>>0]|0)!=0:0){iA(t[c>>2]|0,121192)|0;if(!(t[h>>2]|0)){s=o;return}if(n[(t[w>>2]|0)+10>>0]|0){s=o;return}if(!(t[(t[b>>2]|0)+24>>2]|0)){s=o;return}if((t[(t[(t[b>>2]|0)+24>>2]|0)+4>>2]|0)==3){s=o;return}if((t[(t[(t[b>>2]|0)+24>>2]|0)+4>>2]|0)==5){s=o;return}if(!(t[(t[b>>2]|0)+20>>2]|0)){s=o;return}if(!(t[(t[(t[b>>2]|0)+20>>2]|0)+8>>2]|0)){s=o;return}if((u[t[(t[(t[b>>2]|0)+20>>2]|0)+8>>2]>>0]|0)==112){s=o;return}iA(t[c>>2]|0,121232)|0;s=o;return}if(!((t[(t[b>>2]|0)+4>>2]|0)!=1?(t[(t[b>>2]|0)+40>>2]|0)!=0:0))v=54;if((v|0)==54?(t[(t[b>>2]|0)+12>>2]|0)==0:0){do if(t[w>>2]|0){if(!(n[(t[w>>2]|0)+6>>0]|0)){v=60;break}if(!(Kl(t[t[w>>2]>>2]|0,120888)|0)){v=60;break}if(!(Kl(t[t[w>>2]>>2]|0,121240)|0)){v=60;break}iA(t[c>>2]|0,121192)|0}else v=60;while(0);if((v|0)==60){iA(t[c>>2]|0,121248)|0;do if(t[(t[b>>2]|0)+36>>2]|0){if(!(t[(t[(t[b>>2]|0)+36>>2]|0)+12>>2]|0))break;iA(t[c>>2]|0,t[(t[(t[b>>2]|0)+36>>2]|0)+12>>2]|0)|0;iA(t[c>>2]|0,121224)|0}while(0);iA(t[c>>2]|0,t[(t[b>>2]|0)+8>>2]|0)|0;iA(t[c>>2]|0,121192)|0}if(!(t[h>>2]|0)){s=o;return}if(!((t[w>>2]|0)!=0?(t[(t[b>>2]|0)+24>>2]|0)!=0:0)){s=o;return}if(n[(t[w>>2]|0)+10>>0]|0){s=o;return}if((t[(t[(t[b>>2]|0)+24>>2]|0)+4>>2]|0)==3){s=o;return}if((t[(t[(t[b>>2]|0)+24>>2]|0)+4>>2]|0)==5){s=o;return}if(!(t[(t[b>>2]|0)+20>>2]|0)){s=o;return}if(!(t[(t[(t[b>>2]|0)+20>>2]|0)+8>>2]|0)){s=o;return}if((u[t[(t[(t[b>>2]|0)+20>>2]|0)+8>>2]>>0]|0)==112){s=o;return}iA(t[c>>2]|0,121232)|0;s=o;return}iA(t[c>>2]|0,121192)|0;if((t[(t[b>>2]|0)+4>>2]|0)!=1?(t[(t[b>>2]|0)+40>>2]|0)!=0:0)iA(t[c>>2]|0,t[(t[b>>2]|0)+40>>2]|0)|0;do if(t[(t[b>>2]|0)+12>>2]|0){do if((t[h>>2]|0)!=0&(t[w>>2]|0)!=0){if(n[(t[w>>2]|0)+10>>0]|0)break;if((t[(t[(t[b>>2]|0)+12>>2]|0)+4>>2]|0)==3)break;if((t[(t[(t[b>>2]|0)+12>>2]|0)+4>>2]|0)==5)break;if((t[(t[b>>2]|0)+12>>2]|0)==(t[(t[b>>2]|0)+16>>2]|0))break;if(!(t[(t[b>>2]|0)+8>>2]|0))break;if((u[t[(t[b>>2]|0)+8>>2]>>0]|0)==112)break;iA(t[c>>2]|0,121232)|0}while(0);ar(t[c>>2]|0,t[l>>2]|0,t[(t[b>>2]|0)+12>>2]|0,t[k>>2]|0,t[h>>2]|0);if(!((t[h>>2]|0)!=0&(t[w>>2]|0)!=0))break;if(n[(t[w>>2]|0)+10>>0]|0)break;if((t[(t[(t[b>>2]|0)+16>>2]|0)+4>>2]|0)==3)break;if((t[(t[(t[b>>2]|0)+16>>2]|0)+4>>2]|0)==5)break;if((t[(t[b>>2]|0)+12>>2]|0)==(t[(t[b>>2]|0)+16>>2]|0))break;if(!(t[(t[b>>2]|0)+8>>2]|0))break;if((u[t[(t[b>>2]|0)+8>>2]>>0]|0)==112)break;iA(t[c>>2]|0,121232)|0}while(0);iA(t[c>>2]|0,121256)|0;do if(t[(t[b>>2]|0)+36>>2]|0){if(!(t[(t[(t[b>>2]|0)+36>>2]|0)+12>>2]|0))break;iA(t[c>>2]|0,t[(t[(t[b>>2]|0)+36>>2]|0)+12>>2]|0)|0;iA(t[c>>2]|0,121224)|0}while(0);iA(t[c>>2]|0,t[(t[b>>2]|0)+8>>2]|0)|0;iA(t[c>>2]|0,121192)|0;if(!((t[h>>2]|0)!=0&(t[w>>2]|0)!=0)){s=o;return}if(n[(t[w>>2]|0)+10>>0]|0){s=o;return}if(!(t[(t[b>>2]|0)+24>>2]|0)){s=o;return}if((t[(t[(t[b>>2]|0)+24>>2]|0)+4>>2]|0)==3){s=o;return}if((t[(t[(t[b>>2]|0)+24>>2]|0)+4>>2]|0)==5){s=o;return}if(!(t[(t[b>>2]|0)+20>>2]|0)){s=o;return}if(!(t[(t[(t[b>>2]|0)+20>>2]|0)+8>>2]|0)){s=o;return}if((u[t[(t[(t[b>>2]|0)+20>>2]|0)+8>>2]>>0]|0)==112){s=o;return}iA(t[c>>2]|0,121232)|0;s=o;return}$i(t[c>>2]|0,t[b>>2]|0,t[k>>2]|0);s=o;return}function Ji(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0;n=s;s=s+16|0;f=n+8|0;u=n+4|0;a=n;t[f>>2]=e;t[u>>2]=i;t[a>>2]=r;Xi(t[f>>2]|0,t[u>>2]|0,t[a>>2]|0,0,1)|0;s=n;return}function Qi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,u=0,a=0,o=0,c=0,l=0;f=s;s=s+32|0;u=f+16|0;a=f+12|0;o=f+8|0;c=f+4|0;l=f;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;t[c>>2]=n;rS();if((t[u>>2]|0)==0|(t[a>>2]|0)==0){s=f;return}t[l>>2]=t[(t[a>>2]|0)+4>>2];t[(t[a>>2]|0)+4>>2]=13;if(t[(t[a>>2]|0)+44>>2]|0)or(t[u>>2]|0,t[a>>2]|0,0);if(t[(t[a>>2]|0)+12>>2]|0)ar(t[u>>2]|0,t[a>>2]|0,t[(t[a>>2]|0)+12>>2]|0,t[o>>2]|0,t[c>>2]|0);iA(t[u>>2]|0,121232)|0;t[(t[a>>2]|0)+4>>2]=t[l>>2];s=f;return}function $i(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0;n=s;s=s+16|0;f=n+8|0;u=n+4|0;a=n;t[f>>2]=e;t[u>>2]=i;t[a>>2]=r;Qi(t[f>>2]|0,t[u>>2]|0,t[a>>2]|0,1);s=n;return}function er(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,u=0,a=0,o=0,c=0;f=s;s=s+16|0;u=f+12|0;a=f+8|0;o=f+4|0;c=f;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;t[c>>2]=n;Zi(t[u>>2]|0,t[a>>2]|0,t[o>>2]|0,t[c>>2]|0,1);s=f;return}function ir(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0;r=s;s=s+32|0;n=r+28|0;f=r+24|0;u=r+20|0;a=r+16|0;o=r+12|0;c=r+8|0;l=r+4|0;b=r;t[f>>2]=e;t[u>>2]=i;t[o>>2]=0;rS();if((t[u>>2]|0)==0|(t[f>>2]|0)==0){t[n>>2]=-1;k=t[n>>2]|0;s=r;return k|0}t[c>>2]=Gi(t[u>>2]|0)|0;do if(t[c>>2]|0){t[b>>2]=B_(t[c>>2]|0)|0;if((t[b>>2]|0)==(t[(t[u>>2]|0)+76>>2]|0)){t[o>>2]=V_(t[c>>2]|0)|0;break}if((t[(t[u>>2]|0)+76>>2]|0)!=1){t[n>>2]=-1;k=t[n>>2]|0;s=r;return k|0}else{t[o>>2]=V_(t[c>>2]|0)|0;if(t[o>>2]|0)break;fr(1403,0,t[c>>2]|0);break}}while(0);if(!(t[o>>2]|0))t[o>>2]=V_(121128)|0;if(!(t[o>>2]|0))t[o>>2]=V_(121136)|0;t[a>>2]=qO(t[f>>2]|0,t[o>>2]|0)|0;if(!(t[a>>2]|0)){t[n>>2]=-1;k=t[n>>2]|0;s=r;return k|0}else{$i(t[a>>2]|0,t[u>>2]|0,0);t[l>>2]=HO(t[a>>2]|0)|0;t[n>>2]=t[l>>2];k=t[n>>2]|0;s=r;return k|0}return 0}function rr(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0;r=s;s=s+32|0;n=r+28|0;f=r+24|0;u=r+20|0;a=r+16|0;o=r+12|0;c=r+8|0;l=r+4|0;b=r;t[f>>2]=e;t[u>>2]=i;t[o>>2]=0;if((t[u>>2]|0)==0|(t[f>>2]|0)==0){t[n>>2]=-1;k=t[n>>2]|0;s=r;return k|0}rS();t[c>>2]=Gi(t[u>>2]|0)|0;do if((t[c>>2]|0)!=0?(t[b>>2]=B_(t[c>>2]|0)|0,(t[b>>2]|0)!=(t[(t[u>>2]|0)+76>>2]|0)):0)if((t[(t[u>>2]|0)+76>>2]|0)!=1){t[n>>2]=-1;k=t[n>>2]|0;s=r;return k|0}else{t[o>>2]=V_(t[c>>2]|0)|0;if(t[o>>2]|0)break;fr(1403,0,t[c>>2]|0);break}while(0);if(!(t[o>>2]|0))t[o>>2]=V_(121128)|0;if(!(t[o>>2]|0))t[o>>2]=V_(121136)|0;t[a>>2]=VO(t[f>>2]|0,t[o>>2]|0,t[(t[u>>2]|0)+36>>2]|0)|0;if(!(t[a>>2]|0)){t[n>>2]=0;k=t[n>>2]|0;s=r;return k|0}else{$i(t[a>>2]|0,t[u>>2]|0,0);t[l>>2]=HO(t[a>>2]|0)|0;t[n>>2]=t[l>>2];k=t[n>>2]|0;s=r;return k|0}return 0}function nr(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0;f=s;s=s+48|0;u=f+32|0;a=f+28|0;o=f+24|0;c=f+20|0;l=f+16|0;b=f+12|0;k=f+8|0;h=f+4|0;w=f;t[a>>2]=e;t[o>>2]=i;t[c>>2]=r;t[l>>2]=n;t[k>>2]=0;if((t[o>>2]|0)==0|(t[a>>2]|0)==0){t[u>>2]=-1;d=t[u>>2]|0;s=f;return d|0}rS();if(t[c>>2]|0){t[w>>2]=B_(t[c>>2]|0)|0;do if((t[w>>2]|0)!=(t[(t[o>>2]|0)+76>>2]|0))if((t[(t[o>>2]|0)+76>>2]|0)!=1){t[u>>2]=-1;d=t[u>>2]|0;s=f;return d|0}else{t[k>>2]=V_(t[c>>2]|0)|0;if(t[k>>2]|0)break;fr(1403,0,t[c>>2]|0);break}while(0);Wi(t[o>>2]|0,t[c>>2]|0)|0}else Wi(t[o>>2]|0,121264)|0;if(!(t[k>>2]|0))t[k>>2]=V_(121128)|0;if(!(t[k>>2]|0))t[k>>2]=V_(121136)|0;t[b>>2]=VO(t[a>>2]|0,t[k>>2]|0,0)|0;if(!(t[b>>2]|0)){t[u>>2]=0;d=t[u>>2]|0;s=f;return d|0}else{Qi(t[b>>2]|0,t[o>>2]|0,t[c>>2]|0,t[l>>2]|0);t[h>>2]=HO(t[b>>2]|0)|0;t[u>>2]=t[h>>2];d=t[u>>2]|0;s=f;return d|0}return 0}function fr(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0;n=s;s=s+16|0;f=n+12|0;u=n+8|0;a=n+4|0;o=n;t[f>>2]=e;t[u>>2]=i;t[a>>2]=r;t[o>>2]=0;r=t[f>>2]|0;if((r|0)==1402)t[o>>2]=121488;else if((r|0)==1401)t[o>>2]=121432;else if((r|0)==1400)t[o>>2]=121408;else if((r|0)==1403)t[o>>2]=121464;else t[o>>2]=121512;dp(7,t[f>>2]|0,t[u>>2]|0,t[o>>2]|0,t[a>>2]|0);s=n;return}function tr(e,i,r,f){e=e|0;i=i|0;r=r|0;f=f|0;var a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0;a=s;s=s+48|0;o=a+32|0;c=a+28|0;l=a+24|0;b=a+16|0;k=a+12|0;h=a+8|0;w=a+36|0;d=a+4|0;v=a;t[o>>2]=e;t[c>>2]=i;t[l>>2]=r;t[a+20>>2]=f;if(!(t[l>>2]|0)){s=a;return}iA(t[o>>2]|0,121184)|0;if((t[(t[l>>2]|0)+36>>2]|0)!=0?(t[(t[(t[l>>2]|0)+36>>2]|0)+12>>2]|0)!=0:0){iA(t[o>>2]|0,t[(t[(t[l>>2]|0)+36>>2]|0)+12>>2]|0)|0;iA(t[o>>2]|0,121224)|0}iA(t[o>>2]|0,t[(t[l>>2]|0)+8>>2]|0)|0;if(!(t[(t[l>>2]|0)+12>>2]|0)){s=a;return}if(Ki(t[(t[l>>2]|0)+8>>2]|0)|0){s=a;return}t[b>>2]=sy(t[c>>2]|0,t[(t[l>>2]|0)+12>>2]|0,0)|0;c=t[o>>2]|0;if(!(t[b>>2]|0)){iA(c,121400)|0;s=a;return}iA(c,121328)|0;do if(((t[(t[l>>2]|0)+36>>2]|0)==0?(t[(t[l>>2]|0)+20>>2]|0)!=0:0)?(t[(t[(t[l>>2]|0)+20>>2]|0)+36>>2]|0)==0:0){if(((Ql(t[(t[l>>2]|0)+8>>2]|0,121336)|0)!=0?(Ql(t[(t[l>>2]|0)+8>>2]|0,121344)|0)!=0:0)?(Ql(t[(t[l>>2]|0)+8>>2]|0,121352)|0)!=0:0){if(Ql(t[(t[l>>2]|0)+8>>2]|0,121360)|0){m=31;break}if(Ql(t[(t[(t[l>>2]|0)+20>>2]|0)+8>>2]|0,121368)|0){m=31;break}}t[k>>2]=t[b>>2];Hs(t[(t[o>>2]|0)+16>>2]|0,121376)|0;e:while(1){do if((u[t[k>>2]>>0]|0|0)!=32){if(9<=(u[t[k>>2]>>0]|0|0)?(u[t[k>>2]>>0]|0|0)<=10:0)break;if((u[t[k>>2]>>0]|0|0)!=13)break e}while(0);t[k>>2]=(t[k>>2]|0)+1}while(1){t[d>>2]=0;t[v>>2]=is(t[k>>2]|0,121160)|0;if((t[v>>2]|0)!=0?(t[d>>2]=is(t[k>>2]|0,121168)|0,(t[d>>2]|0)!=0):0)n[t[v>>2]>>0]=0;t[h>>2]=qA(t[k>>2]|0,121384)|0;c=t[(t[o>>2]|0)+16>>2]|0;if(t[h>>2]|0){Is(c,t[h>>2]|0)|0;pAi[t[135736>>2]&511](t[h>>2]|0)}else Is(c,t[k>>2]|0)|0;if(!(t[d>>2]|0))break;n[t[v>>2]>>0]=60;t[d>>2]=(t[d>>2]|0)+3;n[w>>0]=n[t[d>>2]>>0]|0;n[t[d>>2]>>0]=0;Is(t[(t[o>>2]|0)+16>>2]|0,t[v>>2]|0)|0;n[t[d>>2]>>0]=n[w>>0]|0;t[k>>2]=t[d>>2]}Hs(t[(t[o>>2]|0)+16>>2]|0,121376)|0}else m=31;while(0);if((m|0)==31)xs(t[(t[o>>2]|0)+16>>2]|0,t[b>>2]|0)|0;pAi[t[135736>>2]&511](t[b>>2]|0);s=a;return}function ur(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,u=0,a=0,o=0,c=0;f=s;s=s+16|0;u=f+12|0;a=f+8|0;o=f+4|0;c=f;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;t[c>>2]=n;if(!((t[o>>2]|0)!=0&(t[o>>2]|0)!=0)){s=f;return}do{tr(t[u>>2]|0,t[a>>2]|0,t[o>>2]|0,t[c>>2]|0);t[o>>2]=t[(t[o>>2]|0)+24>>2]}while((t[o>>2]|0)!=0);s=f;return}function ar(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;var u=0,a=0,o=0,c=0,l=0,b=0;u=s;s=s+32|0;a=u+16|0;o=u+12|0;c=u+8|0;l=u+4|0;b=u;t[a>>2]=e;t[o>>2]=i;t[c>>2]=r;t[l>>2]=n;t[b>>2]=f;if(!((t[c>>2]|0)!=0&(t[c>>2]|0)!=0)){s=u;return}do{Zi(t[a>>2]|0,t[o>>2]|0,t[c>>2]|0,t[l>>2]|0,t[b>>2]|0);t[c>>2]=t[(t[c>>2]|0)+24>>2]}while((t[c>>2]|0)!=0);s=u;return}function or(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0;n=s;s=s+16|0;f=n+12|0;u=n+8|0;a=n;t[f>>2]=e;t[u>>2]=i;t[n+4>>2]=r;t[a>>2]=t[(t[u>>2]|0)+44>>2];if(!(t[a>>2]|0)){fr(1402,t[u>>2]|0,0);s=n;return}iA(t[f>>2]|0,121272)|0;iA(t[f>>2]|0,t[(t[a>>2]|0)+8>>2]|0)|0;if(t[(t[a>>2]|0)+52>>2]|0){iA(t[f>>2]|0,121288)|0;xs(t[(t[f>>2]|0)+16>>2]|0,t[(t[a>>2]|0)+52>>2]|0)|0;if(t[(t[a>>2]|0)+56>>2]|0){iA(t[f>>2]|0,121184)|0;xs(t[(t[f>>2]|0)+16>>2]|0,t[(t[a>>2]|0)+56>>2]|0)|0}}else if(t[(t[a>>2]|0)+56>>2]|0){iA(t[f>>2]|0,121304)|0;xs(t[(t[f>>2]|0)+16>>2]|0,t[(t[a>>2]|0)+56>>2]|0)|0}iA(t[f>>2]|0,121320)|0;s=n;return}function cr(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,a=0,o=0,c=0;r=s;s=s+16|0;n=r;f=r+12|0;a=r+8|0;o=r+4|0;t[f>>2]=e;t[a>>2]=i;if(!(t[f>>2]|0))t[f>>2]=t[_>>2];if(!(t[a>>2]|0)){xe(t[f>>2]|0,121688,n|0)|0;s=r;return}t[o>>2]=0;while(1){if((t[o>>2]|0)>=40)break;if(!(u[(t[a>>2]|0)+(t[o>>2]|0)>>0]|0)){c=18;break}do if((u[(t[a>>2]|0)+(t[o>>2]|0)>>0]|0|0)!=32){if(9<=(u[(t[a>>2]|0)+(t[o>>2]|0)>>0]|0|0)?(u[(t[a>>2]|0)+(t[o>>2]|0)>>0]|0|0)<=10:0){c=12;break}if((u[(t[a>>2]|0)+(t[o>>2]|0)>>0]|0|0)!=13)if((u[(t[a>>2]|0)+(t[o>>2]|0)>>0]|0|0)>=128){i=t[f>>2]|0;t[n>>2]=u[(t[a>>2]|0)+(t[o>>2]|0)>>0];xe(i|0,121696,n|0)|0;break}else{oi(u[(t[a>>2]|0)+(t[o>>2]|0)>>0]|0|0,t[f>>2]|0)|0;break}else c=12}else c=12;while(0);if((c|0)==12){c=0;oi(32,t[f>>2]|0)|0}t[o>>2]=(t[o>>2]|0)+1}if((c|0)==18){s=r;return}xe(t[f>>2]|0,121704,n|0)|0;s=r;return}function lr(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0;n=s;s=s+160|0;f=n+148|0;u=n+144|0;a=n+140|0;o=n;t[f>>2]=e;t[u>>2]=i;t[a>>2]=r;if(!(t[f>>2]|0)){s=n;return}Mr(o);t[o>>2]=t[f>>2];t[o+108>>2]=t[a>>2];Rr(o,t[u>>2]|0);Nr(o);s=n;return}function sr(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0;r=s;s=s+160|0;n=r+144|0;f=r+140|0;u=r;t[n>>2]=e;t[f>>2]=i;if(!(t[n>>2]|0)){s=r;return}Mr(u);t[u>>2]=t[n>>2];Tr(u,t[f>>2]|0);Nr(u);s=r;return}function br(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0;n=s;s=s+160|0;f=n+148|0;u=n+144|0;a=n+140|0;o=n;t[f>>2]=e;t[u>>2]=i;t[a>>2]=r;if(!(t[f>>2]|0)){s=n;return}Mr(o);t[o>>2]=t[f>>2];t[o+108>>2]=t[a>>2];Dr(o,t[u>>2]|0);Nr(o);s=n;return}function kr(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0;r=s;s=s+160|0;n=r+144|0;f=r+140|0;u=r;t[n>>2]=e;t[f>>2]=i;if(!(t[n>>2]|0))t[n>>2]=t[_>>2];Mr(u);i=u+136|0;t[i>>2]=t[i>>2]|1;t[u>>2]=t[n>>2];Br(u,t[f>>2]|0);Nr(u);s=r;return}function hr(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0;r=s;s=s+160|0;n=r+144|0;f=r+140|0;u=r;t[n>>2]=e;t[f>>2]=i;if(!(t[n>>2]|0))t[n>>2]=t[_>>2];Mr(u);i=u+136|0;t[i>>2]=t[i>>2]|1;t[u>>2]=t[n>>2];Ir(u,t[f>>2]|0);Nr(u);s=r;return}function wr(e){e=e|0;var i=0,r=0,n=0,f=0,u=0,a=0;i=s;s=s+16|0;r=i+12|0;n=i+8|0;f=i+4|0;u=i;t[n>>2]=e;t[f>>2]=0;t[u>>2]=0;if(!(t[n>>2]|0)){t[r>>2]=0;a=t[r>>2]|0;s=i;return a|0}switch(t[(t[n>>2]|0)+4>>2]|0){case 21:case 13:case 9:{t[u>>2]=t[(t[n>>2]|0)+12>>2];break}case 20:case 19:case 18:case 17:case 16:case 15:case 14:case 12:case 11:case 6:case 10:case 5:{t[f>>2]=1;break}case 1:{t[u>>2]=t[(t[n>>2]|0)+12>>2];break}case 2:{t[u>>2]=t[(t[n>>2]|0)+12>>2];break}case 8:case 7:case 4:case 3:{if(t[(t[n>>2]|0)+40>>2]|0)t[f>>2]=rs(t[(t[n>>2]|0)+40>>2]|0)|0;break}default:{}}while(1){if(!(t[u>>2]|0))break;t[u>>2]=t[(t[u>>2]|0)+24>>2];t[f>>2]=(t[f>>2]|0)+1}t[r>>2]=t[f>>2];a=t[r>>2]|0;s=i;return a|0}function dr(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0;r=s;s=s+32|0;n=r;f=r+16|0;u=r+12|0;a=r+8|0;t[f>>2]=e;t[u>>2]=i;if(!(t[f>>2]|0)){s=r;return}if(!(t[u>>2]|0)){xe(t[f>>2]|0,121712,n|0)|0;s=r;return}do switch(t[(t[u>>2]|0)+4>>2]|0){case 4:{xe(t[f>>2]|0,121744,n|0)|0;break}case 8:{xe(t[f>>2]|0,121776,n|0)|0;
	break}case 12:{xe(t[f>>2]|0,121816,n|0)|0;break}case 10:{xe(t[f>>2]|0,121800,n|0)|0;break}case 3:{xe(t[f>>2]|0,121736,n|0)|0;break}case 13:{xe(t[f>>2]|0,121792,n|0)|0;break}case 11:{xe(t[f>>2]|0,121808,n|0)|0;break}case 18:{xe(t[f>>2]|0,121824,n|0)|0;break}case 6:{xe(t[f>>2]|0,121760,n|0)|0;break}case 2:{xe(t[f>>2]|0,121728,n|0)|0;break}case 7:{xe(t[f>>2]|0,121768,n|0)|0;break}case 1:{xe(t[f>>2]|0,121720,n|0)|0;break}case 5:{xe(t[f>>2]|0,121752,n|0)|0;break}case 9:{xe(t[f>>2]|0,121784,n|0)|0;break}default:xe(t[f>>2]|0,121832,n|0)|0}while(0);do if((t[(t[u>>2]|0)+4>>2]|0)!=18){i=t[f>>2]|0;if(t[(t[u>>2]|0)+44>>2]|0)xe(i|0,121728,n|0)|0;else xe(i|0,121720,n|0)|0;i=t[f>>2]|0;if(t[(t[u>>2]|0)+48>>2]|0){xe(i|0,121824,n|0)|0;break}else{xe(i|0,121720,n|0)|0;break}}while(0);i=t[f>>2]|0;t[n>>2]=wr(t[u>>2]|0)|0;xe(i|0,121840,n|0)|0;e:do switch(t[(t[u>>2]|0)+4>>2]|0){case 1:{if(t[(t[u>>2]|0)+8>>2]|0){if((t[(t[u>>2]|0)+36>>2]|0)!=0?(t[(t[(t[u>>2]|0)+36>>2]|0)+12>>2]|0)!=0:0){i=t[f>>2]|0;t[n>>2]=t[(t[(t[u>>2]|0)+36>>2]|0)+12>>2];xe(i|0,121848,n|0)|0}i=t[f>>2]|0;t[n>>2]=t[(t[u>>2]|0)+8>>2];xe(i|0,121856,n|0)|0}break}case 6:{if(t[(t[u>>2]|0)+8>>2]|0){i=t[f>>2]|0;t[n>>2]=t[(t[u>>2]|0)+8>>2];xe(i|0,121856,n|0)|0}break}case 2:{if(t[(t[u>>2]|0)+8>>2]|0){i=t[f>>2]|0;t[n>>2]=t[(t[u>>2]|0)+8>>2];xe(i|0,121856,n|0)|0}break}case 5:{if(t[(t[u>>2]|0)+8>>2]|0){i=t[f>>2]|0;t[n>>2]=t[(t[u>>2]|0)+8>>2];xe(i|0,121856,n|0)|0}break}case 12:case 11:case 10:case 13:case 9:case 8:case 4:break;case 3:{if(t[(t[u>>2]|0)+40>>2]|0)cr(t[f>>2]|0,t[(t[u>>2]|0)+40>>2]|0);break}case 7:{if(t[(t[u>>2]|0)+8>>2]|0){i=t[f>>2]|0;t[n>>2]=t[(t[u>>2]|0)+8>>2];xe(i|0,121856,n|0)|0}break}case 18:{t[a>>2]=t[u>>2];i=t[f>>2]|0;e=t[a>>2]|0;if(!(t[(t[a>>2]|0)+12>>2]|0)){t[n>>2]=t[e+8>>2];xe(i|0,121864,n|0)|0;break e}else{o=t[(t[a>>2]|0)+8>>2]|0;t[n>>2]=t[e+12>>2];t[n+4>>2]=o;xe(i|0,121880,n|0)|0;break e}break}default:if(t[(t[u>>2]|0)+8>>2]|0){i=t[f>>2]|0;t[n>>2]=t[(t[u>>2]|0)+8>>2];xe(i|0,121856,n|0)|0}}while(0);xe(t[f>>2]|0,121896,n|0)|0;s=r;return}function vr(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,u=0,a=0,o=0,c=0,l=0,b=0;f=s;s=s+32|0;u=f+24|0;a=f+20|0;o=f+12|0;c=f+4|0;t[a>>2]=e;t[f+16>>2]=i;t[o>>2]=r;t[f+8>>2]=n;if(!(t[a>>2]|0)){t[u>>2]=0;l=t[u>>2]|0;s=f;return l|0}if(!(t[o>>2]|0)){xe(t[(t[a>>2]|0)+20>>2]|0,121712,f|0)|0;t[u>>2]=0;l=t[u>>2]|0;s=f;return l|0}do if((t[(t[o>>2]|0)+4>>2]|0)!=9?(t[(t[o>>2]|0)+4>>2]|0)!=13:0){if((t[(t[o>>2]|0)+4>>2]|0)==18){dr(t[(t[a>>2]|0)+20>>2]|0,t[o>>2]|0);t[u>>2]=0;l=t[u>>2]|0;s=f;return l|0}if(t[(t[o>>2]|0)+12>>2]|0){t[c>>2]=t[(t[o>>2]|0)+12>>2];break}dr(t[(t[a>>2]|0)+20>>2]|0,t[o>>2]|0);t[u>>2]=0;l=t[u>>2]|0;s=f;return l|0}else b=7;while(0);if((b|0)==7)t[c>>2]=t[(t[o>>2]|0)+12>>2];while(1){if(!(t[c>>2]|0))break;dr(t[(t[a>>2]|0)+20>>2]|0,t[c>>2]|0);t[c>>2]=t[(t[c>>2]|0)+24>>2]}t[u>>2]=0;l=t[u>>2]|0;s=f;return l|0}function mr(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,u=0,a=0,o=0,c=0,l=0,b=0;f=s;s=s+32|0;u=f;a=f+24|0;o=f+20|0;c=f+12|0;l=f+4|0;t[o>>2]=e;t[f+16>>2]=i;t[c>>2]=r;t[f+8>>2]=n;if(!(t[o>>2]|0)){t[a>>2]=0;b=t[a>>2]|0;s=f;return b|0}if(!(t[c>>2]|0)){xe(t[(t[o>>2]|0)+20>>2]|0,121712,u|0)|0;t[a>>2]=0;b=t[a>>2]|0;s=f;return b|0}t[l>>2]=oF(t[(t[c>>2]|0)+32>>2]|0,t[c>>2]|0)|0;c=t[(t[o>>2]|0)+20>>2]|0;if(!(t[l>>2]|0))xe(c|0,122072,u|0)|0;else{t[u>>2]=t[l>>2];xe(c|0,122096,u|0)|0;pAi[t[135736>>2]&511](t[l>>2]|0)}t[a>>2]=0;b=t[a>>2]|0;s=f;return b|0}function _r(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,u=0,a=0,o=0,c=0,l=0;f=s;s=s+32|0;u=f+20|0;a=f+16|0;o=f+8|0;t[a>>2]=e;t[f+12>>2]=i;t[o>>2]=r;t[f+4>>2]=n;if(!(t[a>>2]|0)){t[u>>2]=0;c=t[u>>2]|0;s=f;return c|0}if(!(t[o>>2]|0)){xe(t[(t[a>>2]|0)+20>>2]|0,121712,f|0)|0;t[u>>2]=0;c=t[u>>2]|0;s=f;return c|0}do if((t[(t[o>>2]|0)+4>>2]|0)!=9?(t[(t[o>>2]|0)+4>>2]|0)!=13:0){n=t[(t[a>>2]|0)+20>>2]|0;r=t[o>>2]|0;if((t[(t[o>>2]|0)+4>>2]|0)==2){lr(n,r,0);break}else{br(n,r,0);break}}else l=7;while(0);if((l|0)==7)kr(t[(t[a>>2]|0)+20>>2]|0,t[o>>2]|0);t[u>>2]=0;c=t[u>>2]|0;s=f;return c|0}function pr(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,u=0,a=0,o=0,c=0,l=0;f=s;s=s+32|0;u=f;a=f+20|0;o=f+16|0;c=f+8|0;t[o>>2]=e;t[f+12>>2]=i;t[c>>2]=r;t[f+4>>2]=n;if(!(t[o>>2]|0)){t[a>>2]=0;l=t[a>>2]|0;s=f;return l|0}n=t[o>>2]|0;if(!(t[c>>2]|0)){xe(t[n+20>>2]|0,121712,u|0)|0;t[a>>2]=0;l=t[a>>2]|0;s=f;return l|0}r=t[(t[c>>2]|0)+4>>2]|0;do if((t[(t[n+4>>2]|0)+4>>2]|0)==13){i=t[(t[o>>2]|0)+20>>2]|0;if((r|0)==13){ir(i,t[c>>2]|0)|0;break}else{Ji(i,t[(t[o>>2]|0)+4>>2]|0,t[c>>2]|0);break}}else{i=t[(t[o>>2]|0)+20>>2]|0;if((r|0)==9){mV(i,t[c>>2]|0)|0;break}else{bV(i,t[(t[o>>2]|0)+4>>2]|0,t[c>>2]|0);break}}while(0);xe(t[(t[o>>2]|0)+20>>2]|0,121896,u|0)|0;t[a>>2]=0;l=t[a>>2]|0;s=f;return l|0}function Er(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,u=0,a=0,o=0,c=0,l=0,b=0;f=s;s=s+32|0;u=f+24|0;a=f+20|0;o=f+16|0;c=f+4|0;l=f;t[a>>2]=e;t[o>>2]=i;t[f+12>>2]=r;t[f+8>>2]=n;t[l>>2]=0;if((t[a>>2]|0)==0|(t[o>>2]|0)==0){t[u>>2]=-1;b=t[u>>2]|0;s=f;return b|0}if(t[(t[a>>2]|0)+4>>2]|0)t[l>>2]=(t[(t[(t[a>>2]|0)+4>>2]|0)+4>>2]|0)==13&1;n=t[o>>2]|0;if(t[l>>2]|0)t[c>>2]=RN(n,0)|0;else t[c>>2]=_S(n,0,0)|0;if(!(t[c>>2]|0)){t[u>>2]=-1;b=t[u>>2]|0;s=f;return b|0}if((t[(t[a>>2]|0)+16>>2]|0)==1)fy(t[(t[a>>2]|0)+4>>2]|0);t[(t[a>>2]|0)+16>>2]=1;vf(t[(t[a>>2]|0)+12>>2]|0);pAi[t[135736>>2]&511](t[t[a>>2]>>2]|0);t[(t[a>>2]|0)+4>>2]=t[c>>2];t[(t[a>>2]|0)+8>>2]=t[c>>2];n=wf(t[c>>2]|0)|0;t[(t[a>>2]|0)+12>>2]=n;n=KA(t[o>>2]|0)|0;t[t[a>>2]>>2]=n;t[u>>2]=0;b=t[u>>2]|0;s=f;return b|0}function Sr(e,i,r,f){e=e|0;i=i|0;r=r|0;f=f|0;var u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0;u=s;s=s+32|0;a=u;o=u+24|0;c=u+20|0;l=u+16|0;b=u+12|0;k=u+4|0;t[c>>2]=e;t[l>>2]=i;t[b>>2]=r;t[u+8>>2]=f;if(!(t[b>>2]|0)){t[o>>2]=-1;h=t[o>>2]|0;s=u;return h|0}if((t[l>>2]|0)!=0?(n[t[l>>2]>>0]|0)!=0:0){f=t[(t[b>>2]|0)+4>>2]|0;do if((f|0)==9){if((SV(t[l>>2]|0,t[(t[c>>2]|0)+4>>2]|0)|0)<-1){r=t[33976]|0;i=t[33980]|0;t[a>>2]=t[l>>2];yAi[r&511](i,122104,a);t[o>>2]=-1;h=t[o>>2]|0;s=u;return h|0}}else if((f|0)==13){if((rr(t[l>>2]|0,t[(t[c>>2]|0)+4>>2]|0)|0)<0){i=t[33976]|0;r=t[33980]|0;t[a>>2]=t[l>>2];yAi[i&511](r,122104,a);t[o>>2]=-1;h=t[o>>2]|0;s=u;return h|0}}else{t[k>>2]=mi(t[l>>2]|0,122128)|0;if(t[k>>2]|0){bV(t[k>>2]|0,t[(t[c>>2]|0)+4>>2]|0,t[b>>2]|0);Qe(t[k>>2]|0)|0;break}r=t[33976]|0;i=t[33980]|0;t[a>>2]=t[l>>2];yAi[r&511](i,122104,a);t[o>>2]=-1;h=t[o>>2]|0;s=u;return h|0}while(0);t[o>>2]=0;h=t[o>>2]|0;s=u;return h|0}t[o>>2]=-1;h=t[o>>2]|0;s=u;return h|0}function gr(e,i,r,f){e=e|0;i=i|0;r=r|0;f=f|0;var u=0,a=0,o=0,c=0,l=0,b=0;u=s;s=s+32|0;a=u;o=u+20|0;c=u+16|0;l=u+12|0;t[c>>2]=e;t[l>>2]=i;t[u+8>>2]=r;t[u+4>>2]=f;if((t[c>>2]|0)!=0?(t[(t[c>>2]|0)+4>>2]|0)!=0:0){if(!((t[l>>2]|0)!=0?(n[t[l>>2]>>0]|0)!=0:0))t[l>>2]=t[t[c>>2]>>2];if(!(t[l>>2]|0)){t[o>>2]=-1;b=t[o>>2]|0;s=u;return b|0}f=t[(t[(t[c>>2]|0)+4>>2]|0)+4>>2]|0;if((f|0)==9){if((SV(t[l>>2]|0,t[(t[c>>2]|0)+4>>2]|0)|0)<0){r=t[33976]|0;i=t[33980]|0;t[a>>2]=t[l>>2];yAi[r&511](i,122136,a)}}else if((f|0)==13){if((rr(t[l>>2]|0,t[(t[c>>2]|0)+4>>2]|0)|0)<0){c=t[33976]|0;f=t[33980]|0;t[a>>2]=t[l>>2];yAi[c&511](f,122136,a)}}else{yAi[t[135904>>2]&511](t[33980]|0,122160,a);t[o>>2]=-1;b=t[o>>2]|0;s=u;return b|0}t[o>>2]=0;b=t[o>>2]|0;s=u;return b|0}t[o>>2]=-1;b=t[o>>2]|0;s=u;return b|0}function yr(e,i,r,f){e=e|0;i=i|0;r=r|0;f=f|0;var u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0;u=s;s=s+96|0;a=u+88|0;o=u+84|0;c=u+80|0;l=u+8|0;b=u+4|0;k=u;t[o>>2]=e;t[c>>2]=i;t[u+76>>2]=r;t[u+72>>2]=f;t[b>>2]=-1;if((t[o>>2]|0)!=0?(t[(t[o>>2]|0)+4>>2]|0)!=0:0){t[l>>2]=t[v>>2];t[l+4>>2]=203;t[l+8>>2]=203;if((t[c>>2]|0)!=0?(n[t[c>>2]>>0]|0)!=0:0){t[k>>2]=aS(0,t[c>>2]|0)|0;if(t[k>>2]|0){t[b>>2]=dR(l,t[(t[o>>2]|0)+4>>2]|0,t[k>>2]|0)|0;ey(t[k>>2]|0)}}else t[b>>2]=mR(l,t[(t[o>>2]|0)+4>>2]|0)|0;t[a>>2]=t[b>>2];h=t[a>>2]|0;s=u;return h|0}t[a>>2]=-1;h=t[a>>2]|0;s=u;return h|0}function Fr(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0;f=s;s=s+48|0;u=f;a=f+32|0;o=f+28|0;c=f+20|0;l=f+12|0;b=f+8|0;k=f+4|0;t[o>>2]=e;t[f+24>>2]=i;t[c>>2]=r;t[f+16>>2]=n;t[b>>2]=0;if(!(t[o>>2]|0)){t[a>>2]=-1;h=t[a>>2]|0;s=f;return h|0}if(!(t[c>>2]|0)){t[a>>2]=-1;h=t[a>>2]|0;s=f;return h|0}t[l>>2]=t[c>>2];while(1){if(!(t[l>>2]|0))break;if((t[(t[l>>2]|0)+4>>2]|0)!=9?(t[(t[l>>2]|0)+4>>2]|0)!=13:0){if((t[(t[l>>2]|0)+4>>2]|0)==1){t[k>>2]=0;while(1){if((t[k>>2]|0)>=(t[b>>2]|0))break;xe(t[(t[o>>2]|0)+20>>2]|0,122232,u|0)|0;t[k>>2]=(t[k>>2]|0)+1}if((t[(t[l>>2]|0)+36>>2]|0)!=0?(t[(t[(t[l>>2]|0)+36>>2]|0)+12>>2]|0)!=0:0){n=t[(t[o>>2]|0)+20>>2]|0;t[u>>2]=t[(t[(t[l>>2]|0)+36>>2]|0)+12>>2];xe(n|0,121848,u|0)|0}n=t[(t[o>>2]|0)+20>>2]|0;t[u>>2]=t[(t[l>>2]|0)+8>>2];xe(n|0,122096,u|0)|0}}else xe(t[(t[o>>2]|0)+20>>2]|0,122224,u|0)|0;if((t[(t[l>>2]|0)+4>>2]|0)!=9?(t[(t[l>>2]|0)+4>>2]|0)!=13:0){if((t[(t[l>>2]|0)+12>>2]|0)!=0?(t[(t[l>>2]|0)+4>>2]|0)!=5:0){t[l>>2]=t[(t[l>>2]|0)+12>>2];t[b>>2]=(t[b>>2]|0)+1;continue}if((t[l>>2]|0)!=(t[c>>2]|0)?(t[(t[l>>2]|0)+24>>2]|0)!=0:0){t[l>>2]=t[(t[l>>2]|0)+24>>2];continue}if((t[l>>2]|0)==(t[c>>2]|0)){t[l>>2]=0;continue}while(1){if((t[l>>2]|0)==(t[c>>2]|0))break;if(t[(t[l>>2]|0)+20>>2]|0){t[l>>2]=t[(t[l>>2]|0)+20>>2];t[b>>2]=(t[b>>2]|0)+-1}if((t[l>>2]|0)!=(t[c>>2]|0)?(t[(t[l>>2]|0)+24>>2]|0)!=0:0){w=33;break}if(!(t[(t[l>>2]|0)+20>>2]|0)){w=35;break}if((t[l>>2]|0)==(t[c>>2]|0)){w=37;break}}if((w|0)==33){w=0;t[l>>2]=t[(t[l>>2]|0)+24>>2]}else if((w|0)==35){w=0;t[l>>2]=0}else if((w|0)==37){w=0;t[l>>2]=0}if((t[l>>2]|0)!=(t[c>>2]|0))continue;t[l>>2]=0;continue}t[l>>2]=t[(t[l>>2]|0)+12>>2]}t[a>>2]=0;h=t[a>>2]|0;s=f;return h|0}function Or(e,i,r,f){e=e|0;i=i|0;r=r|0;f=f|0;var u=0,a=0,o=0,c=0,l=0,b=0,k=0;u=s;s=s+32|0;a=u;o=u+24|0;c=u+16|0;l=u+12|0;b=u+4|0;t[u+20>>2]=e;t[c>>2]=i;t[l>>2]=r;t[u+8>>2]=f;if((t[l>>2]|0)==0|(t[c>>2]|0)==0){t[o>>2]=-1;k=t[o>>2]|0;s=u;return k|0}t[b>>2]=$y(t[l>>2]|0)|0;if(!(t[b>>2]|0)){t[o>>2]=-1;k=t[o>>2]|0;s=u;return k|0}else{l=t[c>>2]|0;t[a>>2]=t[b>>2];SY(l,499,121856,a)|0;n[(t[c>>2]|0)+499>>0]=48;pAi[t[135736>>2]&511](t[b>>2]|0);t[o>>2]=0;k=t[o>>2]|0;s=u;return k|0}return 0}function Ar(e,i,r,f){e=e|0;i=i|0;r=r|0;f=f|0;var u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,p=0,E=0,S=0,g=0,y=0,F=0,O=0,A=0,M=0,R=0,N=0,T=0;u=s;s=s+2080|0;a=u;o=u+72|0;c=u+68|0;l=u+64|0;b=u+60|0;k=u+1580|0;h=u+56|0;w=u+52|0;d=u+1480|0;v=u+1080|0;m=u+48|0;p=u+44|0;E=u+40|0;S=u+36|0;g=u+576|0;y=u+32|0;F=u+28|0;O=u+24|0;A=u+20|0;M=u+76|0;R=u+16|0;N=u+12|0;T=u+8|0;t[o>>2]=e;t[c>>2]=i;t[l>>2]=r;t[b>>2]=f;VY(k|0,0,500)|0;n[k>>0]=47;n[k+1>>0]=32;n[k+2>>0]=62;n[k+3>>0]=32;t[h>>2]=0;if((t[o>>2]|0)==0|(t[c>>2]|0)==0|(t[l>>2]|0)==0){s=u;return}if(!(t[b>>2]|0))t[b>>2]=t[_>>2];t[p>>2]=gAi[t[135744>>2]&511](28)|0;if(!(t[p>>2]|0)){s=u;return}t[(t[p>>2]|0)+16>>2]=0;t[(t[p>>2]|0)+4>>2]=t[o>>2];t[(t[p>>2]|0)+24>>2]=t[l>>2];t[(t[p>>2]|0)+20>>2]=t[b>>2];b=Yl(t[c>>2]|0)|0;t[t[p>>2]>>2]=b;t[(t[p>>2]|0)+8>>2]=t[(t[p>>2]|0)+4>>2];b=wf(t[(t[p>>2]|0)+4>>2]|0)|0;t[(t[p>>2]|0)+12>>2]=b;if(!(t[(t[p>>2]|0)+12>>2]|0)){pAi[t[135736>>2]&511](t[p>>2]|0);s=u;return}while(1){do if((t[(t[p>>2]|0)+8>>2]|0)==(t[(t[p>>2]|0)+4>>2]|0)){t[a>>2]=122248;SY(k,500,122240,a)|0}else{if((((t[(t[p>>2]|0)+8>>2]|0)!=0?(t[(t[(t[p>>2]|0)+8>>2]|0)+8>>2]|0)!=0:0)?(t[(t[(t[p>>2]|0)+8>>2]|0)+36>>2]|0)!=0:0)?(t[(t[(t[(t[p>>2]|0)+8>>2]|0)+36>>2]|0)+12>>2]|0)!=0:0){b=t[(t[(t[p>>2]|0)+8>>2]|0)+8>>2]|0;t[a>>2]=t[(t[(t[(t[p>>2]|0)+8>>2]|0)+36>>2]|0)+12>>2];t[a+4>>2]=b;SY(k,500,122256,a)|0;break}if((t[(t[p>>2]|0)+8>>2]|0)!=0?(t[(t[(t[p>>2]|0)+8>>2]|0)+8>>2]|0)!=0:0){t[a>>2]=t[(t[(t[p>>2]|0)+8>>2]|0)+8>>2];SY(k,500,122240,a)|0;break}SY(k,500,122272,a)|0}while(0);n[k+499>>0]=0;t[h>>2]=gAi[t[(t[p>>2]|0)+24>>2]&511](k)|0;if(!(t[h>>2]|0))break;t[w>>2]=t[h>>2];while(1){if((n[t[w>>2]>>0]|0)!=32?(n[t[w>>2]>>0]|0)!=9:0)break;t[w>>2]=(t[w>>2]|0)+1}t[m>>2]=0;while(1){if((n[t[w>>2]>>0]|0)==32)break;if((n[t[w>>2]>>0]|0)==9)break;if((n[t[w>>2]>>0]|0)==10)break;if((n[t[w>>2]>>0]|0)==13)break;if(!(n[t[w>>2]>>0]|0))break;b=t[w>>2]|0;t[w>>2]=b+1;c=n[b>>0]|0;b=t[m>>2]|0;t[m>>2]=b+1;n[d+b>>0]=c}n[d+(t[m>>2]|0)>>0]=0;if(!(t[m>>2]|0))continue;while(1){if((n[t[w>>2]>>0]|0)!=32?(n[t[w>>2]>>0]|0)!=9:0)break;t[w>>2]=(t[w>>2]|0)+1}t[m>>2]=0;while(1){if((n[t[w>>2]>>0]|0)==10)break;if((n[t[w>>2]>>0]|0)==13)break;if(!(n[t[w>>2]>>0]|0))break;if(!(n[t[w>>2]>>0]|0))break;c=t[w>>2]|0;t[w>>2]=c+1;b=n[c>>0]|0;c=t[m>>2]|0;t[m>>2]=c+1;n[v+c>>0]=b}n[v+(t[m>>2]|0)>>0]=0;if(!(MY(d,122280)|0))break;if(!(MY(d,122288)|0))break;if(!(MY(d,122296)|0))break;e:do if(MY(d,122304)|0){if(!(MY(d,123880)|0)){yr(t[p>>2]|0,v,0,0)|0;break}if(!(MY(d,123896)|0)){Er(t[p>>2]|0,v,0,0)|0;break}if(!(MY(d,123904)|0)){Hr(t[p>>2]|0,v,0,0)|0;break}if(!(MY(d,123912)|0)){gr(t[p>>2]|0,v,0,0)|0;break}if(!(MY(d,123920)|0))if(!(n[v>>0]|0)){yAi[t[135904>>2]&511](t[33980]|0,123928,a);break}else{Sr(t[p>>2]|0,v,t[(t[p>>2]|0)+8>>2]|0,0)|0;break}if(!(MY(d,123976)|0)){xr(t[p>>2]|0,v,t[(t[p>>2]|0)+8>>2]|0,0)|0;break}if(!(MY(d,123984)|0))if(!(n[v>>0]|0)){DA(t[(t[p>>2]|0)+20>>2]|0,0);break}else{t[S>>2]=0;t[a>>2]=S;jq(v,123992,a)|0;DA(t[(t[p>>2]|0)+20>>2]|0,t[S>>2]|0);break}if(!(MY(d,124e3)|0)){if(Or(t[p>>2]|0,g,t[(t[p>>2]|0)+8>>2]|0,0)|0)break;b=t[(t[p>>2]|0)+20>>2]|0;t[a>>2]=g;xe(b|0,122096,a|0)|0;break}if(!(MY(d,124008)|0)){b=t[p>>2]|0;if(!(n[v>>0]|0)){Fr(b,0,t[(t[p>>2]|0)+8>>2]|0,0)|0;break}t[(t[(t[p>>2]|0)+12>>2]|0)+4>>2]=t[b+8>>2];t[(t[(t[p>>2]|0)+12>>2]|0)+4>>2]=t[(t[p>>2]|0)+8>>2];t[E>>2]=Et(v,t[(t[p>>2]|0)+12>>2]|0)|0;if(t[E>>2]|0){i:do switch(t[t[E>>2]>>2]|0){case 8:{b=t[33976]|0;c=t[33980]|0;t[a>>2]=v;yAi[b&511](c,122016,a);break}case 9:{c=t[33976]|0;b=t[33980]|0;t[a>>2]=v;yAi[c&511](b,122040,a);break}case 3:{b=t[33976]|0;c=t[33980]|0;t[a>>2]=v;yAi[b&511](c,121952,a);break}case 4:{c=t[33976]|0;b=t[33980]|0;t[a>>2]=v;yAi[c&511](b,121968,a);break}case 7:{b=t[33976]|0;c=t[33980]|0;t[a>>2]=v;yAi[b&511](c,122e3,a);break}case 0:{c=t[33976]|0;b=t[33980]|0;t[a>>2]=v;yAi[c&511](b,121904,a);break}case 1:{if(!(t[(t[E>>2]|0)+4>>2]|0))break i;t[y>>2]=0;while(1){if((t[y>>2]|0)>=(t[t[(t[E>>2]|0)+4>>2]>>2]|0))break i;Fr(t[p>>2]|0,0,t[(t[(t[(t[E>>2]|0)+4>>2]|0)+8>>2]|0)+(t[y>>2]<<2)>>2]|0,0)|0;t[y>>2]=(t[y>>2]|0)+1}break}case 2:{b=t[33976]|0;c=t[33980]|0;t[a>>2]=v;yAi[b&511](c,121928,a);break}case 5:{c=t[33976]|0;b=t[33980]|0;t[a>>2]=v;yAi[c&511](b,121984,a);break}case 6:{b=t[33976]|0;c=t[33980]|0;t[a>>2]=v;yAi[b&511](c,122e3,a);break}default:{}}while(0);_n(t[E>>2]|0)}else{c=t[33976]|0;b=t[33980]|0;t[a>>2]=v;yAi[c&511](b,121904,a)}t[(t[(t[p>>2]|0)+12>>2]|0)+4>>2]=0;break}if(!(MY(d,124016)|0)){mr(t[p>>2]|0,0,t[(t[p>>2]|0)+8>>2]|0,0)|0;break}if(!(MY(d,124024)|0)){Ur(t[p>>2]|0,v,t[(t[p>>2]|0)+8>>2]|0,0)|0;break}if(!(MY(d,124032)|0))if(!(n[v>>0]|0)){yAi[t[135904>>2]&511](t[33980]|0,124040,a);break}else{zr(t[p>>2]|0,v,0,0)|0;break}if(!(MY(d,124072)|0)){t[F>>2]=eF(t[(t[p>>2]|0)+4>>2]|0)|0;jr(t[p>>2]|0,0,t[F>>2]|0,0)|0;break}if(!(MY(d,124088)|0))if(!(n[v>>0]|0)){yAi[t[135904>>2]&511](t[33980]|0,124096,a);break}else{t[(t[(t[p>>2]|0)+12>>2]|0)+4>>2]=t[(t[p>>2]|0)+8>>2];t[E>>2]=Et(v,t[(t[p>>2]|0)+12>>2]|0)|0;pn(t[(t[p>>2]|0)+20>>2]|0,t[E>>2]|0,0);_n(t[E>>2]|0);break}if(!(MY(d,124128)|0)){Vr(t[p>>2]|0,v,t[(t[p>>2]|0)+8>>2]|0,0)|0;break}do if(MY(d,124136)|0){if(!(MY(d,124144)|0))break;if(!(MY(d,124152)|0)){b=t[p>>2]|0;if(!(n[v>>0]|0)){if(Or(b,M,t[(t[p>>2]|0)+8>>2]|0,0)|0)break e;c=t[(t[p>>2]|0)+20>>2]|0;t[a>>2]=M;xe(c|0,122096,a|0)|0;break e}t[(t[(t[p>>2]|0)+12>>2]|0)+4>>2]=t[b+8>>2];t[E>>2]=Et(v,t[(t[p>>2]|0)+12>>2]|0)|0;if(t[E>>2]|0){i:do switch(t[t[E>>2]>>2]|0){case 4:{b=t[33976]|0;c=t[33980]|0;t[a>>2]=v;yAi[b&511](c,121968,a);break}case 5:{c=t[33976]|0;b=t[33980]|0;t[a>>2]=v;yAi[c&511](b,121984,a);break}case 6:{b=t[33976]|0;c=t[33980]|0;t[a>>2]=v;yAi[b&511](c,122e3,a);break}case 7:{c=t[33976]|0;b=t[33980]|0;t[a>>2]=v;yAi[c&511](b,122e3,a);break}case 8:{b=t[33976]|0;c=t[33980]|0;t[a>>2]=v;yAi[b&511](c,122016,a);break}case 9:{c=t[33976]|0;b=t[33980]|0;t[a>>2]=v;yAi[c&511](b,122040,a);break}case 2:{b=t[33976]|0;c=t[33980]|0;t[a>>2]=v;yAi[b&511](c,121928,a);break}case 3:{c=t[33976]|0;b=t[33980]|0;t[a>>2]=v;yAi[c&511](b,121952,a);break}case 0:{b=t[33976]|0;c=t[33980]|0;t[a>>2]=v;yAi[b&511](c,121904,a);break}case 1:{if(!(t[(t[E>>2]|0)+4>>2]|0))break i;t[R>>2]=0;while(1){if((t[R>>2]|0)>=(t[t[(t[E>>2]|0)+4>>2]>>2]|0))break i;if(!(Or(t[p>>2]|0,M,t[(t[(t[(t[E>>2]|0)+4>>2]|0)+8>>2]|0)+(t[R>>2]<<2)>>2]|0,0)|0)){c=t[(t[p>>2]|0)+20>>2]|0;t[a>>2]=M;xe(c|0,122096,a|0)|0}t[R>>2]=(t[R>>2]|0)+1}break}default:{}}while(0);_n(t[E>>2]|0)}else{c=t[33976]|0;b=t[33980]|0;t[a>>2]=v;yAi[c&511](b,121904,a)}t[(t[(t[p>>2]|0)+12>>2]|0)+4>>2]=0;break e}if(MY(d,124160)|0){if(MY(d,124248)|0){b=t[33976]|0;c=t[33980]|0;t[a>>2]=d;yAi[b&511](c,124272,a);break e}c=t[p>>2]|0;if(!(n[v>>0]|0)){pr(c,0,t[(t[p>>2]|0)+8>>2]|0,0)|0;break e}t[(t[(t[p>>2]|0)+12>>2]|0)+4>>2]=t[c+8>>2];t[(t[(t[p>>2]|0)+12>>2]|0)+4>>2]=t[(t[p>>2]|0)+8>>2];t[E>>2]=Et(v,t[(t[p>>2]|0)+12>>2]|0)|0;if(t[E>>2]|0){i:do switch(t[t[E>>2]>>2]|0){case 2:{c=t[33976]|0;b=t[33980]|0;t[a>>2]=v;yAi[c&511](b,121928,a);break}case 3:{b=t[33976]|0;c=t[33980]|0;t[a>>2]=v;yAi[b&511](c,121952,a);break}case 4:{c=t[33976]|0;b=t[33980]|0;t[a>>2]=v;yAi[c&511](b,121968,a);break}case 5:{b=t[33976]|0;c=t[33980]|0;t[a>>2]=v;yAi[b&511](c,121984,a);break}case 6:{c=t[33976]|0;b=t[33980]|0;t[a>>2]=v;yAi[c&511](b,122e3,a);break}case 7:{b=t[33976]|0;c=t[33980]|0;t[a>>2]=v;yAi[b&511](c,122e3,a);break}case 8:{c=t[33976]|0;b=t[33980]|0;t[a>>2]=v;yAi[c&511](b,122016,a);break}case 9:{b=t[33976]|0;c=t[33980]|0;t[a>>2]=v;yAi[b&511](c,122040,a);break}case 0:{c=t[33976]|0;b=t[33980]|0;t[a>>2]=v;yAi[c&511](b,121904,a);break}case 1:{if(!(t[(t[E>>2]|0)+4>>2]|0))break i;t[T>>2]=0;while(1){if((t[T>>2]|0)>=(t[t[(t[E>>2]|0)+4>>2]>>2]|0))break i;if((t[m>>2]|0)>0)xe(t[(t[p>>2]|0)+20>>2]|0,124256,a|0)|0;pr(t[p>>2]|0,0,t[(t[(t[(t[E>>2]|0)+4>>2]|0)+8>>2]|0)+(t[T>>2]<<2)>>2]|0,0)|0;t[T>>2]=(t[T>>2]|0)+1}break}default:{}}while(0);_n(t[E>>2]|0)}else{b=t[33976]|0;c=t[33980]|0;t[a>>2]=v;yAi[b&511](c,121904,a)}t[(t[(t[p>>2]|0)+12>>2]|0)+4>>2]=0;break e}c=t[p>>2]|0;if(!(n[v>>0]|0)){t[(t[p>>2]|0)+8>>2]=t[c+4>>2];break e}t[(t[(t[p>>2]|0)+12>>2]|0)+4>>2]=t[c+8>>2];t[N>>2]=HY(v|0)|0;do if((t[N>>2]|0)>=2){if((n[v+((t[N>>2]|0)-1)>>0]|0)!=47)break;n[v+((t[N>>2]|0)-1)>>0]=0}while(0);t[E>>2]=Et(v,t[(t[p>>2]|0)+12>>2]|0)|0;if(t[E>>2]|0){i:do switch(t[t[E>>2]>>2]|0){case 0:{c=t[33976]|0;b=t[33980]|0;t[a>>2]=v;yAi[c&511](b,121904,a);break}case 1:{if(!(t[(t[E>>2]|0)+4>>2]|0)){b=t[33976]|0;c=t[33980]|0;t[a>>2]=v;yAi[b&511](c,124216,a);break i}if((t[t[(t[E>>2]|0)+4>>2]>>2]|0)!=1){c=t[33976]|0;b=t[33980]|0;l=t[t[(t[E>>2]|0)+4>>2]>>2]|0;t[a>>2]=v;t[a+4>>2]=l;yAi[c&511](b,124192,a);break i}t[(t[p>>2]|0)+8>>2]=t[t[(t[(t[E>>2]|0)+4>>2]|0)+8>>2]>>2];if(!(t[(t[p>>2]|0)+8>>2]|0))break i;if((t[(t[(t[p>>2]|0)+8>>2]|0)+4>>2]|0)!=18)break i;yAi[t[135904>>2]&511](t[33980]|0,124168,a);t[(t[p>>2]|0)+8>>2]=0;break}case 2:{b=t[33976]|0;c=t[33980]|0;t[a>>2]=v;yAi[b&511](c,121928,a);break}case 3:{c=t[33976]|0;b=t[33980]|0;t[a>>2]=v;yAi[c&511](b,121952,a);break}case 4:{b=t[33976]|0;c=t[33980]|0;t[a>>2]=v;yAi[b&511](c,121968,a);break}case 5:{c=t[33976]|0;b=t[33980]|0;t[a>>2]=v;yAi[c&511](b,121984,a);break}case 6:{b=t[33976]|0;c=t[33980]|0;t[a>>2]=v;yAi[b&511](c,122e3,a);break}case 7:{c=t[33976]|0;b=t[33980]|0;t[a>>2]=v;yAi[c&511](b,122e3,a);break}case 8:{b=t[33976]|0;c=t[33980]|0;t[a>>2]=v;yAi[b&511](c,122016,a);break}case 9:{c=t[33976]|0;b=t[33980]|0;t[a>>2]=v;yAi[c&511](b,122040,a);break}default:{}}while(0);_n(t[E>>2]|0)}else{b=t[33976]|0;c=t[33980]|0;t[a>>2]=v;yAi[b&511](c,121904,a)}t[(t[(t[p>>2]|0)+12>>2]|0)+4>>2]=0;break e}while(0);t[O>>2]=((MY(d,124144)|0)!=0^1)&1;if(!(n[v>>0]|0)){c=t[p>>2]|0;b=t[(t[p>>2]|0)+8>>2]|0;if(t[O>>2]|0){_r(c,0,b,0)|0;break}else{vr(c,0,b,0)|0;break}}t[(t[(t[p>>2]|0)+12>>2]|0)+4>>2]=t[(t[p>>2]|0)+8>>2];t[(t[(t[p>>2]|0)+12>>2]|0)+4>>2]=t[(t[p>>2]|0)+8>>2];t[E>>2]=Et(v,t[(t[p>>2]|0)+12>>2]|0)|0;if(t[E>>2]|0){i:do switch(t[t[E>>2]>>2]|0){case 1:{if(!(t[(t[E>>2]|0)+4>>2]|0))break i;t[A>>2]=0;while(1){if((t[A>>2]|0)>=(t[t[(t[E>>2]|0)+4>>2]>>2]|0))break i;b=t[p>>2]|0;c=t[(t[(t[(t[E>>2]|0)+4>>2]|0)+8>>2]|0)+(t[A>>2]<<2)>>2]|0;if(t[O>>2]|0)_r(b,0,c,0)|0;else vr(b,0,c,0)|0;t[A>>2]=(t[A>>2]|0)+1}break}case 7:{c=t[33976]|0;b=t[33980]|0;t[a>>2]=v;yAi[c&511](b,122e3,a);break}case 8:{b=t[33976]|0;c=t[33980]|0;t[a>>2]=v;yAi[b&511](c,122016,a);break}case 9:{c=t[33976]|0;b=t[33980]|0;t[a>>2]=v;yAi[c&511](b,122040,a);break}case 0:{b=t[33976]|0;c=t[33980]|0;t[a>>2]=v;yAi[b&511](c,121904,a);break}case 2:{c=t[33976]|0;b=t[33980]|0;t[a>>2]=v;yAi[c&511](b,121928,a);break}case 3:{b=t[33976]|0;c=t[33980]|0;t[a>>2]=v;yAi[b&511](c,121952,a);break}case 4:{c=t[33976]|0;b=t[33980]|0;t[a>>2]=v;yAi[c&511](b,121968,a);break}case 5:{b=t[33976]|0;c=t[33980]|0;t[a>>2]=v;yAi[b&511](c,121984,a);break}case 6:{c=t[33976]|0;b=t[33980]|0;t[a>>2]=v;yAi[c&511](b,122e3,a);break}default:{}}while(0);_n(t[E>>2]|0)}else{b=t[33976]|0;c=t[33980]|0;t[a>>2]=v;yAi[b&511](c,121904,a)}t[(t[(t[p>>2]|0)+12>>2]|0)+4>>2]=0}else{xe(t[(t[p>>2]|0)+20>>2]|0,122312,a|0)|0;xe(t[(t[p>>2]|0)+20>>2]|0,122360,a|0)|0;xe(t[(t[p>>2]|0)+20>>2]|0,122408,a|0)|0;xe(t[(t[p>>2]|0)+20>>2]|0,122440,a|0)|0;xe(t[(t[p>>2]|0)+20>>2]|0,122488,a|0)|0;xe(t[(t[p>>2]|0)+20>>2]|0,122544,a|0)|0;xe(t[(t[p>>2]|0)+20>>2]|0,122632,a|0)|0;xe(t[(t[p>>2]|0)+20>>2]|0,122712,a|0)|0;xe(t[(t[p>>2]|0)+20>>2]|0,122744,a|0)|0;xe(t[(t[p>>2]|0)+20>>2]|0,122784,a|0)|0;xe(t[(t[p>>2]|0)+20>>2]|0,122824,a|0)|0;xe(t[(t[p>>2]|0)+20>>2]|0,122872,a|0)|0;xe(t[(t[p>>2]|0)+20>>2]|0,122936,a|0)|0;xe(t[(t[p>>2]|0)+20>>2]|0,123024,a|0)|0;xe(t[(t[p>>2]|0)+20>>2]|0,123112,a|0)|0;xe(t[(t[p>>2]|0)+20>>2]|0,123192,a|0)|0;xe(t[(t[p>>2]|0)+20>>2]|0,123280,a|0)|0;xe(t[(t[p>>2]|0)+20>>2]|0,123344,a|0)|0;xe(t[(t[p>>2]|0)+20>>2]|0,123416,a|0)|0;xe(t[(t[p>>2]|0)+20>>2]|0,123472,a|0)|0;xe(t[(t[p>>2]|0)+20>>2]|0,123552,a|0)|0;xe(t[(t[p>>2]|0)+20>>2]|0,123584,a|0)|0;xe(t[(t[p>>2]|0)+20>>2]|0,123648,a|0)|0;xe(t[(t[p>>2]|0)+20>>2]|0,123704,a|0)|0;xe(t[(t[p>>2]|0)+20>>2]|0,123752,a|0)|0;xe(t[(t[p>>2]|0)+20>>2]|0,123824,a|0)|0}while(0);Zq(t[h>>2]|0);t[h>>2]=0}vf(t[(t[p>>2]|0)+12>>2]|0);if(t[(t[p>>2]|0)+16>>2]|0)fy(t[(t[p>>2]|0)+4>>2]|0);if(t[t[p>>2]>>2]|0)pAi[t[135736>>2]&511](t[t[p>>2]>>2]|0);pAi[t[135736>>2]&511](t[p>>2]|0);if(!(t[h>>2]|0)){s=u;return}Zq(t[h>>2]|0);s=u;return}function Mr(e){e=e|0;var i=0,r=0,f=0;i=s;s=s+16|0;r=i+4|0;f=i;t[r>>2]=e;t[(t[r>>2]|0)+108>>2]=0;t[(t[r>>2]|0)+124>>2]=0;t[(t[r>>2]|0)+128>>2]=0;t[t[r>>2]>>2]=t[_>>2];t[(t[r>>2]|0)+112>>2]=0;t[(t[r>>2]|0)+116>>2]=0;t[(t[r>>2]|0)+120>>2]=0;t[(t[r>>2]|0)+132>>2]=0;t[(t[r>>2]|0)+136>>2]=0;t[f>>2]=0;while(1){if((t[f>>2]|0)>=100)break;n[(t[r>>2]|0)+4+(t[f>>2]|0)>>0]=32;t[f>>2]=(t[f>>2]|0)+1}n[(t[r>>2]|0)+104>>0]=0;s=i;return}function Rr(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0;r=s;s=s+16|0;n=r;f=r+8|0;u=r+4|0;t[f>>2]=e;t[u>>2]=i;qr(t[f>>2]|0);i=(t[(t[f>>2]|0)+124>>2]|0)!=0;if(!(t[u>>2]|0)){if(i){s=r;return}xe(t[t[f>>2]>>2]|0,127816,n|0)|0;s=r;return}if(!i?(xe(t[t[f>>2]>>2]|0,127832,n|0)|0,Yr(t[f>>2]|0,t[(t[u>>2]|0)+8>>2]|0),xe(t[t[f>>2]>>2]|0,121896,n|0)|0,(t[(t[u>>2]|0)+12>>2]|0)!=0):0){n=(t[f>>2]|0)+108|0;t[n>>2]=(t[n>>2]|0)+1;Pr(t[f>>2]|0,t[(t[u>>2]|0)+12>>2]|0);n=(t[f>>2]|0)+108|0;t[n>>2]=(t[n>>2]|0)+-1}if(!(t[(t[u>>2]|0)+8>>2]|0))Gr(t[f>>2]|0,5015,127848);Wr(t[f>>2]|0,t[u>>2]|0);s=r;return}function Nr(e){e=e|0;var i=0;i=s;s=s+16|0;t[i>>2]=e;s=i;return}function Tr(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0;r=s;s=s+32|0;n=r;f=r+16|0;u=r+12|0;a=r+8|0;o=r+4|0;t[f>>2]=e;t[u>>2]=i;if(!(t[u>>2]|0)){s=r;return}Kr(t[f>>2]|0,t[u>>2]|0);if((t[(t[u>>2]|0)+44>>2]|0)!=0?(t[(t[(t[u>>2]|0)+44>>2]|0)+48>>2]|0)!=0:0){t[a>>2]=t[(t[(t[u>>2]|0)+44>>2]|0)+48>>2];if(!(t[(t[f>>2]|0)+124>>2]|0))xe(t[t[f>>2]>>2]|0,127472,n|0)|0;aO(t[a>>2]|0,259,t[f>>2]|0)}else xe(t[t[f>>2]>>2]|0,127504,n|0)|0;if((t[(t[u>>2]|0)+48>>2]|0)!=0?(t[(t[(t[u>>2]|0)+48>>2]|0)+48>>2]|0)!=0:0){t[o>>2]=t[(t[(t[u>>2]|0)+48>>2]|0)+48>>2];if(!(t[(t[f>>2]|0)+124>>2]|0))xe(t[t[f>>2]>>2]|0,127536,n|0)|0;aO(t[o>>2]|0,259,t[f>>2]|0);s=r;return}if(t[(t[f>>2]|0)+124>>2]|0){s=r;return}xe(t[t[f>>2]>>2]|0,127568,n|0)|0;s=r;return}function Lr(e,i){e=e|0;i=i|0;var r=0,n=0,f=0;r=s;s=s+16|0;n=r+4|0;f=r;t[n>>2]=e;t[f>>2]=i;while(1){if(!(t[f>>2]|0))break;Rr(t[n>>2]|0,t[f>>2]|0);t[f>>2]=t[(t[f>>2]|0)+24>>2]}s=r;return}function Dr(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0;r=s;s=s+16|0;n=r;f=r+12|0;u=r+8|0;a=r+4|0;t[f>>2]=e;t[u>>2]=i;if(!(t[u>>2]|0)){if(t[(t[f>>2]|0)+124>>2]|0){s=r;return}qr(t[f>>2]|0);xe(t[t[f>>2]>>2]|0,126040,n|0)|0;s=r;return}t[(t[f>>2]|0)+116>>2]=t[u>>2];e:do switch(t[(t[u>>2]|0)+4>>2]|0){case 1:{if(!(t[(t[f>>2]|0)+124>>2]|0)){qr(t[f>>2]|0);xe(t[t[f>>2]>>2]|0,126056,n|0)|0;if((t[(t[u>>2]|0)+36>>2]|0)!=0?(t[(t[(t[u>>2]|0)+36>>2]|0)+12>>2]|0)!=0:0){Yr(t[f>>2]|0,t[(t[(t[u>>2]|0)+36>>2]|0)+12>>2]|0);xe(t[t[f>>2]>>2]|0,126072,n|0)|0}Yr(t[f>>2]|0,t[(t[u>>2]|0)+8>>2]|0);xe(t[t[f>>2]>>2]|0,121896,n|0)|0}break}case 4:{if(!(t[(t[f>>2]|0)+124>>2]|0)){qr(t[f>>2]|0);xe(t[t[f>>2]>>2]|0,126168,n|0)|0}break}case 15:{Jr(t[f>>2]|0,t[u>>2]|0);s=r;return}case 13:case 9:{if(!(t[(t[f>>2]|0)+124>>2]|0))qr(t[f>>2]|0);xe(t[t[f>>2]>>2]|0,126232,n|0)|0;Wr(t[f>>2]|0,t[u>>2]|0);s=r;return}case 11:{if(!(t[(t[f>>2]|0)+124>>2]|0)){qr(t[f>>2]|0);xe(t[t[f>>2]>>2]|0,126280,n|0)|0}break}case 2:{if(!(t[(t[f>>2]|0)+124>>2]|0))qr(t[f>>2]|0);xe(t[t[f>>2]>>2]|0,126080,n|0)|0;Wr(t[f>>2]|0,t[u>>2]|0);s=r;return}case 16:{Qr(t[f>>2]|0,t[u>>2]|0);s=r;return}case 5:{if(!(t[(t[f>>2]|0)+124>>2]|0)){qr(t[f>>2]|0);i=t[t[f>>2]>>2]|0;t[n>>2]=t[(t[u>>2]|0)+8>>2];xe(i|0,126184,n|0)|0}break}case 17:{$r(t[f>>2]|0,t[u>>2]|0);s=r;return}case 8:{if(!(t[(t[f>>2]|0)+124>>2]|0)){qr(t[f>>2]|0);xe(t[t[f>>2]>>2]|0,126216,n|0)|0}break}case 7:{if(!(t[(t[f>>2]|0)+124>>2]|0)){qr(t[f>>2]|0);i=t[t[f>>2]>>2]|0;t[n>>2]=t[(t[u>>2]|0)+8>>2];xe(i|0,126208,n|0)|0}break}case 12:{if(!(t[(t[f>>2]|0)+124>>2]|0)){qr(t[f>>2]|0);xe(t[t[f>>2]>>2]|0,126296,n|0)|0}break}case 14:{Zr(t[f>>2]|0,t[u>>2]|0);s=r;return}case 19:{if(t[(t[f>>2]|0)+124>>2]|0){s=r;return}qr(t[f>>2]|0);xe(t[t[f>>2]>>2]|0,126312,n|0)|0;s=r;return}case 6:{if(!(t[(t[f>>2]|0)+124>>2]|0)){qr(t[f>>2]|0);xe(t[t[f>>2]>>2]|0,126200,n|0)|0}break}case 10:{if(!(t[(t[f>>2]|0)+124>>2]|0)){qr(t[f>>2]|0);xe(t[t[f>>2]>>2]|0,126264,n|0)|0}break}case 18:{en(t[f>>2]|0,t[u>>2]|0);s=r;return}case 20:{if(t[(t[f>>2]|0)+124>>2]|0){s=r;return}qr(t[f>>2]|0);xe(t[t[f>>2]>>2]|0,126328,n|0)|0;s=r;return}case 3:{if(!(t[(t[f>>2]|0)+124>>2]|0)){qr(t[f>>2]|0);i=t[t[f>>2]>>2]|0;if((t[(t[u>>2]|0)+8>>2]|0)==75112)xe(i|0,126112,n|0)|0;else xe(i|0,126128,n|0)|0;if(!(t[(t[f>>2]|0)+136>>2]&1)){xe(t[t[f>>2]>>2]|0,121896,n|0)|0;break e}i=t[f>>2]|0;if((t[(t[u>>2]|0)+40>>2]|0)==((t[u>>2]|0)+44|0)){xe(t[i>>2]|0,126136,n|0)|0;break e}e=(wz(t[i+120>>2]|0,t[(t[u>>2]|0)+40>>2]|0)|0)==1;i=t[t[f>>2]>>2]|0;if(e){xe(i|0,126152,n|0)|0;break e}else{xe(i|0,121896,n|0)|0;break e}}break}default:{if(!(t[(t[f>>2]|0)+124>>2]|0))qr(t[f>>2]|0);rn(t[f>>2]|0,5011,126016,t[(t[u>>2]|0)+4>>2]|0);s=r;return}}while(0);if(!(t[(t[u>>2]|0)+32>>2]|0)){if(!(t[(t[f>>2]|0)+124>>2]|0))qr(t[f>>2]|0);xe(t[t[f>>2]>>2]|0,126344,n|0)|0}i=(t[f>>2]|0)+108|0;t[i>>2]=(t[i>>2]|0)+1;if((t[(t[u>>2]|0)+4>>2]|0)==1?(t[(t[u>>2]|0)+48>>2]|0)!=0:0)nn(t[f>>2]|0,t[(t[u>>2]|0)+48>>2]|0);if((t[(t[u>>2]|0)+4>>2]|0)==1?(t[(t[u>>2]|0)+44>>2]|0)!=0:0)Lr(t[f>>2]|0,t[(t[u>>2]|0)+44>>2]|0);i=t[u>>2]|0;if((t[(t[u>>2]|0)+4>>2]|0)!=5){if(((t[i+4>>2]|0)!=1?(t[(t[u>>2]|0)+40>>2]|0)!=0:0)?(t[(t[f>>2]|0)+124>>2]|0)==0:0){qr(t[f>>2]|0);xe(t[t[f>>2]>>2]|0,126368,n|0)|0;Yr(t[f>>2]|0,t[(t[u>>2]|0)+40>>2]|0);xe(t[t[f>>2]>>2]|0,121896,n|0)|0}}else{t[a>>2]=h_(t[i+32>>2]|0,t[(t[u>>2]|0)+8>>2]|0)|0;if(t[a>>2]|0)fn(t[f>>2]|0,t[a>>2]|0)}a=(t[f>>2]|0)+108|0;t[a>>2]=(t[a>>2]|0)+-1;Wr(t[f>>2]|0,t[u>>2]|0);s=r;return}function Cr(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0;r=s;s=s+16|0;n=r;f=r+8|0;u=r+4|0;t[f>>2]=e;t[u>>2]=i;i=t[f>>2]|0;if(!(t[u>>2]|0)){if(t[i+124>>2]|0){s=r;return}qr(t[f>>2]|0);xe(t[t[f>>2]>>2]|0,126040,n|0)|0;s=r;return}Dr(i,t[u>>2]|0);if((t[(t[u>>2]|0)+4>>2]|0)==18){s=r;return}if(!(t[(t[u>>2]|0)+12>>2]|0)){s=r;return}if((t[(t[u>>2]|0)+4>>2]|0)==5){s=r;return}i=(t[f>>2]|0)+108|0;t[i>>2]=(t[i>>2]|0)+1;Pr(t[f>>2]|0,t[(t[u>>2]|0)+12>>2]|0);u=(t[f>>2]|0)+108|0;t[u>>2]=(t[u>>2]|0)+-1;s=r;return}function Pr(e,i){e=e|0;i=i|0;var r=0,n=0,f=0;r=s;s=s+16|0;n=r+4|0;f=r;t[n>>2]=e;t[f>>2]=i;while(1){if(!(t[f>>2]|0))break;Cr(t[n>>2]|0,t[f>>2]|0);t[f>>2]=t[(t[f>>2]|0)+24>>2]}s=r;return}function Br(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0;r=s;s=s+16|0;n=r;f=r+8|0;u=r+4|0;t[f>>2]=e;t[u>>2]=i;if(!(t[u>>2]|0)){s=r;return}Kr(t[f>>2]|0,t[u>>2]|0);if(!(t[(t[f>>2]|0)+124>>2]|0)){if(t[(t[u>>2]|0)+8>>2]|0){xe(t[t[f>>2]>>2]|0,125424,n|0)|0;Yr(t[f>>2]|0,t[(t[u>>2]|0)+8>>2]|0);xe(t[t[f>>2]>>2]|0,121896,n|0)|0}if(t[(t[u>>2]|0)+56>>2]|0){xe(t[t[f>>2]>>2]|0,125432,n|0)|0;Yr(t[f>>2]|0,t[(t[u>>2]|0)+56>>2]|0);xe(t[t[f>>2]>>2]|0,121896,n|0)|0}if(t[(t[u>>2]|0)+60>>2]|0){xe(t[t[f>>2]>>2]|0,125448,n|0)|0;Yr(t[f>>2]|0,t[(t[u>>2]|0)+60>>2]|0);xe(t[t[f>>2]>>2]|0,121896,n|0)|0}if(t[(t[u>>2]|0)+72>>2]|0){xe(t[t[f>>2]>>2]|0,125464,n|0)|0;Yr(t[f>>2]|0,t[(t[u>>2]|0)+72>>2]|0);xe(t[t[f>>2]>>2]|0,121896,n|0)|0}if(t[(t[u>>2]|0)+40>>2]|0)xe(t[t[f>>2]>>2]|0,125472,n|0)|0}if(!(t[(t[u>>2]|0)+52>>2]|0)){s=r;return}nn(t[f>>2]|0,t[(t[u>>2]|0)+52>>2]|0);s=r;return}function Ir(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0;r=s;s=s+16|0;n=r;f=r+8|0;u=r+4|0;t[f>>2]=e;t[u>>2]=i;i=t[f>>2]|0;if(!(t[u>>2]|0)){if(t[i+124>>2]|0){s=r;return}xe(t[t[f>>2]>>2]|0,125400,n|0)|0;s=r;return}Br(i,t[u>>2]|0);if((t[(t[u>>2]|0)+4>>2]|0)!=9?(t[(t[u>>2]|0)+4>>2]|0)!=13:0){s=r;return}if(!(t[(t[u>>2]|0)+12>>2]|0)){s=r;return}i=(t[f>>2]|0)+108|0;t[i>>2]=(t[i>>2]|0)+1;Pr(t[f>>2]|0,t[(t[u>>2]|0)+12>>2]|0);u=(t[f>>2]|0)+108|0;t[u>>2]=(t[u>>2]|0)+-1;s=r;return}function Hr(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0;f=s;s=s+48|0;u=f;a=f+36|0;o=f+32|0;c=f+28|0;l=f+16|0;b=f+12|0;k=f+8|0;h=f+4|0;t[o>>2]=e;t[c>>2]=i;t[f+24>>2]=r;t[f+20>>2]=n;t[b>>2]=IH(t[c>>2]|0)|0;UH(t[b>>2]|0,203,203,t[v>>2]|0);t[l>>2]=xH(t[b>>2]|0)|0;HH(t[b>>2]|0);if(!(t[l>>2]|0)){b=t[33976]|0;n=t[33980]|0;t[u>>2]=t[c>>2];yAi[b&511](n,124416,u);t[a>>2]=-1;w=t[a>>2]|0;s=f;return w|0}t[k>>2]=YH(t[l>>2]|0)|0;WH(t[k>>2]|0,203,203,t[v>>2]|0);t[h>>2]=XH(t[k>>2]|0,t[(t[o>>2]|0)+4>>2]|0)|0;do if(t[h>>2]|0){n=t[v>>2]|0;b=t[t[o>>2]>>2]|0;if((t[h>>2]|0)>0){t[u>>2]=b;xe(n|0,124472,u|0)|0;break}else{t[u>>2]=b;xe(n|0,124496,u|0)|0;break}}else{n=t[v>>2]|0;t[u>>2]=t[t[o>>2]>>2];xe(n|0,124456,u|0)|0}while(0);GH(t[k>>2]|0);if(t[l>>2]|0)CH(t[l>>2]|0);t[a>>2]=0;w=t[a>>2]|0;s=f;return w|0}function xr(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0;f=s;s=s+32|0;u=f;a=f+20|0;o=f+16|0;c=f+12|0;l=f+8|0;t[o>>2]=e;t[c>>2]=i;t[l>>2]=r;t[f+4>>2]=n;if(!(t[o>>2]|0)){t[a>>2]=0;b=t[a>>2]|0;s=f;return b|0}if(!(t[l>>2]|0)){t[a>>2]=0;b=t[a>>2]|0;s=f;return b|0}if(!(t[c>>2]|0)){t[a>>2]=0;b=t[a>>2]|0;s=f;return b|0}if(((es(t[c>>2]|0,63)|0)==0?(es(t[c>>2]|0,42)|0)==0:0)?(es(t[c>>2]|0,46)|0)==0:0)es(t[c>>2]|0,91)|0;e:while(1){if(!(t[l>>2]|0))break;n=t[l>>2]|0;if((t[(t[l>>2]|0)+4>>2]|0)==8){if(is(t[n+40>>2]|0,t[c>>2]|0)|0){r=t[(t[o>>2]|0)+20>>2]|0;t[u>>2]=$y(t[l>>2]|0)|0;xe(r|0,124408,u|0)|0;vr(t[o>>2]|0,0,t[l>>2]|0,0)|0}}else if((t[n+4>>2]|0)==3?(is(t[(t[l>>2]|0)+40>>2]|0,t[c>>2]|0)|0)!=0:0){n=t[(t[o>>2]|0)+20>>2]|0;t[u>>2]=$y(t[(t[l>>2]|0)+20>>2]|0)|0;xe(n|0,124408,u|0)|0;vr(t[o>>2]|0,0,t[(t[l>>2]|0)+20>>2]|0,0)|0}if((t[(t[l>>2]|0)+4>>2]|0)!=9?(t[(t[l>>2]|0)+4>>2]|0)!=13:0){if((t[(t[l>>2]|0)+12>>2]|0)!=0?(t[(t[l>>2]|0)+4>>2]|0)!=5:0){t[l>>2]=t[(t[l>>2]|0)+12>>2];continue}if(t[(t[l>>2]|0)+24>>2]|0){t[l>>2]=t[(t[l>>2]|0)+24>>2];continue}while(1){if(!(t[l>>2]|0))continue e;if(t[(t[l>>2]|0)+20>>2]|0)t[l>>2]=t[(t[l>>2]|0)+20>>2];k=t[l>>2]|0;if(t[(t[l>>2]|0)+24>>2]|0){h=30;break}if(!(t[k+20>>2]|0)){h=32;break}}if((h|0)==30){h=0;t[l>>2]=t[k+24>>2];continue}else if((h|0)==32){h=0;t[l>>2]=0;continue}}t[l>>2]=t[(t[l>>2]|0)+12>>2]}t[a>>2]=0;b=t[a>>2]|0;s=f;return b|0}function Ur(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0;f=s;s=s+32|0;u=f;a=f+28|0;o=f+24|0;c=f+20|0;l=f+16|0;b=f+8|0;k=f+4|0;t[o>>2]=e;t[c>>2]=i;t[l>>2]=r;t[f+12>>2]=n;if(!(t[o>>2]|0)){t[a>>2]=0;h=t[a>>2]|0;s=f;return h|0}if(!(t[l>>2]|0)){xe(t[(t[o>>2]|0)+20>>2]|0,121712,u|0)|0;
	t[a>>2]=0;h=t[a>>2]|0;s=f;return h|0}if(!(t[c>>2]|0)){xe(t[(t[o>>2]|0)+20>>2]|0,121712,u|0)|0;t[a>>2]=0;h=t[a>>2]|0;s=f;return h|0}n=t[l>>2]|0;r=t[c>>2]|0;t[k>>2]=cS(n,r,HY(t[c>>2]|0)|0,0,b)|0;if(!(t[k>>2]|0)){if(t[(t[l>>2]|0)+12>>2]|0){ty(t[(t[l>>2]|0)+12>>2]|0);t[(t[l>>2]|0)+12>>2]=0;t[(t[l>>2]|0)+16>>2]=0}Iy(t[l>>2]|0,t[b>>2]|0)|0}else xe(t[(t[o>>2]|0)+20>>2]|0,124376,u|0)|0;t[a>>2]=0;h=t[a>>2]|0;s=f;return h|0}function zr(e,i,r,f){e=e|0;i=i|0;r=r|0;f=f|0;var a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0;a=s;s=s+48|0;o=a;c=a+40|0;l=a+36|0;b=a+32|0;k=a+20|0;h=a+16|0;w=a+12|0;d=a+8|0;t[l>>2]=e;t[b>>2]=i;t[a+28>>2]=r;t[a+24>>2]=f;t[k>>2]=Yl(t[b>>2]|0)|0;t[d>>2]=t[k>>2];while(1){if(!(t[d>>2]|0)){v=10;break}if(!(u[t[d>>2]>>0]|0)){v=10;break}t[h>>2]=t[d>>2];t[d>>2]=es(t[d>>2]|0,61)|0;if(!(t[d>>2]|0)){v=5;break}b=t[d>>2]|0;t[d>>2]=b+1;n[b>>0]=0;t[w>>2]=t[d>>2];t[d>>2]=es(t[d>>2]|0,32)|0;if(t[d>>2]|0){b=t[d>>2]|0;t[d>>2]=b+1;n[b>>0]=0}if(Kn(t[(t[l>>2]|0)+12>>2]|0,t[h>>2]|0,t[w>>2]|0)|0){v=9;break}}if((v|0)==5){xe(t[(t[l>>2]|0)+20>>2]|0,124040,o|0)|0;pAi[t[135736>>2]&511](t[k>>2]|0);t[c>>2]=-1;m=t[c>>2]|0;s=a;return m|0}else if((v|0)==9){d=t[(t[l>>2]|0)+20>>2]|0;l=t[w>>2]|0;t[o>>2]=t[h>>2];t[o+4>>2]=l;xe(d|0,124312,o|0)|0;pAi[t[135736>>2]&511](t[k>>2]|0);t[c>>2]=-1;m=t[c>>2]|0;s=a;return m|0}else if((v|0)==10){pAi[t[135736>>2]&511](t[k>>2]|0);t[c>>2]=0;m=t[c>>2]|0;s=a;return m|0}return 0}function jr(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,u=0,a=0,o=0,c=0,l=0;f=s;s=s+32|0;u=f+20|0;a=f+16|0;o=f+8|0;c=f;t[a>>2]=e;t[f+12>>2]=i;t[o>>2]=r;t[f+4>>2]=n;if((((t[o>>2]|0)!=0?(t[(t[o>>2]|0)+4>>2]|0)==1:0)?!((t[a>>2]|0)==0?1:(t[(t[o>>2]|0)+48>>2]|0)==0):0)?(t[(t[a>>2]|0)+12>>2]|0)!=0:0){t[c>>2]=t[(t[o>>2]|0)+48>>2];while(1){if(!(t[c>>2]|0))break;o=t[(t[a>>2]|0)+12>>2]|0;n=t[c>>2]|0;if(!(t[(t[c>>2]|0)+12>>2]|0))Kn(o,124296,t[n+8>>2]|0)|0;else Kn(o,t[n+12>>2]|0,t[(t[c>>2]|0)+8>>2]|0)|0;t[c>>2]=t[t[c>>2]>>2]}t[u>>2]=0;l=t[u>>2]|0;s=f;return l|0}t[u>>2]=-1;l=t[u>>2]|0;s=f;return l|0}function Vr(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,u=0,a=0;f=s;s=s+16|0;u=f+8|0;a=f+4|0;t[f+12>>2]=e;t[u>>2]=i;t[a>>2]=r;t[f>>2]=n;aF(t[a>>2]|0,t[u>>2]|0);s=f;return 0}function qr(e){e=e|0;var i=0,r=0,n=0,f=0;i=s;s=s+16|0;r=i;n=i+4|0;t[n>>2]=e;if(t[(t[n>>2]|0)+124>>2]|0){s=i;return}if(!(t[t[n>>2]>>2]|0)){s=i;return}if((t[(t[n>>2]|0)+108>>2]|0)<=0){s=i;return}e=t[t[n>>2]>>2]|0;f=t[n>>2]|0;if((t[(t[n>>2]|0)+108>>2]|0)<50){t[r>>2]=(t[n>>2]|0)+4+(100-(t[f+108>>2]<<1));xe(e|0,121856,r|0)|0;s=i;return}else{t[r>>2]=f+4;xe(e|0,121856,r|0)|0;s=i;return}}function Yr(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,a=0,o=0,c=0;r=s;s=s+16|0;n=r;f=r+12|0;a=r+8|0;o=r+4|0;t[f>>2]=e;t[a>>2]=i;if(t[(t[f>>2]|0)+124>>2]|0){s=r;return}if(!(t[a>>2]|0)){xe(t[t[f>>2]>>2]|0,121688,n|0)|0;s=r;return}t[o>>2]=0;while(1){if((t[o>>2]|0)>=40)break;if(!(u[(t[a>>2]|0)+(t[o>>2]|0)>>0]|0)){c=17;break}do if((u[(t[a>>2]|0)+(t[o>>2]|0)>>0]|0|0)!=32){if(9<=(u[(t[a>>2]|0)+(t[o>>2]|0)>>0]|0|0)?(u[(t[a>>2]|0)+(t[o>>2]|0)>>0]|0|0)<=10:0){c=11;break}if((u[(t[a>>2]|0)+(t[o>>2]|0)>>0]|0|0)!=13)if((u[(t[a>>2]|0)+(t[o>>2]|0)>>0]|0|0)>=128){i=t[t[f>>2]>>2]|0;t[n>>2]=u[(t[a>>2]|0)+(t[o>>2]|0)>>0];xe(i|0,121696,n|0)|0;break}else{oi(u[(t[a>>2]|0)+(t[o>>2]|0)>>0]|0|0,t[t[f>>2]>>2]|0)|0;break}else c=11}else c=11;while(0);if((c|0)==11){c=0;oi(32,t[t[f>>2]>>2]|0)|0}t[o>>2]=(t[o>>2]|0)+1}if((c|0)==17){s=r;return}xe(t[t[f>>2]>>2]|0,121704,n|0)|0;s=r;return}function Gr(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0;n=s;s=s+16|0;f=n;u=n+12|0;a=n+8|0;o=n+4|0;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;r=(t[u>>2]|0)+128|0;t[r>>2]=(t[r>>2]|0)+1;r=t[(t[u>>2]|0)+116>>2]|0;u=t[a>>2]|0;t[f>>2]=t[o>>2];cp(0,0,0,0,r,24,u,2,0,0,0,0,0,0,0,121856,f);s=n;return}function Wr(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0;r=s;s=s+32|0;n=r+16|0;f=r+12|0;u=r+8|0;a=r+4|0;o=r;t[n>>2]=e;t[f>>2]=i;t[u>>2]=t[(t[f>>2]|0)+32>>2];if(!(t[(t[f>>2]|0)+20>>2]|0))Gr(t[n>>2]|0,5013,124640);if(t[(t[f>>2]|0)+32>>2]|0){t[a>>2]=t[(t[u>>2]|0)+80>>2];if((t[a>>2]|0)==0?(t[(t[n>>2]|0)+132>>2]|0)==0:0)t[(t[n>>2]|0)+132>>2]=1;if(!(t[(t[n>>2]|0)+112>>2]|0))t[(t[n>>2]|0)+112>>2]=t[u>>2];if(!(t[(t[n>>2]|0)+120>>2]|0))t[(t[n>>2]|0)+120>>2]=t[a>>2]}else{Gr(t[n>>2]|0,5014,124664);t[a>>2]=0}if(((t[(t[f>>2]|0)+20>>2]|0)!=0?(t[(t[f>>2]|0)+32>>2]|0)!=(t[(t[(t[f>>2]|0)+20>>2]|0)+32>>2]|0):0)?(Xl(t[(t[f>>2]|0)+8>>2]|0,124688)|0)==0:0)Gr(t[n>>2]|0,5017,124704);a=t[f>>2]|0;do if(!(t[(t[f>>2]|0)+28>>2]|0)){u=(t[(t[f>>2]|0)+20>>2]|0)!=0;if((t[a+4>>2]|0)==2){if(!u)break;if((t[f>>2]|0)==(t[(t[(t[f>>2]|0)+20>>2]|0)+44>>2]|0))break;Gr(t[n>>2]|0,5018,124744);break}else{if(!u)break;if((t[(t[(t[f>>2]|0)+20>>2]|0)+12>>2]|0)==(t[f>>2]|0))break;Gr(t[n>>2]|0,5018,124792);break}}else if((t[(t[a+28>>2]|0)+24>>2]|0)!=(t[f>>2]|0))Gr(t[n>>2]|0,5019,124840);while(0);a=t[f>>2]|0;if(!(t[(t[f>>2]|0)+24>>2]|0)){if((((t[a+20>>2]|0)!=0?(t[(t[f>>2]|0)+4>>2]|0)!=2:0)?(t[(t[(t[f>>2]|0)+20>>2]|0)+16>>2]|0)!=(t[f>>2]|0):0)?(t[(t[(t[f>>2]|0)+20>>2]|0)+4>>2]|0)==1:0)Gr(t[n>>2]|0,5020,124880)}else{if((t[(t[a+24>>2]|0)+28>>2]|0)!=(t[f>>2]|0))Gr(t[n>>2]|0,5021,124928);if((t[(t[(t[f>>2]|0)+24>>2]|0)+20>>2]|0)!=(t[(t[f>>2]|0)+20>>2]|0))Gr(t[n>>2]|0,5029,124928)}a=t[f>>2]|0;if((t[(t[f>>2]|0)+4>>2]|0)==1){t[o>>2]=t[a+48>>2];while(1){if(!(t[o>>2]|0))break;tn(t[n>>2]|0,t[f>>2]|0,t[o>>2]|0);t[o>>2]=t[t[o>>2]>>2]}if(t[(t[f>>2]|0)+36>>2]|0)tn(t[n>>2]|0,t[f>>2]|0,t[(t[f>>2]|0)+36>>2]|0)}else if((t[a+4>>2]|0)==2?(t[(t[f>>2]|0)+36>>2]|0)!=0:0)tn(t[n>>2]|0,t[f>>2]|0,t[(t[f>>2]|0)+36>>2]|0);if((((((((t[(t[f>>2]|0)+4>>2]|0)!=1?(t[(t[f>>2]|0)+4>>2]|0)!=2:0)?(t[(t[f>>2]|0)+4>>2]|0)!=15:0)?(t[(t[f>>2]|0)+4>>2]|0)!=16:0)?(t[(t[f>>2]|0)+4>>2]|0)!=14:0)?(t[(t[f>>2]|0)+4>>2]|0)!=13:0)?(t[(t[f>>2]|0)+4>>2]|0)!=9:0)?(t[(t[f>>2]|0)+40>>2]|0)!=0:0)un(t[n>>2]|0,t[(t[f>>2]|0)+40>>2]|0);switch(t[(t[f>>2]|0)+4>>2]|0){case 2:case 1:{an(t[n>>2]|0,t[(t[f>>2]|0)+8>>2]|0);s=r;return}case 4:{if(!(t[(t[f>>2]|0)+8>>2]|0)){s=r;return}on(t[n>>2]|0,5037,125048,t[(t[f>>2]|0)+8>>2]|0);s=r;return}case 3:{if((t[(t[f>>2]|0)+8>>2]|0)==75104){s=r;return}if((t[(t[f>>2]|0)+8>>2]|0)==75112){s=r;return}if((t[(t[n>>2]|0)+120>>2]|0)!=0?(a=t[(t[f>>2]|0)+8>>2]|0,(a|0)==(kz(t[(t[n>>2]|0)+120>>2]|0,124968,7)|0)):0){s=r;return}on(t[n>>2]|0,5036,124976,t[(t[f>>2]|0)+8>>2]|0);s=r;return}case 7:{an(t[n>>2]|0,t[(t[f>>2]|0)+8>>2]|0);s=r;return}case 8:{if((t[(t[f>>2]|0)+8>>2]|0)==75128){s=r;return}on(t[n>>2]|0,5036,125008,t[(t[f>>2]|0)+8>>2]|0);s=r;return}default:{s=r;return}}}function Kr(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0;r=s;s=s+16|0;n=r;f=r+8|0;u=r+4|0;t[f>>2]=e;t[u>>2]=i;e:do if(!(t[u>>2]|0)){if(!(t[(t[f>>2]|0)+124>>2]|0))xe(t[t[f>>2]>>2]|0,125400,n|0)|0}else{t[(t[f>>2]|0)+116>>2]=t[u>>2];do switch(t[(t[u>>2]|0)+4>>2]|0){case 3:{Gr(t[f>>2]|0,5002,125744);break e;break}case 5:{Gr(t[f>>2]|0,5004,125792);break e;break}case 10:{Gr(t[f>>2]|0,5008,125928);break e;break}case 12:{Gr(t[f>>2]|0,5010,125984);break e;break}case 4:{Gr(t[f>>2]|0,5003,125768);break e;break}case 13:{if(t[(t[f>>2]|0)+124>>2]|0)break e;xe(t[t[f>>2]>>2]|0,125912,n|0)|0;break e;break}case 9:{if(t[(t[f>>2]|0)+124>>2]|0)break e;xe(t[t[f>>2]>>2]|0,125896,n|0)|0;break e;break}case 7:{Gr(t[f>>2]|0,5006,125848);break e;break}case 2:{Gr(t[f>>2]|0,5001,125712);break e;break}case 8:{Gr(t[f>>2]|0,5007,125872);break e;break}case 1:{Gr(t[f>>2]|0,5e3,125688);break e;break}case 11:{Gr(t[f>>2]|0,5009,125952);break e;break}case 6:{Gr(t[f>>2]|0,5005,125824);break e;break}default:{rn(t[f>>2]|0,5011,126016,t[(t[u>>2]|0)+4>>2]|0);break e}}while(0)}while(0);s=r;return}function Xr(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0;r=s;s=s+16|0;n=r;f=r+8|0;u=r+4|0;t[f>>2]=e;t[u>>2]=i;i=(t[(t[u>>2]|0)+124>>2]|0)!=0;if(!(t[f>>2]|0)){if(i){s=r;return}xe(t[t[u>>2]>>2]|0,127600,n|0)|0;s=r;return}if(i){s=r;return}i=t[t[u>>2]>>2]|0;t[n>>2]=t[(t[f>>2]|0)+8>>2];xe(i|0,124408,n|0)|0;switch(t[(t[f>>2]|0)+48>>2]|0){case 2:{xe(t[t[u>>2]>>2]|0,127640,n|0)|0;break}case 5:{xe(t[t[u>>2]>>2]|0,127712,n|0)|0;break}case 1:{xe(t[t[u>>2]>>2]|0,127616,n|0)|0;break}case 3:{xe(t[t[u>>2]>>2]|0,127664,n|0)|0;break}case 4:{xe(t[t[u>>2]>>2]|0,127688,n|0)|0;break}default:rn(t[u>>2]|0,5012,127736,t[(t[f>>2]|0)+48>>2]|0)}if(t[(t[f>>2]|0)+52>>2]|0){i=t[t[u>>2]>>2]|0;t[n>>2]=t[(t[f>>2]|0)+52>>2];xe(i|0,127760,n|0)|0}if(t[(t[f>>2]|0)+56>>2]|0){i=t[t[u>>2]>>2]|0;t[n>>2]=t[(t[f>>2]|0)+56>>2];xe(i|0,127768,n|0)|0}if(t[(t[f>>2]|0)+36>>2]|0){i=t[t[u>>2]>>2]|0;t[n>>2]=t[(t[f>>2]|0)+36>>2];xe(i|0,127784,n|0)|0}if((t[(t[f>>2]|0)+4>>2]|0)!=1?(t[(t[f>>2]|0)+40>>2]|0)!=0:0){i=t[t[u>>2]>>2]|0;t[n>>2]=t[(t[f>>2]|0)+40>>2];xe(i|0,127800,n|0)|0}xe(t[t[u>>2]>>2]|0,121896,n|0)|0;s=r;return}function Zr(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0;r=s;s=s+16|0;n=r;f=r+8|0;u=r+4|0;t[f>>2]=e;t[u>>2]=i;qr(t[f>>2]|0);if(!(t[u>>2]|0)){if(t[(t[f>>2]|0)+124>>2]|0){s=r;return}xe(t[t[f>>2]>>2]|0,124544,n|0)|0;s=r;return}i=t[f>>2]|0;if((t[(t[u>>2]|0)+4>>2]|0)!=14){Gr(i,5022,124568);s=r;return}if(!(t[i+124>>2]|0)){i=t[t[f>>2]>>2]|0;if(t[(t[u>>2]|0)+8>>2]|0){t[n>>2]=t[(t[u>>2]|0)+8>>2];xe(i|0,124592,n|0)|0}else xe(i|0,124600,n|0)|0;if(t[(t[u>>2]|0)+52>>2]|0){i=t[t[f>>2]>>2]|0;t[n>>2]=t[(t[u>>2]|0)+52>>2];xe(i|0,124608,n|0)|0}if(t[(t[u>>2]|0)+56>>2]|0){i=t[t[f>>2]>>2]|0;t[n>>2]=t[(t[u>>2]|0)+56>>2];xe(i|0,124624,n|0)|0}xe(t[t[f>>2]>>2]|0,121896,n|0)|0}Wr(t[f>>2]|0,t[u>>2]|0);s=r;return}function Jr(e,i){e=e|0;i=i|0;var r=0,f=0,u=0,a=0,o=0;r=s;s=s+5024|0;f=r;u=r+8|0;a=r+4|0;o=r+12|0;t[u>>2]=e;t[a>>2]=i;qr(t[u>>2]|0);if(!(t[a>>2]|0)){if(t[(t[u>>2]|0)+124>>2]|0){s=r;return}xe(t[t[u>>2]>>2]|0,127304,f|0)|0;s=r;return}if((t[(t[a>>2]|0)+4>>2]|0)!=15){Gr(t[u>>2]|0,5025,127336);s=r;return}i=t[u>>2]|0;if(t[(t[a>>2]|0)+8>>2]|0){if(!(t[i+124>>2]|0)){xe(t[t[u>>2]>>2]|0,127376,f|0)|0;Yr(t[u>>2]|0,t[(t[a>>2]|0)+8>>2]|0);xe(t[t[u>>2]>>2]|0,126712,f|0)|0}}else Gr(i,5015,127392);if(!(t[(t[u>>2]|0)+124>>2]|0)){switch(t[(t[a>>2]|0)+36>>2]|0){case 0:{xe(t[t[u>>2]>>2]|0,127424,f|0)|0;break}case 2:{xe(t[t[u>>2]>>2]|0,127448,f|0)|0;break}case 4:{xe(t[t[u>>2]>>2]|0,127456,f|0)|0;break}case 1:{xe(t[t[u>>2]>>2]|0,127440,f|0)|0;break}case 3:{xe(t[t[u>>2]>>2]|0,127456,f|0)|0;break}default:{}}if((t[(t[a>>2]|0)+4>>2]|0)!=1?(t[(t[a>>2]|0)+40>>2]|0)!=0:0){n[o>>0]=0;mM(o,5e3,t[(t[a>>2]|0)+40>>2]|0,1);n[o+5e3>>0]=0;i=t[t[u>>2]>>2]|0;t[f>>2]=o;xe(i|0,121856,f|0)|0}xe(t[t[u>>2]>>2]|0,121896,f|0)|0}Wr(t[u>>2]|0,t[a>>2]|0);s=r;return}function Qr(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0;r=s;s=s+32|0;n=r;f=r+16|0;u=r+12|0;a=r+8|0;o=r+4|0;t[f>>2]=e;t[u>>2]=i;qr(t[f>>2]|0);if(!(t[u>>2]|0)){if(t[(t[f>>2]|0)+124>>2]|0){s=r;return}xe(t[t[f>>2]>>2]|0,126928,n|0)|0;s=r;return}if((t[(t[u>>2]|0)+4>>2]|0)!=16){Gr(t[f>>2]|0,5024,126960);s=r;return}i=t[f>>2]|0;if(t[(t[u>>2]|0)+8>>2]|0){if(!(t[i+124>>2]|0)){e=t[t[f>>2]>>2]|0;t[n>>2]=t[(t[u>>2]|0)+8>>2];xe(e|0,127e3,n|0)|0}}else Gr(i,5015,127016);i=t[f>>2]|0;if(t[(t[u>>2]|0)+60>>2]|0){if(!(t[i+124>>2]|0)){e=t[t[f>>2]>>2]|0;t[n>>2]=t[(t[u>>2]|0)+60>>2];xe(e|0,127056,n|0)|0}}else Gr(i,5016,127064);if(!(t[(t[f>>2]|0)+124>>2]|0)){do switch(t[(t[u>>2]|0)+40>>2]|0){case 3:{xe(t[t[f>>2]>>2]|0,127128,n|0)|0;break}case 8:{xe(t[t[f>>2]>>2]|0,127184,n|0)|0;break}case 1:{xe(t[t[f>>2]>>2]|0,127112,n|0)|0;break}case 9:{xe(t[t[f>>2]>>2]|0,127200,n|0)|0;break}case 2:{xe(t[t[f>>2]>>2]|0,127120,n|0)|0;break}case 6:{xe(t[t[f>>2]>>2]|0,127152,n|0)|0;break}case 5:{xe(t[t[f>>2]>>2]|0,127144,n|0)|0;break}case 10:{xe(t[t[f>>2]>>2]|0,127216,n|0)|0;break}case 4:{xe(t[t[f>>2]>>2]|0,127136,n|0)|0;break}case 7:{xe(t[t[f>>2]>>2]|0,127168,n|0)|0;break}default:{}}while(0);do if(t[(t[u>>2]|0)+52>>2]|0){t[o>>2]=t[(t[u>>2]|0)+52>>2];t[a>>2]=0;while(1){if((t[a>>2]|0)>=5)break;i=t[t[f>>2]>>2]|0;e=t[(t[o>>2]|0)+4>>2]|0;if(t[a>>2]|0){t[n>>2]=e;xe(i|0,127232,n|0)|0}else{t[n>>2]=e;xe(i|0,127240,n|0)|0}t[o>>2]=t[t[o>>2]>>2];if(!(t[o>>2]|0))break;t[a>>2]=(t[a>>2]|0)+1}i=t[t[f>>2]>>2]|0;if(!(t[o>>2]|0)){xe(i|0,126712,n|0)|0;break}else{xe(i|0,127248,n|0)|0;break}}while(0);o=t[(t[u>>2]|0)+44>>2]|0;if((o|0)==4)xe(t[t[f>>2]>>2]|0,127288,n|0)|0;else if((o|0)==2)xe(t[t[f>>2]>>2]|0,127256,n|0)|0;else if((o|0)==3)xe(t[t[f>>2]>>2]|0,127272,n|0)|0;if(t[(t[u>>2]|0)+48>>2]|0){xe(t[t[f>>2]>>2]|0,127296,n|0)|0;Yr(t[f>>2]|0,t[(t[u>>2]|0)+48>>2]|0);xe(t[t[f>>2]>>2]|0,127296,n|0)|0}xe(t[t[f>>2]>>2]|0,121896,n|0)|0}Wr(t[f>>2]|0,t[u>>2]|0);s=r;return}function $r(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0;r=s;s=s+16|0;n=r;f=r+8|0;u=r+4|0;t[f>>2]=e;t[u>>2]=i;qr(t[f>>2]|0);if(!(t[u>>2]|0)){if(t[(t[f>>2]|0)+124>>2]|0){s=r;return}xe(t[t[f>>2]>>2]|0,126624,n|0)|0;s=r;return}if((t[(t[u>>2]|0)+4>>2]|0)!=17){Gr(t[f>>2]|0,5026,126656);s=r;return}i=t[f>>2]|0;if(t[(t[u>>2]|0)+8>>2]|0){if(!(t[i+124>>2]|0)){xe(t[t[f>>2]>>2]|0,126696,n|0)|0;Yr(t[f>>2]|0,t[(t[u>>2]|0)+8>>2]|0);xe(t[t[f>>2]>>2]|0,126712,n|0)|0}}else Gr(i,5015,126720);if(!(t[(t[f>>2]|0)+124>>2]|0)){switch(t[(t[u>>2]|0)+48>>2]|0){case 5:{xe(t[t[f>>2]>>2]|0,126824,n|0)|0;break}case 2:{xe(t[t[f>>2]>>2]|0,126768,n|0)|0;break}case 4:{xe(t[t[f>>2]>>2]|0,126808,n|0)|0;break}case 6:{xe(t[t[f>>2]>>2]|0,126848,n|0)|0;break}case 1:{xe(t[t[f>>2]>>2]|0,126752,n|0)|0;break}case 3:{xe(t[t[f>>2]>>2]|0,126792,n|0)|0;break}default:{}}if(t[(t[u>>2]|0)+52>>2]|0){qr(t[f>>2]|0);i=t[t[f>>2]>>2]|0;t[n>>2]=t[(t[u>>2]|0)+52>>2];xe(i|0,126864,n|0)|0}if(t[(t[u>>2]|0)+56>>2]|0){qr(t[f>>2]|0);i=t[t[f>>2]>>2]|0;t[n>>2]=t[(t[u>>2]|0)+56>>2];xe(i|0,126880,n|0)|0}if(t[(t[u>>2]|0)+64>>2]|0){qr(t[f>>2]|0);i=t[t[f>>2]>>2]|0;t[n>>2]=t[(t[u>>2]|0)+64>>2];xe(i|0,126896,n|0)|0}if(t[(t[u>>2]|0)+40>>2]|0){qr(t[f>>2]|0);xe(t[t[f>>2]>>2]|0,126912,n|0)|0;Yr(t[f>>2]|0,t[(t[u>>2]|0)+40>>2]|0);xe(t[t[f>>2]>>2]|0,121896,n|0)|0}}Wr(t[f>>2]|0,t[u>>2]|0);s=r;return}function en(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0;r=s;s=s+16|0;n=r;f=r+8|0;u=r+4|0;t[f>>2]=e;t[u>>2]=i;qr(t[f>>2]|0);if(!(t[u>>2]|0)){if(t[(t[f>>2]|0)+124>>2]|0){s=r;return}xe(t[t[f>>2]>>2]|0,125496,n|0)|0;s=r;return}if((t[(t[u>>2]|0)+4>>2]|0)!=18){Gr(t[f>>2]|0,5027,125520);s=r;return}if(!(t[(t[u>>2]|0)+8>>2]|0)){i=t[f>>2]|0;if(t[(t[u>>2]|0)+12>>2]|0){on(i,5028,125560,t[(t[u>>2]|0)+12>>2]|0);s=r;return}else{Gr(i,5028,125600);s=r;return}}if(t[(t[f>>2]|0)+124>>2]|0){s=r;return}i=t[t[f>>2]>>2]|0;if(t[(t[u>>2]|0)+12>>2]|0){t[n>>2]=t[(t[u>>2]|0)+12>>2];xe(i|0,125640,n|0)|0}else xe(i|0,125664,n|0)|0;Yr(t[f>>2]|0,t[(t[u>>2]|0)+8>>2]|0);xe(t[t[f>>2]>>2]|0,121896,n|0)|0;s=r;return}function rn(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,u=0,a=0,o=0,c=0,l=0;f=s;s=s+32|0;u=f;a=f+16|0;o=f+12|0;c=f+8|0;l=f+4|0;t[a>>2]=e;t[o>>2]=i;t[c>>2]=r;t[l>>2]=n;n=(t[a>>2]|0)+128|0;t[n>>2]=(t[n>>2]|0)+1;n=t[(t[a>>2]|0)+116>>2]|0;a=t[o>>2]|0;o=t[c>>2]|0;t[u>>2]=t[l>>2];cp(0,0,0,0,n,24,a,2,0,0,0,0,0,0,0,o,u);s=f;return}function nn(e,i){e=e|0;i=i|0;var r=0,n=0,f=0;r=s;s=s+16|0;n=r+4|0;f=r;t[n>>2]=e;t[f>>2]=i;while(1){if(!(t[f>>2]|0))break;en(t[n>>2]|0,t[f>>2]|0);t[f>>2]=t[t[f>>2]>>2]}s=r;return}function fn(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0;r=s;s=s+16|0;n=r;f=r+8|0;u=r+4|0;t[f>>2]=e;t[u>>2]=i;qr(t[f>>2]|0);i=(t[(t[f>>2]|0)+124>>2]|0)!=0;if(!(t[u>>2]|0)){if(i){s=r;return}xe(t[t[f>>2]>>2]|0,126384,n|0)|0;s=r;return}if(i){s=r;return}switch(t[(t[u>>2]|0)+48>>2]|0){case 5:{xe(t[t[f>>2]>>2]|0,126536,n|0)|0;break}case 2:{xe(t[t[f>>2]>>2]|0,126432,n|0)|0;break}case 3:{xe(t[t[f>>2]>>2]|0,126464,n|0)|0;break}case 4:{xe(t[t[f>>2]>>2]|0,126504,n|0)|0;break}case 1:{xe(t[t[f>>2]>>2]|0,126400,n|0)|0;break}default:{i=t[t[f>>2]>>2]|0;t[n>>2]=t[(t[u>>2]|0)+48>>2];xe(i|0,126568,n|0)|0}}i=t[t[f>>2]>>2]|0;t[n>>2]=t[(t[u>>2]|0)+8>>2];xe(i|0,122096,n|0)|0;if(t[(t[u>>2]|0)+52>>2]|0){qr(t[f>>2]|0);i=t[t[f>>2]>>2]|0;t[n>>2]=t[(t[u>>2]|0)+52>>2];xe(i|0,126584,n|0)|0}if(t[(t[u>>2]|0)+56>>2]|0){qr(t[f>>2]|0);i=t[t[f>>2]>>2]|0;t[n>>2]=t[(t[u>>2]|0)+56>>2];xe(i|0,126600,n|0)|0}if(t[(t[u>>2]|0)+64>>2]|0){qr(t[f>>2]|0);i=t[t[f>>2]>>2]|0;t[n>>2]=t[(t[u>>2]|0)+64>>2];xe(i|0,126616,n|0)|0}if(!(t[(t[u>>2]|0)+40>>2]|0)){s=r;return}qr(t[f>>2]|0);xe(t[t[f>>2]>>2]|0,126368,n|0)|0;Yr(t[f>>2]|0,t[(t[u>>2]|0)+40>>2]|0);xe(t[t[f>>2]>>2]|0,121896,n|0)|0;s=r;return}function tn(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0;n=s;s=s+16|0;f=n+12|0;u=n+8|0;a=n+4|0;o=n;t[f>>2]=e;t[u>>2]=i;t[a>>2]=r;t[o>>2]=cn(t[u>>2]|0,t[a>>2]|0)|0;do if((t[o>>2]|0)==-2){u=t[f>>2]|0;if(!(t[(t[a>>2]|0)+12>>2]|0)){Gr(u,5030,125208);break}else{on(u,5030,125256,t[(t[a>>2]|0)+12>>2]|0);break}}while(0);if((t[o>>2]|0)!=-3){s=n;return}o=t[f>>2]|0;if(!(t[(t[a>>2]|0)+12>>2]|0)){Gr(o,5031,125304);s=n;return}else{on(o,5031,125352,t[(t[a>>2]|0)+12>>2]|0);s=n;return}}function un(e,i){e=e|0;i=i|0;var r=0,n=0,f=0;r=s;s=s+16|0;n=r+4|0;f=r;t[n>>2]=e;t[f>>2]=i;if(!(t[f>>2]|0)){s=r;return}if(!(t[(t[n>>2]|0)+124>>2]|0)){s=r;return}if(ls(t[f>>2]|0)|0){s=r;return}on(t[n>>2]|0,5032,125184,t[f>>2]|0);s=r;return}function an(e,i){e=e|0;i=i|0;var r=0,n=0,f=0;r=s;s=s+16|0;n=r+4|0;f=r;t[n>>2]=e;t[f>>2]=i;if(!(t[(t[n>>2]|0)+124>>2]|0)){s=r;return}if(!(t[f>>2]|0)){Gr(t[n>>2]|0,5015,125088);s=r;return}if(Yg(t[f>>2]|0,0)|0)on(t[n>>2]|0,5034,125104,t[f>>2]|0);if(!(t[(t[n>>2]|0)+120>>2]|0)){s=r;return}if(wz(t[(t[n>>2]|0)+120>>2]|0,t[f>>2]|0)|0){s=r;return}if((t[(t[n>>2]|0)+112>>2]|0)!=0?(t[(t[(t[n>>2]|0)+112>>2]|0)+88>>2]&4608|0)!=0:0){s=r;return}on(t[n>>2]|0,5035,125136,t[f>>2]|0);s=r;return}function on(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,u=0,a=0,o=0,c=0,l=0;f=s;s=s+32|0;u=f;a=f+16|0;o=f+12|0;c=f+8|0;l=f+4|0;t[a>>2]=e;t[o>>2]=i;t[c>>2]=r;t[l>>2]=n;n=(t[a>>2]|0)+128|0;t[n>>2]=(t[n>>2]|0)+1;n=t[(t[a>>2]|0)+116>>2]|0;a=t[o>>2]|0;o=t[c>>2]|0;t[u>>2]=t[l>>2];cp(0,0,0,0,n,24,a,2,0,0,0,0,0,0,0,o,u);s=f;return}function cn(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0;r=s;s=s+32|0;n=r+16|0;f=r+12|0;u=r+8|0;a=r+4|0;o=r;t[f>>2]=e;t[u>>2]=i;if((t[f>>2]|0)==0|(t[u>>2]|0)==0){t[n>>2]=-1;c=t[n>>2]|0;s=r;return c|0}if((((((t[(t[f>>2]|0)+4>>2]|0)!=1?(t[(t[f>>2]|0)+4>>2]|0)!=2:0)?(t[(t[f>>2]|0)+4>>2]|0)!=9:0)?(t[(t[f>>2]|0)+4>>2]|0)!=3:0)?(t[(t[f>>2]|0)+4>>2]|0)!=13:0)?(t[(t[f>>2]|0)+4>>2]|0)!=19:0){t[n>>2]=-2;c=t[n>>2]|0;s=r;return c|0}e:while(1){if(t[f>>2]|0)if(((t[(t[f>>2]|0)+4>>2]|0)!=1?(t[(t[f>>2]|0)+4>>2]|0)!=2:0)?(t[(t[f>>2]|0)+4>>2]|0)!=3:0)l=(t[(t[f>>2]|0)+4>>2]|0)==19;else l=1;else l=0;b=t[f>>2]|0;if(!l){k=26;break}if(!((t[b+4>>2]|0)!=1?(t[(t[f>>2]|0)+4>>2]|0)!=19:0))k=18;i:do if((k|0)==18){k=0;t[a>>2]=t[(t[f>>2]|0)+48>>2];while(1){if(!(t[a>>2]|0))break i;if((t[a>>2]|0)==(t[u>>2]|0)){k=21;break e}if(Xl(t[(t[a>>2]|0)+12>>2]|0,t[(t[u>>2]|0)+12>>2]|0)|0){k=23;break e}t[a>>2]=t[t[a>>2]>>2]}}while(0);t[f>>2]=t[(t[f>>2]|0)+20>>2]}if((k|0)==21){t[n>>2]=1;c=t[n>>2]|0;s=r;return c|0}else if((k|0)==23){t[n>>2]=-2;c=t[n>>2]|0;s=r;return c|0}else if((k|0)==26){do if(b){if((t[(t[f>>2]|0)+4>>2]|0)!=9?(t[(t[f>>2]|0)+4>>2]|0)!=13:0)break;t[o>>2]=t[(t[f>>2]|0)+52>>2];if((t[o>>2]|0)==(t[u>>2]|0)){t[n>>2]=1;c=t[n>>2]|0;s=r;return c|0}}while(0);t[n>>2]=-3;c=t[n>>2]|0;s=r;return c|0}return 0}function ln(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0;r=s;s=s+32|0;n=r+28|0;f=r+8|0;u=r+24|0;a=r+20|0;o=r+16|0;c=r;l=f;t[l>>2]=e;t[l+4>>2]=i;i=f;l=Be(t[i>>2]|0,t[i+4>>2]|0,0)|0;t[u>>2]=64-l;t[a>>2]=((t[u>>2]|0)>6?t[u>>2]|0:6)-6;u=f;l=qY(t[u>>2]|0,t[u+4>>2]|0,t[a>>2]|0)|0;t[o>>2]=l;l=UY(1,0,t[a>>2]|0)|0;a=BY(l|0,P|0,1,0)|0;l=c;t[l>>2]=a;t[l+4>>2]=P;l=c;c=f;f=t[o>>2]|0;if((t[l>>2]&t[c>>2]|0)!=0?1:(t[l+4>>2]&t[c+4>>2]|0)!=0){t[n>>2]=f+1;b=t[n>>2]|0;s=r;return b|0}else{t[n>>2]=f;b=t[n>>2]|0;s=r;return b|0}return 0}function sn(e,i){e=e|0;i=i|0;var r=0,n=0,f=0;r=s;s=s+16|0;n=r+4|0;f=r;t[n>>2]=e;t[f>>2]=i;St(t[n>>2]|0,1,t[f>>2]|0);s=r;return}function bn(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0;r=s;s=s+2112|0;n=r+2096|0;f=r+2092|0;u=r+2088|0;a=r+2076|0;o=r+24|0;c=r+2072|0;l=r+16|0;b=r+8|0;k=r;t[n>>2]=e;t[f>>2]=i;t[c>>2]=0;i=k;t[i>>2]=0;t[i+4>>2]=0;if((t[f>>2]|0)>>>0<64){sn(t[n>>2]|0,t[f>>2]|0);s=r;return}t[u>>2]=ln(t[f>>2]|0,0)|0;t[a>>2]=r+2080;t[t[a>>2]>>2]=0;t[(t[a>>2]|0)+4>>2]=0;i=k;e=gt(t[n>>2]|0,t[i>>2]|0,t[i+4>>2]|0,t[f>>2]|0)|0;i=l;t[i>>2]=e;t[i+4>>2]=P;i=t[u>>2]|0;e=b;t[e>>2]=i;t[e+4>>2]=((i|0)<0)<<31>>31;i=b;e=t[i+4>>2]|0;h=t[u>>2]|0;w=((h|0)<0)<<31>>31;if((e|0)<(w|0)|((e|0)==(w|0)?(t[i>>2]|0)>>>0<h>>>0:0)){h=t[u>>2]|0;i=b;t[i>>2]=h;t[i+4>>2]=((h|0)<0)<<31>>31}h=b;i=t[h>>2]|0;w=t[h+4>>2]|0;h=k;e=BY(t[f>>2]|0,0,t[h>>2]|0,t[h+4>>2]|0)|0;h=P;if((w|0)>(h|0)|(w|0)==(h|0)&i>>>0>e>>>0){e=k;i=BY(t[f>>2]|0,0,t[e>>2]|0,t[e+4>>2]|0)|0;e=b;t[e>>2]=i;t[e+4>>2]=P}e=b;i=t[e+4>>2]|0;h=l;w=t[h+4>>2]|0;if((i|0)>(w|0)|((i|0)==(w|0)?(t[e>>2]|0)>>>0>(t[h>>2]|0)>>>0:0)){St((t[n>>2]|0)+(t[k>>2]<<2)|0,t[l>>2]|0,t[b>>2]|0);h=b;e=t[h+4>>2]|0;w=l;t[w>>2]=t[h>>2];t[w+4>>2]=e}e=k;w=t[e+4>>2]|0;h=o+(t[c>>2]<<4)|0;t[h>>2]=t[e>>2];t[h+4>>2]=w;w=l;h=t[w+4>>2]|0;e=o+(t[c>>2]<<4)+8|0;t[e>>2]=t[w>>2];t[e+4>>2]=h;t[c>>2]=(t[c>>2]|0)+1;h=l;e=k;w=jY(t[e>>2]|0,t[e+4>>2]|0,t[h>>2]|0,t[h+4>>2]|0)|0;h=k;t[h>>2]=w;t[h+4>>2]=P;h=k;if((t[h+4>>2]|0)==0?(t[h>>2]|0)==(t[f>>2]|0):0){while(1){if((t[c>>2]|0)<=1)break;yt(t[n>>2]|0,o,t[c>>2]|0,t[a>>2]|0);h=o+((t[c>>2]|0)-1<<4)+8|0;w=o+((t[c>>2]|0)-2<<4)+8|0;e=w;i=jY(t[e>>2]|0,t[e+4>>2]|0,t[h>>2]|0,t[h+4>>2]|0)|0;h=w;t[h>>2]=i;t[h+4>>2]=P;t[c>>2]=(t[c>>2]|0)+-1}if(!(t[(t[a>>2]|0)+4>>2]|0)){s=r;return}Zq(t[(t[a>>2]|0)+4>>2]|0);t[(t[a>>2]|0)+4>>2]=0;s=r;return}h=k;i=gt(t[n>>2]|0,t[h>>2]|0,t[h+4>>2]|0,t[f>>2]|0)|0;h=l;t[h>>2]=i;t[h+4>>2]=P;h=t[u>>2]|0;i=b;t[i>>2]=h;t[i+4>>2]=((h|0)<0)<<31>>31;h=b;i=t[h+4>>2]|0;w=t[u>>2]|0;e=((w|0)<0)<<31>>31;if((i|0)<(e|0)|((i|0)==(e|0)?(t[h>>2]|0)>>>0<w>>>0:0)){w=t[u>>2]|0;h=b;t[h>>2]=w;t[h+4>>2]=((w|0)<0)<<31>>31}w=b;h=t[w>>2]|0;e=t[w+4>>2]|0;w=k;i=BY(t[f>>2]|0,0,t[w>>2]|0,t[w+4>>2]|0)|0;w=P;if((e|0)>(w|0)|(e|0)==(w|0)&h>>>0>i>>>0){i=k;h=BY(t[f>>2]|0,0,t[i>>2]|0,t[i+4>>2]|0)|0;i=b;t[i>>2]=h;t[i+4>>2]=P}i=b;h=t[i+4>>2]|0;w=l;e=t[w+4>>2]|0;if((h|0)>(e|0)|((h|0)==(e|0)?(t[i>>2]|0)>>>0>(t[w>>2]|0)>>>0:0)){St((t[n>>2]|0)+(t[k>>2]<<2)|0,t[l>>2]|0,t[b>>2]|0);w=b;i=t[w+4>>2]|0;e=l;t[e>>2]=t[w>>2];t[e+4>>2]=i}i=k;e=t[i+4>>2]|0;w=o+(t[c>>2]<<4)|0;t[w>>2]=t[i>>2];t[w+4>>2]=e;e=l;w=t[e+4>>2]|0;i=o+(t[c>>2]<<4)+8|0;t[i>>2]=t[e>>2];t[i+4>>2]=w;t[c>>2]=(t[c>>2]|0)+1;w=l;i=k;e=jY(t[i>>2]|0,t[i+4>>2]|0,t[w>>2]|0,t[w+4>>2]|0)|0;w=k;t[w>>2]=e;t[w+4>>2]=P;w=k;if((t[w+4>>2]|0)==0?(t[w>>2]|0)==(t[f>>2]|0):0){while(1){if((t[c>>2]|0)<=1)break;yt(t[n>>2]|0,o,t[c>>2]|0,t[a>>2]|0);w=o+((t[c>>2]|0)-1<<4)+8|0;e=o+((t[c>>2]|0)-2<<4)+8|0;i=e;h=jY(t[i>>2]|0,t[i+4>>2]|0,t[w>>2]|0,t[w+4>>2]|0)|0;w=e;t[w>>2]=h;t[w+4>>2]=P;t[c>>2]=(t[c>>2]|0)+-1}if(!(t[(t[a>>2]|0)+4>>2]|0)){s=r;return}Zq(t[(t[a>>2]|0)+4>>2]|0);t[(t[a>>2]|0)+4>>2]=0;s=r;return}w=k;h=gt(t[n>>2]|0,t[w>>2]|0,t[w+4>>2]|0,t[f>>2]|0)|0;w=l;t[w>>2]=h;t[w+4>>2]=P;w=t[u>>2]|0;h=b;t[h>>2]=w;t[h+4>>2]=((w|0)<0)<<31>>31;w=b;h=t[w+4>>2]|0;e=t[u>>2]|0;i=((e|0)<0)<<31>>31;if((h|0)<(i|0)|((h|0)==(i|0)?(t[w>>2]|0)>>>0<e>>>0:0)){e=t[u>>2]|0;w=b;t[w>>2]=e;t[w+4>>2]=((e|0)<0)<<31>>31}e=b;w=t[e>>2]|0;i=t[e+4>>2]|0;e=k;h=BY(t[f>>2]|0,0,t[e>>2]|0,t[e+4>>2]|0)|0;e=P;if((i|0)>(e|0)|(i|0)==(e|0)&w>>>0>h>>>0){h=k;w=BY(t[f>>2]|0,0,t[h>>2]|0,t[h+4>>2]|0)|0;h=b;t[h>>2]=w;t[h+4>>2]=P}h=b;w=t[h+4>>2]|0;e=l;i=t[e+4>>2]|0;if((w|0)>(i|0)|((w|0)==(i|0)?(t[h>>2]|0)>>>0>(t[e>>2]|0)>>>0:0)){St((t[n>>2]|0)+(t[k>>2]<<2)|0,t[l>>2]|0,t[b>>2]|0);e=b;h=t[e+4>>2]|0;i=l;t[i>>2]=t[e>>2];t[i+4>>2]=h}h=k;i=t[h+4>>2]|0;e=o+(t[c>>2]<<4)|0;t[e>>2]=t[h>>2];t[e+4>>2]=i;i=l;e=t[i+4>>2]|0;h=o+(t[c>>2]<<4)+8|0;t[h>>2]=t[i>>2];t[h+4>>2]=e;t[c>>2]=(t[c>>2]|0)+1;e=l;h=k;i=jY(t[h>>2]|0,t[h+4>>2]|0,t[e>>2]|0,t[e+4>>2]|0)|0;e=k;t[e>>2]=i;t[e+4>>2]=P;e=k;if((t[e+4>>2]|0)==0?(t[e>>2]|0)==(t[f>>2]|0):0){while(1){if((t[c>>2]|0)<=1)break;yt(t[n>>2]|0,o,t[c>>2]|0,t[a>>2]|0);e=o+((t[c>>2]|0)-1<<4)+8|0;i=o+((t[c>>2]|0)-2<<4)+8|0;h=i;w=jY(t[h>>2]|0,t[h+4>>2]|0,t[e>>2]|0,t[e+4>>2]|0)|0;e=i;t[e>>2]=w;t[e+4>>2]=P;t[c>>2]=(t[c>>2]|0)+-1}if(!(t[(t[a>>2]|0)+4>>2]|0)){s=r;return}Zq(t[(t[a>>2]|0)+4>>2]|0);t[(t[a>>2]|0)+4>>2]=0;s=r;return}while(1){e=(Ft(o,t[c>>2]|0)|0)!=0;w=t[n>>2]|0;if(!e){t[c>>2]=Ot(w,o,t[c>>2]|0,t[a>>2]|0,t[f>>2]|0)|0;continue}e=k;i=gt(w,t[e>>2]|0,t[e+4>>2]|0,t[f>>2]|0)|0;e=l;t[e>>2]=i;t[e+4>>2]=P;e=t[u>>2]|0;i=b;t[i>>2]=e;t[i+4>>2]=((e|0)<0)<<31>>31;e=b;i=t[e+4>>2]|0;w=t[u>>2]|0;h=((w|0)<0)<<31>>31;if((i|0)<(h|0)|((i|0)==(h|0)?(t[e>>2]|0)>>>0<w>>>0:0)){w=t[u>>2]|0;e=b;t[e>>2]=w;t[e+4>>2]=((w|0)<0)<<31>>31}w=b;e=t[w>>2]|0;h=t[w+4>>2]|0;w=k;i=BY(t[f>>2]|0,0,t[w>>2]|0,t[w+4>>2]|0)|0;w=P;if((h|0)>(w|0)|(h|0)==(w|0)&e>>>0>i>>>0){i=k;e=BY(t[f>>2]|0,0,t[i>>2]|0,t[i+4>>2]|0)|0;i=b;t[i>>2]=e;t[i+4>>2]=P}i=b;e=t[i+4>>2]|0;w=l;h=t[w+4>>2]|0;if((e|0)>(h|0)|((e|0)==(h|0)?(t[i>>2]|0)>>>0>(t[w>>2]|0)>>>0:0)){St((t[n>>2]|0)+(t[k>>2]<<2)|0,t[l>>2]|0,t[b>>2]|0);w=b;i=t[w+4>>2]|0;h=l;t[h>>2]=t[w>>2];t[h+4>>2]=i}i=k;h=t[i+4>>2]|0;w=o+(t[c>>2]<<4)|0;t[w>>2]=t[i>>2];t[w+4>>2]=h;h=l;w=t[h+4>>2]|0;i=o+(t[c>>2]<<4)+8|0;t[i>>2]=t[h>>2];t[i+4>>2]=w;t[c>>2]=(t[c>>2]|0)+1;w=l;i=k;h=jY(t[i>>2]|0,t[i+4>>2]|0,t[w>>2]|0,t[w+4>>2]|0)|0;w=k;t[w>>2]=h;t[w+4>>2]=P;w=k;if((t[w+4>>2]|0)==0?(t[w>>2]|0)==(t[f>>2]|0):0)break}while(1){if((t[c>>2]|0)<=1)break;yt(t[n>>2]|0,o,t[c>>2]|0,t[a>>2]|0);f=o+((t[c>>2]|0)-1<<4)+8|0;k=o+((t[c>>2]|0)-2<<4)+8|0;l=k;b=jY(t[l>>2]|0,t[l+4>>2]|0,t[f>>2]|0,t[f+4>>2]|0)|0;f=k;t[f>>2]=b;t[f+4>>2]=P;t[c>>2]=(t[c>>2]|0)+-1}if(!(t[(t[a>>2]|0)+4>>2]|0)){s=r;return}Zq(t[(t[a>>2]|0)+4>>2]|0);t[(t[a>>2]|0)+4>>2]=0;s=r;return}function kn(){var e=0;e=s;if(t[31974]|0){s=e;return}l[15985]=+At();l[15986]=+Mt();l[15984]=+Rt();l[15988]=+Nt();t[31974]=1;s=e;return}function hn(e){e=+e;var i=0,r=0,n=0;i=s;s=s+16|0;r=i;l[r>>3]=e;n=Tt(+l[r>>3])|0;s=i;return n|0}function wn(e){e=+e;var i=0,r=0,n=0;i=s;s=s+16|0;r=i;l[r>>3]=e;n=Lt(+l[r>>3])|0;s=i;return n|0}function dn(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0;r=s;s=s+16|0;n=r;f=r+8|0;u=r+4|0;t[f>>2]=e;t[u>>2]=i;t[u>>2]=(t[u>>2]|0)<0|(t[u>>2]|0)>25?25:i;i=t[u>>2]|0;if(!(t[f>>2]|0)){t[n>>2]=t[127920+(t[u>>2]<<2)>>2];cp(0,0,0,0,0,12,i+1200-0|0,2,0,0,0,0,0,0,0,127912,n);s=r;return}t[(t[f>>2]|0)+8>>2]=i;if(!(t[(t[f>>2]|0)+12>>2]|0)){i=(t[u>>2]|0)+1200-0|0;e=t[(t[f>>2]|0)+4>>2]|0;a=(t[t[f>>2]>>2]|0)-(t[(t[f>>2]|0)+4>>2]|0)|0;t[n>>2]=t[127920+(t[u>>2]<<2)>>2];cp(0,0,0,0,0,12,i,2,0,0,e,0,0,a,0,127912,n);s=r;return}lp((t[(t[f>>2]|0)+12>>2]|0)+136|0);t[(t[(t[f>>2]|0)+12>>2]|0)+136>>2]=12;t[(t[(t[f>>2]|0)+12>>2]|0)+140>>2]=(t[u>>2]|0)+1200-0;t[(t[(t[f>>2]|0)+12>>2]|0)+148>>2]=2;a=Yl(t[(t[f>>2]|0)+4>>2]|0)|0;t[(t[(t[f>>2]|0)+12>>2]|0)+160>>2]=a;t[(t[(t[f>>2]|0)+12>>2]|0)+172>>2]=(t[t[f>>2]>>2]|0)-(t[(t[f>>2]|0)+4>>2]|0);t[(t[(t[f>>2]|0)+12>>2]|0)+184>>2]=t[(t[(t[f>>2]|0)+12>>2]|0)+188>>2];a=t[(t[f>>2]|0)+12>>2]|0;if(t[(t[(t[f>>2]|0)+12>>2]|0)+132>>2]|0){EAi[t[a+132>>2]&511](t[(t[(t[f>>2]|0)+12>>2]|0)+128>>2]|0,(t[(t[f>>2]|0)+12>>2]|0)+136|0);s=r;return}else{e=t[a+188>>2]|0;a=(t[u>>2]|0)+1200-0|0;i=t[(t[f>>2]|0)+4>>2]|0;o=(t[t[f>>2]>>2]|0)-(t[(t[f>>2]|0)+4>>2]|0)|0;t[n>>2]=t[127920+(t[u>>2]<<2)>>2];cp(0,0,0,0,e,12,a,2,0,0,i,0,0,o,0,127912,n);s=r;return}}function vn(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,u=0,a=0;f=s;s=s+16|0;u=f+12|0;a=f;t[u>>2]=e;t[f+8>>2]=i;t[f+4>>2]=r;t[a>>2]=n;dn(t[u>>2]|0,t[a>>2]|0);s=f;return}function mn(e){e=e|0;var i=0,r=0,n=0,f=0;i=s;s=s+16|0;r=i+8|0;n=i+4|0;f=i;t[r>>2]=e;if(!(t[r>>2]|0)){s=i;return}e=(t[(t[r>>2]|0)+20>>2]|0)==0;t[f>>2]=0;e:do if(e)while(1){if((t[f>>2]|0)>=(t[t[r>>2]>>2]|0))break e;t[n>>2]=(t[(t[r>>2]|0)+8>>2]|0)+((t[f>>2]|0)*40|0);do if(t[(t[n>>2]|0)+24>>2]|0)if((t[t[n>>2]>>2]|0)==12){_n(t[(t[n>>2]|0)+24>>2]|0);break}else{pAi[t[135736>>2]&511](t[(t[n>>2]|0)+24>>2]|0);break}while(0);if(t[(t[n>>2]|0)+28>>2]|0)pAi[t[135736>>2]&511](t[(t[n>>2]|0)+28>>2]|0);t[f>>2]=(t[f>>2]|0)+1}else{while(1){if((t[f>>2]|0)>=(t[t[r>>2]>>2]|0))break;t[n>>2]=(t[(t[r>>2]|0)+8>>2]|0)+((t[f>>2]|0)*40|0);if((t[(t[n>>2]|0)+24>>2]|0)!=0?(t[t[n>>2]>>2]|0)==12:0)_n(t[(t[n>>2]|0)+24>>2]|0);t[f>>2]=(t[f>>2]|0)+1}bz(t[(t[r>>2]|0)+20>>2]|0)}while(0);if(t[(t[r>>2]|0)+8>>2]|0)pAi[t[135736>>2]&511](t[(t[r>>2]|0)+8>>2]|0);if(t[(t[r>>2]|0)+24>>2]|0)mj(t[(t[r>>2]|0)+24>>2]|0);if(t[(t[r>>2]|0)+16>>2]|0)pAi[t[135736>>2]&511](t[(t[r>>2]|0)+16>>2]|0);pAi[t[135736>>2]&511](t[r>>2]|0);s=i;return}function _n(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if(!(t[r>>2]|0)){s=i;return}do if((t[t[r>>2]>>2]|0)!=1?(t[t[r>>2]>>2]|0)!=9:0){e=t[r>>2]|0;if((t[t[r>>2]>>2]|0)==7){if(!(t[e+28>>2]|0))break;Ba(t[(t[r>>2]|0)+28>>2]|0);break}if((t[e>>2]|0)==4?(t[(t[r>>2]|0)+24>>2]|0)!=0:0)pAi[t[135736>>2]&511](t[(t[r>>2]|0)+24>>2]|0)}else n=4;while(0);do if((n|0)==4){e=t[r>>2]|0;if(t[(t[r>>2]|0)+8>>2]|0){t[e>>2]=9;if(!(t[(t[r>>2]|0)+4>>2]|0))break;Dt(t[(t[r>>2]|0)+4>>2]|0);break}else{if(!(t[e+4>>2]|0))break;Bn(t[(t[r>>2]|0)+4>>2]|0);break}}while(0);pAi[t[135736>>2]&511](t[r>>2]|0);s=i;return}function pn(e,i,r){e=e|0;i=i|0;r=r|0;var f=0,u=0,a=0,o=0,c=0,b=0,h=0,w=0;f=s;s=s+128|0;u=f;a=f+20|0;o=f+16|0;c=f+12|0;b=f+8|0;h=f+24|0;t[a>>2]=e;t[o>>2]=i;t[c>>2]=r;if(!(t[a>>2]|0)){s=f;return}t[b>>2]=0;while(1){w=h+((t[b>>2]<<1)+1)|0;if(!((t[b>>2]|0)<25?(t[b>>2]|0)<(t[c>>2]|0):0))break;n[w>>0]=32;n[h+(t[b>>2]<<1)>>0]=32;t[b>>2]=(t[b>>2]|0)+1}n[w>>0]=0;n[h+(t[b>>2]<<1)>>0]=0;b=t[a>>2]|0;t[u>>2]=h;xe(b|0,127912,u|0)|0;if(!(t[o>>2]|0)){xe(t[a>>2]|0,128024,u|0)|0;s=f;return}do switch(t[t[o>>2]>>2]|0){case 5:{b=t[a>>2]|0;t[u>>2]=t[(t[o>>2]|0)+32>>2];xe(b|0,128360,u|0)|0;It(t[a>>2]|0,t[(t[o>>2]|0)+28>>2]|0,(t[c>>2]|0)+1|0);xe(t[a>>2]|0,128352,u|0)|0;s=f;return}case 6:{do if(t[(t[o>>2]|0)+36>>2]|0){if((t[(t[o>>2]|0)+36>>2]|0)==(t[(t[o>>2]|0)+28>>2]|0)?(t[(t[o>>2]|0)+32>>2]|0)==(t[(t[o>>2]|0)+40>>2]|0):0)break;xe(t[a>>2]|0,128456,u|0)|0;b=t[a>>2]|0;t[u>>2]=h;xe(b|0,127912,u|0)|0;xe(t[a>>2]|0,128480,u|0)|0;if((t[(t[o>>2]|0)+32>>2]|0)>=0){b=t[a>>2]|0;t[u>>2]=t[(t[o>>2]|0)+32>>2];xe(b|0,128432,u|0)|0}xe(t[a>>2]|0,128448,u|0)|0;It(t[a>>2]|0,t[(t[o>>2]|0)+28>>2]|0,(t[c>>2]|0)+1|0);b=t[a>>2]|0;t[u>>2]=h;xe(b|0,127912,u|0)|0;xe(t[a>>2]|0,128488,u|0)|0;if((t[(t[o>>2]|0)+40>>2]|0)>=0){b=t[a>>2]|0;t[u>>2]=t[(t[o>>2]|0)+40>>2];xe(b|0,128432,u|0)|0}xe(t[a>>2]|0,128448,u|0)|0;It(t[a>>2]|0,t[(t[o>>2]|0)+36>>2]|0,(t[c>>2]|0)+1|0);xe(t[a>>2]|0,128352,u|0)|0;s=f;return}while(0);xe(t[a>>2]|0,128400,u|0)|0;b=t[a>>2]|0;t[u>>2]=h;xe(b|0,127912,u|0)|0;if((t[(t[o>>2]|0)+32>>2]|0)>=0){b=t[a>>2]|0;t[u>>2]=t[(t[o>>2]|0)+32>>2];xe(b|0,128432,u|0)|0}xe(t[a>>2]|0,128448,u|0)|0;It(t[a>>2]|0,t[(t[o>>2]|0)+28>>2]|0,(t[c>>2]|0)+1|0);s=f;return}case 9:{xe(t[a>>2]|0,128104,u|0)|0;Pt(t[a>>2]|0,t[(t[o>>2]|0)+4>>2]|0,t[c>>2]|0);s=f;return}case 0:{xe(t[a>>2]|0,128048,u|0)|0;s=f;return}case 4:{xe(t[a>>2]|0,128328,u|0)|0;cr(t[a>>2]|0,t[(t[o>>2]|0)+24>>2]|0);xe(t[a>>2]|0,128352,u|0)|0;s=f;return}case 3:{b=wn(+l[(t[o>>2]|0)+16>>3])|0;if((b|0)==-1){xe(t[a>>2]|0,128208,u|0)|0;s=f;return}else if((b|0)==1){xe(t[a>>2]|0,128176,u|0)|0;s=f;return}else{if(hn(+l[(t[o>>2]|0)+16>>3])|0){xe(t[a>>2]|0,128240,u|0)|0;s=f;return}if(+l[(t[o>>2]|0)+16>>3]==0?(Bt(+l[(t[o>>2]|0)+16>>3])|0)!=0:0){xe(t[a>>2]|0,128272,u|0)|0;s=f;return}b=t[a>>2]|0;l[k>>3]=+l[(t[o>>2]|0)+16>>3];t[u>>2]=t[k>>2];t[u+4>>2]=t[k+4>>2];xe(b|0,128296,u|0)|0;s=f;return}break}case 7:{xe(t[a>>2]|0,128496,u|0)|0;Ht(t[a>>2]|0,t[(t[o>>2]|0)+28>>2]|0,t[c>>2]|0);s=f;return}case 8:{xe(t[a>>2]|0,128528,u|0)|0;s=f;return}case 1:{xe(t[a>>2]|0,128080,u|0)|0;Ct(t[a>>2]|0,t[(t[o>>2]|0)+4>>2]|0,t[c>>2]|0);s=f;return}case 2:{xe(t[a>>2]|0,128136,u|0)|0;b=t[a>>2]|0;if(t[(t[o>>2]|0)+8>>2]|0){xe(b|0,128160,u|0)|0;s=f;return}else{xe(b|0,128168,u|0)|0;s=f;return}break}default:{s=f;return}}while(0)}function En(e){e=e|0;var i=0,r=0,n=0,f=0,u=0,a=0;i=s;s=s+16|0;r=i+8|0;n=i+4|0;f=i;t[n>>2]=e;if((t[n>>2]|0)!=0?(t[(t[n>>2]|0)+20>>2]|0)>0:0){e=t[n>>2]|0;if((t[(t[n>>2]|0)+20>>2]|0)<=(t[(t[n>>2]|0)+44>>2]|0)){vn(e,128552,2830,23);t[r>>2]=0;u=t[r>>2]|0;s=i;return u|0}a=e+20|0;t[a>>2]=(t[a>>2]|0)+-1;a=t[n>>2]|0;if((t[(t[n>>2]|0)+20>>2]|0)>0)t[(t[n>>2]|0)+16>>2]=t[(t[(t[n>>2]|0)+28>>2]|0)+((t[a+20>>2]|0)-1<<2)>>2];else t[a+16>>2]=0;t[f>>2]=t[(t[(t[n>>2]|0)+28>>2]|0)+(t[(t[n>>2]|0)+20>>2]<<2)>>2];t[(t[(t[n>>2]|0)+28>>2]|0)+(t[(t[n>>2]|0)+20>>2]<<2)>>2]=0;t[r>>2]=t[f>>2];u=t[r>>2]|0;s=i;return u|0}t[r>>2]=0;u=t[r>>2]|0;s=i;return u|0}function Sn(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0;r=s;s=s+16|0;n=r+12|0;f=r+8|0;u=r+4|0;a=r;t[f>>2]=e;t[u>>2]=i;if((t[f>>2]|0)==0|(t[u>>2]|0)==0){t[n>>2]=-1;o=t[n>>2]|0;s=r;return o|0}do if((t[(t[f>>2]|0)+20>>2]|0)>=(t[(t[f>>2]|0)+24>>2]|0)){
	if((t[(t[f>>2]|0)+24>>2]|0)>=1e6){Ut(0,128576);t[(t[f>>2]|0)+8>>2]=15;t[n>>2]=0;o=t[n>>2]|0;s=r;return o|0}t[a>>2]=MAi[t[135760>>2]&511](t[(t[f>>2]|0)+28>>2]|0,t[(t[f>>2]|0)+24>>2]<<1<<2)|0;if(t[a>>2]|0){i=(t[f>>2]|0)+24|0;t[i>>2]=t[i>>2]<<1;t[(t[f>>2]|0)+28>>2]=t[a>>2];break}Ut(0,128616);t[(t[f>>2]|0)+8>>2]=15;t[n>>2]=0;o=t[n>>2]|0;s=r;return o|0}while(0);t[(t[(t[f>>2]|0)+28>>2]|0)+(t[(t[f>>2]|0)+20>>2]<<2)>>2]=t[u>>2];t[(t[f>>2]|0)+16>>2]=t[u>>2];u=(t[f>>2]|0)+20|0;f=t[u>>2]|0;t[u>>2]=f+1;t[n>>2]=f;o=t[n>>2]|0;s=r;return o|0}function gn(e){e=e|0;var i=0,r=0,n=0,f=0,u=0,a=0;i=s;s=s+16|0;r=i+12|0;n=i+8|0;f=i+4|0;u=i;t[n>>2]=e;t[f>>2]=En(t[n>>2]|0)|0;if(!(t[f>>2]|0)){vn(t[n>>2]|0,128552,2896,10);if(t[n>>2]|0)t[(t[n>>2]|0)+8>>2]=10;t[r>>2]=0;a=t[r>>2]|0;s=i;return a|0}e=t[f>>2]|0;if((t[t[f>>2]>>2]|0)!=2)t[u>>2]=yn(e)|0;else t[u>>2]=t[e+8>>2];zt(t[(t[n>>2]|0)+12>>2]|0,t[f>>2]|0);t[r>>2]=t[u>>2];a=t[r>>2]|0;s=i;return a|0}function yn(e){e=e|0;var i=0,r=0,n=0,f=0,u=0,a=0,o=0;i=s;s=s+32|0;r=i;n=i+16|0;f=i+12|0;u=i+8|0;t[f>>2]=e;t[u>>2]=0;if(!(t[f>>2]|0)){t[n>>2]=0;a=t[n>>2]|0;s=i;return a|0}switch(t[t[f>>2]>>2]|0){case 2:{t[u>>2]=t[(t[f>>2]|0)+8>>2];break}case 4:{t[u>>2]=kf(t[(t[f>>2]|0)+24>>2]|0)|0;break}case 3:{t[u>>2]=bf(+l[(t[f>>2]|0)+16>>3])|0;break}case 7:case 6:case 5:case 8:{e=t[33976]|0;o=t[33980]|0;t[r>>2]=128552;t[r+4>>2]=6066;yAi[e&511](o,129064,r);t[u>>2]=0;break}case 9:case 1:{t[u>>2]=hf(t[(t[f>>2]|0)+4>>2]|0)|0;break}case 0:{t[u>>2]=0;break}default:{}}t[n>>2]=t[u>>2];a=t[n>>2]|0;s=i;return a|0}function Fn(e){e=e|0;var i=0,r=0,n=0,f=0,u=0,a=0,o=0;i=s;s=s+32|0;r=i+16|0;n=i+8|0;f=i+24|0;u=i;t[f>>2]=e;l[u>>3]=0;if(!(t[f>>2]|0)){l[n>>3]=+l[15984];a=+l[n>>3];s=i;return+a}switch(t[t[f>>2]>>2]|0){case 0:{l[u>>3]=+l[15984];break}case 2:{l[u>>3]=+af(t[(t[f>>2]|0)+8>>2]|0);break}case 4:{l[u>>3]=+of(t[(t[f>>2]|0)+24>>2]|0);break}case 3:{l[u>>3]=+l[(t[f>>2]|0)+16>>3];break}case 7:case 6:case 5:case 8:{e=t[33976]|0;o=t[33980]|0;t[r>>2]=128552;t[r+4>>2]=5954;yAi[e&511](o,129064,r);l[u>>3]=+l[15984];break}case 9:case 1:{l[u>>3]=+sf(t[(t[f>>2]|0)+4>>2]|0);break}default:{}}l[n>>3]=+l[u>>3];a=+l[n>>3];s=i;return+a}function On(e){e=e|0;var i=0,r=0,n=0,f=0,u=0,a=0,o=0,c=0;i=s;s=s+16|0;r=i+12|0;n=i+8|0;f=i+4|0;u=i;t[n>>2]=e;t[f>>2]=0;if(!(t[n>>2]|0)){t[r>>2]=-1;a=t[r>>2]|0;s=i;return a|0}t[u>>2]=t[(t[n>>2]|0)+12>>2];e:while(1){if(!(t[u>>2]|0))break;if((t[(t[u>>2]|0)+4>>2]|0)==1?(e=(t[f>>2]|0)+1|0,t[f>>2]=e,t[(t[u>>2]|0)+40>>2]=0-e,(t[(t[u>>2]|0)+12>>2]|0)!=0):0){t[u>>2]=t[(t[u>>2]|0)+12>>2];continue}if(t[(t[u>>2]|0)+24>>2]|0){t[u>>2]=t[(t[u>>2]|0)+24>>2];continue}while(1){t[u>>2]=t[(t[u>>2]|0)+20>>2];if(!(t[u>>2]|0))continue e;if((t[u>>2]|0)==(t[n>>2]|0)){o=12;break}c=t[u>>2]|0;if(t[(t[u>>2]|0)+24>>2]|0){o=14;break}if(!c)continue e}if((o|0)==12){o=0;t[u>>2]=0;continue}else if((o|0)==14){o=0;t[u>>2]=t[c+24>>2];continue}}t[r>>2]=t[f>>2];a=t[r>>2]|0;s=i;return a|0}function An(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0,S=0,g=0;r=s;s=s+64|0;n=r+56|0;f=r+52|0;u=r+48|0;a=r+44|0;o=r+40|0;c=r+36|0;l=r+32|0;b=r+28|0;k=r+24|0;h=r+20|0;w=r+16|0;d=r+12|0;v=r+8|0;m=r+4|0;_=r;t[f>>2]=e;t[u>>2]=i;t[c>>2]=0;t[l>>2]=0;t[b>>2]=0;t[k>>2]=0;if((t[f>>2]|0)==0|(t[u>>2]|0)==0){t[n>>2]=-2;p=t[n>>2]|0;s=r;return p|0}if((t[f>>2]|0)==(t[u>>2]|0)){t[n>>2]=0;p=t[n>>2]|0;s=r;return p|0}if((t[(t[f>>2]|0)+4>>2]|0)==2){t[c>>2]=1;t[b>>2]=t[f>>2];t[f>>2]=t[(t[f>>2]|0)+20>>2]}if((t[(t[u>>2]|0)+4>>2]|0)==2){t[l>>2]=1;t[k>>2]=t[u>>2];t[u>>2]=t[(t[u>>2]|0)+20>>2]}if((t[f>>2]|0)==(t[u>>2]|0)){if((t[c>>2]|0)!=(t[l>>2]|0))if((t[l>>2]|0)==1){t[n>>2]=1;p=t[n>>2]|0;s=r;return p|0}else{t[n>>2]=-1;p=t[n>>2]|0;s=r;return p|0}if(!(t[c>>2]|0)){t[n>>2]=0;p=t[n>>2]|0;s=r;return p|0}t[h>>2]=t[(t[k>>2]|0)+28>>2];while(1){if(!(t[h>>2]|0)){E=17;break}if((t[h>>2]|0)==(t[b>>2]|0)){E=15;break}t[h>>2]=t[(t[h>>2]|0)+28>>2]}if((E|0)==15){t[n>>2]=1;p=t[n>>2]|0;s=r;return p|0}else if((E|0)==17){t[n>>2]=-1;p=t[n>>2]|0;s=r;return p|0}}if((t[(t[f>>2]|0)+4>>2]|0)!=18?(t[(t[u>>2]|0)+4>>2]|0)!=18:0){if((t[f>>2]|0)==(t[(t[u>>2]|0)+28>>2]|0)){t[n>>2]=1;p=t[n>>2]|0;s=r;return p|0}if((t[f>>2]|0)==(t[(t[u>>2]|0)+24>>2]|0)){t[n>>2]=-1;p=t[n>>2]|0;s=r;return p|0}if(((((t[(t[f>>2]|0)+4>>2]|0)==1?(t[(t[u>>2]|0)+4>>2]|0)==1:0)?0>(t[(t[f>>2]|0)+40>>2]|0):0)?0>(t[(t[u>>2]|0)+40>>2]|0):0)?(t[(t[f>>2]|0)+32>>2]|0)==(t[(t[u>>2]|0)+32>>2]|0):0){t[d>>2]=0-(t[(t[f>>2]|0)+40>>2]|0);t[v>>2]=0-(t[(t[u>>2]|0)+40>>2]|0);if((t[d>>2]|0)<(t[v>>2]|0)){t[n>>2]=1;p=t[n>>2]|0;s=r;return p|0}if((t[d>>2]|0)>(t[v>>2]|0)){t[n>>2]=-1;p=t[n>>2]|0;s=r;return p|0}}t[o>>2]=0;t[h>>2]=t[u>>2];while(1){S=t[h>>2]|0;if(!(t[(t[h>>2]|0)+20>>2]|0))break;if((S|0)==(t[f>>2]|0)){E=41;break}t[o>>2]=(t[o>>2]|0)+1;t[h>>2]=t[(t[h>>2]|0)+20>>2]}if((E|0)==41){t[n>>2]=1;p=t[n>>2]|0;s=r;return p|0}t[w>>2]=S;t[a>>2]=0;t[h>>2]=t[f>>2];while(1){if(!(t[(t[h>>2]|0)+20>>2]|0))break;if((t[h>>2]|0)==(t[u>>2]|0)){E=46;break}t[a>>2]=(t[a>>2]|0)+1;t[h>>2]=t[(t[h>>2]|0)+20>>2]}if((E|0)==46){t[n>>2]=-1;p=t[n>>2]|0;s=r;return p|0}if((t[w>>2]|0)!=(t[h>>2]|0)){t[n>>2]=-2;p=t[n>>2]|0;s=r;return p|0}while(1){if((t[a>>2]|0)<=(t[o>>2]|0))break;t[a>>2]=(t[a>>2]|0)+-1;t[f>>2]=t[(t[f>>2]|0)+20>>2]}while(1){if((t[o>>2]|0)<=(t[a>>2]|0))break;t[o>>2]=(t[o>>2]|0)+-1;t[u>>2]=t[(t[u>>2]|0)+20>>2]}while(1){g=t[f>>2]|0;if((t[(t[f>>2]|0)+20>>2]|0)==(t[(t[u>>2]|0)+20>>2]|0))break;t[f>>2]=t[g+20>>2];t[u>>2]=t[(t[u>>2]|0)+20>>2];if((t[f>>2]|0)==0|(t[u>>2]|0)==0){E=56;break}}if((E|0)==56){t[n>>2]=-2;p=t[n>>2]|0;s=r;return p|0}if((g|0)==(t[(t[u>>2]|0)+28>>2]|0)){t[n>>2]=1;p=t[n>>2]|0;s=r;return p|0}if((t[f>>2]|0)==(t[(t[u>>2]|0)+24>>2]|0)){t[n>>2]=-1;p=t[n>>2]|0;s=r;return p|0}do if(((((t[(t[f>>2]|0)+4>>2]|0)==1?(t[(t[u>>2]|0)+4>>2]|0)==1:0)?0>(t[(t[f>>2]|0)+40>>2]|0):0)?0>(t[(t[u>>2]|0)+40>>2]|0):0)?(t[(t[f>>2]|0)+32>>2]|0)==(t[(t[u>>2]|0)+32>>2]|0):0){t[m>>2]=0-(t[(t[f>>2]|0)+40>>2]|0);t[_>>2]=0-(t[(t[u>>2]|0)+40>>2]|0);if((t[m>>2]|0)<(t[_>>2]|0)){t[n>>2]=1;p=t[n>>2]|0;s=r;return p|0}if((t[m>>2]|0)<=(t[_>>2]|0))break;t[n>>2]=-1;p=t[n>>2]|0;s=r;return p|0}while(0);t[h>>2]=t[(t[f>>2]|0)+24>>2];while(1){if(!(t[h>>2]|0)){E=75;break}if((t[h>>2]|0)==(t[u>>2]|0)){E=73;break}t[h>>2]=t[(t[h>>2]|0)+24>>2]}if((E|0)==73){t[n>>2]=1;p=t[n>>2]|0;s=r;return p|0}else if((E|0)==75){t[n>>2]=-1;p=t[n>>2]|0;s=r;return p|0}}t[n>>2]=1;p=t[n>>2]|0;s=r;return p|0}function Mn(e){e=e|0;var i=0,r=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if(!(t[r>>2]|0)){s=i;return}bn(t[(t[r>>2]|0)+8>>2]|0,t[t[r>>2]>>2]|0);s=i;return}function Rn(e){e=e|0;var i=0,r=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if(!(t[r>>2]|0)){s=i;return}if((t[(t[r>>2]|0)+4>>2]|0)!=18){s=i;return}if(!(t[t[r>>2]>>2]|0)){s=i;return}if((t[(t[t[r>>2]>>2]|0)+4>>2]|0)==18){s=i;return}if(t[(t[r>>2]|0)+8>>2]|0)pAi[t[135736>>2]&511](t[(t[r>>2]|0)+8>>2]|0);if(t[(t[r>>2]|0)+12>>2]|0)pAi[t[135736>>2]&511](t[(t[r>>2]|0)+12>>2]|0);pAi[t[135736>>2]&511](t[r>>2]|0);s=i;return}function Nn(e){e=e|0;var i=0,r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0;i=s;s=s+16|0;r=i+12|0;n=i+8|0;f=i+4|0;u=i;t[n>>2]=e;t[f>>2]=gAi[t[135744>>2]&511](12)|0;if(!(t[f>>2]|0)){Ut(0,128632);t[r>>2]=0;a=t[r>>2]|0;s=i;return a|0}e=t[f>>2]|0;t[e+0>>2]=0;t[e+4>>2]=0;t[e+8>>2]=0;do if(t[n>>2]|0){e=gAi[t[135744>>2]&511](40)|0;t[(t[f>>2]|0)+8>>2]=e;if(!(t[(t[f>>2]|0)+8>>2]|0)){Ut(0,128632);pAi[t[135736>>2]&511](t[f>>2]|0);t[r>>2]=0;a=t[r>>2]|0;s=i;return a|0}e=(t[(t[f>>2]|0)+8>>2]|0)+0|0;o=e+40|0;do{t[e>>2]=0;e=e+4|0}while((e|0)<(o|0));t[(t[f>>2]|0)+4>>2]=10;e=t[n>>2]|0;if((t[(t[n>>2]|0)+4>>2]|0)==18){t[u>>2]=e;o=jt(t[t[u>>2]>>2]|0,t[u>>2]|0)|0;c=t[f>>2]|0;l=t[c>>2]|0;t[c>>2]=l+1;t[(t[(t[f>>2]|0)+8>>2]|0)+(l<<2)>>2]=o;break}else{o=t[f>>2]|0;l=t[o>>2]|0;t[o>>2]=l+1;t[(t[(t[f>>2]|0)+8>>2]|0)+(l<<2)>>2]=e;break}}while(0);t[r>>2]=t[f>>2];a=t[r>>2]|0;s=i;return a|0}function Tn(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0;r=s;s=s+32|0;n=r+20|0;f=r+16|0;u=r+12|0;a=r+8|0;o=r+4|0;c=r;t[f>>2]=e;t[u>>2]=i;if((t[f>>2]|0)==0|(t[u>>2]|0)==0){t[n>>2]=0;l=t[n>>2]|0;s=r;return l|0}i=(t[(t[u>>2]|0)+4>>2]|0)==18;t[a>>2]=0;e:do if(i){while(1){if((t[a>>2]|0)>=(t[t[f>>2]>>2]|0))break e;if((t[(t[(t[(t[f>>2]|0)+8>>2]|0)+(t[a>>2]<<2)>>2]|0)+4>>2]|0)==18){t[o>>2]=t[u>>2];t[c>>2]=t[(t[(t[f>>2]|0)+8>>2]|0)+(t[a>>2]<<2)>>2];if((t[o>>2]|0)==(t[c>>2]|0)){b=7;break}if(((t[t[o>>2]>>2]|0)!=0?(t[t[c>>2]>>2]|0)==(t[t[o>>2]>>2]|0):0)?(Xl(t[(t[o>>2]|0)+12>>2]|0,t[(t[c>>2]|0)+12>>2]|0)|0)!=0:0){b=11;break}}t[a>>2]=(t[a>>2]|0)+1}if((b|0)==7){t[n>>2]=1;l=t[n>>2]|0;s=r;return l|0}else if((b|0)==11){t[n>>2]=1;l=t[n>>2]|0;s=r;return l|0}}else{while(1){if((t[a>>2]|0)>=(t[t[f>>2]>>2]|0))break e;if((t[(t[(t[f>>2]|0)+8>>2]|0)+(t[a>>2]<<2)>>2]|0)==(t[u>>2]|0))break;t[a>>2]=(t[a>>2]|0)+1}t[n>>2]=1;l=t[n>>2]|0;s=r;return l|0}while(0);t[n>>2]=0;l=t[n>>2]|0;s=r;return l|0}function Ln(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0;n=s;s=s+32|0;f=n+20|0;u=n+16|0;a=n+12|0;o=n+8|0;c=n+4|0;l=n;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;if((!((t[u>>2]|0)==0|(t[o>>2]|0)==0|(t[a>>2]|0)==0)?(t[(t[o>>2]|0)+4>>2]|0)==18:0)?(t[(t[a>>2]|0)+4>>2]|0)==1:0){t[c>>2]=0;while(1){if((t[c>>2]|0)>=(t[t[u>>2]>>2]|0))break;if((((t[(t[(t[u>>2]|0)+8>>2]|0)+(t[c>>2]<<2)>>2]|0)!=0?(t[(t[(t[(t[u>>2]|0)+8>>2]|0)+(t[c>>2]<<2)>>2]|0)+4>>2]|0)==18:0)?(t[t[(t[(t[u>>2]|0)+8>>2]|0)+(t[c>>2]<<2)>>2]>>2]|0)==(t[a>>2]|0):0)?(Xl(t[(t[o>>2]|0)+12>>2]|0,t[(t[(t[(t[u>>2]|0)+8>>2]|0)+(t[c>>2]<<2)>>2]|0)+12>>2]|0)|0)!=0:0){b=11;break}t[c>>2]=(t[c>>2]|0)+1}if((b|0)==11){t[f>>2]=0;k=t[f>>2]|0;s=n;return k|0}do if(t[(t[u>>2]|0)+4>>2]|0){if((t[t[u>>2]>>2]|0)==(t[(t[u>>2]|0)+4>>2]|0)){if((t[(t[u>>2]|0)+4>>2]|0)>=1e7){Ut(0,128680);t[f>>2]=-1;k=t[f>>2]|0;s=n;return k|0}t[l>>2]=MAi[t[135760>>2]&511](t[(t[u>>2]|0)+8>>2]|0,t[(t[u>>2]|0)+4>>2]<<1<<2)|0;if(t[l>>2]|0){b=(t[u>>2]|0)+4|0;t[b>>2]=t[b>>2]<<1;t[(t[u>>2]|0)+8>>2]=t[l>>2];break}Ut(0,128656);t[f>>2]=-1;k=t[f>>2]|0;s=n;return k|0}}else{b=gAi[t[135744>>2]&511](40)|0;t[(t[u>>2]|0)+8>>2]=b;if(t[(t[u>>2]|0)+8>>2]|0){b=(t[(t[u>>2]|0)+8>>2]|0)+0|0;c=b+40|0;do{t[b>>2]=0;b=b+4|0}while((b|0)<(c|0));t[(t[u>>2]|0)+4>>2]=10;break}Ut(0,128656);t[f>>2]=-1;k=t[f>>2]|0;s=n;return k|0}while(0);l=jt(t[a>>2]|0,t[o>>2]|0)|0;o=t[u>>2]|0;a=t[o>>2]|0;t[o>>2]=a+1;t[(t[(t[u>>2]|0)+8>>2]|0)+(a<<2)>>2]=l;t[f>>2]=0;k=t[f>>2]|0;s=n;return k|0}t[f>>2]=-1;k=t[f>>2]|0;s=n;return k|0}function Dn(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0;r=s;s=s+32|0;n=r+20|0;f=r+16|0;u=r+12|0;a=r+8|0;o=r+4|0;c=r;t[f>>2]=e;t[u>>2]=i;if((t[f>>2]|0)==0|(t[u>>2]|0)==0){t[n>>2]=-1;l=t[n>>2]|0;s=r;return l|0}t[a>>2]=0;while(1){if((t[a>>2]|0)>=(t[t[f>>2]>>2]|0))break;if((t[(t[(t[f>>2]|0)+8>>2]|0)+(t[a>>2]<<2)>>2]|0)==(t[u>>2]|0)){b=6;break}t[a>>2]=(t[a>>2]|0)+1}if((b|0)==6){t[n>>2]=0;l=t[n>>2]|0;s=r;return l|0}do if(t[(t[f>>2]|0)+4>>2]|0){if((t[t[f>>2]>>2]|0)==(t[(t[f>>2]|0)+4>>2]|0)){if((t[(t[f>>2]|0)+4>>2]|0)>=1e7){Ut(0,128680);t[n>>2]=-1;l=t[n>>2]|0;s=r;return l|0}t[o>>2]=MAi[t[135760>>2]&511](t[(t[f>>2]|0)+8>>2]|0,t[(t[f>>2]|0)+4>>2]<<1<<2)|0;if(t[o>>2]|0){b=(t[f>>2]|0)+4|0;t[b>>2]=t[b>>2]<<1;t[(t[f>>2]|0)+8>>2]=t[o>>2];break}Ut(0,128656);t[n>>2]=-1;l=t[n>>2]|0;s=r;return l|0}}else{b=gAi[t[135744>>2]&511](40)|0;t[(t[f>>2]|0)+8>>2]=b;if(t[(t[f>>2]|0)+8>>2]|0){b=(t[(t[f>>2]|0)+8>>2]|0)+0|0;a=b+40|0;do{t[b>>2]=0;b=b+4|0}while((b|0)<(a|0));t[(t[f>>2]|0)+4>>2]=10;break}Ut(0,128656);t[n>>2]=-1;l=t[n>>2]|0;s=r;return l|0}while(0);o=t[u>>2]|0;if((t[(t[u>>2]|0)+4>>2]|0)==18){t[c>>2]=o;u=jt(t[t[c>>2]>>2]|0,t[c>>2]|0)|0;c=t[f>>2]|0;b=t[c>>2]|0;t[c>>2]=b+1;t[(t[(t[f>>2]|0)+8>>2]|0)+(b<<2)>>2]=u}else{u=t[f>>2]|0;b=t[u>>2]|0;t[u>>2]=b+1;t[(t[(t[f>>2]|0)+8>>2]|0)+(b<<2)>>2]=o}t[n>>2]=0;l=t[n>>2]|0;s=r;return l|0}function Cn(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0;r=s;s=s+32|0;n=r+16|0;f=r+12|0;u=r+8|0;a=r+4|0;o=r;t[f>>2]=e;t[u>>2]=i;if((t[f>>2]|0)==0|(t[u>>2]|0)==0){t[n>>2]=-1;c=t[n>>2]|0;s=r;return c|0}do if(t[(t[f>>2]|0)+4>>2]|0){if((t[t[f>>2]>>2]|0)==(t[(t[f>>2]|0)+4>>2]|0)){if((t[(t[f>>2]|0)+4>>2]|0)>=1e7){Ut(0,128680);t[n>>2]=-1;c=t[n>>2]|0;s=r;return c|0}t[a>>2]=MAi[t[135760>>2]&511](t[(t[f>>2]|0)+8>>2]|0,t[(t[f>>2]|0)+4>>2]<<1<<2)|0;if(t[a>>2]|0){t[(t[f>>2]|0)+8>>2]=t[a>>2];i=(t[f>>2]|0)+4|0;t[i>>2]=t[i>>2]<<1;break}Ut(0,128656);t[n>>2]=-1;c=t[n>>2]|0;s=r;return c|0}}else{i=gAi[t[135744>>2]&511](40)|0;t[(t[f>>2]|0)+8>>2]=i;if(t[(t[f>>2]|0)+8>>2]|0){i=(t[(t[f>>2]|0)+8>>2]|0)+0|0;e=i+40|0;do{t[i>>2]=0;i=i+4|0}while((i|0)<(e|0));t[(t[f>>2]|0)+4>>2]=10;break}Ut(0,128656);t[n>>2]=-1;c=t[n>>2]|0;s=r;return c|0}while(0);a=t[u>>2]|0;if((t[(t[u>>2]|0)+4>>2]|0)==18){t[o>>2]=a;u=jt(t[t[o>>2]>>2]|0,t[o>>2]|0)|0;o=t[f>>2]|0;i=t[o>>2]|0;t[o>>2]=i+1;t[(t[(t[f>>2]|0)+8>>2]|0)+(i<<2)>>2]=u}else{u=t[f>>2]|0;i=t[u>>2]|0;t[u>>2]=i+1;t[(t[(t[f>>2]|0)+8>>2]|0)+(i<<2)>>2]=a}t[n>>2]=0;c=t[n>>2]|0;s=r;return c|0}function Pn(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0;r=s;s=s+48|0;n=r+40|0;f=r+36|0;u=r+32|0;a=r+28|0;o=r+24|0;c=r+20|0;l=r+16|0;b=r+12|0;k=r+8|0;h=r+4|0;w=r;t[f>>2]=e;t[u>>2]=i;i=t[f>>2]|0;if(!(t[u>>2]|0)){t[n>>2]=i;d=t[n>>2]|0;s=r;return d|0}if((i|0)==0?(t[f>>2]=Nn(0)|0,(t[f>>2]|0)==0):0){t[n>>2]=0;d=t[n>>2]|0;s=r;return d|0}t[c>>2]=t[t[f>>2]>>2];t[a>>2]=0;e:while(1){if((t[a>>2]|0)>=(t[t[u>>2]>>2]|0)){v=33;break}t[k>>2]=t[(t[(t[u>>2]|0)+8>>2]|0)+(t[a>>2]<<2)>>2];t[l>>2]=0;t[o>>2]=0;while(1){if((t[o>>2]|0)>=(t[c>>2]|0))break;t[b>>2]=t[(t[(t[f>>2]|0)+8>>2]|0)+(t[o>>2]<<2)>>2];if((t[b>>2]|0)==(t[k>>2]|0)){v=11;break}if((((t[(t[b>>2]|0)+4>>2]|0)==18?(t[(t[k>>2]|0)+4>>2]|0)==18:0)?(t[t[b>>2]>>2]|0)==(t[t[k>>2]>>2]|0):0)?(Xl(t[(t[b>>2]|0)+12>>2]|0,t[(t[k>>2]|0)+12>>2]|0)|0)!=0:0){v=16;break}t[o>>2]=(t[o>>2]|0)+1}if((v|0)==11){v=0;t[l>>2]=1}else if((v|0)==16){v=0;t[l>>2]=1}do if(!(t[l>>2]|0)){if(t[(t[f>>2]|0)+4>>2]|0){if((t[t[f>>2]>>2]|0)==(t[(t[f>>2]|0)+4>>2]|0)){if((t[(t[f>>2]|0)+4>>2]|0)>=1e7){v=25;break e}t[h>>2]=MAi[t[135760>>2]&511](t[(t[f>>2]|0)+8>>2]|0,t[(t[f>>2]|0)+4>>2]<<1<<2)|0;if(!(t[h>>2]|0)){v=27;break e}t[(t[f>>2]|0)+8>>2]=t[h>>2];i=(t[f>>2]|0)+4|0;t[i>>2]=t[i>>2]<<1}}else{i=gAi[t[135744>>2]&511](40)|0;t[(t[f>>2]|0)+8>>2]=i;if(!(t[(t[f>>2]|0)+8>>2]|0)){v=21;break e}i=(t[(t[f>>2]|0)+8>>2]|0)+0|0;e=i+40|0;do{t[i>>2]=0;i=i+4|0}while((i|0)<(e|0));t[(t[f>>2]|0)+4>>2]=10}i=t[k>>2]|0;if((t[(t[k>>2]|0)+4>>2]|0)==18){t[w>>2]=i;e=jt(t[t[w>>2]>>2]|0,t[w>>2]|0)|0;m=t[f>>2]|0;_=t[m>>2]|0;t[m>>2]=_+1;t[(t[(t[f>>2]|0)+8>>2]|0)+(_<<2)>>2]=e;break}else{e=t[f>>2]|0;_=t[e>>2]|0;t[e>>2]=_+1;t[(t[(t[f>>2]|0)+8>>2]|0)+(_<<2)>>2]=i;break}}while(0);t[a>>2]=(t[a>>2]|0)+1}if((v|0)==21){Ut(0,128712);t[n>>2]=0;d=t[n>>2]|0;s=r;return d|0}else if((v|0)==25){Ut(0,128736);t[n>>2]=0;d=t[n>>2]|0;s=r;return d|0}else if((v|0)==27){Ut(0,128712);t[n>>2]=0;d=t[n>>2]|0;s=r;return d|0}else if((v|0)==33){t[n>>2]=t[f>>2];d=t[n>>2]|0;s=r;return d|0}return 0}function Bn(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i+4|0;n=i;t[r>>2]=e;if(!(t[r>>2]|0)){s=i;return}if(t[(t[r>>2]|0)+8>>2]|0){t[n>>2]=0;while(1){if((t[n>>2]|0)>=(t[t[r>>2]>>2]|0))break;if((t[(t[(t[r>>2]|0)+8>>2]|0)+(t[n>>2]<<2)>>2]|0)!=0?(t[(t[(t[(t[r>>2]|0)+8>>2]|0)+(t[n>>2]<<2)>>2]|0)+4>>2]|0)==18:0)Rn(t[(t[(t[r>>2]|0)+8>>2]|0)+(t[n>>2]<<2)>>2]|0);t[n>>2]=(t[n>>2]|0)+1}pAi[t[135736>>2]&511](t[(t[r>>2]|0)+8>>2]|0)}pAi[t[135736>>2]&511](t[r>>2]|0);s=i;return}function In(e){e=e|0;var i=0,r=0,n=0,f=0,u=0,a=0;i=s;s=s+16|0;r=i+8|0;n=i+4|0;f=i;t[n>>2]=e;t[f>>2]=gAi[t[135744>>2]&511](48)|0;if(!(t[f>>2]|0)){Ut(0,128632);t[r>>2]=0;u=t[r>>2]|0;s=i;return u|0}else{e=(t[f>>2]|0)+0|0;a=e+48|0;do{t[e>>2]=0;e=e+4|0}while((e|0)<(a|0));t[t[f>>2]>>2]=1;t[(t[f>>2]|0)+8>>2]=0;e=Nn(t[n>>2]|0)|0;t[(t[f>>2]|0)+4>>2]=e;t[r>>2]=t[f>>2];u=t[r>>2]|0;s=i;return u|0}return 0}function Hn(e){e=e|0;var i=0,r=0,n=0,f=0,u=0,a=0;i=s;s=s+16|0;r=i+8|0;n=i+4|0;f=i;t[n>>2]=e;t[f>>2]=gAi[t[135744>>2]&511](48)|0;if(!(t[f>>2]|0)){Ut(0,128768);t[r>>2]=0;u=t[r>>2]|0;s=i;return u|0}else{e=(t[f>>2]|0)+0|0;a=e+48|0;do{t[e>>2]=0;e=e+4|0}while((e|0)<(a|0));t[t[f>>2]>>2]=1;t[(t[f>>2]|0)+4>>2]=t[n>>2];t[r>>2]=t[f>>2];u=t[r>>2]|0;s=i;return u|0}return 0}function xn(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i+4|0;n=i;t[r>>2]=e;e=sF(t[r>>2]|0)|0;t[n>>2]=e;if(!e)t[n>>2]=Yl(128928)|0;s=i;return t[n>>2]|0}function Un(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0;n=s;s=s+16|0;f=n+8|0;u=n+4|0;a=n;t[f>>2]=e;t[u>>2]=i;t[a>>2]=r;r=zn(t[f>>2]|0,t[u>>2]|0,0,t[a>>2]|0)|0;s=n;return r|0}function zn(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,u=0,a=0,o=0,c=0,l=0;f=s;s=s+32|0;u=f+16|0;a=f+12|0;o=f+8|0;c=f+4|0;l=f;t[a>>2]=e;t[o>>2]=i;t[c>>2]=r;t[l>>2]=n;do if(t[a>>2]|0){if(!(t[o>>2]|0)){t[u>>2]=-1;break}if(!(t[(t[a>>2]|0)+40>>2]|0)){n=WF(0)|0;t[(t[a>>2]|0)+40>>2]=n}if(!(t[(t[a>>2]|0)+40>>2]|0)){t[u>>2]=-1;break}n=t[(t[a>>2]|0)+40>>2]|0;r=t[o>>2]|0;i=t[c>>2]|0;if(!(t[l>>2]|0)){t[u>>2]=wO(n,r,i,0)|0;break}else{t[u>>2]=QF(n,r,i,t[l>>2]|0)|0;break}}else t[u>>2]=-1;while(0);s=f;return t[u>>2]|0}function jn(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0;r=s;s=s+32|0;n=r+20|0;f=r+16|0;u=r+12|0;a=r+8|0;o=r+4|0;c=r;t[f>>2]=e;t[u>>2]=i;if(!(t[f>>2]|0)){t[n>>2]=0;l=t[n>>2]|0;s=r;return l|0}if((t[(t[f>>2]|0)+112>>2]|0)!=0?(t[o>>2]=t[(t[f>>2]|0)+112>>2],t[c>>2]=dAi[t[o>>2]&511](t[(t[f>>2]|0)+116>>2]|0,t[u>>2]|0,0)|0,t[a>>2]=t[c>>2],(t[a>>2]|0)!=0):0){t[n>>2]=t[a>>2];l=t[n>>2]|0;s=r;return l|0}t[n>>2]=Vn(t[f>>2]|0,t[u>>2]|0,0)|0;l=t[n>>2]|0;s=r;return l|0}function Vn(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0;n=s;s=s+32|0;f=n+24|0;u=n+20|0;a=n+16|0;o=n+12|0;c=n+8|0;l=n+4|0;b=n;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;if(!(t[u>>2]|0)){t[f>>2]=0;k=t[f>>2]|0;s=n;return k|0}if(!(t[a>>2]|0)){t[f>>2]=0;k=t[f>>2]|0;s=n;return k|0}if((t[(t[u>>2]|0)+112>>2]|0)!=0?(t[l>>2]=t[(t[u>>2]|0)+112>>2],t[b>>2]=dAi[t[l>>2]&511](t[(t[u>>2]|0)+116>>2]|0,t[a>>2]|0,t[o>>2]|0)|0,t[c>>2]=t[b>>2],(t[c>>2]|0)!=0):0){t[f>>2]=t[c>>2];k=t[f>>2]|0;s=n;return k|0}if(!(t[(t[u>>2]|0)+40>>2]|0)){t[f>>2]=0;k=t[f>>2]|0;s=n;return k|0}else{t[c>>2]=fO(t[(t[u>>2]|0)+40>>2]|0,t[a>>2]|0,t[o>>2]|0)|0;t[f>>2]=t[c>>2];k=t[f>>2]|0;s=n;return k|0}return 0}function qn(e){e=e|0;var i=0,r=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if(!(t[r>>2]|0)){s=i;return}XF(t[(t[r>>2]|0)+40>>2]|0,0);t[(t[r>>2]|0)+40>>2]=0;s=i;return}function Yn(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0;r=s;s=s+16|0;n=r+12|0;f=r+8|0;u=r+4|0;a=r;t[f>>2]=e;t[u>>2]=i;if(!(t[f>>2]|0)){t[n>>2]=0;o=t[n>>2]|0;s=r;return o|0}i=t[f>>2]|0;if(t[(t[f>>2]|0)+92>>2]|0){t[a>>2]=dAi[t[i+92>>2]&511](t[(t[f>>2]|0)+96>>2]|0,t[u>>2]|0,0)|0;t[n>>2]=t[a>>2];o=t[n>>2]|0;s=r;return o|0}else{t[n>>2]=Gn(i,t[u>>2]|0,0)|0;o=t[n>>2]|0;s=r;return o|0}return 0}function Gn(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,l=0;n=s;s=s+32|0;f=n+16|0;u=n+12|0;a=n+8|0;o=n+4|0;c=n;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;if(!(t[u>>2]|0)){t[f>>2]=0;l=t[f>>2]|0;s=n;return l|0}if((t[(t[u>>2]|0)+92>>2]|0)!=0?(t[c>>2]=dAi[t[(t[u>>2]|0)+92>>2]&511](t[(t[u>>2]|0)+96>>2]|0,t[a>>2]|0,t[o>>2]|0)|0,(t[c>>2]|0)!=0):0){t[f>>2]=t[c>>2];l=t[f>>2]|0;s=n;return l|0}if(!(t[(t[u>>2]|0)+16>>2]|0)){t[f>>2]=0;l=t[f>>2]|0;s=n;return l|0}if(!(t[a>>2]|0)){t[f>>2]=0;l=t[f>>2]|0;s=n;return l|0}else{c=t[u>>2]|0;t[f>>2]=Vt(c,fO(t[(t[u>>2]|0)+16>>2]|0,t[a>>2]|0,t[o>>2]|0)|0)|0;l=t[f>>2]|0;s=n;return l|0}return 0}function Wn(e){e=e|0;var i=0,r=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if(!(t[r>>2]|0)){s=i;return}XF(t[(t[r>>2]|0)+16>>2]|0,260);t[(t[r>>2]|0)+16>>2]=0;s=i;return}function Kn(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,a=0,o=0,c=0;n=s;s=s+16|0;f=n+12|0;a=n+8|0;o=n+4|0;c=n;t[a>>2]=e;t[o>>2]=i;t[c>>2]=r;do if(t[a>>2]|0){if(!(t[o>>2]|0)){t[f>>2]=-1;break}if(!(u[t[o>>2]>>0]|0)){t[f>>2]=-1;break}if(!(t[(t[a>>2]|0)+88>>2]|0)){r=WF(10)|0;t[(t[a>>2]|0)+88>>2]=r}if(!(t[(t[a>>2]|0)+88>>2]|0)){t[f>>2]=-1;break}r=t[(t[a>>2]|0)+88>>2]|0;i=t[o>>2]|0;if(!(t[c>>2]|0)){t[f>>2]=kO(r,i,t[33934]|0)|0;break}else{e=Yl(t[c>>2]|0)|0;t[f>>2]=$F(r,i,e,t[33934]|0)|0;break}}else t[f>>2]=-1;while(0);s=n;return t[f>>2]|0}function Xn(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0;r=s;s=s+16|0;n=r+12|0;f=r+8|0;u=r+4|0;a=r;t[f>>2]=e;t[u>>2]=i;if(!(t[f>>2]|0)){t[n>>2]=0;o=t[n>>2]|0;s=r;return o|0}if(!(t[u>>2]|0)){t[n>>2]=0;o=t[n>>2]|0;s=r;return o|0}if(Xl(t[u>>2]|0,128800)|0){t[n>>2]=128808;o=t[n>>2]|0;s=r;return o|0}e:do if(t[(t[f>>2]|0)+56>>2]|0){t[a>>2]=0;while(1){if((t[a>>2]|0)>=(t[(t[f>>2]|0)+60>>2]|0))break e;if((t[(t[(t[f>>2]|0)+56>>2]|0)+(t[a>>2]<<2)>>2]|0)!=0?(Xl(t[(t[(t[(t[f>>2]|0)+56>>2]|0)+(t[a>>2]<<2)>>2]|0)+12>>2]|0,t[u>>2]|0)|0)!=0:0)break;t[a>>2]=(t[a>>2]|0)+1}t[n>>2]=t[(t[(t[(t[f>>2]|0)+56>>2]|0)+(t[a>>2]<<2)>>2]|0)+8>>2];o=t[n>>2]|0;s=r;return o|0}while(0);t[n>>2]=rO(t[(t[f>>2]|0)+88>>2]|0,t[u>>2]|0)|0;o=t[n>>2]|0;s=r;return o|0}function Zn(e){e=e|0;var i=0,r=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if(!(t[r>>2]|0)){s=i;return}XF(t[(t[r>>2]|0)+88>>2]|0,t[33934]|0);t[(t[r>>2]|0)+88>>2]=0;s=i;return}function Jn(e){e=+e;var i=0,r=0,n=0,f=0,u=0,a=0,o=0;i=s;s=s+16|0;r=i+12|0;n=i;f=i+8|0;l[n>>3]=e;t[f>>2]=gAi[t[135744>>2]&511](48)|0;if(!(t[f>>2]|0)){Ut(0,128848);t[r>>2]=0;u=t[r>>2]|0;s=i;return u|0}else{a=(t[f>>2]|0)+0|0;o=a+48|0;do{t[a>>2]=0;a=a+4|0}while((a|0)<(o|0));t[t[f>>2]>>2]=3;l[(t[f>>2]|0)+16>>3]=+l[n>>3];t[r>>2]=t[f>>2];u=t[r>>2]|0;s=i;return u|0}return 0}function Qn(e){e=e|0;var i=0,r=0,n=0,f=0,u=0,a=0;i=s;s=s+16|0;r=i+8|0;n=i+4|0;f=i;t[n>>2]=e;t[f>>2]=gAi[t[135744>>2]&511](48)|0;if(!(t[f>>2]|0)){Ut(0,128872);t[r>>2]=0;u=t[r>>2]|0;s=i;return u|0}else{e=(t[f>>2]|0)+0|0;a=e+48|0;do{t[e>>2]=0;e=e+4|0}while((e|0)<(a|0));t[t[f>>2]>>2]=2;t[(t[f>>2]|0)+8>>2]=(t[n>>2]|0)!=0&1;t[r>>2]=t[f>>2];u=t[r>>2]|0;s=i;return u|0}return 0}function $n(e){e=e|0;var i=0,r=0,n=0,f=0,u=0,a=0;i=s;s=s+16|0;r=i+8|0;n=i+4|0;f=i;t[n>>2]=e;t[f>>2]=gAi[t[135744>>2]&511](48)|0;if(!(t[f>>2]|0)){Ut(0,128904);t[r>>2]=0;u=t[r>>2]|0;s=i;return u|0}e=(t[f>>2]|0)+0|0;a=e+48|0;do{t[e>>2]=0;e=e+4|0}while((e|0)<(a|0));t[t[f>>2]>>2]=4;if(t[n>>2]|0){e=Yl(t[n>>2]|0)|0;t[(t[f>>2]|0)+24>>2]=e}else{e=Yl(128928)|0;t[(t[f>>2]|0)+24>>2]=e}t[r>>2]=t[f>>2];u=t[r>>2]|0;s=i;return u|0}function ef(e){e=e|0;var i=0,r=0,n=0,f=0,u=0,a=0;i=s;s=s+16|0;r=i+8|0;n=i+4|0;f=i;t[n>>2]=e;t[f>>2]=gAi[t[135744>>2]&511](48)|0;if(!(t[f>>2]|0)){Ut(0,128904);t[r>>2]=0;u=t[r>>2]|0;s=i;return u|0}else{e=(t[f>>2]|0)+0|0;a=e+48|0;do{t[e>>2]=0;e=e+4|0}while((e|0)<(a|0));t[t[f>>2]>>2]=4;t[(t[f>>2]|0)+24>>2]=t[n>>2];t[r>>2]=t[f>>2];u=t[r>>2]|0;s=i;return u|0}return 0}function rf(e){e=e|0;var i=0,r=0,n=0,f=0,u=0,a=0;i=s;s=s+16|0;r=i+8|0;n=i+4|0;f=i;t[n>>2]=e;t[f>>2]=gAi[t[135744>>2]&511](48)|0;if(!(t[f>>2]|0)){Ut(0,128904);t[r>>2]=0;u=t[r>>2]|0;s=i;return u|0}else{e=(t[f>>2]|0)+0|0;a=e+48|0;do{t[e>>2]=0;e=e+4|0}while((e|0)<(a|0));t[t[f>>2]>>2]=4;e=Yl(t[n>>2]|0)|0;t[(t[f>>2]|0)+24>>2]=e;t[r>>2]=t[f>>2];u=t[r>>2]|0;s=i;return u|0}return 0}function nf(e){e=e|0;var i=0,r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0;i=s;s=s+32|0;r=i;n=i+16|0;f=i+12|0;u=i+8|0;a=i+4|0;t[f>>2]=e;if(!(t[f>>2]|0)){t[n>>2]=0;o=t[n>>2]|0;s=i;return o|0}t[u>>2]=gAi[t[135744>>2]&511](48)|0;if(!(t[u>>2]|0)){Ut(0,128936);t[n>>2]=0;o=t[n>>2]|0;s=i;return o|0}e=(t[u>>2]|0)+0|0;c=(t[f>>2]|0)+0|0;l=e+48|0;do{t[e>>2]=t[c>>2];e=e+4|0;c=c+4|0}while((e|0)<(l|0));switch(t[t[f>>2]>>2]|0){case 9:case 1:{c=Pn(0,t[(t[f>>2]|0)+4>>2]|0)|0;t[(t[u>>2]|0)+4>>2]=c;t[(t[u>>2]|0)+8>>2]=0;break}case 0:{c=t[33976]|0;e=t[33980]|0;t[r>>2]=t[t[f>>2]>>2];yAi[c&511](e,128952,r);break}case 7:{t[a>>2]=t[(t[f>>2]|0)+28>>2];r=Pa(0,t[a>>2]|0)|0;t[(t[u>>2]|0)+28>>2]=r;break}case 8:{t[(t[u>>2]|0)+28>>2]=t[(t[f>>2]|0)+28>>2];break}case 4:{r=Yl(t[(t[f>>2]|0)+24>>2]|0)|0;t[(t[u>>2]|0)+24>>2]=r;break}default:{}}t[n>>2]=t[u>>2];o=t[n>>2]|0;s=i;return o|0}function ff(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i+4|0;n=i;t[r>>2]=e;if(t[r>>2]|0)t[n>>2]=Yl(129e3)|0;else t[n>>2]=Yl(129008)|0;s=i;return t[n>>2]|0}function tf(e){e=+e;var i=0,r=0,f=0,u=0,a=0;i=s;s=s+112|0;r=i;f=i+8|0;u=i+12|0;l[r>>3]=e;a=wn(+l[r>>3])|0;do if((a|0)==1)t[f>>2]=Yl(129016)|0;else if((a|0)==-1)t[f>>2]=Yl(129032)|0;else{if(hn(+l[r>>3])|0){t[f>>2]=Yl(129048)|0;break}if(+l[r>>3]==0?(Bt(+l[r>>3])|0)!=0:0){t[f>>2]=Yl(129056)|0;break}qt(+l[r>>3],u,99);n[u+99>>0]=0;t[f>>2]=Yl(u)|0}while(0);s=i;return t[f>>2]|0}function uf(e){e=e|0;var i=0,r=0,n=0,f=0;i=s;s=s+16|0;r=i+4|0;n=i;t[n>>2]=e;if(((t[n>>2]|0)!=0?(t[t[n>>2]>>2]|0)!=0:0)?(t[(t[n>>2]|0)+8>>2]|0)!=0:0){if((t[t[n>>2]>>2]|0)>1)Mn(t[n>>2]|0);t[r>>2]=xn(t[t[(t[n>>2]|0)+8>>2]>>2]|0)|0;f=t[r>>2]|0;s=i;return f|0}t[r>>2]=Yl(128928)|0;f=t[r>>2]|0;s=i;return f|0}function af(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i;n=i+8|0;t[n>>2]=e;if(t[n>>2]|0)l[r>>3]=1;else l[r>>3]=0;s=i;return+ +l[r>>3]}function of(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i;t[r>>2]=e;n=+cf(t[r>>2]|0);s=i;return+n}function cf(e){e=e|0;var i=0,r=0,n=0,f=0,a=0,o=0,c=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0,S=0,g=0,y=0,F=0;i=s;s=s+80|0;r=i+24|0;n=i+64|0;f=i+60|0;a=i+16|0;o=i+56|0;c=i+52|0;b=i+48|0;k=i+44|0;h=i+40|0;w=i+8|0;d=i+36|0;v=i+32|0;m=i;t[n>>2]=e;t[f>>2]=t[n>>2];t[o>>2]=0;t[c>>2]=0;t[b>>2]=0;t[k>>2]=0;t[h>>2]=0;if(!(t[f>>2]|0)){l[r>>3]=0;_=+l[r>>3];s=i;return+_}while(1){do if((u[t[f>>2]>>0]|0|0)==32)p=1;else{if(9<=(u[t[f>>2]>>0]|0|0)?(u[t[f>>2]>>0]|0|0)<=10:0){p=1;break}p=(u[t[f>>2]>>0]|0|0)==13}while(0);E=t[f>>2]|0;if(!p)break;t[f>>2]=E+1}do if((u[E>>0]|0|0)!=46){if((u[t[f>>2]>>0]|0|0)>=48?(u[t[f>>2]>>0]|0|0)<=57:0)break;if((u[t[f>>2]>>0]|0|0)!=45){l[r>>3]=+l[15984];_=+l[r>>3];s=i;return+_}}while(0);if((u[t[f>>2]>>0]|0|0)==45){t[c>>2]=1;t[f>>2]=(t[f>>2]|0)+1}l[a>>3]=0;while(1){if((u[t[f>>2]>>0]|0|0)<48)break;if((u[t[f>>2]>>0]|0|0)>57)break;l[a>>3]=+l[a>>3]*10;t[h>>2]=(u[t[f>>2]>>0]|0)-48;t[o>>2]=1;t[f>>2]=(t[f>>2]|0)+1;l[w>>3]=+((t[h>>2]|0)>>>0);l[a>>3]=+l[a>>3]+ +l[w>>3]}e:do if((u[t[f>>2]>>0]|0|0)==46){t[v>>2]=0;l[m>>3]=0;t[f>>2]=(t[f>>2]|0)+1;if((u[t[f>>2]>>0]|0|0)<48){if(!(t[o>>2]|0))S=24}else if(!((t[o>>2]|0)!=0?1:(u[t[f>>2]>>0]|0|0)<=57))S=24;if((S|0)==24){l[r>>3]=+l[15984];_=+l[r>>3];s=i;return+_}while(1){if((u[t[f>>2]>>0]|0|0)<48)break;if(!((t[v>>2]|0)<20?(u[t[f>>2]>>0]|0|0)<=57:0))break;t[d>>2]=(u[t[f>>2]>>0]|0)-48;l[m>>3]=+l[m>>3]*10+ +(t[d>>2]|0);t[v>>2]=(t[v>>2]|0)+1;t[f>>2]=(t[f>>2]|0)+1}l[m>>3]=+l[m>>3]/+l[129232+(t[v>>2]<<3)>>3];l[a>>3]=+l[a>>3]+ +l[m>>3];while(1){if((u[t[f>>2]>>0]|0|0)<48)break e;if((u[t[f>>2]>>0]|0|0)>57)break e;t[f>>2]=(t[f>>2]|0)+1}}while(0);if(!((u[t[f>>2]>>0]|0|0)!=101?(u[t[f>>2]>>0]|0|0)!=69:0))S=34;e:do if((S|0)==34){t[f>>2]=(t[f>>2]|0)+1;if((u[t[f>>2]>>0]|0|0)!=45){if((u[t[f>>2]>>0]|0|0)==43)t[f>>2]=(t[f>>2]|0)+1}else{t[k>>2]=1;t[f>>2]=(t[f>>2]|0)+1}while(1){if((u[t[f>>2]>>0]|0|0)<48)break e;if((u[t[f>>2]>>0]|0|0)>57)break e;t[b>>2]=((t[b>>2]|0)*10|0)+((u[t[f>>2]>>0]|0)-48);t[f>>2]=(t[f>>2]|0)+1}}while(0);while(1){do if((u[t[f>>2]>>0]|0|0)==32)g=1;else{if(9<=(u[t[f>>2]>>0]|0|0)?(u[t[f>>2]>>0]|0|0)<=10:0){g=1;break}g=(u[t[f>>2]>>0]|0|0)==13}while(0);y=t[f>>2]|0;if(!g)break;t[f>>2]=y+1}if(u[y>>0]|0){l[r>>3]=+l[15984];_=+l[r>>3];s=i;return+_}if(t[c>>2]|0)l[a>>3]=-+l[a>>3];if(t[k>>2]|0)t[b>>2]=0-(t[b>>2]|0);F=+K(10,+ +(t[b>>2]|0));l[a>>3]=+l[a>>3]*F;l[r>>3]=+l[a>>3];_=+l[r>>3];s=i;return+_}function lf(e){e=e|0;var i=0,r=0,n=0,f=0,u=0,a=0;i=s;s=s+32|0;r=i+8|0;n=i+20|0;f=i+16|0;u=i;t[n>>2]=e;if(!(t[n>>2]|0)){l[r>>3]=+l[15984];a=+l[r>>3];s=i;return+a}t[f>>2]=xn(t[n>>2]|0)|0;if(!(t[f>>2]|0)){l[r>>3]=+l[15984];a=+l[r>>3];s=i;return+a}else{l[u>>3]=+of(t[f>>2]|0);pAi[t[135736>>2]&511](t[f>>2]|0);l[r>>3]=+l[u>>3];a=+l[r>>3];s=i;return+a}return+0}function sf(e){e=e|0;var i=0,r=0,n=0,f=0,u=0,a=0;i=s;s=s+32|0;r=i+8|0;n=i+20|0;f=i+16|0;u=i;t[n>>2]=e;if(!(t[n>>2]|0)){l[r>>3]=+l[15984];a=+l[r>>3];s=i;return+a}else{t[f>>2]=uf(t[n>>2]|0)|0;l[u>>3]=+of(t[f>>2]|0);pAi[t[135736>>2]&511](t[f>>2]|0);l[r>>3]=+l[u>>3];a=+l[r>>3];s=i;return+a}return+0}function bf(e){e=+e;var i=0,r=0,n=0,f=0,u=0;i=s;s=s+16|0;r=i+8|0;n=i;l[n>>3]=e;f=(hn(+l[n>>3])|0)!=0;if(f|+l[n>>3]==0){t[r>>2]=0;u=t[r>>2]|0;s=i;return u|0}else{t[r>>2]=1;u=t[r>>2]|0;s=i;return u|0}return 0}function kf(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i+4|0;n=i;t[n>>2]=e;if((t[n>>2]|0)!=0?(rs(t[n>>2]|0)|0)!=0:0)t[r>>2]=1;else t[r>>2]=0;s=i;return t[r>>2]|0}function hf(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i+4|0;n=i;t[n>>2]=e;if((t[n>>2]|0)!=0?(t[t[n>>2]>>2]|0)!=0:0)t[r>>2]=1;else t[r>>2]=0;s=i;return t[r>>2]|0}function wf(e){e=e|0;var i=0,r=0,n=0,f=0,u=0;i=s;s=s+16|0;r=i+8|0;n=i+4|0;f=i;t[n>>2]=e;t[f>>2]=gAi[t[135744>>2]&511](204)|0;if(!(t[f>>2]|0)){Ut(0,129096);t[r>>2]=0;u=t[r>>2]|0;s=i;return u|0}else{VY(t[f>>2]|0,0,204)|0;t[t[f>>2]>>2]=t[n>>2];t[(t[f>>2]|0)+4>>2]=0;t[(t[f>>2]|0)+16>>2]=0;t[(t[f>>2]|0)+20>>2]=0;t[(t[f>>2]|0)+24>>2]=0;t[(t[f>>2]|0)+28>>2]=0;n=WF(0)|0;t[(t[f>>2]|0)+40>>2]=n;t[(t[f>>2]|0)+44>>2]=0;t[(t[f>>2]|0)+48>>2]=0;t[(t[f>>2]|0)+52>>2]=0;t[(t[f>>2]|0)+88>>2]=0;t[(t[f>>2]|0)+64>>2]=0;t[(t[f>>2]|0)+68>>2]=-1;t[(t[f>>2]|0)+72>>2]=-1;df(t[f>>2]|0);t[r>>2]=t[f>>2];u=t[r>>2]|0;s=i;return u|0}return 0}function df(e){e=e|0;var i=0,r=0;i=s;s=s+16|0;r=i;t[r>>2]=e;Un(t[r>>2]|0,129592,261)|0;Un(t[r>>2]|0,129600,262)|0;Un(t[r>>2]|0,129608,263)|0;Un(t[r>>2]|0,129616,264)|0;Un(t[r>>2]|0,129624,265)|0;Un(t[r>>2]|0,129640,266)|0;Un(t[r>>2]|0,129008,267)|0;Un(t[r>>2]|0,129648,268)|0;Un(t[r>>2]|0,129656,269)|0;Un(t[r>>2]|0,129664,270)|0;Un(t[r>>2]|0,129672,271)|0;Un(t[r>>2]|0,129688,272)|0;Un(t[r>>2]|0,129696,273)|0;Un(t[r>>2]|0,129704,274)|0;Un(t[r>>2]|0,129720,275)|0;Un(t[r>>2]|0,129736,276)|0;Un(t[r>>2]|0,129744,277)|0;Un(t[r>>2]|0,129760,278)|0;Un(t[r>>2]|0,129768,279)|0;Un(t[r>>2]|0,129776,280)|0;Un(t[r>>2]|0,129792,281)|0;Un(t[r>>2]|0,129808,282)|0;Un(t[r>>2]|0,129824,283)|0;Un(t[r>>2]|0,129848,284)|0;Un(t[r>>2]|0,129864,285)|0;Un(t[r>>2]|0,129e3,286)|0;Un(t[r>>2]|0,129872,287)|0;zn(t[r>>2]|0,129888,129904,288)|0;s=i;return}function vf(e){e=e|0;var i=0,r=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if(!(t[r>>2]|0)){s=i;return}if(t[(t[r>>2]|0)+200>>2]|0)xt(t[(t[r>>2]|0)+200>>2]|0);Zn(t[r>>2]|0);qn(t[r>>2]|0);Wn(t[r>>2]|0);lp((t[r>>2]|0)+136|0);pAi[t[135736>>2]&511](t[r>>2]|0);s=i;return}function mf(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0;r=s;s=s+16|0;n=r+12|0;f=r+8|0;u=r+4|0;a=r;t[f>>2]=e;t[u>>2]=i;t[a>>2]=gAi[t[135744>>2]&511](48)|0;if(!(t[a>>2]|0)){Ut(t[u>>2]|0,129120);t[n>>2]=0;o=t[n>>2]|0;s=r;return o|0}i=(t[a>>2]|0)+0|0;e=i+48|0;do{t[i>>2]=0;i=i+4|0}while((i|0)<(e|0));i=t[f>>2]|0;t[(t[a>>2]|0)+4>>2]=i;t[t[a>>2]>>2]=i;t[(t[a>>2]|0)+12>>2]=t[u>>2];i=Wt()|0;t[(t[a>>2]|0)+32>>2]=i;if(!(t[(t[a>>2]|0)+32>>2]|0)){pAi[t[135736>>2]&511](t[(t[a>>2]|0)+28>>2]|0);pAi[t[135736>>2]&511](t[a>>2]|0);t[n>>2]=0;o=t[n>>2]|0;s=r;return o|0}if((t[u>>2]|0)!=0?(t[(t[u>>2]|0)+192>>2]|0)!=0:0){t[(t[(t[a>>2]|0)+32>>2]|0)+20>>2]=t[(t[u>>2]|0)+192>>2];sz(t[(t[(t[a>>2]|0)+32>>2]|0)+20>>2]|0)|0}t[n>>2]=t[a>>2];o=t[n>>2]|0;s=r;return o|0}function _f(e){e=e|0;var i=0,r=0,n=0,f=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if(t[(t[r>>2]|0)+28>>2]|0)pAi[t[135736>>2]&511](t[(t[r>>2]|0)+28>>2]|0);if(!(t[(t[r>>2]|0)+32>>2]|0)){n=t[33934]|0;f=t[r>>2]|0;pAi[n&511](f);s=i;return}if(t[(t[(t[r>>2]|0)+32>>2]|0)+24>>2]|0){mj(t[(t[(t[r>>2]|0)+32>>2]|0)+24>>2]|0);t[(t[(t[r>>2]|0)+32>>2]|0)+24>>2]=0}mn(t[(t[r>>2]|0)+32>>2]|0);n=t[33934]|0;f=t[r>>2]|0;pAi[n&511](f);s=i;return}function pf(e){e=e|0;var i=0,r=0,n=0,f=0,u=0,a=0,o=0,c=0,b=0,k=0;i=s;s=s+32|0;r=i;n=i+28|0;f=i+24|0;u=i+20|0;a=i+16|0;o=i+12|0;c=i+8|0;t[f>>2]=e;t[c>>2]=0;if((t[f>>2]|0)!=0?(t[(t[f>>2]|0)+12>>2]|0)!=0:0){t[a>>2]=En(t[f>>2]|0)|0;t[u>>2]=En(t[f>>2]|0)|0;e=t[u>>2]|0;if((t[u>>2]|0)==0|(t[a>>2]|0)==0){b=t[(t[f>>2]|0)+12>>2]|0;if(e)zt(b,t[u>>2]|0);else zt(b,t[a>>2]|0);dn(t[f>>2]|0,10);t[n>>2]=0;k=t[n>>2]|0;s=i;return k|0}if((e|0)==(t[a>>2]|0)){_n(t[u>>2]|0);t[n>>2]=1;k=t[n>>2]|0;s=i;return k|0}if((((t[t[a>>2]>>2]|0)!=1?(t[t[a>>2]>>2]|0)!=9:0)?(t[t[u>>2]>>2]|0)!=1:0)?(t[t[u>>2]>>2]|0)!=9:0){t[n>>2]=Jt(t[f>>2]|0,t[u>>2]|0,t[a>>2]|0)|0;k=t[n>>2]|0;s=i;return k|0}if((t[t[u>>2]>>2]|0)!=1?(t[t[u>>2]>>2]|0)!=9:0){t[o>>2]=t[a>>2];t[a>>2]=t[u>>2];t[u>>2]=t[o>>2]}switch(t[t[a>>2]>>2]|0){case 2:{if((t[(t[u>>2]|0)+4>>2]|0)!=0?(t[t[(t[u>>2]|0)+4>>2]>>2]|0)!=0:0)t[c>>2]=1;else t[c>>2]=0;t[c>>2]=(t[c>>2]|0)==(t[(t[a>>2]|0)+8>>2]|0)&1;break}case 3:{t[c>>2]=Xt(t[f>>2]|0,t[u>>2]|0,+l[(t[a>>2]|0)+16>>3],0)|0;break}case 4:{t[c>>2]=Zt(t[u>>2]|0,t[(t[a>>2]|0)+24>>2]|0,0)|0;break}case 6:case 5:case 8:case 7:{o=t[33976]|0;e=t[33980]|0;t[r>>2]=128552;t[r+4>>2]=7204;yAi[o&511](e,129064,r);
	break}case 9:case 1:{t[c>>2]=Kt(t[u>>2]|0,t[a>>2]|0,0)|0;break}default:{}}zt(t[(t[f>>2]|0)+12>>2]|0,t[u>>2]|0);zt(t[(t[f>>2]|0)+12>>2]|0,t[a>>2]|0);t[n>>2]=t[c>>2];k=t[n>>2]|0;s=i;return k|0}t[n>>2]=0;k=t[n>>2]|0;s=i;return k|0}function Ef(e){e=e|0;var i=0,r=0,n=0,f=0,u=0,a=0,o=0,c=0,b=0,k=0;i=s;s=s+32|0;r=i;n=i+28|0;f=i+24|0;u=i+20|0;a=i+16|0;o=i+12|0;c=i+8|0;t[f>>2]=e;t[c>>2]=0;if((t[f>>2]|0)!=0?(t[(t[f>>2]|0)+12>>2]|0)!=0:0){t[a>>2]=En(t[f>>2]|0)|0;t[u>>2]=En(t[f>>2]|0)|0;e=t[u>>2]|0;if((t[u>>2]|0)==0|(t[a>>2]|0)==0){b=t[(t[f>>2]|0)+12>>2]|0;if(e)zt(b,t[u>>2]|0);else zt(b,t[a>>2]|0);dn(t[f>>2]|0,10);t[n>>2]=0;k=t[n>>2]|0;s=i;return k|0}if((e|0)==(t[a>>2]|0)){zt(t[(t[f>>2]|0)+12>>2]|0,t[u>>2]|0);t[n>>2]=0;k=t[n>>2]|0;s=i;return k|0}if((((t[t[a>>2]>>2]|0)!=1?(t[t[a>>2]>>2]|0)!=9:0)?(t[t[u>>2]>>2]|0)!=1:0)?(t[t[u>>2]>>2]|0)!=9:0){t[n>>2]=((Jt(t[f>>2]|0,t[u>>2]|0,t[a>>2]|0)|0)!=0^1)&1;k=t[n>>2]|0;s=i;return k|0}if((t[t[u>>2]>>2]|0)!=1?(t[t[u>>2]>>2]|0)!=9:0){t[o>>2]=t[a>>2];t[a>>2]=t[u>>2];t[u>>2]=t[o>>2]}switch(t[t[a>>2]>>2]|0){case 2:{if((t[(t[u>>2]|0)+4>>2]|0)!=0?(t[t[(t[u>>2]|0)+4>>2]>>2]|0)!=0:0)t[c>>2]=1;else t[c>>2]=0;t[c>>2]=(t[c>>2]|0)!=(t[(t[a>>2]|0)+8>>2]|0)&1;break}case 4:{t[c>>2]=Zt(t[u>>2]|0,t[(t[a>>2]|0)+24>>2]|0,1)|0;break}case 3:{t[c>>2]=Xt(t[f>>2]|0,t[u>>2]|0,+l[(t[a>>2]|0)+16>>3],1)|0;break}case 6:case 5:case 8:case 7:{o=t[33976]|0;e=t[33980]|0;t[r>>2]=128552;t[r+4>>2]=7289;yAi[o&511](e,129064,r);break}case 9:case 1:{t[c>>2]=Kt(t[u>>2]|0,t[a>>2]|0,1)|0;break}default:{}}zt(t[(t[f>>2]|0)+12>>2]|0,t[u>>2]|0);zt(t[(t[f>>2]|0)+12>>2]|0,t[a>>2]|0);t[n>>2]=t[c>>2];k=t[n>>2]|0;s=i;return k|0}t[n>>2]=0;k=t[n>>2]|0;s=i;return k|0}function Sf(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,b=0,k=0,h=0,w=0,d=0,v=0;n=s;s=s+48|0;f=n+32|0;u=n+28|0;a=n+24|0;o=n+20|0;c=n+16|0;b=n+12|0;k=n+8|0;h=n+4|0;w=n;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;t[c>>2]=0;t[b>>2]=0;t[k>>2]=0;if((t[u>>2]|0)!=0?(t[(t[u>>2]|0)+12>>2]|0)!=0:0){t[w>>2]=En(t[u>>2]|0)|0;t[h>>2]=En(t[u>>2]|0)|0;if((t[h>>2]|0)==0|(t[w>>2]|0)==0){r=t[(t[u>>2]|0)+12>>2]|0;if(t[h>>2]|0)zt(r,t[h>>2]|0);else zt(r,t[w>>2]|0);dn(t[u>>2]|0,10);t[f>>2]=0;d=t[f>>2]|0;s=n;return d|0}if((((t[t[w>>2]>>2]|0)!=1?(t[t[w>>2]>>2]|0)!=9:0)?(t[t[h>>2]>>2]|0)!=1:0)?(t[t[h>>2]>>2]|0)!=9:0){if((t[t[h>>2]>>2]|0)!=3){Sn(t[u>>2]|0,t[h>>2]|0)|0;gf(t[u>>2]|0,1);t[h>>2]=En(t[u>>2]|0)|0}if((t[t[h>>2]>>2]|0)!=3){_n(t[h>>2]|0);_n(t[w>>2]|0);dn(t[u>>2]|0,10);t[f>>2]=0;d=t[f>>2]|0;s=n;return d|0}if((t[t[w>>2]>>2]|0)!=3){Sn(t[u>>2]|0,t[w>>2]|0)|0;gf(t[u>>2]|0,1);t[w>>2]=En(t[u>>2]|0)|0}if((t[t[w>>2]>>2]|0)!=3){zt(t[(t[u>>2]|0)+12>>2]|0,t[h>>2]|0);zt(t[(t[u>>2]|0)+12>>2]|0,t[w>>2]|0);dn(t[u>>2]|0,10);t[f>>2]=0;d=t[f>>2]|0;s=n;return d|0}e:do if((hn(+l[(t[h>>2]|0)+16>>3])|0)==0?(hn(+l[(t[w>>2]|0)+16>>3])|0)==0:0){t[b>>2]=wn(+l[(t[h>>2]|0)+16>>3])|0;t[k>>2]=wn(+l[(t[w>>2]|0)+16>>3])|0;if((t[a>>2]|0)!=0&(t[o>>2]|0)!=0){do if(!((t[b>>2]|0)==-1&(t[k>>2]|0)!=-1)){if((t[k>>2]|0)==1&(t[b>>2]|0)!=1)break;if((t[b>>2]|0)==0&(t[k>>2]|0)==0){t[c>>2]=+l[(t[h>>2]|0)+16>>3]<+l[(t[w>>2]|0)+16>>3]&1;break e}else{t[c>>2]=0;break e}}while(0);t[c>>2]=1;break}if(!((t[a>>2]|0)==0|(t[o>>2]|0)!=0)){if((t[b>>2]|0)==-1|(t[k>>2]|0)==1){t[c>>2]=1;break}if((t[b>>2]|0)==0&(t[k>>2]|0)==0){t[c>>2]=+l[(t[h>>2]|0)+16>>3]<=+l[(t[w>>2]|0)+16>>3]&1;break}else{t[c>>2]=0;break}}if(!((t[a>>2]|0)==0&(t[o>>2]|0)!=0)){if((t[a>>2]|0)!=0|(t[o>>2]|0)!=0)break;if((t[b>>2]|0)==1|(t[k>>2]|0)==-1){t[c>>2]=1;break}if((t[b>>2]|0)==0&(t[k>>2]|0)==0){t[c>>2]=+l[(t[h>>2]|0)+16>>3]>=+l[(t[w>>2]|0)+16>>3]&1;break}else{t[c>>2]=0;break}}else{do if(!((t[b>>2]|0)==1&(t[k>>2]|0)!=1)){if((t[k>>2]|0)==-1&(t[b>>2]|0)!=-1)break;if((t[b>>2]|0)==0&(t[k>>2]|0)==0){t[c>>2]=+l[(t[h>>2]|0)+16>>3]>+l[(t[w>>2]|0)+16>>3]&1;break e}else{t[c>>2]=0;break e}}while(0);t[c>>2]=1;break}}else v=33;while(0);if((v|0)==33)t[c>>2]=0;zt(t[(t[u>>2]|0)+12>>2]|0,t[h>>2]|0);zt(t[(t[u>>2]|0)+12>>2]|0,t[w>>2]|0);t[f>>2]=t[c>>2];d=t[f>>2]|0;s=n;return d|0}if((t[t[w>>2]>>2]|0)!=1?(t[t[w>>2]>>2]|0)!=9:0)v=18;else v=15;do if((v|0)==15){if((t[t[h>>2]>>2]|0)!=1?(t[t[h>>2]>>2]|0)!=9:0){v=18;break}t[c>>2]=Qt(t[a>>2]|0,t[o>>2]|0,t[h>>2]|0,t[w>>2]|0)|0}while(0);do if((v|0)==18){if((t[t[h>>2]>>2]|0)!=1?(t[t[h>>2]>>2]|0)!=9:0){t[c>>2]=$t(t[u>>2]|0,((t[a>>2]|0)!=0^1)&1,t[o>>2]|0,t[w>>2]|0,t[h>>2]|0)|0;break}t[c>>2]=$t(t[u>>2]|0,t[a>>2]|0,t[o>>2]|0,t[h>>2]|0,t[w>>2]|0)|0}while(0);t[f>>2]=t[c>>2];d=t[f>>2]|0;s=n;return d|0}t[f>>2]=0;d=t[f>>2]|0;s=n;return d|0}function gf(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0;r=s;s=s+32|0;n=r+20|0;f=r+16|0;u=r+12|0;a=r;o=r+8|0;t[n>>2]=e;t[f>>2]=i;if(!(t[n>>2]|0)){s=r;return}i=t[n>>2]|0;if(!(t[f>>2]|0)){e=t[n>>2]|0;if(!(t[(t[i+12>>2]|0)+4>>2]|0)){Sn(e,eu(t[(t[n>>2]|0)+12>>2]|0,0)|0)|0;s=r;return}else{t[o>>2]=sF(t[(t[e+12>>2]|0)+4>>2]|0)|0;l[a>>3]=+cf(t[o>>2]|0);e=t[n>>2]|0;Sn(e,eu(t[(t[n>>2]|0)+12>>2]|0,+l[a>>3])|0)|0;pAi[t[135736>>2]&511](t[o>>2]|0);s=r;return}}if(!i){s=r;return}i=t[n>>2]|0;if((t[f>>2]|0)!=1){dn(i,12);s=r;return}f=t[n>>2]|0;if((t[i+20>>2]|0)<((t[(t[n>>2]|0)+44>>2]|0)+1|0)){dn(f,23);s=r;return}else{t[u>>2]=En(f)|0;f=t[n>>2]|0;Sn(f,iu(t[(t[n>>2]|0)+12>>2]|0,t[u>>2]|0)|0)|0;s=r;return}}function yf(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if(!(t[r>>2]|0)){s=i;return}if(!(t[(t[r>>2]|0)+12>>2]|0)){s=i;return}if((t[(t[r>>2]|0)+16>>2]|0)!=0?(t[t[(t[r>>2]|0)+16>>2]>>2]|0)!=3:0)gf(t[r>>2]|0,1);if((t[(t[r>>2]|0)+16>>2]|0)!=0?(t[t[(t[r>>2]|0)+16>>2]>>2]|0)==3:0){if(hn(+l[(t[(t[r>>2]|0)+16>>2]|0)+16>>3])|0){l[(t[(t[r>>2]|0)+16>>2]|0)+16>>3]=+l[15984];s=i;return}if((wn(+l[(t[(t[r>>2]|0)+16>>2]|0)+16>>3])|0)==1){l[(t[(t[r>>2]|0)+16>>2]|0)+16>>3]=+l[15986];s=i;return}if((wn(+l[(t[(t[r>>2]|0)+16>>2]|0)+16>>3])|0)==-1){l[(t[(t[r>>2]|0)+16>>2]|0)+16>>3]=+l[15985];s=i;return}n=+l[(t[(t[r>>2]|0)+16>>2]|0)+16>>3];if(!(+l[(t[(t[r>>2]|0)+16>>2]|0)+16>>3]==0)){l[(t[(t[r>>2]|0)+16>>2]|0)+16>>3]=-n;s=i;return}if(!(Bt(n)|0)){l[(t[(t[r>>2]|0)+16>>2]|0)+16>>3]=+l[15988];s=i;return}else{l[(t[(t[r>>2]|0)+16>>2]|0)+16>>3]=0;s=i;return}}dn(t[r>>2]|0,11);s=i;return}function Ff(e){e=e|0;var i=0,r=0,n=0,f=0;i=s;s=s+16|0;r=i+12|0;n=i+8|0;f=i;t[r>>2]=e;t[n>>2]=En(t[r>>2]|0)|0;if(!(t[n>>2]|0)){dn(t[r>>2]|0,10);s=i;return}l[f>>3]=+Fn(t[n>>2]|0);zt(t[(t[r>>2]|0)+12>>2]|0,t[n>>2]|0);if((t[(t[r>>2]|0)+16>>2]|0)!=0?(t[t[(t[r>>2]|0)+16>>2]>>2]|0)!=3:0)gf(t[r>>2]|0,1);if((t[(t[r>>2]|0)+16>>2]|0)!=0?(t[t[(t[r>>2]|0)+16>>2]>>2]|0)==3:0){n=(t[(t[r>>2]|0)+16>>2]|0)+16|0;l[n>>3]=+l[n>>3]+ +l[f>>3];s=i;return}dn(t[r>>2]|0,11);s=i;return}function Of(e){e=e|0;var i=0,r=0,n=0,f=0;i=s;s=s+16|0;r=i+12|0;n=i+8|0;f=i;t[r>>2]=e;t[n>>2]=En(t[r>>2]|0)|0;if(!(t[n>>2]|0)){dn(t[r>>2]|0,10);s=i;return}l[f>>3]=+Fn(t[n>>2]|0);zt(t[(t[r>>2]|0)+12>>2]|0,t[n>>2]|0);if((t[(t[r>>2]|0)+16>>2]|0)!=0?(t[t[(t[r>>2]|0)+16>>2]>>2]|0)!=3:0)gf(t[r>>2]|0,1);if((t[(t[r>>2]|0)+16>>2]|0)!=0?(t[t[(t[r>>2]|0)+16>>2]>>2]|0)==3:0){n=(t[(t[r>>2]|0)+16>>2]|0)+16|0;l[n>>3]=+l[n>>3]-+l[f>>3];s=i;return}dn(t[r>>2]|0,11);s=i;return}function Af(e){e=e|0;var i=0,r=0,n=0,f=0;i=s;s=s+16|0;r=i+12|0;n=i+8|0;f=i;t[r>>2]=e;t[n>>2]=En(t[r>>2]|0)|0;if(!(t[n>>2]|0)){dn(t[r>>2]|0,10);s=i;return}l[f>>3]=+Fn(t[n>>2]|0);zt(t[(t[r>>2]|0)+12>>2]|0,t[n>>2]|0);if((t[(t[r>>2]|0)+16>>2]|0)!=0?(t[t[(t[r>>2]|0)+16>>2]>>2]|0)!=3:0)gf(t[r>>2]|0,1);if((t[(t[r>>2]|0)+16>>2]|0)!=0?(t[t[(t[r>>2]|0)+16>>2]>>2]|0)==3:0){n=(t[(t[r>>2]|0)+16>>2]|0)+16|0;l[n>>3]=+l[n>>3]*+l[f>>3];s=i;return}dn(t[r>>2]|0,11);s=i;return}function Mf(e){e=e|0;var i=0,r=0,n=0,f=0;i=s;s=s+16|0;r=i+12|0;n=i+8|0;f=i;t[r>>2]=e;t[n>>2]=En(t[r>>2]|0)|0;if(!(t[n>>2]|0)){dn(t[r>>2]|0,10);s=i;return}l[f>>3]=+Fn(t[n>>2]|0);zt(t[(t[r>>2]|0)+12>>2]|0,t[n>>2]|0);if((t[(t[r>>2]|0)+16>>2]|0)!=0?(t[t[(t[r>>2]|0)+16>>2]>>2]|0)!=3:0)gf(t[r>>2]|0,1);if((t[(t[r>>2]|0)+16>>2]|0)!=0?(t[t[(t[r>>2]|0)+16>>2]>>2]|0)==3:0){if((hn(+l[f>>3])|0)==0?(hn(+l[(t[(t[r>>2]|0)+16>>2]|0)+16>>3])|0)==0:0){if(+l[f>>3]==0?(Bt(+l[f>>3])|0)!=0:0){if(+l[(t[(t[r>>2]|0)+16>>2]|0)+16>>3]==0){l[(t[(t[r>>2]|0)+16>>2]|0)+16>>3]=+l[15984];s=i;return}if(+l[(t[(t[r>>2]|0)+16>>2]|0)+16>>3]>0){l[(t[(t[r>>2]|0)+16>>2]|0)+16>>3]=+l[15986];s=i;return}if(!(+l[(t[(t[r>>2]|0)+16>>2]|0)+16>>3]<0)){s=i;return}l[(t[(t[r>>2]|0)+16>>2]|0)+16>>3]=+l[15985];s=i;return}if(!(+l[f>>3]==0)){n=(t[(t[r>>2]|0)+16>>2]|0)+16|0;l[n>>3]=+l[n>>3]/+l[f>>3];s=i;return}if(+l[(t[(t[r>>2]|0)+16>>2]|0)+16>>3]==0){l[(t[(t[r>>2]|0)+16>>2]|0)+16>>3]=+l[15984];s=i;return}if(+l[(t[(t[r>>2]|0)+16>>2]|0)+16>>3]>0){l[(t[(t[r>>2]|0)+16>>2]|0)+16>>3]=+l[15985];s=i;return}if(!(+l[(t[(t[r>>2]|0)+16>>2]|0)+16>>3]<0)){s=i;return}l[(t[(t[r>>2]|0)+16>>2]|0)+16>>3]=+l[15986];s=i;return}l[(t[(t[r>>2]|0)+16>>2]|0)+16>>3]=+l[15984];s=i;return}dn(t[r>>2]|0,11);s=i;return}function Rf(e){e=e|0;var i=0,r=0,n=0,f=0,u=0,a=0;i=s;s=s+32|0;r=i+20|0;n=i+16|0;f=i+8|0;u=i;t[r>>2]=e;t[n>>2]=En(t[r>>2]|0)|0;if(!(t[n>>2]|0)){dn(t[r>>2]|0,10);s=i;return}l[u>>3]=+Fn(t[n>>2]|0);zt(t[(t[r>>2]|0)+12>>2]|0,t[n>>2]|0);if((t[(t[r>>2]|0)+16>>2]|0)!=0?(t[t[(t[r>>2]|0)+16>>2]>>2]|0)!=3:0)gf(t[r>>2]|0,1);if((t[(t[r>>2]|0)+16>>2]|0)!=0?(t[t[(t[r>>2]|0)+16>>2]>>2]|0)==3:0){l[f>>3]=+l[(t[(t[r>>2]|0)+16>>2]|0)+16>>3];if(+l[u>>3]==0){l[(t[(t[r>>2]|0)+16>>2]|0)+16>>3]=+l[15984];s=i;return}else{a=+aY(+l[f>>3],+l[u>>3]);l[(t[(t[r>>2]|0)+16>>2]|0)+16>>3]=a;s=i;return}}dn(t[r>>2]|0,11);s=i;return}function Nf(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0;r=s;s=s+16|0;n=r+8|0;f=r+4|0;u=r;t[f>>2]=e;t[u>>2]=i;do if((t[f>>2]|0)!=0?(t[(t[f>>2]|0)+12>>2]|0)!=0:0)if(!(t[u>>2]|0)){t[n>>2]=t[(t[(t[f>>2]|0)+12>>2]|0)+4>>2];break}else{t[n>>2]=0;break}else a=3;while(0);if((a|0)==3)t[n>>2]=0;s=r;return t[n>>2]|0}function Tf(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0;r=s;s=s+16|0;n=r+8|0;f=r+4|0;u=r;t[f>>2]=e;t[u>>2]=i;e:do if((t[f>>2]|0)!=0?(t[(t[f>>2]|0)+12>>2]|0)!=0:0){if(t[u>>2]|0){if((t[(t[u>>2]|0)+4>>2]|0)!=9?(t[(t[u>>2]|0)+4>>2]|0)!=13:0){t[n>>2]=t[(t[u>>2]|0)+24>>2];break}t[n>>2]=0;break}if(!(t[(t[(t[f>>2]|0)+12>>2]|0)+4>>2]|0)){t[n>>2]=0;break}switch(t[(t[(t[(t[f>>2]|0)+12>>2]|0)+4>>2]|0)+4>>2]|0){case 20:case 19:case 18:case 2:case 17:case 16:case 15:{t[n>>2]=0;break e;break}case 14:case 12:case 8:case 7:case 6:case 5:case 4:case 3:case 1:{t[n>>2]=t[(t[(t[(t[f>>2]|0)+12>>2]|0)+4>>2]|0)+12>>2];break e;break}case 21:case 13:case 11:case 10:case 9:{t[n>>2]=t[(t[(t[(t[f>>2]|0)+12>>2]|0)+4>>2]|0)+12>>2];break e;break}default:{t[n>>2]=0;break e}}}else a=3;while(0);if((a|0)==3)t[n>>2]=0;s=r;return t[n>>2]|0}function Lf(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0;r=s;s=s+16|0;n=r+8|0;f=r+4|0;u=r;t[f>>2]=e;t[u>>2]=i;if((t[f>>2]|0)!=0?(t[(t[f>>2]|0)+12>>2]|0)!=0:0){if(!(t[u>>2]|0)){if(!(t[(t[(t[f>>2]|0)+12>>2]|0)+4>>2]|0)){t[n>>2]=0;a=t[n>>2]|0;s=r;return a|0}if((t[(t[(t[(t[f>>2]|0)+12>>2]|0)+4>>2]|0)+4>>2]|0)!=2?(t[(t[(t[(t[f>>2]|0)+12>>2]|0)+4>>2]|0)+4>>2]|0)!=18:0){i=t[(t[f>>2]|0)+12>>2]|0;if((t[(t[(t[f>>2]|0)+12>>2]|0)+4>>2]|0)==(t[t[(t[f>>2]|0)+12>>2]>>2]|0)){t[n>>2]=t[(t[i>>2]|0)+12>>2];a=t[n>>2]|0;s=r;return a|0}else{t[n>>2]=t[(t[i+4>>2]|0)+12>>2];a=t[n>>2]|0;s=r;return a|0}}t[n>>2]=0;a=t[n>>2]|0;s=r;return a|0}if((t[(t[u>>2]|0)+4>>2]|0)==18){t[n>>2]=0;a=t[n>>2]|0;s=r;return a|0}if(((t[(t[u>>2]|0)+12>>2]|0)!=0?(t[(t[(t[u>>2]|0)+12>>2]|0)+4>>2]|0)!=17:0)?(t[u>>2]=t[(t[u>>2]|0)+12>>2],(t[(t[u>>2]|0)+4>>2]|0)!=14):0){t[n>>2]=t[u>>2];a=t[n>>2]|0;s=r;return a|0}if((t[u>>2]|0)==(t[(t[(t[f>>2]|0)+12>>2]|0)+4>>2]|0)){t[n>>2]=0;a=t[n>>2]|0;s=r;return a|0}while(1){if(!(t[(t[u>>2]|0)+24>>2]|0))break;t[u>>2]=t[(t[u>>2]|0)+24>>2];if((t[(t[u>>2]|0)+4>>2]|0)==17)continue;if((t[(t[u>>2]|0)+4>>2]|0)!=14){o=24;break}}if((o|0)==24){t[n>>2]=t[u>>2];a=t[n>>2]|0;s=r;return a|0}while(1){t[u>>2]=t[(t[u>>2]|0)+20>>2];if(!(t[u>>2]|0)){o=31;break}if((t[u>>2]|0)==(t[(t[(t[f>>2]|0)+12>>2]|0)+4>>2]|0)){o=27;break}c=t[u>>2]|0;if(t[(t[u>>2]|0)+24>>2]|0){o=29;break}if(!c){o=31;break}}if((o|0)==27){t[n>>2]=0;a=t[n>>2]|0;s=r;return a|0}else if((o|0)==29){t[u>>2]=t[c+24>>2];t[n>>2]=t[u>>2];a=t[n>>2]|0;s=r;return a|0}else if((o|0)==31){t[n>>2]=t[u>>2];a=t[n>>2]|0;s=r;return a|0}}t[n>>2]=0;a=t[n>>2]|0;s=r;return a|0}function Df(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0;r=s;s=s+16|0;n=r+8|0;f=r+4|0;u=r;t[f>>2]=e;t[u>>2]=i;if((t[f>>2]|0)!=0?(t[(t[f>>2]|0)+12>>2]|0)!=0:0){i=t[f>>2]|0;if(t[u>>2]|0){t[n>>2]=Lf(i,t[u>>2]|0)|0;a=t[n>>2]|0;s=r;return a|0}if(!(t[(t[i+12>>2]|0)+4>>2]|0)){t[n>>2]=0;a=t[n>>2]|0;s=r;return a|0}if((t[(t[(t[(t[f>>2]|0)+12>>2]|0)+4>>2]|0)+4>>2]|0)!=2?(t[(t[(t[(t[f>>2]|0)+12>>2]|0)+4>>2]|0)+4>>2]|0)!=18:0){t[n>>2]=t[(t[(t[f>>2]|0)+12>>2]|0)+4>>2];a=t[n>>2]|0;s=r;return a|0}t[n>>2]=0;a=t[n>>2]|0;s=r;return a|0}t[n>>2]=0;a=t[n>>2]|0;s=r;return a|0}function Cf(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,a=0,o=0,c=0,l=0;r=s;s=s+32|0;n=r+16|0;f=r+12|0;a=r+8|0;o=r+4|0;c=r;t[f>>2]=e;t[a>>2]=i;if((t[f>>2]|0)!=0?(t[(t[f>>2]|0)+12>>2]|0)!=0:0){e:do if(!(t[a>>2]|0)){if(!(t[(t[(t[f>>2]|0)+12>>2]|0)+4>>2]|0)){t[n>>2]=0;l=t[n>>2]|0;s=r;return l|0}switch(t[(t[(t[(t[f>>2]|0)+12>>2]|0)+4>>2]|0)+4>>2]|0){case 2:{t[o>>2]=t[(t[(t[f>>2]|0)+12>>2]|0)+4>>2];t[n>>2]=t[(t[o>>2]|0)+20>>2];l=t[n>>2]|0;s=r;return l|0}case 21:case 13:case 11:case 10:case 9:{t[n>>2]=0;l=t[n>>2]|0;s=r;return l|0}case 18:{t[c>>2]=t[(t[(t[f>>2]|0)+12>>2]|0)+4>>2];if((t[t[c>>2]>>2]|0)!=0?(t[(t[t[c>>2]>>2]|0)+4>>2]|0)!=18:0){t[n>>2]=t[t[c>>2]>>2];l=t[n>>2]|0;s=r;return l|0}t[n>>2]=0;l=t[n>>2]|0;s=r;return l|0}case 17:case 20:case 19:case 16:case 15:case 14:case 12:case 8:case 7:case 6:case 5:case 4:case 3:case 1:{i=t[(t[f>>2]|0)+12>>2]|0;if(!(t[(t[(t[(t[f>>2]|0)+12>>2]|0)+4>>2]|0)+20>>2]|0)){t[n>>2]=t[i>>2];l=t[n>>2]|0;s=r;return l|0}do if((t[(t[(t[i+4>>2]|0)+20>>2]|0)+4>>2]|0)==1){if((u[t[(t[(t[(t[(t[f>>2]|0)+12>>2]|0)+4>>2]|0)+20>>2]|0)+8>>2]>>0]|0|0)!=32?(Xl(t[(t[(t[(t[(t[f>>2]|0)+12>>2]|0)+4>>2]|0)+20>>2]|0)+8>>2]|0,129152)|0)==0:0)break;t[n>>2]=0;l=t[n>>2]|0;s=r;return l|0}while(0);t[n>>2]=t[(t[(t[(t[f>>2]|0)+12>>2]|0)+4>>2]|0)+20>>2];l=t[n>>2]|0;s=r;return l|0}default:break e}}while(0);t[n>>2]=0;l=t[n>>2]|0;s=r;return l|0}t[n>>2]=0;l=t[n>>2]|0;s=r;return l|0}function Pf(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,a=0,o=0,c=0,l=0,b=0,k=0;r=s;s=s+32|0;n=r+24|0;f=r+20|0;a=r+16|0;o=r+12|0;c=r+8|0;l=r+4|0;b=r;t[f>>2]=e;t[a>>2]=i;e:do if((t[f>>2]|0)!=0?(t[(t[f>>2]|0)+12>>2]|0)!=0:0){if(!(t[a>>2]|0)){if(!(t[(t[(t[f>>2]|0)+12>>2]|0)+4>>2]|0)){t[n>>2]=0;break}switch(t[(t[(t[(t[f>>2]|0)+12>>2]|0)+4>>2]|0)+4>>2]|0){case 2:{t[o>>2]=t[(t[(t[f>>2]|0)+12>>2]|0)+4>>2];t[n>>2]=t[(t[o>>2]|0)+20>>2];break e;break}case 18:{t[c>>2]=t[(t[(t[f>>2]|0)+12>>2]|0)+4>>2];if((t[t[c>>2]>>2]|0)!=0?(t[(t[t[c>>2]>>2]|0)+4>>2]|0)!=18:0){t[n>>2]=t[t[c>>2]>>2];break e}t[n>>2]=0;break e;break}case 20:case 19:case 12:case 17:case 16:case 15:case 14:case 8:case 7:case 6:case 5:case 4:case 3:case 1:{i=t[(t[f>>2]|0)+12>>2]|0;if(!(t[(t[(t[(t[f>>2]|0)+12>>2]|0)+4>>2]|0)+20>>2]|0)){t[n>>2]=t[i>>2];break e}do if((t[(t[(t[i+4>>2]|0)+20>>2]|0)+4>>2]|0)==1){if((u[t[(t[(t[(t[(t[f>>2]|0)+12>>2]|0)+4>>2]|0)+20>>2]|0)+8>>2]>>0]|0|0)!=32?(Xl(t[(t[(t[(t[(t[f>>2]|0)+12>>2]|0)+4>>2]|0)+20>>2]|0)+8>>2]|0,129152)|0)==0:0)break;t[n>>2]=0;break e}while(0);t[n>>2]=t[(t[(t[(t[f>>2]|0)+12>>2]|0)+4>>2]|0)+20>>2];break e;break}case 21:case 13:case 11:case 10:case 9:{t[n>>2]=0;break e;break}default:{t[n>>2]=0;break e}}}if((t[a>>2]|0)==(t[(t[t[(t[f>>2]|0)+12>>2]>>2]|0)+12>>2]|0)){t[n>>2]=t[t[(t[f>>2]|0)+12>>2]>>2];break}if((t[a>>2]|0)==(t[t[(t[f>>2]|0)+12>>2]>>2]|0)){t[n>>2]=0;break}switch(t[(t[a>>2]|0)+4>>2]|0){case 21:case 13:case 11:case 10:case 9:{t[n>>2]=0;break e;break}case 18:{t[b>>2]=t[(t[(t[f>>2]|0)+12>>2]|0)+4>>2];if((t[t[b>>2]>>2]|0)!=0?(t[(t[t[b>>2]>>2]|0)+4>>2]|0)!=18:0){t[n>>2]=t[t[b>>2]>>2];break e}t[n>>2]=0;break e;break}case 20:case 19:case 17:case 16:case 15:case 14:case 12:case 8:case 7:case 6:case 5:case 4:case 3:case 1:{if(!(t[(t[a>>2]|0)+20>>2]|0)){t[n>>2]=0;break e}do if((t[(t[(t[a>>2]|0)+20>>2]|0)+4>>2]|0)==1){if((u[t[(t[(t[a>>2]|0)+20>>2]|0)+8>>2]>>0]|0|0)!=32?(Xl(t[(t[(t[a>>2]|0)+20>>2]|0)+8>>2]|0,129152)|0)==0:0)break;t[n>>2]=0;break e}while(0);t[n>>2]=t[(t[a>>2]|0)+20>>2];break e;break}case 2:{t[l>>2]=t[(t[(t[f>>2]|0)+12>>2]|0)+4>>2];t[n>>2]=t[(t[l>>2]|0)+20>>2];break e;break}default:{t[n>>2]=0;break e}}}else k=3;while(0);if((k|0)==3)t[n>>2]=0;s=r;return t[n>>2]|0}function Bf(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0;r=s;s=s+16|0;n=r+8|0;f=r+4|0;u=r;t[f>>2]=e;t[u>>2]=i;if((t[f>>2]|0)!=0?(t[(t[f>>2]|0)+12>>2]|0)!=0:0){i=t[f>>2]|0;if(!(t[u>>2]|0)){t[n>>2]=t[(t[i+12>>2]|0)+4>>2];a=t[n>>2]|0;s=r;return a|0}else{t[n>>2]=Pf(i,t[u>>2]|0)|0;a=t[n>>2]|0;s=r;return a|0}}t[n>>2]=0;a=t[n>>2]|0;s=r;return a|0}function If(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0;r=s;s=s+16|0;n=r+8|0;f=r+4|0;u=r;t[f>>2]=e;t[u>>2]=i;if((t[f>>2]|0)!=0?(t[(t[f>>2]|0)+12>>2]|0)!=0:0){if((t[(t[(t[(t[f>>2]|0)+12>>2]|0)+4>>2]|0)+4>>2]|0)!=2?(t[(t[(t[(t[f>>2]|0)+12>>2]|0)+4>>2]|0)+4>>2]|0)!=18:0){if((t[u>>2]|0)==(t[t[(t[f>>2]|0)+12>>2]>>2]|0)){t[n>>2]=0;a=t[n>>2]|0;s=r;return a|0}if(!(t[u>>2]|0)){t[n>>2]=t[(t[(t[(t[f>>2]|0)+12>>2]|0)+4>>2]|0)+24>>2];a=t[n>>2]|0;s=r;return a|0}else{t[n>>2]=t[(t[u>>2]|0)+24>>2];a=t[n>>2]|0;s=r;return a|0}}t[n>>2]=0;a=t[n>>2]|0;s=r;return a|0}t[n>>2]=0;a=t[n>>2]|0;s=r;return a|0}function Hf(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0;r=s;s=s+16|0;n=r+8|0;f=r+4|0;u=r;t[f>>2]=e;t[u>>2]=i;if((t[f>>2]|0)!=0?(t[(t[f>>2]|0)+12>>2]|0)!=0:0){if((t[(t[(t[(t[f>>2]|0)+12>>2]|0)+4>>2]|0)+4>>2]|0)!=2?(t[(t[(t[(t[f>>2]|0)+12>>2]|0)+4>>2]|0)+4>>2]|0)!=18:0){if((t[u>>2]|0)==(t[t[(t[f>>2]|0)+12>>2]>>2]|0)){t[n>>2]=0;a=t[n>>2]|0;s=r;return a|0}if(!(t[u>>2]|0)){t[n>>2]=t[(t[(t[(t[f>>2]|0)+12>>2]|0)+4>>2]|0)+28>>2];a=t[n>>2]|0;s=r;return a|0}if(((t[(t[u>>2]|0)+28>>2]|0)!=0?(t[(t[(t[u>>2]|0)+28>>2]|0)+4>>2]|0)==14:0)?(t[u>>2]=t[(t[u>>2]|0)+28>>2],(t[u>>2]|0)==0):0){t[n>>2]=t[(t[(t[(t[f>>2]|0)+12>>2]|0)+4>>2]|0)+28>>2];a=t[n>>2]|0;s=r;return a|0}t[n>>2]=t[(t[u>>2]|0)+28>>2];a=t[n>>2]|0;s=r;return a|0}t[n>>2]=0;a=t[n>>2]|0;s=r;return a|0}t[n>>2]=0;a=t[n>>2]|0;s=r;return a|0}function xf(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0;r=s;s=s+16|0;n=r+8|0;f=r+4|0;u=r;t[f>>2]=e;t[u>>2]=i;if((t[f>>2]|0)!=0?(t[(t[f>>2]|0)+12>>2]|0)!=0:0){if((((t[u>>2]|0)!=0?(t[(t[u>>2]|0)+4>>2]|0)!=2:0)?(t[(t[u>>2]|0)+4>>2]|0)!=18:0)?(t[(t[u>>2]|0)+12>>2]|0)!=0:0){t[n>>2]=t[(t[u>>2]|0)+12>>2];a=t[n>>2]|0;s=r;return a|0}do if(!(t[u>>2]|0)){t[u>>2]=t[(t[(t[f>>2]|0)+12>>2]|0)+4>>2];if((t[(t[u>>2]|0)+4>>2]|0)==18){t[n>>2]=0;a=t[n>>2]|0;s=r;return a|0}else{if((t[(t[u>>2]|0)+4>>2]|0)!=2)break;t[u>>2]=t[(t[u>>2]|0)+20>>2];break}}while(0);if(!(t[u>>2]|0)){t[n>>2]=0;a=t[n>>2]|0;s=r;return a|0}if(t[(t[u>>2]|0)+24>>2]|0){t[n>>2]=t[(t[u>>2]|0)+24>>2];a=t[n>>2]|0;s=r;return a|0}while(1){t[u>>2]=t[(t[u>>2]|0)+20>>2];if(!(t[u>>2]|0)){o=24;break}if((t[u>>2]|0)==(t[t[(t[f>>2]|0)+12>>2]>>2]|0)){o=20;break}c=t[u>>2]|0;if(t[(t[u>>2]|0)+24>>2]|0){o=22;break}if(!c){o=24;break}}if((o|0)==20){t[n>>2]=0;a=t[n>>2]|0;s=r;return a|0}else if((o|0)==22){t[n>>2]=t[c+24>>2];a=t[n>>2]|0;s=r;return a|0}else if((o|0)==24){t[n>>2]=t[u>>2];a=t[n>>2]|0;s=r;return a|0}}t[n>>2]=0;a=t[n>>2]|0;s=r;return a|0}function Uf(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0;r=s;s=s+16|0;n=r+8|0;f=r+4|0;u=r;t[f>>2]=e;t[u>>2]=i;if((t[f>>2]|0)!=0?(t[(t[f>>2]|0)+12>>2]|0)!=0:0){if((t[(t[(t[(t[f>>2]|0)+12>>2]|0)+4>>2]|0)+4>>2]|0)!=1){t[n>>2]=0;a=t[n>>2]|0;s=r;return a|0}if((t[(t[(t[f>>2]|0)+12>>2]|0)+120>>2]|0)==0?(t[u>>2]|0)!=(t[32294]|0):0){if(t[(t[(t[f>>2]|0)+12>>2]|0)+120>>2]|0)pAi[t[135736>>2]&511](t[(t[(t[f>>2]|0)+12>>2]|0)+120>>2]|0);u=hF(t[t[(t[f>>2]|0)+12>>2]>>2]|0,t[(t[(t[f>>2]|0)+12>>2]|0)+4>>2]|0)|0;t[(t[(t[f>>2]|0)+12>>2]|0)+120>>2]=u;t[(t[(t[f>>2]|0)+12>>2]|0)+124>>2]=0;e:do if(t[(t[(t[f>>2]|0)+12>>2]|0)+120>>2]|0)while(1){if(!(t[(t[(t[(t[f>>2]|0)+12>>2]|0)+120>>2]|0)+(t[(t[(t[f>>2]|0)+12>>2]|0)+124>>2]<<2)>>2]|0))break e;u=(t[(t[f>>2]|0)+12>>2]|0)+124|0;t[u>>2]=(t[u>>2]|0)+1}while(0);t[n>>2]=t[32294];a=t[n>>2]|0;s=r;return a|0}u=t[(t[f>>2]|0)+12>>2]|0;if((t[(t[(t[f>>2]|0)+12>>2]|0)+124>>2]|0)>0){i=u+124|0;e=(t[i>>2]|0)+-1|0;t[i>>2]=e;t[n>>2]=t[(t[(t[(t[f>>2]|0)+12>>2]|0)+120>>2]|0)+(e<<2)>>2];a=t[n>>2]|0;s=r;return a|0}if(t[u+120>>2]|0)pAi[t[135736>>2]&511](t[(t[(t[f>>2]|0)+12>>2]|0)+120>>2]|0);t[(t[(t[f>>2]|0)+12>>2]|0)+120>>2]=0;t[n>>2]=0;a=t[n>>2]|0;s=r;return a|0}t[n>>2]=0;a=t[n>>2]|0;s=r;return a|0}function zf(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0;r=s;s=s+16|0;n=r+8|0;f=r+4|0;u=r;t[f>>2]=e;t[u>>2]=i;do if((t[f>>2]|0)!=0?(t[(t[f>>2]|0)+12>>2]|0)!=0:0){if(!(t[(t[(t[f>>2]|0)+12>>2]|0)+4>>2]|0)){t[n>>2]=0;break}if((t[(t[(t[(t[f>>2]|0)+12>>2]|0)+4>>2]|0)+4>>2]|0)!=1){t[n>>2]=0;break}if(t[u>>2]|0){t[n>>2]=t[(t[u>>2]|0)+24>>2];break}if((t[(t[(t[f>>2]|0)+12>>2]|0)+4>>2]|0)==(t[t[(t[f>>2]|0)+12>>2]>>2]|0)){t[n>>2]=0;break}else{t[n>>2]=t[(t[(t[(t[f>>2]|0)+12>>2]|0)+4>>2]|0)+44>>2];break}}else a=3;while(0);if((a|0)==3)t[n>>2]=0;s=r;return t[n>>2]|0}function jf(e){e=e|0;var i=0,r=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if(!(t[r>>2]|0)){s=i;return}if(!(t[(t[r>>2]|0)+12>>2]|0)){s=i;return}t[(t[(t[r>>2]|0)+12>>2]|0)+4>>2]=t[t[(t[r>>2]|0)+12>>2]>>2];e=t[r>>2]|0;Sn(e,ru(t[(t[r>>2]|0)+12>>2]|0,t[(t[(t[r>>2]|0)+12>>2]|0)+4>>2]|0)|0)|0;s=i;return}function Vf(e,i){e=e|0;i=i|0;var r=0,n=0,f=0;r=s;s=s+16|0;n=r+4|0;f=r;t[n>>2]=e;t[f>>2]=i;if(!(t[n>>2]|0)){s=r;return}i=t[n>>2]|0;if(t[f>>2]|0){dn(i,12);s=r;return}f=t[n>>2]|0;if((t[i+20>>2]|0)<((t[(t[n>>2]|0)+44>>2]|0)+0|0)){dn(f,23);s=r;return}i=t[n>>2]|0;if((t[(t[f+12>>2]|0)+68>>2]|0)>=0){Sn(i,eu(t[(t[n>>2]|0)+12>>2]|0,+(t[(t[(t[n>>2]|0)+12>>2]|0)+68>>2]|0))|0)|0;s=r;return}else{dn(i,13);s=r;return}}function qf(e,i){e=e|0;i=i|0;var r=0,n=0,f=0;r=s;s=s+16|0;n=r+4|0;f=r;t[n>>2]=e;t[f>>2]=i;if(!(t[n>>2]|0)){s=r;return}i=t[n>>2]|0;if(t[f>>2]|0){dn(i,12);s=r;return}f=t[n>>2]|0;if((t[i+20>>2]|0)<((t[(t[n>>2]|0)+44>>2]|0)+0|0)){dn(f,23);s=r;return}i=t[n>>2]|0;if((t[(t[f+12>>2]|0)+72>>2]|0)>=0){Sn(i,eu(t[(t[n>>2]|0)+12>>2]|0,+(t[(t[(t[n>>2]|0)+12>>2]|0)+72>>2]|0))|0)|0;s=r;return}else{dn(i,14);s=r;return}}function Yf(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0;r=s;s=s+32|0;n=r+16|0;f=r+12|0;u=r+8|0;a=r+4|0;o=r;t[n>>2]=e;t[f>>2]=i;if(!(t[n>>2]|0)){s=r;return}i=t[n>>2]|0;if((t[f>>2]|0)!=1){dn(i,12);s=r;return}f=t[n>>2]|0;if((t[i+20>>2]|0)<((t[(t[n>>2]|0)+44>>2]|0)+1|0)){dn(f,23);s=r;return}do if(t[f+16>>2]|0){if((t[t[(t[n>>2]|0)+16>>2]>>2]|0)!=1?(t[t[(t[n>>2]|0)+16>>2]>>2]|0)!=9:0)break;t[u>>2]=En(t[n>>2]|0)|0;do if((t[u>>2]|0)!=0?(t[(t[u>>2]|0)+4>>2]|0)!=0:0){if((t[t[u>>2]>>2]|0)!=1?(t[t[u>>2]>>2]|0)!=9:0){if((t[t[(t[u>>2]|0)+4>>2]>>2]|0)==1?(t[(t[(t[u>>2]|0)+4>>2]|0)+8>>2]|0)!=0:0){t[o>>2]=0;t[a>>2]=t[t[(t[(t[u>>2]|0)+4>>2]|0)+8>>2]>>2];e:do if((t[a>>2]|0)!=0?(t[(t[a>>2]|0)+4>>2]|0)!=18:0){t[a>>2]=t[(t[a>>2]|0)+12>>2];while(1){if(!(t[a>>2]|0))break e;t[a>>2]=t[(t[a>>2]|0)+24>>2];t[o>>2]=(t[o>>2]|0)+1}}while(0);i=t[n>>2]|0;Sn(i,eu(t[(t[n>>2]|0)+12>>2]|0,+(t[o>>2]|0))|0)|0;break}i=t[n>>2]|0;Sn(i,eu(t[(t[n>>2]|0)+12>>2]|0,0)|0)|0;break}i=t[n>>2]|0;Sn(i,eu(t[(t[n>>2]|0)+12>>2]|0,+(t[t[(t[u>>2]|0)+4>>2]>>2]|0))|0)|0}else c=12;while(0);if((c|0)==12){i=t[n>>2]|0;Sn(i,eu(t[(t[n>>2]|0)+12>>2]|0,0)|0)|0}zt(t[(t[n>>2]|0)+12>>2]|0,t[u>>2]|0);s=r;return}while(0);dn(t[n>>2]|0,11);s=r;return}function Gf(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0;r=s;s=s+32|0;n=r+24|0;f=r+20|0;u=r+16|0;a=r+12|0;o=r+8|0;c=r+4|0;l=r;t[n>>2]=e;t[f>>2]=i;if(!(t[n>>2]|0)){s=r;return}i=t[n>>2]|0;if((t[f>>2]|0)!=1){dn(i,12);s=r;return}f=t[n>>2]|0;if((t[i+20>>2]|0)<((t[(t[n>>2]|0)+44>>2]|0)+1|0)){dn(f,23);s=r;return}t[o>>2]=En(f)|0;if(!(t[o>>2]|0)){dn(t[n>>2]|0,10);s=r;return}if((t[t[o>>2]>>2]|0)!=1?(t[t[o>>2]>>2]|0)!=9:0){t[o>>2]=tu(t[(t[n>>2]|0)+12>>2]|0,t[o>>2]|0)|0;t[a>>2]=nu(t[t[(t[n>>2]|0)+12>>2]>>2]|0,t[(t[o>>2]|0)+24>>2]|0)|0;f=t[n>>2]|0;Sn(f,fu(t[(t[n>>2]|0)+12>>2]|0,t[a>>2]|0)|0)|0;zt(t[(t[n>>2]|0)+12>>2]|0,t[o>>2]|0);s=r;return}t[a>>2]=Nn(0)|0;e:do if(t[(t[o>>2]|0)+4>>2]|0){t[l>>2]=0;while(1){if((t[l>>2]|0)>=(t[t[(t[o>>2]|0)+4>>2]>>2]|0))break e;t[u>>2]=xn(t[(t[(t[(t[o>>2]|0)+4>>2]|0)+8>>2]|0)+(t[l>>2]<<2)>>2]|0)|0;t[c>>2]=nu(t[t[(t[n>>2]|0)+12>>2]>>2]|0,t[u>>2]|0)|0;t[a>>2]=Pn(t[a>>2]|0,t[c>>2]|0)|0;Bn(t[c>>2]|0);if(t[u>>2]|0)pAi[t[135736>>2]&511](t[u>>2]|0);t[l>>2]=(t[l>>2]|0)+1}}while(0);zt(t[(t[n>>2]|0)+12>>2]|0,t[o>>2]|0);o=t[n>>2]|0;Sn(o,fu(t[(t[n>>2]|0)+12>>2]|0,t[a>>2]|0)|0)|0;s=r;return}function Wf(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,a=0,o=0,c=0,l=0;r=s;s=s+16|0;n=r+12|0;f=r+8|0;a=r+4|0;o=r;t[n>>2]=e;t[f>>2]=i;if(!(t[n>>2]|0)){s=r;return}if(!(t[f>>2]|0)){i=t[n>>2]|0;Sn(i,ru(t[(t[n>>2]|0)+12>>2]|0,t[(t[(t[n>>2]|0)+12>>2]|0)+4>>2]|0)|0)|0;t[f>>2]=1}if(!(t[n>>2]|0)){s=r;return}i=t[n>>2]|0;if((t[f>>2]|0)!=1){dn(i,12);s=r;return}f=t[n>>2]|0;if((t[i+20>>2]|0)<((t[(t[n>>2]|0)+44>>2]|0)+1|0)){dn(f,23);s=r;return}do if(t[f+16>>2]|0){if((t[t[(t[n>>2]|0)+16>>2]>>2]|0)!=1?(t[t[(t[n>>2]|0)+16>>2]>>2]|0)!=9:0)break;t[a>>2]=En(t[n>>2]|0)|0;do if((t[(t[a>>2]|0)+4>>2]|0)!=0?(t[t[(t[a>>2]|0)+4>>2]>>2]|0)!=0:0){t[o>>2]=0;i=t[(t[(t[(t[(t[a>>2]|0)+4>>2]|0)+8>>2]|0)+(t[o>>2]<<2)>>2]|0)+4>>2]|0;if((i|0)==7|(i|0)==2|(i|0)==1){e=t[n>>2]|0;c=t[(t[n>>2]|0)+12>>2]|0;if((u[t[(t[(t[(t[(t[a>>2]|0)+4>>2]|0)+8>>2]|0)+(t[o>>2]<<2)>>2]|0)+8>>2]>>0]|0|0)==32){Sn(e,uu(c,128928)|0)|0;break}else{Sn(e,au(c,t[(t[(t[(t[(t[a>>2]|0)+4>>2]|0)+8>>2]|0)+(t[o>>2]<<2)>>2]|0)+8>>2]|0)|0)|0;break}}else if((i|0)==18){i=t[n>>2]|0;Sn(i,au(t[(t[n>>2]|0)+12>>2]|0,t[(t[(t[(t[(t[a>>2]|0)+4>>2]|0)+8>>2]|0)+(t[o>>2]<<2)>>2]|0)+12>>2]|0)|0)|0;break}else{i=t[n>>2]|0;Sn(i,uu(t[(t[n>>2]|0)+12>>2]|0,128928)|0)|0;break}}else l=15;while(0);if((l|0)==15){i=t[n>>2]|0;Sn(i,uu(t[(t[n>>2]|0)+12>>2]|0,128928)|0)|0}zt(t[(t[n>>2]|0)+12>>2]|0,t[a>>2]|0);s=r;return}while(0);dn(t[n>>2]|0,11);s=r;return}function Kf(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0;r=s;s=s+16|0;n=r+12|0;f=r+8|0;u=r+4|0;a=r;t[n>>2]=e;t[f>>2]=i;if(!(t[n>>2]|0)){s=r;return}if(!(t[f>>2]|0)){i=t[n>>2]|0;Sn(i,ru(t[(t[n>>2]|0)+12>>2]|0,t[(t[(t[n>>2]|0)+12>>2]|0)+4>>2]|0)|0)|0;t[f>>2]=1}if(!(t[n>>2]|0)){s=r;return}i=t[n>>2]|0;if((t[f>>2]|0)!=1){dn(i,12);s=r;return}f=t[n>>2]|0;if((t[i+20>>2]|0)<((t[(t[n>>2]|0)+44>>2]|0)+1|0)){dn(f,23);s=r;return}do if(t[f+16>>2]|0){if((t[t[(t[n>>2]|0)+16>>2]>>2]|0)!=1?(t[t[(t[n>>2]|0)+16>>2]>>2]|0)!=9:0)break;t[u>>2]=En(t[n>>2]|0)|0;do if((t[(t[u>>2]|0)+4>>2]|0)!=0?(t[t[(t[u>>2]|0)+4>>2]>>2]|0)!=0:0){t[a>>2]=0;if(((t[(t[(t[(t[(t[u>>2]|0)+4>>2]|0)+8>>2]|0)+(t[a>>2]<<2)>>2]|0)+4>>2]|0)+-1|0)>>>0>=2){i=t[n>>2]|0;Sn(i,uu(t[(t[n>>2]|0)+12>>2]|0,128928)|0)|0;break}i=t[n>>2]|0;e=t[(t[n>>2]|0)+12>>2]|0;if(!(t[(t[(t[(t[(t[u>>2]|0)+4>>2]|0)+8>>2]|0)+(t[a>>2]<<2)>>2]|0)+36>>2]|0)){Sn(i,uu(e,128928)|0)|0;break}else{Sn(i,au(e,t[(t[(t[(t[(t[(t[u>>2]|0)+4>>2]|0)+8>>2]|0)+(t[a>>2]<<2)>>2]|0)+36>>2]|0)+8>>2]|0)|0)|0;break}}else o=15;while(0);if((o|0)==15){e=t[n>>2]|0;Sn(e,uu(t[(t[n>>2]|0)+12>>2]|0,128928)|0)|0}zt(t[(t[n>>2]|0)+12>>2]|0,t[u>>2]|0);s=r;return}while(0);dn(t[n>>2]|0,11);s=r;return}function Xf(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0;r=s;s=s+16|0;n=r+8|0;f=r+4|0;u=r;t[n>>2]=e;t[f>>2]=i;if(!(t[n>>2]|0)){s=r;return}i=t[n>>2]|0;if(!(t[f>>2]|0)){e=t[(t[n>>2]|0)+12>>2]|0;Sn(i,ou(e,xn(t[(t[(t[n>>2]|0)+12>>2]|0)+4>>2]|0)|0)|0)|0;s=r;return}if(!i){s=r;return}i=t[n>>2]|0;if((t[f>>2]|0)!=1){dn(i,12);s=r;return}f=t[n>>2]|0;if((t[i+20>>2]|0)<((t[(t[n>>2]|0)+44>>2]|0)+1|0)){dn(f,23);s=r;return}t[u>>2]=En(f)|0;f=t[n>>2]|0;if(!(t[u>>2]|0)){dn(f,10);s=r;return}else{Sn(f,tu(t[(t[n>>2]|0)+12>>2]|0,t[u>>2]|0)|0)|0;s=r;return}}function Zf(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0;r=s;s=s+16|0;n=r+12|0;f=r+8|0;u=r+4|0;a=r;t[n>>2]=e;t[f>>2]=i;i=(t[n>>2]|0)==0;if(!(t[f>>2]|0)){if(i){s=r;return}if(!(t[(t[n>>2]|0)+12>>2]|0)){s=r;return}e=t[n>>2]|0;if(!(t[(t[(t[n>>2]|0)+12>>2]|0)+4>>2]|0)){Sn(e,eu(t[(t[n>>2]|0)+12>>2]|0,0)|0)|0;s=r;return}else{t[a>>2]=xn(t[(t[e+12>>2]|0)+4>>2]|0)|0;e=t[n>>2]|0;o=t[(t[n>>2]|0)+12>>2]|0;Sn(e,eu(o,+(os(t[a>>2]|0)|0))|0)|0;pAi[t[135736>>2]&511](t[a>>2]|0);s=r;return}}if(i){s=r;return}i=t[n>>2]|0;if((t[f>>2]|0)!=1){dn(i,12);s=r;return}f=t[n>>2]|0;if((t[i+20>>2]|0)<((t[(t[n>>2]|0)+44>>2]|0)+1|0)){dn(f,23);s=r;return}if((t[f+16>>2]|0)!=0?(t[t[(t[n>>2]|0)+16>>2]>>2]|0)!=4:0)Xf(t[n>>2]|0,1);if((t[(t[n>>2]|0)+16>>2]|0)!=0?(t[t[(t[n>>2]|0)+16>>2]>>2]|0)==4:0){t[u>>2]=En(t[n>>2]|0)|0;f=t[n>>2]|0;i=t[(t[n>>2]|0)+12>>2]|0;Sn(f,eu(i,+(os(t[(t[u>>2]|0)+24>>2]|0)|0))|0)|0;zt(t[(t[n>>2]|0)+12>>2]|0,t[u>>2]|0);s=r;return}dn(t[n>>2]|0,11);s=r;return}function Jf(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0;r=s;s=s+32|0;n=r+16|0;f=r+12|0;u=r+8|0;a=r+4|0;o=r;t[n>>2]=e;t[f>>2]=i;if(!(t[n>>2]|0)){s=r;return}if((t[f>>2]|0)<2){if(!(t[n>>2]|0)){s=r;return}i=t[n>>2]|0;if((t[f>>2]|0)!=2){dn(i,12);s=r;return}if((t[i+20>>2]|0)<((t[(t[n>>2]|0)+44>>2]|0)+2|0)){dn(t[n>>2]|0,23);s=r;return}}if((t[(t[n>>2]|0)+16>>2]|0)!=0?(t[t[(t[n>>2]|0)+16>>2]>>2]|0)!=4:0)Xf(t[n>>2]|0,1);t[u>>2]=En(t[n>>2]|0)|0;if((t[u>>2]|0)!=0?(t[t[u>>2]>>2]|0)==4:0){t[f>>2]=(t[f>>2]|0)+-1;while(1){c=t[n>>2]|0;if((t[f>>2]|0)<=0){l=23;break}if((t[c+16>>2]|0)!=0?(t[t[(t[n>>2]|0)+16>>2]>>2]|0)!=4:0)Xf(t[n>>2]|0,1);t[a>>2]=En(t[n>>2]|0)|0;if(!(t[a>>2]|0)){l=21;break}if((t[t[a>>2]>>2]|0)!=4){l=21;break}t[o>>2]=us(t[(t[a>>2]|0)+24>>2]|0,t[(t[u>>2]|0)+24>>2]|0)|0;t[(t[a>>2]|0)+24>>2]=t[(t[u>>2]|0)+24>>2];t[(t[u>>2]|0)+24>>2]=t[o>>2];zt(t[(t[n>>2]|0)+12>>2]|0,t[a>>2]|0);t[f>>2]=(t[f>>2]|0)+-1}if((l|0)==21){zt(t[(t[n>>2]|0)+12>>2]|0,t[a>>2]|0);zt(t[(t[n>>2]|0)+12>>2]|0,t[u>>2]|0);dn(t[n>>2]|0,11);s=r;return}else if((l|0)==23){Sn(c,t[u>>2]|0)|0;s=r;return}}zt(t[(t[n>>2]|0)+12>>2]|0,t[u>>2]|0);s=r;return}function Qf(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0;r=s;s=s+16|0;n=r+12|0;f=r+8|0;u=r+4|0;a=r;t[n>>2]=e;t[f>>2]=i;if(!(t[n>>2]|0)){s=r;return}i=t[n>>2]|0;if((t[f>>2]|0)!=2){dn(i,12);s=r;return}f=t[n>>2]|0;if((t[i+20>>2]|0)<((t[(t[n>>2]|0)+44>>2]|0)+2|0)){dn(f,23);s=r;return}if((t[f+16>>2]|0)!=0?(t[t[(t[n>>2]|0)+16>>2]>>2]|0)!=4:0)Xf(t[n>>2]|0,1);if((t[(t[n>>2]|0)+16>>2]|0)!=0?(t[t[(t[n>>2]|0)+16>>2]>>2]|0)==4:0){t[a>>2]=En(t[n>>2]|0)|0;if((t[(t[n>>2]|0)+16>>2]|0)!=0?(t[t[(t[n>>2]|0)+16>>2]>>2]|0)!=4:0)Xf(t[n>>2]|0,1);t[u>>2]=En(t[n>>2]|0)|0;if((t[u>>2]|0)!=0?(t[t[u>>2]>>2]|0)==4:0){f=(is(t[(t[u>>2]|0)+24>>2]|0,t[(t[a>>2]|0)+24>>2]|0)|0)!=0;i=t[n>>2]|0;e=t[(t[n>>2]|0)+12>>2]|0;if(f)Sn(i,cu(e,1)|0)|0;else Sn(i,cu(e,0)|0)|0;zt(t[(t[n>>2]|0)+12>>2]|0,t[u>>2]|0);zt(t[(t[n>>2]|0)+12>>2]|0,t[a>>2]|0);s=r;return}zt(t[(t[n>>2]|0)+12>>2]|0,t[u>>2]|0);zt(t[(t[n>>2]|0)+12>>2]|0,t[a>>2]|0);dn(t[n>>2]|0,11);s=r;return}dn(t[n>>2]|0,11);s=r;return}function $f(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0;r=s;s=s+32|0;n=r+16|0;f=r+12|0;u=r+8|0;a=r+4|0;o=r;t[n>>2]=e;t[f>>2]=i;if(!(t[n>>2]|0)){s=r;return}i=t[n>>2]|0;if((t[f>>2]|0)!=2){dn(i,12);s=r;return}f=t[n>>2]|0;if((t[i+20>>2]|0)<((t[(t[n>>2]|0)+44>>2]|0)+2|0)){dn(f,23);s=r;return}if((t[f+16>>2]|0)!=0?(t[t[(t[n>>2]|0)+16>>2]>>2]|0)!=4:0)Xf(t[n>>2]|0,1);if((t[(t[n>>2]|0)+16>>2]|0)!=0?(t[t[(t[n>>2]|0)+16>>2]>>2]|0)==4:0){t[a>>2]=En(t[n>>2]|0)|0;if((t[(t[n>>2]|0)+16>>2]|0)!=0?(t[t[(t[n>>2]|0)+16>>2]>>2]|0)!=4:0)Xf(t[n>>2]|0,1);t[u>>2]=En(t[n>>2]|0)|0;if((t[u>>2]|0)!=0?(t[t[u>>2]>>2]|0)==4:0){t[o>>2]=rs(t[(t[a>>2]|0)+24>>2]|0)|0;f=(Jl(t[(t[u>>2]|0)+24>>2]|0,t[(t[a>>2]|0)+24>>2]|0,t[o>>2]|0)|0)!=0;o=t[n>>2]|0;i=t[(t[n>>2]|0)+12>>2]|0;if(f)Sn(o,cu(i,0)|0)|0;else Sn(o,cu(i,1)|0)|0;zt(t[(t[n>>2]|0)+12>>2]|0,t[u>>2]|0);zt(t[(t[n>>2]|0)+12>>2]|0,t[a>>2]|0);s=r;return}zt(t[(t[n>>2]|0)+12>>2]|0,t[u>>2]|0);zt(t[(t[n>>2]|0)+12>>2]|0,t[a>>2]|0);dn(t[n>>2]|0,11);s=r;return}dn(t[n>>2]|0,11);s=r;return}function et(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0,b=0,k=0,h=0,w=0,d=0;r=s;s=s+64|0;n=r+48|0;f=r+44|0;u=r+40|0;a=r+36|0;o=r+32|0;c=r+8|0;b=r;k=r+28|0;h=r+24|0;w=r+20|0;d=r+16|0;t[n>>2]=e;t[f>>2]=i;l[c>>3]=0;if((t[f>>2]|0)<2){if(!(t[n>>2]|0)){s=r;return}i=t[n>>2]|0;if((t[f>>2]|0)!=2){dn(i,12);s=r;return}if((t[i+20>>2]|0)<((t[(t[n>>2]|0)+44>>2]|0)+2|0)){dn(t[n>>2]|0,23);s=r;return}}if((t[f>>2]|0)>3){if(!(t[n>>2]|0)){s=r;return}i=t[n>>2]|0;if((t[f>>2]|0)!=3){dn(i,12);s=r;return}if((t[i+20>>2]|0)<((t[(t[n>>2]|0)+44>>2]|0)+3|0)){dn(t[n>>2]|0,23);s=r;return}}do if((t[f>>2]|0)==3){if((t[(t[n>>2]|0)+16>>2]|0)!=0?(t[t[(t[n>>2]|0)+16>>2]>>2]|0)!=3:0)gf(t[n>>2]|0,1);if((t[(t[n>>2]|0)+16>>2]|0)!=0?(t[t[(t[n>>2]|0)+16>>2]>>2]|0)==3:0){t[o>>2]=En(t[n>>2]|0)|0;
	l[c>>3]=+l[(t[o>>2]|0)+16>>3];zt(t[(t[n>>2]|0)+12>>2]|0,t[o>>2]|0);break}dn(t[n>>2]|0,11);s=r;return}while(0);if((t[(t[n>>2]|0)+16>>2]|0)!=0?(t[t[(t[n>>2]|0)+16>>2]>>2]|0)!=3:0)gf(t[n>>2]|0,1);if((t[(t[n>>2]|0)+16>>2]|0)!=0?(t[t[(t[n>>2]|0)+16>>2]>>2]|0)==3:0){t[a>>2]=En(t[n>>2]|0)|0;l[b>>3]=+l[(t[a>>2]|0)+16>>3];zt(t[(t[n>>2]|0)+12>>2]|0,t[a>>2]|0);if((t[(t[n>>2]|0)+16>>2]|0)!=0?(t[t[(t[n>>2]|0)+16>>2]>>2]|0)!=4:0)Xf(t[n>>2]|0,1);if((t[(t[n>>2]|0)+16>>2]|0)!=0?(t[t[(t[n>>2]|0)+16>>2]>>2]|0)==4:0){t[u>>2]=En(t[n>>2]|0)|0;t[w>>2]=os(t[(t[u>>2]|0)+24>>2]|0)|0;if((t[f>>2]|0)!=3?(l[c>>3]=+(t[w>>2]|0),+l[b>>3]<1):0)l[b>>3]=1;if((wn(+l[b>>3])|0)==0?(hn(+l[b>>3]+ +l[c>>3])|0)==0:0){t[k>>2]=~~+l[b>>3];if(+(t[k>>2]|0)+.5<=+l[b>>3])t[k>>2]=(t[k>>2]|0)+1;do if((wn(+l[c>>3])|0)==1){t[h>>2]=t[w>>2];if((t[k>>2]|0)<1)t[k>>2]=1}else{b=(wn(+l[c>>3])|0)==-1;if(b|+l[c>>3]<0){t[h>>2]=0;break}t[h>>2]=~~+l[c>>3];if(+(t[h>>2]|0)+.5<=+l[c>>3])t[h>>2]=(t[h>>2]|0)+1}while(0);t[k>>2]=(t[k>>2]|0)-1;t[h>>2]=(t[h>>2]|0)+(t[k>>2]|0);if((t[k>>2]|0)<0)t[k>>2]=0;if((t[h>>2]|0)>(t[w>>2]|0))t[h>>2]=t[w>>2];t[h>>2]=(t[h>>2]|0)-(t[k>>2]|0);t[d>>2]=ws(t[(t[u>>2]|0)+24>>2]|0,t[k>>2]|0,t[h>>2]|0)|0}else t[d>>2]=0;h=t[n>>2]|0;k=t[(t[n>>2]|0)+12>>2]|0;if(!(t[d>>2]|0))Sn(h,uu(k,128928)|0)|0;else{Sn(h,au(k,t[d>>2]|0)|0)|0;pAi[t[135736>>2]&511](t[d>>2]|0)}zt(t[(t[n>>2]|0)+12>>2]|0,t[u>>2]|0);s=r;return}dn(t[n>>2]|0,11);s=r;return}dn(t[n>>2]|0,11);s=r;return}function it(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0;r=s;s=s+32|0;n=r+24|0;f=r+20|0;u=r+16|0;a=r+12|0;o=r+8|0;c=r+4|0;l=r;t[n>>2]=e;t[f>>2]=i;if(!(t[n>>2]|0)){s=r;return}i=t[n>>2]|0;if((t[f>>2]|0)!=2){dn(i,12);s=r;return}f=t[n>>2]|0;if((t[i+20>>2]|0)<((t[(t[n>>2]|0)+44>>2]|0)+2|0)){dn(f,23);s=r;return}if((t[f+16>>2]|0)!=0?(t[t[(t[n>>2]|0)+16>>2]>>2]|0)!=4:0)Xf(t[n>>2]|0,1);t[a>>2]=En(t[n>>2]|0)|0;if((t[(t[n>>2]|0)+16>>2]|0)!=0?(t[t[(t[n>>2]|0)+16>>2]>>2]|0)!=4:0)Xf(t[n>>2]|0,1);t[u>>2]=En(t[n>>2]|0)|0;t[o>>2]=ds()|0;if(t[o>>2]|0){t[c>>2]=is(t[(t[u>>2]|0)+24>>2]|0,t[(t[a>>2]|0)+24>>2]|0)|0;if(t[c>>2]|0){t[l>>2]=(t[c>>2]|0)-(t[(t[u>>2]|0)+24>>2]|0);Ps(t[o>>2]|0,t[(t[u>>2]|0)+24>>2]|0,t[l>>2]|0)|0}l=t[n>>2]|0;c=t[(t[n>>2]|0)+12>>2]|0;Sn(l,au(c,Os(t[o>>2]|0)|0)|0)|0;Ss(t[o>>2]|0)}zt(t[(t[n>>2]|0)+12>>2]|0,t[u>>2]|0);zt(t[(t[n>>2]|0)+12>>2]|0,t[a>>2]|0);s=r;return}function rt(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0;r=s;s=s+32|0;n=r+24|0;f=r+20|0;u=r+16|0;a=r+12|0;o=r+8|0;c=r+4|0;l=r;t[n>>2]=e;t[f>>2]=i;if(!(t[n>>2]|0)){s=r;return}i=t[n>>2]|0;if((t[f>>2]|0)!=2){dn(i,12);s=r;return}f=t[n>>2]|0;if((t[i+20>>2]|0)<((t[(t[n>>2]|0)+44>>2]|0)+2|0)){dn(f,23);s=r;return}if((t[f+16>>2]|0)!=0?(t[t[(t[n>>2]|0)+16>>2]>>2]|0)!=4:0)Xf(t[n>>2]|0,1);t[a>>2]=En(t[n>>2]|0)|0;if((t[(t[n>>2]|0)+16>>2]|0)!=0?(t[t[(t[n>>2]|0)+16>>2]>>2]|0)!=4:0)Xf(t[n>>2]|0,1);t[u>>2]=En(t[n>>2]|0)|0;t[o>>2]=ds()|0;if(t[o>>2]|0){t[c>>2]=is(t[(t[u>>2]|0)+24>>2]|0,t[(t[a>>2]|0)+24>>2]|0)|0;if(t[c>>2]|0){f=(t[c>>2]|0)-(t[(t[u>>2]|0)+24>>2]|0)|0;t[l>>2]=f+(rs(t[(t[a>>2]|0)+24>>2]|0)|0);f=t[o>>2]|0;c=(t[(t[u>>2]|0)+24>>2]|0)+(t[l>>2]|0)|0;i=rs(t[(t[u>>2]|0)+24>>2]|0)|0;Ps(f,c,i-(t[l>>2]|0)|0)|0}l=t[n>>2]|0;i=t[(t[n>>2]|0)+12>>2]|0;Sn(l,au(i,Os(t[o>>2]|0)|0)|0)|0;Ss(t[o>>2]|0)}zt(t[(t[n>>2]|0)+12>>2]|0,t[u>>2]|0);zt(t[(t[n>>2]|0)+12>>2]|0,t[a>>2]|0);s=r;return}function nt(e,i){e=e|0;i=i|0;var r=0,f=0,a=0,o=0,c=0,l=0,b=0,k=0;r=s;s=s+32|0;f=r+16|0;a=r+12|0;o=r+8|0;c=r+4|0;l=r;b=r+20|0;t[f>>2]=e;t[a>>2]=i;t[o>>2]=0;t[c>>2]=0;if(!(t[f>>2]|0)){s=r;return}if(!(t[a>>2]|0)){i=t[f>>2]|0;e=t[(t[f>>2]|0)+12>>2]|0;Sn(i,ou(e,xn(t[(t[(t[f>>2]|0)+12>>2]|0)+4>>2]|0)|0)|0)|0;t[a>>2]=1}if(!(t[f>>2]|0)){s=r;return}e=t[f>>2]|0;if((t[a>>2]|0)!=1){dn(e,12);s=r;return}a=t[f>>2]|0;if((t[e+20>>2]|0)<((t[(t[f>>2]|0)+44>>2]|0)+1|0)){dn(a,23);s=r;return}if((t[a+16>>2]|0)!=0?(t[t[(t[f>>2]|0)+16>>2]>>2]|0)!=4:0)Xf(t[f>>2]|0,1);if((t[(t[f>>2]|0)+16>>2]|0)!=0?(t[t[(t[f>>2]|0)+16>>2]>>2]|0)==4:0){t[o>>2]=En(t[f>>2]|0)|0;t[c>>2]=t[(t[o>>2]|0)+24>>2];t[l>>2]=ds()|0;if((t[l>>2]|0)!=0&(t[c>>2]|0)!=0){e:while(1){do if((u[t[c>>2]>>0]|0)!=32){if(9<=(u[t[c>>2]>>0]|0)?(u[t[c>>2]>>0]|0)<=10:0)break;if((u[t[c>>2]>>0]|0)!=13)break e}while(0);t[c>>2]=(t[c>>2]|0)+1}n[b>>0]=0;while(1){if(!(n[t[c>>2]>>0]|0))break;do if((u[t[c>>2]>>0]|0)!=32){if(9<=(u[t[c>>2]>>0]|0)?(u[t[c>>2]>>0]|0)<=10:0){k=27;break}if((u[t[c>>2]>>0]|0)!=13){if(n[b>>0]|0){Ps(t[l>>2]|0,b,1)|0;n[b>>0]=0}Ps(t[l>>2]|0,t[c>>2]|0,1)|0}else k=27}else k=27;while(0);if((k|0)==27){k=0;n[b>>0]=32}t[c>>2]=(t[c>>2]|0)+1}c=t[f>>2]|0;b=t[(t[f>>2]|0)+12>>2]|0;Sn(c,au(b,Os(t[l>>2]|0)|0)|0)|0;Ss(t[l>>2]|0)}zt(t[(t[f>>2]|0)+12>>2]|0,t[o>>2]|0);s=r;return}dn(t[f>>2]|0,11);s=r;return}function ft(e,i){e=e|0;i=i|0;var r=0,f=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0;r=s;s=s+48|0;f=r;a=r+40|0;o=r+36|0;c=r+32|0;l=r+28|0;b=r+24|0;k=r+20|0;h=r+16|0;w=r+12|0;d=r+44|0;v=r+8|0;m=r+4|0;t[a>>2]=e;t[o>>2]=i;if(!(t[a>>2]|0)){s=r;return}i=t[a>>2]|0;if((t[o>>2]|0)!=3){dn(i,12);s=r;return}o=t[a>>2]|0;if((t[i+20>>2]|0)<((t[(t[a>>2]|0)+44>>2]|0)+3|0)){dn(o,23);s=r;return}if((t[o+16>>2]|0)!=0?(t[t[(t[a>>2]|0)+16>>2]>>2]|0)!=4:0)Xf(t[a>>2]|0,1);t[b>>2]=En(t[a>>2]|0)|0;if((t[(t[a>>2]|0)+16>>2]|0)!=0?(t[t[(t[a>>2]|0)+16>>2]>>2]|0)!=4:0)Xf(t[a>>2]|0,1);t[l>>2]=En(t[a>>2]|0)|0;if((t[(t[a>>2]|0)+16>>2]|0)!=0?(t[t[(t[a>>2]|0)+16>>2]>>2]|0)!=4:0)Xf(t[a>>2]|0,1);t[c>>2]=En(t[a>>2]|0)|0;t[k>>2]=ds()|0;e:do if(t[k>>2]|0){t[w>>2]=os(t[(t[b>>2]|0)+24>>2]|0)|0;t[m>>2]=t[(t[c>>2]|0)+24>>2];while(1){o=n[t[m>>2]>>0]|0;n[d>>0]=o;if(!(o<<24>>24))break e;t[h>>2]=hs(t[(t[l>>2]|0)+24>>2]|0,t[m>>2]|0)|0;if((t[h>>2]|0)>=0){if((t[h>>2]|0)<(t[w>>2]|0)?(t[v>>2]=ks(t[(t[b>>2]|0)+24>>2]|0,t[h>>2]|0)|0,(t[v>>2]|0)!=0):0){o=t[k>>2]|0;i=t[v>>2]|0;Ps(o,i,ss(t[v>>2]|0,1)|0)|0}}else{i=t[k>>2]|0;o=t[m>>2]|0;Ps(i,o,ss(t[m>>2]|0,1)|0)|0}t[m>>2]=(t[m>>2]|0)+1;if(!((u[d>>0]|0)&128))continue;if(((u[d>>0]|0)&192|0)!=192)break;while(1){o=(u[d>>0]|0)<<1&255;n[d>>0]=o;if(!(o&128))break;o=t[m>>2]|0;t[m>>2]=o+1;if(((u[o>>0]|0)&192|0)!=128){_=28;break}}if((_|0)==28){_=0;yAi[t[135904>>2]&511](t[33980]|0,129184,f)}if((u[d>>0]|0)&128)break e}yAi[t[135904>>2]&511](t[33980]|0,129184,f)}while(0);f=t[a>>2]|0;d=t[(t[a>>2]|0)+12>>2]|0;Sn(f,au(d,Os(t[k>>2]|0)|0)|0)|0;Ss(t[k>>2]|0);zt(t[(t[a>>2]|0)+12>>2]|0,t[c>>2]|0);zt(t[(t[a>>2]|0)+12>>2]|0,t[l>>2]|0);zt(t[(t[a>>2]|0)+12>>2]|0,t[b>>2]|0);s=r;return}function tt(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0;r=s;s=s+16|0;n=r+8|0;f=r+4|0;u=r;t[n>>2]=e;t[f>>2]=i;if(!(t[n>>2]|0)){s=r;return}i=t[n>>2]|0;if((t[f>>2]|0)!=1){dn(i,12);s=r;return}f=t[n>>2]|0;if((t[i+20>>2]|0)<((t[(t[n>>2]|0)+44>>2]|0)+1|0)){dn(f,23);s=r;return}t[u>>2]=En(f)|0;f=t[n>>2]|0;if(!(t[u>>2]|0)){dn(f,10);s=r;return}else{t[u>>2]=lu(t[f+12>>2]|0,t[u>>2]|0)|0;Sn(t[n>>2]|0,t[u>>2]|0)|0;s=r;return}}function ut(e,i){e=e|0;i=i|0;var r=0,n=0,f=0;r=s;s=s+16|0;n=r+4|0;f=r;t[n>>2]=e;t[f>>2]=i;if(!(t[n>>2]|0)){s=r;return}i=t[n>>2]|0;if((t[f>>2]|0)!=1){dn(i,12);s=r;return}f=t[n>>2]|0;if((t[i+20>>2]|0)<((t[(t[n>>2]|0)+44>>2]|0)+1|0)){dn(f,23);s=r;return}if((t[f+16>>2]|0)!=0?(t[t[(t[n>>2]|0)+16>>2]>>2]|0)!=2:0)tt(t[n>>2]|0,1);if((t[(t[n>>2]|0)+16>>2]|0)!=0?(t[t[(t[n>>2]|0)+16>>2]>>2]|0)==2:0){t[(t[(t[n>>2]|0)+16>>2]|0)+8>>2]=((t[(t[(t[n>>2]|0)+16>>2]|0)+8>>2]|0)!=0^1)&1;s=r;return}dn(t[n>>2]|0,11);s=r;return}function at(e,i){e=e|0;i=i|0;var r=0,n=0,f=0;r=s;s=s+16|0;n=r+4|0;f=r;t[n>>2]=e;t[f>>2]=i;if(!(t[n>>2]|0)){s=r;return}i=t[n>>2]|0;if(t[f>>2]|0){dn(i,12);s=r;return}f=t[n>>2]|0;if((t[i+20>>2]|0)<((t[(t[n>>2]|0)+44>>2]|0)+0|0)){dn(f,23);s=r;return}else{Sn(f,cu(t[(t[n>>2]|0)+12>>2]|0,1)|0)|0;s=r;return}}function ot(e,i){e=e|0;i=i|0;var r=0,n=0,f=0;r=s;s=s+16|0;n=r+4|0;f=r;t[n>>2]=e;t[f>>2]=i;if(!(t[n>>2]|0)){s=r;return}i=t[n>>2]|0;if(t[f>>2]|0){dn(i,12);s=r;return}f=t[n>>2]|0;if((t[i+20>>2]|0)<((t[(t[n>>2]|0)+44>>2]|0)+0|0)){dn(f,23);s=r;return}else{Sn(f,cu(t[(t[n>>2]|0)+12>>2]|0,0)|0)|0;s=r;return}}function ct(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,a=0,o=0,c=0,l=0,b=0,k=0;r=s;s=s+32|0;n=r+24|0;f=r+20|0;a=r+16|0;o=r+12|0;c=r+8|0;l=r+4|0;b=r;t[n>>2]=e;t[f>>2]=i;t[a>>2]=0;t[o>>2]=0;t[l>>2]=0;if(!(t[n>>2]|0)){s=r;return}i=t[n>>2]|0;if((t[f>>2]|0)!=1){dn(i,12);s=r;return}f=t[n>>2]|0;if((t[i+20>>2]|0)<((t[(t[n>>2]|0)+44>>2]|0)+1|0)){dn(f,23);s=r;return}if((t[f+16>>2]|0)!=0?(t[t[(t[n>>2]|0)+16>>2]>>2]|0)!=4:0)Xf(t[n>>2]|0,1);if((t[(t[n>>2]|0)+16>>2]|0)!=0?(t[t[(t[n>>2]|0)+16>>2]>>2]|0)==4:0){t[a>>2]=En(t[n>>2]|0)|0;t[c>>2]=t[(t[a>>2]|0)+24>>2];t[o>>2]=fF(t[(t[(t[n>>2]|0)+12>>2]|0)+4>>2]|0)|0;e:do if((t[o>>2]|0)!=0&(t[c>>2]|0)!=0){t[b>>2]=0;while(1){k=t[b>>2]|0;if(!(u[(t[c>>2]|0)+(t[b>>2]|0)>>0]|0))break;f=Pq(u[(t[c>>2]|0)+k>>0]|0)|0;if((f|0)!=(Pq(u[(t[o>>2]|0)+(t[b>>2]|0)>>0]|0)|0))break e;t[b>>2]=(t[b>>2]|0)+1}if((u[(t[o>>2]|0)+k>>0]|0|0)!=0?(u[(t[o>>2]|0)+(t[b>>2]|0)>>0]|0|0)!=45:0)break;t[l>>2]=1}while(0);if(t[o>>2]|0)pAi[t[135736>>2]&511](t[o>>2]|0);zt(t[(t[n>>2]|0)+12>>2]|0,t[a>>2]|0);a=t[n>>2]|0;Sn(a,cu(t[(t[n>>2]|0)+12>>2]|0,t[l>>2]|0)|0)|0;s=r;return}dn(t[n>>2]|0,11);s=r;return}function lt(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0;r=s;s=s+32|0;n=r+20|0;f=r+16|0;u=r+12|0;a=r+8|0;o=r;t[n>>2]=e;t[f>>2]=i;l[o>>3]=0;if(!(t[n>>2]|0)){s=r;return}i=t[n>>2]|0;if((t[f>>2]|0)!=1){dn(i,12);s=r;return}f=t[n>>2]|0;if((t[i+20>>2]|0)<((t[(t[n>>2]|0)+44>>2]|0)+1|0)){dn(f,23);s=r;return}do if(t[f+16>>2]|0){if((t[t[(t[n>>2]|0)+16>>2]>>2]|0)!=1?(t[t[(t[n>>2]|0)+16>>2]>>2]|0)!=9:0)break;t[u>>2]=En(t[n>>2]|0)|0;e:do if((t[(t[u>>2]|0)+4>>2]|0)!=0?(t[t[(t[u>>2]|0)+4>>2]>>2]|0)!=0:0){t[a>>2]=0;while(1){if((t[a>>2]|0)>=(t[t[(t[u>>2]|0)+4>>2]>>2]|0))break e;c=+lf(t[(t[(t[(t[u>>2]|0)+4>>2]|0)+8>>2]|0)+(t[a>>2]<<2)>>2]|0);l[o>>3]=+l[o>>3]+c;t[a>>2]=(t[a>>2]|0)+1}}while(0);i=t[n>>2]|0;Sn(i,eu(t[(t[n>>2]|0)+12>>2]|0,+l[o>>3])|0)|0;zt(t[(t[n>>2]|0)+12>>2]|0,t[u>>2]|0);s=r;return}while(0);dn(t[n>>2]|0,11);s=r;return}function st(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0;r=s;s=s+16|0;n=r+12|0;f=r+8|0;u=r;t[n>>2]=e;t[f>>2]=i;if(!(t[n>>2]|0)){s=r;return}i=t[n>>2]|0;if((t[f>>2]|0)!=1){dn(i,12);s=r;return}f=t[n>>2]|0;if((t[i+20>>2]|0)<((t[(t[n>>2]|0)+44>>2]|0)+1|0)){dn(f,23);s=r;return}if((t[f+16>>2]|0)!=0?(t[t[(t[n>>2]|0)+16>>2]>>2]|0)!=3:0)gf(t[n>>2]|0,1);if((t[(t[n>>2]|0)+16>>2]|0)!=0?(t[t[(t[n>>2]|0)+16>>2]>>2]|0)==3:0){l[u>>3]=+aY(+l[(t[(t[n>>2]|0)+16>>2]|0)+16>>3],2147483647);l[u>>3]=+l[(t[(t[n>>2]|0)+16>>2]|0)+16>>3]-+l[u>>3]+ +(~~+l[u>>3]|0);if(!(+l[u>>3]!=+l[(t[(t[n>>2]|0)+16>>2]|0)+16>>3])){s=r;return}a=+l[u>>3];if(+l[(t[(t[n>>2]|0)+16>>2]|0)+16>>3]>0){l[(t[(t[n>>2]|0)+16>>2]|0)+16>>3]=a;s=r;return}else{l[(t[(t[n>>2]|0)+16>>2]|0)+16>>3]=a-1;s=r;return}}dn(t[n>>2]|0,11);s=r;return}function bt(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0;r=s;s=s+16|0;n=r+12|0;f=r+8|0;u=r;t[n>>2]=e;t[f>>2]=i;if(!(t[n>>2]|0)){s=r;return}i=t[n>>2]|0;if((t[f>>2]|0)!=1){dn(i,12);s=r;return}f=t[n>>2]|0;if((t[i+20>>2]|0)<((t[(t[n>>2]|0)+44>>2]|0)+1|0)){dn(f,23);s=r;return}if((t[f+16>>2]|0)!=0?(t[t[(t[n>>2]|0)+16>>2]>>2]|0)!=3:0)gf(t[n>>2]|0,1);if((t[(t[n>>2]|0)+16>>2]|0)!=0?(t[t[(t[n>>2]|0)+16>>2]>>2]|0)==3:0){l[u>>3]=+aY(+l[(t[(t[n>>2]|0)+16>>2]|0)+16>>3],2147483647);l[u>>3]=+l[(t[(t[n>>2]|0)+16>>2]|0)+16>>3]-+l[u>>3]+ +(~~+l[u>>3]|0);if(!(+l[u>>3]!=+l[(t[(t[n>>2]|0)+16>>2]|0)+16>>3])){s=r;return}if(+l[(t[(t[n>>2]|0)+16>>2]|0)+16>>3]>0){l[(t[(t[n>>2]|0)+16>>2]|0)+16>>3]=+l[u>>3]+1;s=r;return}if(+l[u>>3]==0?+l[(t[(t[n>>2]|0)+16>>2]|0)+16>>3]<0:0){l[(t[(t[n>>2]|0)+16>>2]|0)+16>>3]=+l[15988];s=r;return}else{l[(t[(t[n>>2]|0)+16>>2]|0)+16>>3]=+l[u>>3];s=r;return}}dn(t[n>>2]|0,11);s=r;return}function kt(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0;r=s;s=s+16|0;n=r+12|0;f=r+8|0;u=r;t[n>>2]=e;t[f>>2]=i;if(!(t[n>>2]|0)){s=r;return}i=t[n>>2]|0;if((t[f>>2]|0)!=1){dn(i,12);s=r;return}f=t[n>>2]|0;if((t[i+20>>2]|0)<((t[(t[n>>2]|0)+44>>2]|0)+1|0)){dn(f,23);s=r;return}if((t[f+16>>2]|0)!=0?(t[t[(t[n>>2]|0)+16>>2]>>2]|0)!=3:0)gf(t[n>>2]|0,1);if((t[(t[n>>2]|0)+16>>2]|0)!=0?(t[t[(t[n>>2]|0)+16>>2]>>2]|0)==3:0){if(hn(+l[(t[(t[n>>2]|0)+16>>2]|0)+16>>3])|0){s=r;return}if((wn(+l[(t[(t[n>>2]|0)+16>>2]|0)+16>>3])|0)==1){s=r;return}if((wn(+l[(t[(t[n>>2]|0)+16>>2]|0)+16>>3])|0)==-1){s=r;return}if(+l[(t[(t[n>>2]|0)+16>>2]|0)+16>>3]==0){s=r;return}l[u>>3]=+aY(+l[(t[(t[n>>2]|0)+16>>2]|0)+16>>3],2147483647);l[u>>3]=+l[(t[(t[n>>2]|0)+16>>2]|0)+16>>3]-+l[u>>3]+ +(~~+l[u>>3]|0);a=+l[(t[(t[n>>2]|0)+16>>2]|0)+16>>3];o=+l[u>>3];if(!(+l[(t[(t[n>>2]|0)+16>>2]|0)+16>>3]<0)){c=+l[u>>3];if(a<o+.5){l[(t[(t[n>>2]|0)+16>>2]|0)+16>>3]=c;s=r;return}else{l[(t[(t[n>>2]|0)+16>>2]|0)+16>>3]=c+1;s=r;return}}c=+l[u>>3];if(a<o-.5)l[(t[(t[n>>2]|0)+16>>2]|0)+16>>3]=c-1;else l[(t[(t[n>>2]|0)+16>>2]|0)+16>>3]=c;if(!(+l[(t[(t[n>>2]|0)+16>>2]|0)+16>>3]==0)){s=r;return}l[(t[(t[n>>2]|0)+16>>2]|0)+16>>3]=+l[15988];s=r;return}dn(t[n>>2]|0,11);s=r;return}function ht(e){e=e|0;var i=0,r=0,n=0,f=0,a=0,o=0,c=0,l=0,b=0,k=0;i=s;s=s+32|0;r=i+16|0;n=i+12|0;f=i+8|0;a=i+4|0;o=i;t[n>>2]=e;t[o>>2]=0;if((t[n>>2]|0)!=0?(t[t[n>>2]>>2]|0)!=0:0){t[f>>2]=t[t[n>>2]>>2];if((u[t[f>>2]>>0]|0|0)>=97?(u[t[f>>2]>>0]|0|0)<=122:0)c=9;else c=6;do if((c|0)==6){if((u[t[f>>2]>>0]|0|0)>=65?(u[t[f>>2]>>0]|0|0)<=90:0){c=9;break}if((u[t[f>>2]>>0]|0|0)==95)c=9}while(0);do if((c|0)==9){t[f>>2]=(t[f>>2]|0)+1;while(1){if((u[t[f>>2]>>0]|0|0)>=97?(u[t[f>>2]>>0]|0|0)<=122:0)l=1;else c=12;do if((c|0)==12){c=0;if((u[t[f>>2]>>0]|0|0)>=65?(u[t[f>>2]>>0]|0|0)<=90:0){l=1;break}if((u[t[f>>2]>>0]|0|0)>=48?(u[t[f>>2]>>0]|0|0)<=57:0){l=1;break}if((u[t[f>>2]>>0]|0|0)!=95?(u[t[f>>2]>>0]|0|0)!=46:0)l=(u[t[f>>2]>>0]|0|0)==45;else l=1}while(0);b=t[f>>2]|0;if(!l)break;t[f>>2]=b+1}if((((((((u[b>>0]|0|0)!=32?(u[t[f>>2]>>0]|0|0)!=62:0)?(u[t[f>>2]>>0]|0|0)!=47:0)?(u[t[f>>2]>>0]|0|0)!=91:0)?(u[t[f>>2]>>0]|0|0)!=93:0)?(u[t[f>>2]>>0]|0|0)!=58:0)?(u[t[f>>2]>>0]|0|0)!=64:0)?(u[t[f>>2]>>0]|0|0)!=42:0)break;t[o>>2]=(t[f>>2]|0)-(t[t[n>>2]>>2]|0);if(!(t[o>>2]|0)){t[r>>2]=0;k=t[r>>2]|0;s=i;return k|0}else{t[a>>2]=ql(t[t[n>>2]>>2]|0,t[o>>2]|0)|0;t[t[n>>2]>>2]=t[f>>2];t[r>>2]=t[a>>2];k=t[r>>2]|0;s=i;return k|0}}while(0);t[r>>2]=su(t[n>>2]|0,0)|0;k=t[r>>2]|0;s=i;return k|0}t[r>>2]=0;k=t[r>>2]|0;s=i;return k|0}function wt(e){e=e|0;var i=0,r=0,n=0,f=0,a=0,o=0,c=0,l=0,b=0,k=0;i=s;s=s+32|0;r=i+16|0;n=i+12|0;f=i+8|0;a=i+4|0;o=i;t[n>>2]=e;t[o>>2]=0;if((t[n>>2]|0)!=0?(t[t[n>>2]>>2]|0)!=0:0){t[f>>2]=t[t[n>>2]>>2];if((u[t[f>>2]>>0]|0|0)>=97?(u[t[f>>2]>>0]|0|0)<=122:0)c=10;else c=6;do if((c|0)==6){if((u[t[f>>2]>>0]|0|0)>=65?(u[t[f>>2]>>0]|0|0)<=90:0){c=10;break}if(!((u[t[f>>2]>>0]|0|0)!=95?(u[t[f>>2]>>0]|0|0)!=58:0))c=10}while(0);if((c|0)==10){t[f>>2]=(t[f>>2]|0)+1;while(1){if((u[t[f>>2]>>0]|0|0)>=97?(u[t[f>>2]>>0]|0|0)<=122:0)l=1;else c=13;do if((c|0)==13){c=0;if((u[t[f>>2]>>0]|0|0)>=65?(u[t[f>>2]>>0]|0|0)<=90:0){l=1;break}if((u[t[f>>2]>>0]|0|0)>=48?(u[t[f>>2]>>0]|0|0)<=57:0){l=1;break}if(((u[t[f>>2]>>0]|0|0)!=95?(u[t[f>>2]>>0]|0|0)!=45:0)?(u[t[f>>2]>>0]|0|0)!=58:0)l=(u[t[f>>2]>>0]|0|0)==46;else l=1}while(0);b=t[f>>2]|0;if(!l)break;t[f>>2]=b+1}if((u[b>>0]|0|0)>0?(u[t[f>>2]>>0]|0|0)<128:0){t[o>>2]=(t[f>>2]|0)-(t[t[n>>2]>>2]|0);if((t[o>>2]|0)>>>0>5e4){t[t[n>>2]>>2]=t[f>>2];dn(t[n>>2]|0,7);t[r>>2]=0;k=t[r>>2]|0;s=i;return k|0}else{t[a>>2]=ql(t[t[n>>2]>>2]|0,t[o>>2]|0)|0;t[t[n>>2]>>2]=t[f>>2];t[r>>2]=t[a>>2];k=t[r>>2]|0;s=i;return k|0}}}t[r>>2]=su(t[n>>2]|0,1)|0;k=t[r>>2]|0;s=i;return k|0}t[r>>2]=0;k=t[r>>2]|0;s=i;return k|0}function dt(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i+4|0;n=i;t[n>>2]=e;do if(t[n>>2]|0){if(Xl(t[n>>2]|0,129400)|0){t[r>>2]=1;break}if(Xl(t[n>>2]|0,129408)|0){t[r>>2]=1;break}if(Xl(t[n>>2]|0,129416)|0){t[r>>2]=1;break}if(Xl(t[n>>2]|0,129424)|0){t[r>>2]=1;break}else{t[r>>2]=0;break}}else t[r>>2]=0;while(0);s=i;return t[r>>2]|0}function vt(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,a=0,o=0,c=0,b=0;r=s;s=s+32|0;n=r;f=r+20|0;a=r+16|0;o=r+12|0;c=r+8|0;t[a>>2]=e;t[o>>2]=i;e:do if((t[a>>2]|0)==0|(t[o>>2]|0)==0)t[f>>2]=0;else switch(t[t[o>>2]>>2]|0){case 9:case 1:{if(!(t[(t[o>>2]|0)+4>>2]|0)){t[f>>2]=0;break e}else{t[f>>2]=(t[t[(t[o>>2]|0)+4>>2]>>2]|0)!=0&1;break e}break}case 2:{t[f>>2]=t[(t[o>>2]|0)+8>>2];break e;break}case 7:{t[c>>2]=t[(t[o>>2]|0)+28>>2];if(!(t[c>>2]|0)){t[f>>2]=0;break e}else{t[f>>2]=(t[t[c>>2]>>2]|0)!=0&1;break e}break}case 4:{if(t[(t[o>>2]|0)+24>>2]|0)b=(u[t[(t[o>>2]|0)+24>>2]>>0]|0|0)!=0;else b=0;t[f>>2]=b&1;break e;break}case 3:{t[f>>2]=+l[(t[o>>2]|0)+16>>3]==+(t[(t[(t[a>>2]|0)+12>>2]|0)+72>>2]|0)&1;break e;break}default:{i=t[33976]|0;e=t[33980]|0;t[n>>2]=128552;t[n+4>>2]=14647;yAi[i&511](e,129448,n);t[f>>2]=0;break e}}while(0);s=r;return t[f>>2]|0}function mt(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,a=0,o=0,c=0,l=0;r=s;s=s+32|0;n=r+16|0;f=r+12|0;a=r+8|0;o=r+4|0;c=r;t[f>>2]=e;t[a>>2]=i;t[c>>2]=bu(t[f>>2]|0,t[a>>2]|0)|0;if(t[c>>2]|0){t[n>>2]=t[c>>2];l=t[n>>2]|0;s=r;return l|0}kn();t[o>>2]=mf(t[a>>2]|0,t[f>>2]|0)|0;if(!(t[o>>2]|0)){t[n>>2]=0;l=t[n>>2]|0;s=r;return l|0}ku(t[o>>2]|0,1);f=t[o>>2]|0;if(t[(t[o>>2]|0)+8>>2]|0){_f(f);t[n>>2]=0;l=t[n>>2]|0;s=r;return l|0}i=t[o>>2]|0;if(u[t[f>>2]>>0]|0){vn(i,128552,14835,7);t[c>>2]=0}else{t[c>>2]=t[i+32>>2];t[(t[o>>2]|0)+32>>2]=0}_f(t[o>>2]|0);if(((t[c>>2]|0)!=0?(o=Yl(t[a>>2]|0)|0,t[(t[c>>2]|0)+16>>2]=o,(t[t[c>>2]>>2]|0)>1):0)?(t[(t[c>>2]|0)+12>>2]|0)>=0:0)hu(t[c>>2]|0,(t[(t[c>>2]|0)+8>>2]|0)+((t[(t[c>>2]|0)+12>>2]|0)*40|0)|0);t[n>>2]=t[c>>2];l=t[n>>2]|0;s=r;return l|0}function _t(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0;r=s;s=s+16|0;n=r+8|0;f=r+4|0;u=r;t[n>>2]=e;t[f>>2]=i;t[u>>2]=0;wu(t[n>>2]|0,t[f>>2]|0,u,0)|0;s=r;return t[u>>2]|0}function pt(e){e=e|0;var i=0,r=0,n=0,f=0;i=s;s=s+16|0;r=i+4|0;n=i;t[r>>2]=e;if(!(t[r>>2]|0)){s=i;return}t[n>>2]=bu(t[(t[r>>2]|0)+12>>2]|0,t[(t[r>>2]|0)+4>>2]|0)|0;e=t[r>>2]|0;e:do if(t[n>>2]|0){if(t[e+32>>2]|0)mn(t[(t[r>>2]|0)+32>>2]|0);t[(t[r>>2]|0)+32>>2]=t[n>>2];if(t[t[r>>2]>>2]|0)while(1){if(!(u[t[t[r>>2]>>2]>>0]|0))break e;f=t[r>>2]|0;t[f>>2]=(t[f>>2]|0)+1}}else{ku(e,1);if((((t[(t[r>>2]|0)+8>>2]|0)==0?(t[(t[r>>2]|0)+32>>2]|0)!=0:0)?(t[t[(t[r>>2]|0)+32>>2]>>2]|0)>1:0)?(t[(t[(t[r>>2]|0)+32>>2]|0)+12>>2]|0)>=0:0)hu(t[(t[r>>2]|0)+32>>2]|0,(t[(t[(t[r>>2]|0)+32>>2]|0)+8>>2]|0)+((t[(t[(t[r>>2]|0)+32>>2]|0)+12>>2]|0)*40|0)|0)}while(0);if(t[(t[r>>2]|0)+8>>2]|0){s=i;return}du(t[r>>2]|0,0)|0;s=i;return}function Et(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0;r=s;s=s+48|0;n=r;f=r+32|0;a=r+28|0;o=r+24|0;c=r+20|0;l=r+16|0;b=r+12|0;k=r+8|0;h=r+4|0;t[a>>2]=e;t[o>>2]=i;t[k>>2]=0;t[h>>2]=0;if(!(t[o>>2]|0)){cp(0,0,0,0,0,12,1,3,128552,15056,0,0,0,0,0,129480,n);t[f>>2]=0;w=t[f>>2]|0;s=r;return w|0}kn();t[c>>2]=mf(t[a>>2]|0,t[o>>2]|0)|0;if(!(t[c>>2]|0)){t[f>>2]=0;w=t[f>>2]|0;s=r;return w|0}pt(t[c>>2]|0);do if(!(t[(t[c>>2]|0)+16>>2]|0)){yAi[t[135904>>2]&511](t[33980]|0,129504,n);t[l>>2]=0}else{if(((u[t[t[c>>2]>>2]>>0]|0|0)!=0?(t[(t[c>>2]|0)+32>>2]|0)!=0:0)?(t[(t[(t[c>>2]|0)+32>>2]|0)+24>>2]|0)==0:0){vn(t[c>>2]|0,128552,15074,7);t[l>>2]=0;break}t[l>>2]=En(t[c>>2]|0)|0}while(0);do{t[b>>2]=En(t[c>>2]|0)|0;if(t[b>>2]|0){if((t[b>>2]|0)!=(t[k>>2]|0))t[h>>2]=(t[h>>2]|0)+1;zt(t[o>>2]|0,t[b>>2]|0)}}while((t[b>>2]|0)!=0);if((t[h>>2]|0)!=0&(t[l>>2]|0)!=0){b=t[33976]|0;o=t[33980]|0;t[n>>2]=t[h>>2];yAi[b&511](o,129544,n)}if(t[(t[c>>2]|0)+8>>2]|0){_n(t[l>>2]|0);t[l>>2]=0}_f(t[c>>2]|0);t[f>>2]=t[l>>2];w=t[f>>2]|0;s=r;return w|0}function St(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0;n=s;s=s+48|0;f=n+36|0;u=n+32|0;a=n+28|0;o=n+16|0;c=n+8|0;l=n+24|0;b=n;t[f>>2]=e;t[u>>2]=i;t[a>>2]=r;r=o;t[r>>2]=t[u>>2];t[r+4>>2]=0;while(1){r=o;u=t[r+4>>2]|0;if(!((u|0)<0|((u|0)==0?(t[r>>2]|0)>>>0<(t[a>>2]|0)>>>0:0)))break;r=o;u=BY(t[r>>2]|0,t[r+4>>2]|0,1,0)|0;if((vu(t[(t[f>>2]|0)+(u<<2)>>2]|0,t[(t[f>>2]|0)+(t[o>>2]<<2)>>2]|0)|0)>0){t[l>>2]=t[(t[f>>2]|0)+(t[o>>2]<<2)>>2];u=mu(t[f>>2]|0,t[l>>2]|0,t[o>>2]|0)|0;r=b;t[r>>2]=u;t[r+4>>2]=P;r=o;u=BY(t[r>>2]|0,t[r+4>>2]|0,1,0)|0;r=c;t[r>>2]=u;t[r+4>>2]=P;while(1){r=c;u=t[r+4>>2]|0;i=b;e=t[i+4>>2]|0;if(!((u|0)>(e|0)|((u|0)==(e|0)?(t[r>>2]|0)>>>0>=(t[i>>2]|0)>>>0:0)))break;i=t[(t[f>>2]|0)+(t[c>>2]<<2)>>2]|0;r=c;e=jY(t[r>>2]|0,t[r+4>>2]|0,1,0)|0;t[(t[f>>2]|0)+(e<<2)>>2]=i;i=c;e=jY(t[i>>2]|0,t[i+4>>2]|0,-1,-1)|0;i=c;t[i>>2]=e;t[i+4>>2]=P}t[(t[f>>2]|0)+(t[b>>2]<<2)>>2]=t[l>>2]}i=o;e=jY(t[i>>2]|0,t[i+4>>2]|0,1,0)|0;i=o;t[i>>2]=e;t[i+4>>2]=P}s=n;return}function gt(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0;f=s;s=s+48|0;u=f+16|0;a=f+32|0;o=f+8|0;c=f+28|0;l=f;b=f+24|0;t[a>>2]=e;e=o;t[e>>2]=i;t[e+4>>2]=r;t[c>>2]=n;n=o;r=BY(t[c>>2]|0,0,t[n>>2]|0,t[n+4>>2]|0)|0;if((r|0)==1&(P|0)==0){r=u;t[r>>2]=1;t[r+4>>2]=0;k=u;h=k;w=t[h>>2]|0;d=k+4|0;v=d;m=t[v>>2]|0;P=m;s=f;return w|0}r=o;n=t[r>>2]|0;e=t[r+4>>2]|0;r=BY(t[c>>2]|0,0,2,0)|0;i=P;if((e|0)>(i|0)|(e|0)==(i|0)&n>>>0>=r>>>0){if((vu(t[(t[a>>2]|0)+((t[c>>2]|0)-2<<2)>>2]|0,t[(t[a>>2]|0)+((t[c>>2]|0)-1<<2)>>2]|0)|0)>0){t[b>>2]=t[(t[a>>2]|0)+((t[c>>2]|0)-2<<2)>>2];t[(t[a>>2]|0)+((t[c>>2]|0)-2<<2)>>2]=t[(t[a>>2]|0)+((t[c>>2]|0)-1<<2)>>2];t[(t[a>>2]|0)+((t[c>>2]|0)-1<<2)>>2]=t[b>>2]}b=u;t[b>>2]=2;t[b+4>>2]=0;k=u;h=k;w=t[h>>2]|0;d=k+4|0;v=d;m=t[v>>2]|0;P=m;s=f;return w|0}b=o;r=jY(t[b>>2]|0,t[b+4>>2]|0,2,0)|0;b=l;t[b>>2]=r;t[b+4>>2]=P;b=t[(t[a>>2]|0)+(t[o>>2]<<2)>>2]|0;r=o;n=jY(t[r>>2]|0,t[r+4>>2]|0,1,0)|0;if((vu(b,t[(t[a>>2]|0)+(n<<2)>>2]|0)|0)<=0){while(1){n=l;b=t[n>>2]|0;r=t[n+4>>2]|0;n=BY(t[c>>2]|0,0,1,0)|0;if((b|0)==(n|0)&(r|0)==(P|0))break;r=l;n=BY(t[r>>2]|0,t[r+4>>2]|0,1,0)|0;if((vu(t[(t[a>>2]|0)+(n<<2)>>2]|0,t[(t[a>>2]|0)+(t[l>>2]<<2)>>2]|0)|0)>0)break;n=l;r=jY(t[n>>2]|0,t[n+4>>2]|0,1,0)|0;n=l;t[n>>2]=r;t[n+4>>2]=P}n=l;r=o;b=BY(t[n>>2]|0,t[n+4>>2]|0,t[r>>2]|0,t[r+4>>2]|0)|0;r=u;t[r>>2]=b;t[r+4>>2]=P;k=u;h=k;w=t[h>>2]|0;d=k+4|0;v=d;m=t[v>>2]|0;P=m;s=f;return w|0}else{while(1){r=l;b=t[r>>2]|0;n=t[r+4>>2]|0;r=BY(t[c>>2]|0,0,1,0)|0;if((b|0)==(r|0)&(n|0)==(P|0))break;n=l;r=BY(t[n>>2]|0,t[n+4>>2]|0,1,0)|0;if((vu(t[(t[a>>2]|0)+(r<<2)>>2]|0,t[(t[a>>2]|0)+(t[l>>2]<<2)>>2]|0)|0)<=0)break;r=l;n=jY(t[r>>2]|0,t[r+4>>2]|0,1,0)|0;r=l;t[r>>2]=n;t[r+4>>2]=P}c=t[a>>2]|0;a=o;r=t[a>>2]|0;n=t[a+4>>2]|0;a=l;b=BY(t[a>>2]|0,t[a+4>>2]|0,1,0)|0;_u(c,r,n,b,P);b=l;l=o;o=BY(t[b>>2]|0,t[b+4>>2]|0,t[l>>2]|0,t[l+4>>2]|0)|0;l=u;t[l>>2]=o;t[l+4>>2]=P;k=u;h=k;w=t[h>>2]|0;d=k+4|0;v=d;m=t[v>>2]|0;P=m;s=f;return w|0}return 0}function yt(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0,S=0,g=0;f=s;s=s+80|0;u=f+64|0;a=f+60|0;o=f+56|0;c=f+52|0;l=f+40|0;b=f+32|0;k=f+24|0;h=f+48|0;w=f+16|0;d=f+8|0;v=f;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;t[c>>2]=n;n=(t[a>>2]|0)+((t[o>>2]|0)-2<<4)+8|0;r=t[n+4>>2]|0;i=l;t[i>>2]=t[n>>2];t[i+4>>2]=r;r=(t[a>>2]|0)+((t[o>>2]|0)-1<<4)+8|0;i=t[r+4>>2]|0;n=b;t[n>>2]=t[r>>2];t[n+4>>2]=i;i=(t[a>>2]|0)+((t[o>>2]|0)-2<<4)|0;o=t[i+4>>2]|0;a=k;t[a>>2]=t[i>>2];t[a+4>>2]=o;o=t[c>>2]|0;a=l;i=t[a+4>>2]|0;n=b;r=t[n+4>>2]|0;e=(i|0)<(r|0)|((i|0)==(r|0)?(t[a>>2]|0)>>>0<(t[n>>2]|0)>>>0:0);n=l;a=t[n+4>>2]|0;a=b;r=t[a+4>>2]|0;r=e?t[n>>2]|0:t[a>>2]|0;pu(o,r);t[h>>2]=t[(t[c>>2]|0)+4>>2];c=l;r=t[c+4>>2]|0;o=b;a=t[o+4>>2]|0;n=t[h>>2]|0;e=k;i=t[e>>2]|0;m=t[e+4>>2]|0;if((r|0)<(a|0)|((r|0)==(a|0)?(t[c>>2]|0)>>>0<(t[o>>2]|0)>>>0:0)){o=(t[u>>2]|0)+(i<<2)|0;c=l;a=$Y(t[c>>2]|0,t[c+4>>2]|0,4,0)|0;YY(n|0,o|0,a|0)|0;a=w;t[a>>2]=0;t[a+4>>2]=0;a=k;o=l;c=jY(t[a>>2]|0,t[a+4>>2]|0,t[o>>2]|0,t[o+4>>2]|0)|0;o=d;t[o>>2]=c;t[o+4>>2]=P;o=k;c=t[o+4>>2]|0;a=v;t[a>>2]=t[o>>2];t[a+4>>2]=c;while(1){c=v;a=t[c>>2]|0;o=t[c+4>>2]|0;c=k;r=l;e=jY(t[c>>2]|0,t[c+4>>2]|0,t[r>>2]|0,t[r+4>>2]|0)|0;r=b;c=jY(e|0,P|0,t[r>>2]|0,t[r+4>>2]|0)|0;r=P;if(!((o|0)<(r|0)|(o|0)==(r|0)&a>>>0<c>>>0))break;c=w;a=t[c+4>>2]|0;r=l;o=t[r+4>>2]|0;do if((a|0)<(o|0)|((a|0)==(o|0)?(t[c>>2]|0)>>>0<(t[r>>2]|0)>>>0:0)?(e=d,_=t[e>>2]|0,p=t[e+4>>2]|0,e=k,E=l,S=jY(t[e>>2]|0,t[e+4>>2]|0,t[E>>2]|0,t[E+4>>2]|0)|0,E=b,e=jY(S|0,P|0,t[E>>2]|0,t[E+4>>2]|0)|0,E=P,(p|0)<(E|0)|(p|0)==(E|0)&_>>>0<e>>>0):0)if((vu(t[(t[h>>2]|0)+(t[w>>2]<<2)>>2]|0,t[(t[u>>2]|0)+(t[d>>2]<<2)>>2]|0)|0)<=0){e=w;_=t[e>>2]|0;E=jY(_|0,t[e+4>>2]|0,1,0)|0;e=w;t[e>>2]=E;t[e+4>>2]=P;t[(t[u>>2]|0)+(t[v>>2]<<2)>>2]=t[(t[h>>2]|0)+(_<<2)>>2];break}else{_=d;e=t[_>>2]|0;E=jY(e|0,t[_+4>>2]|0,1,0)|0;_=d;t[_>>2]=E;t[_+4>>2]=P;t[(t[u>>2]|0)+(t[v>>2]<<2)>>2]=t[(t[u>>2]|0)+(e<<2)>>2];break}else g=9;while(0);do if((g|0)==9){g=0;r=w;c=t[r+4>>2]|0;o=l;a=t[o+4>>2]|0;if((c|0)<(a|0)|((c|0)==(a|0)?(t[r>>2]|0)>>>0<(t[o>>2]|0)>>>0:0)){o=w;r=t[o>>2]|0;a=jY(r|0,t[o+4>>2]|0,1,0)|0;o=w;t[o>>2]=a;t[o+4>>2]=P;t[(t[u>>2]|0)+(t[v>>2]<<2)>>2]=t[(t[h>>2]|0)+(r<<2)>>2];break}else{r=d;o=t[r>>2]|0;a=jY(o|0,t[r+4>>2]|0,1,0)|0;r=d;t[r>>2]=a;t[r+4>>2]=P;t[(t[u>>2]|0)+(t[v>>2]<<2)>>2]=t[(t[u>>2]|0)+(o<<2)>>2];break}}while(0);o=v;r=jY(t[o>>2]|0,t[o+4>>2]|0,1,0)|0;o=v;t[o>>2]=r;t[o+4>>2]=P}s=f;return}else{o=l;r=jY(i|0,m|0,t[o>>2]|0,t[o+4>>2]|0)|0;o=(t[u>>2]|0)+(r<<2)|0;r=b;m=$Y(t[r>>2]|0,t[r+4>>2]|0,4,0)|0;YY(n|0,o|0,m|0)|0;m=b;o=BY(t[m>>2]|0,t[m+4>>2]|0,1,0)|0;m=w;t[m>>2]=o;t[m+4>>2]=P;m=k;o=l;n=jY(t[m>>2]|0,t[m+4>>2]|0,t[o>>2]|0,t[o+4>>2]|0)|0;o=BY(n|0,P|0,1,0)|0;n=d;t[n>>2]=o;t[n+4>>2]=P;n=k;o=l;l=jY(t[n>>2]|0,t[n+4>>2]|0,t[o>>2]|0,t[o+4>>2]|0)|0;o=b;b=jY(l|0,P|0,t[o>>2]|0,t[o+4>>2]|0)|0;o=BY(b|0,P|0,1,0)|0;b=v;t[b>>2]=o;t[b+4>>2]=P;while(1){b=v;o=t[b+4>>2]|0;l=k;n=t[l+4>>2]|0;if(!((o|0)>(n|0)|((o|0)==(n|0)?(t[b>>2]|0)>>>0>=(t[l>>2]|0)>>>0:0)))break;l=w;b=t[l+4>>2]|0;do if((b|0)>0|(b|0)==0&(t[l>>2]|0)>>>0>=0?(n=d,o=t[n+4>>2]|0,m=k,r=t[m+4>>2]|0,(o|0)>(r|0)|((o|0)==(r|0)?(t[n>>2]|0)>>>0>=(t[m>>2]|0)>>>0:0)):0)if((vu(t[(t[u>>2]|0)+(t[d>>2]<<2)>>2]|0,t[(t[h>>2]|0)+(t[w>>2]<<2)>>2]|0)|0)>0){m=d;n=t[m>>2]|0;r=jY(n|0,t[m+4>>2]|0,-1,-1)|0;m=d;t[m>>2]=r;t[m+4>>2]=P;t[(t[u>>2]|0)+(t[v>>2]<<2)>>2]=t[(t[u>>2]|0)+(n<<2)>>2];break}else{n=w;m=t[n>>2]|0;r=jY(m|0,t[n+4>>2]|0,-1,-1)|0;n=w;t[n>>2]=r;t[n+4>>2]=P;t[(t[u>>2]|0)+(t[v>>2]<<2)>>2]=t[(t[h>>2]|0)+(m<<2)>>2];break}else g=20;while(0);do if((g|0)==20){g=0;l=w;b=t[l+4>>2]|0;if((b|0)>0|(b|0)==0&(t[l>>2]|0)>>>0>=0){l=w;b=t[l>>2]|0;m=jY(b|0,t[l+4>>2]|0,-1,-1)|0;l=w;t[l>>2]=m;t[l+4>>2]=P;t[(t[u>>2]|0)+(t[v>>2]<<2)>>2]=t[(t[h>>2]|0)+(b<<2)>>2];break}else{b=d;l=t[b>>2]|0;m=jY(l|0,t[b+4>>2]|0,-1,-1)|0;b=d;t[b>>2]=m;t[b+4>>2]=P;t[(t[u>>2]|0)+(t[v>>2]<<2)>>2]=t[(t[u>>2]|0)+(l<<2)>>2];break}}while(0);l=v;b=jY(t[l>>2]|0,t[l+4>>2]|0,-1,-1)|0;l=v;t[l>>2]=b;t[l+4>>2]=P}s=f;return}}function Ft(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0;r=s;s=s+64|0;n=r+48|0;f=r+44|0;u=r+40|0;a=r+32|0;o=r+24|0;c=r+16|0;l=r+8|0;b=r;t[f>>2]=e;t[u>>2]=i;if((t[u>>2]|0)<2){t[n>>2]=1;k=t[n>>2]|0;s=r;return k|0}i=t[u>>2]|0;if((t[u>>2]|0)==2){e=(t[f>>2]|0)+(i-2<<4)+8|0;h=t[e+4>>2]|0;w=l;t[w>>2]=t[e>>2];t[w+4>>2]=h;h=(t[f>>2]|0)+((t[u>>2]|0)-1<<4)+8|0;w=t[h+4>>2]|0;e=b;t[e>>2]=t[h>>2];t[e+4>>2]=w;w=l;l=t[w+4>>2]|0;e=b;b=t[e+4>>2]|0;if((l|0)<(b|0)|((l|0)==(b|0)?(t[w>>2]|0)>>>0<=(t[e>>2]|0)>>>0:0)){t[n>>2]=0;k=t[n>>2]|0;s=r;return k|0}else{t[n>>2]=1;k=t[n>>2]|0;s=r;return k|0}}e=(t[f>>2]|0)+(i-3<<4)+8|0;i=t[e+4>>2]|0;w=a;t[w>>2]=t[e>>2];t[w+4>>2]=i;i=(t[f>>2]|0)+((t[u>>2]|0)-2<<4)+8|0;w=t[i+4>>2]|0;e=o;t[e>>2]=t[i>>2];t[e+4>>2]=w;w=(t[f>>2]|0)+((t[u>>2]|0)-1<<4)+8|0;u=t[w+4>>2]|0;f=c;t[f>>2]=t[w>>2];t[f+4>>2]=u;u=a;a=t[u>>2]|0;f=t[u+4>>2]|0;u=o;w=c;e=jY(t[u>>2]|0,t[u+4>>2]|0,t[w>>2]|0,t[w+4>>2]|0)|0;w=P;if(!((f|0)<(w|0)|(f|0)==(w|0)&a>>>0<=e>>>0)?(e=o,o=t[e+4>>2]|0,a=c,c=t[a+4>>2]|0,!((o|0)<(c|0)|((o|0)==(c|0)?(t[e>>2]|0)>>>0<=(t[a>>2]|0)>>>0:0))):0){t[n>>2]=1;k=t[n>>2]|0;s=r;return k|0}t[n>>2]=0;k=t[n>>2]|0;s=r;return k|0}function Ot(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;var u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0;u=s;s=s+48|0;a=u+40|0;o=u+36|0;c=u+32|0;l=u+28|0;b=u+24|0;k=u+16|0;h=u+8|0;w=u;t[a>>2]=e;t[o>>2]=i;t[c>>2]=r;t[l>>2]=n;t[b>>2]=f;while(1){if((t[c>>2]|0)<=1){d=16;break}if((t[c>>2]|0)==2?(f=(t[o>>2]|0)+8|0,n=(t[o>>2]|0)+24|0,r=jY(t[f>>2]|0,t[f+4>>2]|0,t[n>>2]|0,t[n+4>>2]|0)|0,(P|0)==0?(r|0)==(t[b>>2]|0):0):0){d=5;break}if((t[c>>2]|0)==2?(r=(t[o>>2]|0)+8|0,n=t[r+4>>2]|0,f=(t[o>>2]|0)+24|0,i=t[f+4>>2]|0,(n|0)<(i|0)|((n|0)==(i|0)?(t[r>>2]|0)>>>0<=(t[f>>2]|0)>>>0:0)):0){d=8;break}if((t[c>>2]|0)==2){d=16;break}f=(t[o>>2]|0)+((t[c>>2]|0)-3<<4)+8|0;r=t[f+4>>2]|0;i=k;t[i>>2]=t[f>>2];t[i+4>>2]=r;r=(t[o>>2]|0)+((t[c>>2]|0)-2<<4)+8|0;i=t[r+4>>2]|0;f=h;t[f>>2]=t[r>>2];t[f+4>>2]=i;i=(t[o>>2]|0)+((t[c>>2]|0)-1<<4)+8|0;f=t[i+4>>2]|0;r=w;t[r>>2]=t[i>>2];t[r+4>>2]=f;f=k;r=t[f>>2]|0;i=t[f+4>>2]|0;f=h;n=w;e=jY(t[f>>2]|0,t[f+4>>2]|0,t[n>>2]|0,t[n+4>>2]|0)|0;n=P;if(!((i|0)<(n|0)|(i|0)==(n|0)&r>>>0<=e>>>0)){e=h;r=t[e+4>>2]|0;n=w;i=t[n+4>>2]|0;if(!((r|0)<(i|0)|((r|0)==(i|0)?(t[e>>2]|0)>>>0<=(t[n>>2]|0)>>>0:0))){d=16;break}yt(t[a>>2]|0,t[o>>2]|0,t[c>>2]|0,t[l>>2]|0);n=(t[o>>2]|0)+((t[c>>2]|0)-1<<4)+8|0;e=(t[o>>2]|0)+((t[c>>2]|0)-2<<4)+8|0;i=e;r=jY(t[i>>2]|0,t[i+4>>2]|0,t[n>>2]|0,t[n+4>>2]|0)|0;n=e;t[n>>2]=r;t[n+4>>2]=P;t[c>>2]=(t[c>>2]|0)+-1;continue}n=k;r=t[n+4>>2]|0;e=w;i=t[e+4>>2]|0;f=t[a>>2]|0;v=t[o>>2]|0;m=t[c>>2]|0;if((r|0)<(i|0)|((r|0)==(i|0)?(t[n>>2]|0)>>>0<(t[e>>2]|0)>>>0:0)){yt(f,v,m-1|0,t[l>>2]|0);e=(t[o>>2]|0)+((t[c>>2]|0)-2<<4)+8|0;n=(t[o>>2]|0)+((t[c>>2]|0)-3<<4)+8|0;i=n;r=jY(t[i>>2]|0,t[i+4>>2]|0,t[e>>2]|0,t[e+4>>2]|0)|0;e=n;t[e>>2]=r;t[e+4>>2]=P;e=(t[o>>2]|0)+((t[c>>2]|0)-2<<4)|0;r=(t[o>>2]|0)+((t[c>>2]|0)-1<<4)|0;t[e+0>>2]=t[r+0>>2];t[e+4>>2]=t[r+4>>2];t[e+8>>2]=t[r+8>>2];t[e+12>>2]=t[r+12>>2];t[c>>2]=(t[c>>2]|0)+-1;continue}else{yt(f,v,m,t[l>>2]|0);m=(t[o>>2]|0)+((t[c>>2]|0)-1<<4)+8|0;v=(t[o>>2]|0)+((t[c>>2]|0)-2<<4)+8|0;f=v;r=jY(t[f>>2]|0,t[f+4>>2]|0,t[m>>2]|0,t[m+4>>2]|0)|0;m=v;t[m>>2]=r;t[m+4>>2]=P;t[c>>2]=(t[c>>2]|0)+-1;continue}}if((d|0)==5){yt(t[a>>2]|0,t[o>>2]|0,t[c>>2]|0,t[l>>2]|0);w=(t[o>>2]|0)+24|0;k=(t[o>>2]|0)+8|0;h=k;b=jY(t[h>>2]|0,t[h+4>>2]|0,t[w>>2]|0,t[w+4>>2]|0)|0;w=k;t[w>>2]=b;t[w+4>>2]=P;t[c>>2]=(t[c>>2]|0)+-1;_=t[c>>2]|0;s=u;return _|0}else if((d|0)==8){yt(t[a>>2]|0,t[o>>2]|0,t[c>>2]|0,t[l>>2]|0);l=(t[o>>2]|0)+24|0;a=(t[o>>2]|0)+8|0;o=a;w=jY(t[o>>2]|0,t[o+4>>2]|0,t[l>>2]|0,t[l+4>>2]|0)|0;l=a;t[l>>2]=w;t[l+4>>2]=P;t[c>>2]=(t[c>>2]|0)+-1;_=t[c>>2]|0;s=u;return _|0}else if((d|0)==16){_=t[c>>2]|0;s=u;return _|0}return 0}function At(){var e=0;e=s;if(+l[16480]==0)l[16480]=+Eu(131848);s=e;return+ +l[16480]}function Mt(){var e=0;e=s;if(+l[16479]==0)l[16479]=-+At();s=e;return+ +l[16479]}function Rt(){var e=0;e=s;if(+l[16478]==0)l[16478]=+bY(128928);s=e;return+ +l[16478]}function Nt(){var e=0,i=0;e=s;i=+Eu(131808);s=e;return+i}function Tt(e){e=+e;var i=0,r=0,n=0;i=s;s=s+16|0;r=i;l[r>>3]=e;n=Su(+l[r>>3])|0;r=P&2147483647;s=i;return(r>>>0>2146435072|(r|0)==2146435072&n>>>0>0)&1|0}function Lt(e){e=+e;var i=0,r=0,n=0,f=0;i=s;s=s+16|0;r=i;l[r>>3]=e;n=Su(+l[r>>3])|0;if(!((n|0)==0&(P&2147483647|0)==2146435072)){f=0;s=i;return f|0}f=+l[r>>3]>0?1:-1;s=i;return f|0}function Dt(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i+4|0;n=i;t[r>>2]=e;if(!(t[r>>2]|0)){s=i;return}if(t[(t[r>>2]|0)+8>>2]|0){t[n>>2]=0;while(1){if((t[n>>2]|0)>=(t[t[r>>2]>>2]|0))break;do if(t[(t[(t[r>>2]|0)+8>>2]|0)+(t[n>>2]<<2)>>2]|0){e=t[(t[(t[r>>2]|0)+8>>2]|0)+(t[n>>2]<<2)>>2]|0;if((t[(t[(t[(t[r>>2]|0)+8>>2]|0)+(t[n>>2]<<2)>>2]|0)+4>>2]|0)==18){Rn(e);break}else{ty(e);break}}while(0);t[n>>2]=(t[n>>2]|0)+1}pAi[t[135736>>2]&511](t[(t[r>>2]|0)+8>>2]|0)}pAi[t[135736>>2]&511](t[r>>2]|0);s=i;return}function Ct(e,i,r){e=e|0;i=i|0;r=r|0;var f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0;f=s;s=s+128|0;u=f;a=f+16|0;o=f+12|0;c=f+8|0;l=f+4|0;b=f+20|0;t[a>>2]=e;t[o>>2]=i;t[c>>2]=r;t[l>>2]=0;while(1){k=b+((t[l>>2]<<1)+1)|0;if(!((t[l>>2]|0)<25?(t[l>>2]|0)<(t[c>>2]|0):0))break;n[k>>0]=32;n[b+(t[l>>2]<<1)>>0]=32;t[l>>2]=(t[l>>2]|0)+1}n[k>>0]=0;n[b+(t[l>>2]<<1)>>0]=0;if(!(t[o>>2]|0)){k=t[a>>2]|0;t[u>>2]=b;xe(k|0,127912,u|0)|0;xe(t[a>>2]|0,131120,u|0)|0;s=f;return}if(!(t[o>>2]|0)){s=f;return}k=t[a>>2]|0;t[u>>2]=t[t[o>>2]>>2];xe(k|0,131144,u|0)|0;t[l>>2]=0;while(1){if((t[l>>2]|0)>=(t[t[o>>2]>>2]|0))break;k=t[a>>2]|0;t[u>>2]=b;xe(k|0,127912,u|0)|0;k=t[a>>2]|0;t[u>>2]=(t[l>>2]|0)+1;xe(k|0,130840,u|0)|0;It(t[a>>2]|0,t[(t[(t[o>>2]|0)+8>>2]|0)+(t[l>>2]<<2)>>2]|0,(t[c>>2]|0)+1|0);t[l>>2]=(t[l>>2]|0)+1}s=f;return}function Pt(e,i,r){e=e|0;i=i|0;r=r|0;var f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0;f=s;s=s+128|0;u=f;a=f+16|0;o=f+12|0;c=f+8|0;l=f+4|0;b=f+20|0;t[a>>2]=e;t[o>>2]=i;t[c>>2]=r;t[l>>2]=0;while(1){k=b+((t[l>>2]<<1)+1)|0;if(!((t[l>>2]|0)<25?(t[l>>2]|0)<(t[c>>2]|0):0))break;n[k>>0]=32;n[b+(t[l>>2]<<1)>>0]=32;t[l>>2]=(t[l>>2]|0)+1}n[k>>0]=0;n[b+(t[l>>2]<<1)>>0]=0;if(((t[o>>2]|0)!=0?(t[t[o>>2]>>2]|0)!=0:0)?(t[t[(t[o>>2]|0)+8>>2]>>2]|0)!=0:0){
	k=t[a>>2]|0;t[u>>2]=b;xe(k|0,127912,u|0)|0;k=t[a>>2]|0;t[u>>2]=(t[l>>2]|0)+1;xe(k|0,130840,u|0)|0;yu(t[a>>2]|0,t[(t[t[(t[o>>2]|0)+8>>2]>>2]|0)+12>>2]|0,(t[c>>2]|0)+1|0);s=f;return}c=t[a>>2]|0;t[u>>2]=b;xe(c|0,127912,u|0)|0;xe(t[a>>2]|0,131096,u|0)|0;s=f;return}function Bt(e){e=+e;var i=0,r=0,n=0;i=s;s=s+16|0;r=i;l[r>>3]=e;n=Fu(+l[r>>3])|0;s=i;return n|0}function It(e,i,r){e=e|0;i=i|0;r=r|0;var f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0;f=s;s=s+128|0;u=f;a=f+16|0;o=f+12|0;c=f+8|0;l=f+4|0;b=f+20|0;t[a>>2]=e;t[o>>2]=i;t[c>>2]=r;t[l>>2]=0;while(1){k=b+((t[l>>2]<<1)+1)|0;if(!((t[l>>2]|0)<25?(t[l>>2]|0)<(t[c>>2]|0):0))break;n[k>>0]=32;n[b+(t[l>>2]<<1)>>0]=32;t[l>>2]=(t[l>>2]|0)+1}n[k>>0]=0;n[b+(t[l>>2]<<1)>>0]=0;if(!(t[o>>2]|0)){l=t[a>>2]|0;t[u>>2]=b;xe(l|0,127912,u|0)|0;xe(t[a>>2]|0,131072,u|0)|0;s=f;return}if((t[(t[o>>2]|0)+4>>2]|0)!=9?(t[(t[o>>2]|0)+4>>2]|0)!=13:0){l=t[a>>2]|0;k=t[o>>2]|0;if((t[(t[o>>2]|0)+4>>2]|0)==2){lr(l,k,t[c>>2]|0);s=f;return}else{br(l,k,t[c>>2]|0);s=f;return}}c=t[a>>2]|0;t[u>>2]=b;xe(c|0,127912,u|0)|0;xe(t[a>>2]|0,131088,u|0)|0;s=f;return}function Ht(e,i,r){e=e|0;i=i|0;r=r|0;var f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0;f=s;s=s+128|0;u=f;a=f+16|0;o=f+12|0;c=f+8|0;l=f+4|0;b=f+20|0;t[a>>2]=e;t[o>>2]=i;t[c>>2]=r;t[l>>2]=0;while(1){k=b+((t[l>>2]<<1)+1)|0;if(!((t[l>>2]|0)<25?(t[l>>2]|0)<(t[c>>2]|0):0))break;n[k>>0]=32;n[b+(t[l>>2]<<1)>>0]=32;t[l>>2]=(t[l>>2]|0)+1}n[k>>0]=0;n[b+(t[l>>2]<<1)>>0]=0;if(!(t[o>>2]|0)){k=t[a>>2]|0;t[u>>2]=b;xe(k|0,127912,u|0)|0;xe(t[a>>2]|0,131040,u|0)|0;s=f;return}t[l>>2]=0;while(1){if((t[l>>2]|0)>=(t[t[o>>2]>>2]|0))break;k=t[a>>2]|0;t[u>>2]=b;xe(k|0,127912,u|0)|0;k=t[a>>2]|0;t[u>>2]=(t[l>>2]|0)+1;xe(k|0,131064,u|0)|0;pn(t[a>>2]|0,t[(t[(t[o>>2]|0)+8>>2]|0)+(t[l>>2]<<2)>>2]|0,(t[c>>2]|0)+1|0);t[l>>2]=(t[l>>2]|0)+1}s=f;return}function xt(e){e=e|0;var i=0,r=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if(!(t[r>>2]|0)){s=i;return}if(t[t[r>>2]>>2]|0)Ou(t[t[r>>2]>>2]|0);if(t[(t[r>>2]|0)+4>>2]|0)Ou(t[(t[r>>2]|0)+4>>2]|0);if(t[(t[r>>2]|0)+8>>2]|0)Ou(t[(t[r>>2]|0)+8>>2]|0);if(t[(t[r>>2]|0)+12>>2]|0)Ou(t[(t[r>>2]|0)+12>>2]|0);if(t[(t[r>>2]|0)+16>>2]|0)Ou(t[(t[r>>2]|0)+16>>2]|0);pAi[t[135736>>2]&511](t[r>>2]|0);s=i;return}function Ut(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0;r=s;s=s+224|0;n=r;f=r+8|0;u=r+4|0;a=r+16|0;t[f>>2]=e;t[u>>2]=i;i=(t[u>>2]|0)!=0;if(!(t[f>>2]|0))if(i){e=t[u>>2]|0;t[n>>2]=t[u>>2];cp(0,0,0,0,0,12,2,3,0,0,e,0,0,0,0,130976,n);s=r;return}else{cp(0,0,0,0,0,12,2,3,0,0,0,0,0,0,0,131008,n);s=r;return}if(i){t[n>>2]=t[u>>2];as(a,200,130976,n)|0;n=Yl(a)|0;t[(t[f>>2]|0)+144>>2]=n}else{n=Yl(131008)|0;t[(t[f>>2]|0)+144>>2]=n}t[(t[f>>2]|0)+136>>2]=12;t[(t[f>>2]|0)+140>>2]=2;if(!(t[(t[f>>2]|0)+132>>2]|0)){s=r;return}EAi[t[(t[f>>2]|0)+132>>2]&511](t[(t[f>>2]|0)+128>>2]|0,(t[f>>2]|0)+136|0);s=r;return}function zt(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0;r=s;s=s+32|0;n=r+20|0;f=r+16|0;u=r+12|0;a=r+8|0;o=r+4|0;c=r;t[n>>2]=e;t[f>>2]=i;if(!(t[f>>2]|0)){s=r;return}if((t[n>>2]|0)!=0?(t[(t[n>>2]|0)+200>>2]|0)!=0:0){t[u>>2]=t[(t[n>>2]|0)+200>>2];e:do switch(t[t[f>>2]>>2]|0){case 3:{if((t[(t[u>>2]|0)+12>>2]|0)!=0?(t[(t[(t[u>>2]|0)+12>>2]|0)+4>>2]|0)>=(t[(t[u>>2]|0)+32>>2]|0):0){l=35;break e}if((t[(t[u>>2]|0)+12>>2]|0)==0?(n=Au(10)|0,t[(t[u>>2]|0)+12>>2]=n,(t[(t[u>>2]|0)+12>>2]|0)==0):0){l=54;break e}if((Mu(t[(t[u>>2]|0)+12>>2]|0,t[f>>2]|0,0)|0)==-1)l=54;break}case 7:{if(t[(t[f>>2]|0)+28>>2]|0){Ba(t[(t[f>>2]|0)+28>>2]|0);l=54}else l=54;break}case 2:{if((t[(t[u>>2]|0)+8>>2]|0)!=0?(t[(t[(t[u>>2]|0)+8>>2]|0)+4>>2]|0)>=(t[(t[u>>2]|0)+28>>2]|0):0){l=35;break e}if((t[(t[u>>2]|0)+8>>2]|0)==0?(n=Au(10)|0,t[(t[u>>2]|0)+8>>2]=n,(t[(t[u>>2]|0)+8>>2]|0)==0):0){l=54;break e}if((Mu(t[(t[u>>2]|0)+8>>2]|0,t[f>>2]|0,0)|0)==-1)l=54;break}case 9:case 1:{if(t[(t[f>>2]|0)+4>>2]|0){n=t[f>>2]|0;if(t[(t[f>>2]|0)+8>>2]|0){t[n>>2]=9;Dt(t[(t[f>>2]|0)+4>>2]|0);t[(t[f>>2]|0)+4>>2]=0;l=35;break e}do if((t[(t[n+4>>2]|0)+4>>2]|0)<=40){if((t[t[u>>2]>>2]|0)!=0?(t[(t[t[u>>2]>>2]|0)+4>>2]|0)>=(t[(t[u>>2]|0)+20>>2]|0):0)break;if((t[t[u>>2]>>2]|0)==0?(i=Au(10)|0,t[t[u>>2]>>2]=i,(t[t[u>>2]>>2]|0)==0):0){l=54;break e}if((Mu(t[t[u>>2]>>2]|0,t[f>>2]|0,0)|0)==-1){l=54;break e}else break e}while(0);Bn(t[(t[f>>2]|0)+4>>2]|0);t[(t[f>>2]|0)+4>>2]=0;l=35}else l=35;break}case 4:{if(t[(t[f>>2]|0)+24>>2]|0)pAi[t[135736>>2]&511](t[(t[f>>2]|0)+24>>2]|0);if((t[(t[u>>2]|0)+4>>2]|0)!=0?(t[(t[(t[u>>2]|0)+4>>2]|0)+4>>2]|0)>=(t[(t[u>>2]|0)+24>>2]|0):0){l=35;break e}if((t[(t[u>>2]|0)+4>>2]|0)==0?(n=Au(10)|0,t[(t[u>>2]|0)+4>>2]=n,(t[(t[u>>2]|0)+4>>2]|0)==0):0){l=54;break e}if((Mu(t[(t[u>>2]|0)+4>>2]|0,t[f>>2]|0,0)|0)==-1)l=54;break}default:l=54}while(0);do if((l|0)==35){if((t[(t[u>>2]|0)+16>>2]|0)!=0?(t[(t[(t[u>>2]|0)+16>>2]|0)+4>>2]|0)>=(t[(t[u>>2]|0)+36>>2]|0):0){l=54;break}if((t[(t[u>>2]|0)+16>>2]|0)==0?(n=Au(10)|0,t[(t[u>>2]|0)+16>>2]=n,(t[(t[u>>2]|0)+16>>2]|0)==0):0){l=54;break}if((Mu(t[(t[u>>2]|0)+16>>2]|0,t[f>>2]|0,0)|0)==-1)l=54}while(0);if((l|0)==54){if(t[(t[f>>2]|0)+4>>2]|0)Bn(t[(t[f>>2]|0)+4>>2]|0);pAi[t[135736>>2]&511](t[f>>2]|0);s=r;return}l=t[f>>2]|0;if(!(t[(t[f>>2]|0)+4>>2]|0)){b=l+0|0;k=b+48|0;do{t[b>>2]=0;b=b+4|0}while((b|0)<(k|0));s=r;return}t[a>>2]=t[l+4>>2];e:do if((t[t[a>>2]>>2]|0)<=1){if(((t[t[a>>2]>>2]|0)==1?(t[t[(t[a>>2]|0)+8>>2]>>2]|0)!=0:0)?(t[(t[t[(t[a>>2]|0)+8>>2]>>2]|0)+4>>2]|0)==18:0)Rn(t[t[(t[a>>2]|0)+8>>2]>>2]|0)}else{t[o>>2]=0;while(1){if((t[o>>2]|0)>=(t[t[a>>2]>>2]|0))break e;t[c>>2]=t[(t[(t[a>>2]|0)+8>>2]|0)+(t[o>>2]<<2)>>2];if((t[c>>2]|0)!=0?(t[(t[c>>2]|0)+4>>2]|0)==18:0)Rn(t[c>>2]|0);t[o>>2]=(t[o>>2]|0)+1}}while(0);t[t[a>>2]>>2]=0;b=(t[f>>2]|0)+0|0;k=b+48|0;do{t[b>>2]=0;b=b+4|0}while((b|0)<(k|0));t[(t[f>>2]|0)+4>>2]=t[a>>2];s=r;return}_n(t[f>>2]|0);s=r;return}function jt(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0;r=s;s=s+16|0;n=r+12|0;f=r+8|0;u=r+4|0;a=r;t[f>>2]=e;t[u>>2]=i;if((t[u>>2]|0)!=0?(t[(t[u>>2]|0)+4>>2]|0)==18:0){if((t[f>>2]|0)!=0?(t[(t[f>>2]|0)+4>>2]|0)!=18:0){t[a>>2]=gAi[t[135744>>2]&511](24)|0;if(!(t[a>>2]|0)){Ut(0,130952);t[n>>2]=0;o=t[n>>2]|0;s=r;return o|0}i=t[a>>2]|0;t[i+0>>2]=0;t[i+4>>2]=0;t[i+8>>2]=0;t[i+12>>2]=0;t[i+16>>2]=0;t[i+20>>2]=0;t[(t[a>>2]|0)+4>>2]=18;if(t[(t[u>>2]|0)+8>>2]|0){i=Yl(t[(t[u>>2]|0)+8>>2]|0)|0;t[(t[a>>2]|0)+8>>2]=i}if(t[(t[u>>2]|0)+12>>2]|0){i=Yl(t[(t[u>>2]|0)+12>>2]|0)|0;t[(t[a>>2]|0)+12>>2]=i}t[t[a>>2]>>2]=t[f>>2];t[n>>2]=t[a>>2];o=t[n>>2]|0;s=r;return o|0}t[n>>2]=t[u>>2];o=t[n>>2]|0;s=r;return o|0}t[n>>2]=0;o=t[n>>2]|0;s=r;return o|0}function Vt(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0;r=s;s=s+16|0;n=r+8|0;f=r+4|0;u=r;t[f>>2]=e;t[u>>2]=i;e:do if(!(t[u>>2]|0))t[n>>2]=0;else{do if((t[f>>2]|0)!=0?(t[(t[f>>2]|0)+200>>2]|0)!=0:0){i=t[t[u>>2]>>2]|0;if((i|0)==4){t[n>>2]=au(t[f>>2]|0,t[(t[u>>2]|0)+24>>2]|0)|0;break e}else if((i|0)==3){t[n>>2]=eu(t[f>>2]|0,+l[(t[u>>2]|0)+16>>3])|0;break e}else if((i|0)==2){t[n>>2]=cu(t[f>>2]|0,t[(t[u>>2]|0)+8>>2]|0)|0;break e}else if((i|0)==1){i=t[f>>2]|0;t[n>>2]=fu(i,Pn(0,t[(t[u>>2]|0)+4>>2]|0)|0)|0;break e}else break}while(0);t[n>>2]=nf(t[u>>2]|0)|0}while(0);s=r;return t[n>>2]|0}function qt(e,i,r){e=+e;i=i|0;r=r|0;var f=0,u=0,a=0,o=0,c=0,b=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0,S=0,g=0;f=s;s=s+144|0;u=f+16|0;a=f+8|0;o=f+68|0;c=f+64|0;b=f+100|0;h=f+60|0;w=f+56|0;d=f+52|0;v=f+72|0;m=f+48|0;_=f+44|0;p=f+40|0;E=f+36|0;S=f;g=f+32|0;l[a>>3]=e;t[o>>2]=i;t[c>>2]=r;r=wn(+l[a>>3])|0;if((r|0)==-1){if((t[c>>2]|0)<=10){s=f;return}SY(t[o>>2]|0,t[c>>2]|0,129032,u)|0;s=f;return}else if((r|0)==1){if((t[c>>2]|0)<=9){s=f;return}SY(t[o>>2]|0,t[c>>2]|0,129016,u)|0;s=f;return}else{if(hn(+l[a>>3])|0){if((t[c>>2]|0)<=4){s=f;return}SY(t[o>>2]|0,t[c>>2]|0,129048,u)|0;s=f;return}if(+l[a>>3]==0?(Bt(+l[a>>3])|0)!=0:0){SY(t[o>>2]|0,t[c>>2]|0,129056,u)|0;s=f;return}e=+l[a>>3];if(+l[a>>3]==+(~~+l[a>>3]|0)){t[d>>2]=~~e;t[h>>2]=t[o>>2];e:do if(!(t[d>>2]|0)){r=t[h>>2]|0;t[h>>2]=r+1;n[r>>0]=48}else{t[u>>2]=t[d>>2];SY(b,29,130840,u)|0;t[w>>2]=b;while(1){if(!(n[t[w>>2]>>0]|0))break e;if(((t[h>>2]|0)-(t[o>>2]|0)|0)>=(t[c>>2]|0))break e;r=t[w>>2]|0;t[w>>2]=r+1;i=n[r>>0]|0;r=t[h>>2]|0;t[h>>2]=r+1;n[r>>0]=i}}while(0);if(((t[h>>2]|0)-(t[o>>2]|0)|0)<(t[c>>2]|0)){n[t[h>>2]>>0]=0;s=f;return}if((t[c>>2]|0)<=0){s=f;return}t[h>>2]=(t[h>>2]|0)+-1;n[t[h>>2]>>0]=0;s=f;return}l[S>>3]=+G(+e);e:do if((+l[S>>3]>1e9|+l[S>>3]<1e-5)&+l[S>>3]!=0){t[m>>2]=21;t[_>>2]=14;h=t[_>>2]|0;e=+l[a>>3];t[u>>2]=t[m>>2];t[u+4>>2]=h;h=u+8|0;l[k>>3]=e;t[h>>2]=t[k>>2];t[h+4>>2]=t[k+4>>2];t[g>>2]=SY(v,28,130848,u)|0;while(1){if((t[g>>2]|0)<=0)break e;if((n[v+(t[g>>2]|0)>>0]|0)==101)break e;t[g>>2]=(t[g>>2]|0)+-1}}else{do if(+l[S>>3]>0){t[m>>2]=~~+sY(+l[S>>3]);h=15-(t[m>>2]|0)|0;if((t[m>>2]|0)>0){t[_>>2]=h-1;break}else{t[_>>2]=h;break}}else t[_>>2]=1;while(0);e=+l[a>>3];t[u>>2]=t[_>>2];h=u+4|0;l[k>>3]=e;t[h>>2]=t[k>>2];t[h+4>>2]=t[k+4>>2];t[g>>2]=SY(v,28,130856,u)|0}while(0);while(1){if((n[v>>0]|0)!=32)break;t[p>>2]=v;while(1){u=n[(t[p>>2]|0)+1>>0]|0;n[t[p>>2]>>0]=u;if(!(u<<24>>24))break;t[p>>2]=(t[p>>2]|0)+1}t[g>>2]=(t[g>>2]|0)+-1}t[E>>2]=v+(t[g>>2]|0);t[p>>2]=t[E>>2];do{u=(t[p>>2]|0)+-1|0;t[p>>2]=u}while((n[u>>0]|0)==48);if((n[t[p>>2]>>0]|0)!=46)t[p>>2]=(t[p>>2]|0)+1;do{u=t[E>>2]|0;t[E>>2]=u+1;_=n[u>>0]|0;u=t[p>>2]|0;t[p>>2]=u+1;n[u>>0]=_}while((_<<24>>24|0)!=0);t[g>>2]=(HY(v|0)|0)+1;if((t[g>>2]|0)>(t[c>>2]|0)){n[v+((t[c>>2]|0)-1)>>0]=0;t[g>>2]=t[c>>2]}GY(t[o>>2]|0,v|0,t[g>>2]|0)|0;s=f;return}}function Yt(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,a=0,o=0,c=0,l=0;r=s;s=s+32|0;n=r+16|0;f=r+12|0;a=r+8|0;o=r+4|0;c=r;t[n>>2]=e;t[f>>2]=i;if(!(t[f>>2]|0)){i=t[n>>2]|0;Sn(i,ru(t[(t[n>>2]|0)+12>>2]|0,t[(t[(t[n>>2]|0)+12>>2]|0)+4>>2]|0)|0)|0;t[f>>2]=1}if(!(t[n>>2]|0)){s=r;return}i=t[n>>2]|0;if((t[f>>2]|0)!=1){dn(i,12);s=r;return}f=t[n>>2]|0;if((t[i+20>>2]|0)<((t[(t[n>>2]|0)+44>>2]|0)+1|0)){dn(f,23);s=r;return}do if(t[f+16>>2]|0){if((t[t[(t[n>>2]|0)+16>>2]>>2]|0)!=1?(t[t[(t[n>>2]|0)+16>>2]>>2]|0)!=9:0)break;t[a>>2]=En(t[n>>2]|0)|0;do if((t[(t[a>>2]|0)+4>>2]|0)!=0?(t[t[(t[a>>2]|0)+4>>2]>>2]|0)!=0:0){t[o>>2]=0;if(((t[(t[(t[(t[(t[a>>2]|0)+4>>2]|0)+8>>2]|0)+(t[o>>2]<<2)>>2]|0)+4>>2]|0)+-1|0)>>>0>=2){i=t[n>>2]|0;Sn(i,ru(t[(t[n>>2]|0)+12>>2]|0,t[(t[(t[(t[a>>2]|0)+4>>2]|0)+8>>2]|0)+(t[o>>2]<<2)>>2]|0)|0)|0;Wf(t[n>>2]|0,1);break}if((u[t[(t[(t[(t[(t[a>>2]|0)+4>>2]|0)+8>>2]|0)+(t[o>>2]<<2)>>2]|0)+8>>2]>>0]|0|0)==32){i=t[n>>2]|0;Sn(i,uu(t[(t[n>>2]|0)+12>>2]|0,128928)|0)|0;break}if((t[(t[(t[(t[(t[a>>2]|0)+4>>2]|0)+8>>2]|0)+(t[o>>2]<<2)>>2]|0)+36>>2]|0)!=0?(t[(t[(t[(t[(t[(t[a>>2]|0)+4>>2]|0)+8>>2]|0)+(t[o>>2]<<2)>>2]|0)+36>>2]|0)+12>>2]|0)!=0:0){t[c>>2]=Ug(t[(t[(t[(t[(t[a>>2]|0)+4>>2]|0)+8>>2]|0)+(t[o>>2]<<2)>>2]|0)+8>>2]|0,t[(t[(t[(t[(t[(t[a>>2]|0)+4>>2]|0)+8>>2]|0)+(t[o>>2]<<2)>>2]|0)+36>>2]|0)+12>>2]|0,0,0)|0;if((t[c>>2]|0)==(t[(t[(t[(t[(t[a>>2]|0)+4>>2]|0)+8>>2]|0)+(t[o>>2]<<2)>>2]|0)+8>>2]|0))t[c>>2]=Yl(t[(t[(t[(t[(t[a>>2]|0)+4>>2]|0)+8>>2]|0)+(t[o>>2]<<2)>>2]|0)+8>>2]|0)|0;i=t[n>>2]|0;if(t[c>>2]|0){Sn(i,ou(t[(t[n>>2]|0)+12>>2]|0,t[c>>2]|0)|0)|0;break}dn(i,15);s=r;return}i=t[n>>2]|0;Sn(i,au(t[(t[n>>2]|0)+12>>2]|0,t[(t[(t[(t[(t[a>>2]|0)+4>>2]|0)+8>>2]|0)+(t[o>>2]<<2)>>2]|0)+8>>2]|0)|0)|0}else l=14;while(0);if((l|0)==14){i=t[n>>2]|0;Sn(i,uu(t[(t[n>>2]|0)+12>>2]|0,128928)|0)|0}zt(t[(t[n>>2]|0)+12>>2]|0,t[a>>2]|0);s=r;return}while(0);dn(t[n>>2]|0,11);s=r;return}function Gt(e,i){e=e|0;i=i|0;var r=0,f=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0;r=s;s=s+32|0;f=r+20|0;a=r+16|0;o=r+12|0;c=r+8|0;l=r+4|0;b=r;k=r+24|0;t[f>>2]=e;t[a>>2]=i;if(!(t[f>>2]|0)){s=r;return}i=t[f>>2]|0;if((t[a>>2]|0)!=2){dn(i,12);s=r;return}a=t[f>>2]|0;if((t[i+20>>2]|0)<((t[(t[f>>2]|0)+44>>2]|0)+2|0)){dn(a,23);s=r;return}t[c>>2]=gn(a)|0;if((t[(t[f>>2]|0)+16>>2]|0)!=0?(t[t[(t[f>>2]|0)+16>>2]>>2]|0)!=4:0)Xf(t[f>>2]|0,1);t[o>>2]=En(t[f>>2]|0)|0;t[l>>2]=ds()|0;n[k>>0]=37;n[k+3>>0]=0;e:do if(t[l>>2]|0){t[b>>2]=t[(t[o>>2]|0)+24>>2];while(1){if(!(n[t[b>>2]>>0]|0))break e;if((u[t[b>>2]>>0]|0)>=65?(u[t[b>>2]>>0]|0)<=90:0)h=51;else h=14;i:do if((h|0)==14){h=0;if((u[t[b>>2]>>0]|0)>=97?(u[t[b>>2]>>0]|0)<=122:0){h=51;break}if((u[t[b>>2]>>0]|0)>=48?(u[t[b>>2]>>0]|0)<=57:0){h=51;break}if((((((((u[t[b>>2]>>0]|0)!=45?(u[t[b>>2]>>0]|0)!=95:0)?(u[t[b>>2]>>0]|0)!=46:0)?(u[t[b>>2]>>0]|0)!=33:0)?(u[t[b>>2]>>0]|0)!=126:0)?(u[t[b>>2]>>0]|0)!=42:0)?(u[t[b>>2]>>0]|0)!=39:0)?(u[t[b>>2]>>0]|0)!=40:0){if((u[t[b>>2]>>0]|0)==41){h=51;break}r:do if((u[t[b>>2]>>0]|0)==37){if(!((u[(t[b>>2]|0)+1>>0]|0)>=65?(u[(t[b>>2]|0)+1>>0]|0)<=70:0))h=30;do if((h|0)==30){h=0;if((u[(t[b>>2]|0)+1>>0]|0)>=97?(u[(t[b>>2]|0)+1>>0]|0)<=102:0)break;if((u[(t[b>>2]|0)+1>>0]|0)<48)break r;if((u[(t[b>>2]|0)+1>>0]|0)>57)break r}while(0);if((u[(t[b>>2]|0)+2>>0]|0)>=65?(u[(t[b>>2]|0)+2>>0]|0)<=70:0){h=51;break i}if((u[(t[b>>2]|0)+2>>0]|0)>=97?(u[(t[b>>2]|0)+2>>0]|0)<=102:0){h=51;break i}if((u[(t[b>>2]|0)+2>>0]|0)<48)break;if((u[(t[b>>2]|0)+2>>0]|0)<=57){h=51;break i}}while(0);if(!(t[c>>2]|0)){if((u[t[b>>2]>>0]|0)==59){h=51;break}if((u[t[b>>2]>>0]|0)==47){h=51;break}if((u[t[b>>2]>>0]|0)==63){h=51;break}if((u[t[b>>2]>>0]|0)==58){h=51;break}if((u[t[b>>2]>>0]|0)==64){h=51;break}if((u[t[b>>2]>>0]|0)==38){h=51;break}if((u[t[b>>2]>>0]|0)==61){h=51;break}if((u[t[b>>2]>>0]|0)==43){h=51;break}if((u[t[b>>2]>>0]|0)==36){h=51;break}if((u[t[b>>2]>>0]|0)==44){h=51;break}}a=u[t[b>>2]>>0]>>4;if((u[t[b>>2]>>0]>>4|0)<10)n[k+1>>0]=48+a;else n[k+1>>0]=55+a;a=u[t[b>>2]>>0]&15;if((u[t[b>>2]>>0]&15|0)<10)n[k+2>>0]=48+a;else n[k+2>>0]=55+a;Ps(t[l>>2]|0,k,3)|0}else h=51}while(0);if((h|0)==51){h=0;Ps(t[l>>2]|0,t[b>>2]|0,1)|0}t[b>>2]=(t[b>>2]|0)+1}}while(0);b=t[f>>2]|0;h=t[(t[f>>2]|0)+12>>2]|0;Sn(b,au(h,Os(t[l>>2]|0)|0)|0)|0;Ss(t[l>>2]|0);zt(t[(t[f>>2]|0)+12>>2]|0,t[o>>2]|0);s=r;return}function Wt(){var e=0,i=0,r=0,n=0,f=0;e=s;s=s+16|0;i=e+4|0;r=e;t[r>>2]=gAi[t[135744>>2]&511](28)|0;if(!(t[r>>2]|0)){Ut(0,130792);t[i>>2]=0;n=t[i>>2]|0;s=e;return n|0}f=t[r>>2]|0;t[f+0>>2]=0;t[f+4>>2]=0;t[f+8>>2]=0;t[f+12>>2]=0;t[f+16>>2]=0;t[f+20>>2]=0;t[f+24>>2]=0;t[(t[r>>2]|0)+4>>2]=10;t[t[r>>2]>>2]=0;f=gAi[t[135744>>2]&511]((t[(t[r>>2]|0)+4>>2]|0)*40|0)|0;t[(t[r>>2]|0)+8>>2]=f;if(!(t[(t[r>>2]|0)+8>>2]|0)){Ut(0,130816);pAi[t[135736>>2]&511](t[r>>2]|0);t[i>>2]=0;n=t[i>>2]|0;s=e;return n|0}else{VY(t[(t[r>>2]|0)+8>>2]|0,0,(t[(t[r>>2]|0)+4>>2]|0)*40|0)|0;t[(t[r>>2]|0)+12>>2]=-1;t[i>>2]=t[r>>2];n=t[i>>2]|0;s=e;return n|0}return 0}function Kt(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0;n=s;s=s+64|0;f=n+48|0;u=n+44|0;a=n+40|0;o=n+36|0;c=n+32|0;l=n+28|0;b=n+24|0;k=n+20|0;h=n+16|0;w=n+12|0;d=n+8|0;v=n+4|0;m=n;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;t[d>>2]=0;do if(t[u>>2]|0){if((t[t[u>>2]>>2]|0)!=1?(t[t[u>>2]>>2]|0)!=9:0)break;do if(t[a>>2]|0){if((t[t[a>>2]>>2]|0)!=1?(t[t[a>>2]>>2]|0)!=9:0)break;t[v>>2]=t[(t[u>>2]|0)+4>>2];t[m>>2]=t[(t[a>>2]|0)+4>>2];if((t[v>>2]|0)!=0?(t[t[v>>2]>>2]|0)>0:0){if((t[m>>2]|0)!=0?(t[t[m>>2]>>2]|0)>0:0){e:do if(!(t[o>>2]|0)){t[c>>2]=0;i:while(1){if((t[c>>2]|0)>=(t[t[v>>2]>>2]|0))break e;t[l>>2]=0;while(1){_=t[c>>2]|0;if((t[l>>2]|0)>=(t[t[m>>2]>>2]|0))break;if((t[(t[(t[v>>2]|0)+8>>2]|0)+(_<<2)>>2]|0)==(t[(t[(t[m>>2]|0)+8>>2]|0)+(t[l>>2]<<2)>>2]|0))break i;t[l>>2]=(t[l>>2]|0)+1}t[c>>2]=_+1}t[f>>2]=1;p=t[f>>2]|0;s=n;return p|0}while(0);t[h>>2]=gAi[t[135744>>2]&511](t[t[v>>2]>>2]<<2)|0;if(!(t[h>>2]|0)){Ut(0,130768);t[f>>2]=0;p=t[f>>2]|0;s=n;return p|0}t[b>>2]=gAi[t[135744>>2]&511](t[t[v>>2]>>2]<<2)|0;if(!(t[b>>2]|0)){Ut(0,130768);pAi[t[135736>>2]&511](t[h>>2]|0);t[f>>2]=0;p=t[f>>2]|0;s=n;return p|0}VY(t[h>>2]|0,0,t[t[v>>2]>>2]<<2|0)|0;t[w>>2]=gAi[t[135744>>2]&511](t[t[m>>2]>>2]<<2)|0;if(!(t[w>>2]|0)){Ut(0,130768);pAi[t[135736>>2]&511](t[b>>2]|0);pAi[t[135736>>2]&511](t[h>>2]|0);t[f>>2]=0;p=t[f>>2]|0;s=n;return p|0}t[k>>2]=gAi[t[135744>>2]&511](t[t[m>>2]>>2]<<2)|0;if(!(t[k>>2]|0)){Ut(0,130768);pAi[t[135736>>2]&511](t[b>>2]|0);pAi[t[135736>>2]&511](t[h>>2]|0);pAi[t[135736>>2]&511](t[w>>2]|0);t[f>>2]=0;p=t[f>>2]|0;s=n;return p|0}VY(t[w>>2]|0,0,t[t[m>>2]>>2]<<2|0)|0;t[c>>2]=0;while(1){if((t[c>>2]|0)>=(t[t[v>>2]>>2]|0))break;r=Ru(t[(t[(t[v>>2]|0)+8>>2]|0)+(t[c>>2]<<2)>>2]|0)|0;t[(t[b>>2]|0)+(t[c>>2]<<2)>>2]=r;t[l>>2]=0;while(1){if((t[l>>2]|0)>=(t[t[m>>2]>>2]|0))break;if(!(t[c>>2]|0)){r=Ru(t[(t[(t[m>>2]|0)+8>>2]|0)+(t[l>>2]<<2)>>2]|0)|0;t[(t[k>>2]|0)+(t[l>>2]<<2)>>2]=r}if((t[(t[b>>2]|0)+(t[c>>2]<<2)>>2]|0)!=(t[(t[k>>2]|0)+(t[l>>2]<<2)>>2]|0)){if(t[o>>2]|0){E=40;break}}else{if(!(t[(t[h>>2]|0)+(t[c>>2]<<2)>>2]|0)){r=sF(t[(t[(t[v>>2]|0)+8>>2]|0)+(t[c>>2]<<2)>>2]|0)|0;t[(t[h>>2]|0)+(t[c>>2]<<2)>>2]=r}if(!(t[(t[w>>2]|0)+(t[l>>2]<<2)>>2]|0)){r=sF(t[(t[(t[m>>2]|0)+8>>2]|0)+(t[l>>2]<<2)>>2]|0)|0;t[(t[w>>2]|0)+(t[l>>2]<<2)>>2]=r}r=Xl(t[(t[h>>2]|0)+(t[c>>2]<<2)>>2]|0,t[(t[w>>2]|0)+(t[l>>2]<<2)>>2]|0)|0;t[d>>2]=r^t[o>>2];if(t[d>>2]|0)break}t[l>>2]=(t[l>>2]|0)+1}if((E|0)==40){E=0;t[d>>2]=1}if(t[d>>2]|0)break;t[c>>2]=(t[c>>2]|0)+1}t[c>>2]=0;while(1){if((t[c>>2]|0)>=(t[t[v>>2]>>2]|0))break;if(t[(t[h>>2]|0)+(t[c>>2]<<2)>>2]|0)pAi[t[135736>>2]&511](t[(t[h>>2]|0)+(t[c>>2]<<2)>>2]|0);t[c>>2]=(t[c>>2]|0)+1}t[l>>2]=0;while(1){if((t[l>>2]|0)>=(t[t[m>>2]>>2]|0))break;if(t[(t[w>>2]|0)+(t[l>>2]<<2)>>2]|0)pAi[t[135736>>2]&511](t[(t[w>>2]|0)+(t[l>>2]<<2)>>2]|0);t[l>>2]=(t[l>>2]|0)+1}pAi[t[135736>>2]&511](t[h>>2]|0);pAi[t[135736>>2]&511](t[w>>2]|0);pAi[t[135736>>2]&511](t[b>>2]|0);pAi[t[135736>>2]&511](t[k>>2]|0);t[f>>2]=t[d>>2];p=t[f>>2]|0;s=n;return p|0}t[f>>2]=0;p=t[f>>2]|0;s=n;return p|0}t[f>>2]=0;p=t[f>>2]|0;s=n;return p|0}while(0);t[f>>2]=0;p=t[f>>2]|0;s=n;return p|0}while(0);t[f>>2]=0;p=t[f>>2]|0;s=n;return p|0}function Xt(e,i,r,n){e=e|0;i=i|0;r=+r;n=n|0;var f=0,u=0,a=0,o=0,c=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0;f=s;s=s+64|0;u=f+48|0;a=f+44|0;o=f+40|0;c=f+8|0;b=f+36|0;k=f+32|0;h=f+28|0;w=f+24|0;d=f+20|0;v=f+16|0;m=f;t[a>>2]=e;t[o>>2]=i;l[c>>3]=r;t[b>>2]=n;t[h>>2]=0;do if(t[o>>2]|0){if((t[t[o>>2]>>2]|0)!=1?(t[t[o>>2]>>2]|0)!=9:0)break;t[w>>2]=t[(t[o>>2]|0)+4>>2];e:do if(t[w>>2]|0){t[k>>2]=0;i:while(1){if((t[k>>2]|0)>=(t[t[w>>2]>>2]|0))break e;t[d>>2]=xn(t[(t[(t[w>>2]|0)+8>>2]|0)+(t[k>>2]<<2)>>2]|0)|0;do if(t[d>>2]|0){n=t[a>>2]|0;Sn(n,au(t[(t[a>>2]|0)+12>>2]|0,t[d>>2]|0)|0)|0;pAi[t[135736>>2]&511](t[d>>2]|0);gf(t[a>>2]|0,1);t[v>>2]=En(t[a>>2]|0)|0;l[m>>3]=+l[(t[v>>2]|0)+16>>3];zt(t[(t[a>>2]|0)+12>>2]|0,t[v>>2]|0);n=(hn(+l[m>>3])|0)!=0;i=(t[b>>2]|0)!=0;if(n){if(!i)break;t[h>>2]=1;break}if(!i?+l[m>>3]==+l[c>>3]:0){_=12;break i}if((t[b>>2]|0)!=0?+l[m>>3]!=+l[c>>3]:0){_=15;break i}}while(0);t[k>>2]=(t[k>>2]|0)+1}if((_|0)==12){t[h>>2]=1;break}else if((_|0)==15){t[h>>2]=1;break}}while(0);t[u>>2]=t[h>>2];p=t[u>>2]|0;s=f;return p|0}while(0);t[u>>2]=0;p=t[u>>2]|0;s=f;return p|0}function Zt(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0;n=s;s=s+32|0;f=n+28|0;u=n+24|0;a=n+20|0;o=n+16|0;c=n+12|0;l=n+8|0;b=n+4|0;k=n;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;do if(!((t[a>>2]|0)==0|(t[u>>2]|0)==0)){if((t[t[u>>2]>>2]|0)!=1?(t[t[u>>2]>>2]|0)!=9:0)break;t[l>>2]=t[(t[u>>2]|0)+4>>2];if((t[l>>2]|0)!=0?(t[t[l>>2]>>2]|0)>0:0){t[k>>2]=Nu(t[a>>2]|0)|0;t[c>>2]=0;e:while(1){if((t[c>>2]|0)>=(t[t[l>>2]>>2]|0)){h=28;break}r=Ru(t[(t[(t[l>>2]|0)+8>>2]|0)+(t[c>>2]<<2)>>2]|0)|0;do if((r|0)==(t[k>>2]|0)){t[b>>2]=sF(t[(t[(t[l>>2]|0)+8>>2]|0)+(t[c>>2]<<2)>>2]|0)|0;if((t[b>>2]|0)!=0?(Xl(t[a>>2]|0,t[b>>2]|0)|0)!=0:0){pAi[t[135736>>2]&511](t[b>>2]|0);if(t[o>>2]|0)break;else{h=14;break e}}if((t[b>>2]|0)==0?(Xl(t[a>>2]|0,128928)|0)!=0:0)if(t[o>>2]|0)break;else{h=18;break e}w=(t[b>>2]|0)!=0;if(t[o>>2]|0){h=20;break e}if(w)pAi[t[135736>>2]&511](t[b>>2]|0)}else if(t[o>>2]|0){h=26;break e}while(0);t[c>>2]=(t[c>>2]|0)+1}if((h|0)==14){t[f>>2]=1;d=t[f>>2]|0;s=n;return d|0}else if((h|0)==18){t[f>>2]=1;d=t[f>>2]|0;s=n;return d|0}else if((h|0)==20){if(w)pAi[t[135736>>2]&511](t[b>>2]|0);t[f>>2]=1;d=t[f>>2]|0;s=n;return d|0}else if((h|0)==26){t[f>>2]=1;d=t[f>>2]|0;s=n;return d|0}else if((h|0)==28){t[f>>2]=0;d=t[f>>2]|0;s=n;return d|0}}t[f>>2]=0;d=t[f>>2]|0;s=n;return d|0}while(0);t[f>>2]=0;d=t[f>>2]|0;s=n;return d|0}function Jt(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,a=0,o=0,c=0,b=0,k=0;n=s;s=s+32|0;f=n;a=n+20|0;o=n+16|0;c=n+12|0;b=n+8|0;t[a>>2]=e;t[o>>2]=i;t[c>>2]=r;t[b>>2]=0;e:do switch(t[t[o>>2]>>2]|0){case 3:{switch(t[t[c>>2]>>2]|0){case 4:{Sn(t[a>>2]|0,t[c>>2]|0)|0;gf(t[a>>2]|0,1);t[c>>2]=En(t[a>>2]|0)|0;break}case 3:break;case 6:case 5:case 8:case 7:{r=t[33976]|0;i=t[33980]|0;t[f>>2]=128552;t[f+4>>2]=7047;yAi[r&511](i,129064,f);break e;break}case 2:{t[b>>2]=(t[(t[c>>2]|0)+8>>2]|0)==(bf(+l[(t[o>>2]|0)+16>>3])|0)&1;break e;break}default:break e}if((hn(+l[(t[o>>2]|0)+16>>3])|0)==0?(hn(+l[(t[c>>2]|0)+16>>3])|0)==0:0){if((wn(+l[(t[o>>2]|0)+16>>3])|0)==1)if((wn(+l[(t[c>>2]|0)+16>>3])|0)==1){t[b>>2]=1;break e}else{t[b>>2]=0;break e}i=(wn(+l[(t[o>>2]|0)+16>>3])|0)==-1;r=wn(+l[(t[c>>2]|0)+16>>3])|0;if(i)if((r|0)==-1){t[b>>2]=1;break e}else{t[b>>2]=0;break e}if((r|0)==1)if((wn(+l[(t[o>>2]|0)+16>>3])|0)==1){t[b>>2]=1;break e}else{t[b>>2]=0;break e}r=(wn(+l[(t[c>>2]|0)+16>>3])|0)==-1;k=+l[(t[o>>2]|0)+16>>3];if(!r){t[b>>2]=k==+l[(t[c>>2]|0)+16>>3]&1;break e}if((wn(k)|0)==-1){t[b>>2]=1;break e}else{t[b>>2]=0;break e}}t[b>>2]=0;break}case 6:case 5:case 8:case 7:{r=t[33976]|0;i=t[33980]|0;t[f>>2]=128552;t[f+4>>2]=7119;yAi[r&511](i,129064,f);break}case 2:{switch(t[t[c>>2]>>2]|0){case 6:case 5:case 8:case 7:{i=t[33976]|0;r=t[33980]|0;t[f>>2]=128552;t[f+4>>2]=6990;yAi[i&511](r,129064,f);break e;break}case 3:{t[b>>2]=(t[(t[o>>2]|0)+8>>2]|0)==(bf(+l[(t[c>>2]|0)+16>>3])|0)&1;break e;break}case 2:{t[b>>2]=(t[(t[o>>2]|0)+8>>2]|0)==(t[(t[c>>2]|0)+8>>2]|0)&1;break e;break}case 4:{if((t[(t[c>>2]|0)+24>>2]|0)!=0?(u[t[(t[c>>2]|0)+24>>2]>>0]|0|0)!=0:0)t[b>>2]=1;else t[b>>2]=0;t[b>>2]=(t[(t[o>>2]|0)+8>>2]|0)==(t[b>>2]|0)&1;break e;break}default:break e}break}case 4:{switch(t[t[c>>2]>>2]|0){case 3:{Sn(t[a>>2]|0,t[o>>2]|0)|0;gf(t[a>>2]|0,1);t[o>>2]=En(t[a>>2]|0)|0;if((hn(+l[(t[o>>2]|0)+16>>3])|0)==0?(hn(+l[(t[c>>2]|0)+16>>3])|0)==0:0){if((wn(+l[(t[o>>2]|0)+16>>3])|0)==1)if((wn(+l[(t[c>>2]|0)+16>>3])|0)==1){t[b>>2]=1;break e}else{t[b>>2]=0;break e}r=(wn(+l[(t[o>>2]|0)+16>>3])|0)==-1;i=wn(+l[(t[c>>2]|0)+16>>3])|0;if(r)if((i|0)==-1){t[b>>2]=1;break e}else{t[b>>2]=0;break e}if((i|0)==1)if((wn(+l[(t[o>>2]|0)+16>>3])|0)==1){t[b>>2]=1;break e}else{t[b>>2]=0;break e}i=(wn(+l[(t[c>>2]|0)+16>>3])|0)==-1;k=+l[(t[o>>2]|0)+16>>3];if(!i){t[b>>2]=k==+l[(t[c>>2]|0)+16>>3]&1;break e}if((wn(k)|0)==-1){t[b>>2]=1;break e}else{t[b>>2]=0;break e}}t[b>>2]=0;break e;break}case 6:case 5:case 8:case 7:{i=t[33976]|0;r=t[33980]|0;t[f>>2]=128552;t[f+4>>2]=7108;yAi[i&511](r,129064,f);break e;break}case 2:{if((t[(t[o>>2]|0)+24>>2]|0)!=0?(u[t[(t[o>>2]|0)+24>>2]>>0]|0|0)!=0:0)t[b>>2]=1;else t[b>>2]=0;t[b>>2]=(t[(t[c>>2]|0)+8>>2]|0)==(t[b>>2]|0)&1;break e;break}case 4:{t[b>>2]=Xl(t[(t[o>>2]|0)+24>>2]|0,t[(t[c>>2]|0)+24>>2]|0)|0;break e;break}default:break e}break}default:{}}while(0);zt(t[(t[a>>2]|0)+12>>2]|0,t[o>>2]|0);zt(t[(t[a>>2]|0)+12>>2]|0,t[c>>2]|0);s=n;return t[b>>2]|0}function Qt(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,u=0,a=0,o=0,c=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0,S=0;f=s;s=s+64|0;u=f+52|0;a=f+48|0;o=f+44|0;c=f+40|0;b=f+36|0;k=f+32|0;h=f+28|0;w=f+24|0;d=f;v=f+20|0;m=f+16|0;_=f+12|0;p=f+8|0;t[a>>2]=e;t[o>>2]=i;t[c>>2]=r;t[b>>2]=n;t[w>>2]=0;t[m>>2]=0;do if(t[c>>2]|0){if((t[t[c>>2]>>2]|0)!=1?(t[t[c>>2]>>2]|0)!=9:0)break;do if(t[b>>2]|0){if((t[t[b>>2]>>2]|0)!=1?(t[t[b>>2]>>2]|0)!=9:0)break;t[_>>2]=t[(t[c>>2]|0)+4>>2];t[p>>2]=t[(t[b>>2]|0)+4>>2];if((t[_>>2]|0)!=0?(t[t[_>>2]>>2]|0)>0:0){if((t[p>>2]|0)!=0?(t[t[p>>2]>>2]|0)>0:0){t[v>>2]=gAi[t[135744>>2]&511](t[t[p>>2]>>2]<<3)|0;if(!(t[v>>2]|0)){Ut(0,130768);_n(t[c>>2]|0);_n(t[b>>2]|0);t[u>>2]=0;E=t[u>>2]|0;s=f;return E|0}t[k>>2]=0;while(1){if((t[k>>2]|0)>=(t[t[_>>2]>>2]|0))break;l[d>>3]=+lf(t[(t[(t[_>>2]|0)+8>>2]|0)+(t[k>>2]<<2)>>2]|0);if(!(hn(+l[d>>3])|0)){t[h>>2]=0;while(1){if((t[h>>2]|0)>=(t[t[p>>2]>>2]|0))break;if(!(t[w>>2]|0)){S=+lf(t[(t[(t[p>>2]|0)+8>>2]|0)+(t[h>>2]<<2)>>2]|0);l[(t[v>>2]|0)+(t[h>>2]<<3)>>3]=S}if(!(hn(+l[(t[v>>2]|0)+(t[h>>2]<<3)>>3])|0)){do if((t[a>>2]|0)!=0&(t[o>>2]|0)!=0)t[m>>2]=+l[d>>3]<+l[(t[v>>2]|0)+(t[h>>2]<<3)>>3]&1;else{if(!((t[a>>2]|0)==0|(t[o>>2]|0)!=0)){t[m>>2]=+l[d>>3]<=+l[(t[v>>2]|0)+(t[h>>2]<<3)>>3]&1;break}if((t[a>>2]|0)==0&(t[o>>2]|0)!=0){t[m>>2]=+l[d>>3]>+l[(t[v>>2]|0)+(t[h>>2]<<3)>>3]&1;break}if((t[a>>2]|0)!=0|(t[o>>2]|0)!=0)break;t[m>>2]=+l[d>>3]>=+l[(t[v>>2]|0)+(t[h>>2]<<3)>>3]&1}while(0);if(t[m>>2]|0)break}t[h>>2]=(t[h>>2]|0)+1}if(t[m>>2]|0)break;t[w>>2]=1}t[k>>2]=(t[k>>2]|0)+1}pAi[t[135736>>2]&511](t[v>>2]|0);_n(t[c>>2]|0);_n(t[b>>2]|0);t[u>>2]=t[m>>2];E=t[u>>2]|0;s=f;return E|0}_n(t[c>>2]|0);_n(t[b>>2]|0);t[u>>2]=0;E=t[u>>2]|0;s=f;return E|0}_n(t[c>>2]|0);_n(t[b>>2]|0);t[u>>2]=0;E=t[u>>2]|0;s=f;return E|0}while(0);_n(t[c>>2]|0);_n(t[b>>2]|0);t[u>>2]=0;E=t[u>>2]|0;s=f;return E|0}while(0);_n(t[b>>2]|0);t[u>>2]=0;E=t[u>>2]|0;s=f;return E|0}function $t(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;var u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0;u=s;s=s+32|0;a=u;o=u+28|0;c=u+24|0;l=u+20|0;b=u+16|0;k=u+12|0;h=u+8|0;t[c>>2]=e;t[l>>2]=i;t[b>>2]=r;t[k>>2]=n;t[h>>2]=f;do if(!((t[h>>2]|0)==0|(t[k>>2]|0)==0)){if((t[t[k>>2]>>2]|0)!=1?(t[t[k>>2]>>2]|0)!=9:0)break;switch(t[t[h>>2]>>2]|0){case 9:case 1:{t[o>>2]=Qt(t[l>>2]|0,t[b>>2]|0,t[k>>2]|0,t[h>>2]|0)|0;w=t[o>>2]|0;s=u;return w|0}case 4:{t[o>>2]=Lu(t[c>>2]|0,t[l>>2]|0,t[b>>2]|0,t[k>>2]|0,t[h>>2]|0)|0;w=t[o>>2]|0;s=u;return w|0}case 2:{Sn(t[c>>2]|0,t[k>>2]|0)|0;tt(t[c>>2]|0,1);Sn(t[c>>2]|0,t[h>>2]|0)|0;t[o>>2]=Sf(t[c>>2]|0,t[l>>2]|0,t[b>>2]|0)|0;w=t[o>>2]|0;s=u;return w|0}case 3:{t[o>>2]=Tu(t[c>>2]|0,t[l>>2]|0,t[b>>2]|0,t[k>>2]|0,t[h>>2]|0)|0;w=t[o>>2]|0;s=u;return w|0}default:{f=t[33976]|0;n=t[33980]|0;t[a>>2]=128552;t[a+4>>2]=6705;yAi[f&511](n,129064,a);t[o>>2]=0;w=t[o>>2]|0;s=u;return w|0}}}while(0);t[o>>2]=0;w=t[o>>2]|0;s=u;return w|0}function eu(e,i){e=e|0;i=+i;var r=0,n=0,f=0,u=0,a=0,o=0,c=0,b=0;r=s;s=s+32|0;n=r+24|0;f=r+20|0;u=r;a=r+16|0;o=r+12|0;c=r+8|0;t[f>>2]=e;l[u>>3]=i;if((t[f>>2]|0)!=0?(t[(t[f>>2]|0)+200>>2]|0)!=0:0){t[a>>2]=t[(t[f>>2]|0)+200>>2];if((t[(t[a>>2]|0)+12>>2]|0)!=0?(t[(t[(t[a>>2]|0)+12>>2]|0)+4>>2]|0)!=0:0){f=(t[(t[a>>2]|0)+12>>2]|0)+4|0;e=(t[f>>2]|0)+-1|0;t[f>>2]=e;t[o>>2]=t[(t[t[(t[a>>2]|0)+12>>2]>>2]|0)+(e<<2)>>2];t[t[o>>2]>>2]=3;l[(t[o>>2]|0)+16>>3]=+l[u>>3];t[n>>2]=t[o>>2];b=t[n>>2]|0;s=r;return b|0}if((t[(t[a>>2]|0)+16>>2]|0)!=0?(t[(t[(t[a>>2]|0)+16>>2]|0)+4>>2]|0)!=0:0){o=(t[(t[a>>2]|0)+16>>2]|0)+4|0;e=(t[o>>2]|0)+-1|0;t[o>>2]=e;t[c>>2]=t[(t[t[(t[a>>2]|0)+16>>2]>>2]|0)+(e<<2)>>2];t[t[c>>2]>>2]=3;l[(t[c>>2]|0)+16>>3]=+l[u>>3];t[n>>2]=t[c>>2];b=t[n>>2]|0;s=r;return b|0}}t[n>>2]=Jn(+l[u>>3])|0;b=t[n>>2]|0;s=r;return b|0}function iu(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0;r=s;s=s+16|0;n=r+12|0;f=r+8|0;u=r+4|0;a=r;t[f>>2]=e;t[u>>2]=i;if(!(t[u>>2]|0)){t[n>>2]=eu(t[f>>2]|0,0)|0;o=t[n>>2]|0;s=r;return o|0}if((t[t[u>>2]>>2]|0)==3){t[n>>2]=t[u>>2];o=t[n>>2]|0;s=r;return o|0}else{i=t[f>>2]|0;t[a>>2]=eu(i,+Fn(t[u>>2]|0))|0;zt(t[f>>2]|0,t[u>>2]|0);t[n>>2]=t[a>>2];o=t[n>>2]|0;s=r;return o|0}return 0}function ru(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0;r=s;s=s+32|0;n=r+20|0;f=r+16|0;u=r+12|0;a=r+8|0;o=r+4|0;c=r;t[f>>2]=e;t[u>>2]=i;if((t[f>>2]|0)!=0?(t[(t[f>>2]|0)+200>>2]|0)!=0:0){t[a>>2]=t[(t[f>>2]|0)+200>>2];if((t[t[a>>2]>>2]|0)!=0?(t[(t[t[a>>2]>>2]|0)+4>>2]|0)!=0:0){i=(t[t[a>>2]>>2]|0)+4|0;e=(t[i>>2]|0)+-1|0;t[i>>2]=e;t[o>>2]=t[(t[t[t[a>>2]>>2]>>2]|0)+(e<<2)>>2];t[t[o>>2]>>2]=1;t[(t[o>>2]|0)+8>>2]=0;do if(t[u>>2]|0){if((t[(t[(t[o>>2]|0)+4>>2]|0)+4>>2]|0)!=0?(t[(t[u>>2]|0)+4>>2]|0)!=18:0){t[t[(t[(t[o>>2]|0)+4>>2]|0)+8>>2]>>2]=t[u>>2];t[t[(t[o>>2]|0)+4>>2]>>2]=1;break}Cn(t[(t[o>>2]|0)+4>>2]|0,t[u>>2]|0)|0}while(0);t[n>>2]=t[o>>2];l=t[n>>2]|0;s=r;return l|0}if((t[(t[a>>2]|0)+16>>2]|0)!=0?(t[(t[(t[a>>2]|0)+16>>2]|0)+4>>2]|0)!=0:0){o=(t[(t[a>>2]|0)+16>>2]|0)+4|0;e=(t[o>>2]|0)+-1|0;t[o>>2]=e;t[c>>2]=t[(t[t[(t[a>>2]|0)+16>>2]>>2]|0)+(e<<2)>>2];t[t[c>>2]>>2]=1;t[(t[c>>2]|0)+8>>2]=0;e=Nn(t[u>>2]|0)|0;t[(t[c>>2]|0)+4>>2]=e;if(!(t[(t[c>>2]|0)+4>>2]|0)){t[(t[f>>2]|0)+136>>2]=12;t[(t[f>>2]|0)+140>>2]=2;t[n>>2]=0;l=t[n>>2]|0;s=r;return l|0}else{t[n>>2]=t[c>>2];l=t[n>>2]|0;s=r;return l|0}}}t[n>>2]=In(t[u>>2]|0)|0;l=t[n>>2]|0;s=r;return l|0}function nu(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0;r=s;s=s+32|0;n=r+28|0;f=r+24|0;a=r+20|0;o=r+16|0;c=r+12|0;l=r+8|0;b=r+4|0;k=r;t[f>>2]=e;t[a>>2]=i;t[c>>2]=t[a>>2];t[k>>2]=0;if(!(t[a>>2]|0)){t[n>>2]=0;h=t[n>>2]|0;s=r;return h|0}t[o>>2]=Nn(0)|0;if(!(t[o>>2]|0)){t[n>>2]=t[o>>2];h=t[n>>2]|0;s=r;return h|0}e:while(1){do if((u[t[c>>2]>>0]|0|0)!=32){if(9<=(u[t[c>>2]>>0]|0|0)?(u[t[c>>2]>>0]|0|0)<=10:0)break;if((u[t[c>>2]>>0]|0|0)!=13)break e}while(0);t[c>>2]=(t[c>>2]|0)+1}while(1){if(!(u[t[c>>2]>>0]|0))break;while(1){if((u[t[c>>2]>>0]|0|0)==32)break;if(9<=(u[t[c>>2]>>0]|0|0)?(u[t[c>>2]>>0]|0|0)<=10:0)break;if((u[t[c>>2]>>0]|0|0)==13)break;if(!(u[t[c>>2]>>0]|0))break;t[c>>2]=(t[c>>2]|0)+1}t[l>>2]=ql(t[a>>2]|0,(t[c>>2]|0)-(t[a>>2]|0)|0)|0;if(t[l>>2]|0){t[b>>2]=GM(t[f>>2]|0,t[l>>2]|0)|0;if(t[b>>2]|0){i=t[b>>2]|0;do if((t[(t[b>>2]|0)+4>>2]|0)!=2)if((t[i+4>>2]|0)==1){t[k>>2]=t[b>>2];break}else{t[k>>2]=0;break}else t[k>>2]=t[i+20>>2];while(0);if(t[k>>2]|0)Dn(t[o>>2]|0,t[k>>2]|0)|0}pAi[t[135736>>2]&511](t[l>>2]|0)}while(1){do if((u[t[c>>2]>>0]|0|0)==32)w=1;else{if(9<=(u[t[c>>2]>>0]|0|0)?(u[t[c>>2]>>0]|0|0)<=10:0){w=1;break}w=(u[t[c>>2]>>0]|0|0)==13}while(0);d=t[c>>2]|0;if(!w)break;t[c>>2]=d+1}t[a>>2]=d}t[n>>2]=t[o>>2];h=t[n>>2]|0;s=r;return h|0}function fu(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0;r=s;s=s+32|0;n=r+16|0;f=r+12|0;u=r+8|0;a=r+4|0;o=r;t[f>>2]=e;t[u>>2]=i;if((((t[f>>2]|0)!=0?(t[(t[f>>2]|0)+200>>2]|0)!=0:0)?(t[a>>2]=t[(t[f>>2]|0)+200>>2],(t[(t[a>>2]|0)+16>>2]|0)!=0):0)?(t[(t[(t[a>>2]|0)+16>>2]|0)+4>>2]|0)!=0:0){f=(t[(t[a>>2]|0)+16>>2]|0)+4|0;i=(t[f>>2]|0)+-1|0;t[f>>2]=i;t[o>>2]=t[(t[t[(t[a>>2]|0)+16>>2]>>2]|0)+(i<<2)>>2];t[t[o>>2]>>2]=1;t[(t[o>>2]|0)+4>>2]=t[u>>2];t[n>>2]=t[o>>2];c=t[n>>2]|0;s=r;return c|0}t[n>>2]=Hn(t[u>>2]|0)|0;c=t[n>>2]|0;s=r;return c|0}function tu(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0;r=s;s=s+32|0;n=r;f=r+20|0;u=r+16|0;a=r+12|0;o=r+8|0;t[u>>2]=e;t[a>>2]=i;t[o>>2]=0;if(!(t[a>>2]|0)){t[f>>2]=uu(t[u>>2]|0,128928)|0;c=t[f>>2]|0;s=r;return c|0}switch(t[t[a>>2]>>2]|0){case 9:case 1:{t[o>>2]=uf(t[(t[a>>2]|0)+4>>2]|0)|0;break}case 3:{t[o>>2]=tf(+l[(t[a>>2]|0)+16>>3])|0;break}case 6:case 5:case 8:case 7:{i=t[33976]|0;e=t[33980]|0;t[n>>2]=128552;t[n+4>>2]=2680;yAi[i&511](e,129064,n);break}case 2:{t[o>>2]=ff(t[(t[a>>2]|0)+8>>2]|0)|0;break}case 4:{t[f>>2]=t[a>>2];c=t[f>>2]|0;s=r;return c|0}default:{}}zt(t[u>>2]|0,t[a>>2]|0);a=t[u>>2]|0;if(!(t[o>>2]|0)){t[f>>2]=uu(a,128928)|0;c=t[f>>2]|0;s=r;return c|0}else{t[f>>2]=ou(a,t[o>>2]|0)|0;c=t[f>>2]|0;s=r;return c|0}return 0}function uu(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0;r=s;s=s+32|0;n=r+20|0;f=r+16|0;u=r+12|0;a=r+8|0;o=r+4|0;c=r;t[f>>2]=e;t[u>>2]=i;if((t[f>>2]|0)!=0?(t[(t[f>>2]|0)+200>>2]|0)!=0:0){t[a>>2]=t[(t[f>>2]|0)+200>>2];if((t[(t[a>>2]|0)+4>>2]|0)!=0?(t[(t[(t[a>>2]|0)+4>>2]|0)+4>>2]|0)!=0:0){f=(t[(t[a>>2]|0)+4>>2]|0)+4|0;i=(t[f>>2]|0)+-1|0;t[f>>2]=i;t[o>>2]=t[(t[t[(t[a>>2]|0)+4>>2]>>2]|0)+(i<<2)>>2];t[t[o>>2]>>2]=4;i=Yl(t[u>>2]|0)|0;t[(t[o>>2]|0)+24>>2]=i;t[n>>2]=t[o>>2];l=t[n>>2]|0;s=r;return l|0}if((t[(t[a>>2]|0)+16>>2]|0)!=0?(t[(t[(t[a>>2]|0)+16>>2]|0)+4>>2]|0)!=0:0){o=(t[(t[a>>2]|0)+16>>2]|0)+4|0;i=(t[o>>2]|0)+-1|0;t[o>>2]=i;t[c>>2]=t[(t[t[(t[a>>2]|0)+16>>2]>>2]|0)+(i<<2)>>2];t[t[c>>2]>>2]=4;i=Yl(t[u>>2]|0)|0;t[(t[c>>2]|0)+24>>2]=i;t[n>>2]=t[c>>2];l=t[n>>2]|0;s=r;return l|0}}t[n>>2]=rf(t[u>>2]|0)|0;l=t[n>>2]|0;s=r;return l|0}function au(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0;r=s;s=s+32|0;n=r+20|0;f=r+16|0;u=r+12|0;a=r+8|0;o=r+4|0;c=r;t[f>>2]=e;t[u>>2]=i;if((t[f>>2]|0)!=0?(t[(t[f>>2]|0)+200>>2]|0)!=0:0){t[a>>2]=t[(t[f>>2]|0)+200>>2];if((t[(t[a>>2]|0)+4>>2]|0)!=0?(t[(t[(t[a>>2]|0)+4>>2]|0)+4>>2]|0)!=0:0){f=(t[(t[a>>2]|0)+4>>2]|0)+4|0;i=(t[f>>2]|0)+-1|0;t[f>>2]=i;t[o>>2]=t[(t[t[(t[a>>2]|0)+4>>2]>>2]|0)+(i<<2)>>2];t[t[o>>2]>>2]=4;if(t[u>>2]|0){i=Yl(t[u>>2]|0)|0;t[(t[o>>2]|0)+24>>2]=i}else{i=Yl(128928)|0;t[(t[o>>2]|0)+24>>2]=i}t[n>>2]=t[o>>2];l=t[n>>2]|0;s=r;return l|0}if((t[(t[a>>2]|0)+16>>2]|0)!=0?(t[(t[(t[a>>2]|0)+16>>2]|0)+4>>2]|0)!=0:0){o=(t[(t[a>>2]|0)+16>>2]|0)+4|0;i=(t[o>>2]|0)+-1|0;t[o>>2]=i;t[c>>2]=t[(t[t[(t[a>>2]|0)+16>>2]>>2]|0)+(i<<2)>>2];
	t[t[c>>2]>>2]=4;if(t[u>>2]|0){i=Yl(t[u>>2]|0)|0;t[(t[c>>2]|0)+24>>2]=i}else{i=Yl(128928)|0;t[(t[c>>2]|0)+24>>2]=i}t[n>>2]=t[c>>2];l=t[n>>2]|0;s=r;return l|0}}t[n>>2]=$n(t[u>>2]|0)|0;l=t[n>>2]|0;s=r;return l|0}function ou(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0;r=s;s=s+32|0;n=r+20|0;f=r+16|0;u=r+12|0;a=r+8|0;o=r+4|0;c=r;t[f>>2]=e;t[u>>2]=i;if((t[f>>2]|0)!=0?(t[(t[f>>2]|0)+200>>2]|0)!=0:0){t[a>>2]=t[(t[f>>2]|0)+200>>2];if((t[(t[a>>2]|0)+4>>2]|0)!=0?(t[(t[(t[a>>2]|0)+4>>2]|0)+4>>2]|0)!=0:0){f=(t[(t[a>>2]|0)+4>>2]|0)+4|0;i=(t[f>>2]|0)+-1|0;t[f>>2]=i;t[o>>2]=t[(t[t[(t[a>>2]|0)+4>>2]>>2]|0)+(i<<2)>>2];t[t[o>>2]>>2]=4;t[(t[o>>2]|0)+24>>2]=t[u>>2];t[n>>2]=t[o>>2];l=t[n>>2]|0;s=r;return l|0}if((t[(t[a>>2]|0)+16>>2]|0)!=0?(t[(t[(t[a>>2]|0)+16>>2]|0)+4>>2]|0)!=0:0){o=(t[(t[a>>2]|0)+16>>2]|0)+4|0;i=(t[o>>2]|0)+-1|0;t[o>>2]=i;t[c>>2]=t[(t[t[(t[a>>2]|0)+16>>2]>>2]|0)+(i<<2)>>2];t[t[c>>2]>>2]=4;t[(t[c>>2]|0)+24>>2]=t[u>>2];t[n>>2]=t[c>>2];l=t[n>>2]|0;s=r;return l|0}}t[n>>2]=ef(t[u>>2]|0)|0;l=t[n>>2]|0;s=r;return l|0}function cu(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0;r=s;s=s+32|0;n=r+20|0;f=r+16|0;u=r+12|0;a=r+8|0;o=r+4|0;c=r;t[f>>2]=e;t[u>>2]=i;if((t[f>>2]|0)!=0?(t[(t[f>>2]|0)+200>>2]|0)!=0:0){t[a>>2]=t[(t[f>>2]|0)+200>>2];if((t[(t[a>>2]|0)+8>>2]|0)!=0?(t[(t[(t[a>>2]|0)+8>>2]|0)+4>>2]|0)!=0:0){f=(t[(t[a>>2]|0)+8>>2]|0)+4|0;i=(t[f>>2]|0)+-1|0;t[f>>2]=i;t[o>>2]=t[(t[t[(t[a>>2]|0)+8>>2]>>2]|0)+(i<<2)>>2];t[t[o>>2]>>2]=2;t[(t[o>>2]|0)+8>>2]=(t[u>>2]|0)!=0&1;t[n>>2]=t[o>>2];l=t[n>>2]|0;s=r;return l|0}if((t[(t[a>>2]|0)+16>>2]|0)!=0?(t[(t[(t[a>>2]|0)+16>>2]|0)+4>>2]|0)!=0:0){o=(t[(t[a>>2]|0)+16>>2]|0)+4|0;i=(t[o>>2]|0)+-1|0;t[o>>2]=i;t[c>>2]=t[(t[t[(t[a>>2]|0)+16>>2]>>2]|0)+(i<<2)>>2];t[t[c>>2]>>2]=2;t[(t[c>>2]|0)+8>>2]=(t[u>>2]|0)!=0&1;t[n>>2]=t[c>>2];l=t[n>>2]|0;s=r;return l|0}}t[n>>2]=Qn(t[u>>2]|0)|0;l=t[n>>2]|0;s=r;return l|0}function lu(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0;r=s;s=s+16|0;n=r+12|0;f=r+8|0;u=r+4|0;a=r;t[f>>2]=e;t[u>>2]=i;if(!(t[u>>2]|0)){t[n>>2]=cu(t[f>>2]|0,0)|0;o=t[n>>2]|0;s=r;return o|0}if((t[t[u>>2]>>2]|0)==2){t[n>>2]=t[u>>2];o=t[n>>2]|0;s=r;return o|0}else{i=t[f>>2]|0;t[a>>2]=cu(i,yn(t[u>>2]|0)|0)|0;zt(t[f>>2]|0,t[u>>2]|0);t[n>>2]=t[a>>2];o=t[n>>2]|0;s=r;return o|0}return 0}function su(e,i){e=e|0;i=i|0;var r=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0;r=s;s=s+144|0;f=r+28|0;u=r+24|0;a=r+20|0;o=r+32|0;c=r+16|0;l=r+12|0;b=r+8|0;k=r+4|0;h=r;t[u>>2]=e;t[a>>2]=i;t[c>>2]=0;t[b>>2]=Du(t[u>>2]|0,l)|0;e:do if(!((t[b>>2]|0)==32|(t[b>>2]|0)==62|(t[b>>2]|0)==47|(t[b>>2]|0)==91|(t[b>>2]|0)==93|(t[b>>2]|0)==64|(t[b>>2]|0)==42)){i=t[b>>2]|0;if((t[b>>2]|0)<256){if(((!(65<=(i|0)&(t[b>>2]|0)<=90)?!(97<=(t[b>>2]|0)&(t[b>>2]|0)<=122):0)?!(192<=(t[b>>2]|0)&(t[b>>2]|0)<=214):0)?!(216<=(t[b>>2]|0)&(t[b>>2]|0)<=246|248<=(t[b>>2]|0)):0)w=8}else if(!(dj(i,199744)|0))w=8;do if((w|0)==8){i=t[b>>2]|0;if((t[b>>2]|0)<256)if((i|0)!=95&(t[a>>2]|0)!=0&(t[b>>2]|0)!=58)break e;else break;if(!(19968<=(i|0)&(t[b>>2]|0)<=40869|(t[b>>2]|0)==12295)?(12321<=(t[b>>2]|0)&(t[b>>2]|0)<=12329^1)&(t[b>>2]|0)!=95&(t[a>>2]|0)!=0&(t[b>>2]|0)!=58:0)break e}while(0);i:do{if(!((t[b>>2]|0)!=32&(t[b>>2]|0)!=62&(t[b>>2]|0)!=47)){w=72;break}i=t[b>>2]|0;if((t[b>>2]|0)<256){if(((!(65<=(i|0)&(t[b>>2]|0)<=90)?!(97<=(t[b>>2]|0)&(t[b>>2]|0)<=122):0)?!(192<=(t[b>>2]|0)&(t[b>>2]|0)<=214):0)?!(216<=(t[b>>2]|0)&(t[b>>2]|0)<=246|248<=(t[b>>2]|0)):0)w=20}else if(!(dj(i,199744)|0))w=20;do if((w|0)==20){w=0;if((t[b>>2]|0)>=256){if(19968<=(t[b>>2]|0)&(t[b>>2]|0)<=40869|(t[b>>2]|0)==12295)break;if(12321<=(t[b>>2]|0)&(t[b>>2]|0)<=12329)break}i=t[b>>2]|0;if((t[b>>2]|0)<256){if(48<=(i|0)&(t[b>>2]|0)<=57|(t[b>>2]|0)==46|(t[b>>2]|0)==45|(t[b>>2]|0)==95)break}else{e=(dj(i,200216)|0)!=0;if(e|(t[b>>2]|0)==46|(t[b>>2]|0)==45|(t[b>>2]|0)==95)break}if(!((t[a>>2]|0)!=0&(t[b>>2]|0)==58)){if((t[b>>2]|0)>=256?(dj(t[b>>2]|0,200144)|0)!=0:0)break;e=t[b>>2]|0;if((t[b>>2]|0)<256)d=(e|0)==183&1;else d=dj(e,200272)|0;if(!d){w=72;break i}}}while(0);if((t[l>>2]|0)==1){e=t[b>>2]&255;i=t[c>>2]|0;t[c>>2]=i+1;n[o+i>>0]=e}else{e=Np(t[l>>2]|0,o+(t[c>>2]|0)|0,t[b>>2]|0)|0;t[c>>2]=(t[c>>2]|0)+e}e=t[u>>2]|0;t[e>>2]=(t[e>>2]|0)+(t[l>>2]|0);t[b>>2]=Du(t[u>>2]|0,l)|0}while((t[c>>2]|0)<100);if((w|0)==72)if(!(t[c>>2]|0)){t[f>>2]=0;v=t[f>>2]|0;s=r;return v|0}else{t[f>>2]=ql(o,t[c>>2]|0)|0;v=t[f>>2]|0;s=r;return v|0}t[h>>2]=t[c>>2]<<1;if((t[c>>2]|0)>5e4){dn(t[u>>2]|0,7);t[f>>2]=0;v=t[f>>2]|0;s=r;return v|0}t[k>>2]=gAi[t[135752>>2]&511](t[h>>2]|0)|0;if(!(t[k>>2]|0)){dn(t[u>>2]|0,15);t[f>>2]=0;v=t[f>>2]|0;s=r;return v|0}YY(t[k>>2]|0,o|0,t[c>>2]|0)|0;while(1){e=t[b>>2]|0;if((t[b>>2]|0)<256)if(((!(65<=(e|0)&(t[b>>2]|0)<=90)?!(97<=(t[b>>2]|0)&(t[b>>2]|0)<=122):0)?!(192<=(t[b>>2]|0)&(t[b>>2]|0)<=214):0)?!(216<=(t[b>>2]|0)&(t[b>>2]|0)<=246|248<=(t[b>>2]|0)):0)w=48;else m=1;else if(dj(e,199744)|0)m=1;else w=48;do if((w|0)==48){w=0;if((t[b>>2]|0)>=256){if(19968<=(t[b>>2]|0)&(t[b>>2]|0)<=40869|(t[b>>2]|0)==12295){m=1;break}if(12321<=(t[b>>2]|0)&(t[b>>2]|0)<=12329){m=1;break}}e=t[b>>2]|0;if((t[b>>2]|0)<256){if(48<=(e|0)&(t[b>>2]|0)<=57|(t[b>>2]|0)==46|(t[b>>2]|0)==45|(t[b>>2]|0)==95){m=1;break}}else{i=(dj(e,200216)|0)!=0;if(i|(t[b>>2]|0)==46|(t[b>>2]|0)==45|(t[b>>2]|0)==95){m=1;break}}if((t[a>>2]|0)!=0&(t[b>>2]|0)==58)m=1;else{if((t[b>>2]|0)>=256?(dj(t[b>>2]|0,200144)|0)!=0:0){m=1;break}i=t[b>>2]|0;if((t[b>>2]|0)<256)_=(i|0)==183&1;else _=dj(i,200272)|0;m=(_|0)!=0}}while(0);p=t[c>>2]|0;if(!m){w=71;break}if((p+10|0)>(t[h>>2]|0)){if((t[h>>2]|0)>5e4){w=64;break}t[h>>2]=t[h>>2]<<1;t[k>>2]=MAi[t[135760>>2]&511](t[k>>2]|0,t[h>>2]|0)|0;if(!(t[k>>2]|0)){w=66;break}}if((t[l>>2]|0)==1){i=t[b>>2]&255;e=t[c>>2]|0;t[c>>2]=e+1;n[(t[k>>2]|0)+e>>0]=i}else{i=Np(t[l>>2]|0,(t[k>>2]|0)+(t[c>>2]|0)|0,t[b>>2]|0)|0;t[c>>2]=(t[c>>2]|0)+i}i=t[u>>2]|0;t[i>>2]=(t[i>>2]|0)+(t[l>>2]|0);t[b>>2]=Du(t[u>>2]|0,l)|0}if((w|0)==64){dn(t[u>>2]|0,7);t[f>>2]=0;v=t[f>>2]|0;s=r;return v|0}else if((w|0)==66){dn(t[u>>2]|0,15);t[f>>2]=0;v=t[f>>2]|0;s=r;return v|0}else if((w|0)==71){n[(t[k>>2]|0)+p>>0]=0;t[f>>2]=t[k>>2];v=t[f>>2]|0;s=r;return v|0}}while(0);t[f>>2]=0;v=t[f>>2]|0;s=r;return v|0}function bu(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0;r=s;s=s+48|0;n=r+40|0;f=r+36|0;a=r+32|0;o=r+28|0;c=r+24|0;l=r+20|0;b=r+16|0;k=r+12|0;h=r+8|0;w=r+4|0;d=r;t[f>>2]=e;t[a>>2]=i;t[l>>2]=0;t[b>>2]=0;if(((es(t[a>>2]|0,91)|0)==0?(es(t[a>>2]|0,40)|0)==0:0)?(es(t[a>>2]|0,64)|0)==0:0){t[d>>2]=es(t[a>>2]|0,58)|0;do if(t[d>>2]|0){if(((t[f>>2]|0)!=0?(t[(t[f>>2]|0)+60>>2]|0)!=0:0)?(u[(t[d>>2]|0)+1>>0]|0|0)!=58:0)break;t[n>>2]=0;v=t[n>>2]|0;s=r;return v|0}while(0);if((t[f>>2]|0)!=0?(t[l>>2]=t[(t[f>>2]|0)+192>>2],(t[(t[f>>2]|0)+60>>2]|0)>0):0){t[b>>2]=gAi[t[135744>>2]&511]((t[(t[f>>2]|0)+60>>2]|0)+1<<1<<2)|0;if(!(t[b>>2]|0)){Ut(t[f>>2]|0,130672);t[n>>2]=0;v=t[n>>2]|0;s=r;return v|0}t[h>>2]=0;t[w>>2]=0;while(1){if((t[w>>2]|0)>=(t[(t[f>>2]|0)+60>>2]|0))break;t[k>>2]=t[(t[(t[f>>2]|0)+56>>2]|0)+(t[w>>2]<<2)>>2];d=t[(t[k>>2]|0)+8>>2]|0;i=t[h>>2]|0;t[h>>2]=i+1;t[(t[b>>2]|0)+(i<<2)>>2]=d;d=t[(t[k>>2]|0)+12>>2]|0;i=t[h>>2]|0;t[h>>2]=i+1;t[(t[b>>2]|0)+(i<<2)>>2]=d;t[w>>2]=(t[w>>2]|0)+1}w=t[h>>2]|0;t[h>>2]=w+1;t[(t[b>>2]|0)+(w<<2)>>2]=0;t[(t[b>>2]|0)+(t[h>>2]<<2)>>2]=0}t[o>>2]=Fj(t[a>>2]|0,t[l>>2]|0,1,t[b>>2]|0)|0;if(t[b>>2]|0)pAi[t[135736>>2]&511](t[b>>2]|0);if((t[o>>2]|0)!=0?(Mj(t[o>>2]|0)|0)==1:0){t[c>>2]=Wt()|0;if(!(t[c>>2]|0)){Ut(t[f>>2]|0,130704);t[n>>2]=0;v=t[n>>2]|0;s=r;return v|0}t[(t[c>>2]|0)+24>>2]=t[o>>2];t[(t[c>>2]|0)+20>>2]=t[l>>2];if(t[(t[c>>2]|0)+20>>2]|0)sz(t[(t[c>>2]|0)+20>>2]|0)|0;t[n>>2]=t[c>>2];v=t[n>>2]|0;s=r;return v|0}vj(t[o>>2]|0)}t[n>>2]=0;v=t[n>>2]|0;s=r;return v|0}function ku(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,a=0,o=0,c=0,l=0;r=s;s=s+16|0;n=r+8|0;f=r+4|0;a=r;t[n>>2]=e;t[f>>2]=i;Cu(t[n>>2]|0);if(t[(t[n>>2]|0)+8>>2]|0){s=r;return}e:while(1){do if((u[t[t[n>>2]>>2]>>0]|0|0)!=32){if(9<=(u[t[t[n>>2]>>2]>>0]|0|0)?(u[t[t[n>>2]>>2]>>0]|0|0)<=10:0)break;if((u[t[t[n>>2]>>2]>>0]|0|0)!=13)break e}while(0);i=t[n>>2]|0;if(!(u[t[t[n>>2]>>2]>>0]|0))continue;t[i>>2]=(t[i>>2]|0)+1}e:while(1){if((u[t[t[n>>2]>>2]>>0]|0|0)!=111)break;if((u[(t[t[n>>2]>>2]|0)+1>>0]|0|0)!=114)break;t[a>>2]=t[(t[(t[n>>2]|0)+32>>2]|0)+12>>2];i=t[n>>2]|0;t[i>>2]=(t[i>>2]|0)+2;while(1){do if((u[t[t[n>>2]>>2]>>0]|0|0)==32)o=1;else{if(9<=(u[t[t[n>>2]>>2]>>0]|0|0)?(u[t[t[n>>2]>>2]>>0]|0|0)<=10:0){o=1;break}o=(u[t[t[n>>2]>>2]>>0]|0|0)==13}while(0);c=t[n>>2]|0;if(!o)break;i=t[n>>2]|0;if(!(u[t[c>>2]>>0]|0))continue;t[i>>2]=(t[i>>2]|0)+1}Cu(c);if(t[(t[n>>2]|0)+8>>2]|0){l=29;break}Pu(t[(t[n>>2]|0)+32>>2]|0,t[a>>2]|0,t[(t[(t[n>>2]|0)+32>>2]|0)+12>>2]|0,2,0,0,0,0,0)|0;while(1){do if((u[t[t[n>>2]>>2]>>0]|0|0)!=32){if(9<=(u[t[t[n>>2]>>2]>>0]|0|0)?(u[t[t[n>>2]>>2]>>0]|0|0)<=10:0)break;if((u[t[t[n>>2]>>2]>>0]|0|0)!=13)continue e}while(0);i=t[n>>2]|0;if(!(u[t[t[n>>2]>>2]>>0]|0))continue;t[i>>2]=(t[i>>2]|0)+1}}if((l|0)==29){s=r;return}if(!(t[f>>2]|0)){s=r;return}if((t[(t[(t[(t[n>>2]|0)+32>>2]|0)+8>>2]|0)+((t[(t[(t[n>>2]|0)+32>>2]|0)+12>>2]|0)*40|0)>>2]|0)==12){s=r;return}Pu(t[(t[n>>2]|0)+32>>2]|0,t[(t[(t[n>>2]|0)+32>>2]|0)+12>>2]|0,-1,18,0,0,0,0,0)|0;s=r;return}function hu(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0;r=s;s=s+16|0;n=r+8|0;f=r+4|0;u=r;t[n>>2]=e;t[f>>2]=i;do if((((((((t[t[f>>2]>>2]|0)==11?(t[(t[f>>2]|0)+4>>2]|0)!=-1:0)?(t[(t[f>>2]|0)+8>>2]|0)==-1:0)?(t[u>>2]=(t[(t[n>>2]|0)+8>>2]|0)+((t[(t[f>>2]|0)+4>>2]|0)*40|0),(t[t[u>>2]>>2]|0)==11):0)?(t[(t[u>>2]|0)+12>>2]|0)==6:0)?(t[(t[u>>2]|0)+8>>2]|0)==-1:0)?(t[(t[u>>2]|0)+16>>2]|0)==1:0)?(t[(t[u>>2]|0)+20>>2]|0)==0:0){i=t[(t[f>>2]|0)+12>>2]|0;if((i|0)==6|(i|0)==13){t[(t[f>>2]|0)+4>>2]=t[(t[u>>2]|0)+4>>2];t[(t[f>>2]|0)+12>>2]=6;break}else if((i|0)==5|(i|0)==4){t[(t[f>>2]|0)+4>>2]=t[(t[u>>2]|0)+4>>2];t[(t[f>>2]|0)+12>>2]=5;break}else break}while(0);if((t[(t[f>>2]|0)+4>>2]|0)!=-1)hu(t[n>>2]|0,(t[(t[n>>2]|0)+8>>2]|0)+((t[(t[f>>2]|0)+4>>2]|0)*40|0)|0);if((t[(t[f>>2]|0)+8>>2]|0)==-1){s=r;return}hu(t[n>>2]|0,(t[(t[n>>2]|0)+8>>2]|0)+((t[(t[f>>2]|0)+8>>2]|0)*40|0)|0);s=r;return}function wu(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0;f=s;s=s+48|0;u=f;a=f+36|0;o=f+32|0;c=f+28|0;l=f+24|0;b=f+20|0;k=f+16|0;h=f+12|0;w=f+8|0;d=f+4|0;t[o>>2]=e;t[c>>2]=i;t[l>>2]=r;t[b>>2]=n;if(!(t[c>>2]|0)){cp(0,0,0,0,0,12,1,3,128552,14895,0,0,0,0,0,129480,u);t[a>>2]=-1;v=t[a>>2]|0;s=f;return v|0}if(!(t[o>>2]|0)){t[a>>2]=-1;v=t[a>>2]|0;s=f;return v|0}kn();t[32576]=(t[32576]|0)+1;if((t[32576]|0)>1)t[32574]=1;t[k>>2]=Bu(t[o>>2]|0,t[c>>2]|0)|0;t[h>>2]=du(t[k>>2]|0,t[b>>2]|0)|0;do if(t[l>>2]|0)if(!(t[(t[k>>2]|0)+16>>2]|0)){yAi[t[135904>>2]&511](t[33980]|0,130312,u);t[t[l>>2]>>2]=0;break}else{o=En(t[k>>2]|0)|0;t[t[l>>2]>>2]=o;break}while(0);do if((t[(t[k>>2]|0)+20>>2]|0)>0){t[d>>2]=0;do{t[w>>2]=En(t[k>>2]|0)|0;if(t[w>>2]|0){t[d>>2]=(t[d>>2]|0)+1;zt(t[c>>2]|0,t[w>>2]|0)}}while((t[w>>2]|0)!=0);if(t[d>>2]|0){if(!(t[b>>2]|0)){if(!(t[l>>2]|0))break;if(!(t[t[l>>2]>>2]|0))break}o=t[33976]|0;n=t[33980]|0;t[u>>2]=t[d>>2];yAi[o&511](n,130360,u)}}while(0);if(((t[l>>2]|0)!=0?(t[(t[k>>2]|0)+8>>2]|0)!=0:0)?(t[t[l>>2]>>2]|0)!=0:0){_n(t[t[l>>2]>>2]|0);t[t[l>>2]>>2]=0}t[(t[k>>2]|0)+32>>2]=0;_f(t[k>>2]|0);t[32576]=(t[32576]|0)+-1;t[a>>2]=t[h>>2];v=t[a>>2]|0;s=f;return v|0}function du(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0;r=s;s=s+32|0;n=r;f=r+24|0;u=r+20|0;a=r+16|0;o=r+12|0;c=r+8|0;l=r+4|0;t[u>>2]=e;t[a>>2]=i;if((t[u>>2]|0)!=0?(t[(t[u>>2]|0)+32>>2]|0)!=0:0){if(!(t[(t[u>>2]|0)+28>>2]|0)){i=gAi[t[135744>>2]&511](40)|0;t[(t[u>>2]|0)+28>>2]=i;if(!(t[(t[u>>2]|0)+28>>2]|0)){Iu(t[u>>2]|0,129952);pAi[t[135736>>2]&511](t[u>>2]|0)}t[(t[u>>2]|0)+20>>2]=0;t[(t[u>>2]|0)+24>>2]=10;t[(t[u>>2]|0)+16>>2]=0;t[(t[u>>2]|0)+44>>2]=0}do if(t[(t[(t[u>>2]|0)+32>>2]|0)+24>>2]|0){if(t[a>>2]|0){t[c>>2]=Hu(t[(t[u>>2]|0)+12>>2]|0,t[(t[(t[u>>2]|0)+32>>2]|0)+24>>2]|0,0,1)|0;if((t[c>>2]|0)==-1)break;t[f>>2]=t[c>>2];b=t[f>>2]|0;s=r;return b|0}t[l>>2]=0;t[c>>2]=Hu(t[(t[u>>2]|0)+12>>2]|0,t[(t[(t[u>>2]|0)+32>>2]|0)+24>>2]|0,l,0)|0;if((t[c>>2]|0)!=-1&(t[l>>2]|0)!=0){Sn(t[u>>2]|0,t[l>>2]|0)|0;t[f>>2]=0;b=t[f>>2]|0;s=r;return b|0}else{if(!(t[l>>2]|0))break;zt(t[(t[u>>2]|0)+12>>2]|0,t[l>>2]|0);break}}while(0);t[o>>2]=t[(t[u>>2]|0)+32>>2];if((t[(t[o>>2]|0)+12>>2]|0)<0){yAi[t[135904>>2]&511](t[33980]|0,129984,n);t[f>>2]=-1;b=t[f>>2]|0;s=r;return b|0}n=t[u>>2]|0;u=(t[(t[o>>2]|0)+8>>2]|0)+((t[(t[o>>2]|0)+12>>2]|0)*40|0)|0;if(t[a>>2]|0){t[f>>2]=xu(n,u,0)|0;b=t[f>>2]|0;s=r;return b|0}else{Uu(n,u)|0;t[f>>2]=0;b=t[f>>2]|0;s=r;return b|0}}t[f>>2]=-1;b=t[f>>2]|0;s=r;return b|0}function vu(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0;r=s;s=s+16|0;n=r+8|0;f=r+4|0;u=r;t[n>>2]=e;t[f>>2]=i;t[u>>2]=zu(t[n>>2]|0,t[f>>2]|0)|0;f=t[u>>2]|0;s=r;return((t[u>>2]|0)==-2?f:0-f|0)|0}function mu(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0,S=0,g=0,y=0,F=0,O=0,A=0,M=0,R=0;n=s;s=s+64|0;f=n+32|0;u=n+60|0;a=n+56|0;o=n+52|0;c=n+24|0;l=n+16|0;b=n+8|0;k=n+48|0;h=n+44|0;w=n;d=n+40|0;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;r=c;t[r>>2]=0;t[r+4>>2]=0;r=b;t[r>>2]=(t[o>>2]|0)-1;t[r+4>>2]=0;r=b;o=IY(t[r>>2]|0,t[r+4>>2]|0,1)|0;r=l;t[r>>2]=o;t[r+4>>2]=P;t[k>>2]=t[(t[u>>2]|0)+(t[c>>2]<<2)>>2];if((vu(t[a>>2]|0,t[k>>2]|0)|0)<0){r=f;t[r>>2]=0;t[r+4>>2]=0;v=f;m=v;_=t[m>>2]|0;p=v+4|0;E=p;S=t[E>>2]|0;P=S;s=n;return _|0}if(!(vu(t[a>>2]|0,t[k>>2]|0)|0)){r=w;t[r>>2]=1;t[r+4>>2]=0;while(1){r=(vu(t[a>>2]|0,t[(t[u>>2]|0)+(t[w>>2]<<2)>>2]|0)|0)==0;o=w;g=t[o>>2]|0;y=t[o+4>>2]|0;if(!r)break;r=jY(g|0,y|0,1,0)|0;o=w;t[o>>2]=r;t[o+4>>2]=P}w=f;t[w>>2]=g;t[w+4>>2]=y;v=f;m=v;_=t[m>>2]|0;p=v+4|0;E=p;S=t[E>>2]|0;P=S;s=n;return _|0}t[h>>2]=t[(t[u>>2]|0)+(t[l>>2]<<2)>>2];while(1){t[d>>2]=vu(t[a>>2]|0,t[h>>2]|0)|0;if((t[d>>2]|0)<0){y=l;w=c;g=BY(t[y>>2]|0,t[y+4>>2]|0,t[w>>2]|0,t[w+4>>2]|0)|0;w=P;y=l;F=t[y>>2]|0;O=t[y+4>>2]|0;if((w|0)<0|(w|0)==0&g>>>0<=1){A=11;break}g=b;t[g>>2]=F;t[g+4>>2]=O}else{if((t[d>>2]|0)<=0){A=17;break}g=b;w=l;y=BY(t[g>>2]|0,t[g+4>>2]|0,t[w>>2]|0,t[w+4>>2]|0)|0;w=P;g=l;M=t[g>>2]|0;R=t[g+4>>2]|0;if((w|0)<0|(w|0)==0&y>>>0<=1){A=15;break}y=c;t[y>>2]=M;t[y+4>>2]=R;t[k>>2]=t[h>>2]}y=c;w=t[y>>2]|0;g=t[y+4>>2]|0;y=b;o=c;r=BY(t[y>>2]|0,t[y+4>>2]|0,t[o>>2]|0,t[o+4>>2]|0)|0;o=IY(r|0,P|0,1)|0;r=jY(w|0,g|0,o|0,P|0)|0;o=l;t[o>>2]=r;t[o+4>>2]=P;t[h>>2]=t[(t[u>>2]|0)+(t[l>>2]<<2)>>2]}if((A|0)==11){c=f;t[c>>2]=F;t[c+4>>2]=O;v=f;m=v;_=t[m>>2]|0;p=v+4|0;E=p;S=t[E>>2]|0;P=S;s=n;return _|0}else if((A|0)==15){O=jY(M|0,R|0,1,0)|0;R=f;t[R>>2]=O;t[R+4>>2]=P;v=f;m=v;_=t[m>>2]|0;p=v+4|0;E=p;S=t[E>>2]|0;P=S;s=n;return _|0}else if((A|0)==17){while(1){A=0;R=l;O=jY(t[R>>2]|0,t[R+4>>2]|0,1,0)|0;R=l;t[R>>2]=O;t[R+4>>2]=P;t[h>>2]=t[(t[u>>2]|0)+(O<<2)>>2];if(!(vu(t[a>>2]|0,t[h>>2]|0)|0))A=17;else break}A=l;l=t[A+4>>2]|0;h=f;t[h>>2]=t[A>>2];t[h+4>>2]=l;v=f;m=v;_=t[m>>2]|0;p=v+4|0;E=p;S=t[E>>2]|0;P=S;s=n;return _|0}return 0}function _u(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;var u=0,a=0,o=0,c=0,l=0;u=s;s=s+32|0;a=u+20|0;o=u+8|0;c=u;l=u+16|0;t[a>>2]=e;e=o;t[e>>2]=i;t[e+4>>2]=r;r=c;t[r>>2]=n;t[r+4>>2]=f;while(1){f=o;r=t[f+4>>2]|0;n=c;e=t[n+4>>2]|0;if((r|0)>(e|0)|((r|0)==(e|0)?(t[f>>2]|0)>>>0>=(t[n>>2]|0)>>>0:0))break;t[l>>2]=t[(t[a>>2]|0)+(t[o>>2]<<2)>>2];t[(t[a>>2]|0)+(t[o>>2]<<2)>>2]=t[(t[a>>2]|0)+(t[c>>2]<<2)>>2];t[(t[a>>2]|0)+(t[c>>2]<<2)>>2]=t[l>>2];n=o;f=jY(t[n>>2]|0,t[n+4>>2]|0,1,0)|0;n=o;t[n>>2]=f;t[n+4>>2]=P;n=c;f=jY(t[n>>2]|0,t[n+4>>2]|0,-1,-1)|0;n=c;t[n>>2]=f;t[n+4>>2]=P}s=u;return}function pu(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0;r=s;s=s+16|0;n=r;f=r+12|0;u=r+8|0;a=r+4|0;t[f>>2]=e;t[u>>2]=i;if((t[t[f>>2]>>2]|0)>>>0>=(t[u>>2]|0)>>>0){s=r;return}t[a>>2]=Jq(t[(t[f>>2]|0)+4>>2]|0,t[u>>2]<<2)|0;if(!(t[a>>2]|0)){i=t[v>>2]|0;t[n>>2]=t[u>>2]<<2;xe(i|0,131856,n|0)|0;_i(1)}t[(t[f>>2]|0)+4>>2]=t[a>>2];t[t[f>>2]>>2]=t[u>>2];s=r;return}function Eu(e){e=e|0;var i=0,r=0,f=0,a=0;i=s;s=s+16|0;r=i+12|0;f=i;a=i+8|0;t[r>>2]=e;t[a>>2]=0;while(1){if((t[a>>2]|0)>=8)break;n[f+(u[131816+(7-(t[a>>2]|0))>>0]|0)>>0]=n[(t[r>>2]|0)+(t[a>>2]|0)>>0]|0;t[a>>2]=(t[a>>2]|0)+1}s=i;return+ +l[f>>3]}function Su(e){e=+e;var i=0,r=0,n=0;i=s;s=s+16|0;r=i+8|0;n=i;l[r>>3]=e;l[n>>3]=+l[r>>3];r=n;P=t[r+4>>2]|0;s=i;return t[r>>2]|0}function gu(e){e=+e;var i=0,r=0,n=0;i=s;s=s+16|0;r=i+4|0;n=i;c[r>>2]=e;c[n>>2]=+c[r>>2];s=i;return t[n>>2]|0}function yu(e,i,r){e=e|0;i=i|0;r=r|0;var f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0;f=s;s=s+128|0;u=f;a=f+20|0;o=f+16|0;c=f+12|0;l=f+8|0;b=f+4|0;k=f+24|0;t[a>>2]=e;t[o>>2]=i;t[c>>2]=r;t[b>>2]=0;while(1){h=k+((t[b>>2]<<1)+1)|0;if(!((t[b>>2]|0)<25?(t[b>>2]|0)<(t[c>>2]|0):0))break;n[h>>0]=32;n[k+(t[b>>2]<<1)>>0]=32;t[b>>2]=(t[b>>2]|0)+1}n[h>>0]=0;n[k+(t[b>>2]<<1)>>0]=0;if(!(t[o>>2]|0)){b=t[a>>2]|0;t[u>>2]=k;xe(b|0,127912,u|0)|0;xe(t[a>>2]|0,131072,u|0)|0;s=f;return}while(1){if(!(t[o>>2]|0))break;t[l>>2]=t[o>>2];t[o>>2]=t[(t[o>>2]|0)+24>>2];br(t[a>>2]|0,t[l>>2]|0,t[c>>2]|0)}s=f;return}function Fu(e){e=+e;var i=0,r=0,n=0;i=s;s=s+16|0;r=i;n=i+8|0;l[r>>3]=e;ju(+l[r>>3],n)|0;s=i;return t[n>>2]|0}function Ou(e){e=e|0;var i=0,r=0,n=0,f=0;i=s;s=s+16|0;r=i+8|0;n=i+4|0;f=i;t[r>>2]=e;if(!(t[r>>2]|0)){s=i;return}t[n>>2]=0;while(1){if((t[n>>2]|0)>=(t[(t[r>>2]|0)+4>>2]|0))break;t[f>>2]=t[(t[t[r>>2]>>2]|0)+(t[n>>2]<<2)>>2];if(t[(t[f>>2]|0)+4>>2]|0){if(t[(t[(t[f>>2]|0)+4>>2]|0)+8>>2]|0)pAi[t[135736>>2]&511](t[(t[(t[f>>2]|0)+4>>2]|0)+8>>2]|0);pAi[t[135736>>2]&511](t[(t[f>>2]|0)+4>>2]|0)}pAi[t[135736>>2]&511](t[f>>2]|0);t[n>>2]=(t[n>>2]|0)+1}Vu(t[r>>2]|0);s=i;return}function Au(e){e=e|0;var i=0,r=0,n=0,f=0,u=0;i=s;s=s+16|0;r=i+8|0;n=i+4|0;f=i;t[n>>2]=e;t[f>>2]=gAi[t[135744>>2]&511](12)|0;if(!(t[f>>2]|0)){Ut(0,130864);t[r>>2]=0;u=t[r>>2]|0;s=i;return u|0}e=t[f>>2]|0;t[e+0>>2]=0;t[e+4>>2]=0;t[e+8>>2]=0;if((t[n>>2]|0)>0){Mu(t[f>>2]|0,0,t[n>>2]|0)|0;t[(t[f>>2]|0)+4>>2]=0}t[r>>2]=t[f>>2];u=t[r>>2]|0;s=i;return u|0}function Mu(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0;n=s;s=s+16|0;f=n+12|0;u=n+8|0;a=n+4|0;o=n;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;do if(t[t[u>>2]>>2]|0){if((t[(t[u>>2]|0)+8>>2]|0)<=(t[(t[u>>2]|0)+4>>2]|0)){if((t[(t[u>>2]|0)+8>>2]|0)>5e7){Ut(0,130904);t[f>>2]=-1;c=t[f>>2]|0;s=n;return c|0}r=(t[u>>2]|0)+8|0;t[r>>2]=t[r>>2]<<1;r=MAi[t[135760>>2]&511](t[t[u>>2]>>2]|0,t[(t[u>>2]|0)+8>>2]<<2)|0;t[t[u>>2]>>2]=r;if(!(t[t[u>>2]>>2]|0)){Ut(0,130904);t[(t[u>>2]|0)+8>>2]=0;t[f>>2]=-1;c=t[f>>2]|0;s=n;return c|0}}}else{if((t[o>>2]|0)<=0)t[o>>2]=1;r=gAi[t[135744>>2]&511](t[o>>2]<<2)|0;t[t[u>>2]>>2]=r;if(t[t[u>>2]>>2]|0){t[(t[u>>2]|0)+4>>2]=0;t[(t[u>>2]|0)+8>>2]=t[o>>2];break}Ut(0,130864);t[f>>2]=-1;c=t[f>>2]|0;s=n;return c|0}while(0);o=t[a>>2]|0;a=(t[u>>2]|0)+4|0;r=t[a>>2]|0;t[a>>2]=r+1;t[(t[t[u>>2]>>2]|0)+(r<<2)>>2]=o;t[f>>2]=0;c=t[f>>2]|0;s=n;return c|0}function Ru(e){e=e|0;var i=0,r=0,n=0,f=0,a=0,o=0,c=0,l=0,b=0,k=0;i=s;s=s+32|0;r=i+20|0;n=i+16|0;f=i+12|0;a=i+8|0;o=i+4|0;c=i;t[n>>2]=e;t[f>>2]=2;t[a>>2]=0;t[o>>2]=0;t[c>>2]=0;if(!(t[n>>2]|0)){t[r>>2]=0;l=t[r>>2]|0;s=i;return l|0}if((t[(t[n>>2]|0)+4>>2]|0)==9){t[o>>2]=eF(t[n>>2]|0)|0;if(!(t[o>>2]|0))t[n>>2]=t[(t[n>>2]|0)+12>>2];else t[n>>2]=t[o>>2];if(!(t[n>>2]|0)){t[r>>2]=0;l=t[r>>2]|0;s=i;return l|0}}switch(t[(t[n>>2]|0)+4>>2]|0){case 2:{t[o>>2]=t[(t[n>>2]|0)+12>>2];break}case 1:{t[o>>2]=t[(t[n>>2]|0)+12>>2];break}case 3:case 4:case 7:case 8:{t[a>>2]=t[(t[n>>2]|0)+40>>2];if(!(t[a>>2]|0)){t[r>>2]=0;l=t[r>>2]|0;s=i;return l|0}if(!(u[t[a>>2]>>0]|0)){t[r>>2]=0;l=t[r>>2]|0;s=i;return l|0}else{t[r>>2]=(u[t[a>>2]>>0]|0)+((u[(t[a>>2]|0)+1>>0]|0)<<8);l=t[r>>2]|0;s=i;return l|0}break}case 18:{t[a>>2]=t[(t[n>>2]|0)+8>>2];if(!(t[a>>2]|0)){t[r>>2]=0;l=t[r>>2]|0;s=i;return l|0}if(!(u[t[a>>2]>>0]|0)){t[r>>2]=0;l=t[r>>2]|0;s=i;return l|0}else{t[r>>2]=(u[t[a>>2]>>0]|0)+((u[(t[a>>2]|0)+1>>0]|0)<<8);l=t[r>>2]|0;s=i;return l|0}break}default:{t[r>>2]=0;l=t[r>>2]|0;s=i;return l|0}}e:while(1){if(!(t[o>>2]|0)){b=47;break}switch(t[(t[o>>2]|0)+4>>2]|0){case 18:{t[a>>2]=t[(t[o>>2]|0)+8>>2];break}case 3:case 4:case 7:case 8:{t[a>>2]=t[(t[o>>2]|0)+40>>2];break}default:{}}if((t[a>>2]|0)!=0?(u[t[a>>2]>>0]|0|0)!=0:0){if((t[f>>2]|0)==1){b=30;break}if(u[(t[a>>2]|0)+1>>0]|0){b=33;break}t[f>>2]=1;t[c>>2]=u[t[a>>2]>>0]}if(((t[(t[o>>2]|0)+12>>2]|0)!=0?(t[(t[o>>2]|0)+4>>2]|0)!=14:0)?(t[(t[(t[o>>2]|0)+12>>2]|0)+4>>2]|0)!=17:0){t[o>>2]=t[(t[o>>2]|0)+12>>2];continue}if((t[o>>2]|0)==(t[n>>2]|0)){b=47;break}if(t[(t[o>>2]|0)+24>>2]|0){t[o>>2]=t[(t[o>>2]|0)+24>>2];continue}while(1){t[o>>2]=t[(t[o>>2]|0)+20>>2];if(!(t[o>>2]|0))continue e;if((t[o>>2]|0)==(t[n>>2]|0)){b=43;break}k=t[o>>2]|0;if(t[(t[o>>2]|0)+24>>2]|0){b=45;break}if(!k)continue e}if((b|0)==43){b=0;t[o>>2]=0;continue}else if((b|0)==45){b=0;t[o>>2]=t[k+24>>2];continue}}if((b|0)==30){t[r>>2]=(t[c>>2]|0)+((u[t[a>>2]>>0]|0)<<8);l=t[r>>2]|0;s=i;return l|0}else if((b|0)==33){t[r>>2]=(u[t[a>>2]>>0]|0)+((u[(t[a>>2]|0)+1>>0]|0)<<8);l=t[r>>2]|0;s=i;return l|0}else if((b|0)==47){t[r>>2]=t[c>>2];l=t[r>>2]|0;s=i;return l|0}return 0}function Nu(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i+4|0;n=i;t[n>>2]=e;do if(t[n>>2]|0)if(!(u[t[n>>2]>>0]|0)){t[r>>2]=0;break}else{t[r>>2]=(u[t[n>>2]>>0]|0)+((u[(t[n>>2]|0)+1>>0]|0)<<8);break}else t[r>>2]=0;while(0);s=i;return t[r>>2]|0}function Tu(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;var u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0;u=s;s=s+48|0;a=u+36|0;o=u+32|0;c=u+28|0;l=u+24|0;b=u+20|0;k=u+16|0;h=u+12|0;w=u+8|0;d=u+4|0;v=u;t[o>>2]=e;t[c>>2]=i;t[l>>2]=r;t[b>>2]=n;t[k>>2]=f;t[w>>2]=0;do if(!((t[k>>2]|0)==0|(t[b>>2]|0)==0)){if((t[t[b>>2]>>2]|0)!=1?(t[t[b>>2]>>2]|0)!=9:0)break;t[d>>2]=t[(t[b>>2]|0)+4>>2];e:do if(t[d>>2]|0){t[h>>2]=0;while(1){if((t[h>>2]|0)>=(t[t[d>>2]>>2]|0))break e;t[v>>2]=xn(t[(t[(t[d>>2]|0)+8>>2]|0)+(t[h>>2]<<2)>>2]|0)|0;if((t[v>>2]|0)!=0?(f=t[o>>2]|0,Sn(f,au(t[(t[o>>2]|0)+12>>2]|0,t[v>>2]|0)|0)|0,pAi[t[135736>>2]&511](t[v>>2]|0),gf(t[o>>2]|0,1),f=t[o>>2]|0,Sn(f,Vt(t[(t[o>>2]|0)+12>>2]|0,t[k>>2]|0)|0)|0,t[w>>2]=Sf(t[o>>2]|0,t[c>>2]|0,t[l>>2]|0)|0,(t[w>>2]|0)!=0):0)break e;t[h>>2]=(t[h>>2]|0)+1}}while(0);zt(t[(t[o>>2]|0)+12>>2]|0,t[b>>2]|0);zt(t[(t[o>>2]|0)+12>>2]|0,t[k>>2]|0);t[a>>2]=t[w>>2];m=t[a>>2]|0;s=u;return m|0}while(0);zt(t[(t[o>>2]|0)+12>>2]|0,t[b>>2]|0);zt(t[(t[o>>2]|0)+12>>2]|0,t[k>>2]|0);t[a>>2]=0;m=t[a>>2]|0;s=u;return m|0}function Lu(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;var u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0;u=s;s=s+48|0;a=u+36|0;o=u+32|0;c=u+28|0;l=u+24|0;b=u+20|0;k=u+16|0;h=u+12|0;w=u+8|0;d=u+4|0;v=u;t[o>>2]=e;t[c>>2]=i;t[l>>2]=r;t[b>>2]=n;t[k>>2]=f;t[w>>2]=0;do if(!((t[k>>2]|0)==0|(t[b>>2]|0)==0)){if((t[t[b>>2]>>2]|0)!=1?(t[t[b>>2]>>2]|0)!=9:0)break;t[d>>2]=t[(t[b>>2]|0)+4>>2];e:do if(t[d>>2]|0){t[h>>2]=0;while(1){if((t[h>>2]|0)>=(t[t[d>>2]>>2]|0))break e;t[v>>2]=xn(t[(t[(t[d>>2]|0)+8>>2]|0)+(t[h>>2]<<2)>>2]|0)|0;if((t[v>>2]|0)!=0?(f=t[o>>2]|0,Sn(f,au(t[(t[o>>2]|0)+12>>2]|0,t[v>>2]|0)|0)|0,pAi[t[135736>>2]&511](t[v>>2]|0),f=t[o>>2]|0,Sn(f,Vt(t[(t[o>>2]|0)+12>>2]|0,t[k>>2]|0)|0)|0,t[w>>2]=Sf(t[o>>2]|0,t[c>>2]|0,t[l>>2]|0)|0,(t[w>>2]|0)!=0):0)break e;t[h>>2]=(t[h>>2]|0)+1}}while(0);zt(t[(t[o>>2]|0)+12>>2]|0,t[b>>2]|0);zt(t[(t[o>>2]|0)+12>>2]|0,t[k>>2]|0);t[a>>2]=t[w>>2];m=t[a>>2]|0;s=u;return m|0}while(0);zt(t[(t[o>>2]|0)+12>>2]|0,t[b>>2]|0);zt(t[(t[o>>2]|0)+12>>2]|0,t[k>>2]|0);t[a>>2]=0;m=t[a>>2]|0;s=u;return m|0}function Du(e,i){e=e|0;i=i|0;var r=0,f=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0;r=s;s=s+32|0;f=r+16|0;a=r+12|0;o=r+8|0;c=r+20|0;l=r+4|0;b=r;t[a>>2]=e;t[o>>2]=i;if(!(t[a>>2]|0)){t[f>>2]=0;k=t[f>>2]|0;s=r;return k|0}t[b>>2]=t[t[a>>2]>>2];n[c>>0]=n[t[b>>2]>>0]|0;if(!((u[c>>0]|0)&128)){t[t[o>>2]>>2]=1;t[f>>2]=u[t[b>>2]>>0];k=t[f>>2]|0;s=r;return k|0}e:do if(((u[(t[b>>2]|0)+1>>0]|0)&192|0)==128){do if(((u[c>>0]|0)&224|0)==224){if(((u[(t[b>>2]|0)+2>>0]|0)&192|0)!=128)break e;if(((u[c>>0]|0)&240|0)!=240){t[t[o>>2]>>2]=3;t[l>>2]=((u[t[b>>2]>>0]|0)&15)<<12;t[l>>2]=t[l>>2]|((u[(t[b>>2]|0)+1>>0]|0)&63)<<6;t[l>>2]=t[l>>2]|(u[(t[b>>2]|0)+2>>0]|0)&63;break}if(((u[c>>0]|0)&248|0)!=240)break e;if(((u[(t[b>>2]|0)+3>>0]|0)&192|0)!=128)break e;t[t[o>>2]>>2]=4;t[l>>2]=((u[t[b>>2]>>0]|0)&7)<<18;t[l>>2]=t[l>>2]|((u[(t[b>>2]|0)+1>>0]|0)&63)<<12;t[l>>2]=t[l>>2]|((u[(t[b>>2]|0)+2>>0]|0)&63)<<6;t[l>>2]=t[l>>2]|(u[(t[b>>2]|0)+3>>0]|0)&63}else{t[t[o>>2]>>2]=2;t[l>>2]=((u[t[b>>2]>>0]|0)&31)<<6;t[l>>2]=t[l>>2]|(u[(t[b>>2]|0)+1>>0]|0)&63}while(0);i=t[l>>2]|0;if((t[l>>2]|0)>>>0<256)if(9<=i>>>0&(t[l>>2]|0)>>>0<=10|(t[l>>2]|0)==13|32<=(t[l>>2]|0)>>>0)h=19;else h=18;else if((!(256<=i>>>0&(t[l>>2]|0)>>>0<=55295)?!(57344<=(t[l>>2]|0)>>>0&(t[l>>2]|0)>>>0<=65533):0)?!(65536<=(t[l>>2]|0)>>>0&(t[l>>2]|0)>>>0<=1114111):0)h=18;else h=19;if((h|0)==18){dn(t[a>>2]|0,21);t[f>>2]=0;k=t[f>>2]|0;s=r;return k|0}else if((h|0)==19){t[f>>2]=t[l>>2];k=t[f>>2]|0;s=r;return k|0}}while(0);t[t[o>>2]>>2]=0;dn(t[a>>2]|0,20);t[f>>2]=0;k=t[f>>2]|0;s=r;return k|0}function Cu(e){e=e|0;var i=0,r=0,n=0,f=0,a=0,o=0;i=s;s=s+16|0;r=i+4|0;n=i;t[r>>2]=e;qu(t[r>>2]|0);if(t[(t[r>>2]|0)+8>>2]|0){s=i;return}e:while(1){do if((u[t[t[r>>2]>>2]>>0]|0|0)!=32){if(9<=(u[t[t[r>>2]>>2]>>0]|0|0)?(u[t[t[r>>2]>>2]>>0]|0|0)<=10:0)break;if((u[t[t[r>>2]>>2]>>0]|0|0)!=13)break e}while(0);e=t[r>>2]|0;if(!(u[t[t[r>>2]>>2]>>0]|0))continue;t[e>>2]=(t[e>>2]|0)+1}e:while(1){if((u[t[t[r>>2]>>2]>>0]|0|0)!=97){f=27;break}if((u[(t[t[r>>2]>>2]|0)+1>>0]|0|0)!=110){f=27;break}if((u[(t[t[r>>2]>>2]|0)+2>>0]|0|0)!=100){f=27;break}t[n>>2]=t[(t[(t[r>>2]|0)+32>>2]|0)+12>>2];e=t[r>>2]|0;t[e>>2]=(t[e>>2]|0)+3;while(1){do if((u[t[t[r>>2]>>2]>>0]|0|0)==32)a=1;else{if(9<=(u[t[t[r>>2]>>2]>>0]|0|0)?(u[t[t[r>>2]>>2]>>0]|0|0)<=10:0){a=1;break}a=(u[t[t[r>>2]>>2]>>0]|0|0)==13}while(0);o=t[r>>2]|0;if(!a)break;e=t[r>>2]|0;if(!(u[t[o>>2]>>0]|0))continue;t[e>>2]=(t[e>>2]|0)+1}qu(o);if(t[(t[r>>2]|0)+8>>2]|0){f=27;break}Pu(t[(t[r>>2]|0)+32>>2]|0,t[n>>2]|0,t[(t[(t[r>>2]|0)+32>>2]|0)+12>>2]|0,1,0,0,0,0,0)|0;while(1){do if((u[t[t[r>>2]>>2]>>0]|0|0)!=32){if(9<=(u[t[t[r>>2]>>2]>>0]|0|0)?(u[t[t[r>>2]>>2]>>0]|0|0)<=10:0)break;if((u[t[t[r>>2]>>2]>>0]|0|0)!=13)continue e}while(0);e=t[r>>2]|0;if(!(u[t[t[r>>2]>>2]>>0]|0))continue;t[e>>2]=(t[e>>2]|0)+1}}if((f|0)==27){s=i;return}}function Pu(e,i,r,n,f,u,a,o,c){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;u=u|0;a=a|0;o=o|0;c=c|0;var l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0,S=0,g=0,y=0;l=s;s=s+48|0;b=l+40|0;k=l+36|0;h=l+32|0;w=l+28|0;d=l+24|0;v=l+20|0;m=l+16|0;_=l+12|0;p=l+8|0;E=l+4|0;S=l;t[k>>2]=e;t[h>>2]=i;t[w>>2]=r;t[d>>2]=n;t[v>>2]=f;t[m>>2]=u;t[_>>2]=a;t[p>>2]=o;t[E>>2]=c;do if((t[t[k>>2]>>2]|0)>=(t[(t[k>>2]|0)+4>>2]|0)){if((t[(t[k>>2]|0)+4>>2]|0)>=1e6){Ut(0,130416);t[b>>2]=-1;g=t[b>>2]|0;s=l;return g|0}c=(t[k>>2]|0)+4|0;t[c>>2]=t[c>>2]<<1;t[S>>2]=MAi[t[135760>>2]&511](t[(t[k>>2]|0)+8>>2]|0,(t[(t[k>>2]|0)+4>>2]|0)*40|0)|0;if(t[S>>2]|0){t[(t[k>>2]|0)+8>>2]=t[S>>2];break}c=(t[k>>2]|0)+4|0;t[c>>2]=(t[c>>2]|0)/2|0;Ut(0,130416);t[b>>2]=-1;g=t[b>>2]|0;s=l;return g|0}while(0);t[(t[k>>2]|0)+12>>2]=t[t[k>>2]>>2];t[(t[(t[k>>2]|0)+8>>2]|0)+((t[t[k>>2]>>2]|0)*40|0)+4>>2]=t[h>>2];t[(t[(t[k>>2]|0)+8>>2]|0)+((t[t[k>>2]>>2]|0)*40|0)+8>>2]=t[w>>2];t[(t[(t[k>>2]|0)+8>>2]|0)+((t[t[k>>2]>>2]|0)*40|0)>>2]=t[d>>2];t[(t[(t[k>>2]|0)+8>>2]|0)+((t[t[k>>2]>>2]|0)*40|0)+12>>2]=t[v>>2];t[(t[(t[k>>2]|0)+8>>2]|0)+((t[t[k>>2]>>2]|0)*40|0)+16>>2]=t[m>>2];t[(t[(t[k>>2]|0)+8>>2]|0)+((t[t[k>>2]>>2]|0)*40|0)+20>>2]=t[_>>2];do if((t[(t[k>>2]|0)+20>>2]|0)!=0?(t[d>>2]|0)==14|(t[d>>2]|0)==13|(t[d>>2]|0)==11:0){_=t[k>>2]|0;if(t[p>>2]|0){m=kz(t[_+20>>2]|0,t[p>>2]|0,-1)|0;t[(t[(t[k>>2]|0)+8>>2]|0)+((t[t[k>>2]>>2]|0)*40|0)+24>>2]=m;pAi[t[135736>>2]&511](t[p>>2]|0)}else t[(t[(t[k>>2]|0)+8>>2]|0)+((t[_>>2]|0)*40|0)+24>>2]=0;_=t[k>>2]|0;if(t[E>>2]|0){m=kz(t[_+20>>2]|0,t[E>>2]|0,-1)|0;t[(t[(t[k>>2]|0)+8>>2]|0)+((t[t[k>>2]>>2]|0)*40|0)+28>>2]=m;pAi[t[135736>>2]&511](t[E>>2]|0);break}else{t[(t[(t[k>>2]|0)+8>>2]|0)+((t[_>>2]|0)*40|0)+28>>2]=0;break}}else y=15;while(0);if((y|0)==15){t[(t[(t[k>>2]|0)+8>>2]|0)+((t[t[k>>2]>>2]|0)*40|0)+24>>2]=t[p>>2];t[(t[(t[k>>2]|0)+8>>2]|0)+((t[t[k>>2]>>2]|0)*40|0)+28>>2]=t[E>>2]}t[(t[(t[k>>2]|0)+8>>2]|0)+((t[t[k>>2]>>2]|0)*40|0)+32>>2]=0;E=t[k>>2]|0;k=t[E>>2]|0;t[E>>2]=k+1;t[b>>2]=k;g=t[b>>2]|0;s=l;return g|0}function Bu(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0;r=s;s=s+16|0;n=r+12|0;f=r+8|0;u=r+4|0;a=r;t[f>>2]=e;t[u>>2]=i;t[a>>2]=gAi[t[135744>>2]&511](48)|0;if(!(t[a>>2]|0)){Ut(t[u>>2]|0,129952);t[n>>2]=0;o=t[n>>2]|0;s=r;return o|0}i=(t[a>>2]|0)+0|0;e=i+48|0;do{t[i>>2]=0;i=i+4|0}while((i|0)<(e|0));i=gAi[t[135744>>2]&511](40)|0;t[(t[a>>2]|0)+28>>2]=i;if(!(t[(t[a>>2]|0)+28>>2]|0)){pAi[t[135736>>2]&511](t[a>>2]|0);Ut(t[u>>2]|0,129952);t[n>>2]=0;o=t[n>>2]|0;s=r;return o|0}else{t[(t[a>>2]|0)+20>>2]=0;t[(t[a>>2]|0)+24>>2]=10;t[(t[a>>2]|0)+16>>2]=0;t[(t[a>>2]|0)+44>>2]=0;t[(t[a>>2]|0)+12>>2]=t[u>>2];t[(t[a>>2]|0)+32>>2]=t[f>>2];t[n>>2]=t[a>>2];o=t[n>>2]|0;s=r;return o|0}return 0}function Iu(e,i){e=e|0;i=i|0;var r=0,n=0,f=0;r=s;s=s+16|0;n=r+4|0;f=r;t[n>>2]=e;t[f>>2]=i;if(!(t[n>>2]|0)){Ut(0,t[f>>2]|0);s=r;return}else{t[(t[n>>2]|0)+8>>2]=15;Ut(t[(t[n>>2]|0)+12>>2]|0,t[f>>2]|0);s=r;return}}function Hu(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0,S=0,g=0,y=0,F=0;f=s;s=s+64|0;u=f+56|0;a=f+52|0;o=f+48|0;c=f+44|0;l=f+40|0;b=f+36|0;k=f+32|0;h=f+28|0;w=f+24|0;d=f+20|0;v=f+16|0;m=f+12|0;_=f+8|0;p=f+4|0;E=f;t[a>>2]=e;t[o>>2]=i;t[c>>2]=r;t[l>>2]=n;t[m>>2]=0;t[_>>2]=0;t[p>>2]=0;t[E>>2]=0;if((t[a>>2]|0)==0|(t[o>>2]|0)==0){t[u>>2]=-1;S=t[u>>2]|0;s=f;return S|0}t[b>>2]=Rj(t[o>>2]|0)|0;if((t[b>>2]|0)==-1){t[u>>2]=-1;S=t[u>>2]|0;s=f;return S|0}if((t[b>>2]|0)==-2)t[b>>2]=1e4;t[k>>2]=Nj(t[o>>2]|0)|0;if((t[k>>2]|0)==-1){t[u>>2]=-1;S=t[u>>2]|0;s=f;return S|0}t[h>>2]=Tj(t[o>>2]|0)|0;if((t[h>>2]|0)<0){t[u>>2]=-1;S=t[u>>2]|0;s=f;return S|0}if(!(t[l>>2]|0)){if(!(t[c>>2]|0)){t[u>>2]=-1;S=t[u>>2]|0;s=f;return S|0}n=ru(t[a>>2]|0,0)|0;t[t[c>>2]>>2]=n;if(!(t[t[c>>2]>>2]|0)){t[u>>2]=-1;S=t[u>>2]|0;s=f;return S|0}}do if(!(t[k>>2]|0)){n=(t[l>>2]|0)!=0;if(t[h>>2]|0){if(!n){Cn(t[(t[t[c>>2]>>2]|0)+4>>2]|0,t[t[a>>2]>>2]|0)|0;break}t[u>>2]=1;S=t[u>>2]|0;s=f;return S|0}else{if(!n){Cn(t[(t[t[c>>2]>>2]|0)+4>>2]|0,t[(t[a>>2]|0)+4>>2]|0)|0;break}t[u>>2]=1;S=t[u>>2]|0;s=f;return S|0}}while(0);if(!(t[b>>2]|0)){t[u>>2]=0;S=t[u>>2]|0;s=f;return S|0}k=t[a>>2]|0;if(!(t[h>>2]|0)){if(t[k+4>>2]|0){switch(t[(t[(t[a>>2]|0)+4>>2]|0)+4>>2]|0){case 21:case 13:case 11:case 9:case 1:{t[m>>2]=t[(t[a>>2]|0)+4>>2];break}default:{}}t[_>>2]=t[m>>2]}}else t[m>>2]=t[k>>2];if(!(t[m>>2]|0)){t[u>>2]=0;S=t[u>>2]|0;s=f;return S|0}t[p>>2]=Aj(t[o>>2]|0)|0;if(!(t[p>>2]|0)){t[u>>2]=0;S=t[u>>2]|0;s=f;return S|0}t[v>>2]=yj(t[p>>2]|0)|0;if((t[h>>2]|0)!=0?(t[w>>2]=pj(t[p>>2]|0,0,0)|0,(t[w>>2]|0)>=0&(t[w>>2]|0)==1):0){if(!(t[l>>2]|0)){Cn(t[(t[t[c>>2]>>2]|0)+4>>2]|0,t[m>>2]|0)|0;g=40}}else g=40;e:do if((g|0)==40){t[d>>2]=0;i:while(1){if((t[(t[m>>2]|0)+4>>2]|0)==18)break;if((((t[(t[m>>2]|0)+12>>2]|0)!=0?(t[d>>2]|0)<(t[b>>2]|0):0)?(t[(t[(t[m>>2]|0)+12>>2]|0)+4>>2]|0)!=17:0)?(t[m>>2]=t[(t[m>>2]|0)+12>>2],t[d>>2]=(t[d>>2]|0)+1,(t[(t[m>>2]|0)+4>>2]|0)!=14):0)g=80;else g=63;r:do if((g|0)==63){g=0;if((t[m>>2]|0)==(t[_>>2]|0))break i;while(1){if(!(t[(t[m>>2]|0)+24>>2]|0))break;t[m>>2]=t[(t[m>>2]|0)+24>>2];if((t[(t[m>>2]|0)+4>>2]|0)==17)continue;if((t[(t[m>>2]|0)+4>>2]|0)!=14)break r}while(1){t[m>>2]=t[(t[m>>2]|0)+20>>2];t[d>>2]=(t[d>>2]|0)+-1;if(!(t[m>>2]|0))break i;if((t[m>>2]|0)==(t[_>>2]|0))break i;n:do if((t[(t[m>>2]|0)+4>>2]|0)==1)t[w>>2]=gj(t[p>>2]|0)|0;else{if(!(t[v>>2]|0))break;do if((t[(t[m>>2]|0)+4>>2]|0)!=3){if((t[(t[m>>2]|0)+4>>2]|0)==4)break;if((t[(t[m>>2]|0)+4>>2]|0)==8)break;if((t[(t[m>>2]|0)+4>>2]|0)!=7)break n}while(0);t[w>>2]=gj(t[p>>2]|0)|0}while(0);y=t[m>>2]|0;if(t[(t[m>>2]|0)+24>>2]|0)break;if(!y){g=80;break r}}t[m>>2]=t[y+24>>2];g=80}while(0);if((g|0)==80?(g=0,!((t[m>>2]|0)!=0&(t[d>>2]|0)>=0)):0)break;r:while(1){t[E>>2]=(t[E>>2]|0)+1;switch(t[(t[m>>2]|0)+4>>2]|0){case 7:case 8:case 4:case 3:case 1:break;default:continue i}if((t[(t[m>>2]|0)+4>>2]|0)==1){if(t[(t[m>>2]|0)+36>>2]|0)F=t[(t[(t[m>>2]|0)+36>>2]|0)+8>>2]|0;else F=0;t[w>>2]=pj(t[p>>2]|0,t[(t[m>>2]|0)+8>>2]|0,F)|0}else{if(!(t[v>>2]|0))continue i;t[w>>2]=Ej(t[p>>2]|0,0,0,t[(t[m>>2]|0)+4>>2]|0)|0}do if((t[w>>2]|0)>=0&(t[w>>2]|0)==1){if(t[l>>2]|0)break e;if((Cn(t[(t[t[c>>2]>>2]|0)+4>>2]|0,t[m>>2]|0)|0)>=0)break;t[(t[a>>2]|0)+136>>2]=12;t[(t[a>>2]|0)+140>>2]=2}while(0);if((t[(t[m>>2]|0)+12>>2]|0)!=0?(t[d>>2]|0)<(t[b>>2]|0):0)continue i;
	t[w>>2]=gj(t[p>>2]|0)|0;while(1){if(!(t[(t[m>>2]|0)+24>>2]|0))continue i;t[m>>2]=t[(t[m>>2]|0)+24>>2];if((t[(t[m>>2]|0)+4>>2]|0)==17)continue;if((t[(t[m>>2]|0)+4>>2]|0)!=14)continue r}}}if(t[p>>2]|0)_j(t[p>>2]|0);t[u>>2]=0;S=t[u>>2]|0;s=f;return S|0}while(0);if(t[p>>2]|0)_j(t[p>>2]|0);t[u>>2]=1;S=t[u>>2]|0;s=f;return S|0}function xu(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0;n=s;s=s+32|0;f=n+20|0;u=n+16|0;a=n+12|0;o=n+8|0;c=n+4|0;l=n;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;t[c>>2]=0;while(1){r=t[t[a>>2]>>2]|0;if(!r){b=3;break}else if((r|0)==11){b=10;break}else if((r|0)==12){b=4;break}else if((r|0)!=18){b=18;break}if((t[(t[a>>2]|0)+4>>2]|0)==-1){b=9;break}t[a>>2]=(t[(t[(t[u>>2]|0)+32>>2]|0)+8>>2]|0)+((t[(t[a>>2]|0)+4>>2]|0)*40|0)}do if((b|0)==3)t[f>>2]=0;else if((b|0)==4){t[c>>2]=t[(t[a>>2]|0)+24>>2];if(t[o>>2]|0){t[f>>2]=vt(t[u>>2]|0,t[c>>2]|0)|0;break}else{t[f>>2]=yn(t[c>>2]|0)|0;break}}else if((b|0)==9)t[f>>2]=0;else if((b|0)==10){if((t[(t[a>>2]|0)+4>>2]|0)==-1){t[f>>2]=0;break}Uu(t[u>>2]|0,(t[(t[(t[u>>2]|0)+32>>2]|0)+8>>2]|0)+((t[(t[a>>2]|0)+4>>2]|0)*40|0)|0)|0;if(t[(t[u>>2]|0)+8>>2]|0){t[f>>2]=-1;break}Yu(t[u>>2]|0,t[a>>2]|0,0,0,1)|0;if(t[(t[u>>2]|0)+8>>2]|0){t[f>>2]=-1;break}t[c>>2]=En(t[u>>2]|0)|0;if(!(t[c>>2]|0))t[f>>2]=-1;else b=22}else if((b|0)==18){Uu(t[u>>2]|0,t[a>>2]|0)|0;if(t[(t[u>>2]|0)+8>>2]|0){t[f>>2]=-1;break}t[c>>2]=En(t[u>>2]|0)|0;if(!(t[c>>2]|0))t[f>>2]=-1;else b=22}while(0);do if((b|0)==22){if(!(t[c>>2]|0)){t[f>>2]=0;break}do if((t[t[c>>2]>>2]|0)!=2)if(t[o>>2]|0){t[l>>2]=vt(t[u>>2]|0,t[c>>2]|0)|0;break}else{t[l>>2]=yn(t[c>>2]|0)|0;break}else t[l>>2]=t[(t[c>>2]|0)+8>>2];while(0);zt(t[(t[u>>2]|0)+12>>2]|0,t[c>>2]|0);t[f>>2]=t[l>>2]}while(0);s=n;return t[f>>2]|0}function Uu(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0,S=0,g=0,y=0,F=0,O=0,A=0,M=0,R=0,N=0,T=0,L=0,D=0,C=0,P=0,B=0,I=0,H=0,x=0,U=0,z=0,j=0,V=0,q=0,Y=0,G=0,W=0,K=0,X=0,Z=0,J=0,Q=0,$=0,ee=0,ie=0,re=0;r=s;s=s+192|0;n=r;f=r+184|0;u=r+180|0;a=r+176|0;o=r+172|0;c=r+168|0;b=r+164|0;k=r+160|0;h=r+156|0;w=r+152|0;d=r+148|0;v=r+144|0;m=r+140|0;_=r+136|0;p=r+132|0;E=r+128|0;S=r+124|0;g=r+120|0;y=r+116|0;F=r+112|0;O=r+108|0;A=r+104|0;M=r+100|0;R=r+96|0;N=r+92|0;T=r+88|0;L=r+84|0;D=r+80|0;C=r+76|0;P=r+72|0;B=r+68|0;I=r+64|0;H=r+60|0;x=r+56|0;U=r+52|0;z=r+48|0;j=r+44|0;V=r+40|0;q=r+36|0;Y=r+32|0;G=r+28|0;W=r+24|0;K=r+20|0;X=r+16|0;Z=r+12|0;J=r+8|0;t[u>>2]=e;t[a>>2]=i;t[o>>2]=0;if(t[(t[u>>2]|0)+8>>2]|0){t[f>>2]=0;Q=t[f>>2]|0;s=r;return Q|0}t[k>>2]=t[(t[u>>2]|0)+32>>2];do switch(t[t[a>>2]>>2]|0){case 0:{t[f>>2]=0;Q=t[f>>2]|0;s=r;return Q|0}case 8:{jf(t[u>>2]|0);t[f>>2]=t[o>>2];Q=t[f>>2]|0;s=r;return Q|0}case 10:{if((t[(t[a>>2]|0)+4>>2]|0)!=-1){i=Uu(t[u>>2]|0,(t[(t[k>>2]|0)+8>>2]|0)+((t[(t[a>>2]|0)+4>>2]|0)*40|0)|0)|0;t[o>>2]=(t[o>>2]|0)+i}if(t[(t[u>>2]|0)+8>>2]|0){t[f>>2]=0;Q=t[f>>2]|0;s=r;return Q|0}if((t[(t[a>>2]|0)+8>>2]|0)!=-1){i=Uu(t[u>>2]|0,(t[(t[k>>2]|0)+8>>2]|0)+((t[(t[a>>2]|0)+8>>2]|0)*40|0)|0)|0;t[o>>2]=(t[o>>2]|0)+i}if(t[(t[u>>2]|0)+8>>2]|0){t[f>>2]=0;Q=t[f>>2]|0;s=r;return Q|0}else{t[(t[(t[u>>2]|0)+12>>2]|0)+4>>2]=0;t[f>>2]=t[o>>2];Q=t[f>>2]|0;s=r;return Q|0}break}case 9:{if((t[(t[a>>2]|0)+4>>2]|0)!=-1){i=Uu(t[u>>2]|0,(t[(t[k>>2]|0)+8>>2]|0)+((t[(t[a>>2]|0)+4>>2]|0)*40|0)|0)|0;t[o>>2]=(t[o>>2]|0)+i}if(t[(t[u>>2]|0)+8>>2]|0){t[f>>2]=0;Q=t[f>>2]|0;s=r;return Q|0}if((t[(t[a>>2]|0)+8>>2]|0)!=-1){i=Uu(t[u>>2]|0,(t[(t[k>>2]|0)+8>>2]|0)+((t[(t[a>>2]|0)+8>>2]|0)*40|0)|0)|0;t[o>>2]=(t[o>>2]|0)+i}if(t[(t[u>>2]|0)+8>>2]|0){t[f>>2]=0;Q=t[f>>2]|0;s=r;return Q|0}else{i=t[u>>2]|0;Sn(i,ru(t[(t[u>>2]|0)+12>>2]|0,t[(t[(t[u>>2]|0)+12>>2]|0)+4>>2]|0)|0)|0;t[f>>2]=t[o>>2];Q=t[f>>2]|0;s=r;return Q|0}break}case 11:{if((t[(t[a>>2]|0)+4>>2]|0)==-1){t[f>>2]=t[o>>2];Q=t[f>>2]|0;s=r;return Q|0}t[o>>2]=(Uu(t[u>>2]|0,(t[(t[k>>2]|0)+8>>2]|0)+((t[(t[a>>2]|0)+4>>2]|0)*40|0)|0)|0)+(t[o>>2]|0);if(t[(t[u>>2]|0)+8>>2]|0){t[f>>2]=0;Q=t[f>>2]|0;s=r;return Q|0}else{i=Yu(t[u>>2]|0,t[a>>2]|0,0,0,0)|0;t[o>>2]=(t[o>>2]|0)+i;t[f>>2]=t[o>>2];Q=t[f>>2]|0;s=r;return Q|0}break}case 7:{t[v>>2]=t[t[(t[u>>2]|0)+12>>2]>>2];t[d>>2]=t[(t[(t[u>>2]|0)+12>>2]|0)+4>>2];t[m>>2]=t[(t[(t[u>>2]|0)+12>>2]|0)+72>>2];t[_>>2]=t[(t[(t[u>>2]|0)+12>>2]|0)+68>>2];t[o>>2]=(Uu(t[u>>2]|0,(t[(t[k>>2]|0)+8>>2]|0)+((t[(t[a>>2]|0)+4>>2]|0)*40|0)|0)|0)+(t[o>>2]|0);if(t[(t[u>>2]|0)+8>>2]|0){t[f>>2]=0;Q=t[f>>2]|0;s=r;return Q|0}t[t[(t[u>>2]|0)+12>>2]>>2]=t[v>>2];t[(t[(t[u>>2]|0)+12>>2]|0)+4>>2]=t[d>>2];t[(t[(t[u>>2]|0)+12>>2]|0)+72>>2]=t[m>>2];t[(t[(t[u>>2]|0)+12>>2]|0)+68>>2]=t[_>>2];t[o>>2]=(Uu(t[u>>2]|0,(t[(t[k>>2]|0)+8>>2]|0)+((t[(t[a>>2]|0)+8>>2]|0)*40|0)|0)|0)+(t[o>>2]|0);if(t[(t[u>>2]|0)+8>>2]|0){t[f>>2]=0;Q=t[f>>2]|0;s=r;return Q|0}if((t[(t[u>>2]|0)+16>>2]|0)!=0?(t[t[(t[u>>2]|0)+16>>2]>>2]|0)==1:0){t[w>>2]=En(t[u>>2]|0)|0;if((t[(t[u>>2]|0)+16>>2]|0)!=0?(t[t[(t[u>>2]|0)+16>>2]>>2]|0)==1:0){t[h>>2]=En(t[u>>2]|0)|0;if(t[(t[h>>2]|0)+4>>2]|0){if((t[(t[w>>2]|0)+4>>2]|0)!=0?(t[t[(t[w>>2]|0)+4>>2]>>2]|0)!=0:0)$=78}else $=78;if(($|0)==78){i=Pn(t[(t[h>>2]|0)+4>>2]|0,t[(t[w>>2]|0)+4>>2]|0)|0;t[(t[h>>2]|0)+4>>2]=i}Sn(t[u>>2]|0,t[h>>2]|0)|0;zt(t[(t[u>>2]|0)+12>>2]|0,t[w>>2]|0);t[f>>2]=t[o>>2];Q=t[f>>2]|0;s=r;return Q|0}dn(t[u>>2]|0,11);t[f>>2]=0;Q=t[f>>2]|0;s=r;return Q|0}dn(t[u>>2]|0,11);t[f>>2]=0;Q=t[f>>2]|0;s=r;return Q|0}case 5:{t[v>>2]=t[t[(t[u>>2]|0)+12>>2]>>2];t[d>>2]=t[(t[(t[u>>2]|0)+12>>2]|0)+4>>2];t[m>>2]=t[(t[(t[u>>2]|0)+12>>2]|0)+72>>2];t[_>>2]=t[(t[(t[u>>2]|0)+12>>2]|0)+68>>2];t[o>>2]=(Uu(t[u>>2]|0,(t[(t[k>>2]|0)+8>>2]|0)+((t[(t[a>>2]|0)+4>>2]|0)*40|0)|0)|0)+(t[o>>2]|0);if(t[(t[u>>2]|0)+8>>2]|0){t[f>>2]=0;Q=t[f>>2]|0;s=r;return Q|0}if((t[(t[a>>2]|0)+8>>2]|0)!=-1){t[t[(t[u>>2]|0)+12>>2]>>2]=t[v>>2];t[(t[(t[u>>2]|0)+12>>2]|0)+4>>2]=t[d>>2];t[(t[(t[u>>2]|0)+12>>2]|0)+72>>2]=t[m>>2];t[(t[(t[u>>2]|0)+12>>2]|0)+68>>2]=t[_>>2];i=Uu(t[u>>2]|0,(t[(t[k>>2]|0)+8>>2]|0)+((t[(t[a>>2]|0)+8>>2]|0)*40|0)|0)|0;t[o>>2]=(t[o>>2]|0)+i}if(t[(t[u>>2]|0)+8>>2]|0){t[f>>2]=0;Q=t[f>>2]|0;s=r;return Q|0}do if(t[(t[a>>2]|0)+12>>2]|0){if((t[(t[a>>2]|0)+12>>2]|0)==1){Ff(t[u>>2]|0);break}if((t[(t[a>>2]|0)+12>>2]|0)==2){yf(t[u>>2]|0);break}if((t[(t[a>>2]|0)+12>>2]|0)==3){if((t[(t[u>>2]|0)+16>>2]|0)!=0?(t[t[(t[u>>2]|0)+16>>2]>>2]|0)!=3:0)gf(t[u>>2]|0,1);if((t[(t[u>>2]|0)+16>>2]|0)!=0?(t[t[(t[u>>2]|0)+16>>2]>>2]|0)==3:0)break;dn(t[u>>2]|0,11);t[f>>2]=0;Q=t[f>>2]|0;s=r;return Q|0}}else Of(t[u>>2]|0);while(0);t[f>>2]=t[o>>2];Q=t[f>>2]|0;s=r;return Q|0}case 1:{t[v>>2]=t[t[(t[u>>2]|0)+12>>2]>>2];t[d>>2]=t[(t[(t[u>>2]|0)+12>>2]|0)+4>>2];t[m>>2]=t[(t[(t[u>>2]|0)+12>>2]|0)+72>>2];t[_>>2]=t[(t[(t[u>>2]|0)+12>>2]|0)+68>>2];t[o>>2]=(Uu(t[u>>2]|0,(t[(t[k>>2]|0)+8>>2]|0)+((t[(t[a>>2]|0)+4>>2]|0)*40|0)|0)|0)+(t[o>>2]|0);if(t[(t[u>>2]|0)+8>>2]|0){t[f>>2]=0;Q=t[f>>2]|0;s=r;return Q|0}tt(t[u>>2]|0,1);if((t[(t[u>>2]|0)+16>>2]|0)!=0?(t[(t[(t[u>>2]|0)+16>>2]|0)+8>>2]|0)!=0:0){t[w>>2]=En(t[u>>2]|0)|0;t[t[(t[u>>2]|0)+12>>2]>>2]=t[v>>2];t[(t[(t[u>>2]|0)+12>>2]|0)+4>>2]=t[d>>2];t[(t[(t[u>>2]|0)+12>>2]|0)+72>>2]=t[m>>2];t[(t[(t[u>>2]|0)+12>>2]|0)+68>>2]=t[_>>2];i=Uu(t[u>>2]|0,(t[(t[k>>2]|0)+8>>2]|0)+((t[(t[a>>2]|0)+8>>2]|0)*40|0)|0)|0;t[o>>2]=(t[o>>2]|0)+i;if(t[(t[u>>2]|0)+8>>2]|0){_n(t[w>>2]|0);t[f>>2]=0;Q=t[f>>2]|0;s=r;return Q|0}else{tt(t[u>>2]|0,1);t[h>>2]=En(t[u>>2]|0)|0;i=(t[h>>2]|0)+8|0;t[i>>2]=t[i>>2]&t[(t[w>>2]|0)+8>>2];Sn(t[u>>2]|0,t[h>>2]|0)|0;zt(t[(t[u>>2]|0)+12>>2]|0,t[w>>2]|0);t[f>>2]=t[o>>2];Q=t[f>>2]|0;s=r;return Q|0}}t[f>>2]=t[o>>2];Q=t[f>>2]|0;s=r;return Q|0}case 2:{t[v>>2]=t[t[(t[u>>2]|0)+12>>2]>>2];t[d>>2]=t[(t[(t[u>>2]|0)+12>>2]|0)+4>>2];t[m>>2]=t[(t[(t[u>>2]|0)+12>>2]|0)+72>>2];t[_>>2]=t[(t[(t[u>>2]|0)+12>>2]|0)+68>>2];t[o>>2]=(Uu(t[u>>2]|0,(t[(t[k>>2]|0)+8>>2]|0)+((t[(t[a>>2]|0)+4>>2]|0)*40|0)|0)|0)+(t[o>>2]|0);if(t[(t[u>>2]|0)+8>>2]|0){t[f>>2]=0;Q=t[f>>2]|0;s=r;return Q|0}tt(t[u>>2]|0,1);if((t[(t[u>>2]|0)+16>>2]|0)!=0?(t[(t[(t[u>>2]|0)+16>>2]|0)+8>>2]|0)!=1:0){t[w>>2]=En(t[u>>2]|0)|0;t[t[(t[u>>2]|0)+12>>2]>>2]=t[v>>2];t[(t[(t[u>>2]|0)+12>>2]|0)+4>>2]=t[d>>2];t[(t[(t[u>>2]|0)+12>>2]|0)+72>>2]=t[m>>2];t[(t[(t[u>>2]|0)+12>>2]|0)+68>>2]=t[_>>2];i=Uu(t[u>>2]|0,(t[(t[k>>2]|0)+8>>2]|0)+((t[(t[a>>2]|0)+8>>2]|0)*40|0)|0)|0;t[o>>2]=(t[o>>2]|0)+i;if(t[(t[u>>2]|0)+8>>2]|0){_n(t[w>>2]|0);t[f>>2]=0;Q=t[f>>2]|0;s=r;return Q|0}else{tt(t[u>>2]|0,1);t[h>>2]=En(t[u>>2]|0)|0;i=(t[h>>2]|0)+8|0;t[i>>2]=t[i>>2]|t[(t[w>>2]|0)+8>>2];Sn(t[u>>2]|0,t[h>>2]|0)|0;zt(t[(t[u>>2]|0)+12>>2]|0,t[w>>2]|0);t[f>>2]=t[o>>2];Q=t[f>>2]|0;s=r;return Q|0}}t[f>>2]=t[o>>2];Q=t[f>>2]|0;s=r;return Q|0}case 4:{t[v>>2]=t[t[(t[u>>2]|0)+12>>2]>>2];t[d>>2]=t[(t[(t[u>>2]|0)+12>>2]|0)+4>>2];t[m>>2]=t[(t[(t[u>>2]|0)+12>>2]|0)+72>>2];t[_>>2]=t[(t[(t[u>>2]|0)+12>>2]|0)+68>>2];t[o>>2]=(Uu(t[u>>2]|0,(t[(t[k>>2]|0)+8>>2]|0)+((t[(t[a>>2]|0)+4>>2]|0)*40|0)|0)|0)+(t[o>>2]|0);if(t[(t[u>>2]|0)+8>>2]|0){t[f>>2]=0;Q=t[f>>2]|0;s=r;return Q|0}t[t[(t[u>>2]|0)+12>>2]>>2]=t[v>>2];t[(t[(t[u>>2]|0)+12>>2]|0)+4>>2]=t[d>>2];t[(t[(t[u>>2]|0)+12>>2]|0)+72>>2]=t[m>>2];t[(t[(t[u>>2]|0)+12>>2]|0)+68>>2]=t[_>>2];t[o>>2]=(Uu(t[u>>2]|0,(t[(t[k>>2]|0)+8>>2]|0)+((t[(t[a>>2]|0)+8>>2]|0)*40|0)|0)|0)+(t[o>>2]|0);if(t[(t[u>>2]|0)+8>>2]|0){t[f>>2]=0;Q=t[f>>2]|0;s=r;return Q|0}else{t[b>>2]=Sf(t[u>>2]|0,t[(t[a>>2]|0)+12>>2]|0,t[(t[a>>2]|0)+16>>2]|0)|0;i=t[u>>2]|0;Sn(i,cu(t[(t[u>>2]|0)+12>>2]|0,t[b>>2]|0)|0)|0;t[f>>2]=t[o>>2];Q=t[f>>2]|0;s=r;return Q|0}break}case 12:{Sn(t[u>>2]|0,Vt(t[(t[u>>2]|0)+12>>2]|0,t[(t[a>>2]|0)+24>>2]|0)|0)|0;t[f>>2]=t[o>>2];Q=t[f>>2]|0;s=r;return Q|0}case 13:{if((t[(t[a>>2]|0)+4>>2]|0)!=-1){i=Uu(t[u>>2]|0,(t[(t[k>>2]|0)+8>>2]|0)+((t[(t[a>>2]|0)+4>>2]|0)*40|0)|0)|0;t[o>>2]=(t[o>>2]|0)+i}i=t[(t[u>>2]|0)+12>>2]|0;e=t[a>>2]|0;do if(!(t[(t[a>>2]|0)+28>>2]|0)){t[p>>2]=Yn(i,t[e+24>>2]|0)|0;ee=t[u>>2]|0;if(t[p>>2]|0){Sn(ee,t[p>>2]|0)|0;break}t[ee+8>>2]=5;t[f>>2]=0;Q=t[f>>2]|0;s=r;return Q|0}else{t[E>>2]=Xn(i,t[e+28>>2]|0)|0;if(!(t[E>>2]|0)){ee=t[33976]|0;ie=t[33980]|0;re=t[(t[a>>2]|0)+28>>2]|0;t[n>>2]=t[(t[a>>2]|0)+24>>2];t[n+4>>2]=re;yAi[ee&511](ie,130032,n);t[(t[u>>2]|0)+8>>2]=19;t[f>>2]=t[o>>2];Q=t[f>>2]|0;s=r;return Q|0}t[p>>2]=Gn(t[(t[u>>2]|0)+12>>2]|0,t[(t[a>>2]|0)+24>>2]|0,t[E>>2]|0)|0;ie=t[u>>2]|0;if(t[p>>2]|0){Sn(ie,t[p>>2]|0)|0;break}t[ie+8>>2]=5;t[f>>2]=0;Q=t[f>>2]|0;s=r;return Q|0}while(0);t[f>>2]=t[o>>2];Q=t[f>>2]|0;s=r;return Q|0}case 14:{t[O>>2]=Gu(t[u>>2]|0)|0;if((t[(t[a>>2]|0)+4>>2]|0)!=-1?(e=Uu(t[u>>2]|0,(t[(t[k>>2]|0)+8>>2]|0)+((t[(t[a>>2]|0)+4>>2]|0)*40|0)|0)|0,t[o>>2]=(t[o>>2]|0)+e,(t[(t[u>>2]|0)+8>>2]|0)!=0):0){Wu(t[u>>2]|0,t[O>>2]|0);t[f>>2]=t[o>>2];Q=t[f>>2]|0;s=r;return Q|0}if((t[(t[u>>2]|0)+20>>2]|0)<((t[(t[u>>2]|0)+44>>2]|0)+(t[(t[a>>2]|0)+12>>2]|0)|0)){yAi[t[135904>>2]&511](t[33980]|0,130096,n);t[(t[u>>2]|0)+8>>2]=10;Wu(t[u>>2]|0,t[O>>2]|0);t[f>>2]=t[o>>2];Q=t[f>>2]|0;s=r;return Q|0}t[F>>2]=0;while(1){if((t[F>>2]|0)>=(t[(t[a>>2]|0)+12>>2]|0))break;if(!(t[(t[(t[u>>2]|0)+28>>2]|0)+((t[(t[u>>2]|0)+20>>2]|0)-1-(t[F>>2]|0)<<2)>>2]|0)){$=125;break}t[F>>2]=(t[F>>2]|0)+1}if(($|0)==125){yAi[t[135904>>2]&511](t[33980]|0,130096,n);t[(t[u>>2]|0)+8>>2]=10;Wu(t[u>>2]|0,t[O>>2]|0);t[f>>2]=t[o>>2];Q=t[f>>2]|0;s=r;return Q|0}do if(t[(t[a>>2]|0)+32>>2]|0)t[S>>2]=t[(t[a>>2]|0)+32>>2];else{t[A>>2]=0;e=t[(t[u>>2]|0)+12>>2]|0;i=t[a>>2]|0;do if(!(t[(t[a>>2]|0)+28>>2]|0))t[S>>2]=jn(e,t[i+24>>2]|0)|0;else{t[A>>2]=Xn(e,t[i+28>>2]|0)|0;if(t[A>>2]|0){t[S>>2]=Vn(t[(t[u>>2]|0)+12>>2]|0,t[(t[a>>2]|0)+24>>2]|0,t[A>>2]|0)|0;break}ie=t[33976]|0;ee=t[33980]|0;re=t[(t[a>>2]|0)+28>>2]|0;t[n>>2]=t[(t[a>>2]|0)+24>>2];t[n+4>>2]=re;yAi[ie&511](ee,130136,n);Wu(t[u>>2]|0,t[O>>2]|0);t[(t[u>>2]|0)+8>>2]=19;t[f>>2]=t[o>>2];Q=t[f>>2]|0;s=r;return Q|0}while(0);if(t[S>>2]|0){t[(t[a>>2]|0)+32>>2]=t[S>>2];t[(t[a>>2]|0)+36>>2]=t[A>>2];break}i=t[33976]|0;e=t[33980]|0;t[n>>2]=t[(t[a>>2]|0)+24>>2];yAi[i&511](e,130200,n);dn(t[u>>2]|0,9);t[f>>2]=0;Q=t[f>>2]|0;s=r;return Q|0}while(0);t[g>>2]=t[(t[(t[u>>2]|0)+12>>2]|0)+104>>2];t[y>>2]=t[(t[(t[u>>2]|0)+12>>2]|0)+108>>2];t[(t[(t[u>>2]|0)+12>>2]|0)+104>>2]=t[(t[a>>2]|0)+24>>2];t[(t[(t[u>>2]|0)+12>>2]|0)+108>>2]=t[(t[a>>2]|0)+36>>2];EAi[t[S>>2]&511](t[u>>2]|0,t[(t[a>>2]|0)+12>>2]|0);t[(t[(t[u>>2]|0)+12>>2]|0)+104>>2]=t[g>>2];t[(t[(t[u>>2]|0)+12>>2]|0)+108>>2]=t[y>>2];Wu(t[u>>2]|0,t[O>>2]|0);t[f>>2]=t[o>>2];Q=t[f>>2]|0;s=r;return Q|0}case 18:{if((t[(t[a>>2]|0)+4>>2]|0)!=-1){e=Uu(t[u>>2]|0,(t[(t[k>>2]|0)+8>>2]|0)+((t[(t[a>>2]|0)+4>>2]|0)*40|0)|0)|0;t[o>>2]=(t[o>>2]|0)+e}if(t[(t[u>>2]|0)+8>>2]|0){t[f>>2]=0;Q=t[f>>2]|0;s=r;return Q|0}if((((t[(t[u>>2]|0)+16>>2]|0)!=0?(t[t[(t[u>>2]|0)+16>>2]>>2]|0)==1:0)?(t[(t[(t[u>>2]|0)+16>>2]|0)+4>>2]|0)!=0:0)?(t[t[(t[(t[u>>2]|0)+16>>2]|0)+4>>2]>>2]|0)>1:0)Mn(t[(t[(t[u>>2]|0)+16>>2]|0)+4>>2]|0);t[f>>2]=t[o>>2];Q=t[f>>2]|0;s=r;return Q|0}case 19:{t[G>>2]=0;if((t[(t[a>>2]|0)+4>>2]|0)!=-1){e=Uu(t[u>>2]|0,(t[(t[k>>2]|0)+8>>2]|0)+((t[(t[a>>2]|0)+4>>2]|0)*40|0)|0)|0;t[o>>2]=(t[o>>2]|0)+e}if((t[(t[a>>2]|0)+8>>2]|0)==-1){t[f>>2]=t[o>>2];Q=t[f>>2]|0;s=r;return Q|0}e=(t[(t[u>>2]|0)+16>>2]|0)==0;e:do if((t[t[(t[u>>2]|0)+16>>2]>>2]|0)==7){if(!e?(t[t[(t[u>>2]|0)+16>>2]>>2]|0)==7:0){t[q>>2]=En(t[u>>2]|0)|0;t[W>>2]=t[(t[q>>2]|0)+28>>2];if((t[W>>2]|0)!=0?(t[t[W>>2]>>2]|0)!=0:0){t[G>>2]=Da(0)|0;t[X>>2]=0;while(1){if((t[X>>2]|0)>=(t[t[W>>2]>>2]|0))break e;t[(t[(t[u>>2]|0)+12>>2]|0)+4>>2]=t[(t[(t[(t[W>>2]|0)+8>>2]|0)+(t[X>>2]<<2)>>2]|0)+28>>2];t[(t[(t[u>>2]|0)+12>>2]|0)+68>>2]=t[t[W>>2]>>2];t[(t[(t[u>>2]|0)+12>>2]|0)+72>>2]=(t[X>>2]|0)+1;t[Y>>2]=ru(t[(t[u>>2]|0)+12>>2]|0,t[(t[(t[u>>2]|0)+12>>2]|0)+4>>2]|0)|0;Sn(t[u>>2]|0,t[Y>>2]|0)|0;if((t[(t[a>>2]|0)+8>>2]|0)!=-1){i=Uu(t[u>>2]|0,(t[(t[k>>2]|0)+8>>2]|0)+((t[(t[a>>2]|0)+8>>2]|0)*40|0)|0)|0;t[o>>2]=(t[o>>2]|0)+i}if(t[(t[u>>2]|0)+8>>2]|0)break;t[V>>2]=En(t[u>>2]|0)|0;i:do if((t[t[V>>2]>>2]|0)!=7){t[j>>2]=La(t[(t[(t[(t[W>>2]|0)+8>>2]|0)+(t[X>>2]<<2)>>2]|0)+28>>2]|0,t[V>>2]|0)|0;if(t[j>>2]|0)Ca(t[G>>2]|0,t[j>>2]|0)}else{t[J>>2]=t[(t[V>>2]|0)+28>>2];t[Z>>2]=0;while(1){if((t[Z>>2]|0)>=(t[t[J>>2]>>2]|0))break i;t[j>>2]=Ra(t[(t[(t[(t[W>>2]|0)+8>>2]|0)+(t[X>>2]<<2)>>2]|0)+28>>2]|0,t[(t[(t[(t[W>>2]|0)+8>>2]|0)+(t[X>>2]<<2)>>2]|0)+32>>2]|0,t[(t[(t[(t[J>>2]|0)+8>>2]|0)+(t[Z>>2]<<2)>>2]|0)+36>>2]|0,t[(t[(t[(t[J>>2]|0)+8>>2]|0)+(t[Z>>2]<<2)>>2]|0)+40>>2]|0)|0;if(t[j>>2]|0)Ca(t[G>>2]|0,t[j>>2]|0);t[Z>>2]=(t[Z>>2]|0)+1}}while(0);if(t[V>>2]|0)zt(t[(t[u>>2]|0)+12>>2]|0,t[V>>2]|0);if((t[(t[u>>2]|0)+16>>2]|0)==(t[Y>>2]|0)){t[V>>2]=En(t[u>>2]|0)|0;zt(t[(t[u>>2]|0)+12>>2]|0,t[V>>2]|0)}t[(t[(t[u>>2]|0)+12>>2]|0)+4>>2]=0;t[X>>2]=(t[X>>2]|0)+1}_n(t[q>>2]|0);t[f>>2]=0;Q=t[f>>2]|0;s=r;return Q|0}t[(t[(t[u>>2]|0)+12>>2]|0)+4>>2]=0;t[(t[(t[u>>2]|0)+12>>2]|0)+68>>2]=0;t[(t[(t[u>>2]|0)+12>>2]|0)+72>>2]=0;i=Uu(t[u>>2]|0,(t[(t[k>>2]|0)+8>>2]|0)+((t[(t[a>>2]|0)+8>>2]|0)*40|0)|0)|0;t[o>>2]=(t[o>>2]|0)+i;t[V>>2]=En(t[u>>2]|0)|0;if(t[V>>2]|0)zt(t[(t[u>>2]|0)+12>>2]|0,t[V>>2]|0);Sn(t[u>>2]|0,t[q>>2]|0)|0;if(t[(t[u>>2]|0)+8>>2]|0){t[f>>2]=0;Q=t[f>>2]|0;s=r;return Q|0}else{t[f>>2]=t[o>>2];Q=t[f>>2]|0;s=r;return Q|0}}dn(t[u>>2]|0,11);t[f>>2]=0;Q=t[f>>2]|0;s=r;return Q|0}else{if(!e?(t[t[(t[u>>2]|0)+16>>2]>>2]|0)==1:0){t[q>>2]=En(t[u>>2]|0)|0;t[K>>2]=t[(t[q>>2]|0)+4>>2];t[(t[(t[u>>2]|0)+12>>2]|0)+4>>2]=0;t[G>>2]=Da(0)|0;if(!(t[K>>2]|0))break;t[X>>2]=0;while(1){if((t[X>>2]|0)>=(t[t[K>>2]>>2]|0))break e;t[(t[(t[u>>2]|0)+12>>2]|0)+4>>2]=t[(t[(t[K>>2]|0)+8>>2]|0)+(t[X>>2]<<2)>>2];t[Y>>2]=ru(t[(t[u>>2]|0)+12>>2]|0,t[(t[(t[u>>2]|0)+12>>2]|0)+4>>2]|0)|0;Sn(t[u>>2]|0,t[Y>>2]|0)|0;if((t[(t[a>>2]|0)+8>>2]|0)!=-1){i=Uu(t[u>>2]|0,(t[(t[k>>2]|0)+8>>2]|0)+((t[(t[a>>2]|0)+8>>2]|0)*40|0)|0)|0;t[o>>2]=(t[o>>2]|0)+i}if(t[(t[u>>2]|0)+8>>2]|0)break;t[V>>2]=En(t[u>>2]|0)|0;t[j>>2]=La(t[(t[(t[K>>2]|0)+8>>2]|0)+(t[X>>2]<<2)>>2]|0,t[V>>2]|0)|0;if(t[j>>2]|0)Ca(t[G>>2]|0,t[j>>2]|0);if(t[V>>2]|0)zt(t[(t[u>>2]|0)+12>>2]|0,t[V>>2]|0);if((t[(t[u>>2]|0)+16>>2]|0)==(t[Y>>2]|0)){t[V>>2]=En(t[u>>2]|0)|0;zt(t[(t[u>>2]|0)+12>>2]|0,t[V>>2]|0)}t[(t[(t[u>>2]|0)+12>>2]|0)+4>>2]=0;t[X>>2]=(t[X>>2]|0)+1}_n(t[q>>2]|0);t[f>>2]=0;Q=t[f>>2]|0;s=r;return Q|0}dn(t[u>>2]|0,11);t[f>>2]=0;Q=t[f>>2]|0;s=r;return Q|0}while(0);zt(t[(t[u>>2]|0)+12>>2]|0,t[q>>2]|0);t[(t[(t[u>>2]|0)+12>>2]|0)+4>>2]=0;t[(t[(t[u>>2]|0)+12>>2]|0)+68>>2]=-1;t[(t[(t[u>>2]|0)+12>>2]|0)+72>>2]=-1;e=t[u>>2]|0;Sn(e,xa(t[G>>2]|0)|0)|0;t[f>>2]=t[o>>2];Q=t[f>>2]|0;s=r;return Q|0}case 15:{t[v>>2]=t[t[(t[u>>2]|0)+12>>2]>>2];t[d>>2]=t[(t[(t[u>>2]|0)+12>>2]|0)+4>>2];t[m>>2]=t[(t[(t[u>>2]|0)+12>>2]|0)+72>>2];t[_>>2]=t[(t[(t[u>>2]|0)+12>>2]|0)+68>>2];if((t[(t[a>>2]|0)+4>>2]|0)!=-1?(e=Uu(t[u>>2]|0,(t[(t[k>>2]|0)+8>>2]|0)+((t[(t[a>>2]|0)+4>>2]|0)*40|0)|0)|0,t[o>>2]=(t[o>>2]|0)+e,t[(t[(t[u>>2]|0)+12>>2]|0)+68>>2]=t[_>>2],t[(t[(t[u>>2]|0)+12>>2]|0)+72>>2]=t[m>>2],t[(t[(t[u>>2]|0)+12>>2]|0)+4>>2]=t[d>>2],t[t[(t[u>>2]|0)+12>>2]>>2]=t[v>>2],(t[(t[u>>2]|0)+8>>2]|0)!=0):0){t[f>>2]=0;Q=t[f>>2]|0;s=r;return Q|0}if((t[(t[a>>2]|0)+8>>2]|0)!=-1?(e=Uu(t[u>>2]|0,(t[(t[k>>2]|0)+8>>2]|0)+((t[(t[a>>2]|0)+8>>2]|0)*40|0)|0)|0,t[o>>2]=(t[o>>2]|0)+e,t[(t[(t[u>>2]|0)+12>>2]|0)+68>>2]=t[_>>2],t[(t[(t[u>>2]|0)+12>>2]|0)+72>>2]=t[m>>2],t[(t[(t[u>>2]|0)+12>>2]|0)+4>>2]=t[d>>2],t[t[(t[u>>2]|0)+12>>2]>>2]=t[v>>2],(t[(t[u>>2]|0)+8>>2]|0)!=0):0){t[f>>2]=0;Q=t[f>>2]|0;s=r;return Q|0}t[f>>2]=t[o>>2];Q=t[f>>2]|0;s=r;return Q|0}case 17:case 16:{t[T>>2]=0;do if((t[(t[a>>2]|0)+4>>2]|0)!=-1?(t[(t[a>>2]|0)+8>>2]|0)!=-1:0){if((t[(t[(t[k>>2]|0)+8>>2]|0)+((t[(t[a>>2]|0)+4>>2]|0)*40|0)>>2]|0)!=18?(t[(t[(t[k>>2]|0)+8>>2]|0)+((t[(t[a>>2]|0)+4>>2]|0)*40|0)>>2]|0)!=17:0)break;if((((t[(t[(t[k>>2]|0)+8>>2]|0)+((t[(t[a>>2]|0)+8>>2]|0)*40|0)>>2]|0)==12?(t[B>>2]=t[(t[(t[k>>2]|0)+8>>2]|0)+((t[(t[a>>2]|0)+8>>2]|0)*40|0)+24>>2],(t[B>>2]|0)!=0):0)?(t[t[B>>2]>>2]|0)==3:0)?+l[(t[B>>2]|0)+16>>3]==1:0){t[I>>2]=0;e=Ku(t[u>>2]|0,(t[(t[k>>2]|0)+8>>2]|0)+((t[(t[a>>2]|0)+4>>2]|0)*40|0)|0,I)|0;t[o>>2]=(t[o>>2]|0)+e;if(t[(t[u>>2]|0)+8>>2]|0){t[f>>2]=0;Q=t[f>>2]|0;s=r;return Q|0}if((((t[(t[u>>2]|0)+16>>2]|0)!=0?(t[t[(t[u>>2]|0)+16>>2]>>2]|0)==1:0)?(t[(t[(t[u>>2]|0)+16>>2]|0)+4>>2]|0)!=0:0)?(t[t[(t[(t[u>>2]|0)+16>>2]|0)+4>>2]>>2]|0)>1:0)t[t[(t[(t[u>>2]|0)+16>>2]|0)+4>>2]>>2]=1;t[f>>2]=t[o>>2];Q=t[f>>2]|0;s=r;return Q|0}}while(0);if((((((((((t[(t[a>>2]|0)+4>>2]|0)!=-1?(t[(t[a>>2]|0)+8>>2]|0)!=-1:0)?(t[(t[(t[k>>2]|0)+8>>2]|0)+((t[(t[a>>2]|0)+4>>2]|0)*40|0)>>2]|0)==18:0)?(t[(t[(t[k>>2]|0)+8>>2]|0)+((t[(t[a>>2]|0)+8>>2]|0)*40|0)>>2]|0)==18:0)?(t[H>>2]=t[(t[(t[k>>2]|0)+8>>2]|0)+((t[(t[a>>2]|0)+8>>2]|0)*40|0)+4>>2],(t[H>>2]|0)!=-1):0)?(t[(t[(t[k>>2]|0)+8>>2]|0)+((t[H>>2]|0)*40|0)>>2]|0)==14:0)?(t[(t[(t[k>>2]|0)+8>>2]|0)+((t[H>>2]|0)*40|0)+28>>2]|0)==0:0)?(t[(t[(t[k>>2]|0)+8>>2]|0)+((t[H>>2]|0)*40|0)+12>>2]|0)==0:0)?(t[(t[(t[k>>2]|0)+8>>2]|0)+((t[H>>2]|0)*40|0)+24>>2]|0)!=0:0)?(Xl(t[(t[(t[k>>2]|0)+8>>2]|0)+((t[H>>2]|0)*40|0)+24>>2]|0,129656)|0)!=0:0){t[x>>2]=0;e=Xu(t[u>>2]|0,(t[(t[k>>2]|0)+8>>2]|0)+((t[(t[a>>2]|0)+4>>2]|0)*40|0)|0,x)|0;t[o>>2]=(t[o>>2]|0)+e;if(t[(t[u>>2]|0)+8>>2]|0){t[f>>2]=0;Q=t[f>>2]|0;s=r;return Q|0}do if((((t[(t[u>>2]|0)+16>>2]|0)!=0?(t[t[(t[u>>2]|0)+16>>2]>>2]|0)==1:0)?(t[(t[(t[u>>2]|0)+16>>2]|0)+4>>2]|0)!=0:0)?(t[(t[(t[(t[u>>2]|0)+16>>2]|0)+4>>2]|0)+8>>2]|0)!=0:0){if((t[t[(t[(t[u>>2]|0)+16>>2]|0)+4>>2]>>2]|0)<=1)break;t[t[(t[(t[(t[u>>2]|0)+16>>2]|0)+4>>2]|0)+8>>2]>>2]=t[(t[(t[(t[(t[u>>2]|0)+16>>2]|0)+4>>2]|0)+8>>2]|0)+((t[t[(t[(t[u>>2]|0)+16>>2]|0)+4>>2]>>2]|0)-1<<2)>>2];t[t[(t[(t[u>>2]|0)+16>>2]|0)+4>>2]>>2]=1}while(0);t[f>>2]=t[o>>2];Q=t[f>>2]|0;s=r;return Q|0}if((t[(t[a>>2]|0)+4>>2]|0)!=-1){e=Uu(t[u>>2]|0,(t[(t[k>>2]|0)+8>>2]|0)+((t[(t[a>>2]|0)+4>>2]|0)*40|0)|0)|0;t[o>>2]=(t[o>>2]|0)+e}if(t[(t[u>>2]|0)+8>>2]|0){t[f>>2]=0;Q=t[f>>2]|0;s=r;return Q|0}if((t[(t[a>>2]|0)+8>>2]|0)==-1){t[f>>2]=t[o>>2];Q=t[f>>2]|0;s=r;return Q|0}if(!(t[(t[u>>2]|0)+16>>2]|0)){t[f>>2]=t[o>>2];Q=t[f>>2]|0;s=r;return Q|0}t[D>>2]=t[(t[(t[u>>2]|0)+12>>2]|0)+4>>2];if((t[t[(t[u>>2]|0)+16>>2]>>2]|0)==7){t[U>>2]=0;if((t[(t[u>>2]|0)+16>>2]|0)!=0?(t[t[(t[u>>2]|0)+16>>2]>>2]|0)==7:0){t[R>>2]=En(t[u>>2]|0)|0;t[z>>2]=t[(t[R>>2]|0)+28>>2];t[(t[(t[u>>2]|0)+12>>2]|0)+4>>2]=0;if((t[z>>2]|0)!=0?(t[t[z>>2]>>2]|0)!=0:0){t[U>>2]=Da(0)|0;t[P>>2]=0;while(1){if((t[P>>2]|0)>=(t[t[z>>2]>>2]|0)){$=214;break}t[(t[(t[u>>2]|0)+12>>2]|0)+4>>2]=t[(t[(t[(t[z>>2]|0)+8>>2]|0)+(t[P>>2]<<2)>>2]|0)+28>>2];t[(t[(t[u>>2]|0)+12>>2]|0)+68>>2]=t[t[z>>2]>>2];t[(t[(t[u>>2]|0)+12>>2]|0)+72>>2]=(t[P>>2]|0)+1;t[N>>2]=ru(t[(t[u>>2]|0)+12>>2]|0,t[(t[(t[u>>2]|0)+12>>2]|0)+4>>2]|0)|0;Sn(t[u>>2]|0,t[N>>2]|0)|0;if((t[(t[a>>2]|0)+8>>2]|0)!=-1){e=Uu(t[u>>2]|0,(t[(t[k>>2]|0)+8>>2]|0)+((t[(t[a>>2]|0)+8>>2]|0)*40|0)|0)|0;t[o>>2]=(t[o>>2]|0)+e}if(t[(t[u>>2]|0)+8>>2]|0){$=206;break}t[M>>2]=En(t[u>>2]|0)|0;if(vt(t[u>>2]|0,t[M>>2]|0)|0){e=t[U>>2]|0;Ca(e,nf(t[(t[(t[z>>2]|0)+8>>2]|0)+(t[P>>2]<<2)>>2]|0)|0)}if(t[M>>2]|0)zt(t[(t[u>>2]|0)+12>>2]|0,t[M>>2]|0);if((t[(t[u>>2]|0)+16>>2]|0)==(t[N>>2]|0)){t[M>>2]=En(t[u>>2]|0)|0;zt(t[(t[u>>2]|0)+12>>2]|0,t[M>>2]|0)}t[(t[(t[u>>2]|0)+12>>2]|0)+4>>2]=0;t[P>>2]=(t[P>>2]|0)+1}if(($|0)==206){_n(t[R>>2]|0);t[f>>2]=0;Q=t[f>>2]|0;s=r;return Q|0}else if(($|0)==214){zt(t[(t[u>>2]|0)+12>>2]|0,t[R>>2]|0);t[(t[(t[u>>2]|0)+12>>2]|0)+4>>2]=0;t[(t[(t[u>>2]|0)+12>>2]|0)+68>>2]=-1;t[(t[(t[u>>2]|0)+12>>2]|0)+72>>2]=-1;e=t[u>>2]|0;Sn(e,xa(t[U>>2]|0)|0)|0;t[(t[(t[u>>2]|0)+12>>2]|0)+4>>2]=t[D>>2];t[f>>2]=t[o>>2];Q=t[f>>2]|0;s=r;return Q|0}}t[(t[(t[u>>2]|0)+12>>2]|0)+68>>2]=0;t[(t[(t[u>>2]|0)+12>>2]|0)+72>>2]=0;if((t[(t[a>>2]|0)+8>>2]|0)!=-1){e=Uu(t[u>>2]|0,(t[(t[k>>2]|0)+8>>2]|0)+((t[(t[a>>2]|0)+8>>2]|0)*40|0)|0)|0;t[o>>2]=(t[o>>2]|0)+e}t[M>>2]=En(t[u>>2]|0)|0;if(t[M>>2]|0)zt(t[(t[u>>2]|0)+12>>2]|0,t[M>>2]|0);Sn(t[u>>2]|0,t[R>>2]|0)|0;if(t[(t[u>>2]|0)+8>>2]|0){t[f>>2]=0;Q=t[f>>2]|0;s=r;return Q|0}else{t[f>>2]=t[o>>2];Q=t[f>>2]|0;s=r;return Q|0}}dn(t[u>>2]|0,11);t[f>>2]=0;Q=t[f>>2]|0;s=r;return Q|0}if((t[(t[u>>2]|0)+16>>2]|0)!=0?(t[t[(t[u>>2]|0)+16>>2]>>2]|0)==1:0){t[R>>2]=En(t[u>>2]|0)|0;t[L>>2]=t[(t[R>>2]|0)+4>>2];t[D>>2]=t[(t[(t[u>>2]|0)+12>>2]|0)+4>>2];t[C>>2]=t[t[(t[u>>2]|0)+12>>2]>>2];t[(t[(t[u>>2]|0)+12>>2]|0)+4>>2]=0;if((t[L>>2]|0)!=0?(t[t[L>>2]>>2]|0)!=0:0){t[N>>2]=0;t[T>>2]=Nn(0)|0;t[P>>2]=0;while(1){if((t[P>>2]|0)>=(t[t[L>>2]>>2]|0))break;t[(t[(t[u>>2]|0)+12>>2]|0)+4>>2]=t[(t[(t[L>>2]|0)+8>>2]|0)+(t[P>>2]<<2)>>2];if((t[(t[(t[(t[L>>2]|0)+8>>2]|0)+(t[P>>2]<<2)>>2]|0)+4>>2]|0)!=18?(t[(t[(t[(t[L>>2]|0)+8>>2]|0)+(t[P>>2]<<2)>>2]|0)+32>>2]|0)!=0:0)t[t[(t[u>>2]|0)+12>>2]>>2]=t[(t[(t[(t[L>>2]|0)+8>>2]|0)+(t[P>>2]<<2)>>2]|0)+32>>2];do if(!(t[N>>2]|0))t[N>>2]=ru(t[(t[u>>2]|0)+12>>2]|0,t[(t[(t[u>>2]|0)+12>>2]|0)+4>>2]|0)|0;else{if((Cn(t[(t[N>>2]|0)+4>>2]|0,t[(t[(t[u>>2]|0)+12>>2]|0)+4>>2]|0)|0)>=0)break;t[(t[u>>2]|0)+8>>2]=15}while(0);Sn(t[u>>2]|0,t[N>>2]|0)|0;t[(t[(t[u>>2]|0)+12>>2]|0)+68>>2]=t[t[L>>2]>>2];t[(t[(t[u>>2]|0)+12>>2]|0)+72>>2]=(t[P>>2]|0)+1;if((t[(t[a>>2]|0)+8>>2]|0)!=-1){e=Uu(t[u>>2]|0,(t[(t[k>>2]|0)+8>>2]|0)+((t[(t[a>>2]|0)+8>>2]|0)*40|0)|0)|0;t[o>>2]=(t[o>>2]|0)+e}if(t[(t[u>>2]|0)+8>>2]|0){$=234;break}t[M>>2]=En(t[u>>2]|0)|0;do if(vt(t[u>>2]|0,t[M>>2]|0)|0){if((Dn(t[T>>2]|0,t[(t[(t[L>>2]|0)+8>>2]|0)+(t[P>>2]<<2)>>2]|0)|0)>=0)break;t[(t[u>>2]|0)+8>>2]=15}while(0);if(t[M>>2]|0)zt(t[(t[u>>2]|0)+12>>2]|0,t[M>>2]|0);if((t[(t[u>>2]|0)+16>>2]|0)==(t[N>>2]|0)){En(t[u>>2]|0)|0;Zu(t[(t[N>>2]|0)+4>>2]|0,1)}else t[N>>2]=0;t[(t[(t[u>>2]|0)+12>>2]|0)+4>>2]=0;t[P>>2]=(t[P>>2]|0)+1}if(($|0)==234){Bn(t[T>>2]|0);_n(t[R>>2]|0);t[f>>2]=0;Q=t[f>>2]|0;s=r;return Q|0}if(t[N>>2]|0)zt(t[(t[u>>2]|0)+12>>2]|0,t[N>>2]|0);zt(t[(t[u>>2]|0)+12>>2]|0,t[R>>2]|0);t[(t[(t[u>>2]|0)+12>>2]|0)+4>>2]=0;t[(t[(t[u>>2]|0)+12>>2]|0)+68>>2]=-1;t[(t[(t[u>>2]|0)+12>>2]|0)+72>>2]=-1;t[t[(t[u>>2]|0)+12>>2]>>2]=t[C>>2];e=t[u>>2]|0;Sn(e,fu(t[(t[u>>2]|0)+12>>2]|0,t[T>>2]|0)|0)|0}else $=220;if(($|0)==220?(t[(t[(t[u>>2]|0)+12>>2]|0)+68>>2]=0,t[(t[(t[u>>2]|0)+12>>2]|0)+72>>2]=0,Sn(t[u>>2]|0,t[R>>2]|0)|0,t[(t[(t[u>>2]|0)+12>>2]|0)+4>>2]=t[D>>2],(t[(t[u>>2]|0)+8>>2]|0)!=0):0){t[f>>2]=0;Q=t[f>>2]|0;s=r;return Q|0}t[(t[(t[u>>2]|0)+12>>2]|0)+4>>2]=t[D>>2];t[f>>2]=t[o>>2];Q=t[f>>2]|0;s=r;return Q|0}dn(t[u>>2]|0,11);t[f>>2]=0;Q=t[f>>2]|0;s=r;return Q|0}case 3:{t[v>>2]=t[t[(t[u>>2]|0)+12>>2]>>2];t[d>>2]=t[(t[(t[u>>2]|0)+12>>2]|0)+4>>2];t[m>>2]=t[(t[(t[u>>2]|0)+12>>2]|0)+72>>2];t[_>>2]=t[(t[(t[u>>2]|0)+12>>2]|0)+68>>2];e=Uu(t[u>>2]|0,(t[(t[k>>2]|0)+8>>2]|0)+((t[(t[a>>2]|0)+4>>2]|0)*40|0)|0)|0;t[o>>2]=(t[o>>2]|0)+e;if(t[(t[u>>2]|0)+8>>2]|0){t[f>>2]=0;Q=t[f>>2]|0;s=r;return Q|0}t[t[(t[u>>2]|0)+12>>2]>>2]=t[v>>2];t[(t[(t[u>>2]|0)+12>>2]|0)+4>>2]=t[d>>2];t[(t[(t[u>>2]|0)+12>>2]|0)+72>>2]=t[m>>2];t[(t[(t[u>>2]|0)+12>>2]|0)+68>>2]=t[_>>2];e=Uu(t[u>>2]|0,(t[(t[k>>2]|0)+8>>2]|0)+((t[(t[a>>2]|0)+8>>2]|0)*40|0)|0)|0;t[o>>2]=(t[o>>2]|0)+e;if(t[(t[u>>2]|0)+8>>2]|0){t[f>>2]=0;Q=t[f>>2]|0;s=r;return Q|0}e=t[u>>2]|0;if(t[(t[a>>2]|0)+12>>2]|0)t[c>>2]=pf(e)|0;else t[c>>2]=Ef(e)|0;e=t[u>>2]|0;Sn(e,cu(t[(t[u>>2]|0)+12>>2]|0,t[c>>2]|0)|0)|0;t[f>>2]=t[o>>2];Q=t[f>>2]|0;s=r;return Q|0}case 6:{t[v>>2]=t[t[(t[u>>2]|0)+12>>2]>>2];t[d>>2]=t[(t[(t[u>>2]|0)+12>>2]|0)+4>>2];t[m>>2]=t[(t[(t[u>>2]|0)+12>>2]|0)+72>>2];t[_>>2]=t[(t[(t[u>>2]|0)+12>>2]|0)+68>>2];e=Uu(t[u>>2]|0,(t[(t[k>>2]|0)+8>>2]|0)+((t[(t[a>>2]|0)+4>>2]|0)*40|0)|0)|0;t[o>>2]=(t[o>>2]|0)+e;if(t[(t[u>>2]|0)+8>>2]|0){t[f>>2]=0;Q=t[f>>2]|0;s=r;return Q|0}t[t[(t[u>>2]|0)+12>>2]>>2]=t[v>>2];t[(t[(t[u>>2]|0)+12>>2]|0)+4>>2]=t[d>>2];t[(t[(t[u>>2]|0)+12>>2]|0)+72>>2]=t[m>>2];t[(t[(t[u>>2]|0)+12>>2]|0)+68>>2]=t[_>>2];e=Uu(t[u>>2]|0,(t[(t[k>>2]|0)+8>>2]|0)+((t[(t[a>>2]|0)+8>>2]|0)*40|0)|0)|0;t[o>>2]=(t[o>>2]|0)+e;if(t[(t[u>>2]|0)+8>>2]|0){t[f>>2]=0;Q=t[f>>2]|0;s=r;return Q|0}do if(t[(t[a>>2]|0)+12>>2]|0){if((t[(t[a>>2]|0)+12>>2]|0)==1){Mf(t[u>>2]|0);break}if((t[(t[a>>2]|0)+12>>2]|0)==2)Rf(t[u>>2]|0)}else Af(t[u>>2]|0);while(0);t[f>>2]=t[o>>2];Q=t[f>>2]|0;s=r;return Q|0}default:{e=t[33976]|0;i=t[33980]|0;t[n>>2]=t[t[a>>2]>>2];yAi[e&511](i,130248,n);t[(t[u>>2]|0)+8>>2]=10;t[f>>2]=t[o>>2];Q=t[f>>2]|0;s=r;return Q|0}}while(0);return 0}function zu(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0,S=0;r=s;s=s+64|0;n=r+52|0;f=r+48|0;u=r+44|0;a=r+40|0;o=r+36|0;c=r+32|0;l=r+28|0;b=r+24|0;k=r+20|0;h=r+16|0;w=r+12|0;d=r+8|0;v=r+4|0;m=r;t[f>>2]=e;t[u>>2]=i;t[c>>2]=0;t[l>>2]=0;t[b>>2]=0;t[k>>2]=0;t[h>>2]=0;if((t[f>>2]|0)==0|(t[u>>2]|0)==0){t[n>>2]=-2;_=t[n>>2]|0;s=r;return _|0}if((t[f>>2]|0)==(t[u>>2]|0)){t[n>>2]=0;_=t[n>>2]|0;s=r;return _|0}e:do switch(t[(t[f>>2]|0)+4>>2]|0){case 2:{t[l>>2]=1;t[k>>2]=t[f>>2];t[f>>2]=t[(t[f>>2]|0)+20>>2];t[c>>2]=1;p=27;break}case 7:case 8:case 4:case 3:{t[k>>2]=t[f>>2];do if(t[(t[f>>2]|0)+28>>2]|0){while(1){t[f>>2]=t[(t[f>>2]|0)+28>>2];if((t[(t[f>>2]|0)+4>>2]|0)==1){p=17;break}if(!(t[(t[f>>2]|0)+28>>2]|0)){p=19;break}}if((p|0)==17){t[l>>2]=3;break}else if((p|0)==19){t[l>>2]=2;t[f>>2]=t[(t[f>>2]|0)+20>>2];break}}else{t[l>>2]=2;t[f>>2]=t[(t[f>>2]|0)+20>>2]}while(0);if(((t[f>>2]|0)!=0?(t[(t[f>>2]|0)+4>>2]|0)==1:0)?0>(t[(t[f>>2]|0)+40>>2]|0):0){t[c>>2]=1;p=27;break e}t[f>>2]=t[k>>2];t[l>>2]=0;p=27;break}case 18:{t[n>>2]=1;_=t[n>>2]|0;s=r;return _|0}case 1:{if((t[(t[u>>2]|0)+4>>2]|0)==1){if((0>(t[(t[f>>2]|0)+40>>2]|0)?0>(t[(t[u>>2]|0)+40>>2]|0):0)?(t[(t[f>>2]|0)+32>>2]|0)==(t[(t[u>>2]|0)+32>>2]|0):0){t[v>>2]=0-(t[(t[f>>2]|0)+40>>2]|0);t[m>>2]=0-(t[(t[u>>2]|0)+40>>2]|0);if((t[v>>2]|0)<(t[m>>2]|0)){t[n>>2]=1;_=t[n>>2]|0;s=r;return _|0}if((t[v>>2]|0)>(t[m>>2]|0)){t[n>>2]=-1;_=t[n>>2]|0;s=r;return _|0}else p=27}}else p=27;break}default:p=27}while(0);if((p|0)==27){e:do switch(t[(t[u>>2]|0)+4>>2]|0){case 7:case 8:case 4:case 3:{t[h>>2]=t[u>>2];do if(t[(t[u>>2]|0)+28>>2]|0){while(1){t[u>>2]=t[(t[u>>2]|0)+28>>2];if((t[(t[u>>2]|0)+4>>2]|0)==1){p=31;break}if(!(t[(t[u>>2]|0)+28>>2]|0)){p=33;break}}if((p|0)==31){t[b>>2]=3;break}else if((p|0)==33){t[b>>2]=2;t[u>>2]=t[(t[u>>2]|0)+20>>2];break}}else{t[b>>2]=2;t[u>>2]=t[(t[u>>2]|0)+20>>2]}while(0);if(((t[u>>2]|0)!=0?(t[(t[u>>2]|0)+4>>2]|0)==1:0)?0>(t[(t[u>>2]|0)+40>>2]|0):0){t[c>>2]=1;break e}t[u>>2]=t[h>>2];t[b>>2]=0;break}case 2:{t[b>>2]=1;t[h>>2]=t[u>>2];t[u>>2]=t[(t[u>>2]|0)+20>>2];t[c>>2]=1;break}case 18:{t[n>>2]=1;_=t[n>>2]|0;s=r;return _|0}default:{}}while(0);e:do if(t[c>>2]|0){if((t[f>>2]|0)!=(t[u>>2]|0)){i:do if((t[b>>2]|0)==3&(t[l>>2]|0)>1){t[w>>2]=t[(t[f>>2]|0)+20>>2];while(1){if(!(t[w>>2]|0))break i;if((t[w>>2]|0)==(t[u>>2]|0))break;t[w>>2]=t[(t[w>>2]|0)+20>>2]}t[n>>2]=1;_=t[n>>2]|0;s=r;return _|0}while(0);if(!((t[l>>2]|0)==3&(t[b>>2]|0)>1))break;t[w>>2]=t[(t[u>>2]|0)+20>>2];while(1){if(!(t[w>>2]|0))break e;if((t[w>>2]|0)==(t[f>>2]|0))break;t[w>>2]=t[(t[w>>2]|0)+20>>2]}t[n>>2]=-1;_=t[n>>2]|0;s=r;return _|0}if((t[l>>2]|0)!=(t[b>>2]|0))if((t[l>>2]|0)<(t[b>>2]|0)){t[n>>2]=1;_=t[n>>2]|0;s=r;return _|0}else{t[n>>2]=-1;_=t[n>>2]|0;s=r;return _|0}t[w>>2]=t[(t[h>>2]|0)+28>>2];while(1){if(!(t[w>>2]|0)){p=51;break}if((t[w>>2]|0)==(t[k>>2]|0)){p=47;break}if((t[(t[w>>2]|0)+4>>2]|0)==1){p=49;break}t[w>>2]=t[(t[w>>2]|0)+28>>2]}if((p|0)==47){t[n>>2]=1;_=t[n>>2]|0;s=r;return _|0}else if((p|0)==49){t[n>>2]=-1;_=t[n>>2]|0;s=r;return _|0}else if((p|0)==51){t[n>>2]=-1;_=t[n>>2]|0;s=r;return _|0}}while(0);if(((((t[(t[f>>2]|0)+4>>2]|0)==1?(t[(t[u>>2]|0)+4>>2]|0)==1:0)?0>(t[(t[f>>2]|0)+40>>2]|0):0)?0>(t[(t[u>>2]|0)+40>>2]|0):0)?(t[(t[f>>2]|0)+32>>2]|0)==(t[(t[u>>2]|0)+32>>2]|0):0){t[v>>2]=0-(t[(t[f>>2]|0)+40>>2]|0);t[m>>2]=0-(t[(t[u>>2]|0)+40>>2]|0);if((t[v>>2]|0)<(t[m>>2]|0)){t[n>>2]=1;_=t[n>>2]|0;s=r;return _|0}if((t[v>>2]|0)>(t[m>>2]|0)){t[n>>2]=-1;_=t[n>>2]|0;s=r;return _|0}}}if((t[f>>2]|0)==(t[(t[u>>2]|0)+28>>2]|0)){t[n>>2]=1;_=t[n>>2]|0;s=r;return _|0}if((t[f>>2]|0)==(t[(t[u>>2]|0)+24>>2]|0)){t[n>>2]=-1;_=t[n>>2]|0;s=r;return _|0}t[o>>2]=0;t[w>>2]=t[u>>2];while(1){E=t[w>>2]|0;if(!(t[(t[w>>2]|0)+20>>2]|0))break;if((E|0)==(t[f>>2]|0)){p=83;break}t[o>>2]=(t[o>>2]|0)+1;t[w>>2]=t[(t[w>>2]|0)+20>>2]}if((p|0)==83){t[n>>2]=1;_=t[n>>2]|0;s=r;return _|0}t[d>>2]=E;t[a>>2]=0;t[w>>2]=t[f>>2];while(1){if(!(t[(t[w>>2]|0)+20>>2]|0))break;if((t[w>>2]|0)==(t[u>>2]|0)){p=88;break}t[a>>2]=(t[a>>2]|0)+1;t[w>>2]=t[(t[w>>2]|0)+20>>2]}if((p|0)==88){t[n>>2]=-1;_=t[n>>2]|0;s=r;return _|0}if((t[d>>2]|0)!=(t[w>>2]|0)){t[n>>2]=-2;_=t[n>>2]|0;s=r;return _|0}while(1){if((t[a>>2]|0)<=(t[o>>2]|0))break;t[a>>2]=(t[a>>2]|0)+-1;t[f>>2]=t[(t[f>>2]|0)+20>>2]}while(1){if((t[o>>2]|0)<=(t[a>>2]|0))break;t[o>>2]=(t[o>>2]|0)+-1;t[u>>2]=t[(t[u>>2]|0)+20>>2]}while(1){S=t[f>>2]|0;if((t[(t[f>>2]|0)+20>>2]|0)==(t[(t[u>>2]|0)+20>>2]|0))break;t[f>>2]=t[S+20>>2];t[u>>2]=t[(t[u>>2]|0)+20>>2];if((t[f>>2]|0)==0|(t[u>>2]|0)==0){p=98;break}}if((p|0)==98){t[n>>2]=-2;_=t[n>>2]|0;s=r;return _|0}if((S|0)==(t[(t[u>>2]|0)+28>>2]|0)){t[n>>2]=1;_=t[n>>2]|0;s=r;return _|0}if((t[f>>2]|0)==(t[(t[u>>2]|0)+24>>2]|0)){t[n>>2]=-1;_=t[n>>2]|0;s=r;return _|0}if(((((t[(t[f>>2]|0)+4>>2]|0)==1?(t[(t[u>>2]|0)+4>>2]|0)==1:0)?0>(t[(t[f>>2]|0)+40>>2]|0):0)?0>(t[(t[u>>2]|0)+40>>2]|0):0)?(t[(t[f>>2]|0)+32>>2]|0)==(t[(t[u>>2]|0)+32>>2]|0):0){t[v>>2]=0-(t[(t[f>>2]|0)+40>>2]|0);t[m>>2]=0-(t[(t[u>>2]|0)+40>>2]|0);if((t[v>>2]|0)<(t[m>>2]|0)){t[n>>2]=1;_=t[n>>2]|0;s=r;return _|0}if((t[v>>2]|0)>(t[m>>2]|0)){t[n>>2]=-1;_=t[n>>2]|0;s=r;return _|0}}t[w>>2]=t[(t[f>>2]|0)+24>>2];while(1){if(!(t[w>>2]|0)){p=117;break}if((t[w>>2]|0)==(t[u>>2]|0)){p=115;break}t[w>>2]=t[(t[w>>2]|0)+24>>2]}if((p|0)==115){t[n>>2]=1;_=t[n>>2]|0;s=r;return _|0}else if((p|0)==117){t[n>>2]=-1;_=t[n>>2]|0;s=r;return _|0}return 0}function ju(e,i){e=+e;i=i|0;var r=0,n=0,f=0,u=0,a=0;r=s;s=s+16|0;n=r+12|0;f=r;u=r+8|0;l[f>>3]=e;t[u>>2]=i;i=Su(+l[f>>3])|0;a=qY(i|0,P|0,63)|0;t[t[u>>2]>>2]=a;a=fY(+l[f>>3])|0;if((a|0)==3)t[n>>2]=3;else if((a|0)==2)t[n>>2]=4;else if(!a)t[n>>2]=1;else if((a|0)==1)t[n>>2]=0;else t[n>>2]=2;s=r;return t[n>>2]|0}function Vu(e){e=e|0;var i=0,r=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if(!(t[r>>2]|0)){s=i;return}if(t[t[r>>2]>>2]|0)pAi[t[135736>>2]&511](t[t[r>>2]>>2]|0);pAi[t[135736>>2]&511](t[r>>2]|0);s=i;return}function qu(e){e=e|0;var i=0,r=0,n=0,f=0,a=0,o=0,c=0;i=s;s=s+16|0;r=i+8|0;n=i+4|0;f=i;t[r>>2]=e;Ju(t[r>>2]|0);if(t[(t[r>>2]|0)+8>>2]|0){s=i;return}e:while(1){do if((u[t[t[r>>2]>>2]>>0]|0|0)!=32){if(9<=(u[t[t[r>>2]>>2]>>0]|0|0)?(u[t[t[r>>2]>>2]>>0]|0|0)<=10:0)break;if((u[t[t[r>>2]>>2]>>0]|0|0)!=13)break e}while(0);e=t[r>>2]|0;if(!(u[t[t[r>>2]>>2]>>0]|0))continue;t[e>>2]=(t[e>>2]|0)+1}e:while(1){if((u[t[t[r>>2]>>2]>>0]|0|0)!=61){if((u[t[t[r>>2]>>2]>>0]|0|0)!=33){a=34;break}if((u[(t[t[r>>2]>>2]|0)+1>>0]|0|0)!=61){a=34;break}}t[f>>2]=t[(t[(t[r>>2]|0)+32>>2]|0)+12>>2];
	if((u[t[t[r>>2]>>2]>>0]|0|0)==61)t[n>>2]=1;else t[n>>2]=0;e=t[r>>2]|0;if(u[t[t[r>>2]>>2]>>0]|0)t[e>>2]=(t[e>>2]|0)+1;if((t[n>>2]|0)==0?(e=t[r>>2]|0,(u[t[t[r>>2]>>2]>>0]|0|0)!=0):0)t[e>>2]=(t[e>>2]|0)+1;while(1){do if((u[t[t[r>>2]>>2]>>0]|0|0)==32)o=1;else{if(9<=(u[t[t[r>>2]>>2]>>0]|0|0)?(u[t[t[r>>2]>>2]>>0]|0|0)<=10:0){o=1;break}o=(u[t[t[r>>2]>>2]>>0]|0|0)==13}while(0);c=t[r>>2]|0;if(!o)break;e=t[r>>2]|0;if(!(u[t[c>>2]>>0]|0))continue;t[e>>2]=(t[e>>2]|0)+1}Ju(c);if(t[(t[r>>2]|0)+8>>2]|0){a=34;break}Pu(t[(t[r>>2]|0)+32>>2]|0,t[f>>2]|0,t[(t[(t[r>>2]|0)+32>>2]|0)+12>>2]|0,3,t[n>>2]|0,0,0,0,0)|0;while(1){do if((u[t[t[r>>2]>>2]>>0]|0|0)!=32){if(9<=(u[t[t[r>>2]>>2]>>0]|0|0)?(u[t[t[r>>2]>>2]>>0]|0|0)<=10:0)break;if((u[t[t[r>>2]>>2]>>0]|0|0)!=13)continue e}while(0);e=t[r>>2]|0;if(!(u[t[t[r>>2]>>2]>>0]|0))continue;t[e>>2]=(t[e>>2]|0)+1}}if((a|0)==34){s=i;return}}function Yu(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;var u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0,S=0,g=0,y=0,F=0,O=0,A=0,M=0,R=0,N=0,T=0,L=0,D=0,C=0,P=0,B=0,I=0,H=0,x=0,U=0,z=0,j=0,V=0,q=0,Y=0,G=0,W=0;u=s;s=s+160|0;a=u;o=u+148|0;c=u+144|0;l=u+140|0;b=u+136|0;k=u+132|0;h=u+128|0;w=u+124|0;d=u+120|0;v=u+116|0;m=u+112|0;_=u+108|0;p=u+104|0;E=u+100|0;S=u+96|0;g=u+92|0;y=u+88|0;F=u+84|0;O=u+80|0;A=u+76|0;M=u+72|0;R=u+68|0;N=u+64|0;T=u+60|0;L=u+56|0;D=u+52|0;C=u+48|0;P=u+44|0;B=u+40|0;I=u+36|0;H=u+32|0;x=u+28|0;U=u+24|0;z=u+20|0;j=u+16|0;V=u+12|0;q=u+8|0;t[c>>2]=e;t[l>>2]=i;t[b>>2]=r;t[k>>2]=n;t[h>>2]=f;t[w>>2]=t[(t[l>>2]|0)+12>>2];t[d>>2]=t[(t[l>>2]|0)+16>>2];t[v>>2]=t[(t[l>>2]|0)+20>>2];t[m>>2]=t[(t[l>>2]|0)+24>>2];t[_>>2]=t[(t[l>>2]|0)+28>>2];t[p>>2]=0;t[E>>2]=0;t[S>>2]=0;t[H>>2]=0;t[j>>2]=t[(t[c>>2]|0)+12>>2];if((t[(t[c>>2]|0)+16>>2]|0)!=0?(t[t[(t[c>>2]|0)+16>>2]>>2]|0)==1:0){t[g>>2]=En(t[c>>2]|0)|0;if((t[m>>2]|0)!=0?(t[p>>2]=Xn(t[j>>2]|0,t[m>>2]|0)|0,(t[p>>2]|0)==0):0){zt(t[j>>2]|0,t[g>>2]|0);dn(t[c>>2]|0,19);t[o>>2]=0;Y=t[o>>2]|0;s=u;return Y|0}t[U>>2]=289;do switch(t[w>>2]|0){case 9:{t[b>>2]=0;t[k>>2]=0;t[H>>2]=300;t[U>>2]=293;break}case 3:{t[b>>2]=0;t[k>>2]=0;t[H>>2]=292;t[U>>2]=293;break}case 7:{t[k>>2]=0;t[H>>2]=298;break}case 11:{t[b>>2]=0;t[H>>2]=302;break}case 8:{t[k>>2]=0;t[H>>2]=299;break}case 1:{t[b>>2]=0;t[H>>2]=290;break}case 12:{t[b>>2]=0;t[H>>2]=303;break}case 6:{t[k>>2]=0;t[H>>2]=297;break}case 4:{t[k>>2]=0;if(((t[d>>2]|0)==5|(t[d>>2]|0)==3)&(t[v>>2]|0)==0)t[H>>2]=294;else t[H>>2]=295;t[U>>2]=293;break}case 13:{t[b>>2]=0;t[k>>2]=0;t[H>>2]=304;t[U>>2]=293;break}case 2:{t[b>>2]=0;t[H>>2]=291;break}case 5:{t[k>>2]=0;t[H>>2]=296;break}case 10:{t[b>>2]=0;t[H>>2]=301;break}default:{}}while(0);if(!(t[H>>2]|0)){zt(t[j>>2]|0,t[g>>2]|0);t[o>>2]=0;Y=t[o>>2]|0;s=u;return Y|0}t[y>>2]=t[(t[g>>2]|0)+4>>2];if((t[y>>2]|0)!=0?(t[t[y>>2]>>2]|0)>0:0){t[T>>2]=0;t[N>>2]=0;t[L>>2]=0;t[D>>2]=0;do if((t[(t[l>>2]|0)+8>>2]|0)!=-1?(t[N>>2]=(t[(t[(t[c>>2]|0)+32>>2]|0)+8>>2]|0)+((t[(t[l>>2]|0)+8>>2]|0)*40|0),(ra(t[c>>2]|0,t[N>>2]|0,T)|0)!=0):0)if((t[(t[N>>2]|0)+4>>2]|0)!=-1){t[N>>2]=(t[(t[(t[c>>2]|0)+32>>2]|0)+8>>2]|0)+((t[(t[N>>2]|0)+4>>2]|0)*40|0);t[L>>2]=1;break}else{t[N>>2]=0;t[D>>2]=1;break}while(0);if(t[h>>2]|0)G=(t[N>>2]|0)==0;else G=0;t[I>>2]=G?1:0;t[z>>2]=t[(t[j>>2]|0)+4>>2];t[x>>2]=305;t[A>>2]=0;t[M>>2]=0;t[O>>2]=0;t[F>>2]=0;e:while(1){if(!((t[O>>2]|0)!=0?1:(t[F>>2]|0)<(t[t[y>>2]>>2]|0)))break;if(t[(t[c>>2]|0)+8>>2]|0)break;G=t[F>>2]|0;t[F>>2]=G+1;t[(t[j>>2]|0)+4>>2]=t[(t[(t[y>>2]|0)+8>>2]|0)+(G<<2)>>2];if((t[M>>2]|0)==0?(t[M>>2]=Nn(0)|0,(t[M>>2]|0)==0):0){W=41;break}t[C>>2]=0;t[R>>2]=0;t[S>>2]=0;i:while(1){t[R>>2]=MAi[t[H>>2]&511](t[c>>2]|0,t[R>>2]|0)|0;if(!(t[R>>2]|0)){W=211;break}do if((t[b>>2]|0)!=0?(t[t[b>>2]>>2]|0)!=0:0){if((t[t[b>>2]>>2]|0)==(t[R>>2]|0)){W=211;break i}if((t[E>>2]|0)%256|0)break;if((zu(t[t[b>>2]>>2]|0,t[R>>2]|0)|0)>=0){W=211;break i}}while(0);do if((t[k>>2]|0)!=0?(t[t[k>>2]>>2]|0)!=0:0){if((t[t[k>>2]>>2]|0)==(t[R>>2]|0)){W=211;break i}if((t[E>>2]|0)%256|0)break;if((zu(t[R>>2]|0,t[t[k>>2]>>2]|0)|0)>=0){W=211;break i}}while(0);t[E>>2]=(t[E>>2]|0)+1;r:do switch(t[d>>2]|0){case 5:{do if((t[w>>2]|0)==3){if((t[(t[R>>2]|0)+4>>2]|0)!=2)break r}else{G=t[(t[R>>2]|0)+4>>2]|0;if((t[w>>2]|0)==9)if((G|0)!=18)break r;else break;else if((G|0)!=1)break r;else break}while(0);G=t[(t[R>>2]|0)+4>>2]|0;if((G|0)==18){if((t[(t[R>>2]|0)+4>>2]|0)!=18)break r;t[q>>2]=t[R>>2];if(!((t[_>>2]|0)!=0?(t[(t[q>>2]|0)+12>>2]|0)!=0:0))break r;if(!(Xl(t[(t[q>>2]|0)+12>>2]|0,t[_>>2]|0)|0))break r;if(t[D>>2]|0){l=(t[C>>2]|0)+1|0;t[C>>2]=l;if((l|0)==(t[T>>2]|0)){W=197;break i}else break r}t[S>>2]=1;if((Ln(t[M>>2]|0,t[(t[j>>2]|0)+4>>2]|0,t[R>>2]|0)|0)<0)t[(t[c>>2]|0)+8>>2]=15;if(t[I>>2]|0){W=208;break e}else break r}else if((G|0)==2){t[V>>2]=t[R>>2];if(!(Xl(t[_>>2]|0,t[(t[V>>2]|0)+8>>2]|0)|0))break r;l=t[(t[V>>2]|0)+36>>2]|0;if(!(t[m>>2]|0)){if((l|0)!=0?(t[(t[(t[V>>2]|0)+36>>2]|0)+12>>2]|0)!=0:0)break r;if(t[D>>2]|0){f=(t[C>>2]|0)+1|0;t[C>>2]=f;if((f|0)==(t[T>>2]|0)){W=178;break i}else break r}if((MAi[t[x>>2]&511](t[M>>2]|0,t[R>>2]|0)|0)<0)t[(t[c>>2]|0)+8>>2]=15;if(t[I>>2]|0){W=208;break e}else break r}else{if(!l)break r;if(!(Xl(t[p>>2]|0,t[(t[(t[V>>2]|0)+36>>2]|0)+8>>2]|0)|0))break r;if(t[D>>2]|0){l=(t[C>>2]|0)+1|0;t[C>>2]=l;if((l|0)==(t[T>>2]|0)){W=187;break i}else break r}if((MAi[t[x>>2]&511](t[M>>2]|0,t[R>>2]|0)|0)<0)t[(t[c>>2]|0)+8>>2]=15;if(t[I>>2]|0){W=208;break e}else break r}}else if((G|0)==1){if(!(Xl(t[_>>2]|0,t[(t[R>>2]|0)+8>>2]|0)|0))break r;G=t[(t[R>>2]|0)+36>>2]|0;if(!(t[m>>2]|0)){if(G)break r;if(t[D>>2]|0){l=(t[C>>2]|0)+1|0;t[C>>2]=l;if((l|0)==(t[T>>2]|0)){W=158;break i}else break r}if((MAi[t[x>>2]&511](t[M>>2]|0,t[R>>2]|0)|0)<0)t[(t[c>>2]|0)+8>>2]=15;if(t[I>>2]|0){W=208;break e}else break r}if(!G)break r;if(!(Xl(t[p>>2]|0,t[(t[(t[R>>2]|0)+36>>2]|0)+8>>2]|0)|0))break r;if(t[D>>2]|0){G=(t[C>>2]|0)+1|0;t[C>>2]=G;if((G|0)==(t[T>>2]|0)){W=167;break i}else break r}if((MAi[t[x>>2]&511](t[M>>2]|0,t[R>>2]|0)|0)<0)t[(t[c>>2]|0)+8>>2]=15;if(t[I>>2]|0){W=208;break e}else break r}else break r;break}case 2:{if((t[(t[R>>2]|0)+4>>2]|0)==7){if((t[_>>2]|0)!=0?(Xl(t[_>>2]|0,t[(t[R>>2]|0)+8>>2]|0)|0)==0:0)break r;if(t[D>>2]|0){G=(t[C>>2]|0)+1|0;t[C>>2]=G;if((G|0)==(t[T>>2]|0)){W=95;break i}else break r}if((MAi[t[x>>2]&511](t[M>>2]|0,t[R>>2]|0)|0)<0)t[(t[c>>2]|0)+8>>2]=15;if(t[I>>2]|0){W=208;break e}}break}case 1:{G=t[(t[R>>2]|0)+4>>2]|0;if(!(t[v>>2]|0)){switch(G|0){case 18:case 3:case 4:case 8:case 7:case 2:case 1:case 21:case 13:case 9:break;default:break r}if(t[D>>2]|0){l=(t[C>>2]|0)+1|0;t[C>>2]=l;if((l|0)==(t[T>>2]|0)){W=60;break i}else break r}if((MAi[t[x>>2]&511](t[M>>2]|0,t[R>>2]|0)|0)<0)t[(t[c>>2]|0)+8>>2]=15;if(t[I>>2]|0){W=208;break e}else break r}if((G|0)!=(t[v>>2]|0)){if((t[v>>2]|0)!=3)break r;if((t[(t[R>>2]|0)+4>>2]|0)!=4)break r;if(t[D>>2]|0){G=(t[C>>2]|0)+1|0;t[C>>2]=G;if((G|0)==(t[T>>2]|0)){W=85;break i}else break r}if((MAi[t[x>>2]&511](t[M>>2]|0,t[R>>2]|0)|0)<0)t[(t[c>>2]|0)+8>>2]=15;if(t[I>>2]|0){W=208;break e}else break r}G=(t[D>>2]|0)!=0;if((t[(t[R>>2]|0)+4>>2]|0)==18){if(G){l=(t[C>>2]|0)+1|0;t[C>>2]=l;if((l|0)==(t[T>>2]|0)){W=69;break i}else break r}t[S>>2]=1;if((Ln(t[M>>2]|0,t[(t[j>>2]|0)+4>>2]|0,t[R>>2]|0)|0)<0)t[(t[c>>2]|0)+8>>2]=15;if(t[I>>2]|0){W=208;break e}else break r}else{if(G){G=(t[C>>2]|0)+1|0;t[C>>2]=G;if((G|0)==(t[T>>2]|0)){W=76;break i}else break r}if((MAi[t[x>>2]&511](t[M>>2]|0,t[R>>2]|0)|0)<0)t[(t[c>>2]|0)+8>>2]=15;if(t[I>>2]|0){W=208;break e}else break r}break}case 0:{W=55;break e;break}case 4:{G=t[33976]|0;l=t[33980]|0;t[a>>2]=128552;t[a+4>>2]=12457;yAi[G&511](l,129064,a);break}case 3:{if((t[w>>2]|0)==3){if((t[(t[R>>2]|0)+4>>2]|0)!=2)break r;if(!(t[m>>2]|0)){if(t[D>>2]|0){l=(t[C>>2]|0)+1|0;t[C>>2]=l;if((l|0)==(t[T>>2]|0)){W=105;break i}else break r}if((MAi[t[x>>2]&511](t[M>>2]|0,t[R>>2]|0)|0)<0)t[(t[c>>2]|0)+8>>2]=15;if(t[I>>2]|0){W=208;break e}else break r}if(!(t[(t[R>>2]|0)+36>>2]|0))break r;if(!(Xl(t[p>>2]|0,t[(t[(t[R>>2]|0)+36>>2]|0)+8>>2]|0)|0))break r;if(t[D>>2]|0){l=(t[C>>2]|0)+1|0;t[C>>2]=l;if((l|0)==(t[T>>2]|0)){W=114;break i}else break r}if((MAi[t[x>>2]&511](t[M>>2]|0,t[R>>2]|0)|0)<0)t[(t[c>>2]|0)+8>>2]=15;if(t[I>>2]|0){W=208;break e}else break r}l=t[(t[R>>2]|0)+4>>2]|0;if((t[w>>2]|0)==9){if((l|0)!=18)break r;if(t[D>>2]|0){G=(t[C>>2]|0)+1|0;t[C>>2]=G;if((G|0)==(t[T>>2]|0)){W=123;break i}else break r}t[S>>2]=1;if((Ln(t[M>>2]|0,t[(t[j>>2]|0)+4>>2]|0,t[R>>2]|0)|0)<0)t[(t[c>>2]|0)+8>>2]=15;if(t[I>>2]|0){W=208;break e}else break r}if((l|0)!=1)break r;if(!(t[m>>2]|0)){if(t[D>>2]|0){l=(t[C>>2]|0)+1|0;t[C>>2]=l;if((l|0)==(t[T>>2]|0)){W=132;break i}else break r}if((MAi[t[x>>2]&511](t[M>>2]|0,t[R>>2]|0)|0)<0)t[(t[c>>2]|0)+8>>2]=15;if(t[I>>2]|0){W=208;break e}else break r}if(!(t[(t[R>>2]|0)+36>>2]|0))break r;if(!(Xl(t[p>>2]|0,t[(t[(t[R>>2]|0)+36>>2]|0)+8>>2]|0)|0))break r;if(t[D>>2]|0){l=(t[C>>2]|0)+1|0;t[C>>2]=l;if((l|0)==(t[T>>2]|0)){W=141;break i}else break r}if((MAi[t[x>>2]&511](t[M>>2]|0,t[R>>2]|0)|0)<0)t[(t[c>>2]|0)+8>>2]=15;if(t[I>>2]|0){W=208;break e}break}default:{}}while(0);if(!(t[R>>2]|0)){W=211;break}if(t[(t[c>>2]|0)+8>>2]|0){W=211;break}}switch(W|0){case 60:{W=0;if((MAi[t[x>>2]&511](t[M>>2]|0,t[R>>2]|0)|0)<0)t[(t[c>>2]|0)+8>>2]=15;break}case 69:{W=0;t[S>>2]=1;if((Ln(t[M>>2]|0,t[(t[j>>2]|0)+4>>2]|0,t[R>>2]|0)|0)<0)t[(t[c>>2]|0)+8>>2]=15;break}case 76:{W=0;if((MAi[t[x>>2]&511](t[M>>2]|0,t[R>>2]|0)|0)<0)t[(t[c>>2]|0)+8>>2]=15;break}case 85:{W=0;if((MAi[t[x>>2]&511](t[M>>2]|0,t[R>>2]|0)|0)<0)t[(t[c>>2]|0)+8>>2]=15;break}case 95:{W=0;if((MAi[t[x>>2]&511](t[M>>2]|0,t[R>>2]|0)|0)<0)t[(t[c>>2]|0)+8>>2]=15;break}case 105:{W=0;if((MAi[t[x>>2]&511](t[M>>2]|0,t[R>>2]|0)|0)<0)t[(t[c>>2]|0)+8>>2]=15;break}case 114:{W=0;if((MAi[t[x>>2]&511](t[M>>2]|0,t[R>>2]|0)|0)<0)t[(t[c>>2]|0)+8>>2]=15;break}case 123:{W=0;t[S>>2]=1;if((Ln(t[M>>2]|0,t[(t[j>>2]|0)+4>>2]|0,t[R>>2]|0)|0)<0)t[(t[c>>2]|0)+8>>2]=15;break}case 132:{W=0;if((MAi[t[x>>2]&511](t[M>>2]|0,t[R>>2]|0)|0)<0)t[(t[c>>2]|0)+8>>2]=15;break}case 141:{W=0;if((MAi[t[x>>2]&511](t[M>>2]|0,t[R>>2]|0)|0)<0)t[(t[c>>2]|0)+8>>2]=15;break}case 158:{W=0;if((MAi[t[x>>2]&511](t[M>>2]|0,t[R>>2]|0)|0)<0)t[(t[c>>2]|0)+8>>2]=15;break}case 167:{W=0;if((MAi[t[x>>2]&511](t[M>>2]|0,t[R>>2]|0)|0)<0)t[(t[c>>2]|0)+8>>2]=15;break}case 178:{W=0;if((MAi[t[x>>2]&511](t[M>>2]|0,t[R>>2]|0)|0)<0)t[(t[c>>2]|0)+8>>2]=15;break}case 187:{W=0;if((MAi[t[x>>2]&511](t[M>>2]|0,t[R>>2]|0)|0)<0)t[(t[c>>2]|0)+8>>2]=15;break}case 197:{W=0;t[S>>2]=1;if((Ln(t[M>>2]|0,t[(t[j>>2]|0)+4>>2]|0,t[R>>2]|0)|0)<0)t[(t[c>>2]|0)+8>>2]=15;break}case 211:{W=0;if(t[(t[c>>2]|0)+8>>2]|0)break e;if((t[N>>2]|0)!=0?(t[t[M>>2]>>2]|0)>0:0){t[P>>2]=t[t[M>>2]>>2];l=t[c>>2]|0;G=t[N>>2]|0;f=t[M>>2]|0;n=t[P>>2]|0;if(t[L>>2]|0)t[B>>2]=na(l,G,f,n,t[T>>2]|0,t[T>>2]|0,t[S>>2]|0)|0;else t[B>>2]=fa(l,G,f,n,t[S>>2]|0)|0;if(t[(t[c>>2]|0)+8>>2]|0){W=218;break e}n=t[M>>2]|0;if(!(t[B>>2]|0)){Zu(n,t[S>>2]|0);continue e}if((t[n>>2]|0)<=0)continue e;do if(!(t[A>>2]|0))if((t[P>>2]|0)!=(t[B>>2]|0)){t[A>>2]=dAi[t[U>>2]&511](0,t[M>>2]|0,1)|0;break}else{t[A>>2]=t[M>>2];t[M>>2]=0;break}else t[A>>2]=dAi[t[U>>2]&511](t[A>>2]|0,t[M>>2]|0,(t[P>>2]|0)!=(t[B>>2]|0)?1:0)|0;while(0);if(t[h>>2]|0)break e;else continue e}if((t[t[M>>2]>>2]|0)<=0)continue e;if(!(t[A>>2]|0)){t[A>>2]=t[M>>2];t[M>>2]=0;continue e}else{t[A>>2]=dAi[t[U>>2]&511](t[A>>2]|0,t[M>>2]|0,0)|0;continue e}break}}if(!(t[A>>2]|0)){t[A>>2]=t[M>>2];t[M>>2]=0}else t[A>>2]=dAi[t[U>>2]&511](t[A>>2]|0,t[M>>2]|0,0)|0;if(t[h>>2]|0)break}do if((W|0)==41)t[E>>2]=0;else if((W|0)==55){t[E>>2]=0;h=t[33976]|0;B=t[33980]|0;t[a>>2]=128552;t[a+4>>2]=12379;yAi[h&511](B,129448,a)}else if((W|0)==208)if(!(t[A>>2]|0)){t[A>>2]=t[M>>2];t[M>>2]=0;break}else{t[A>>2]=dAi[t[U>>2]&511](t[A>>2]|0,t[M>>2]|0,0)|0;break}else if((W|0)==218)t[E>>2]=0;while(0);if((t[(t[g>>2]|0)+8>>2]|0)!=0?(t[(t[g>>2]|0)+28>>2]|0)!=0:0){t[(t[(t[c>>2]|0)+16>>2]|0)+8>>2]=1;t[(t[(t[c>>2]|0)+16>>2]|0)+28>>2]=t[(t[g>>2]|0)+28>>2];t[(t[g>>2]|0)+28>>2]=0;t[(t[g>>2]|0)+8>>2]=0}zt(t[j>>2]|0,t[g>>2]|0);do if(!(t[A>>2]|0)){if((t[M>>2]|0)!=0?(t[t[M>>2]>>2]|0)==0:0){t[A>>2]=t[M>>2];break}t[A>>2]=Nn(0)|0}while(0);if((t[M>>2]|0)!=0?(t[M>>2]|0)!=(t[A>>2]|0):0)Bn(t[M>>2]|0);M=t[c>>2]|0;Sn(M,fu(t[j>>2]|0,t[A>>2]|0)|0)|0;t[(t[j>>2]|0)+4>>2]=t[z>>2];t[o>>2]=t[E>>2];Y=t[o>>2]|0;s=u;return Y|0}zt(t[j>>2]|0,t[g>>2]|0);g=t[c>>2]|0;Sn(g,fu(t[j>>2]|0,0)|0)|0;t[o>>2]=0;Y=t[o>>2]|0;s=u;return Y|0}dn(t[c>>2]|0,11);t[o>>2]=0;Y=t[o>>2]|0;s=u;return Y|0}function Gu(e){e=e|0;var i=0,r=0,n=0,f=0,u=0;i=s;s=s+16|0;r=i+8|0;n=i+4|0;f=i;t[n>>2]=e;if(!(t[n>>2]|0)){t[r>>2]=0;u=t[r>>2]|0;s=i;return u|0}else{t[f>>2]=t[(t[n>>2]|0)+44>>2];t[(t[n>>2]|0)+44>>2]=t[(t[n>>2]|0)+20>>2];t[r>>2]=t[f>>2];u=t[r>>2]|0;s=i;return u|0}return 0}function Wu(e,i){e=e|0;i=i|0;var r=0,n=0,f=0;r=s;s=s+16|0;n=r+4|0;f=r;t[n>>2]=e;t[f>>2]=i;if(!(t[n>>2]|0)){s=r;return}if((t[(t[n>>2]|0)+20>>2]|0)<(t[(t[n>>2]|0)+44>>2]|0))vn(t[n>>2]|0,128552,2808,23);t[(t[n>>2]|0)+44>>2]=t[f>>2];s=r;return}function Ku(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0;n=s;s=s+48|0;f=n+32|0;u=n+28|0;a=n+24|0;o=n+20|0;c=n+16|0;l=n+12|0;b=n+8|0;k=n+4|0;h=n;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;t[c>>2]=0;if(t[(t[u>>2]|0)+8>>2]|0){t[f>>2]=0;w=t[f>>2]|0;s=n;return w|0}t[b>>2]=t[(t[u>>2]|0)+32>>2];do switch(t[t[a>>2]>>2]|0){case 0:{t[f>>2]=0;w=t[f>>2]|0;s=n;return w|0}case 12:{Sn(t[u>>2]|0,Vt(t[(t[u>>2]|0)+12>>2]|0,t[(t[a>>2]|0)+24>>2]|0)|0)|0;t[f>>2]=0;w=t[f>>2]|0;s=n;return w|0}case 7:{t[c>>2]=Ku(t[u>>2]|0,(t[(t[b>>2]|0)+8>>2]|0)+((t[(t[a>>2]|0)+4>>2]|0)*40|0)|0,t[o>>2]|0)|0;if(t[(t[u>>2]|0)+8>>2]|0){t[f>>2]=0;w=t[f>>2]|0;s=n;return w|0}if((((t[(t[u>>2]|0)+16>>2]|0)!=0?(t[t[(t[u>>2]|0)+16>>2]>>2]|0)==1:0)?(t[(t[(t[u>>2]|0)+16>>2]|0)+4>>2]|0)!=0:0)?(t[t[(t[(t[u>>2]|0)+16>>2]|0)+4>>2]>>2]|0)>=1:0){if((t[t[(t[(t[u>>2]|0)+16>>2]|0)+4>>2]>>2]|0)>1)Mn(t[(t[(t[u>>2]|0)+16>>2]|0)+4>>2]|0);t[t[o>>2]>>2]=t[t[(t[(t[(t[u>>2]|0)+16>>2]|0)+4>>2]|0)+8>>2]>>2]}t[l>>2]=Ku(t[u>>2]|0,(t[(t[b>>2]|0)+8>>2]|0)+((t[(t[a>>2]|0)+8>>2]|0)*40|0)|0,t[o>>2]|0)|0;if(t[(t[u>>2]|0)+8>>2]|0){t[f>>2]=0;w=t[f>>2]|0;s=n;return w|0}if((t[(t[u>>2]|0)+16>>2]|0)!=0?(t[t[(t[u>>2]|0)+16>>2]>>2]|0)==1:0){t[h>>2]=En(t[u>>2]|0)|0;if((t[(t[u>>2]|0)+16>>2]|0)!=0?(t[t[(t[u>>2]|0)+16>>2]>>2]|0)==1:0){t[k>>2]=En(t[u>>2]|0)|0;r=Pn(t[(t[k>>2]|0)+4>>2]|0,t[(t[h>>2]|0)+4>>2]|0)|0;t[(t[k>>2]|0)+4>>2]=r;Sn(t[u>>2]|0,t[k>>2]|0)|0;zt(t[(t[u>>2]|0)+12>>2]|0,t[h>>2]|0);if((t[c>>2]|0)>(t[l>>2]|0))ta(t[a>>2]|0);t[f>>2]=(t[c>>2]|0)+(t[l>>2]|0);w=t[f>>2]|0;s=n;return w|0}dn(t[u>>2]|0,11);t[f>>2]=0;w=t[f>>2]|0;s=n;return w|0}dn(t[u>>2]|0,11);t[f>>2]=0;w=t[f>>2]|0;s=n;return w|0}case 10:{if((t[(t[a>>2]|0)+4>>2]|0)!=-1){r=Uu(t[u>>2]|0,(t[(t[b>>2]|0)+8>>2]|0)+((t[(t[a>>2]|0)+4>>2]|0)*40|0)|0)|0;t[c>>2]=(t[c>>2]|0)+r}if(t[(t[u>>2]|0)+8>>2]|0){t[f>>2]=0;w=t[f>>2]|0;s=n;return w|0}if((t[(t[a>>2]|0)+8>>2]|0)!=-1){r=Uu(t[u>>2]|0,(t[(t[b>>2]|0)+8>>2]|0)+((t[(t[a>>2]|0)+8>>2]|0)*40|0)|0)|0;t[c>>2]=(t[c>>2]|0)+r}if(t[(t[u>>2]|0)+8>>2]|0){t[f>>2]=0;w=t[f>>2]|0;s=n;return w|0}else{t[(t[(t[u>>2]|0)+12>>2]|0)+4>>2]=0;t[f>>2]=t[c>>2];w=t[f>>2]|0;s=n;return w|0}break}case 18:{if((t[(t[a>>2]|0)+4>>2]|0)!=-1){r=Ku(t[u>>2]|0,(t[(t[b>>2]|0)+8>>2]|0)+((t[(t[a>>2]|0)+4>>2]|0)*40|0)|0,t[o>>2]|0)|0;t[c>>2]=(t[c>>2]|0)+r}if(t[(t[u>>2]|0)+8>>2]|0){t[f>>2]=0;w=t[f>>2]|0;s=n;return w|0}if((((t[(t[u>>2]|0)+16>>2]|0)!=0?(t[t[(t[u>>2]|0)+16>>2]>>2]|0)==1:0)?(t[(t[(t[u>>2]|0)+16>>2]|0)+4>>2]|0)!=0:0)?(t[t[(t[(t[u>>2]|0)+16>>2]|0)+4>>2]>>2]|0)>1:0)Mn(t[(t[(t[u>>2]|0)+16>>2]|0)+4>>2]|0);t[f>>2]=t[c>>2];w=t[f>>2]|0;s=n;return w|0}case 9:{if((t[(t[a>>2]|0)+4>>2]|0)!=-1){r=Uu(t[u>>2]|0,(t[(t[b>>2]|0)+8>>2]|0)+((t[(t[a>>2]|0)+4>>2]|0)*40|0)|0)|0;t[c>>2]=(t[c>>2]|0)+r}if(t[(t[u>>2]|0)+8>>2]|0){t[f>>2]=0;w=t[f>>2]|0;s=n;return w|0}if((t[(t[a>>2]|0)+8>>2]|0)!=-1){r=Uu(t[u>>2]|0,(t[(t[b>>2]|0)+8>>2]|0)+((t[(t[a>>2]|0)+8>>2]|0)*40|0)|0)|0;t[c>>2]=(t[c>>2]|0)+r}if(t[(t[u>>2]|0)+8>>2]|0){t[f>>2]=0;w=t[f>>2]|0;s=n;return w|0}else{r=t[u>>2]|0;Sn(r,ru(t[(t[u>>2]|0)+12>>2]|0,t[(t[(t[u>>2]|0)+12>>2]|0)+4>>2]|0)|0)|0;t[f>>2]=t[c>>2];w=t[f>>2]|0;s=n;return w|0}break}case 11:{if((t[(t[a>>2]|0)+4>>2]|0)==-1){t[f>>2]=t[c>>2];w=t[f>>2]|0;s=n;return w|0}t[c>>2]=Uu(t[u>>2]|0,(t[(t[b>>2]|0)+8>>2]|0)+((t[(t[a>>2]|0)+4>>2]|0)*40|0)|0)|0;if(t[(t[u>>2]|0)+8>>2]|0){t[f>>2]=0;w=t[f>>2]|0;s=n;return w|0}else{r=Yu(t[u>>2]|0,t[a>>2]|0,t[o>>2]|0,0,0)|0;t[c>>2]=(t[c>>2]|0)+r;t[f>>2]=t[c>>2];w=t[f>>2]|0;s=n;return w|0}break}case 8:{jf(t[u>>2]|0);t[f>>2]=0;w=t[f>>2]|0;s=n;return w|0}case 17:{t[c>>2]=(ua(t[u>>2]|0,t[a>>2]|0,t[o>>2]|0)|0)+(t[c>>2]|0);t[f>>2]=t[c>>2];w=t[f>>2]|0;s=n;return w|0}default:{t[f>>2]=Uu(t[u>>2]|0,t[a>>2]|0)|0;w=t[f>>2]|0;s=n;return w|0}}while(0);return 0}function Xu(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0;n=s;s=s+64|0;f=n+48|0;u=n+44|0;a=n+40|0;o=n+36|0;c=n+32|0;l=n+28|0;b=n+24|0;k=n+20|0;h=n+16|0;w=n+12|0;d=n+8|0;v=n+4|0;m=n;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;t[c>>2]=0;if(t[(t[u>>2]|0)+8>>2]|0){t[f>>2]=0;_=t[f>>2]|0;s=n;return _|0}t[b>>2]=t[(t[u>>2]|0)+32>>2];switch(t[t[a>>2]>>2]|0){case 0:{t[f>>2]=0;_=t[f>>2]|0;s=n;return _|0}case 11:{if((t[(t[a>>2]|0)+4>>2]|0)==-1){t[f>>2]=0;_=t[f>>2]|0;s=n;return _|0}t[c>>2]=(Uu(t[u>>2]|0,(t[(t[b>>2]|0)+8>>2]|0)+((t[(t[a>>2]|0)+4>>2]|0)*40|0)|0)|0)+(t[c>>2]|0);if(t[(t[u>>2]|0)+8>>2]|0){t[f>>2]=0;_=t[f>>2]|0;s=n;return _|0}else{r=Yu(t[u>>2]|0,t[a>>2]|0,0,t[o>>2]|0,0)|0;t[c>>2]=(t[c>>2]|0)+r;t[f>>2]=t[c>>2];_=t[f>>2]|0;s=n;return _|0}break}case 7:{t[d>>2]=t[t[(t[u>>2]|0)+12>>2]>>2];t[w>>2]=t[(t[(t[u>>2]|0)+12>>2]|0)+4>>2];t[v>>2]=t[(t[(t[u>>2]|0)+12>>2]|0)+72>>2];t[m>>2]=t[(t[(t[u>>2]|0)+12>>2]|0)+68>>2];t[c>>2]=Xu(t[u>>2]|0,(t[(t[b>>2]|0)+8>>2]|0)+((t[(t[a>>2]|0)+4>>2]|0)*40|0)|0,t[o>>2]|0)|0;if(t[(t[u>>2]|0)+8>>2]|0){t[f>>2]=0;_=t[f>>2]|0;s=n;return _|0}if((((t[(t[u>>2]|0)+16>>2]|0)!=0?(t[t[(t[u>>2]|0)+16>>2]>>2]|0)==1:0)?(t[(t[(t[u>>2]|0)+16>>2]|0)+4>>2]|0)!=0:0)?(t[t[(t[(t[u>>2]|0)+16>>2]|0)+4>>2]>>2]|0)>=1:0){if((t[t[(t[(t[u>>2]|0)+16>>2]|0)+4>>2]>>2]|0)>1)Mn(t[(t[(t[u>>2]|0)+16>>2]|0)+4>>2]|0);t[t[o>>2]>>2]=t[(t[(t[(t[(t[u>>2]|0)+16>>2]|0)+4>>2]|0)+8>>2]|0)+((t[t[(t[(t[u>>2]|0)+16>>2]|0)+4>>2]>>2]|0)-1<<2)>>2]}t[t[(t[u>>2]|0)+12>>2]>>2]=t[d>>2];t[(t[(t[u>>2]|0)+12>>2]|0)+4>>2]=t[w>>2];t[(t[(t[u>>2]|0)+12>>2]|0)+72>>2]=t[v>>2];t[(t[(t[u>>2]|0)+12>>2]|0)+68>>2]=t[m>>2];t[l>>2]=Xu(t[u>>2]|0,(t[(t[b>>2]|0)+8>>2]|0)+((t[(t[a>>2]|0)+8>>2]|0)*40|0)|0,t[o>>2]|0)|0;if(t[(t[u>>2]|0)+8>>2]|0){t[f>>2]=0;_=t[f>>2]|0;s=n;return _|0}if((t[(t[u>>2]|0)+16>>2]|0)!=0?(t[t[(t[u>>2]|0)+16>>2]>>2]|0)==1:0){t[h>>2]=En(t[u>>2]|0)|0;if((t[(t[u>>2]|0)+16>>2]|0)!=0?(t[t[(t[u>>2]|0)+16>>2]>>2]|0)==1:0){t[k>>2]=En(t[u>>2]|0)|0;m=Pn(t[(t[k>>2]|0)+4>>2]|0,t[(t[h>>2]|0)+4>>2]|0)|0;t[(t[k>>2]|0)+4>>2]=m;Sn(t[u>>2]|0,t[k>>2]|0)|0;zt(t[(t[u>>2]|0)+12>>2]|0,t[h>>2]|0);if((t[c>>2]|0)>(t[l>>2]|0))ta(t[a>>2]|0);t[f>>2]=(t[c>>2]|0)+(t[l>>2]|0);_=t[f>>2]|0;s=n;return _|0}dn(t[u>>2]|0,11);t[f>>2]=0;_=t[f>>2]|0;s=n;return _|0}dn(t[u>>2]|0,11);t[f>>2]=0;_=t[f>>2]|0;s=n;return _|0}case 10:{if((t[(t[a>>2]|0)+4>>2]|0)!=-1){l=Uu(t[u>>2]|0,(t[(t[b>>2]|0)+8>>2]|0)+((t[(t[a>>2]|0)+4>>2]|0)*40|0)|0)|0;t[c>>2]=(t[c>>2]|0)+l}if(t[(t[u>>2]|0)+8>>2]|0){t[f>>2]=0;_=t[f>>2]|0;s=n;return _|0}if((t[(t[a>>2]|0)+8>>2]|0)!=-1){l=Uu(t[u>>2]|0,(t[(t[b>>2]|0)+8>>2]|0)+((t[(t[a>>2]|0)+8>>2]|0)*40|0)|0)|0;t[c>>2]=(t[c>>2]|0)+l}if(t[(t[u>>2]|0)+8>>2]|0){t[f>>2]=0;_=t[f>>2]|0;s=n;return _|0}else{t[(t[(t[u>>2]|0)+12>>2]|0)+4>>2]=0;t[f>>2]=t[c>>2];_=t[f>>2]|0;s=n;return _|0}break}case 9:{if((t[(t[a>>2]|0)+4>>2]|0)!=-1){l=Uu(t[u>>2]|0,(t[(t[b>>2]|0)+8>>2]|0)+((t[(t[a>>2]|0)+4>>2]|0)*40|0)|0)|0;t[c>>2]=(t[c>>2]|0)+l}if(t[(t[u>>2]|0)+8>>2]|0){t[f>>2]=0;_=t[f>>2]|0;s=n;return _|0}if((t[(t[a>>2]|0)+8>>2]|0)!=-1){l=Uu(t[u>>2]|0,(t[(t[b>>2]|0)+8>>2]|0)+((t[(t[a>>2]|0)+8>>2]|0)*40|0)|0)|0;t[c>>2]=(t[c>>2]|0)+l}if(t[(t[u>>2]|0)+8>>2]|0){t[f>>2]=0;_=t[f>>2]|0;s=n;return _|0}else{l=t[u>>2]|0;Sn(l,ru(t[(t[u>>2]|0)+12>>2]|0,t[(t[(t[u>>2]|0)+12>>2]|0)+4>>2]|0)|0)|0;t[f>>2]=t[c>>2];_=t[f>>2]|0;s=n;return _|0}break}case 8:{jf(t[u>>2]|0);t[f>>2]=0;_=t[f>>2]|0;s=n;return _|0}case 12:{Sn(t[u>>2]|0,Vt(t[(t[u>>2]|0)+12>>2]|0,t[(t[a>>2]|0)+24>>2]|0)|0)|0;t[f>>2]=0;_=t[f>>2]|0;s=n;return _|0}case 18:{if((t[(t[a>>2]|0)+4>>2]|0)!=-1){l=Xu(t[u>>2]|0,(t[(t[b>>2]|0)+8>>2]|0)+((t[(t[a>>2]|0)+4>>2]|0)*40|0)|0,t[o>>2]|0)|0;t[c>>2]=(t[c>>2]|0)+l}if(t[(t[u>>2]|0)+8>>2]|0){t[f>>2]=0;_=t[f>>2]|0;s=n;return _|0}if((((t[(t[u>>2]|0)+16>>2]|0)!=0?(t[t[(t[u>>2]|0)+16>>2]>>2]|0)==1:0)?(t[(t[(t[u>>2]|0)+16>>2]|0)+4>>2]|0)!=0:0)?(t[t[(t[(t[u>>2]|0)+16>>2]|0)+4>>2]>>2]|0)>1:0)Mn(t[(t[(t[u>>2]|0)+16>>2]|0)+4>>2]|0);t[f>>2]=t[c>>2];_=t[f>>2]|0;s=n;return _|0}default:{t[f>>2]=Uu(t[u>>2]|0,t[a>>2]|0)|0;_=t[f>>2]|0;s=n;return _|0}}return 0}function Zu(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0;r=s;s=s+16|0;n=r+12|0;f=r+8|0;u=r+4|0;a=r;t[n>>2]=e;t[f>>2]=i;if(!(t[n>>2]|0)){s=r;return}if((t[t[n>>2]>>2]|0)<=0){s=r;return}e:do if(t[f>>2]|0){t[u>>2]=0;while(1){if((t[u>>2]|0)>=(t[t[n>>2]>>2]|0))break e;t[a>>2]=t[(t[(t[n>>2]|0)+8>>2]|0)+(t[u>>2]<<2)>>2];if((t[a>>2]|0)!=0?(t[(t[a>>2]|0)+4>>2]|0)==18:0)Rn(t[a>>2]|0);t[u>>2]=(t[u>>2]|0)+1}}while(0);t[t[n>>2]>>2]=0;s=r;return}function Ju(e){e=e|0;var i=0,r=0,n=0,f=0,a=0,o=0,c=0,l=0;i=s;s=s+16|0;r=i+12|0;n=i+8|0;f=i+4|0;a=i;t[r>>2]=e;aa(t[r>>2]|0);if(t[(t[r>>2]|0)+8>>2]|0){s=i;return}e:while(1){do if((u[t[t[r>>2]>>2]>>0]|0|0)!=32){if(9<=(u[t[t[r>>2]>>2]>>0]|0|0)?(u[t[t[r>>2]>>2]>>0]|0|0)<=10:0)break;if((u[t[t[r>>2]>>2]>>0]|0|0)!=13)break e}while(0);e=t[r>>2]|0;if(!(u[t[t[r>>2]>>2]>>0]|0))continue;t[e>>2]=(t[e>>2]|0)+1}e:while(1){do if((u[t[t[r>>2]>>2]>>0]|0|0)!=60?(u[t[t[r>>2]>>2]>>0]|0|0)!=62:0){if((u[t[t[r>>2]>>2]>>0]|0|0)==60?(u[(t[t[r>>2]>>2]|0)+1>>0]|0|0)==61:0)break;if((u[t[t[r>>2]>>2]>>0]|0|0)!=62){o=40;break e}if((u[(t[t[r>>2]>>2]|0)+1>>0]|0|0)!=61){o=40;break e}}while(0);t[a>>2]=t[(t[(t[r>>2]|0)+32>>2]|0)+12>>2];if((u[t[t[r>>2]>>2]>>0]|0|0)==60)t[n>>2]=1;else t[n>>2]=0;if((u[(t[t[r>>2]>>2]|0)+1>>0]|0|0)==61)t[f>>2]=0;else t[f>>2]=1;e=t[r>>2]|0;if(u[t[t[r>>2]>>2]>>0]|0)t[e>>2]=(t[e>>2]|0)+1;if((t[f>>2]|0)==0?(e=t[r>>2]|0,(u[t[t[r>>2]>>2]>>0]|0|0)!=0):0)t[e>>2]=(t[e>>2]|0)+1;while(1){do if((u[t[t[r>>2]>>2]>>0]|0|0)==32)c=1;else{if(9<=(u[t[t[r>>2]>>2]>>0]|0|0)?(u[t[t[r>>2]>>2]>>0]|0|0)<=10:0){c=1;break}c=(u[t[t[r>>2]>>2]>>0]|0|0)==13}while(0);l=t[r>>2]|0;if(!c)break;e=t[r>>2]|0;if(!(u[t[l>>2]>>0]|0))continue;t[e>>2]=(t[e>>2]|0)+1}aa(l);if(t[(t[r>>2]|0)+8>>2]|0){o=40;break}Pu(t[(t[r>>2]|0)+32>>2]|0,t[a>>2]|0,t[(t[(t[r>>2]|0)+32>>2]|0)+12>>2]|0,4,t[n>>2]|0,t[f>>2]|0,0,0,0)|0;while(1){do if((u[t[t[r>>2]>>2]>>0]|0|0)!=32){if(9<=(u[t[t[r>>2]>>2]>>0]|0|0)?(u[t[t[r>>2]>>2]>>0]|0|0)<=10:0)break;if((u[t[t[r>>2]>>2]>>0]|0|0)!=13)continue e}while(0);e=t[r>>2]|0;if(!(u[t[t[r>>2]>>2]>>0]|0))continue;t[e>>2]=(t[e>>2]|0)+1}}if((o|0)==40){s=i;return}}function Qu(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0;n=s;s=s+48|0;f=n+40|0;u=n+36|0;a=n+32|0;o=n+28|0;c=n+24|0;l=n+20|0;b=n+16|0;k=n+12|0;h=n+8|0;w=n+4|0;d=n;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;e:do if((t[u>>2]|0)==0&(t[o>>2]|0)==0){t[u>>2]=oa(t[t[a>>2]>>2]|0)|0;if(!(t[u>>2]|0)){t[f>>2]=0;v=t[f>>2]|0;s=n;return v|0}else{if(!(t[t[a>>2]>>2]|0))break;YY(t[(t[u>>2]|0)+8>>2]|0,t[(t[a>>2]|0)+8>>2]|0,t[t[a>>2]>>2]<<2|0)|0;t[t[u>>2]>>2]=t[t[a>>2]>>2];break}}else{if(!(t[u>>2]|0))t[u>>2]=Nn(0)|0;if(!(t[u>>2]|0)){t[f>>2]=0;v=t[f>>2]|0;s=n;return v|0}t[b>>2]=t[t[u>>2]>>2];t[c>>2]=0;i:while(1){if((t[c>>2]|0)>=(t[t[a>>2]>>2]|0))break e;t[h>>2]=t[(t[(t[a>>2]|0)+8>>2]|0)+(t[c>>2]<<2)>>2];r:do if(t[h>>2]|0){t[l>>2]=0;while(1){if((t[l>>2]|0)>=(t[b>>2]|0))break;t[k>>2]=t[(t[(t[u>>2]|0)+8>>2]|0)+(t[l>>2]<<2)>>2];if((t[k>>2]|0)==(t[h>>2]|0))break r;if((((t[(t[k>>2]|0)+4>>2]|0)==18?(t[(t[h>>2]|0)+4>>2]|0)==18:0)?(t[t[k>>2]>>2]|0)==(t[t[h>>2]>>2]|0):0)?(Xl(t[(t[k>>2]|0)+12>>2]|0,t[(t[h>>2]|0)+12>>2]|0)|0)!=0:0){m=20;break}t[l>>2]=(t[l>>2]|0)+1}if((m|0)==20){m=0;t[(t[(t[a>>2]|0)+8>>2]|0)+(t[c>>2]<<2)>>2]=0;Rn(t[h>>2]|0);break}if(t[(t[u>>2]|0)+4>>2]|0){if((t[t[u>>2]>>2]|0)>=(t[(t[u>>2]|0)+4>>2]|0)){if((t[(t[u>>2]|0)+4>>2]|0)>=1e7){m=28;break i}t[w>>2]=MAi[t[135760>>2]&511](t[(t[u>>2]|0)+8>>2]|0,t[(t[u>>2]|0)+4>>2]<<1<<2)|0;if(!(t[w>>2]|0)){m=30;break i}t[(t[u>>2]|0)+8>>2]=t[w>>2];r=(t[u>>2]|0)+4|0;t[r>>2]=t[r>>2]<<1}}else{r=gAi[t[135744>>2]&511](40)|0;t[(t[u>>2]|0)+8>>2]=r;if(!(t[(t[u>>2]|0)+8>>2]|0)){m=24;break i}r=(t[(t[u>>2]|0)+8>>2]|0)+0|0;i=r+40|0;do{t[r>>2]=0;r=r+4|0}while((r|0)<(i|0));t[(t[u>>2]|0)+4>>2]=10}r=t[h>>2]|0;if((t[(t[h>>2]|0)+4>>2]|0)==18){t[d>>2]=r;i=jt(t[t[d>>2]>>2]|0,t[d>>2]|0)|0;e=t[u>>2]|0;_=t[e>>2]|0;t[e>>2]=_+1;t[(t[(t[u>>2]|0)+8>>2]|0)+(_<<2)>>2]=i;break}else{i=t[u>>2]|0;_=t[i>>2]|0;t[i>>2]=_+1;t[(t[(t[u>>2]|0)+8>>2]|0)+(_<<2)>>2]=r;break}}while(0);t[c>>2]=(t[c>>2]|0)+1}if((m|0)==24){Ut(0,128712);t[f>>2]=0;v=t[f>>2]|0;s=n;return v|0}else if((m|0)==28){Ut(0,128736);t[f>>2]=0;v=t[f>>2]|0;s=n;return v|0}else if((m|0)==30){Ut(0,128712);t[f>>2]=0;v=t[f>>2]|0;s=n;return v|0}}while(0);t[t[a>>2]>>2]=0;t[f>>2]=t[u>>2];v=t[f>>2]|0;s=n;return v|0}function $u(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0;n=s;s=s+32|0;f=n+24|0;u=n+20|0;a=n+16|0;o=n+12|0;c=n+8|0;l=n+4|0;b=n;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;r=t[u>>2]|0;if(!(t[a>>2]|0)){t[f>>2]=r;k=t[f>>2]|0;s=n;return k|0}e:do if((r|0)==0&(t[o>>2]|0)==0){t[u>>2]=oa(t[t[a>>2]>>2]|0)|0;if(!(t[u>>2]|0)){t[f>>2]=0;k=t[f>>2]|0;s=n;return k|0}else{if(!(t[t[a>>2]>>2]|0))break;YY(t[(t[u>>2]|0)+8>>2]|0,t[(t[a>>2]|0)+8>>2]|0,t[t[a>>2]>>2]<<2|0)|0;t[t[u>>2]>>2]=t[t[a>>2]>>2];break}}else{if(!(t[u>>2]|0))t[u>>2]=Nn(0)|0;if(!(t[u>>2]|0)){t[f>>2]=0;k=t[f>>2]|0;s=n;return k|0}t[c>>2]=0;while(1){if((t[c>>2]|0)>=(t[t[a>>2]>>2]|0))break e;t[l>>2]=t[(t[(t[a>>2]|0)+8>>2]|0)+(t[c>>2]<<2)>>2];if(t[l>>2]|0){if(t[(t[u>>2]|0)+4>>2]|0){if((t[t[u>>2]>>2]|0)>=(t[(t[u>>2]|0)+4>>2]|0)){if((t[(t[u>>2]|0)+4>>2]|0)>=1e7){h=21;break}t[b>>2]=MAi[t[135760>>2]&511](t[(t[u>>2]|0)+8>>2]|0,t[(t[u>>2]|0)+4>>2]<<1<<2)|0;if(!(t[b>>2]|0)){h=23;break}t[(t[u>>2]|0)+8>>2]=t[b>>2];i=(t[u>>2]|0)+4|0;t[i>>2]=t[i>>2]<<1}}else{i=gAi[t[135744>>2]&511](40)|0;t[(t[u>>2]|0)+8>>2]=i;if(!(t[(t[u>>2]|0)+8>>2]|0)){h=17;break}i=(t[(t[u>>2]|0)+8>>2]|0)+0|0;e=i+40|0;do{t[i>>2]=0;i=i+4|0}while((i|0)<(e|0));t[(t[u>>2]|0)+4>>2]=10}i=t[l>>2]|0;e=t[u>>2]|0;w=t[e>>2]|0;t[e>>2]=w+1;t[(t[(t[u>>2]|0)+8>>2]|0)+(w<<2)>>2]=i}t[c>>2]=(t[c>>2]|0)+1}if((h|0)==17){Ut(0,128712);t[f>>2]=0;k=t[f>>2]|0;s=n;return k|0}else if((h|0)==21){Ut(0,128736);t[f>>2]=0;k=t[f>>2]|0;s=n;return k|0}else if((h|0)==23){Ut(0,128712);t[f>>2]=0;k=t[f>>2]|0;s=n;return k|0}}while(0);t[t[a>>2]>>2]=0;t[f>>2]=t[u>>2];k=t[f>>2]|0;s=n;return k|0}function ea(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0;r=s;s=s+16|0;n=r+8|0;f=r+4|0;u=r;t[f>>2]=e;t[u>>2]=i;e:do if((t[f>>2]|0)!=0?(t[(t[f>>2]|0)+12>>2]|0)!=0:0){if(t[u>>2]|0){switch(t[(t[u>>2]|0)+4>>2]|0){case 20:case 8:case 7:case 4:case 6:case 5:case 3:case 1:break;default:{t[n>>2]=0;break e}}if(!(t[(t[u>>2]|0)+24>>2]|0)){t[n>>2]=0;break}i=t[(t[u>>2]|0)+24>>2]|0;if((t[(t[(t[u>>2]|0)+24>>2]|0)+4>>2]|0)==1){t[n>>2]=i;break}t[u>>2]=i;do{t[u>>2]=t[(t[u>>2]|0)+24>>2];if(!(t[u>>2]|0))break}while((t[(t[u>>2]|0)+4>>2]|0)!=1);t[n>>2]=t[u>>2];break}t[u>>2]=t[(t[(t[f>>2]|0)+12>>2]|0)+4>>2];if(!(t[u>>2]|0)){t[n>>2]=0;break}switch(t[(t[u>>2]|0)+4>>2]|0){case 21:case 13:case 9:{t[n>>2]=eF(t[u>>2]|0)|0;break e;break}case 6:case 5:case 11:case 1:{t[u>>2]=t[(t[u>>2]|0)+12>>2];if(!(t[u>>2]|0)){t[n>>2]=0;break e}if((t[(t[u>>2]|0)+4>>2]|0)==1){t[n>>2]=t[u>>2];break e}do{t[u>>2]=t[(t[u>>2]|0)+24>>2];if(!(t[u>>2]|0))break}while((t[(t[u>>2]|0)+4>>2]|0)!=1);t[n>>2]=t[u>>2];break e;break}default:{t[n>>2]=0;break e}}}else a=3;while(0);if((a|0)==3)t[n>>2]=0;s=r;return t[n>>2]|0}function ia(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0;r=s;s=s+16|0;n=r+8|0;f=r+4|0;u=r;t[f>>2]=e;t[u>>2]=i;if((t[f>>2]|0)!=0?(t[(t[f>>2]|0)+12>>2]|0)!=0:0){do if(!(t[u>>2]|0)){t[u>>2]=t[(t[(t[f>>2]|0)+12>>2]|0)+4>>2];if(!(t[u>>2]|0)){t[n>>2]=0;a=t[n>>2]|0;s=r;return a|0}if((t[(t[u>>2]|0)+4>>2]|0)!=18){t[(t[f>>2]|0)+40>>2]=t[(t[u>>2]|0)+20>>2];break}t[n>>2]=0;a=t[n>>2]|0;s=r;return a|0}while(0);if((t[(t[u>>2]|0)+4>>2]|0)==18){t[n>>2]=0;a=t[n>>2]|0;s=r;return a|0}if((t[(t[u>>2]|0)+28>>2]|0)!=0?(t[(t[(t[u>>2]|0)+28>>2]|0)+4>>2]|0)==14:0)t[u>>2]=t[(t[u>>2]|0)+28>>2];while(1){o=t[u>>2]|0;if(t[(t[u>>2]|0)+28>>2]|0){c=23;break}t[u>>2]=t[o+20>>2];if(!(t[u>>2]|0)){c=17;break}if((t[u>>2]|0)==(t[(t[t[(t[f>>2]|0)+12>>2]>>2]|0)+12>>2]|0)){c=19;break}l=t[u>>2]|0;if((t[u>>2]|0)!=(t[(t[f>>2]|0)+40>>2]|0)){c=21;break}t[(t[f>>2]|0)+40>>2]=t[l+20>>2]}if((c|0)==17){t[n>>2]=0;a=t[n>>2]|0;s=r;return a|0}else if((c|0)==19){t[n>>2]=0;a=t[n>>2]|0;s=r;return a|0}else if((c|0)==21){t[n>>2]=l;a=t[n>>2]|0;s=r;return a|0}else if((c|0)==23){t[u>>2]=t[o+28>>2];while(1){b=t[u>>2]|0;if(!(t[(t[u>>2]|0)+16>>2]|0))break;t[u>>2]=t[b+16>>2]}t[n>>2]=b;a=t[n>>2]|0;s=r;return a|0}}t[n>>2]=0;a=t[n>>2]|0;s=r;return a|0}function ra(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,b=0;n=s;s=s+32|0;f=n+16|0;u=n+12|0;a=n+8|0;o=n+4|0;c=n;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;if((t[t[a>>2]>>2]|0)!=16?(t[t[a>>2]>>2]|0)!=17:0){t[f>>2]=0;b=t[f>>2]|0;s=n;return b|0}if((t[(t[a>>2]|0)+8>>2]|0)==-1){t[f>>2]=0;b=t[f>>2]|0;s=n;return b|0}t[c>>2]=(t[(t[(t[u>>2]|0)+32>>2]|0)+8>>2]|0)+((t[(t[a>>2]|0)+8>>2]|0)*40|0);if(((((t[c>>2]|0)!=0?(t[t[c>>2]>>2]|0)==12:0)?(t[(t[c>>2]|0)+24>>2]|0)!=0:0)?(t[t[(t[c>>2]|0)+24>>2]>>2]|0)==3:0)?(t[t[o>>2]>>2]=~~+l[(t[(t[c>>2]|0)+24>>2]|0)+16>>3],+l[(t[(t[c>>2]|0)+24>>2]|0)+16>>3]==+(t[t[o>>2]>>2]|0)):0){t[f>>2]=1;b=t[f>>2]|0;s=n;return b|0}t[f>>2]=0;b=t[f>>2]|0;s=n;return b|0}function na(e,i,r,n,f,u,a){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;u=u|0;a=a|0;var o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0,S=0,g=0,y=0,F=0,O=0,A=0,M=0,R=0,N=0,T=0,L=0,D=0,C=0;o=s;s=s+96|0;c=o+88|0;l=o+84|0;b=o+80|0;k=o+76|0;h=o+72|0;w=o+68|0;d=o+64|0;v=o+60|0;m=o+56|0;_=o+52|0;p=o+48|0;E=o+44|0;S=o+40|0;g=o+36|0;y=o+32|0;F=o+28|0;O=o+24|0;A=o+20|0;M=o+16|0;R=o+12|0;N=o+8|0;T=o+4|0;L=o;t[l>>2]=e;t[b>>2]=i;t[k>>2]=r;t[h>>2]=n;t[w>>2]=f;t[d>>2]=u;t[v>>2]=a;if((t[(t[b>>2]|0)+4>>2]|0)!=-1){t[m>>2]=t[(t[l>>2]|0)+32>>2];t[h>>2]=fa(t[l>>2]|0,(t[(t[m>>2]|0)+8>>2]|0)+((t[(t[b>>2]|0)+4>>2]|0)*40|0)|0,t[k>>2]|0,t[h>>2]|0,t[v>>2]|0)|0;if(t[(t[l>>2]|0)+8>>2]|0){t[c>>2]=0;D=t[c>>2]|0;s=o;return D|0}if((t[h>>2]|0)<=0){t[c>>2]=0;D=t[c>>2]|0;s=o;return D|0}}if((t[h>>2]|0)<(t[w>>2]|0)){Zu(t[k>>2]|0,t[v>>2]|0);t[c>>2]=0;D=t[c>>2]|0;s=o;return D|0}if((t[(t[b>>2]|0)+8>>2]|0)==-1){t[c>>2]=t[h>>2];D=t[c>>2]|0;s=o;return D|0}t[E>>2]=0;t[S>>2]=0;t[g>>2]=0;t[O>>2]=0;t[A>>2]=0;t[R>>2]=0;t[N>>2]=t[(t[l>>2]|0)+12>>2];t[M>>2]=t[(t[N>>2]|0)+4>>2];t[_>>2]=t[t[N>>2]>>2];t[F>>2]=(t[(t[(t[l>>2]|0)+32>>2]|0)+8>>2]|0)+((t[(t[b>>2]|0)+8>>2]|0)*40|0);t[p>>2]=0;e:while(1){if((t[p>>2]|0)>=(t[t[k>>2]>>2]|0))break;do if(t[(t[(t[k>>2]|0)+8>>2]|0)+(t[p>>2]<<2)>>2]|0){t[R>>2]=t[(t[(t[k>>2]|0)+8>>2]|0)+(t[p>>2]<<2)>>2];t[(t[N>>2]|0)+4>>2]=t[R>>2];t[(t[N>>2]|0)+68>>2]=t[h>>2];b=(t[g>>2]|0)+1|0;t[g>>2]=b;t[(t[N>>2]|0)+72>>2]=b;if((t[(t[R>>2]|0)+4>>2]|0)!=18?(t[(t[R>>2]|0)+32>>2]|0)!=0:0)t[t[N>>2]>>2]=t[(t[R>>2]|0)+32>>2];if(t[O>>2]|0){if((Cn(t[(t[O>>2]|0)+4>>2]|0,t[R>>2]|0)|0)<0){C=19;break e}}else t[O>>2]=ru(t[N>>2]|0,t[R>>2]|0)|0;t[T>>2]=Gu(t[l>>2]|0)|0;Sn(t[l>>2]|0,t[O>>2]|0)|0;t[y>>2]=xu(t[l>>2]|0,t[F>>2]|0,1)|0;t[L>>2]=En(t[l>>2]|0)|0;Wu(t[l>>2]|0,t[T>>2]|0);if((t[y>>2]|0)==-1?1:(t[(t[l>>2]|0)+8>>2]|0)!=0){C=21;break e}Sn(t[l>>2]|0,t[L>>2]|0)|0;if(t[y>>2]|0)t[E>>2]=(t[E>>2]|0)+1;if(((t[y>>2]|0)!=0?(t[E>>2]|0)>=(t[w>>2]|0):0)?(t[E>>2]|0)<=(t[d>>2]|0):0){t[S>>2]=(t[S>>2]|0)+1;if((t[w>>2]|0)==(t[d>>2]|0)){C=29;break e}if((t[E>>2]|0)==(t[d>>2]|0)){C=33;break e}}else C=34;if((C|0)==34?(C=0,t[(t[(t[k>>2]|0)+8>>2]|0)+(t[p>>2]<<2)>>2]=0,(t[(t[R>>2]|0)+4>>2]|0)==18):0)Rn(t[R>>2]|0);if(t[A>>2]|0){zt(t[(t[l>>2]|0)+12>>2]|0,t[A>>2]|0);t[A>>2]=0}if((t[(t[l>>2]|0)+16>>2]|0)==(t[O>>2]|0)){En(t[l>>2]|0)|0;Zu(t[(t[O>>2]|0)+4>>2]|0,t[v>>2]|0);break}else{t[O>>2]=0;break}}while(0);t[p>>2]=(t[p>>2]|0)+1}if((C|0)==19)t[(t[l>>2]|0)+8>>2]=15;else if((C|0)==21){while(1){C=0;if((t[L>>2]|0)==(t[O>>2]|0))break;zt(t[N>>2]|0,t[L>>2]|0);t[L>>2]=En(t[l>>2]|0)|0;C=21}Zu(t[k>>2]|0,t[v>>2]|0);t[S>>2]=0}else if((C|0)==29){if((t[(t[R>>2]|0)+4>>2]|0)==18)t[(t[(t[k>>2]|0)+8>>2]|0)+(t[p>>2]<<2)>>2]=0;
	Zu(t[k>>2]|0,t[v>>2]|0);t[t[k>>2]>>2]=1;t[t[(t[k>>2]|0)+8>>2]>>2]=t[R>>2]}else if((C|0)==33)ca(t[k>>2]|0,(t[p>>2]|0)+1|0,t[v>>2]|0);if(t[O>>2]|0){if((t[(t[l>>2]|0)+16>>2]|0)==(t[O>>2]|0))En(t[l>>2]|0)|0;zt(t[N>>2]|0,t[O>>2]|0)}if(t[A>>2]|0)zt(t[(t[l>>2]|0)+12>>2]|0,t[A>>2]|0);t[(t[N>>2]|0)+4>>2]=t[M>>2];t[t[N>>2]>>2]=t[_>>2];t[(t[N>>2]|0)+68>>2]=-1;t[(t[N>>2]|0)+72>>2]=-1;t[c>>2]=t[S>>2];D=t[c>>2]|0;s=o;return D|0}function fa(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;var u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0,S=0,g=0,y=0,F=0,O=0,A=0;u=s;s=s+80|0;a=u+68|0;o=u+64|0;c=u+60|0;l=u+56|0;b=u+52|0;k=u+48|0;h=u+44|0;w=u+40|0;d=u+36|0;v=u+32|0;m=u+28|0;_=u+24|0;p=u+20|0;E=u+16|0;S=u+12|0;g=u+8|0;y=u+4|0;F=u;t[o>>2]=e;t[c>>2]=i;t[l>>2]=r;t[b>>2]=n;t[k>>2]=f;if((t[(t[c>>2]|0)+4>>2]|0)!=-1){t[h>>2]=t[(t[o>>2]|0)+32>>2];t[b>>2]=fa(t[o>>2]|0,(t[(t[h>>2]|0)+8>>2]|0)+((t[(t[c>>2]|0)+4>>2]|0)*40|0)|0,t[l>>2]|0,t[b>>2]|0,t[k>>2]|0)|0;if(t[(t[o>>2]|0)+8>>2]|0){t[a>>2]=0;O=t[a>>2]|0;s=u;return O|0}if((t[b>>2]|0)<=0){t[a>>2]=0;O=t[a>>2]|0;s=u;return O|0}}if((t[(t[c>>2]|0)+8>>2]|0)==-1){t[a>>2]=t[b>>2];O=t[a>>2]|0;s=u;return O|0}t[w>>2]=t[(t[o>>2]|0)+12>>2];t[E>>2]=0;t[y>>2]=0;t[F>>2]=0;t[v>>2]=t[(t[w>>2]|0)+4>>2];t[m>>2]=t[t[w>>2]>>2];t[g>>2]=(t[(t[(t[o>>2]|0)+32>>2]|0)+8>>2]|0)+((t[(t[c>>2]|0)+8>>2]|0)*40|0);t[S>>2]=0;t[_>>2]=0;e:while(1){if((t[_>>2]|0)>=(t[t[l>>2]>>2]|0)){A=27;break}do if(t[(t[(t[l>>2]|0)+8>>2]|0)+(t[_>>2]<<2)>>2]|0){t[d>>2]=t[(t[(t[l>>2]|0)+8>>2]|0)+(t[_>>2]<<2)>>2];t[(t[w>>2]|0)+4>>2]=t[d>>2];t[(t[w>>2]|0)+68>>2]=t[b>>2];c=(t[E>>2]|0)+1|0;t[E>>2]=c;t[(t[w>>2]|0)+72>>2]=c;if((t[(t[d>>2]|0)+4>>2]|0)!=18?(t[(t[d>>2]|0)+32>>2]|0)!=0:0)t[t[w>>2]>>2]=t[(t[d>>2]|0)+32>>2];if(t[y>>2]|0){if((Cn(t[(t[y>>2]|0)+4>>2]|0,t[d>>2]|0)|0)<0){A=16;break e}}else t[y>>2]=ru(t[w>>2]|0,t[d>>2]|0)|0;Sn(t[o>>2]|0,t[y>>2]|0)|0;t[p>>2]=xu(t[o>>2]|0,t[g>>2]|0,1)|0;if((t[p>>2]|0)==-1?1:(t[(t[o>>2]|0)+8>>2]|0)!=0){A=18;break e}if(!(t[p>>2]|0)){t[(t[(t[l>>2]|0)+8>>2]|0)+(t[_>>2]<<2)>>2]=0;if((t[(t[d>>2]|0)+4>>2]|0)==18)Rn(t[d>>2]|0)}else t[S>>2]=(t[S>>2]|0)+1;if((t[(t[o>>2]|0)+16>>2]|0)==(t[y>>2]|0)){En(t[o>>2]|0)|0;Zu(t[(t[y>>2]|0)+4>>2]|0,t[k>>2]|0);break}else{t[y>>2]=0;break}}while(0);t[_>>2]=(t[_>>2]|0)+1}if((A|0)==16)t[(t[o>>2]|0)+8>>2]=15;else if((A|0)==18){Zu(t[l>>2]|0,t[k>>2]|0);t[S>>2]=0}else if((A|0)==27?(t[y>>2]|0)!=0:0){if((t[(t[o>>2]|0)+16>>2]|0)==(t[y>>2]|0))En(t[o>>2]|0)|0;zt(t[w>>2]|0,t[y>>2]|0)}if(t[F>>2]|0)zt(t[(t[o>>2]|0)+12>>2]|0,t[F>>2]|0);t[(t[w>>2]|0)+4>>2]=t[v>>2];t[t[w>>2]>>2]=t[m>>2];t[(t[w>>2]|0)+68>>2]=-1;t[(t[w>>2]|0)+72>>2]=-1;t[a>>2]=t[S>>2];O=t[a>>2]|0;s=u;return O|0}function ta(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i+4|0;n=i;t[r>>2]=e;if(t[32574]|0){s=i;return}t[n>>2]=t[(t[r>>2]|0)+4>>2];t[(t[r>>2]|0)+4>>2]=t[(t[r>>2]|0)+8>>2];t[(t[r>>2]|0)+8>>2]=t[n>>2];s=i;return}function ua(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0,S=0,g=0,y=0,F=0,O=0,A=0;n=s;s=s+80|0;f=n+72|0;u=n+68|0;a=n+64|0;o=n+60|0;c=n+56|0;l=n+52|0;b=n+48|0;k=n+44|0;h=n+40|0;w=n+36|0;d=n+32|0;v=n+28|0;m=n+24|0;_=n+20|0;p=n+16|0;E=n+12|0;S=n+8|0;g=n+4|0;y=n;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;t[c>>2]=0;if(t[(t[u>>2]|0)+8>>2]|0){t[f>>2]=0;F=t[f>>2]|0;s=n;return F|0}t[l>>2]=t[(t[u>>2]|0)+32>>2];if((((((((((t[(t[a>>2]|0)+4>>2]|0)!=-1?(t[(t[a>>2]|0)+8>>2]|0)!=-1:0)?(t[(t[(t[l>>2]|0)+8>>2]|0)+((t[(t[a>>2]|0)+4>>2]|0)*40|0)>>2]|0)==18:0)?(t[(t[(t[l>>2]|0)+8>>2]|0)+((t[(t[a>>2]|0)+8>>2]|0)*40|0)>>2]|0)==18:0)?(t[m>>2]=t[(t[(t[l>>2]|0)+8>>2]|0)+((t[(t[a>>2]|0)+8>>2]|0)*40|0)+4>>2],(t[m>>2]|0)!=-1):0)?(t[(t[(t[l>>2]|0)+8>>2]|0)+((t[m>>2]|0)*40|0)>>2]|0)==14:0)?(t[(t[(t[l>>2]|0)+8>>2]|0)+((t[m>>2]|0)*40|0)+28>>2]|0)==0:0)?(t[(t[(t[l>>2]|0)+8>>2]|0)+((t[m>>2]|0)*40|0)+12>>2]|0)==0:0)?(t[(t[(t[l>>2]|0)+8>>2]|0)+((t[m>>2]|0)*40|0)+24>>2]|0)!=0:0)?(Xl(t[(t[(t[l>>2]|0)+8>>2]|0)+((t[m>>2]|0)*40|0)+24>>2]|0,129656)|0)!=0:0){t[_>>2]=0;m=Xu(t[u>>2]|0,(t[(t[l>>2]|0)+8>>2]|0)+((t[(t[a>>2]|0)+4>>2]|0)*40|0)|0,_)|0;t[c>>2]=(t[c>>2]|0)+m;if(t[(t[u>>2]|0)+8>>2]|0){t[f>>2]=0;F=t[f>>2]|0;s=n;return F|0}if(((((t[(t[u>>2]|0)+16>>2]|0)!=0?(t[t[(t[u>>2]|0)+16>>2]>>2]|0)==1:0)?(t[(t[(t[u>>2]|0)+16>>2]|0)+4>>2]|0)!=0:0)?(t[(t[(t[(t[u>>2]|0)+16>>2]|0)+4>>2]|0)+8>>2]|0)!=0:0)?(t[t[(t[(t[u>>2]|0)+16>>2]|0)+4>>2]>>2]|0)>1:0){t[t[(t[(t[(t[u>>2]|0)+16>>2]|0)+4>>2]|0)+8>>2]>>2]=t[(t[(t[(t[(t[u>>2]|0)+16>>2]|0)+4>>2]|0)+8>>2]|0)+((t[t[(t[(t[u>>2]|0)+16>>2]|0)+4>>2]>>2]|0)-1<<2)>>2];t[t[(t[(t[u>>2]|0)+16>>2]|0)+4>>2]>>2]=1;t[t[o>>2]>>2]=t[t[(t[(t[(t[u>>2]|0)+16>>2]|0)+4>>2]|0)+8>>2]>>2]}t[f>>2]=t[c>>2];F=t[f>>2]|0;s=n;return F|0}if((t[(t[a>>2]|0)+4>>2]|0)!=-1){m=Uu(t[u>>2]|0,(t[(t[l>>2]|0)+8>>2]|0)+((t[(t[a>>2]|0)+4>>2]|0)*40|0)|0)|0;t[c>>2]=(t[c>>2]|0)+m}if(t[(t[u>>2]|0)+8>>2]|0){t[f>>2]=0;F=t[f>>2]|0;s=n;return F|0}if((t[(t[a>>2]|0)+8>>2]|0)==-1){t[f>>2]=t[c>>2];F=t[f>>2]|0;s=n;return F|0}if(!(t[(t[u>>2]|0)+16>>2]|0)){t[f>>2]=t[c>>2];F=t[f>>2]|0;s=n;return F|0}t[w>>2]=t[(t[(t[u>>2]|0)+12>>2]|0)+4>>2];if((t[t[(t[u>>2]|0)+16>>2]>>2]|0)!=7){if((t[(t[u>>2]|0)+16>>2]|0)!=0?(t[t[(t[u>>2]|0)+16>>2]>>2]|0)==1:0){t[k>>2]=En(t[u>>2]|0)|0;t[h>>2]=t[(t[k>>2]|0)+4>>2];t[w>>2]=t[(t[(t[u>>2]|0)+12>>2]|0)+4>>2];t[d>>2]=t[t[(t[u>>2]|0)+12>>2]>>2];t[(t[(t[u>>2]|0)+12>>2]|0)+4>>2]=0;if((t[h>>2]|0)!=0?(t[t[h>>2]>>2]|0)!=0:0){t[y>>2]=0;t[g>>2]=Nn(0)|0;t[v>>2]=0;while(1){if((t[v>>2]|0)>=(t[t[h>>2]>>2]|0))break;t[(t[(t[u>>2]|0)+12>>2]|0)+4>>2]=t[(t[(t[h>>2]|0)+8>>2]|0)+(t[v>>2]<<2)>>2];if((t[(t[(t[(t[h>>2]|0)+8>>2]|0)+(t[v>>2]<<2)>>2]|0)+4>>2]|0)!=18?(t[(t[(t[(t[h>>2]|0)+8>>2]|0)+(t[v>>2]<<2)>>2]|0)+32>>2]|0)!=0:0)t[t[(t[u>>2]|0)+12>>2]>>2]=t[(t[(t[(t[h>>2]|0)+8>>2]|0)+(t[v>>2]<<2)>>2]|0)+32>>2];if(t[y>>2]|0){if((Cn(t[(t[y>>2]|0)+4>>2]|0,t[(t[(t[u>>2]|0)+12>>2]|0)+4>>2]|0)|0)<0)t[(t[u>>2]|0)+8>>2]=15}else t[y>>2]=ru(t[(t[u>>2]|0)+12>>2]|0,t[(t[(t[u>>2]|0)+12>>2]|0)+4>>2]|0)|0;Sn(t[u>>2]|0,t[y>>2]|0)|0;t[(t[(t[u>>2]|0)+12>>2]|0)+68>>2]=t[t[h>>2]>>2];t[(t[(t[u>>2]|0)+12>>2]|0)+72>>2]=(t[v>>2]|0)+1;if((t[(t[a>>2]|0)+8>>2]|0)!=-1){m=Uu(t[u>>2]|0,(t[(t[l>>2]|0)+8>>2]|0)+((t[(t[a>>2]|0)+8>>2]|0)*40|0)|0)|0;t[c>>2]=(t[c>>2]|0)+m}if(t[(t[u>>2]|0)+8>>2]|0){O=85;break}t[b>>2]=En(t[u>>2]|0)|0;do if(vt(t[u>>2]|0,t[b>>2]|0)|0){if((Dn(t[g>>2]|0,t[(t[(t[h>>2]|0)+8>>2]|0)+(t[v>>2]<<2)>>2]|0)|0)>=0)break;t[(t[u>>2]|0)+8>>2]=15}while(0);if(t[b>>2]|0)zt(t[(t[u>>2]|0)+12>>2]|0,t[b>>2]|0);if((t[(t[u>>2]|0)+16>>2]|0)==(t[y>>2]|0)){En(t[u>>2]|0)|0;Zu(t[(t[y>>2]|0)+4>>2]|0,1)}else t[y>>2]=0;t[(t[(t[u>>2]|0)+12>>2]|0)+4>>2]=0;if((t[t[g>>2]>>2]|0)>0){O=95;break}t[v>>2]=(t[v>>2]|0)+1}if((O|0)==85){Bn(t[g>>2]|0);_n(t[k>>2]|0);t[f>>2]=0;F=t[f>>2]|0;s=n;return F|0}else if((O|0)==95)t[t[o>>2]>>2]=t[t[(t[g>>2]|0)+8>>2]>>2];if(t[y>>2]|0)zt(t[(t[u>>2]|0)+12>>2]|0,t[y>>2]|0);zt(t[(t[u>>2]|0)+12>>2]|0,t[k>>2]|0);t[(t[(t[u>>2]|0)+12>>2]|0)+4>>2]=0;t[(t[(t[u>>2]|0)+12>>2]|0)+68>>2]=-1;t[(t[(t[u>>2]|0)+12>>2]|0)+72>>2]=-1;t[t[(t[u>>2]|0)+12>>2]>>2]=t[d>>2];d=t[u>>2]|0;Sn(d,fu(t[(t[u>>2]|0)+12>>2]|0,t[g>>2]|0)|0)|0}else O=71;if((O|0)==71?(t[(t[(t[u>>2]|0)+12>>2]|0)+68>>2]=0,t[(t[(t[u>>2]|0)+12>>2]|0)+72>>2]=0,Sn(t[u>>2]|0,t[k>>2]|0)|0,t[(t[(t[u>>2]|0)+12>>2]|0)+4>>2]=t[w>>2],(t[(t[u>>2]|0)+8>>2]|0)!=0):0){t[f>>2]=0;F=t[f>>2]|0;s=n;return F|0}t[(t[(t[u>>2]|0)+12>>2]|0)+4>>2]=t[w>>2];t[f>>2]=t[c>>2];F=t[f>>2]|0;s=n;return F|0}dn(t[u>>2]|0,11);t[f>>2]=0;F=t[f>>2]|0;s=n;return F|0}t[p>>2]=0;t[E>>2]=0;if((t[(t[u>>2]|0)+16>>2]|0)!=0?(t[t[(t[u>>2]|0)+16>>2]>>2]|0)==7:0){t[k>>2]=En(t[u>>2]|0)|0;t[S>>2]=t[(t[k>>2]|0)+28>>2];t[(t[(t[u>>2]|0)+12>>2]|0)+4>>2]=0;if((t[S>>2]|0)!=0?(t[t[S>>2]>>2]|0)!=0:0){t[E>>2]=Da(0)|0;t[v>>2]=0;while(1){if((t[v>>2]|0)>=(t[t[S>>2]>>2]|0))break;t[(t[(t[u>>2]|0)+12>>2]|0)+4>>2]=t[(t[(t[(t[S>>2]|0)+8>>2]|0)+(t[v>>2]<<2)>>2]|0)+28>>2];t[(t[(t[u>>2]|0)+12>>2]|0)+68>>2]=t[t[S>>2]>>2];t[(t[(t[u>>2]|0)+12>>2]|0)+72>>2]=(t[v>>2]|0)+1;if(t[p>>2]|0){if((Cn(t[(t[p>>2]|0)+4>>2]|0,t[(t[(t[u>>2]|0)+12>>2]|0)+4>>2]|0)|0)<0)t[(t[u>>2]|0)+8>>2]=15}else t[p>>2]=ru(t[(t[u>>2]|0)+12>>2]|0,t[(t[(t[u>>2]|0)+12>>2]|0)+4>>2]|0)|0;Sn(t[u>>2]|0,t[p>>2]|0)|0;if((t[(t[a>>2]|0)+8>>2]|0)!=-1){g=Uu(t[u>>2]|0,(t[(t[l>>2]|0)+8>>2]|0)+((t[(t[a>>2]|0)+8>>2]|0)*40|0)|0)|0;t[c>>2]=(t[c>>2]|0)+g}if(t[(t[u>>2]|0)+8>>2]|0){O=52;break}t[b>>2]=En(t[u>>2]|0)|0;if(vt(t[u>>2]|0,t[b>>2]|0)|0){g=t[E>>2]|0;Ca(g,Vt(t[(t[u>>2]|0)+12>>2]|0,t[(t[(t[S>>2]|0)+8>>2]|0)+(t[v>>2]<<2)>>2]|0)|0)}if(t[b>>2]|0)zt(t[(t[u>>2]|0)+12>>2]|0,t[b>>2]|0);if((t[(t[u>>2]|0)+16>>2]|0)==(t[p>>2]|0)){En(t[u>>2]|0)|0;Zu(t[(t[p>>2]|0)+4>>2]|0,1)}else t[p>>2]=0;t[(t[(t[u>>2]|0)+12>>2]|0)+4>>2]=0;A=t[v>>2]|0;if((t[t[E>>2]>>2]|0)>0){O=61;break}t[v>>2]=A+1}if((O|0)==52){_n(t[k>>2]|0);t[f>>2]=0;F=t[f>>2]|0;s=n;return F|0}else if((O|0)==61)t[t[o>>2]>>2]=t[(t[(t[(t[S>>2]|0)+8>>2]|0)+(A<<2)>>2]|0)+28>>2];if(t[p>>2]|0)zt(t[(t[u>>2]|0)+12>>2]|0,t[p>>2]|0);zt(t[(t[u>>2]|0)+12>>2]|0,t[k>>2]|0);t[(t[(t[u>>2]|0)+12>>2]|0)+4>>2]=0;t[(t[(t[u>>2]|0)+12>>2]|0)+68>>2]=-1;t[(t[(t[u>>2]|0)+12>>2]|0)+72>>2]=-1;p=t[u>>2]|0;Sn(p,xa(t[E>>2]|0)|0)|0;t[(t[(t[u>>2]|0)+12>>2]|0)+4>>2]=t[w>>2];t[f>>2]=t[c>>2];F=t[f>>2]|0;s=n;return F|0}t[(t[(t[u>>2]|0)+12>>2]|0)+68>>2]=0;t[(t[(t[u>>2]|0)+12>>2]|0)+72>>2]=0;if((t[(t[a>>2]|0)+8>>2]|0)!=-1){w=Uu(t[u>>2]|0,(t[(t[l>>2]|0)+8>>2]|0)+((t[(t[a>>2]|0)+8>>2]|0)*40|0)|0)|0;t[c>>2]=(t[c>>2]|0)+w}t[b>>2]=En(t[u>>2]|0)|0;if(t[b>>2]|0)zt(t[(t[u>>2]|0)+12>>2]|0,t[b>>2]|0);Sn(t[u>>2]|0,t[k>>2]|0)|0;if(t[(t[u>>2]|0)+8>>2]|0){t[f>>2]=0;F=t[f>>2]|0;s=n;return F|0}else{t[f>>2]=t[c>>2];F=t[f>>2]|0;s=n;return F|0}}dn(t[u>>2]|0,11);t[f>>2]=0;F=t[f>>2]|0;s=n;return F|0}function aa(e){e=e|0;var i=0,r=0,n=0,f=0,a=0,o=0,c=0;i=s;s=s+16|0;r=i+8|0;n=i+4|0;f=i;t[r>>2]=e;la(t[r>>2]|0);if(t[(t[r>>2]|0)+8>>2]|0){s=i;return}e:while(1){do if((u[t[t[r>>2]>>2]>>0]|0|0)!=32){if(9<=(u[t[t[r>>2]>>2]>>0]|0|0)?(u[t[t[r>>2]>>2]>>0]|0|0)<=10:0)break;if((u[t[t[r>>2]>>2]>>0]|0|0)!=13)break e}while(0);e=t[r>>2]|0;if(!(u[t[t[r>>2]>>2]>>0]|0))continue;t[e>>2]=(t[e>>2]|0)+1}e:while(1){if((u[t[t[r>>2]>>2]>>0]|0|0)!=43?(u[t[t[r>>2]>>2]>>0]|0|0)!=45:0){a=30;break}t[f>>2]=t[(t[(t[r>>2]|0)+32>>2]|0)+12>>2];if((u[t[t[r>>2]>>2]>>0]|0|0)==43)t[n>>2]=1;else t[n>>2]=0;e=t[r>>2]|0;if(u[t[t[r>>2]>>2]>>0]|0)t[e>>2]=(t[e>>2]|0)+1;while(1){do if((u[t[t[r>>2]>>2]>>0]|0|0)==32)o=1;else{if(9<=(u[t[t[r>>2]>>2]>>0]|0|0)?(u[t[t[r>>2]>>2]>>0]|0|0)<=10:0){o=1;break}o=(u[t[t[r>>2]>>2]>>0]|0|0)==13}while(0);c=t[r>>2]|0;if(!o)break;e=t[r>>2]|0;if(!(u[t[c>>2]>>0]|0))continue;t[e>>2]=(t[e>>2]|0)+1}la(c);if(t[(t[r>>2]|0)+8>>2]|0){a=30;break}Pu(t[(t[r>>2]|0)+32>>2]|0,t[f>>2]|0,t[(t[(t[r>>2]|0)+32>>2]|0)+12>>2]|0,5,t[n>>2]|0,0,0,0,0)|0;while(1){do if((u[t[t[r>>2]>>2]>>0]|0|0)!=32){if(9<=(u[t[t[r>>2]>>2]>>0]|0|0)?(u[t[t[r>>2]>>2]>>0]|0|0)<=10:0)break;if((u[t[t[r>>2]>>2]>>0]|0|0)!=13)continue e}while(0);e=t[r>>2]|0;if(!(u[t[t[r>>2]>>2]>>0]|0))continue;t[e>>2]=(t[e>>2]|0)+1}}if((a|0)==30){s=i;return}}function oa(e){e=e|0;var i=0,r=0,n=0,f=0,u=0;i=s;s=s+16|0;r=i+8|0;n=i+4|0;f=i;t[n>>2]=e;t[f>>2]=gAi[t[135744>>2]&511](12)|0;if(!(t[f>>2]|0)){Ut(0,128632);t[r>>2]=0;u=t[r>>2]|0;s=i;return u|0}e=t[f>>2]|0;t[e+0>>2]=0;t[e+4>>2]=0;t[e+8>>2]=0;if((t[n>>2]|0)<10)t[n>>2]=10;e=gAi[t[135744>>2]&511](t[n>>2]<<2)|0;t[(t[f>>2]|0)+8>>2]=e;if(!(t[(t[f>>2]|0)+8>>2]|0)){Ut(0,128632);pAi[t[135736>>2]&511](t[f>>2]|0);t[r>>2]=0;u=t[r>>2]|0;s=i;return u|0}else{VY(t[(t[f>>2]|0)+8>>2]|0,0,t[n>>2]<<2|0)|0;t[(t[f>>2]|0)+4>>2]=t[n>>2];t[r>>2]=t[f>>2];u=t[r>>2]|0;s=i;return u|0}return 0}function ca(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0;n=s;s=s+32|0;f=n+16|0;u=n+12|0;a=n+8|0;o=n+4|0;c=n;t[f>>2]=e;t[u>>2]=i;t[a>>2]=r;if(!(t[f>>2]|0)){s=n;return}if((t[t[f>>2]>>2]|0)<=0){s=n;return}if((t[u>>2]|0)>=(t[t[f>>2]>>2]|0)){s=n;return}e:do if(t[a>>2]|0){t[o>>2]=t[u>>2];while(1){if((t[o>>2]|0)>=(t[t[f>>2]>>2]|0))break e;t[c>>2]=t[(t[(t[f>>2]|0)+8>>2]|0)+(t[o>>2]<<2)>>2];if((t[c>>2]|0)!=0?(t[(t[c>>2]|0)+4>>2]|0)==18:0)Rn(t[c>>2]|0);t[o>>2]=(t[o>>2]|0)+1}}while(0);t[t[f>>2]>>2]=t[u>>2];s=n;return}function la(e){e=e|0;var i=0,r=0,n=0,f=0,a=0,o=0,c=0;i=s;s=s+16|0;r=i+8|0;n=i+4|0;f=i;t[r>>2]=e;sa(t[r>>2]|0);if(t[(t[r>>2]|0)+8>>2]|0){s=i;return}e:while(1){do if((u[t[t[r>>2]>>2]>>0]|0|0)!=32){if(9<=(u[t[t[r>>2]>>2]>>0]|0|0)?(u[t[t[r>>2]>>2]>>0]|0|0)<=10:0)break;if((u[t[t[r>>2]>>2]>>0]|0|0)!=13)break e}while(0);e=t[r>>2]|0;if(!(u[t[t[r>>2]>>2]>>0]|0))continue;t[e>>2]=(t[e>>2]|0)+1}e:while(1){do if((u[t[t[r>>2]>>2]>>0]|0|0)!=42){if(((u[t[t[r>>2]>>2]>>0]|0|0)==100?(u[(t[t[r>>2]>>2]|0)+1>>0]|0|0)==105:0)?(u[(t[t[r>>2]>>2]|0)+2>>0]|0|0)==118:0)break;if((u[t[t[r>>2]>>2]>>0]|0|0)!=109){a=37;break e}if((u[(t[t[r>>2]>>2]|0)+1>>0]|0|0)!=111){a=37;break e}if((u[(t[t[r>>2]>>2]|0)+2>>0]|0|0)!=100){a=37;break e}}while(0);t[n>>2]=-1;t[f>>2]=t[(t[(t[r>>2]|0)+32>>2]|0)+12>>2];do if((u[t[t[r>>2]>>2]>>0]|0|0)==42){t[n>>2]=0;e=t[r>>2]|0;if(u[t[t[r>>2]>>2]>>0]|0)t[e>>2]=(t[e>>2]|0)+1}else{if((u[t[t[r>>2]>>2]>>0]|0|0)==100){t[n>>2]=1;e=t[r>>2]|0;t[e>>2]=(t[e>>2]|0)+3;break}if((u[t[t[r>>2]>>2]>>0]|0|0)==109){t[n>>2]=2;e=t[r>>2]|0;t[e>>2]=(t[e>>2]|0)+3}}while(0);while(1){do if((u[t[t[r>>2]>>2]>>0]|0|0)==32)o=1;else{if(9<=(u[t[t[r>>2]>>2]>>0]|0|0)?(u[t[t[r>>2]>>2]>>0]|0|0)<=10:0){o=1;break}o=(u[t[t[r>>2]>>2]>>0]|0|0)==13}while(0);c=t[r>>2]|0;if(!o)break;e=t[r>>2]|0;if(!(u[t[c>>2]>>0]|0))continue;t[e>>2]=(t[e>>2]|0)+1}sa(c);if(t[(t[r>>2]|0)+8>>2]|0){a=37;break}Pu(t[(t[r>>2]|0)+32>>2]|0,t[f>>2]|0,t[(t[(t[r>>2]|0)+32>>2]|0)+12>>2]|0,6,t[n>>2]|0,0,0,0,0)|0;while(1){do if((u[t[t[r>>2]>>2]>>0]|0|0)!=32){if(9<=(u[t[t[r>>2]>>2]>>0]|0|0)?(u[t[t[r>>2]>>2]>>0]|0|0)<=10:0)break;if((u[t[t[r>>2]>>2]>>0]|0|0)!=13)continue e}while(0);e=t[r>>2]|0;if(!(u[t[t[r>>2]>>2]>>0]|0))continue;t[e>>2]=(t[e>>2]|0)+1}}if((a|0)==37){s=i;return}}function sa(e){e=e|0;var i=0,r=0,n=0,f=0;i=s;s=s+16|0;r=i+8|0;n=i+4|0;f=i;t[r>>2]=e;t[n>>2]=0;t[f>>2]=0;e:while(1){do if((u[t[t[r>>2]>>2]>>0]|0|0)!=32){if(9<=(u[t[t[r>>2]>>2]>>0]|0|0)?(u[t[t[r>>2]>>2]>>0]|0|0)<=10:0)break;if((u[t[t[r>>2]>>2]>>0]|0|0)!=13)break e}while(0);e=t[r>>2]|0;if(!(u[t[t[r>>2]>>2]>>0]|0))continue;t[e>>2]=(t[e>>2]|0)+1}e:while(1){if((u[t[t[r>>2]>>2]>>0]|0|0)!=45)break;t[n>>2]=1-(t[n>>2]|0);t[f>>2]=1;e=t[r>>2]|0;if(u[t[t[r>>2]>>2]>>0]|0)t[e>>2]=(t[e>>2]|0)+1;while(1){do if((u[t[t[r>>2]>>2]>>0]|0|0)!=32){if(9<=(u[t[t[r>>2]>>2]>>0]|0|0)?(u[t[t[r>>2]>>2]>>0]|0|0)<=10:0)break;if((u[t[t[r>>2]>>2]>>0]|0|0)!=13)continue e}while(0);e=t[r>>2]|0;if(!(u[t[t[r>>2]>>2]>>0]|0))continue;t[e>>2]=(t[e>>2]|0)+1}}ba(t[r>>2]|0);if(!((t[f>>2]|0)!=0?(t[(t[r>>2]|0)+8>>2]|0)==0:0)){s=i;return}f=t[(t[r>>2]|0)+32>>2]|0;e=t[(t[(t[r>>2]|0)+32>>2]|0)+12>>2]|0;if(t[n>>2]|0){Pu(f,e,-1,5,2,0,0,0,0)|0;s=i;return}else{Pu(f,e,-1,5,3,0,0,0,0)|0;s=i;return}}function ba(e){e=e|0;var i=0,r=0,n=0,f=0,a=0;i=s;s=s+16|0;r=i+4|0;n=i;t[r>>2]=e;ka(t[r>>2]|0);if(t[(t[r>>2]|0)+8>>2]|0){s=i;return}e:while(1){do if((u[t[t[r>>2]>>2]>>0]|0|0)!=32){if(9<=(u[t[t[r>>2]>>2]>>0]|0|0)?(u[t[t[r>>2]>>2]>>0]|0|0)<=10:0)break;if((u[t[t[r>>2]>>2]>>0]|0|0)!=13)break e}while(0);e=t[r>>2]|0;if(!(u[t[t[r>>2]>>2]>>0]|0))continue;t[e>>2]=(t[e>>2]|0)+1}e:while(1){if((u[t[t[r>>2]>>2]>>0]|0|0)!=124)break;t[n>>2]=t[(t[(t[r>>2]|0)+32>>2]|0)+12>>2];Pu(t[(t[r>>2]|0)+32>>2]|0,-1,-1,9,0,0,0,0,0)|0;e=t[r>>2]|0;if(u[t[t[r>>2]>>2]>>0]|0)t[e>>2]=(t[e>>2]|0)+1;while(1){do if((u[t[t[r>>2]>>2]>>0]|0|0)==32)f=1;else{if(9<=(u[t[t[r>>2]>>2]>>0]|0|0)?(u[t[t[r>>2]>>2]>>0]|0|0)<=10:0){f=1;break}f=(u[t[t[r>>2]>>2]>>0]|0|0)==13}while(0);a=t[r>>2]|0;if(!f)break;e=t[r>>2]|0;if(!(u[t[a>>2]>>0]|0))continue;t[e>>2]=(t[e>>2]|0)+1}ka(a);Pu(t[(t[r>>2]|0)+32>>2]|0,t[n>>2]|0,t[(t[(t[r>>2]|0)+32>>2]|0)+12>>2]|0,7,0,0,0,0,0)|0;while(1){do if((u[t[t[r>>2]>>2]>>0]|0|0)!=32){if(9<=(u[t[t[r>>2]>>2]>>0]|0|0)?(u[t[t[r>>2]>>2]>>0]|0|0)<=10:0)break;if((u[t[t[r>>2]>>2]>>0]|0|0)!=13)continue e}while(0);e=t[r>>2]|0;if(!(u[t[t[r>>2]>>2]>>0]|0))continue;t[e>>2]=(t[e>>2]|0)+1}}s=i;return}function ka(e){e=e|0;var i=0,r=0,n=0,f=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0;i=s;s=s+16|0;r=i+12|0;n=i+8|0;f=i+4|0;a=i;t[r>>2]=e;t[n>>2]=1;t[f>>2]=0;while(1){do if((u[t[t[r>>2]>>2]>>0]|0|0)==32)o=1;else{if(9<=(u[t[t[r>>2]>>2]>>0]|0|0)?(u[t[t[r>>2]>>2]>>0]|0|0)<=10:0){o=1;break}o=(u[t[t[r>>2]>>2]>>0]|0|0)==13}while(0);c=u[t[t[r>>2]>>2]>>0]|0;if(!o)break;e=t[r>>2]|0;if(!c)continue;t[e>>2]=(t[e>>2]|0)+1}do if((c|0)!=36?(u[t[t[r>>2]>>2]>>0]|0|0)!=40:0){if(48<=(u[t[t[r>>2]>>2]>>0]|0|0)?(u[t[t[r>>2]>>2]>>0]|0|0)<=57:0){l=18;break}if((u[t[t[r>>2]>>2]>>0]|0|0)!=39?(u[t[t[r>>2]>>2]>>0]|0|0)!=34:0){if(((u[t[t[r>>2]>>2]>>0]|0|0)==46?48<=(u[(t[t[r>>2]>>2]|0)+1>>0]|0|0):0)?(u[(t[t[r>>2]>>2]|0)+1>>0]|0|0)<=57:0){l=18;break}if((u[t[t[r>>2]>>2]>>0]|0|0)==42){t[n>>2]=1;break}if((u[t[t[r>>2]>>2]>>0]|0|0)==47){t[n>>2]=1;break}if((u[t[t[r>>2]>>2]>>0]|0|0)==64){t[n>>2]=1;break}if((u[t[t[r>>2]>>2]>>0]|0|0)==46){t[n>>2]=1;break}while(1){do if((u[t[t[r>>2]>>2]>>0]|0|0)==32)b=1;else{if(9<=(u[t[t[r>>2]>>2]>>0]|0|0)?(u[t[t[r>>2]>>2]>>0]|0|0)<=10:0){b=1;break}b=(u[t[t[r>>2]>>2]>>0]|0|0)==13}while(0);k=t[r>>2]|0;if(!b)break;o=t[r>>2]|0;if(!(u[t[k>>2]>>0]|0))continue;t[o>>2]=(t[o>>2]|0)+1}t[f>>2]=ha(k)|0;if((t[f>>2]|0)!=0?(is(t[f>>2]|0,130432)|0)!=0:0){t[n>>2]=1;pAi[t[135736>>2]&511](t[f>>2]|0);break}if(!(t[f>>2]|0)){dn(t[r>>2]|0,7);s=i;return}t[a>>2]=rs(t[f>>2]|0)|0;e:while(1){if(!(u[(t[t[r>>2]>>2]|0)+(t[a>>2]|0)>>0]|0))break;if((u[(t[t[r>>2]>>2]|0)+(t[a>>2]|0)>>0]|0|0)==47){l=41;break}do if((u[(t[t[r>>2]>>2]|0)+(t[a>>2]|0)>>0]|0|0)!=32){if(9<=(u[(t[t[r>>2]>>2]|0)+(t[a>>2]|0)>>0]|0|0)?(u[(t[t[r>>2]>>2]|0)+(t[a>>2]|0)>>0]|0|0)<=10:0)break;if((u[(t[t[r>>2]>>2]|0)+(t[a>>2]|0)>>0]|0|0)!=13){l=46;break e}}while(0);t[a>>2]=(t[a>>2]|0)+1}e:do if((l|0)==41)t[n>>2]=1;else if((l|0)==46){if((u[(t[t[r>>2]>>2]|0)+(t[a>>2]|0)>>0]|0|0)==58){t[n>>2]=1;break}if((u[(t[t[r>>2]>>2]|0)+(t[a>>2]|0)>>0]|0|0)==40)if(dt(t[f>>2]|0)|0){t[n>>2]=1;break}else{t[n>>2]=0;break}if((u[(t[t[r>>2]>>2]|0)+(t[a>>2]|0)>>0]|0|0)==91){t[n>>2]=1;break}do if((u[(t[t[r>>2]>>2]|0)+(t[a>>2]|0)>>0]|0|0)!=60?(u[(t[t[r>>2]>>2]|0)+(t[a>>2]|0)>>0]|0|0)!=62:0){if((u[(t[t[r>>2]>>2]|0)+(t[a>>2]|0)>>0]|0|0)==61)break;t[n>>2]=1;break e}while(0);t[n>>2]=1}while(0);if(!(u[(t[t[r>>2]>>2]|0)+(t[a>>2]|0)>>0]|0))t[n>>2]=1;pAi[t[135736>>2]&511](t[f>>2]|0)}else l=18}else l=18;while(0);if((l|0)==18)t[n>>2]=0;l=t[r>>2]|0;do if(!(t[n>>2]|0)){da(l);if(t[(t[r>>2]|0)+8>>2]|0){s=i;return}if((u[t[t[r>>2]>>2]>>0]|0|0)==47?(u[(t[t[r>>2]>>2]|0)+1>>0]|0|0)==47:0){f=t[r>>2]|0;t[f>>2]=(t[f>>2]|0)+2;while(1){do if((u[t[t[r>>2]>>2]>>0]|0|0)==32)h=1;else{if(9<=(u[t[t[r>>2]>>2]>>0]|0|0)?(u[t[t[r>>2]>>2]>>0]|0|0)<=10:0){h=1;break}h=(u[t[t[r>>2]>>2]>>0]|0|0)==13}while(0);w=t[r>>2]|0;if(!h)break;f=t[r>>2]|0;if(!(u[t[w>>2]>>0]|0))continue;t[f>>2]=(t[f>>2]|0)+1}Pu(t[w+32>>2]|0,t[(t[(t[r>>2]|0)+32>>2]|0)+12>>2]|0,-1,11,6,1,0,0,0)|0;Pu(t[(t[r>>2]|0)+32>>2]|0,t[(t[(t[r>>2]|0)+32>>2]|0)+12>>2]|0,-1,10,1,0,0,0,0)|0;va(t[r>>2]|0);break}if((u[t[t[r>>2]>>2]>>0]|0|0)==47)va(t[r>>2]|0)}else{f=t[(t[r>>2]|0)+32>>2]|0;if((u[t[l>>2]>>0]|0|0)==47)Pu(f,-1,-1,8,0,0,0,0,0)|0;else Pu(f,-1,-1,9,0,0,0,0,0)|0;wa(t[r>>2]|0)}while(0);e:while(1){do if((u[t[t[r>>2]>>2]>>0]|0|0)!=32){if(9<=(u[t[t[r>>2]>>2]>>0]|0|0)?(u[t[t[r>>2]>>2]>>0]|0|0)<=10:0)break;if((u[t[t[r>>2]>>2]>>0]|0|0)!=13)break e}while(0);l=t[r>>2]|0;if(!(u[t[t[r>>2]>>2]>>0]|0))continue;t[l>>2]=(t[l>>2]|0)+1}s=i;return}function ha(e){e=e|0;var i=0,r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0;i=s;s=s+32|0;r=i+24|0;n=i+20|0;f=i+16|0;u=i+12|0;a=i+8|0;o=i+4|0;c=i;t[n>>2]=e;t[f>>2]=0;t[o>>2]=t[t[n>>2]>>2];t[a>>2]=Du(t[n>>2]|0,u)|0;e:do if(!((t[a>>2]|0)==32|(t[a>>2]|0)==62|(t[a>>2]|0)==47)){e=t[a>>2]|0;if((t[a>>2]|0)<256){if(((!(65<=(e|0)&(t[a>>2]|0)<=90)?!(97<=(t[a>>2]|0)&(t[a>>2]|0)<=122):0)?!(192<=(t[a>>2]|0)&(t[a>>2]|0)<=214):0)?!(216<=(t[a>>2]|0)&(t[a>>2]|0)<=246|248<=(t[a>>2]|0)):0)l=8}else if(!(dj(e,199744)|0))l=8;do if((l|0)==8){e=t[a>>2]|0;if((t[a>>2]|0)<256)if((e|0)!=95&(t[a>>2]|0)!=58)break e;else break;if(!(19968<=(e|0)&(t[a>>2]|0)<=40869|(t[a>>2]|0)==12295)?(12321<=(t[a>>2]|0)&(t[a>>2]|0)<=12329^1)&(t[a>>2]|0)!=95&(t[a>>2]|0)!=58:0)break e}while(0);i:while(1){if(!((t[a>>2]|0)!=32&(t[a>>2]|0)!=62&(t[a>>2]|0)!=47))break;e=t[a>>2]|0;if((t[a>>2]|0)<256){if(((!(65<=(e|0)&(t[a>>2]|0)<=90)?!(97<=(t[a>>2]|0)&(t[a>>2]|0)<=122):0)?!(192<=(t[a>>2]|0)&(t[a>>2]|0)<=214):0)?!(216<=(t[a>>2]|0)&(t[a>>2]|0)<=246|248<=(t[a>>2]|0)):0)l=20}else if(!(dj(e,199744)|0))l=20;do if((l|0)==20){l=0;if((t[a>>2]|0)>=256){if(19968<=(t[a>>2]|0)&(t[a>>2]|0)<=40869|(t[a>>2]|0)==12295)break;if(12321<=(t[a>>2]|0)&(t[a>>2]|0)<=12329)break}e=t[a>>2]|0;if((t[a>>2]|0)<256){if(48<=(e|0)&(t[a>>2]|0)<=57|(t[a>>2]|0)==46|(t[a>>2]|0)==45|(t[a>>2]|0)==95|(t[a>>2]|0)==58)break}else{b=(dj(e,200216)|0)!=0;if(b|(t[a>>2]|0)==46|(t[a>>2]|0)==45|(t[a>>2]|0)==95|(t[a>>2]|0)==58)break}if((t[a>>2]|0)>=256?(dj(t[a>>2]|0,200144)|0)!=0:0)break;b=t[a>>2]|0;if((t[a>>2]|0)<256)k=(b|0)==183&1;else k=dj(b,200272)|0;if(!k)break i}while(0);t[f>>2]=(t[f>>2]|0)+(t[u>>2]|0);b=t[n>>2]|0;t[b>>2]=(t[b>>2]|0)+(t[u>>2]|0);t[a>>2]=Du(t[n>>2]|0,u)|0}t[c>>2]=ql(t[o>>2]|0,(t[t[n>>2]>>2]|0)-(t[o>>2]|0)|0)|0;t[t[n>>2]>>2]=t[o>>2];t[r>>2]=t[c>>2];h=t[r>>2]|0;s=i;return h|0}while(0);t[r>>2]=0;h=t[r>>2]|0;s=i;return h|0}function wa(e){e=e|0;var i=0,r=0,n=0,f=0,a=0,o=0,c=0,l=0,b=0;i=s;s=s+16|0;r=i;t[r>>2]=e;while(1){do if((u[t[t[r>>2]>>2]>>0]|0|0)==32)n=1;else{if(9<=(u[t[t[r>>2]>>2]>>0]|0|0)?(u[t[t[r>>2]>>2]>>0]|0|0)<=10:0){n=1;break}n=(u[t[t[r>>2]>>2]>>0]|0|0)==13}while(0);f=u[t[t[r>>2]>>2]>>0]|0;if(!n)break;e=t[r>>2]|0;if(!f)continue;t[e>>2]=(t[e>>2]|0)+1}if((f|0)!=47){va(t[r>>2]|0);s=i;return}while(1){if((u[t[t[r>>2]>>2]>>0]|0|0)!=47){a=44;break}if((u[t[t[r>>2]>>2]>>0]|0|0)==47?(u[(t[t[r>>2]>>2]|0)+1>>0]|0|0)==47:0){f=t[r>>2]|0;t[f>>2]=(t[f>>2]|0)+2;while(1){do if((u[t[t[r>>2]>>2]>>0]|0|0)==32)o=1;else{if(9<=(u[t[t[r>>2]>>2]>>0]|0|0)?(u[t[t[r>>2]>>2]>>0]|0|0)<=10:0){o=1;break}o=(u[t[t[r>>2]>>2]>>0]|0|0)==13}while(0);c=t[r>>2]|0;if(!o)break;f=t[r>>2]|0;if(!(u[t[c>>2]>>0]|0))continue;t[f>>2]=(t[f>>2]|0)+1}Pu(t[c+32>>2]|0,t[(t[(t[r>>2]|0)+32>>2]|0)+12>>2]|0,-1,11,6,1,0,0,0)|0;va(t[r>>2]|0)}else a=23;e:do if((a|0)==23?(a=0,(u[t[t[r>>2]>>2]>>0]|0|0)==47):0){f=t[r>>2]|0;if(u[t[t[r>>2]>>2]>>0]|0)t[f>>2]=(t[f>>2]|0)+1;while(1){do if((u[t[t[r>>2]>>2]>>0]|0|0)==32)l=1;else{if(9<=(u[t[t[r>>2]>>2]>>0]|0|0)?(u[t[t[r>>2]>>2]>>0]|0|0)<=10:0){l=1;break}l=(u[t[t[r>>2]>>2]>>0]|0|0)==13}while(0);b=(u[t[t[r>>2]>>2]>>0]|0|0)!=0;if(!l)break;f=t[r>>2]|0;if(!b)continue;t[f>>2]=(t[f>>2]|0)+1}if(b){if(!(65<=(u[t[t[r>>2]>>2]>>0]|0|0)?(u[t[t[r>>2]>>2]>>0]|0|0)<=90:0))a=36;do if((a|0)==36){a=0;if(97<=(u[t[t[r>>2]>>2]>>0]|0|0)?(u[t[t[r>>2]>>2]>>0]|0|0)<=122:0)break;if((((u[t[t[r>>2]>>2]>>0]|0|0)!=95?(u[t[t[r>>2]>>2]>>0]|0|0)!=46:0)?(u[t[t[r>>2]>>2]>>0]|0|0)!=64:0)?(u[t[t[r>>2]>>2]>>0]|0|0)!=42:0)break e}while(0);va(t[r>>2]|0)}}while(0);if(t[(t[r>>2]|0)+8>>2]|0){a=44;break}}if((a|0)==44){s=i;return}}function da(e){e=e|0;var i=0,r=0;i=s;s=s+16|0;r=i;t[r>>2]=e;ma(t[r>>2]|0);if(t[(t[r>>2]|0)+8>>2]|0){s=i;return}e:while(1){do if((u[t[t[r>>2]>>2]>>0]|0|0)!=32){if(9<=(u[t[t[r>>2]>>2]>>0]|0|0)?(u[t[t[r>>2]>>2]>>0]|0|0)<=10:0)break;if((u[t[t[r>>2]>>2]>>0]|0|0)!=13)break e}while(0);e=t[r>>2]|0;if(!(u[t[t[r>>2]>>2]>>0]|0))continue;t[e>>2]=(t[e>>2]|0)+1}e:while(1){if((u[t[t[r>>2]>>2]>>0]|0|0)!=91)break;_a(t[r>>2]|0,1);while(1){do if((u[t[t[r>>2]>>2]>>0]|0|0)!=32){if(9<=(u[t[t[r>>2]>>2]>>0]|0|0)?(u[t[t[r>>2]>>2]>>0]|0|0)<=10:0)break;if((u[t[t[r>>2]>>2]>>0]|0|0)!=13)continue e}while(0);e=t[r>>2]|0;if(!(u[t[t[r>>2]>>2]>>0]|0))continue;t[e>>2]=(t[e>>2]|0)+1}}s=i;return}function va(e){e=e|0;var i=0,r=0,n=0,f=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0;i=s;s=s+16|0;r=i;t[r>>2]=e;while(1){do if((u[t[t[r>>2]>>2]>>0]|0|0)==32)n=1;else{if(9<=(u[t[t[r>>2]>>2]>>0]|0|0)?(u[t[t[r>>2]>>2]>>0]|0|0)<=10:0){n=1;break}n=(u[t[t[r>>2]>>2]>>0]|0|0)==13}while(0);f=u[t[t[r>>2]>>2]>>0]|0;if(!n)break;e=t[r>>2]|0;if(!f)continue;t[e>>2]=(t[e>>2]|0)+1}if((f|0)==47?(u[(t[t[r>>2]>>2]|0)+1>>0]|0|0)==47:0){f=t[r>>2]|0;t[f>>2]=(t[f>>2]|0)+2;while(1){do if((u[t[t[r>>2]>>2]>>0]|0|0)==32)a=1;else{if(9<=(u[t[t[r>>2]>>2]>>0]|0|0)?(u[t[t[r>>2]>>2]>>0]|0|0)<=10:0){a=1;break}a=(u[t[t[r>>2]>>2]>>0]|0|0)==13}while(0);o=t[r>>2]|0;if(!a)break;f=t[r>>2]|0;if(!(u[t[o>>2]>>0]|0))continue;t[f>>2]=(t[f>>2]|0)+1}Pu(t[o+32>>2]|0,t[(t[(t[r>>2]|0)+32>>2]|0)+12>>2]|0,-1,11,6,1,0,0,0)|0}else c=20;e:do if((c|0)==20?(u[t[t[r>>2]>>2]>>0]|0|0)==47:0){o=t[r>>2]|0;if(u[t[t[r>>2]>>2]>>0]|0)t[o>>2]=(t[o>>2]|0)+1;while(1){do if((u[t[t[r>>2]>>2]>>0]|0|0)!=32){if(9<=(u[t[t[r>>2]>>2]>>0]|0|0)?(u[t[t[r>>2]>>2]>>0]|0|0)<=10:0)break;if((u[t[t[r>>2]>>2]>>0]|0|0)!=13)break e}while(0);o=t[r>>2]|0;if(!(u[t[t[r>>2]>>2]>>0]|0))continue;t[o>>2]=(t[o>>2]|0)+1}}while(0);pa(t[r>>2]|0);if(t[(t[r>>2]|0)+8>>2]|0){s=i;return}e:while(1){do if((u[t[t[r>>2]>>2]>>0]|0|0)!=32){if(9<=(u[t[t[r>>2]>>2]>>0]|0|0)?(u[t[t[r>>2]>>2]>>0]|0|0)<=10:0)break;if((u[t[t[r>>2]>>2]>>0]|0|0)!=13)break e}while(0);o=t[r>>2]|0;if(!(u[t[t[r>>2]>>2]>>0]|0))continue;t[o>>2]=(t[o>>2]|0)+1}e:while(1){if((u[t[t[r>>2]>>2]>>0]|0|0)!=47)break;if((u[t[t[r>>2]>>2]>>0]|0|0)==47?(u[(t[t[r>>2]>>2]|0)+1>>0]|0|0)==47:0){o=t[r>>2]|0;t[o>>2]=(t[o>>2]|0)+2;while(1){do if((u[t[t[r>>2]>>2]>>0]|0|0)==32)l=1;else{if(9<=(u[t[t[r>>2]>>2]>>0]|0|0)?(u[t[t[r>>2]>>2]>>0]|0|0)<=10:0){l=1;break}l=(u[t[t[r>>2]>>2]>>0]|0|0)==13}while(0);b=t[r>>2]|0;if(!l)break;o=t[r>>2]|0;if(!(u[t[b>>2]>>0]|0))continue;t[o>>2]=(t[o>>2]|0)+1}Pu(t[b+32>>2]|0,t[(t[(t[r>>2]|0)+32>>2]|0)+12>>2]|0,-1,11,6,1,0,0,0)|0;pa(t[r>>2]|0)}else c=48;if((c|0)==48?(c=0,(u[t[t[r>>2]>>2]>>0]|0|0)==47):0){o=t[r>>2]|0;if(u[t[t[r>>2]>>2]>>0]|0)t[o>>2]=(t[o>>2]|0)+1;while(1){do if((u[t[t[r>>2]>>2]>>0]|0|0)==32)k=1;else{if(9<=(u[t[t[r>>2]>>2]>>0]|0|0)?(u[t[t[r>>2]>>2]>>0]|0|0)<=10:0){k=1;break}k=(u[t[t[r>>2]>>2]>>0]|0|0)==13}while(0);h=t[r>>2]|0;if(!k)break;o=t[r>>2]|0;if(!(u[t[h>>2]>>0]|0))continue;t[o>>2]=(t[o>>2]|0)+1}pa(h)}while(1){do if((u[t[t[r>>2]>>2]>>0]|0|0)!=32){if(9<=(u[t[t[r>>2]>>2]>>0]|0|0)?(u[t[t[r>>2]>>2]>>0]|0|0)<=10:0)break;if((u[t[t[r>>2]>>2]>>0]|0|0)!=13)continue e}while(0);o=t[r>>2]|0;if(!(u[t[t[r>>2]>>2]>>0]|0))continue;t[o>>2]=(t[o>>2]|0)+1}}s=i;return}function ma(e){e=e|0;var i=0,r=0,n=0,f=0,a=0,o=0,c=0,l=0;i=s;s=s+16|0;r=i;t[r>>2]=e;while(1){do if((u[t[t[r>>2]>>2]>>0]|0|0)==32)n=1;else{if(9<=(u[t[t[r>>2]>>2]>>0]|0|0)?(u[t[t[r>>2]>>2]>>0]|0|0)<=10:0){n=1;break}n=(u[t[t[r>>2]>>2]>>0]|0|0)==13}while(0);f=u[t[t[r>>2]>>2]>>0]|0;if(!n)break;e=t[r>>2]|0;if(!f)continue;t[e>>2]=(t[e>>2]|0)+1}n=t[r>>2]|0;e:do if((f|0)==36)Ea(n);else{e=u[t[t[r>>2]>>2]>>0]|0;if((u[t[n>>2]>>0]|0|0)!=40){if(!(48<=(e|0)?(u[t[t[r>>2]>>2]>>0]|0|0)<=57:0))a=34;do if((a|0)==34){if(((u[t[t[r>>2]>>2]>>0]|0|0)==46?48<=(u[(t[t[r>>2]>>2]|0)+1>>0]|0|0):0)?(u[(t[t[r>>2]>>2]|0)+1>>0]|0|0)<=57:0)break;if((u[t[t[r>>2]>>2]>>0]|0|0)!=39?(u[t[t[r>>2]>>2]>>0]|0|0)!=34:0){ya(t[r>>2]|0);break e}ga(t[r>>2]|0);break e}while(0);Sa(t[r>>2]|0);break}o=t[r>>2]|0;if(e)t[o>>2]=(t[o>>2]|0)+1;while(1){do if((u[t[t[r>>2]>>2]>>0]|0|0)==32)c=1;else{if(9<=(u[t[t[r>>2]>>2]>>0]|0|0)?(u[t[t[r>>2]>>2]>>0]|0|0)<=10:0){c=1;break}c=(u[t[t[r>>2]>>2]>>0]|0|0)==13}while(0);l=t[r>>2]|0;if(!c)break;o=t[r>>2]|0;if(!(u[t[l>>2]>>0]|0))continue;t[o>>2]=(t[o>>2]|0)+1}ku(l,1);if(t[(t[r>>2]|0)+8>>2]|0){s=i;return}e=t[r>>2]|0;if((u[t[t[r>>2]>>2]>>0]|0|0)!=41){dn(e,7);s=i;return}o=t[r>>2]|0;if(u[t[e>>2]>>0]|0)t[o>>2]=(t[o>>2]|0)+1;while(1){do if((u[t[t[r>>2]>>2]>>0]|0|0)!=32){if(9<=(u[t[t[r>>2]>>2]>>0]|0|0)?(u[t[t[r>>2]>>2]>>0]|0|0)<=10:0)break;if((u[t[t[r>>2]>>2]>>0]|0|0)!=13)break e}while(0);o=t[r>>2]|0;if(!(u[t[t[r>>2]>>2]>>0]|0))continue;t[o>>2]=(t[o>>2]|0)+1}}while(0);e:while(1){do if((u[t[t[r>>2]>>2]>>0]|0|0)!=32){if(9<=(u[t[t[r>>2]>>2]>>0]|0|0)?(u[t[t[r>>2]>>2]>>0]|0|0)<=10:0)break;if((u[t[t[r>>2]>>2]>>0]|0|0)!=13)break e}while(0);l=t[r>>2]|0;if(!(u[t[t[r>>2]>>2]>>0]|0))continue;t[l>>2]=(t[l>>2]|0)+1}s=i;return}function _a(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,a=0,o=0,c=0,l=0,b=0;r=s;s=s+16|0;n=r+8|0;f=r+4|0;a=r;t[n>>2]=e;t[f>>2]=i;t[a>>2]=t[(t[(t[n>>2]|0)+32>>2]|0)+12>>2];while(1){do if((u[t[t[n>>2]>>2]>>0]|0|0)==32)o=1;else{if(9<=(u[t[t[n>>2]>>2]>>0]|0|0)?(u[t[t[n>>2]>>2]>>0]|0|0)<=10:0){o=1;break}o=(u[t[t[n>>2]>>2]>>0]|0|0)==13}while(0);c=u[t[t[n>>2]>>2]>>0]|0;if(!o)break;i=t[n>>2]|0;if(!c)continue;t[i>>2]=(t[i>>2]|0)+1}o=t[n>>2]|0;if((c|0)!=91){dn(o,6);s=r;return}c=t[n>>2]|0;if(u[t[o>>2]>>0]|0)t[c>>2]=(t[c>>2]|0)+1;while(1){do if((u[t[t[n>>2]>>2]>>0]|0|0)==32)l=1;else{if(9<=(u[t[t[n>>2]>>2]>>0]|0|0)?(u[t[t[n>>2]>>2]>>0]|0|0)<=10:0){l=1;break}l=(u[t[t[n>>2]>>2]>>0]|0|0)==13}while(0);b=t[n>>2]|0;if(!l)break;c=t[n>>2]|0;if(!(u[t[b>>2]>>0]|0))continue;t[c>>2]=(t[c>>2]|0)+1}t[(t[b+32>>2]|0)+12>>2]=-1;b=t[n>>2]|0;if(t[f>>2]|0)ku(b,1);else ku(b,0);if(t[(t[n>>2]|0)+8>>2]|0){s=r;return}if((u[t[t[n>>2]>>2]>>0]|0|0)!=93){dn(t[n>>2]|0,6);s=r;return}b=t[(t[n>>2]|0)+32>>2]|0;l=t[a>>2]|0;a=t[(t[(t[n>>2]|0)+32>>2]|0)+12>>2]|0;if(t[f>>2]|0)Pu(b,l,a,17,0,0,0,0,0)|0;else Pu(b,l,a,16,0,0,0,0,0)|0;a=t[n>>2]|0;if(u[t[t[n>>2]>>2]>>0]|0)t[a>>2]=(t[a>>2]|0)+1;e:while(1){do if((u[t[t[n>>2]>>2]>>0]|0|0)!=32){if(9<=(u[t[t[n>>2]>>2]>>0]|0|0)?(u[t[t[n>>2]>>2]>>0]|0|0)<=10:0)break;if((u[t[t[n>>2]>>2]>>0]|0|0)!=13)break e}while(0);a=t[n>>2]|0;if(!(u[t[t[n>>2]>>2]>>0]|0))continue;t[a>>2]=(t[a>>2]|0)+1}s=r;return}function pa(e){e=e|0;var i=0,r=0,n=0,f=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0,S=0,g=0,y=0,F=0;i=s;s=s+48|0;r=i+32|0;n=i+28|0;f=i+24|0;a=i+20|0;o=i+16|0;c=i+12|0;l=i+8|0;b=i+4|0;k=i;t[r>>2]=e;t[n>>2]=0;t[f>>2]=-1;while(1){do if((u[t[t[r>>2]>>2]>>0]|0|0)==32)h=1;else{if(9<=(u[t[t[r>>2]>>2]>>0]|0|0)?(u[t[t[r>>2]>>2]>>0]|0|0)<=10:0){h=1;break}h=(u[t[t[r>>2]>>2]>>0]|0|0)==13}while(0);w=u[t[t[r>>2]>>2]>>0]|0;if(!h)break;e=t[r>>2]|0;if(!w)continue;t[e>>2]=(t[e>>2]|0)+1}if((w|0)==46?(u[(t[t[r>>2]>>2]|0)+1>>0]|0|0)==46:0){w=t[r>>2]|0;t[w>>2]=(t[w>>2]|0)+2;while(1){do if((u[t[t[r>>2]>>2]>>0]|0|0)==32)d=1;else{if(9<=(u[t[t[r>>2]>>2]>>0]|0|0)?(u[t[t[r>>2]>>2]>>0]|0|0)<=10:0){d=1;break}d=(u[t[t[r>>2]>>2]>>0]|0|0)==13}while(0);v=t[r>>2]|0;if(!d)break;w=t[r>>2]|0;if(!(u[t[v>>2]>>0]|0))continue;t[w>>2]=(t[w>>2]|0)+1}Pu(t[v+32>>2]|0,t[(t[(t[r>>2]|0)+32>>2]|0)+12>>2]|0,-1,11,10,1,0,0,0)|0;s=i;return}if((u[t[t[r>>2]>>2]>>0]|0|0)==46){v=t[r>>2]|0;if(u[t[t[r>>2]>>2]>>0]|0)t[v>>2]=(t[v>>2]|0)+1;e:while(1){do if((u[t[t[r>>2]>>2]>>0]|0|0)!=32){if(9<=(u[t[t[r>>2]>>2]>>0]|0|0)?(u[t[t[r>>2]>>2]>>0]|0|0)<=10:0)break;if((u[t[t[r>>2]>>2]>>0]|0|0)!=13)break e}while(0);v=t[r>>2]|0;if(!(u[t[t[r>>2]>>2]>>0]|0))continue;t[v>>2]=(t[v>>2]|0)+1}s=i;return}t[a>>2]=0;t[o>>2]=0;t[c>>2]=0;t[l>>2]=0;t[b>>2]=0;if(((t[(t[r>>2]|0)+36>>2]|0)!=0?(t[a>>2]=ht(t[r>>2]|0)|0,(t[a>>2]|0)!=0):0)?(Xl(t[a>>2]|0,130440)|0)!=0:0){t[f>>2]=t[(t[(t[r>>2]|0)+32>>2]|0)+12>>2];pAi[t[135736>>2]&511](t[a>>2]|0);while(1){do if((u[t[t[r>>2]>>2]>>0]|0|0)==32)m=1;else{if(9<=(u[t[t[r>>2]>>2]>>0]|0|0)?(u[t[t[r>>2]>>2]>>0]|0|0)<=10:0){m=1;break}m=(u[t[t[r>>2]>>2]>>0]|0|0)==13}while(0);_=u[t[t[r>>2]>>2]>>0]|0;if(!m)break;v=t[r>>2]|0;if(!_)continue;t[v>>2]=(t[v>>2]|0)+1}m=t[r>>2]|0;if((_|0)!=40){dn(m,7);s=i;return}_=t[r>>2]|0;if(u[t[m>>2]>>0]|0)t[_>>2]=(t[_>>2]|0)+1;while(1){do if((u[t[t[r>>2]>>2]>>0]|0|0)==32)p=1;else{if(9<=(u[t[t[r>>2]>>2]>>0]|0|0)?(u[t[t[r>>2]>>2]>>0]|0|0)<=10:0){p=1;break}p=(u[t[t[r>>2]>>2]>>0]|0|0)==13}while(0);E=t[r>>2]|0;if(!p)break;_=t[r>>2]|0;if(!(u[t[E>>2]>>0]|0))continue;t[_>>2]=(t[_>>2]|0)+1}ku(E,1);if(t[(t[r>>2]|0)+8>>2]|0){s=i;return}while(1){do if((u[t[t[r>>2]>>2]>>0]|0|0)==32)S=1;else{if(9<=(u[t[t[r>>2]>>2]>>0]|0|0)?(u[t[t[r>>2]>>2]>>0]|0|0)<=10:0){S=1;break}S=(u[t[t[r>>2]>>2]>>0]|0|0)==13}while(0);g=u[t[t[r>>2]>>2]>>0]|0;if(!S)break;E=t[r>>2]|0;if(!g)continue;t[E>>2]=(t[E>>2]|0)+1}S=t[r>>2]|0;if((g|0)!=41){dn(S,7);s=i;return}g=t[r>>2]|0;if(u[t[S>>2]>>0]|0)t[g>>2]=(t[g>>2]|0)+1;t[n>>2]=1}else{do if((u[t[t[r>>2]>>2]>>0]|0|0)==42)t[l>>2]=4;else{if(!(t[a>>2]|0))t[a>>2]=ht(t[r>>2]|0)|0;if(!(t[a>>2]|0)){if((u[t[t[r>>2]>>2]>>0]|0|0)!=64){t[l>>2]=4;break}g=t[r>>2]|0;if(u[t[t[r>>2]>>2]>>0]|0)t[g>>2]=(t[g>>2]|0)+1;t[l>>2]=3;break}t[l>>2]=Fa(t[a>>2]|0)|0;if(!(t[l>>2]|0)){t[l>>2]=4;break}while(1){do if((u[t[t[r>>2]>>2]>>0]|0|0)==32)y=1;else{if(9<=(u[t[t[r>>2]>>2]>>0]|0|0)?(u[t[t[r>>2]>>2]>>0]|0|0)<=10:0){y=1;break}y=(u[t[t[r>>2]>>2]>>0]|0|0)==13;
	}while(0);F=u[t[t[r>>2]>>2]>>0]|0;if(!y)break;g=t[r>>2]|0;if(!F)continue;t[g>>2]=(t[g>>2]|0)+1}if((F|0)==58?(u[(t[t[r>>2]>>2]|0)+1>>0]|0|0)==58:0){g=t[r>>2]|0;t[g>>2]=(t[g>>2]|0)+2;pAi[t[135736>>2]&511](t[a>>2]|0);t[a>>2]=0;break}t[l>>2]=4}while(0);if(t[(t[r>>2]|0)+8>>2]|0){pAi[t[135736>>2]&511](t[a>>2]|0);s=i;return}t[a>>2]=Oa(t[r>>2]|0,c,b,o,t[a>>2]|0)|0;if(!(t[c>>2]|0)){s=i;return}if((((t[o>>2]|0)!=0?(t[(t[r>>2]|0)+12>>2]|0)!=0:0)?(t[(t[(t[r>>2]|0)+12>>2]|0)+196>>2]&1|0)!=0:0)?(Xn(t[(t[r>>2]|0)+12>>2]|0,t[o>>2]|0)|0)==0:0)dn(t[r>>2]|0,19)}t[k>>2]=t[(t[(t[r>>2]|0)+32>>2]|0)+12>>2];t[(t[(t[r>>2]|0)+32>>2]|0)+12>>2]=-1;e:while(1){do if((u[t[t[r>>2]>>2]>>0]|0|0)!=32){if(9<=(u[t[t[r>>2]>>2]>>0]|0|0)?(u[t[t[r>>2]>>2]>>0]|0|0)<=10:0)break;if((u[t[t[r>>2]>>2]>>0]|0|0)!=13)break e}while(0);F=t[r>>2]|0;if(!(u[t[t[r>>2]>>2]>>0]|0))continue;t[F>>2]=(t[F>>2]|0)+1}while(1){if((u[t[t[r>>2]>>2]>>0]|0|0)!=91)break;_a(t[r>>2]|0,0)}F=t[(t[r>>2]|0)+32>>2]|0;if(t[n>>2]|0){Pu(F,t[f>>2]|0,t[k>>2]|0,19,0,0,0,0,0)|0;s=i;return}else{Pu(F,t[k>>2]|0,t[(t[(t[r>>2]|0)+32>>2]|0)+12>>2]|0,11,t[l>>2]|0,t[c>>2]|0,t[b>>2]|0,t[o>>2]|0,t[a>>2]|0)|0;s=i;return}}function Ea(e){e=e|0;var i=0,r=0,n=0,f=0,a=0,o=0,c=0,l=0;i=s;s=s+16|0;r=i+8|0;n=i+4|0;f=i;t[r>>2]=e;while(1){do if((u[t[t[r>>2]>>2]>>0]|0|0)==32)a=1;else{if(9<=(u[t[t[r>>2]>>2]>>0]|0|0)?(u[t[t[r>>2]>>2]>>0]|0|0)<=10:0){a=1;break}a=(u[t[t[r>>2]>>2]>>0]|0|0)==13}while(0);o=u[t[t[r>>2]>>2]>>0]|0;if(!a)break;e=t[r>>2]|0;if(!o)continue;t[e>>2]=(t[e>>2]|0)+1}a=t[r>>2]|0;if((o|0)!=36){dn(a,4);s=i;return}o=t[r>>2]|0;if(u[t[a>>2]>>0]|0)t[o>>2]=(t[o>>2]|0)+1;t[n>>2]=Aa(t[r>>2]|0,f)|0;o=t[r>>2]|0;if(!(t[n>>2]|0)){dn(o,4);s=i;return}t[(t[o+32>>2]|0)+12>>2]=-1;Pu(t[(t[r>>2]|0)+32>>2]|0,t[(t[(t[r>>2]|0)+32>>2]|0)+12>>2]|0,-1,13,0,0,0,t[n>>2]|0,t[f>>2]|0)|0;while(1){do if((u[t[t[r>>2]>>2]>>0]|0|0)==32)c=1;else{if(9<=(u[t[t[r>>2]>>2]>>0]|0|0)?(u[t[t[r>>2]>>2]>>0]|0|0)<=10:0){c=1;break}c=(u[t[t[r>>2]>>2]>>0]|0|0)==13}while(0);l=t[r>>2]|0;if(!c)break;f=t[r>>2]|0;if(!(u[t[l>>2]>>0]|0))continue;t[f>>2]=(t[f>>2]|0)+1}if(!(t[l+12>>2]|0)){s=i;return}if(!(t[(t[(t[r>>2]|0)+12>>2]|0)+196>>2]&2)){s=i;return}dn(t[r>>2]|0,24);s=i;return}function Sa(e){e=e|0;var i=0,r=0,n=0,f=0,a=0,o=0,c=0,b=0,k=0,h=0,w=0,d=0,v=0;i=s;s=s+64|0;r=i+48|0;n=i+16|0;f=i+44|0;a=i+40|0;o=i+36|0;c=i+32|0;b=i+8|0;k=i+28|0;h=i+24|0;w=i;t[r>>2]=e;l[n>>3]=0;t[f>>2]=0;t[a>>2]=0;t[o>>2]=0;t[c>>2]=0;if(t[(t[r>>2]|0)+8>>2]|0){s=i;return}do if((u[t[t[r>>2]>>2]>>0]|0|0)!=46){if((u[t[t[r>>2]>>2]>>0]|0|0)>=48?(u[t[t[r>>2]>>2]>>0]|0|0)<=57:0)break;dn(t[r>>2]|0,1);s=i;return}while(0);l[n>>3]=0;while(1){if((u[t[t[r>>2]>>2]>>0]|0|0)<48)break;if((u[t[t[r>>2]>>2]>>0]|0|0)>57)break;l[n>>3]=+l[n>>3]*10;t[c>>2]=(u[t[t[r>>2]>>2]>>0]|0)-48;t[f>>2]=1;e=t[r>>2]|0;if(u[t[t[r>>2]>>2]>>0]|0)t[e>>2]=(t[e>>2]|0)+1;l[b>>3]=+((t[c>>2]|0)>>>0);l[n>>3]=+l[n>>3]+ +l[b>>3]}e:do if((u[t[t[r>>2]>>2]>>0]|0|0)==46){t[h>>2]=0;l[w>>3]=0;b=t[r>>2]|0;if(u[t[t[r>>2]>>2]>>0]|0)t[b>>2]=(t[b>>2]|0)+1;if((u[t[t[r>>2]>>2]>>0]|0|0)<48){if(!(t[f>>2]|0))d=18}else if(!((t[f>>2]|0)!=0?1:(u[t[t[r>>2]>>2]>>0]|0|0)<=57))d=18;if((d|0)==18){dn(t[r>>2]|0,1);s=i;return}while(1){if((u[t[t[r>>2]>>2]>>0]|0|0)<48)break;if(!((t[h>>2]|0)<20?(u[t[t[r>>2]>>2]>>0]|0|0)<=57:0))break;t[k>>2]=(u[t[t[r>>2]>>2]>>0]|0)-48;l[w>>3]=+l[w>>3]*10+ +(t[k>>2]|0);t[h>>2]=(t[h>>2]|0)+1;b=t[r>>2]|0;if(!(u[t[t[r>>2]>>2]>>0]|0))continue;t[b>>2]=(t[b>>2]|0)+1}l[w>>3]=+l[w>>3]/+l[129232+(t[h>>2]<<3)>>3];l[n>>3]=+l[n>>3]+ +l[w>>3];while(1){if((u[t[t[r>>2]>>2]>>0]|0|0)<48)break e;if((u[t[t[r>>2]>>2]>>0]|0|0)>57)break e;b=t[r>>2]|0;if(!(u[t[t[r>>2]>>2]>>0]|0))continue;t[b>>2]=(t[b>>2]|0)+1}}while(0);if(!((u[t[t[r>>2]>>2]>>0]|0|0)!=101?(u[t[t[r>>2]>>2]>>0]|0|0)!=69:0)){w=t[r>>2]|0;if(u[t[t[r>>2]>>2]>>0]|0)t[w>>2]=(t[w>>2]|0)+1;if((u[t[t[r>>2]>>2]>>0]|0|0)==45){t[o>>2]=1;w=t[r>>2]|0;if(u[t[t[r>>2]>>2]>>0]|0)t[w>>2]=(t[w>>2]|0)+1}else if((u[t[t[r>>2]>>2]>>0]|0|0)==43?(w=t[r>>2]|0,(u[t[t[r>>2]>>2]>>0]|0|0)!=0):0)t[w>>2]=(t[w>>2]|0)+1;while(1){if((u[t[t[r>>2]>>2]>>0]|0|0)<48)break;if((u[t[t[r>>2]>>2]>>0]|0|0)>57)break;t[a>>2]=((t[a>>2]|0)*10|0)+((u[t[t[r>>2]>>2]>>0]|0)-48);w=t[r>>2]|0;if(!(u[t[t[r>>2]>>2]>>0]|0))continue;t[w>>2]=(t[w>>2]|0)+1}if(t[o>>2]|0)t[a>>2]=0-(t[a>>2]|0);v=+K(10,+ +(t[a>>2]|0));l[n>>3]=+l[n>>3]*v}a=t[(t[r>>2]|0)+32>>2]|0;o=t[(t[(t[r>>2]|0)+32>>2]|0)+12>>2]|0;Pu(a,o,-1,12,3,0,0,eu(t[(t[r>>2]|0)+12>>2]|0,+l[n>>3])|0,0)|0;s=i;return}function ga(e){e=e|0;var i=0,r=0,n=0,f=0,a=0,o=0,c=0,l=0,b=0,k=0;i=s;s=s+16|0;r=i+8|0;n=i+4|0;f=i;t[r>>2]=e;t[f>>2]=0;e=u[t[t[r>>2]>>2]>>0]|0;if((u[t[t[r>>2]>>2]>>0]|0|0)==34){a=t[r>>2]|0;if(e)t[a>>2]=(t[a>>2]|0)+1;t[n>>2]=t[t[r>>2]>>2];while(1){if(9<=(u[t[t[r>>2]>>2]>>0]|0|0)?(u[t[t[r>>2]>>2]>>0]|0|0)<=10:0)o=9;else if((u[t[t[r>>2]>>2]>>0]|0|0)!=13?32>(u[t[t[r>>2]>>2]>>0]|0|0):0)c=0;else o=9;if((o|0)==9){o=0;c=(u[t[t[r>>2]>>2]>>0]|0|0)!=34}l=u[t[t[r>>2]>>2]>>0]|0;if(!c)break;a=t[r>>2]|0;if(!l)continue;t[a>>2]=(t[a>>2]|0)+1}if(!(9<=(l|0)?(u[t[t[r>>2]>>2]>>0]|0|0)<=10:0))o=15;if(((o|0)==15?(u[t[t[r>>2]>>2]>>0]|0|0)!=13:0)?32>(u[t[t[r>>2]>>2]>>0]|0|0):0){dn(t[r>>2]|0,2);s=i;return}t[f>>2]=ql(t[n>>2]|0,(t[t[r>>2]>>2]|0)-(t[n>>2]|0)|0)|0;l=t[r>>2]|0;if(u[t[t[r>>2]>>2]>>0]|0)t[l>>2]=(t[l>>2]|0)+1}else{l=t[r>>2]|0;if((e|0)!=39){dn(l,3);s=i;return}e=t[r>>2]|0;if(u[t[l>>2]>>0]|0)t[e>>2]=(t[e>>2]|0)+1;t[n>>2]=t[t[r>>2]>>2];while(1){if(9<=(u[t[t[r>>2]>>2]>>0]|0|0)?(u[t[t[r>>2]>>2]>>0]|0|0)<=10:0)o=28;else if((u[t[t[r>>2]>>2]>>0]|0|0)!=13?32>(u[t[t[r>>2]>>2]>>0]|0|0):0)b=0;else o=28;if((o|0)==28){o=0;b=(u[t[t[r>>2]>>2]>>0]|0|0)!=39}k=u[t[t[r>>2]>>2]>>0]|0;if(!b)break;e=t[r>>2]|0;if(!k)continue;t[e>>2]=(t[e>>2]|0)+1}if(!(9<=(k|0)?(u[t[t[r>>2]>>2]>>0]|0|0)<=10:0))o=34;if(((o|0)==34?(u[t[t[r>>2]>>2]>>0]|0|0)!=13:0)?32>(u[t[t[r>>2]>>2]>>0]|0|0):0){dn(t[r>>2]|0,2);s=i;return}t[f>>2]=ql(t[n>>2]|0,(t[t[r>>2]>>2]|0)-(t[n>>2]|0)|0)|0;n=t[r>>2]|0;if(u[t[t[r>>2]>>2]>>0]|0)t[n>>2]=(t[n>>2]|0)+1}if(!(t[f>>2]|0)){s=i;return}n=t[(t[r>>2]|0)+32>>2]|0;o=t[(t[(t[r>>2]|0)+32>>2]|0)+12>>2]|0;Pu(n,o,-1,12,4,0,0,au(t[(t[r>>2]|0)+12>>2]|0,t[f>>2]|0)|0,0)|0;pAi[t[135736>>2]&511](t[f>>2]|0);s=i;return}function ya(e){e=e|0;var i=0,r=0,n=0,f=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0;i=s;s=s+32|0;r=i+20|0;n=i+16|0;f=i+12|0;a=i+8|0;o=i+4|0;c=i;t[r>>2]=e;t[a>>2]=0;t[o>>2]=1;t[n>>2]=Aa(t[r>>2]|0,f)|0;if(!(t[n>>2]|0)){pAi[t[135736>>2]&511](t[f>>2]|0);dn(t[r>>2]|0,7);s=i;return}while(1){do if((u[t[t[r>>2]>>2]>>0]|0|0)==32)l=1;else{if(9<=(u[t[t[r>>2]>>2]>>0]|0|0)?(u[t[t[r>>2]>>2]>>0]|0|0)<=10:0){l=1;break}l=(u[t[t[r>>2]>>2]>>0]|0|0)==13}while(0);b=u[t[t[r>>2]>>2]>>0]|0;if(!l)break;e=t[r>>2]|0;if(!b)continue;t[e>>2]=(t[e>>2]|0)+1}l=t[r>>2]|0;if((b|0)!=40){dn(l,7);s=i;return}b=t[r>>2]|0;if(u[t[l>>2]>>0]|0)t[b>>2]=(t[b>>2]|0)+1;e:while(1){do if((u[t[t[r>>2]>>2]>>0]|0|0)!=32){if(9<=(u[t[t[r>>2]>>2]>>0]|0|0)?(u[t[t[r>>2]>>2]>>0]|0|0)<=10:0)break;if((u[t[t[r>>2]>>2]>>0]|0|0)!=13)break e}while(0);b=t[r>>2]|0;if(!(u[t[t[r>>2]>>2]>>0]|0))continue;t[b>>2]=(t[b>>2]|0)+1}if(((t[f>>2]|0)==0?(u[t[n>>2]>>0]|0|0)==99:0)?(Xl(t[n>>2]|0,129608)|0)!=0:0)t[o>>2]=0;t[(t[(t[r>>2]|0)+32>>2]|0)+12>>2]=-1;e:do if((u[t[t[r>>2]>>2]>>0]|0|0)!=41){i:while(1){if(!(u[t[t[r>>2]>>2]>>0]|0))break e;t[c>>2]=t[(t[(t[r>>2]|0)+32>>2]|0)+12>>2];t[(t[(t[r>>2]|0)+32>>2]|0)+12>>2]=-1;ku(t[r>>2]|0,t[o>>2]|0);if(t[(t[r>>2]|0)+8>>2]|0){k=27;break}Pu(t[(t[r>>2]|0)+32>>2]|0,t[c>>2]|0,t[(t[(t[r>>2]|0)+32>>2]|0)+12>>2]|0,15,0,0,0,0,0)|0;t[a>>2]=(t[a>>2]|0)+1;if((u[t[t[r>>2]>>2]>>0]|0|0)==41)break e;h=t[r>>2]|0;if((u[t[t[r>>2]>>2]>>0]|0|0)!=44){k=30;break}b=t[r>>2]|0;if(u[t[h>>2]>>0]|0)t[b>>2]=(t[b>>2]|0)+1;while(1){do if((u[t[t[r>>2]>>2]>>0]|0|0)!=32){if(9<=(u[t[t[r>>2]>>2]>>0]|0|0)?(u[t[t[r>>2]>>2]>>0]|0|0)<=10:0)break;if((u[t[t[r>>2]>>2]>>0]|0|0)!=13)continue i}while(0);b=t[r>>2]|0;if(!(u[t[t[r>>2]>>2]>>0]|0))continue;t[b>>2]=(t[b>>2]|0)+1}}if((k|0)==27){pAi[t[135736>>2]&511](t[n>>2]|0);pAi[t[135736>>2]&511](t[f>>2]|0);s=i;return}else if((k|0)==30){dn(h,7);s=i;return}}while(0);Pu(t[(t[r>>2]|0)+32>>2]|0,t[(t[(t[r>>2]|0)+32>>2]|0)+12>>2]|0,-1,14,t[a>>2]|0,0,0,t[n>>2]|0,t[f>>2]|0)|0;f=t[r>>2]|0;if(u[t[t[r>>2]>>2]>>0]|0)t[f>>2]=(t[f>>2]|0)+1;e:while(1){do if((u[t[t[r>>2]>>2]>>0]|0|0)!=32){if(9<=(u[t[t[r>>2]>>2]>>0]|0|0)?(u[t[t[r>>2]>>2]>>0]|0|0)<=10:0)break;if((u[t[t[r>>2]>>2]>>0]|0|0)!=13)break e}while(0);f=t[r>>2]|0;if(!(u[t[t[r>>2]>>2]>>0]|0))continue;t[f>>2]=(t[f>>2]|0)+1}s=i;return}function Fa(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i+4|0;n=i;t[r>>2]=e;t[n>>2]=0;switch(u[t[r>>2]>>0]|0|0){case 110:{if(Xl(t[r>>2]|0,130600)|0)t[n>>2]=9;break}case 115:{if(Xl(t[r>>2]|0,130664)|0)t[n>>2]=13;break}case 97:{if(Xl(t[r>>2]|0,130456)|0)t[n>>2]=1;if(Xl(t[r>>2]|0,130472)|0)t[n>>2]=2;if(Xl(t[r>>2]|0,130496)|0)t[n>>2]=3;break}case 99:{if(Xl(t[r>>2]|0,130512)|0)t[n>>2]=4;break}case 102:{if(Xl(t[r>>2]|0,130560)|0)t[n>>2]=7;if(Xl(t[r>>2]|0,130576)|0)t[n>>2]=8;break}case 112:{if(Xl(t[r>>2]|0,130616)|0)t[n>>2]=10;if(Xl(t[r>>2]|0,130624)|0)t[n>>2]=11;if(Xl(t[r>>2]|0,130640)|0)t[n>>2]=12;break}case 100:{if(Xl(t[r>>2]|0,130520)|0)t[n>>2]=5;if(Xl(t[r>>2]|0,130536)|0)t[n>>2]=6;break}default:{}}s=i;return t[n>>2]|0}function Oa(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;var a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0;a=s;s=s+48|0;o=a;c=a+32|0;l=a+28|0;b=a+24|0;k=a+20|0;h=a+16|0;w=a+12|0;d=a+8|0;t[l>>2]=e;t[b>>2]=i;t[k>>2]=r;t[h>>2]=n;t[w>>2]=f;if((t[b>>2]|0)==0|(t[k>>2]|0)==0|(t[h>>2]|0)==0){f=t[33976]|0;n=t[33980]|0;t[o>>2]=128552;t[o+4>>2]=11124;yAi[f&511](n,129448,o);t[c>>2]=0;v=t[c>>2]|0;s=a;return v|0}t[t[k>>2]>>2]=0;t[t[b>>2]>>2]=0;t[t[h>>2]>>2]=0;e:while(1){do if((u[t[t[l>>2]>>2]>>0]|0|0)!=32){if(9<=(u[t[t[l>>2]>>2]>>0]|0|0)?(u[t[t[l>>2]>>2]>>0]|0|0)<=10:0)break;if((u[t[t[l>>2]>>2]>>0]|0|0)!=13)break e}while(0);o=t[l>>2]|0;if(!(u[t[t[l>>2]>>2]>>0]|0))continue;t[o>>2]=(t[o>>2]|0)+1}if((t[w>>2]|0)==0?(u[t[t[l>>2]>>2]>>0]|0|0)==42:0){o=t[l>>2]|0;if(u[t[t[l>>2]>>2]>>0]|0)t[o>>2]=(t[o>>2]|0)+1;t[t[b>>2]>>2]=3;t[c>>2]=0;v=t[c>>2]|0;s=a;return v|0}if(!(t[w>>2]|0))t[w>>2]=ht(t[l>>2]|0)|0;o=t[l>>2]|0;if(!(t[w>>2]|0)){dn(o,7);t[c>>2]=0;v=t[c>>2]|0;s=a;return v|0}do if((u[t[o>>2]>>0]|0|0)==32)m=1;else{if(9<=(u[t[t[l>>2]>>2]>>0]|0|0)?(u[t[t[l>>2]>>2]>>0]|0|0)<=10:0){m=1;break}m=(u[t[t[l>>2]>>2]>>0]|0|0)==13}while(0);t[d>>2]=m&1;while(1){do if((u[t[t[l>>2]>>2]>>0]|0|0)==32)_=1;else{if(9<=(u[t[t[l>>2]>>2]>>0]|0|0)?(u[t[t[l>>2]>>2]>>0]|0|0)<=10:0){_=1;break}_=(u[t[t[l>>2]>>2]>>0]|0|0)==13}while(0);p=u[t[t[l>>2]>>2]>>0]|0;if(!_)break;m=t[l>>2]|0;if(!p)continue;t[m>>2]=(t[m>>2]|0)+1}if((p|0)!=40){t[t[b>>2]>>2]=5;do if((t[d>>2]|0)==0?(u[t[t[l>>2]>>2]>>0]|0|0)==58:0){p=t[l>>2]|0;if(u[t[t[l>>2]>>2]>>0]|0)t[p>>2]=(t[p>>2]|0)+1;t[t[h>>2]>>2]=t[w>>2];p=t[l>>2]|0;if((u[t[t[l>>2]>>2]>>0]|0|0)!=42){t[w>>2]=ht(p)|0;if(t[w>>2]|0)break;dn(t[l>>2]|0,7);t[c>>2]=0;v=t[c>>2]|0;s=a;return v|0}_=t[l>>2]|0;if(u[t[p>>2]>>0]|0)t[_>>2]=(t[_>>2]|0)+1;t[t[b>>2]>>2]=3;t[c>>2]=0;v=t[c>>2]|0;s=a;return v|0}while(0);t[c>>2]=t[w>>2];v=t[c>>2]|0;s=a;return v|0}h=t[l>>2]|0;if(u[t[t[l>>2]>>2]>>0]|0)t[h>>2]=(t[h>>2]|0)+1;do if(Xl(t[w>>2]|0,129416)|0)t[t[k>>2]>>2]=8;else{if(Xl(t[w>>2]|0,129400)|0){t[t[k>>2]>>2]=0;break}if(Xl(t[w>>2]|0,129424)|0){t[t[k>>2]>>2]=7;break}if(Xl(t[w>>2]|0,129408)|0){t[t[k>>2]>>2]=3;break}if(t[w>>2]|0)pAi[t[135736>>2]&511](t[w>>2]|0);dn(t[l>>2]|0,7);t[c>>2]=0;v=t[c>>2]|0;s=a;return v|0}while(0);t[t[b>>2]>>2]=1;e:while(1){do if((u[t[t[l>>2]>>2]>>0]|0|0)!=32){if(9<=(u[t[t[l>>2]>>2]>>0]|0|0)?(u[t[t[l>>2]>>2]>>0]|0|0)<=10:0)break;if((u[t[t[l>>2]>>2]>>0]|0|0)!=13)break e}while(0);h=t[l>>2]|0;if(!(u[t[t[l>>2]>>2]>>0]|0))continue;t[h>>2]=(t[h>>2]|0)+1}e:do if((t[t[k>>2]>>2]|0)==7){if(t[w>>2]|0)pAi[t[135736>>2]&511](t[w>>2]|0);t[w>>2]=0;if((u[t[t[l>>2]>>2]>>0]|0|0)!=41){t[w>>2]=Ma(t[l>>2]|0)|0;if(t[(t[l>>2]|0)+8>>2]|0){t[c>>2]=0;v=t[c>>2]|0;s=a;return v|0}t[t[b>>2]>>2]=2;while(1){do if((u[t[t[l>>2]>>2]>>0]|0|0)!=32){if(9<=(u[t[t[l>>2]>>2]>>0]|0|0)?(u[t[t[l>>2]>>2]>>0]|0|0)<=10:0)break;if((u[t[t[l>>2]>>2]>>0]|0|0)!=13)break e}while(0);h=t[l>>2]|0;if(!(u[t[t[l>>2]>>2]>>0]|0))continue;t[h>>2]=(t[h>>2]|0)+1}}}while(0);if((u[t[t[l>>2]>>2]>>0]|0|0)!=41){if(t[w>>2]|0)pAi[t[135736>>2]&511](t[w>>2]|0);dn(t[l>>2]|0,8);t[c>>2]=0;v=t[c>>2]|0;s=a;return v|0}else{b=t[l>>2]|0;if(u[t[t[l>>2]>>2]>>0]|0)t[b>>2]=(t[b>>2]|0)+1;t[c>>2]=t[w>>2];v=t[c>>2]|0;s=a;return v|0}return 0}function Aa(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,a=0,o=0;r=s;s=s+16|0;n=r+8|0;f=r+4|0;a=r;t[n>>2]=e;t[f>>2]=i;t[a>>2]=0;t[t[f>>2]>>2]=0;t[a>>2]=ht(t[n>>2]|0)|0;if(!(t[a>>2]|0)){o=t[a>>2]|0;s=r;return o|0}if((u[t[t[n>>2]>>2]>>0]|0|0)!=58){o=t[a>>2]|0;s=r;return o|0}t[t[f>>2]>>2]=t[a>>2];f=t[n>>2]|0;if(u[t[t[n>>2]>>2]>>0]|0)t[f>>2]=(t[f>>2]|0)+1;t[a>>2]=ht(t[n>>2]|0)|0;o=t[a>>2]|0;s=r;return o|0}function Ma(e){e=e|0;var i=0,r=0,n=0,f=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0;i=s;s=s+16|0;r=i+12|0;n=i+8|0;f=i+4|0;a=i;t[n>>2]=e;t[a>>2]=0;e=u[t[t[n>>2]>>2]>>0]|0;if((u[t[t[n>>2]>>2]>>0]|0|0)==34){o=t[n>>2]|0;if(e)t[o>>2]=(t[o>>2]|0)+1;t[f>>2]=t[t[n>>2]>>2];while(1){if(9<=(u[t[t[n>>2]>>2]>>0]|0|0)?(u[t[t[n>>2]>>2]>>0]|0|0)<=10:0)c=9;else if((u[t[t[n>>2]>>2]>>0]|0|0)!=13?32>(u[t[t[n>>2]>>2]>>0]|0|0):0)l=0;else c=9;if((c|0)==9){c=0;l=(u[t[t[n>>2]>>2]>>0]|0|0)!=34}b=u[t[t[n>>2]>>2]>>0]|0;if(!l)break;o=t[n>>2]|0;if(!b)continue;t[o>>2]=(t[o>>2]|0)+1}if(!(9<=(b|0)?(u[t[t[n>>2]>>2]>>0]|0|0)<=10:0))c=15;if(((c|0)==15?(u[t[t[n>>2]>>2]>>0]|0|0)!=13:0)?32>(u[t[t[n>>2]>>2]>>0]|0|0):0){dn(t[n>>2]|0,2);t[r>>2]=0;k=t[r>>2]|0;s=i;return k|0}t[a>>2]=ql(t[f>>2]|0,(t[t[n>>2]>>2]|0)-(t[f>>2]|0)|0)|0;b=t[n>>2]|0;if(u[t[t[n>>2]>>2]>>0]|0)t[b>>2]=(t[b>>2]|0)+1}else{b=t[n>>2]|0;if((e|0)!=39){dn(b,3);t[r>>2]=0;k=t[r>>2]|0;s=i;return k|0}e=t[n>>2]|0;if(u[t[b>>2]>>0]|0)t[e>>2]=(t[e>>2]|0)+1;t[f>>2]=t[t[n>>2]>>2];while(1){if(9<=(u[t[t[n>>2]>>2]>>0]|0|0)?(u[t[t[n>>2]>>2]>>0]|0|0)<=10:0)c=28;else if((u[t[t[n>>2]>>2]>>0]|0|0)!=13?32>(u[t[t[n>>2]>>2]>>0]|0|0):0)h=0;else c=28;if((c|0)==28){c=0;h=(u[t[t[n>>2]>>2]>>0]|0|0)!=39}w=u[t[t[n>>2]>>2]>>0]|0;if(!h)break;e=t[n>>2]|0;if(!w)continue;t[e>>2]=(t[e>>2]|0)+1}if(!(9<=(w|0)?(u[t[t[n>>2]>>2]>>0]|0|0)<=10:0))c=34;if(((c|0)==34?(u[t[t[n>>2]>>2]>>0]|0|0)!=13:0)?32>(u[t[t[n>>2]>>2]>>0]|0|0):0){dn(t[n>>2]|0,2);t[r>>2]=0;k=t[r>>2]|0;s=i;return k|0}t[a>>2]=ql(t[f>>2]|0,(t[t[n>>2]>>2]|0)-(t[f>>2]|0)|0)|0;f=t[n>>2]|0;if(u[t[t[n>>2]>>2]>>0]|0)t[f>>2]=(t[f>>2]|0)+1}t[r>>2]=t[a>>2];k=t[r>>2]|0;s=i;return k|0}function Ra(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,u=0,a=0,o=0,c=0,l=0,b=0;f=s;s=s+32|0;u=f+20|0;a=f+16|0;o=f+12|0;c=f+8|0;l=f+4|0;b=f;t[a>>2]=e;t[o>>2]=i;t[c>>2]=r;t[l>>2]=n;do if(t[a>>2]|0){if(!(t[c>>2]|0)){t[u>>2]=0;break}if((t[o>>2]|0)<0){t[u>>2]=0;break}if((t[l>>2]|0)<0){t[u>>2]=0;break}t[b>>2]=gAi[t[135744>>2]&511](48)|0;if(!(t[b>>2]|0)){qa(131920);t[u>>2]=0;break}else{n=(t[b>>2]|0)+0|0;r=n+48|0;do{t[n>>2]=0;n=n+4|0}while((n|0)<(r|0));t[t[b>>2]>>2]=6;t[(t[b>>2]|0)+28>>2]=t[a>>2];t[(t[b>>2]|0)+32>>2]=t[o>>2];t[(t[b>>2]|0)+36>>2]=t[c>>2];t[(t[b>>2]|0)+40>>2]=t[l>>2];Ya(t[b>>2]|0);t[u>>2]=t[b>>2];break}}else t[u>>2]=0;while(0);s=f;return t[u>>2]|0}function Na(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0;r=s;s=s+16|0;n=r+12|0;f=r+8|0;u=r+4|0;a=r;t[f>>2]=e;t[u>>2]=i;if(!(t[f>>2]|0)){t[n>>2]=0;o=t[n>>2]|0;s=r;return o|0}if(!(t[u>>2]|0)){t[n>>2]=0;o=t[n>>2]|0;s=r;return o|0}t[a>>2]=gAi[t[135744>>2]&511](48)|0;if(!(t[a>>2]|0)){qa(131920);t[n>>2]=0;o=t[n>>2]|0;s=r;return o|0}else{i=(t[a>>2]|0)+0|0;e=i+48|0;do{t[i>>2]=0;i=i+4|0}while((i|0)<(e|0));t[t[a>>2]>>2]=6;t[(t[a>>2]|0)+28>>2]=t[f>>2];t[(t[a>>2]|0)+32>>2]=-1;t[(t[a>>2]|0)+36>>2]=t[u>>2];t[(t[a>>2]|0)+40>>2]=-1;Ya(t[a>>2]|0);t[n>>2]=t[a>>2];o=t[n>>2]|0;s=r;return o|0}return 0}function Ta(e){e=e|0;var i=0,r=0,n=0,f=0,u=0,a=0;i=s;s=s+16|0;r=i+8|0;n=i+4|0;f=i;t[n>>2]=e;if(!(t[n>>2]|0)){t[r>>2]=0;u=t[r>>2]|0;s=i;return u|0}t[f>>2]=gAi[t[135744>>2]&511](48)|0;if(!(t[f>>2]|0)){qa(131920);t[r>>2]=0;u=t[r>>2]|0;s=i;return u|0}else{e=(t[f>>2]|0)+0|0;a=e+48|0;do{t[e>>2]=0;e=e+4|0}while((e|0)<(a|0));t[t[f>>2]>>2]=6;t[(t[f>>2]|0)+28>>2]=t[n>>2];t[(t[f>>2]|0)+32>>2]=-1;t[(t[f>>2]|0)+36>>2]=0;t[(t[f>>2]|0)+40>>2]=-1;t[r>>2]=t[f>>2];u=t[r>>2]|0;s=i;return u|0}return 0}function La(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0;r=s;s=s+32|0;n=r;f=r+20|0;u=r+16|0;a=r+12|0;o=r+8|0;t[u>>2]=e;t[a>>2]=i;if(!(t[u>>2]|0)){t[f>>2]=0;c=t[f>>2]|0;s=r;return c|0}if(!(t[a>>2]|0)){t[f>>2]=0;c=t[f>>2]|0;s=r;return c|0}i=t[t[a>>2]>>2]|0;if((i|0)==1)l=6;else if(!((i|0)==6|(i|0)==5)){t[f>>2]=0;c=t[f>>2]|0;s=r;return c|0}if((l|0)==6?(t[t[(t[a>>2]|0)+4>>2]>>2]|0)<=0:0){t[f>>2]=0;c=t[f>>2]|0;s=r;return c|0}t[o>>2]=gAi[t[135744>>2]&511](48)|0;if(!(t[o>>2]|0)){qa(131920);t[f>>2]=0;c=t[f>>2]|0;s=r;return c|0}l=(t[o>>2]|0)+0|0;i=l+48|0;do{t[l>>2]=0;l=l+4|0}while((l|0)<(i|0));t[t[o>>2]>>2]=6;t[(t[o>>2]|0)+28>>2]=t[u>>2];t[(t[o>>2]|0)+32>>2]=-1;u=t[t[a>>2]>>2]|0;if((u|0)==1){t[(t[o>>2]|0)+36>>2]=t[(t[(t[(t[a>>2]|0)+4>>2]|0)+8>>2]|0)+((t[t[(t[a>>2]|0)+4>>2]>>2]|0)-1<<2)>>2];t[(t[o>>2]|0)+40>>2]=-1}else if((u|0)==5){t[(t[o>>2]|0)+36>>2]=t[(t[a>>2]|0)+28>>2];t[(t[o>>2]|0)+40>>2]=t[(t[a>>2]|0)+32>>2]}else if((u|0)==6){t[(t[o>>2]|0)+36>>2]=t[(t[a>>2]|0)+36>>2];t[(t[o>>2]|0)+40>>2]=t[(t[a>>2]|0)+40>>2]}else{a=t[33976]|0;u=t[33980]|0;t[n>>2]=131976;t[n+4>>2]=590;yAi[a&511](u,131944,n);t[f>>2]=0;c=t[f>>2]|0;s=r;return c|0}Ya(t[o>>2]|0);t[f>>2]=t[o>>2];c=t[f>>2]|0;s=r;return c|0}function Da(e){e=e|0;var i=0,r=0,n=0,f=0,u=0,a=0,o=0;i=s;s=s+16|0;r=i+8|0;n=i+4|0;f=i;t[n>>2]=e;t[f>>2]=gAi[t[135744>>2]&511](12)|0;if(!(t[f>>2]|0)){qa(132e3);t[r>>2]=0;u=t[r>>2]|0;s=i;return u|0}e=t[f>>2]|0;t[e+0>>2]=0;t[e+4>>2]=0;t[e+8>>2]=0;do if(t[n>>2]|0){e=gAi[t[135744>>2]&511](40)|0;t[(t[f>>2]|0)+8>>2]=e;if(t[(t[f>>2]|0)+8>>2]|0){e=(t[(t[f>>2]|0)+8>>2]|0)+0|0;a=e+40|0;do{t[e>>2]=0;e=e+4|0}while((e|0)<(a|0));t[(t[f>>2]|0)+4>>2]=10;e=t[n>>2]|0;a=t[f>>2]|0;o=t[a>>2]|0;t[a>>2]=o+1;t[(t[(t[f>>2]|0)+8>>2]|0)+(o<<2)>>2]=e;break}qa(132e3);pAi[t[135736>>2]&511](t[f>>2]|0);t[r>>2]=0;u=t[r>>2]|0;s=i;return u|0}while(0);t[r>>2]=t[f>>2];u=t[r>>2]|0;s=i;return u|0}function Ca(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0;r=s;s=s+16|0;n=r+12|0;f=r+8|0;u=r+4|0;a=r;t[n>>2]=e;t[f>>2]=i;if((t[n>>2]|0)==0|(t[f>>2]|0)==0){s=r;return}t[u>>2]=0;while(1){if((t[u>>2]|0)>=(t[t[n>>2]>>2]|0))break;if(Ga(t[(t[(t[n>>2]|0)+8>>2]|0)+(t[u>>2]<<2)>>2]|0,t[f>>2]|0)|0){o=5;break}t[u>>2]=(t[u>>2]|0)+1}if((o|0)==5){_n(t[f>>2]|0);s=r;return}do if(t[(t[n>>2]|0)+4>>2]|0){if((t[t[n>>2]>>2]|0)==(t[(t[n>>2]|0)+4>>2]|0)){o=(t[n>>2]|0)+4|0;t[o>>2]=t[o>>2]<<1;t[a>>2]=MAi[t[135760>>2]&511](t[(t[n>>2]|0)+8>>2]|0,t[(t[n>>2]|0)+4>>2]<<2)|0;if(t[a>>2]|0){t[(t[n>>2]|0)+8>>2]=t[a>>2];break}qa(132024);s=r;return}}else{o=gAi[t[135744>>2]&511](40)|0;t[(t[n>>2]|0)+8>>2]=o;if(t[(t[n>>2]|0)+8>>2]|0){o=(t[(t[n>>2]|0)+8>>2]|0)+0|0;u=o+40|0;do{t[o>>2]=0;o=o+4|0}while((o|0)<(u|0));t[(t[n>>2]|0)+4>>2]=10;break}qa(132024);s=r;return}while(0);a=t[f>>2]|0;f=t[n>>2]|0;o=t[f>>2]|0;t[f>>2]=o+1;t[(t[(t[n>>2]|0)+8>>2]|0)+(o<<2)>>2]=a;s=r;return}function Pa(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0;r=s;s=s+16|0;n=r+12|0;f=r+8|0;u=r+4|0;a=r;t[f>>2]=e;t[u>>2]=i;if(!(t[f>>2]|0)){t[n>>2]=0;o=t[n>>2]|0;s=r;return o|0}if(!(t[u>>2]|0)){t[n>>2]=t[f>>2];o=t[n>>2]|0;s=r;return o|0}t[a>>2]=0;while(1){c=t[f>>2]|0;if((t[a>>2]|0)>=(t[t[u>>2]>>2]|0))break;Ca(c,t[(t[(t[u>>2]|0)+8>>2]|0)+(t[a>>2]<<2)>>2]|0);t[a>>2]=(t[a>>2]|0)+1}t[n>>2]=c;o=t[n>>2]|0;s=r;return o|0}function Ba(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i+4|0;n=i;t[r>>2]=e;if(!(t[r>>2]|0)){s=i;return}if(t[(t[r>>2]|0)+8>>2]|0){t[n>>2]=0;while(1){if((t[n>>2]|0)>=(t[t[r>>2]>>2]|0))break;_n(t[(t[(t[r>>2]|0)+8>>2]|0)+(t[n>>2]<<2)>>2]|0);t[n>>2]=(t[n>>2]|0)+1}pAi[t[135736>>2]&511](t[(t[r>>2]|0)+8>>2]|0)}pAi[t[135736>>2]&511](t[r>>2]|0);s=i;return}function Ia(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0;r=s;s=s+16|0;n=r+12|0;f=r+8|0;u=r+4|0;a=r;t[f>>2]=e;t[u>>2]=i;t[a>>2]=gAi[t[135744>>2]&511](48)|0;if(!(t[a>>2]|0)){qa(132e3);t[n>>2]=0;o=t[n>>2]|0;s=r;return o|0}i=(t[a>>2]|0)+0|0;e=i+48|0;do{t[i>>2]=0;i=i+4|0}while((i|0)<(e|0));t[t[a>>2]>>2]=7;i=t[f>>2]|0;if(!(t[u>>2]|0)){f=Da(Ta(i)|0)|0;t[(t[a>>2]|0)+28>>2]=f}else{f=Da(Na(i,t[u>>2]|0)|0)|0;t[(t[a>>2]|0)+28>>2]=f}t[n>>2]=t[a>>2];o=t[n>>2]|0;s=r;return o|0}function Ha(e){e=e|0;var i=0,r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0;i=s;s=s+32|0;r=i+16|0;n=i+12|0;f=i+8|0;u=i+4|0;a=i;t[n>>2]=e;t[f>>2]=gAi[t[135744>>2]&511](48)|0;if(!(t[f>>2]|0)){qa(132e3);t[r>>2]=0;o=t[r>>2]|0;s=i;return o|0}e=(t[f>>2]|0)+0|0;c=e+48|0;do{t[e>>2]=0;e=e+4|0}while((e|0)<(c|0));t[t[f>>2]>>2]=7;if(t[n>>2]|0){t[a>>2]=Da(0)|0;if(!(t[a>>2]|0)){t[r>>2]=t[f>>2];o=t[r>>2]|0;s=i;return o|0}t[u>>2]=0;while(1){l=t[a>>2]|0;if((t[u>>2]|0)>=(t[t[n>>2]>>2]|0))break;Ca(l,Ta(t[(t[(t[n>>2]|0)+8>>2]|0)+(t[u>>2]<<2)>>2]|0)|0);t[u>>2]=(t[u>>2]|0)+1}t[(t[f>>2]|0)+28>>2]=l}t[r>>2]=t[f>>2];o=t[r>>2]|0;s=i;return o|0}function xa(e){e=e|0;var i=0,r=0,n=0,f=0,u=0,a=0;i=s;s=s+16|0;r=i+8|0;n=i+4|0;f=i;t[n>>2]=e;t[f>>2]=gAi[t[135744>>2]&511](48)|0;if(!(t[f>>2]|0)){qa(132e3);t[r>>2]=0;u=t[r>>2]|0;s=i;return u|0}else{e=(t[f>>2]|0)+0|0;a=e+48|0;do{t[e>>2]=0;e=e+4|0}while((e|0)<(a|0));t[t[f>>2]>>2]=7;t[(t[f>>2]|0)+28>>2]=t[n>>2];t[r>>2]=t[f>>2];u=t[r>>2]|0;s=i;return u|0}return 0}function Ua(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,l=0;n=s;s=s+32|0;f=n+16|0;u=n+12|0;a=n+8|0;o=n+4|0;c=n;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;t[c>>2]=wf(t[u>>2]|0)|0;u=t[c>>2]|0;if(!(t[c>>2]|0)){t[f>>2]=u;l=t[f>>2]|0;s=n;return l|0}else{t[u+76>>2]=1;t[(t[c>>2]|0)+80>>2]=t[a>>2];t[(t[c>>2]|0)+84>>2]=t[o>>2];Un(t[c>>2]|0,132048,306)|0;Un(t[c>>2]|0,132064,307)|0;Un(t[c>>2]|0,132072,308)|0;Un(t[c>>2]|0,132088,309)|0;Un(t[c>>2]|0,132104,310)|0;Un(t[c>>2]|0,132120,311)|0;Un(t[c>>2]|0,132136,312)|0;Un(t[c>>2]|0,132144,313)|0;t[f>>2]=t[c>>2];l=t[f>>2]|0;s=n;return l|0}return 0}function za(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0;r=s;s=s+48|0;n=r+36|0;f=r+32|0;u=r+28|0;a=r+24|0;o=r+20|0;c=r+16|0;l=r+12|0;b=r+8|0;k=r+4|0;h=r;t[n>>2]=e;t[f>>2]=i;t[b>>2]=0;if((t[n>>2]|0)==0|(t[n>>2]|0)==0){s=r;return}i=t[n>>2]|0;if((t[f>>2]|0)!=1){dn(i,12);s=r;return}f=t[n>>2]|0;if((t[i+20>>2]|0)<((t[(t[n>>2]|0)+44>>2]|0)+1|0)){dn(f,23);s=r;return}if((t[f+16>>2]|0)!=0?(t[t[(t[n>>2]|0)+16>>2]>>2]|0)==1:0){t[c>>2]=En(t[n>>2]|0)|0;t[k>>2]=t[(t[c>>2]|0)+4>>2];t[(t[(t[n>>2]|0)+12>>2]|0)+4>>2]=0;t[a>>2]=t[t[n>>2]>>2];t[b>>2]=Da(0)|0;t[h>>2]=0;while(1){if((t[h>>2]|0)>=(t[t[k>>2]>>2]|0))break;t[t[n>>2]>>2]=t[a>>2];t[(t[(t[n>>2]|0)+12>>2]|0)+4>>2]=t[(t[(t[k>>2]|0)+8>>2]|0)+(t[h>>2]<<2)>>2];t[l>>2]=In(t[(t[(t[n>>2]|0)+12>>2]|0)+4>>2]|0)|0;Sn(t[n>>2]|0,t[l>>2]|0)|0;pt(t[n>>2]|0);if(t[(t[n>>2]|0)+8>>2]|0){w=20;break}t[o>>2]=En(t[n>>2]|0)|0;t[u>>2]=La(t[(t[(t[k>>2]|0)+8>>2]|0)+(t[h>>2]<<2)>>2]|0,t[o>>2]|0)|0;if(t[u>>2]|0)Ca(t[b>>2]|0,t[u>>2]|0);if(t[o>>2]|0)_n(t[o>>2]|0);if((t[(t[n>>2]|0)+16>>2]|0)==(t[l>>2]|0)){t[o>>2]=En(t[n>>2]|0)|0;_n(t[o>>2]|0)}t[(t[(t[n>>2]|0)+12>>2]|0)+4>>2]=0;t[h>>2]=(t[h>>2]|0)+1}if((w|0)==20){s=r;return}_n(t[c>>2]|0);t[(t[(t[n>>2]|0)+12>>2]|0)+4>>2]=0;t[(t[(t[n>>2]|0)+12>>2]|0)+68>>2]=-1;t[(t[(t[n>>2]|0)+12>>2]|0)+72>>2]=-1;c=t[n>>2]|0;Sn(c,xa(t[b>>2]|0)|0)|0;s=r;return}dn(t[n>>2]|0,11);s=r;return}function ja(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0;r=s;s=s+48|0;n=r+32|0;f=r+28|0;u=r+24|0;a=r+20|0;o=r+16|0;c=r+12|0;l=r+8|0;b=r+4|0;k=r;t[f>>2]=e;t[u>>2]=i;t[o>>2]=0;t[l>>2]=0;t[b>>2]=0;kn();if((t[u>>2]|0)==0|(t[f>>2]|0)==0){t[n>>2]=0;h=t[n>>2]|0;s=r;return h|0}t[a>>2]=mf(t[f>>2]|0,t[u>>2]|0)|0;if(!(t[a>>2]|0)){t[n>>2]=0;h=t[n>>2]|0;s=r;return h|0}t[(t[a>>2]|0)+36>>2]=1;eo(t[a>>2]|0);if(((t[(t[a>>2]|0)+16>>2]|0)!=0?(t[t[(t[a>>2]|0)+16>>2]>>2]|0)!=1:0)?(t[t[(t[a>>2]|0)+16>>2]>>2]|0)!=7:0)io(t[a>>2]|0,1902,132152,0);else t[o>>2]=En(t[a>>2]|0)|0;do{t[c>>2]=En(t[a>>2]|0)|0;if(t[c>>2]|0){do if((t[c>>2]|0)!=(t[l>>2]|0)){if((t[t[c>>2]>>2]|0)!=1){t[b>>2]=(t[b>>2]|0)+1;break}t[k>>2]=t[(t[c>>2]|0)+4>>2];if((t[t[k>>2]>>2]|0)==1?(t[t[(t[k>>2]|0)+8>>2]>>2]|0)==(t[t[u>>2]>>2]|0):0)break;t[b>>2]=(t[b>>2]|0)+1}while(0);_n(t[c>>2]|0)}}while((t[c>>2]|0)!=0);if(t[b>>2]|0)io(t[a>>2]|0,1903,132208,0);if(t[(t[a>>2]|0)+8>>2]|0){_n(t[o>>2]|0);t[o>>2]=0}_f(t[a>>2]|0);t[n>>2]=t[o>>2];h=t[n>>2]|0;s=r;return h|0}function Va(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0;r=s;s=s+32|0;n=r;f=r+16|0;u=r+12|0;a=r+8|0;t[u>>2]=e;t[a>>2]=i;e:while(1){if(!(t[u>>2]|0)){o=4;break}if((t[(t[u>>2]|0)+4>>2]|0)==18){o=4;break}if(t[(t[u>>2]|0)+12>>2]|0){t[u>>2]=t[(t[u>>2]|0)+12>>2];if(t[a>>2]|0){i=t[a>>2]|0;t[i>>2]=(t[i>>2]|0)+1;o=17}else o=17}i:while(1){if((o|0)==17){o=0;if((t[(t[u>>2]|0)+4>>2]|0)==1){o=24;break e}if((t[(t[u>>2]|0)+4>>2]|0)==3){o=24;break e}if((t[(t[u>>2]|0)+4>>2]|0)==9){o=24;break e}if((t[(t[u>>2]|0)+4>>2]|0)==13){o=24;break e}if((t[(t[u>>2]|0)+4>>2]|0)==4){o=24;break e}if((t[(t[u>>2]|0)+4>>2]|0)!=5)continue e;i=t[33976]|0;e=t[33980]|0;t[n>>2]=131976;t[n+4>>2]=2362;yAi[i&511](e,132256,n)}if(t[(t[u>>2]|0)+24>>2]|0){t[u>>2]=t[(t[u>>2]|0)+24>>2];o=17;continue}while(1){t[u>>2]=t[(t[u>>2]|0)+20>>2];if(t[a>>2]|0){e=t[a>>2]|0;t[e>>2]=(t[e>>2]|0)+-1}if(!(t[u>>2]|0)){o=13;break e}c=t[u>>2]|0;if(t[(t[u>>2]|0)+24>>2]|0)break;if(!c){o=17;continue i}}t[u>>2]=t[c+24>>2];o=17}}if((o|0)==4){t[f>>2]=0;l=t[f>>2]|0;s=r;return l|0}else if((o|0)==13){t[f>>2]=0;l=t[f>>2]|0;s=r;return l|0}else if((o|0)==24){t[f>>2]=t[u>>2];l=t[f>>2]|0;s=r;return l|0}return 0}function qa(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i;n=i+4|0;t[n>>2]=e;e=t[n>>2]|0;t[r>>2]=t[n>>2];cp(0,0,0,0,0,13,2,2,0,0,e,0,0,0,0,132472,r);s=i;return}function Ya(e){e=e|0;var i=0,r=0,n=0,f=0;i=s;s=s+16|0;r=i+8|0;n=i+4|0;f=i;t[r>>2]=e;if(!(t[r>>2]|0)){s=i;return}if((t[t[r>>2]>>2]|0)!=6){s=i;return}if(!(t[(t[r>>2]|0)+36>>2]|0)){s=i;return}t[n>>2]=ro(t[(t[r>>2]|0)+28>>2]|0,t[(t[r>>2]|0)+32>>2]|0,t[(t[r>>2]|0)+36>>2]|0,t[(t[r>>2]|0)+40>>2]|0)|0;if((t[n>>2]|0)!=-1){s=i;return}t[f>>2]=t[(t[r>>2]|0)+28>>2];t[(t[r>>2]|0)+28>>2]=t[(t[r>>2]|0)+36>>2];t[(t[r>>2]|0)+36>>2]=t[f>>2];t[n>>2]=t[(t[r>>2]|0)+32>>2];t[(t[r>>2]|0)+32>>2]=t[(t[r>>2]|0)+40>>2];t[(t[r>>2]|0)+40>>2]=t[n>>2];s=i;return}function Ga(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0;r=s;s=s+16|0;n=r+8|0;f=r+4|0;u=r;t[f>>2]=e;t[u>>2]=i;do if((t[f>>2]|0)!=(t[u>>2]|0)){if((t[f>>2]|0)==0|(t[u>>2]|0)==0){t[n>>2]=0;break}if((t[t[f>>2]>>2]|0)!=(t[t[u>>2]>>2]|0)){t[n>>2]=0;break}if((t[t[f>>2]>>2]|0)!=6){t[n>>2]=0;break}if((t[(t[f>>2]|0)+28>>2]|0)!=(t[(t[u>>2]|0)+28>>2]|0)){t[n>>2]=0;break}if((t[(t[f>>2]|0)+32>>2]|0)!=(t[(t[u>>2]|0)+32>>2]|0)){t[n>>2]=0;break}if((t[(t[f>>2]|0)+36>>2]|0)!=(t[(t[u>>2]|0)+36>>2]|0)){t[n>>2]=0;break}if((t[(t[f>>2]|0)+40>>2]|0)!=(t[(t[u>>2]|0)+40>>2]|0)){t[n>>2]=0;break}else{t[n>>2]=1;break}}else t[n>>2]=1;while(0);s=r;return t[n>>2]|0}function Wa(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0;r=s;s=s+32|0;n=r+24|0;f=r+20|0;u=r+16|0;a=r+12|0;o=r+8|0;c=r+4|0;l=r;t[n>>2]=e;t[f>>2]=i;if(!(t[n>>2]|0)){s=r;return}i=t[n>>2]|0;if((t[f>>2]|0)!=1){dn(i,12);s=r;return}f=t[n>>2]|0;if((t[i+20>>2]|0)<((t[(t[n>>2]|0)+44>>2]|0)+1|0)){dn(f,23);s=r;return}do if(t[f+16>>2]|0){if((t[t[(t[n>>2]|0)+16>>2]>>2]|0)!=7?(t[t[(t[n>>2]|0)+16>>2]>>2]|0)!=1:0)break;t[a>>2]=En(t[n>>2]|0)|0;do if((t[t[a>>2]>>2]|0)==1){t[l>>2]=Ha(t[(t[a>>2]|0)+4>>2]|0)|0;_n(t[a>>2]|0);if(t[l>>2]|0){t[a>>2]=t[l>>2];break}dn(t[n>>2]|0,15);s=r;return}while(0);t[o>>2]=t[(t[a>>2]|0)+28>>2];t[c>>2]=Da(0)|0;if(!(t[c>>2]|0)){_n(t[a>>2]|0);dn(t[n>>2]|0,15);s=r;return}t[u>>2]=0;while(1){if((t[u>>2]|0)>=(t[t[o>>2]>>2]|0))break;i=t[c>>2]|0;Ca(i,no(t[n>>2]|0,t[(t[(t[o>>2]|0)+8>>2]|0)+(t[u>>2]<<2)>>2]|0)|0);t[u>>2]=(t[u>>2]|0)+1}i=t[n>>2]|0;Sn(i,xa(t[c>>2]|0)|0)|0;_n(t[a>>2]|0);s=r;return}while(0);dn(t[n>>2]|0,11);s=r;return}function Ka(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0;r=s;s=s+32|0;n=r+24|0;f=r+20|0;u=r+16|0;a=r+12|0;o=r+8|0;c=r+4|0;l=r;t[n>>2]=e;t[f>>2]=i;if(!(t[n>>2]|0)){s=r;return}i=t[n>>2]|0;if((t[f>>2]|0)!=1){dn(i,12);s=r;return}f=t[n>>2]|0;if((t[i+20>>2]|0)<((t[(t[n>>2]|0)+44>>2]|0)+1|0)){dn(f,23);s=r;return}do if(t[f+16>>2]|0){if((t[t[(t[n>>2]|0)+16>>2]>>2]|0)!=7?(t[t[(t[n>>2]|0)+16>>2]>>2]|0)!=1:0)break;t[a>>2]=En(t[n>>2]|0)|0;do if((t[t[a>>2]>>2]|0)==1){t[l>>2]=Ha(t[(t[a>>2]|0)+4>>2]|0)|0;_n(t[a>>2]|0);if(t[l>>2]|0){t[a>>2]=t[l>>2];break}dn(t[n>>2]|0,15);s=r;return}while(0);t[o>>2]=t[(t[a>>2]|0)+28>>2];t[c>>2]=Da(0)|0;if(!(t[c>>2]|0)){_n(t[a>>2]|0);dn(t[n>>2]|0,15);s=r;return}t[u>>2]=0;while(1){if((t[u>>2]|0)>=(t[t[o>>2]>>2]|0))break;i=t[c>>2]|0;Ca(i,fo(t[n>>2]|0,t[(t[(t[o>>2]|0)+8>>2]|0)+(t[u>>2]<<2)>>2]|0)|0);t[u>>2]=(t[u>>2]|0)+1}i=t[n>>2]|0;Sn(i,xa(t[c>>2]|0)|0)|0;_n(t[a>>2]|0);s=r;return}while(0);dn(t[n>>2]|0,11);s=r;return}function Xa(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,a=0,o=0,c=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0,S=0,g=0,y=0,F=0,O=0,A=0,M=0;r=s;s=s+96|0;n=r+80|0;f=r+76|0;a=r+72|0;o=r+68|0;c=r+64|0;b=r+60|0;k=r+56|0;h=r+52|0;w=r+48|0;d=r+44|0;v=r+40|0;m=r+36|0;_=r+32|0;p=r+28|0;E=r+24|0;S=r+20|0;g=r+16|0;y=r+12|0;F=r+8|0;O=r+4|0;A=r;t[n>>2]=e;t[f>>2]=i;t[c>>2]=0;t[h>>2]=0;t[p>>2]=0;t[E>>2]=0;t[g>>2]=0;t[y>>2]=0;if((t[f>>2]|0)<2|(t[f>>2]|0)>4){dn(t[n>>2]|0,12);s=r;return}do if((t[f>>2]|0)>=4){if((t[(t[n>>2]|0)+16>>2]|0)!=0?(t[t[(t[n>>2]|0)+16>>2]>>2]|0)==3:0){t[E>>2]=En(t[n>>2]|0)|0;if(!(t[E>>2]|0))break;t[y>>2]=~~+l[(t[E>>2]|0)+16>>3];break}dn(t[n>>2]|0,11);s=r;return}while(0);do if((t[f>>2]|0)>=3){if((t[(t[n>>2]|0)+16>>2]|0)!=0?(t[t[(t[n>>2]|0)+16>>2]>>2]|0)==3:0){t[p>>2]=En(t[n>>2]|0)|0;if(!(t[p>>2]|0))break;t[g>>2]=~~+l[(t[p>>2]|0)+16>>3];break}dn(t[n>>2]|0,11);s=r;return}while(0);if((t[(t[n>>2]|0)+16>>2]|0)!=0?(t[t[(t[n>>2]|0)+16>>2]>>2]|0)==4:0){t[_>>2]=En(t[n>>2]|0)|0;do if(t[(t[n>>2]|0)+16>>2]|0){if((t[t[(t[n>>2]|0)+16>>2]>>2]|0)!=7?(t[t[(t[n>>2]|0)+16>>2]>>2]|0)!=1:0)break;t[d>>2]=En(t[n>>2]|0)|0;t[m>>2]=Da(0)|0;f=t[d>>2]|0;if(!(t[m>>2]|0)){_n(f);dn(t[n>>2]|0,15);s=r;return}e:do if(t[f+4>>2]|0){do if((t[t[d>>2]>>2]|0)==1){t[F>>2]=Ha(t[(t[d>>2]|0)+4>>2]|0)|0;_n(t[d>>2]|0);if(t[F>>2]|0){t[d>>2]=t[F>>2];break}dn(t[n>>2]|0,15);s=r;return}while(0);t[v>>2]=t[(t[d>>2]|0)+28>>2];t[a>>2]=0;while(1){if((t[a>>2]|0)>=(t[t[v>>2]>>2]|0))break e;to(t[(t[(t[v>>2]|0)+8>>2]|0)+(t[a>>2]<<2)>>2]|0,k,o)|0;uo(t[(t[(t[v>>2]|0)+8>>2]|0)+(t[a>>2]<<2)>>2]|0,h,c)|0;ao(k,o,0)|0;oo(h,c)|0;do{t[w>>2]=t[h>>2];t[b>>2]=t[c>>2];t[S>>2]=co(t[(t[_>>2]|0)+24>>2]|0,k,o,w,b)|0;if((t[S>>2]|0)==1){do if(t[p>>2]|0){if(ao(k,o,(t[g>>2]|0)-1|0)|0)break;if((t[E>>2]|0)!=0&(t[y>>2]|0)>0){t[A>>2]=t[k>>2];t[O>>2]=(t[o>>2]|0)-1;if(ao(A,O,t[y>>2]|0)|0)break;i=t[m>>2]|0;Ca(i,Ra(t[k>>2]|0,t[o>>2]|0,t[A>>2]|0,t[O>>2]|0)|0);break}i=t[m>>2]|0;e=t[k>>2]|0;M=t[o>>2]|0;if((t[E>>2]|0)!=0&(t[y>>2]|0)<=0){Ca(i,Ra(e,M,t[k>>2]|0,t[o>>2]|0)|0);break}else{Ca(i,Ra(e,M,t[w>>2]|0,t[b>>2]|0)|0);break}}else{M=t[m>>2]|0;Ca(M,Ra(t[k>>2]|0,t[o>>2]|0,t[w>>2]|0,t[b>>2]|0)|0)}while(0);t[k>>2]=t[w>>2];t[o>>2]=t[b>>2];if(!(u[t[(t[_>>2]|0)+24>>2]>>0]|0))t[o>>2]=(t[o>>2]|0)+1}}while((t[S>>2]|0)==1);t[a>>2]=(t[a>>2]|0)+1}}while(0);f=t[n>>2]|0;Sn(f,xa(t[m>>2]|0)|0)|0;_n(t[d>>2]|0);_n(t[_>>2]|0);if(t[p>>2]|0)_n(t[p>>2]|0);if(!(t[E>>2]|0)){s=r;return}_n(t[E>>2]|0);s=r;return}while(0);dn(t[n>>2]|0,11);s=r;return}dn(t[n>>2]|0,11);s=r;return}function Za(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0;r=s;s=s+48|0;n=r+32|0;f=r+28|0;u=r+24|0;a=r+20|0;o=r+16|0;c=r+12|0;l=r+8|0;b=r+4|0;k=r;t[n>>2]=e;t[f>>2]=i;t[c>>2]=0;t[l>>2]=0;if(!(t[n>>2]|0)){s=r;return}i=t[n>>2]|0;if((t[f>>2]|0)!=1){dn(i,12);s=r;return}f=t[n>>2]|0;if((t[i+20>>2]|0)<((t[(t[n>>2]|0)+44>>2]|0)+1|0)){dn(f,23);s=r;return}do if(t[f+16>>2]|0){if((t[t[(t[n>>2]|0)+16>>2]>>2]|0)!=7?(t[t[(t[n>>2]|0)+16>>2]>>2]|0)!=1:0)break;t[a>>2]=En(t[n>>2]|0)|0;do if((t[t[a>>2]>>2]|0)==1){t[u>>2]=Ha(t[(t[a>>2]|0)+4>>2]|0)|0;_n(t[a>>2]|0);if(t[u>>2]|0){t[a>>2]=t[u>>2];break}dn(t[n>>2]|0,15);s=r;return}while(0);t[c>>2]=Da(0)|0;i=t[a>>2]|0;if(!(t[c>>2]|0)){_n(i);dn(t[n>>2]|0,15);s=r;return}t[l>>2]=t[i+28>>2];e:do if(t[l>>2]|0){t[b>>2]=0;while(1){if((t[b>>2]|0)>=(t[t[l>>2]>>2]|0))break e;t[u>>2]=t[(t[(t[l>>2]|0)+8>>2]|0)+(t[b>>2]<<2)>>2];if(t[u>>2]|0){t[o>>2]=0;i=t[t[u>>2]>>2]|0;if((i|0)==5)t[o>>2]=lo(t[(t[u>>2]|0)+28>>2]|0,t[(t[u>>2]|0)+32>>2]|0)|0;else if((i|0)==6?(t[k>>2]=t[(t[u>>2]|0)+28>>2],(t[k>>2]|0)!=0):0){if((t[(t[k>>2]|0)+4>>2]|0)==2)break;t[o>>2]=lo(t[k>>2]|0,t[(t[u>>2]|0)+32>>2]|0)|0;
	}if(t[o>>2]|0)Ca(t[c>>2]|0,t[o>>2]|0)}t[b>>2]=(t[b>>2]|0)+1}_n(t[a>>2]|0);Ba(t[c>>2]|0);dn(t[n>>2]|0,16);s=r;return}while(0);_n(t[a>>2]|0);i=t[n>>2]|0;Sn(i,xa(t[c>>2]|0)|0)|0;s=r;return}while(0);dn(t[n>>2]|0,11);s=r;return}function Ja(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0;r=s;s=s+48|0;n=r+32|0;f=r+28|0;u=r+24|0;a=r+20|0;o=r+16|0;c=r+12|0;l=r+8|0;b=r+4|0;k=r;t[n>>2]=e;t[f>>2]=i;t[c>>2]=0;t[l>>2]=0;if(!(t[n>>2]|0)){s=r;return}i=t[n>>2]|0;if((t[f>>2]|0)!=1){dn(i,12);s=r;return}f=t[n>>2]|0;if((t[i+20>>2]|0)<((t[(t[n>>2]|0)+44>>2]|0)+1|0)){dn(f,23);s=r;return}do if(t[f+16>>2]|0){if((t[t[(t[n>>2]|0)+16>>2]>>2]|0)!=7?(t[t[(t[n>>2]|0)+16>>2]>>2]|0)!=1:0)break;t[a>>2]=En(t[n>>2]|0)|0;do if((t[t[a>>2]>>2]|0)==1){t[u>>2]=Ha(t[(t[a>>2]|0)+4>>2]|0)|0;_n(t[a>>2]|0);if(t[u>>2]|0){t[a>>2]=t[u>>2];break}dn(t[n>>2]|0,15);s=r;return}while(0);t[c>>2]=Da(0)|0;i=t[a>>2]|0;if(!(t[c>>2]|0)){_n(i);dn(t[n>>2]|0,15);s=r;return}t[l>>2]=t[i+28>>2];e:do if(t[l>>2]|0){t[b>>2]=0;i:while(1){if((t[b>>2]|0)>=(t[t[l>>2]>>2]|0))break e;t[u>>2]=t[(t[(t[l>>2]|0)+8>>2]|0)+(t[b>>2]<<2)>>2];if(t[u>>2]|0){t[o>>2]=0;i=t[t[u>>2]>>2]|0;do if((i|0)==6){t[k>>2]=t[(t[u>>2]|0)+36>>2];if(t[k>>2]|0){if((t[(t[k>>2]|0)+4>>2]|0)==2)break i;t[o>>2]=lo(t[k>>2]|0,t[(t[u>>2]|0)+40>>2]|0)|0;break}else{if(t[(t[u>>2]|0)+28>>2]|0)break;e=t[k>>2]|0;t[o>>2]=lo(e,so(t[k>>2]|0)|0)|0;break}}else if((i|0)==5)t[o>>2]=lo(t[(t[u>>2]|0)+28>>2]|0,t[(t[u>>2]|0)+32>>2]|0)|0;while(0);if(t[o>>2]|0)Ca(t[c>>2]|0,t[o>>2]|0)}t[b>>2]=(t[b>>2]|0)+1}_n(t[a>>2]|0);Ba(t[c>>2]|0);dn(t[n>>2]|0,16);s=r;return}while(0);_n(t[a>>2]|0);i=t[n>>2]|0;Sn(i,xa(t[c>>2]|0)|0)|0;s=r;return}while(0);dn(t[n>>2]|0,11);s=r;return}function Qa(e,i){e=e|0;i=i|0;var r=0,n=0,f=0;r=s;s=s+16|0;n=r+4|0;f=r;t[n>>2]=e;t[f>>2]=i;if(!(t[n>>2]|0)){s=r;return}i=t[n>>2]|0;if(t[f>>2]|0){dn(i,12);s=r;return}f=t[n>>2]|0;if((t[i+20>>2]|0)<((t[(t[n>>2]|0)+44>>2]|0)+0|0)){dn(f,23);s=r;return}i=t[n>>2]|0;if(!(t[(t[f+12>>2]|0)+80>>2]|0)){dn(i,16);s=r;return}else{Sn(i,Ia(t[(t[(t[n>>2]|0)+12>>2]|0)+80>>2]|0,0)|0)|0;s=r;return}}function $a(e,i){e=e|0;i=i|0;var r=0,n=0,f=0;r=s;s=s+16|0;n=r+4|0;f=r;t[n>>2]=e;t[f>>2]=i;if(!(t[n>>2]|0)){s=r;return}i=t[n>>2]|0;if(t[f>>2]|0){dn(i,12);s=r;return}f=t[n>>2]|0;if((t[i+20>>2]|0)<((t[(t[n>>2]|0)+44>>2]|0)+0|0)){dn(f,23);s=r;return}i=t[n>>2]|0;if(!(t[(t[f+12>>2]|0)+84>>2]|0)){dn(i,16);s=r;return}else{Sn(i,Ia(t[(t[(t[n>>2]|0)+12>>2]|0)+84>>2]|0,0)|0)|0;s=r;return}}function eo(e){e=e|0;var i=0,r=0,n=0,f=0,a=0,o=0,c=0,l=0,b=0;i=s;s=s+16|0;r=i+4|0;n=i;t[r>>2]=e;do if(!(t[(t[r>>2]|0)+28>>2]|0)){e=gAi[t[135744>>2]&511](40)|0;t[(t[r>>2]|0)+28>>2]=e;if(t[(t[r>>2]|0)+28>>2]|0){t[(t[r>>2]|0)+20>>2]=0;t[(t[r>>2]|0)+24>>2]=10;t[(t[r>>2]|0)+16>>2]=0;t[(t[r>>2]|0)+44>>2]=0;break}qa(132312);s=i;return}while(0);while(1){do if((u[t[t[r>>2]>>2]>>0]|0|0)==32)f=1;else{if(9<=(u[t[t[r>>2]>>2]>>0]|0|0)?(u[t[t[r>>2]>>2]>>0]|0|0)<=10:0){f=1;break}f=(u[t[t[r>>2]>>2]>>0]|0|0)==13}while(0);a=u[t[t[r>>2]>>2]>>0]|0;if(!f)break;e=t[r>>2]|0;if(!a)continue;t[e>>2]=(t[e>>2]|0)+1}f=t[r>>2]|0;do if((a|0)==47){jf(f);bo(t[r>>2]|0,0)}else{t[n>>2]=wt(f)|0;e=t[r>>2]|0;if(!(t[n>>2]|0)){dn(e,7);s=i;return}o=t[r>>2]|0;c=t[n>>2]|0;if((u[t[e>>2]>>0]|0|0)!=40){bo(o,c);break}ko(o,c);s=i;return}while(0);while(1){do if((u[t[t[r>>2]>>2]>>0]|0|0)==32)l=1;else{if(9<=(u[t[t[r>>2]>>2]>>0]|0|0)?(u[t[t[r>>2]>>2]>>0]|0|0)<=10:0){l=1;break}l=(u[t[t[r>>2]>>2]>>0]|0|0)==13}while(0);b=(u[t[t[r>>2]>>2]>>0]|0|0)!=0;if(!l)break;n=t[r>>2]|0;if(!b)continue;t[n>>2]=(t[n>>2]|0)+1}if(!b){s=i;return}dn(t[r>>2]|0,7);s=i;return}function io(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,u=0,a=0,o=0,c=0,l=0,b=0;f=s;s=s+32|0;u=f;a=f+16|0;o=f+12|0;c=f+8|0;l=f+4|0;t[a>>2]=e;t[o>>2]=i;t[c>>2]=r;t[l>>2]=n;if(t[a>>2]|0)t[(t[a>>2]|0)+8>>2]=t[o>>2];if((t[a>>2]|0)!=0?(t[(t[a>>2]|0)+12>>2]|0)!=0:0){t[(t[(t[a>>2]|0)+12>>2]|0)+136>>2]=13;t[(t[(t[a>>2]|0)+12>>2]|0)+140>>2]=t[o>>2];t[(t[(t[a>>2]|0)+12>>2]|0)+148>>2]=2;n=Yl(t[(t[a>>2]|0)+4>>2]|0)|0;t[(t[(t[a>>2]|0)+12>>2]|0)+160>>2]=n;t[(t[(t[a>>2]|0)+12>>2]|0)+172>>2]=(t[t[a>>2]>>2]|0)-(t[(t[a>>2]|0)+4>>2]|0);t[(t[(t[a>>2]|0)+12>>2]|0)+184>>2]=t[(t[(t[a>>2]|0)+12>>2]|0)+188>>2];n=t[(t[a>>2]|0)+12>>2]|0;if(t[(t[(t[a>>2]|0)+12>>2]|0)+132>>2]|0){EAi[t[n+132>>2]&511](t[(t[(t[a>>2]|0)+12>>2]|0)+128>>2]|0,(t[(t[a>>2]|0)+12>>2]|0)+136|0);s=f;return}else{r=t[n+188>>2]|0;n=t[o>>2]|0;i=t[l>>2]|0;e=t[(t[a>>2]|0)+4>>2]|0;b=(t[t[a>>2]>>2]|0)-(t[(t[a>>2]|0)+4>>2]|0)|0;a=t[c>>2]|0;t[u>>2]=t[l>>2];cp(0,0,0,0,r,13,n,2,0,0,i,e,0,b,0,a,u);s=f;return}}a=t[o>>2]|0;o=t[l>>2]|0;b=t[c>>2]|0;t[u>>2]=t[l>>2];cp(0,0,0,0,0,13,a,2,0,0,o,0,0,0,0,b,u);s=f;return}function ro(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,u=0,a=0,o=0,c=0,l=0;f=s;s=s+32|0;u=f+16|0;a=f+12|0;o=f+8|0;c=f+4|0;l=f;t[a>>2]=e;t[o>>2]=i;t[c>>2]=r;t[l>>2]=n;do if(!((t[a>>2]|0)==0|(t[c>>2]|0)==0)){if((t[a>>2]|0)!=(t[c>>2]|0)){t[u>>2]=An(t[a>>2]|0,t[c>>2]|0)|0;break}if((t[o>>2]|0)<(t[l>>2]|0)){t[u>>2]=1;break}if((t[o>>2]|0)>(t[l>>2]|0)){t[u>>2]=-1;break}else{t[u>>2]=0;break}}else t[u>>2]=-2;while(0);s=f;return t[u>>2]|0}function no(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0;r=s;s=s+32|0;n=r;f=r+24|0;u=r+20|0;a=r+16|0;o=r+12|0;c=r+8|0;t[u>>2]=e;t[a>>2]=i;if(!(t[a>>2]|0)){t[f>>2]=0;l=t[f>>2]|0;s=r;return l|0}if(((t[u>>2]|0)!=0?(t[(t[u>>2]|0)+12>>2]|0)!=0:0)?(t[t[(t[u>>2]|0)+12>>2]>>2]|0)!=0:0){i=t[t[a>>2]>>2]|0;if((i|0)==6){e=t[(t[a>>2]|0)+28>>2]|0;if(t[(t[a>>2]|0)+36>>2]|0){t[f>>2]=Ra(e,t[(t[a>>2]|0)+32>>2]|0,t[(t[a>>2]|0)+36>>2]|0,t[(t[a>>2]|0)+40>>2]|0)|0;l=t[f>>2]|0;s=r;return l|0}t[o>>2]=e;e=t[o>>2]|0;if((t[o>>2]|0)==(t[t[(t[u>>2]|0)+12>>2]>>2]|0)){u=t[o>>2]|0;t[f>>2]=Ra(e,0,u,wo(t[o>>2]|0)|0)|0;l=t[f>>2]|0;s=r;return l|0}switch(t[e+4>>2]|0){case 13:case 12:case 9:case 8:case 7:case 5:case 4:case 3:case 1:{t[c>>2]=vo(t[o>>2]|0)|0;t[o>>2]=t[(t[o>>2]|0)+20>>2];t[f>>2]=Ra(t[o>>2]|0,(t[c>>2]|0)-1|0,t[o>>2]|0,(t[c>>2]|0)+1|0)|0;l=t[f>>2]|0;s=r;return l|0}case 2:{t[f>>2]=Ra(t[o>>2]|0,0,t[o>>2]|0,wo(t[o>>2]|0)|0)|0;l=t[f>>2]|0;s=r;return l|0}default:{t[f>>2]=0;l=t[f>>2]|0;s=r;return l|0}}}else if((i|0)==5){t[f>>2]=Ra(t[(t[a>>2]|0)+28>>2]|0,t[(t[a>>2]|0)+32>>2]|0,t[(t[a>>2]|0)+28>>2]|0,t[(t[a>>2]|0)+32>>2]|0)|0;l=t[f>>2]|0;s=r;return l|0}else{a=t[33976]|0;i=t[33980]|0;t[n>>2]=131976;t[n+4>>2]=2022;yAi[a&511](i,132256,n);t[f>>2]=0;l=t[f>>2]|0;s=r;return l|0}}t[f>>2]=0;l=t[f>>2]|0;s=r;return l|0}function fo(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0;r=s;s=s+32|0;n=r;f=r+24|0;u=r+20|0;a=r+16|0;o=r+12|0;c=r+8|0;t[u>>2]=e;t[a>>2]=i;e:do if(!(t[a>>2]|0))t[f>>2]=0;else{if(((t[u>>2]|0)!=0?(t[(t[u>>2]|0)+12>>2]|0)!=0:0)?(t[t[(t[u>>2]|0)+12>>2]>>2]|0)!=0:0){i=t[t[a>>2]>>2]|0;if((i|0)==5){t[o>>2]=t[(t[a>>2]|0)+28>>2];switch(t[(t[o>>2]|0)+4>>2]|0){case 4:case 3:case 8:case 7:{e=t[o>>2]|0;l=t[o>>2]|0;if(!(t[(t[o>>2]|0)+40>>2]|0)){t[f>>2]=Ra(e,0,l,0)|0;break e}else{t[f>>2]=Ra(e,0,l,rs(t[(t[o>>2]|0)+40>>2]|0)|0)|0;break e}break}case 13:case 12:case 9:case 5:case 1:case 2:{t[f>>2]=Ra(t[o>>2]|0,0,t[o>>2]|0,wo(t[o>>2]|0)|0)|0;break e;break}default:{t[f>>2]=0;break e}}}else if((i|0)==6){t[c>>2]=t[(t[a>>2]|0)+28>>2];i=t[c>>2]|0;if(t[(t[a>>2]|0)+36>>2]|0){t[f>>2]=Ra(i,t[(t[a>>2]|0)+32>>2]|0,t[(t[a>>2]|0)+36>>2]|0,t[(t[a>>2]|0)+40>>2]|0)|0;break}switch(t[i+4>>2]|0){case 13:case 12:case 9:case 5:case 1:case 2:{t[f>>2]=Ra(t[c>>2]|0,0,t[c>>2]|0,wo(t[c>>2]|0)|0)|0;break e;break}case 4:case 3:case 8:case 7:{i=t[c>>2]|0;l=t[c>>2]|0;if(!(t[(t[c>>2]|0)+40>>2]|0)){t[f>>2]=Ra(i,0,l,0)|0;break e}else{t[f>>2]=Ra(i,0,l,rs(t[(t[c>>2]|0)+40>>2]|0)|0)|0;break e}break}default:{t[f>>2]=0;break e}}}else{l=t[33976]|0;i=t[33980]|0;t[n>>2]=131976;t[n+4>>2]=2167;yAi[l&511](i,132256,n);t[f>>2]=0;break}}t[f>>2]=0}while(0);s=r;return t[f>>2]|0}function to(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0;n=s;s=s+16|0;f=n+12|0;u=n+8|0;a=n+4|0;o=n;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;if((t[u>>2]|0)==0|(t[a>>2]|0)==0|(t[o>>2]|0)==0){t[f>>2]=-1;c=t[f>>2]|0;s=n;return c|0}r=t[t[u>>2]>>2]|0;if((r|0)==5){t[t[a>>2]>>2]=t[(t[u>>2]|0)+28>>2];if((t[(t[u>>2]|0)+32>>2]|0)<=0)t[t[o>>2]>>2]=0;else t[t[o>>2]>>2]=t[(t[u>>2]|0)+32>>2];t[f>>2]=0;c=t[f>>2]|0;s=n;return c|0}else if((r|0)==6){t[t[a>>2]>>2]=t[(t[u>>2]|0)+28>>2];if((t[(t[u>>2]|0)+32>>2]|0)<=0)t[t[o>>2]>>2]=0;else t[t[o>>2]>>2]=t[(t[u>>2]|0)+32>>2];t[f>>2]=0;c=t[f>>2]|0;s=n;return c|0}else{t[f>>2]=-1;c=t[f>>2]|0;s=n;return c|0}return 0}function uo(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0;n=s;s=s+16|0;f=n+12|0;u=n+8|0;a=n+4|0;o=n;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;if((t[u>>2]|0)==0|(t[a>>2]|0)==0|(t[o>>2]|0)==0){t[f>>2]=-1;c=t[f>>2]|0;s=n;return c|0}r=t[t[u>>2]>>2]|0;if((r|0)==6){t[t[a>>2]>>2]=t[(t[u>>2]|0)+28>>2];if((t[(t[u>>2]|0)+32>>2]|0)<=0)t[t[o>>2]>>2]=0;else t[t[o>>2]>>2]=t[(t[u>>2]|0)+32>>2];t[f>>2]=0;c=t[f>>2]|0;s=n;return c|0}else if((r|0)==5){t[t[a>>2]>>2]=t[(t[u>>2]|0)+28>>2];if((t[(t[u>>2]|0)+32>>2]|0)<=0)t[t[o>>2]>>2]=0;else t[t[o>>2]>>2]=t[(t[u>>2]|0)+32>>2];t[f>>2]=0;c=t[f>>2]|0;s=n;return c|0}else{t[f>>2]=-1;c=t[f>>2]|0;s=n;return c|0}return 0}function ao(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0;n=s;s=s+48|0;f=n;u=n+32|0;a=n+28|0;o=n+24|0;c=n+20|0;l=n+16|0;b=n+12|0;k=n+8|0;t[a>>2]=e;t[o>>2]=i;t[c>>2]=r;if((t[a>>2]|0)==0|(t[o>>2]|0)==0){t[u>>2]=-1;h=t[u>>2]|0;s=n;return h|0}t[l>>2]=t[t[a>>2]>>2];if((t[l>>2]|0)!=0?(t[(t[l>>2]|0)+4>>2]|0)!=18:0){t[b>>2]=t[t[o>>2]>>2];while(1){if((t[c>>2]|0)<0){w=30;break}while(1){if(!(t[l>>2]|0))break;if(((t[(t[l>>2]|0)+4>>2]|0)!=1?(t[(t[l>>2]|0)+4>>2]|0)!=9:0)?(t[(t[l>>2]|0)+4>>2]|0)!=13:0)break;r=t[l>>2]|0;if((t[b>>2]|0)>0){t[l>>2]=ho(r,t[b>>2]|0)|0;t[b>>2]=0;continue}else{t[l>>2]=Va(r,0)|0;t[b>>2]=0;continue}}if(!(t[l>>2]|0)){w=16;break}if(!(t[b>>2]|0))t[b>>2]=1;if(!(t[c>>2]|0)){w=20;break}t[k>>2]=0;if((t[(t[l>>2]|0)+4>>2]|0)!=1?(t[(t[l>>2]|0)+40>>2]|0)!=0:0)t[k>>2]=rs(t[(t[l>>2]|0)+40>>2]|0)|0;if((t[b>>2]|0)>(t[k>>2]|0)){r=t[33976]|0;i=t[33980]|0;t[f>>2]=131976;t[f+4>>2]=2436;yAi[r&511](i,131944,f);t[b>>2]=t[k>>2]}if(((t[b>>2]|0)+(t[c>>2]|0)|0)<(t[k>>2]|0))if(((t[b>>2]|0)+(t[c>>2]|0)|0)<(t[k>>2]|0)){w=29;break}else continue;else{t[c>>2]=(t[c>>2]|0)-((t[k>>2]|0)-(t[b>>2]|0));t[l>>2]=Va(t[l>>2]|0,0)|0;t[b>>2]=0;continue}}if((w|0)==16){t[t[a>>2]>>2]=0;t[t[o>>2]>>2]=0;t[u>>2]=-1;h=t[u>>2]|0;s=n;return h|0}else if((w|0)==20){t[t[a>>2]>>2]=t[l>>2];t[t[o>>2]>>2]=t[b>>2];t[u>>2]=0;h=t[u>>2]|0;s=n;return h|0}else if((w|0)==29){t[b>>2]=(t[b>>2]|0)+(t[c>>2]|0);t[t[a>>2]>>2]=t[l>>2];t[t[o>>2]>>2]=t[b>>2];t[u>>2]=0;h=t[u>>2]|0;s=n;return h|0}else if((w|0)==30){t[u>>2]=-1;h=t[u>>2]|0;s=n;return h|0}}t[u>>2]=-1;h=t[u>>2]|0;s=n;return h|0}function oo(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0;r=s;s=s+32|0;n=r+20|0;f=r+16|0;u=r+12|0;a=r+8|0;o=r+4|0;c=r;t[f>>2]=e;t[u>>2]=i;t[c>>2]=0;if(((t[f>>2]|0)!=0?(t[t[f>>2]>>2]|0)!=0:0)?!((t[u>>2]|0)==0?1:(t[(t[t[f>>2]>>2]|0)+4>>2]|0)==18):0){t[a>>2]=t[t[f>>2]>>2];t[o>>2]=t[t[u>>2]>>2];if((t[(t[a>>2]|0)+4>>2]|0)!=1?(t[(t[a>>2]|0)+4>>2]|0)!=9:0){if((t[o>>2]|0)>0?(t[(t[a>>2]|0)+4>>2]|0)==13:0)l=9}else l=8;if((l|0)==8?(t[o>>2]|0)>0:0)l=9;if((l|0)==9)t[a>>2]=ho(t[a>>2]|0,t[o>>2]|0)|0;while(1){if(!(t[a>>2]|0))break;b=t[a>>2]|0;if(!(t[(t[a>>2]|0)+16>>2]|0)){l=13;break}t[a>>2]=t[b+16>>2]}do if((l|0)==13){if((t[b+4>>2]|0)!=1?(t[(t[a>>2]|0)+40>>2]|0)!=0:0){t[c>>2]=rs(t[(t[a>>2]|0)+40>>2]|0)|0;break}t[n>>2]=-1;k=t[n>>2]|0;s=r;return k|0}while(0);if(!(t[a>>2]|0)){t[n>>2]=-1;k=t[n>>2]|0;s=r;return k|0}else{t[t[f>>2]>>2]=t[a>>2];t[t[u>>2]>>2]=t[c>>2];t[n>>2]=0;k=t[n>>2]|0;s=r;return k|0}}t[n>>2]=-1;k=t[n>>2]|0;s=r;return k|0}function co(e,i,r,f,a){e=e|0;i=i|0;r=r|0;f=f|0;a=a|0;var o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0,S=0;o=s;s=s+48|0;c=o+36|0;l=o+32|0;b=o+28|0;k=o+24|0;h=o+20|0;w=o+16|0;d=o+12|0;v=o+8|0;m=o+4|0;_=o;p=o+40|0;t[l>>2]=e;t[b>>2]=i;t[k>>2]=r;t[h>>2]=f;t[w>>2]=a;if(!(t[l>>2]|0)){t[c>>2]=-1;E=t[c>>2]|0;s=o;return E|0}if(((t[b>>2]|0)!=0?(t[t[b>>2]>>2]|0)!=0:0)?!((t[k>>2]|0)==0?1:(t[(t[t[b>>2]>>2]|0)+4>>2]|0)==18):0){if((t[h>>2]|0)==0|(t[w>>2]|0)==0){t[c>>2]=-1;E=t[c>>2]|0;s=o;return E|0}t[d>>2]=t[t[b>>2]>>2];t[m>>2]=(t[t[k>>2]>>2]|0)-1;n[p>>0]=n[t[l>>2]>>0]|0;e:while(1){if(!(t[d>>2]|0)){S=28;break}i:do if((t[(t[d>>2]|0)+4>>2]|0)!=1?(t[(t[d>>2]|0)+40>>2]|0)!=0:0){t[_>>2]=rs(t[(t[d>>2]|0)+40>>2]|0)|0;while(1){if((t[m>>2]|0)>(t[_>>2]|0))break i;if(!(u[p>>0]|0)){S=21;break e}t[v>>2]=es((t[(t[d>>2]|0)+40>>2]|0)+(t[m>>2]|0)|0,n[p>>0]|0)|0;if(!(t[v>>2]|0)){t[m>>2]=(t[_>>2]|0)+1;continue}t[m>>2]=(t[v>>2]|0)-(t[(t[d>>2]|0)+40>>2]|0);if(mo(t[l>>2]|0,t[d>>2]|0,(t[m>>2]|0)+1|0,t[h>>2]|0,t[w>>2]|0)|0){S=18;break e}t[m>>2]=(t[m>>2]|0)+1}}while(0);if((t[d>>2]|0)==(t[t[h>>2]>>2]|0)?(t[m>>2]|0)>=(t[t[w>>2]>>2]|0):0){S=24;break}t[d>>2]=Va(t[d>>2]|0,0)|0;if(!(t[d>>2]|0)){S=26;break}t[m>>2]=1}if((S|0)==18){t[t[b>>2]>>2]=t[d>>2];t[t[k>>2]>>2]=(t[m>>2]|0)+1;t[c>>2]=1;E=t[c>>2]|0;s=o;return E|0}else if((S|0)==21){t[t[b>>2]>>2]=t[d>>2];t[t[k>>2]>>2]=(t[m>>2]|0)+1;t[t[h>>2]>>2]=t[d>>2];t[t[w>>2]>>2]=(t[m>>2]|0)+1;t[c>>2]=1;E=t[c>>2]|0;s=o;return E|0}else if((S|0)==24){t[c>>2]=0;E=t[c>>2]|0;s=o;return E|0}else if((S|0)==26){t[c>>2]=0;E=t[c>>2]|0;s=o;return E|0}else if((S|0)==28){t[c>>2]=0;E=t[c>>2]|0;s=o;return E|0}}t[c>>2]=-1;E=t[c>>2]|0;s=o;return E|0}function lo(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0;r=s;s=s+16|0;n=r+12|0;f=r+8|0;u=r+4|0;a=r;t[f>>2]=e;t[u>>2]=i;if(!(t[f>>2]|0)){t[n>>2]=0;o=t[n>>2]|0;s=r;return o|0}if((t[u>>2]|0)<0){t[n>>2]=0;o=t[n>>2]|0;s=r;return o|0}t[a>>2]=gAi[t[135744>>2]&511](48)|0;if(!(t[a>>2]|0)){qa(132288);t[n>>2]=0;o=t[n>>2]|0;s=r;return o|0}else{i=(t[a>>2]|0)+0|0;e=i+48|0;do{t[i>>2]=0;i=i+4|0}while((i|0)<(e|0));t[t[a>>2]>>2]=5;t[(t[a>>2]|0)+28>>2]=t[f>>2];t[(t[a>>2]|0)+32>>2]=t[u>>2];t[n>>2]=t[a>>2];o=t[n>>2]|0;s=r;return o|0}return 0}function so(e){e=e|0;var i=0,r=0,n=0,f=0,u=0;i=s;s=s+16|0;r=i+8|0;n=i+4|0;f=i;t[n>>2]=e;t[f>>2]=0;if(!(t[n>>2]|0)){t[r>>2]=-1;u=t[r>>2]|0;s=i;return u|0}e:do switch(t[(t[n>>2]|0)+4>>2]|0){case 1:case 9:case 13:{t[n>>2]=t[(t[n>>2]|0)+12>>2];while(1){if(!(t[n>>2]|0))break e;if((t[(t[n>>2]|0)+4>>2]|0)==1)t[f>>2]=(t[f>>2]|0)+1;t[n>>2]=t[(t[n>>2]|0)+24>>2]}break}case 2:{t[r>>2]=-1;u=t[r>>2]|0;s=i;return u|0}case 5:case 4:case 3:case 8:case 7:{t[f>>2]=rs(t[(t[n>>2]|0)+40>>2]|0)|0;break}default:{t[r>>2]=-1;u=t[r>>2]|0;s=i;return u|0}}while(0);t[r>>2]=t[f>>2];u=t[r>>2]|0;s=i;return u|0}function bo(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,a=0;r=s;s=s+16|0;n=r+8|0;f=r+4|0;a=r;t[n>>2]=e;t[f>>2]=i;if(((t[f>>2]|0)==0?(u[t[t[n>>2]>>2]>>0]|0|0)==47:0)?(u[(t[t[n>>2]>>2]|0)+1>>0]|0|0)!=49:0)io(t[n>>2]|0,1901,132432,0);if((t[f>>2]|0)!=0?(i=t[n>>2]|0,Sn(i,$n(t[f>>2]|0)|0)|0,pAi[t[135736>>2]&511](t[f>>2]|0),Gf(t[n>>2]|0,1),(t[(t[n>>2]|0)+8>>2]|0)!=0):0){s=r;return}while(1){if((u[t[t[n>>2]>>2]>>0]|0|0)!=47)break;t[a>>2]=0;f=t[n>>2]|0;if(u[t[t[n>>2]>>2]>>0]|0)t[f>>2]=(t[f>>2]|0)+1;while(1){if((u[t[t[n>>2]>>2]>>0]|0|0)<48)break;if((u[t[t[n>>2]>>2]>>0]|0|0)>57)break;t[a>>2]=((t[a>>2]|0)*10|0)+((u[t[t[n>>2]>>2]>>0]|0)-48);f=t[n>>2]|0;if(!(u[t[t[n>>2]>>2]>>0]|0))continue;t[f>>2]=(t[f>>2]|0)+1}_o(t[n>>2]|0,t[a>>2]|0)}s=r;return}function ko(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,a=0,o=0,c=0,l=0,b=0,k=0;r=s;s=s+32|0;n=r+16|0;f=r+12|0;a=r+8|0;o=r+4|0;c=r;t[n>>2]=e;t[f>>2]=i;if(!(t[f>>2]|0))t[f>>2]=wt(t[n>>2]|0)|0;if(!(t[f>>2]|0)){dn(t[n>>2]|0,7);s=r;return}while(1){if(!(t[f>>2]|0)){l=25;break}t[(t[n>>2]|0)+8>>2]=0;po(t[n>>2]|0,t[f>>2]|0);if((t[(t[n>>2]|0)+8>>2]|0)!=0?(t[(t[n>>2]|0)+8>>2]|0)!=1900:0){l=25;break}if(t[(t[n>>2]|0)+16>>2]|0){t[a>>2]=t[(t[n>>2]|0)+16>>2];i=t[t[a>>2]>>2]|0;if((i|0)==7){t[o>>2]=t[(t[(t[n>>2]|0)+16>>2]|0)+28>>2];if((t[o>>2]|0)!=0?(t[t[o>>2]>>2]|0)>0:0){l=25;break}}else if(((i|0)==1?(t[c>>2]=t[(t[(t[n>>2]|0)+16>>2]|0)+4>>2],(t[c>>2]|0)!=0):0)?(t[t[c>>2]>>2]|0)>0:0){l=25;break}do{t[a>>2]=En(t[n>>2]|0)|0;if(t[a>>2]|0)_n(t[a>>2]|0)}while((t[a>>2]|0)!=0)}while(1){do if((u[t[t[n>>2]>>2]>>0]|0|0)==32)b=1;else{if(9<=(u[t[t[n>>2]>>2]>>0]|0|0)?(u[t[t[n>>2]>>2]>>0]|0|0)<=10:0){b=1;break}b=(u[t[t[n>>2]>>2]>>0]|0|0)==13}while(0);k=t[n>>2]|0;if(!b)break;i=t[n>>2]|0;if(!(u[t[k>>2]>>0]|0))continue;t[i>>2]=(t[i>>2]|0)+1}t[f>>2]=wt(k)|0}if((l|0)==25){s=r;return}}function ho(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0;r=s;s=s+16|0;n=r+12|0;f=r+8|0;u=r+4|0;a=r;t[f>>2]=e;t[u>>2]=i;if((t[f>>2]|0)!=0?(t[(t[f>>2]|0)+4>>2]|0)!=18:0){t[f>>2]=t[(t[f>>2]|0)+12>>2];t[a>>2]=0;while(1){if((t[a>>2]|0)>(t[u>>2]|0)){o=13;break}c=t[f>>2]|0;if(!(t[f>>2]|0)){o=7;break}if(!(((t[c+4>>2]|0)!=1?(t[(t[f>>2]|0)+4>>2]|0)!=9:0)?(t[(t[f>>2]|0)+4>>2]|0)!=13:0))o=11;if((o|0)==11?(o=0,t[a>>2]=(t[a>>2]|0)+1,(t[a>>2]|0)==(t[u>>2]|0)):0){o=13;break}t[f>>2]=t[(t[f>>2]|0)+24>>2]}if((o|0)==7){t[n>>2]=c;l=t[n>>2]|0;s=r;return l|0}else if((o|0)==13){t[n>>2]=t[f>>2];l=t[n>>2]|0;s=r;return l|0}}t[n>>2]=t[f>>2];l=t[n>>2]|0;s=r;return l|0}function wo(e){e=e|0;var i=0,r=0,n=0,f=0,u=0;i=s;s=s+16|0;r=i+8|0;n=i+4|0;f=i;t[n>>2]=e;if((t[n>>2]|0)!=0?(t[(t[n>>2]|0)+4>>2]|0)!=18:0){t[n>>2]=t[(t[n>>2]|0)+12>>2];t[f>>2]=0;while(1){if(!(t[n>>2]|0))break;if(!(((t[(t[n>>2]|0)+4>>2]|0)!=1?(t[(t[n>>2]|0)+4>>2]|0)!=9:0)?(t[(t[n>>2]|0)+4>>2]|0)!=13:0))t[f>>2]=(t[f>>2]|0)+1;t[n>>2]=t[(t[n>>2]|0)+24>>2]}t[r>>2]=t[f>>2];u=t[r>>2]|0;s=i;return u|0}t[r>>2]=-1;u=t[r>>2]|0;s=i;return u|0}function vo(e){e=e|0;var i=0,r=0,n=0,f=0,u=0;i=s;s=s+16|0;r=i+8|0;n=i+4|0;f=i;t[n>>2]=e;if((t[n>>2]|0)!=0?(t[(t[n>>2]|0)+4>>2]|0)!=18:0){t[f>>2]=1;while(1){if(!(t[n>>2]|0))break;if(!(((t[(t[n>>2]|0)+4>>2]|0)!=1?(t[(t[n>>2]|0)+4>>2]|0)!=9:0)?(t[(t[n>>2]|0)+4>>2]|0)!=13:0))t[f>>2]=(t[f>>2]|0)+1;t[n>>2]=t[(t[n>>2]|0)+28>>2]}t[r>>2]=t[f>>2];u=t[r>>2]|0;s=i;return u|0}t[r>>2]=-1;u=t[r>>2]|0;s=i;return u|0}function mo(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;var u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0;u=s;s=s+48|0;a=u+44|0;o=u+40|0;c=u+36|0;l=u+32|0;b=u+28|0;k=u+24|0;h=u+20|0;w=u+16|0;d=u+12|0;v=u+8|0;m=u+4|0;_=u;t[o>>2]=e;t[c>>2]=i;t[l>>2]=r;t[b>>2]=n;t[k>>2]=f;if(!(t[o>>2]|0)){t[a>>2]=-1;p=t[a>>2]|0;s=u;return p|0}if((t[c>>2]|0)!=0?(t[(t[c>>2]|0)+4>>2]|0)!=18:0){if(((t[b>>2]|0)!=0?(t[t[b>>2]>>2]|0)!=0:0)?!((t[k>>2]|0)==0?1:(t[(t[t[b>>2]>>2]|0)+4>>2]|0)==18):0){t[h>>2]=t[c>>2];t[w>>2]=(t[l>>2]|0)-1;t[v>>2]=rs(t[o>>2]|0)|0;while(1){if((t[v>>2]|0)<=0){E=27;break}if((t[h>>2]|0)==(t[t[b>>2]>>2]|0)?((t[w>>2]|0)+(t[v>>2]|0)|0)>(t[t[k>>2]>>2]|0):0){E=14;break}if((t[(t[h>>2]|0)+4>>2]|0)!=1?(t[(t[h>>2]|0)+40>>2]|0)!=0:0){t[d>>2]=rs(t[(t[h>>2]|0)+40>>2]|0)|0;if((t[d>>2]|0)>=((t[w>>2]|0)+(t[v>>2]|0)|0)){E=18;break}t[_>>2]=(t[d>>2]|0)-(t[w>>2]|0);t[m>>2]=((Jl((t[(t[h>>2]|0)+40>>2]|0)+(t[w>>2]|0)|0,t[o>>2]|0,t[_>>2]|0)|0)!=0^1)&1;if(!(t[m>>2]|0)){E=23;break}t[o>>2]=(t[o>>2]|0)+(t[_>>2]|0);t[v>>2]=(t[v>>2]|0)-(t[_>>2]|0)}t[h>>2]=Va(t[h>>2]|0,0)|0;if(!(t[h>>2]|0)){E=25;break}t[w>>2]=0}if((E|0)==14){t[a>>2]=0;p=t[a>>2]|0;s=u;return p|0}else if((E|0)==18){t[m>>2]=((Jl((t[(t[h>>2]|0)+40>>2]|0)+(t[w>>2]|0)|0,t[o>>2]|0,t[v>>2]|0)|0)!=0^1)&1;if(t[m>>2]|0){t[t[b>>2]>>2]=t[h>>2];t[t[k>>2]>>2]=(t[w>>2]|0)+(t[v>>2]|0);t[a>>2]=1;p=t[a>>2]|0;s=u;return p|0}else{t[a>>2]=0;p=t[a>>2]|0;s=u;return p|0}}else if((E|0)==23){t[a>>2]=0;p=t[a>>2]|0;s=u;return p|0}else if((E|0)==25){t[a>>2]=0;p=t[a>>2]|0;s=u;return p|0}else if((E|0)==27){t[a>>2]=1;p=t[a>>2]|0;s=u;return p|0}}t[a>>2]=-1;p=t[a>>2]|0;s=u;return p|0}t[a>>2]=-1;p=t[a>>2]|0;s=u;return p|0}function _o(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0;r=s;s=s+32|0;n=r+16|0;f=r+12|0;u=r+8|0;a=r+4|0;o=r;t[n>>2]=e;t[f>>2]=i;t[u>>2]=0;if((t[(t[n>>2]|0)+16>>2]|0)!=0?(t[t[(t[n>>2]|0)+16>>2]>>2]|0)==1:0){t[a>>2]=En(t[n>>2]|0)|0;t[o>>2]=t[(t[a>>2]|0)+4>>2];if(!((t[f>>2]|0)<=0|(t[o>>2]|0)==0)?(t[t[o>>2]>>2]|0)==1:0){t[u>>2]=ho(t[t[(t[o>>2]|0)+8>>2]>>2]|0,t[f>>2]|0)|0;if(!(t[u>>2]|0)){_n(t[a>>2]|0);f=t[n>>2]|0;Sn(f,In(0)|0)|0;s=r;return}else{t[t[(t[o>>2]|0)+8>>2]>>2]=t[u>>2];Sn(t[n>>2]|0,t[a>>2]|0)|0;s=r;return}}_n(t[a>>2]|0);a=t[n>>2]|0;Sn(a,In(0)|0)|0;s=r;return}dn(t[n>>2]|0,11);s=r;return}function po(e,i){e=e|0;i=i|0;var r=0,f=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0,S=0,g=0,y=0;r=s;s=s+64|0;f=r+48|0;a=r+44|0;o=r+40|0;c=r+36|0;l=r+32|0;b=r+28|0;k=r+24|0;h=r+20|0;w=r+16|0;d=r+12|0;v=r+8|0;m=r+4|0;_=r;t[f>>2]=e;t[a>>2]=i;if(!(t[a>>2]|0))t[a>>2]=wt(t[f>>2]|0)|0;i=t[f>>2]|0;if(!(t[a>>2]|0)){dn(i,7);s=r;return}e=t[f>>2]|0;if((u[t[i>>2]>>0]|0|0)!=40){dn(e,7);s=r;return}i=t[f>>2]|0;if(u[t[e>>2]>>0]|0)t[i>>2]=(t[i>>2]|0)+1;t[b>>2]=1;t[l>>2]=rs(t[t[f>>2]>>2]|0)|0;t[l>>2]=(t[l>>2]|0)+1;t[o>>2]=gAi[t[135752>>2]&511](t[l>>2]|0)|0;if(!(t[o>>2]|0)){qa(132344);s=r;return}t[c>>2]=t[o>>2];e:while(1){if(!(u[t[t[f>>2]>>2]>>0]|0))break;do if((u[t[t[f>>2]>>2]>>0]|0|0)==41){t[b>>2]=(t[b>>2]|0)+-1;if(!(t[b>>2]|0)){p=15;break e}}else{if((u[t[t[f>>2]>>2]>>0]|0|0)==40){t[b>>2]=(t[b>>2]|0)+1;break}if((u[t[t[f>>2]>>2]>>0]|0|0)==94){if(((u[(t[t[f>>2]>>2]|0)+1>>0]|0|0)!=41?(u[(t[t[f>>2]>>2]|0)+1>>0]|0|0)!=40:0)?(u[(t[t[f>>2]>>2]|0)+1>>0]|0|0)!=94:0)break;l=t[f>>2]|0;if(u[t[t[f>>2]>>2]>>0]|0)t[l>>2]=(t[l>>2]|0)+1}}while(0);l=n[t[t[f>>2]>>2]>>0]|0;i=t[c>>2]|0;t[c>>2]=i+1;n[i>>0]=l;l=t[f>>2]|0;if(!(u[t[t[f>>2]>>2]>>0]|0))continue;t[l>>2]=(t[l>>2]|0)+1}if((p|0)==15?(p=t[f>>2]|0,(u[t[t[f>>2]>>2]>>0]|0|0)!=0):0)t[p>>2]=(t[p>>2]|0)+1;n[t[c>>2]>>0]=0;if((t[b>>2]|0)!=0?(u[t[t[f>>2]>>2]>>0]|0|0)==0:0){pAi[t[135736>>2]&511](t[o>>2]|0);dn(t[f>>2]|0,16);s=r;return}do if(Xl(t[a>>2]|0,132368)|0){t[k>>2]=t[t[f>>2]>>2];t[t[f>>2]>>2]=t[o>>2];t[(t[(t[f>>2]|0)+12>>2]|0)+4>>2]=t[t[(t[f>>2]|0)+12>>2]>>2];t[(t[(t[f>>2]|0)+12>>2]|0)+72>>2]=1;t[(t[(t[f>>2]|0)+12>>2]|0)+68>>2]=1;pt(t[f>>2]|0);t[t[f>>2]>>2]=t[k>>2]}else{if(Xl(t[a>>2]|0,132384)|0){t[h>>2]=t[t[f>>2]>>2];t[t[f>>2]>>2]=t[o>>2];b=t[f>>2]|0;do if((u[t[o>>2]>>0]|0|0)==47){jf(b);bo(t[f>>2]|0,0)}else{t[w>>2]=wt(b)|0;if(t[w>>2]|0){bo(t[f>>2]|0,t[w>>2]|0);break}t[t[f>>2]>>2]=t[h>>2];pAi[t[135736>>2]&511](t[o>>2]|0);dn(t[f>>2]|0,7);s=r;return}while(0);t[t[f>>2]>>2]=t[h>>2];break}b=(Xl(t[a>>2]|0,132392)|0)!=0;c=t[f>>2]|0;if(!b){io(c,1900,132400,t[a>>2]|0);break}t[d>>2]=t[c>>2];t[t[f>>2]>>2]=t[o>>2];t[v>>2]=ht(t[f>>2]|0)|0;if(!(t[v>>2]|0)){pAi[t[135736>>2]&511](t[o>>2]|0);pAi[t[135736>>2]&511](t[a>>2]|0);dn(t[f>>2]|0,16);s=r;return}while(1){do if((u[t[t[f>>2]>>2]>>0]|0|0)==32)E=1;else{if(9<=(u[t[t[f>>2]>>2]>>0]|0|0)?(u[t[t[f>>2]>>2]>>0]|0|0)<=10:0){E=1;break}E=(u[t[t[f>>2]>>2]>>0]|0|0)==13}while(0);S=u[t[t[f>>2]>>2]>>0]|0;if(!E)break;c=t[f>>2]|0;if(!S)continue;t[c>>2]=(t[c>>2]|0)+1}if((S|0)!=61){pAi[t[135736>>2]&511](t[v>>2]|0);pAi[t[135736>>2]&511](t[o>>2]|0);pAi[t[135736>>2]&511](t[a>>2]|0);dn(t[f>>2]|0,16);s=r;return}c=t[f>>2]|0;if(u[t[t[f>>2]>>2]>>0]|0)t[c>>2]=(t[c>>2]|0)+1;while(1){do if((u[t[t[f>>2]>>2]>>0]|0|0)==32)g=1;else{if(9<=(u[t[t[f>>2]>>2]>>0]|0|0)?(u[t[t[f>>2]>>2]>>0]|0|0)<=10:0){g=1;break}g=(u[t[t[f>>2]>>2]>>0]|0|0)==13}while(0);y=t[t[f>>2]>>2]|0;if(!g)break;c=t[f>>2]|0;if(!(u[y>>0]|0))continue;t[c>>2]=(t[c>>2]|0)+1}t[_>>2]=IA(y)|0;if(!(t[_>>2]|0)){pAi[t[135736>>2]&511](t[v>>2]|0);pAi[t[135736>>2]&511](t[o>>2]|0);pAi[t[135736>>2]&511](t[a>>2]|0);dn(t[f>>2]|0,16);s=r;return}t[m>>2]=zA(t[_>>2]|0)|0;xA(t[_>>2]|0);if(t[m>>2]|0){Kn(t[(t[f>>2]|0)+12>>2]|0,t[v>>2]|0,t[m>>2]|0)|0;t[t[f>>2]>>2]=t[d>>2];pAi[t[135736>>2]&511](t[m>>2]|0);pAi[t[135736>>2]&511](t[v>>2]|0);break}pAi[t[135736>>2]&511](t[v>>2]|0);pAi[t[135736>>2]&511](t[o>>2]|0);pAi[t[135736>>2]&511](t[a>>2]|0);dn(t[f>>2]|0,15);s=r;return}while(0);pAi[t[135736>>2]&511](t[o>>2]|0);pAi[t[135736>>2]&511](t[a>>2]|0);s=r;return}function Eo(e){e=e|0;var i=0,r=0,n=0,f=0,u=0,a=0;i=s;s=s+16|0;r=i+8|0;n=i+4|0;f=i;t[n>>2]=e;if(!(t[n>>2]|0)){t[r>>2]=0;u=t[r>>2]|0;s=i;return u|0}t[f>>2]=gAi[t[135744>>2]&511](72)|0;if(!(t[f>>2]|0)){Mo(0,t[n>>2]|0,132504);t[r>>2]=0;u=t[r>>2]|0;s=i;return u|0}else{e=(t[f>>2]|0)+0|0;a=e+72|0;do{t[e>>2]=0;e=e+4|0}while((e|0)<(a|0));t[t[f>>2]>>2]=t[n>>2];t[(t[f>>2]|0)+8>>2]=0;t[(t[f>>2]|0)+4>>2]=0;t[(t[f>>2]|0)+12>>2]=0;t[(t[f>>2]|0)+16>>2]=0;t[(t[f>>2]|0)+52>>2]=0;t[r>>2]=t[f>>2];u=t[r>>2]|0;s=i;return u|0}return 0}function So(e){e=e|0;var i=0,r=0,n=0,f=0;i=s;s=s+16|0;r=i+4|0;n=i;t[r>>2]=e;if(!(t[r>>2]|0)){s=i;return}while(1){f=t[r>>2]|0;if((t[(t[r>>2]|0)+40>>2]|0)<=0)break;Ro(f)}if(t[f+48>>2]|0)pAi[t[135736>>2]&511](t[(t[r>>2]|0)+48>>2]|0);t[n>>2]=0;while(1){if((t[n>>2]|0)>=(t[(t[r>>2]|0)+8>>2]|0))break;if(t[(t[(t[r>>2]|0)+16>>2]|0)+(t[n>>2]<<2)>>2]|0)No(t[(t[(t[r>>2]|0)+16>>2]|0)+(t[n>>2]<<2)>>2]|0);t[n>>2]=(t[n>>2]|0)+1}e:do if(t[(t[r>>2]|0)+32>>2]|0){t[n>>2]=0;while(1){if((t[n>>2]|0)>=(t[(t[r>>2]|0)+20>>2]|0))break e;if(t[(t[(t[r>>2]|0)+32>>2]|0)+(t[n>>2]<<2)>>2]|0)pAi[t[135736>>2]&511](t[(t[(t[r>>2]|0)+32>>2]|0)+(t[n>>2]<<2)>>2]|0);t[n>>2]=(t[n>>2]|0)+1}}while(0);if(t[(t[r>>2]|0)+16>>2]|0)pAi[t[135736>>2]&511](t[(t[r>>2]|0)+16>>2]|0);if(t[(t[r>>2]|0)+28>>2]|0)pAi[t[135736>>2]&511](t[(t[r>>2]|0)+28>>2]|0);if(t[(t[r>>2]|0)+32>>2]|0)pAi[t[135736>>2]&511](t[(t[r>>2]|0)+32>>2]|0);if(t[(t[r>>2]|0)+64>>2]|0)pAi[t[135736>>2]&511](t[(t[r>>2]|0)+64>>2]|0);pAi[t[135736>>2]&511](t[r>>2]|0);s=i;return}function go(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0;r=s;s=s+16|0;n=r+8|0;f=r+4|0;u=r;t[f>>2]=e;t[u>>2]=i;if(!(t[f>>2]|0)){t[n>>2]=-1;a=t[n>>2]|0;s=r;return a|0}else{t[(t[f>>2]|0)+60>>2]=t[u>>2];t[n>>2]=0;a=t[n>>2]|0;s=r;return a|0}return 0}function yo(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0;n=s;s=s+32|0;f=n+20|0;u=n+16|0;a=n+12|0;o=n+8|0;c=n+4|0;l=n;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;t[l>>2]=0;if(((t[u>>2]|0)!=0?(t[(t[u>>2]|0)+4>>2]|0)!=18:0)?(t[(t[u>>2]|0)+32>>2]|0)!=0:0){t[c>>2]=Eo(t[(t[u>>2]|0)+32>>2]|0)|0;if(!(t[c>>2]|0)){t[f>>2]=-1;b=t[f>>2]|0;s=n;return b|0}t[(t[c>>2]|0)+68>>2]=t[o>>2];o=Yl(t[(t[(t[u>>2]|0)+32>>2]|0)+72>>2]|0)|0;t[(t[c>>2]|0)+64>>2]=o;go(t[c>>2]|0,t[a>>2]|0)|0;t[l>>2]=To(t[c>>2]|0,t[(t[u>>2]|0)+32>>2]|0,t[u>>2]|0)|0;if((t[l>>2]|0)>=0?(t[(t[c>>2]|0)+52>>2]|0)>0:0)t[l>>2]=-1;So(t[c>>2]|0);t[f>>2]=t[l>>2];b=t[f>>2]|0;s=n;return b|0}t[f>>2]=-1;b=t[f>>2]|0;s=n;return b|0}function Fo(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,l=0;n=s;s=s+32|0;f=n+16|0;u=n+12|0;a=n+8|0;o=n+4|0;c=n;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;if(!(t[u>>2]|0)){t[f>>2]=-1;l=t[f>>2]|0;s=n;return l|0}t[c>>2]=eF(t[u>>2]|0)|0;if(!(t[c>>2]|0)){t[f>>2]=-1;l=t[f>>2]|0;s=n;return l|0}else{t[f>>2]=yo(t[c>>2]|0,t[a>>2]|0,t[o>>2]|0)|0;l=t[f>>2]|0;s=n;return l|0}return 0}function Oo(e,i){e=e|0;i=i|0;var r=0,n=0,f=0;r=s;s=s+16|0;n=r+4|0;f=r;t[n>>2]=e;t[f>>2]=i;i=Fo(t[n>>2]|0,t[f>>2]|0,0)|0;s=r;return i|0}function Ao(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0;r=s;s=s+16|0;n=r+12|0;f=r+8|0;u=r+4|0;a=r;t[f>>2]=e;t[u>>2]=i;t[a>>2]=0;if(((t[u>>2]|0)!=0?(t[(t[u>>2]|0)+4>>2]|0)!=18:0)?!((t[f>>2]|0)==0?1:(t[(t[u>>2]|0)+32>>2]|0)==0):0){t[a>>2]=To(t[f>>2]|0,t[(t[u>>2]|0)+32>>2]|0,t[u>>2]|0)|0;if((t[a>>2]|0)>=0?(t[(t[f>>2]|0)+52>>2]|0)>0:0)t[a>>2]=-1;t[n>>2]=t[a>>2];o=t[n>>2]|0;s=r;return o|0}t[n>>2]=-1;o=t[n>>2]|0;s=r;return o|0}function Mo(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0;n=s;s=s+16|0;f=n;u=n+12|0;a=n+8|0;o=n+4|0;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;if(t[u>>2]|0){r=(t[u>>2]|0)+52|0;t[r>>2]=(t[r>>2]|0)+1}r=t[u>>2]|0;u=t[a>>2]|0;a=t[o>>2]|0;t[f>>2]=t[o>>2];cp(0,0,0,r,u,11,2,2,0,0,a,0,0,0,0,133840,f);s=n;return}function Ro(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i+4|0;n=i;t[r>>2]=e;if((t[(t[r>>2]|0)+40>>2]|0)<=0){s=i;return}e=(t[r>>2]|0)+40|0;t[e>>2]=(t[e>>2]|0)+-1;e=t[r>>2]|0;if((t[(t[r>>2]|0)+40>>2]|0)>0)t[(t[r>>2]|0)+36>>2]=t[(t[(t[r>>2]|0)+48>>2]|0)+((t[e+40>>2]|0)-1<<2)>>2];else t[e+36>>2]=0;t[n>>2]=t[(t[(t[r>>2]|0)+48>>2]|0)+(t[(t[r>>2]|0)+40>>2]<<2)>>2];t[(t[(t[r>>2]|0)+48>>2]|0)+(t[(t[r>>2]|0)+40>>2]<<2)>>2]=0;if(!(t[n>>2]|0)){s=i;return}pAi[t[135736>>2]&511](t[n>>2]|0);s=i;return}function No(e){e=e|0;var i=0,r=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if(!(t[r>>2]|0)){s=i;return}if(t[(t[r>>2]|0)+8>>2]|0)fy(t[(t[r>>2]|0)+8>>2]|0);if(t[t[r>>2]>>2]|0)pAi[t[135736>>2]&511](t[t[r>>2]>>2]|0);if(t[(t[r>>2]|0)+4>>2]|0)pAi[t[135736>>2]&511](t[(t[r>>2]|0)+4>>2]|0);if(t[(t[r>>2]|0)+28>>2]|0)_n(t[(t[r>>2]|0)+28>>2]|0);pAi[t[135736>>2]&511](t[r>>2]|0);s=i;return}function To(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0;n=s;s=s+32|0;f=n+28|0;u=n+24|0;a=n+20|0;o=n+16|0;c=n+12|0;l=n+8|0;b=n+4|0;k=n;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;t[l>>2]=0;if(!((t[a>>2]|0)==0|(t[o>>2]|0)==0)?(t[(t[o>>2]|0)+4>>2]|0)!=18:0){if(!(t[u>>2]|0)){t[f>>2]=-1;h=t[f>>2]|0;s=n;return h|0}if((t[(t[a>>2]|0)+72>>2]|0)!=0?(t[l>>2]=Lo(t[u>>2]|0,t[(t[a>>2]|0)+72>>2]|0)|0,(t[l>>2]|0)<0):0){t[f>>2]=-1;h=t[f>>2]|0;s=n;return h|0}t[k>>2]=t[(t[u>>2]|0)+8>>2];t[c>>2]=t[o>>2];if((Do(t[u>>2]|0,t[c>>2]|0)|0)==1)Co(t[u>>2]|0,t[c>>2]|0)|0;e:while(1){if(!(t[c>>2]|0))break;if((t[c>>2]|0)==(t[(t[o>>2]|0)+20>>2]|0))break;if((((t[(t[c>>2]|0)+12>>2]|0)!=0?(t[(t[(t[c>>2]|0)+12>>2]|0)+4>>2]|0)!=17:0)?(t[(t[(t[c>>2]|0)+12>>2]|0)+4>>2]|0)!=19:0)?(t[(t[(t[c>>2]|0)+12>>2]|0)+4>>2]|0)!=20:0){t[c>>2]=t[(t[c>>2]|0)+12>>2];if(!(Do(t[u>>2]|0,t[c>>2]|0)|0))continue;Co(t[u>>2]|0,t[c>>2]|0)|0;continue}r=t[c>>2]|0;if(t[(t[c>>2]|0)+24>>2]|0){t[c>>2]=t[r+24>>2];if(!(Do(t[u>>2]|0,t[c>>2]|0)|0))continue;Co(t[u>>2]|0,t[c>>2]|0)|0;continue}if((r|0)==(t[o>>2]|0))break;while(1){t[c>>2]=t[(t[c>>2]|0)+20>>2];if(!(t[c>>2]|0))continue e;if((t[c>>2]|0)==(t[(t[o>>2]|0)+20>>2]|0))continue e;w=t[c>>2]|0;if(t[(t[c>>2]|0)+24>>2]|0)break;if(!w)continue e}t[c>>2]=t[w+24>>2];if(!(Do(t[u>>2]|0,t[c>>2]|0)|0))continue;Co(t[u>>2]|0,t[c>>2]|0)|0}t[b>>2]=t[k>>2];while(1){d=t[u>>2]|0;if((t[b>>2]|0)>=(t[(t[u>>2]|0)+8>>2]|0))break;Po(d,t[b>>2]|0)|0;t[l>>2]=(t[l>>2]|0)+1;t[b>>2]=(t[b>>2]|0)+1}t[b>>2]=t[d+4>>2];while(1){if((t[b>>2]|0)>=(t[(t[u>>2]|0)+8>>2]|0))break;if(!(((t[(t[(t[(t[u>>2]|0)+16>>2]|0)+(t[b>>2]<<2)>>2]|0)+16>>2]|0)==0?(t[(t[(t[(t[u>>2]|0)+16>>2]|0)+(t[b>>2]<<2)>>2]|0)+28>>2]|0)==0:0)?(t[(t[(t[(t[u>>2]|0)+16>>2]|0)+(t[b>>2]<<2)>>2]|0)+32>>2]|0)==0:0))Bo(t[u>>2]|0,t[b>>2]|0)|0;t[b>>2]=(t[b>>2]|0)+1}if(t[(t[a>>2]|0)+72>>2]|0)Ro(t[u>>2]|0);t[f>>2]=t[l>>2];h=t[f>>2]|0;s=n;return h|0}t[f>>2]=-1;h=t[f>>2]|0;s=n;return h|0}function Lo(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0;r=s;s=s+16|0;n=r+8|0;f=r+4|0;u=r;t[f>>2]=e;t[u>>2]=i;i=t[f>>2]|0;if((t[(t[f>>2]|0)+40>>2]|0)>40){Io(i,0,1600,133640,t[u>>2]|0);t[n>>2]=-1;a=t[n>>2]|0;s=r;return a|0}if((t[i+48>>2]|0)==0?(t[(t[f>>2]|0)+44>>2]=4,t[(t[f>>2]|0)+40>>2]=0,i=gAi[t[135744>>2]&511](t[(t[f>>2]|0)+44>>2]<<2)|0,t[(t[f>>2]|0)+48>>2]=i,(t[(t[f>>2]|0)+48>>2]|0)==0):0){Mo(t[f>>2]|0,0,133824);t[n>>2]=-1;a=t[n>>2]|0;s=r;return a|0}if((t[(t[f>>2]|0)+40>>2]|0)>=(t[(t[f>>2]|0)+44>>2]|0)?(i=(t[f>>2]|0)+44|0,t[i>>2]=t[i>>2]<<1,i=MAi[t[135760>>2]&511](t[(t[f>>2]|0)+48>>2]|0,t[(t[f>>2]|0)+44>>2]<<2)|0,t[(t[f>>2]|0)+48>>2]=i,(t[(t[f>>2]|0)+48>>2]|0)==0):0){Mo(t[f>>2]|0,0,133824);t[n>>2]=-1;a=t[n>>2]|0;s=r;return a|0}i=Yl(t[u>>2]|0)|0;t[(t[(t[f>>2]|0)+48>>2]|0)+(t[(t[f>>2]|0)+40>>2]<<2)>>2]=i;t[(t[f>>2]|0)+36>>2]=i;i=(t[f>>2]|0)+40|0;f=t[i>>2]|0;t[i>>2]=f+1;t[n>>2]=f;a=t[n>>2]|0;s=r;return a|0}function Do(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0;r=s;s=s+32|0;n=r+16|0;f=r+12|0;u=r+8|0;a=r+4|0;o=r;t[f>>2]=e;t[u>>2]=i;if(!(t[u>>2]|0)){t[n>>2]=0;c=t[n>>2]|0;s=r;return c|0}if((t[(t[u>>2]|0)+4>>2]|0)!=1){t[n>>2]=0;c=t[n>>2]|0;s=r;return c|0}if(!(t[(t[u>>2]|0)+36>>2]|0)){t[n>>2]=0;c=t[n>>2]|0;s=r;return c|0}if(!((Xl(t[(t[(t[u>>2]|0)+36>>2]|0)+8>>2]|0,132728)|0)==0?(Xl(t[(t[(t[u>>2]|0)+36>>2]|0)+8>>2]|0,132760)|0)==0:0))l=9;e:do if((l|0)==9){if((Xl(t[(t[(t[u>>2]|0)+36>>2]|0)+8>>2]|0,132760)|0)!=0?(t[(t[f>>2]|0)+56>>2]|0)==0:0)t[(t[f>>2]|0)+56>>2]=1;i=(Xl(t[(t[u>>2]|0)+8>>2]|0,133704)|0)!=0;e=t[u>>2]|0;if(!i){if(!(Xl(t[e+8>>2]|0,132712)|0))break;do if(((t[(t[u>>2]|0)+20>>2]|0)!=0?(t[(t[(t[u>>2]|0)+20>>2]|0)+4>>2]|0)==1:0)?(t[(t[(t[u>>2]|0)+20>>2]|0)+36>>2]|0)!=0:0){if((Xl(t[(t[(t[(t[u>>2]|0)+20>>2]|0)+36>>2]|0)+8>>2]|0,132728)|0)==0?(Xl(t[(t[(t[(t[u>>2]|0)+20>>2]|0)+36>>2]|0)+8>>2]|0,132760)|0)==0:0)break;if(Xl(t[(t[(t[u>>2]|0)+20>>2]|0)+8>>2]|0,133704)|0)break e}while(0);Io(t[f>>2]|0,t[u>>2]|0,1616,133784,132712);break}t[a>>2]=t[e+12>>2];t[o>>2]=0;i:while(1){if(!(t[a>>2]|0))break;do if((t[(t[a>>2]|0)+4>>2]|0)==1?(t[(t[a>>2]|0)+36>>2]|0)!=0:0){if((Xl(t[(t[(t[a>>2]|0)+36>>2]|0)+8>>2]|0,132728)|0)==0?(Xl(t[(t[(t[a>>2]|0)+36>>2]|0)+8>>2]|0,132760)|0)==0:0)break;if(Xl(t[(t[a>>2]|0)+8>>2]|0,133704)|0){l=20;break i}if(Xl(t[(t[a>>2]|0)+8>>2]|0,132712)|0)t[o>>2]=(t[o>>2]|0)+1;
	}while(0);t[a>>2]=t[(t[a>>2]|0)+24>>2]}if((l|0)==20){Io(t[f>>2]|0,t[u>>2]|0,1614,133712,133704);t[n>>2]=0;c=t[n>>2]|0;s=r;return c|0}if((t[o>>2]|0)>1){Io(t[f>>2]|0,t[u>>2]|0,1615,133744,133704);t[n>>2]=0;c=t[n>>2]|0;s=r;return c|0}else{t[n>>2]=1;c=t[n>>2]|0;s=r;return c|0}}while(0);t[n>>2]=0;c=t[n>>2]|0;s=r;return c|0}function Co(e,i){e=e|0;i=i|0;var r=0,n=0,f=0;r=s;s=s+16|0;n=r+4|0;f=r;t[n>>2]=e;t[f>>2]=i;Ho(t[n>>2]|0,t[f>>2]|0)|0;s=r;return 0}function Po(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0;r=s;s=s+64|0;n=r+52|0;f=r+48|0;u=r+44|0;a=r+40|0;o=r+36|0;c=r+32|0;l=r+28|0;b=r+24|0;k=r+20|0;h=r+16|0;w=r+12|0;d=r+8|0;v=r+4|0;m=r;t[f>>2]=e;t[u>>2]=i;t[h>>2]=1;if(!(t[f>>2]|0)){t[n>>2]=-1;_=t[n>>2]|0;s=r;return _|0}if((t[u>>2]|0)>=0?(t[u>>2]|0)<(t[(t[f>>2]|0)+8>>2]|0):0){t[a>>2]=t[(t[(t[(t[f>>2]|0)+16>>2]|0)+(t[u>>2]<<2)>>2]|0)+12>>2];if(!(t[a>>2]|0)){t[n>>2]=-1;_=t[n>>2]|0;s=r;return _|0}t[o>>2]=xo(t[f>>2]|0,t[a>>2]|0,132616)|0;if((t[o>>2]|0)==0?(t[o>>2]=Yl(132624)|0,(t[o>>2]|0)==0):0){t[n>>2]=-1;_=t[n>>2]|0;s=r;return _|0}t[c>>2]=xo(t[f>>2]|0,t[a>>2]|0,132632)|0;do if(t[c>>2]|0){if(Xl(t[c>>2]|0,132640)|0){t[h>>2]=1;break}if(Xl(t[c>>2]|0,132648)|0){t[h>>2]=0;break}Io(t[f>>2]|0,t[(t[(t[(t[f>>2]|0)+16>>2]|0)+(t[u>>2]<<2)>>2]|0)+12>>2]|0,1601,132656,t[c>>2]|0);if(t[o>>2]|0)pAi[t[135736>>2]&511](t[o>>2]|0);if(t[c>>2]|0)pAi[t[135736>>2]&511](t[c>>2]|0);t[n>>2]=-1;_=t[n>>2]|0;s=r;return _|0}while(0);t[l>>2]=oF(t[t[f>>2]>>2]|0,t[a>>2]|0)|0;i=t[o>>2]|0;if(!(t[l>>2]|0))t[k>>2]=GA(i,t[(t[t[f>>2]>>2]|0)+72>>2]|0)|0;else t[k>>2]=GA(i,t[l>>2]|0)|0;if(!(t[k>>2]|0)){t[d>>2]=YA(t[l>>2]|0)|0;t[v>>2]=YA(t[o>>2]|0)|0;t[k>>2]=GA(t[v>>2]|0,t[d>>2]|0)|0;if(t[d>>2]|0)pAi[t[135736>>2]&511](t[d>>2]|0);if(t[v>>2]|0)pAi[t[135736>>2]&511](t[v>>2]|0)}v=t[f>>2]|0;if(!(t[k>>2]|0)){Io(v,t[(t[(t[(t[f>>2]|0)+16>>2]|0)+(t[u>>2]<<2)>>2]|0)+12>>2]|0,1605,132688,0);if(t[c>>2]|0)pAi[t[135736>>2]&511](t[c>>2]|0);if(t[o>>2]|0)pAi[t[135736>>2]&511](t[o>>2]|0);if(t[l>>2]|0)pAi[t[135736>>2]&511](t[l>>2]|0);t[n>>2]=-1;_=t[n>>2]|0;s=r;return _|0}t[b>>2]=t[v+64>>2];t[(t[f>>2]|0)+64>>2]=t[l>>2];v=t[f>>2]|0;d=t[k>>2]|0;i=t[u>>2]|0;if(t[h>>2]|0)t[w>>2]=Uo(v,d,i)|0;else t[w>>2]=zo(v,d,i)|0;t[(t[f>>2]|0)+64>>2]=t[b>>2];e:do if((t[w>>2]|0)<0){t[m>>2]=t[(t[a>>2]|0)+12>>2];while(1){if(!(t[m>>2]|0))break e;do if(((t[(t[m>>2]|0)+4>>2]|0)==1?(t[(t[m>>2]|0)+36>>2]|0)!=0:0)?(Xl(t[(t[m>>2]|0)+8>>2]|0,132712)|0)!=0:0){if((Xl(t[(t[(t[m>>2]|0)+36>>2]|0)+8>>2]|0,132728)|0)==0?(Xl(t[(t[(t[m>>2]|0)+36>>2]|0)+8>>2]|0,132760)|0)==0:0)break;t[w>>2]=jo(t[f>>2]|0,t[m>>2]|0,t[u>>2]|0)|0;if(!(t[w>>2]|0))break e}while(0);t[m>>2]=t[(t[m>>2]|0)+24>>2]}}while(0);if((t[w>>2]|0)<0)Io(t[f>>2]|0,t[(t[(t[(t[f>>2]|0)+16>>2]|0)+(t[u>>2]<<2)>>2]|0)+12>>2]|0,1604,132792,t[k>>2]|0);if(t[k>>2]|0)pAi[t[135736>>2]&511](t[k>>2]|0);if(t[c>>2]|0)pAi[t[135736>>2]&511](t[c>>2]|0);if(t[o>>2]|0)pAi[t[135736>>2]&511](t[o>>2]|0);if(t[l>>2]|0)pAi[t[135736>>2]&511](t[l>>2]|0);t[n>>2]=0;_=t[n>>2]|0;s=r;return _|0}t[n>>2]=-1;_=t[n>>2]|0;s=r;return _|0}function Bo(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0;r=s;s=s+32|0;n=r+28|0;f=r+24|0;u=r+20|0;a=r+16|0;o=r+12|0;c=r+8|0;l=r+4|0;b=r;t[f>>2]=e;t[u>>2]=i;if(!(t[f>>2]|0)){t[n>>2]=-1;k=t[n>>2]|0;s=r;return k|0}if((t[u>>2]|0)>=0?(t[u>>2]|0)<(t[(t[f>>2]|0)+8>>2]|0):0){t[a>>2]=t[(t[(t[(t[f>>2]|0)+16>>2]|0)+(t[u>>2]<<2)>>2]|0)+12>>2];if((t[a>>2]|0)!=0?(t[(t[a>>2]|0)+4>>2]|0)!=18:0){if((t[(t[(t[(t[f>>2]|0)+16>>2]|0)+(t[u>>2]<<2)>>2]|0)+16>>2]|0)==0?(t[(t[(t[(t[f>>2]|0)+16>>2]|0)+(t[u>>2]<<2)>>2]|0)+28>>2]|0)!=0:0){i=Vo(t[f>>2]|0,t[t[f>>2]>>2]|0,t[t[f>>2]>>2]|0,t[(t[(t[(t[f>>2]|0)+16>>2]|0)+(t[u>>2]<<2)>>2]|0)+28>>2]|0)|0;t[(t[(t[(t[f>>2]|0)+16>>2]|0)+(t[u>>2]<<2)>>2]|0)+16>>2]=i;_n(t[(t[(t[(t[f>>2]|0)+16>>2]|0)+(t[u>>2]<<2)>>2]|0)+28>>2]|0);t[(t[(t[(t[f>>2]|0)+16>>2]|0)+(t[u>>2]<<2)>>2]|0)+28>>2]=0}t[c>>2]=t[(t[(t[(t[f>>2]|0)+16>>2]|0)+(t[u>>2]<<2)>>2]|0)+16>>2];t[(t[(t[(t[f>>2]|0)+16>>2]|0)+(t[u>>2]<<2)>>2]|0)+16>>2]=0;if((t[(t[a>>2]|0)+20>>2]|0)!=0?(t[(t[(t[a>>2]|0)+20>>2]|0)+4>>2]|0)!=1:0){t[b>>2]=0;t[l>>2]=t[c>>2];while(1){if(!(t[l>>2]|0))break;if((t[(t[l>>2]|0)+4>>2]|0)==1)t[b>>2]=(t[b>>2]|0)+1;t[l>>2]=t[(t[l>>2]|0)+24>>2]}if((t[b>>2]|0)>1){Io(t[f>>2]|0,t[(t[(t[(t[f>>2]|0)+16>>2]|0)+(t[u>>2]<<2)>>2]|0)+12>>2]|0,1611,132536,0);t[n>>2]=-1;k=t[n>>2]|0;s=r;return k|0}}e:do if(t[(t[f>>2]|0)+60>>2]&32768){while(1){if(!(t[c>>2]|0))break;t[o>>2]=t[c>>2];t[c>>2]=t[(t[c>>2]|0)+24>>2];Py(t[a>>2]|0,t[o>>2]|0)|0}iy(t[a>>2]|0);ry(t[a>>2]|0)}else{t[(t[a>>2]|0)+4>>2]=19;t[o>>2]=Sy(t[(t[a>>2]|0)+32>>2]|0,t[(t[a>>2]|0)+36>>2]|0,t[(t[a>>2]|0)+8>>2]|0,0)|0;if(!(t[o>>2]|0)){Io(t[f>>2]|0,t[(t[(t[(t[f>>2]|0)+16>>2]|0)+(t[u>>2]<<2)>>2]|0)+12>>2]|0,1609,132592,0);t[n>>2]=-1;k=t[n>>2]|0;s=r;return k|0}t[(t[o>>2]|0)+4>>2]=20;oy(t[a>>2]|0,t[o>>2]|0)|0;while(1){if(!(t[c>>2]|0))break e;t[a>>2]=t[c>>2];t[c>>2]=t[(t[c>>2]|0)+24>>2];Py(t[o>>2]|0,t[a>>2]|0)|0}}while(0);t[n>>2]=0;k=t[n>>2]|0;s=r;return k|0}t[n>>2]=-1;k=t[n>>2]|0;s=r;return k|0}t[n>>2]=-1;k=t[n>>2]|0;s=r;return k|0}function Io(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;var u=0,a=0,o=0,c=0,l=0,b=0,k=0;u=s;s=s+32|0;a=u;o=u+20|0;c=u+16|0;l=u+12|0;b=u+8|0;k=u+4|0;t[o>>2]=e;t[c>>2]=i;t[l>>2]=r;t[b>>2]=n;t[k>>2]=f;if(t[o>>2]|0){f=(t[o>>2]|0)+52|0;t[f>>2]=(t[f>>2]|0)+1}f=t[o>>2]|0;o=t[c>>2]|0;c=t[l>>2]|0;l=t[k>>2]|0;n=t[b>>2]|0;t[a>>2]=t[k>>2];cp(0,0,0,f,o,11,c,2,0,0,l,0,0,0,0,n,a);s=u;return}function Ho(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0,S=0;r=s;s=s+64|0;n=r+60|0;f=r+56|0;a=r+52|0;o=r+48|0;c=r+44|0;l=r+40|0;b=r+36|0;k=r+32|0;h=r+28|0;w=r+24|0;d=r+20|0;v=r+16|0;m=r+12|0;_=r+8|0;p=r+4|0;E=r;t[f>>2]=e;t[a>>2]=i;t[b>>2]=0;t[v>>2]=1;t[_>>2]=0;if(!(t[f>>2]|0)){t[n>>2]=-1;S=t[n>>2]|0;s=r;return S|0}if(!(t[a>>2]|0)){t[n>>2]=-1;S=t[n>>2]|0;s=r;return S|0}t[k>>2]=xo(t[f>>2]|0,t[a>>2]|0,132616)|0;if((t[k>>2]|0)==0?(t[k>>2]=Yl(132624)|0,(t[k>>2]|0)==0):0){t[n>>2]=-1;S=t[n>>2]|0;s=r;return S|0}if(!((u[t[k>>2]>>0]|0|0)!=35?(u[t[k>>2]>>0]|0|0)!=0:0))t[_>>2]=1;t[h>>2]=xo(t[f>>2]|0,t[a>>2]|0,132632)|0;do if(t[h>>2]|0){if(Xl(t[h>>2]|0,132640)|0){t[v>>2]=1;break}if(Xl(t[h>>2]|0,132648)|0){t[v>>2]=0;break}Io(t[f>>2]|0,t[a>>2]|0,1601,132656,t[h>>2]|0);if(t[k>>2]|0)pAi[t[135736>>2]&511](t[k>>2]|0);if(t[h>>2]|0)pAi[t[135736>>2]&511](t[h>>2]|0);t[n>>2]=-1;S=t[n>>2]|0;s=r;return S|0}while(0);t[w>>2]=oF(t[t[f>>2]>>2]|0,t[a>>2]|0)|0;i=t[k>>2]|0;if(!(t[w>>2]|0))t[d>>2]=GA(i,t[(t[t[f>>2]>>2]|0)+72>>2]|0)|0;else t[d>>2]=GA(i,t[w>>2]|0)|0;if(!(t[d>>2]|0)){t[p>>2]=YA(t[w>>2]|0)|0;t[E>>2]=YA(t[k>>2]|0)|0;t[d>>2]=GA(t[E>>2]|0,t[p>>2]|0)|0;if(t[p>>2]|0)pAi[t[135736>>2]&511](t[p>>2]|0);if(t[E>>2]|0)pAi[t[135736>>2]&511](t[E>>2]|0)}if(t[h>>2]|0)pAi[t[135736>>2]&511](t[h>>2]|0);if(t[k>>2]|0)pAi[t[135736>>2]&511](t[k>>2]|0);if(t[w>>2]|0)pAi[t[135736>>2]&511](t[w>>2]|0);w=t[f>>2]|0;k=t[a>>2]|0;if(!(t[d>>2]|0)){Io(w,k,1605,132688,0);t[n>>2]=-1;S=t[n>>2]|0;s=r;return S|0}t[b>>2]=xo(w,k,133496)|0;t[c>>2]=IA(t[d>>2]|0)|0;if(!(t[c>>2]|0)){Io(t[f>>2]|0,t[a>>2]|0,1605,132840,t[d>>2]|0);if(t[b>>2]|0)pAi[t[135736>>2]&511](t[b>>2]|0);pAi[t[135736>>2]&511](t[d>>2]|0);t[n>>2]=-1;S=t[n>>2]|0;s=r;return S|0}do if(t[(t[c>>2]|0)+32>>2]|0)if(t[(t[f>>2]|0)+56>>2]|0){if(!(t[b>>2]|0))t[b>>2]=t[(t[c>>2]|0)+32>>2];else pAi[t[135736>>2]&511](t[(t[c>>2]|0)+32>>2]|0);t[(t[c>>2]|0)+32>>2]=0;break}else{Io(t[f>>2]|0,t[a>>2]|0,1618,133512,t[d>>2]|0);if(t[b>>2]|0)pAi[t[135736>>2]&511](t[b>>2]|0);xA(t[c>>2]|0);pAi[t[135736>>2]&511](t[d>>2]|0);t[n>>2]=-1;S=t[n>>2]|0;s=r;return S|0}while(0);t[l>>2]=zA(t[c>>2]|0)|0;xA(t[c>>2]|0);pAi[t[135736>>2]&511](t[d>>2]|0);if(!(t[l>>2]|0)){Io(t[f>>2]|0,t[a>>2]|0,1605,132840,t[d>>2]|0);if(t[b>>2]|0)pAi[t[135736>>2]&511](t[b>>2]|0);t[n>>2]=-1;S=t[n>>2]|0;s=r;return S|0}do if((t[_>>2]|0)==1&(t[v>>2]|0)==1){if((t[b>>2]|0)!=0?(u[t[b>>2]>>0]|0|0)!=0:0)break;Io(t[f>>2]|0,t[a>>2]|0,1600,133584,t[l>>2]|0);if(t[b>>2]|0)pAi[t[135736>>2]&511](t[b>>2]|0);t[n>>2]=-1;S=t[n>>2]|0;s=r;return S|0}while(0);e:do if((t[_>>2]|0)==0&(t[v>>2]|0)==1){t[m>>2]=0;while(1){if((t[m>>2]|0)>=(t[(t[f>>2]|0)+40>>2]|0))break e;if(Xl(t[l>>2]|0,t[(t[(t[f>>2]|0)+48>>2]|0)+(t[m>>2]<<2)>>2]|0)|0)break;t[m>>2]=(t[m>>2]|0)+1}Io(t[f>>2]|0,t[a>>2]|0,1600,133640,t[l>>2]|0);t[n>>2]=-1;S=t[n>>2]|0;s=r;return S|0}while(0);t[o>>2]=qo(t[f>>2]|0,t[l>>2]|0,t[a>>2]|0)|0;if(!(t[o>>2]|0)){t[n>>2]=-1;S=t[n>>2]|0;s=r;return S|0}else{t[(t[o>>2]|0)+4>>2]=t[b>>2];t[(t[o>>2]|0)+8>>2]=0;t[(t[o>>2]|0)+20>>2]=t[v>>2];t[(t[o>>2]|0)+24>>2]=1;pAi[t[135736>>2]&511](t[l>>2]|0);t[n>>2]=0;S=t[n>>2]|0;s=r;return S|0}return 0}function xo(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,l=0;n=s;s=s+32|0;f=n+16|0;u=n+12|0;a=n+8|0;o=n+4|0;c=n;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;t[c>>2]=tF(t[a>>2]|0,132728,t[o>>2]|0)|0;if(t[c>>2]|0){t[f>>2]=t[c>>2];l=t[f>>2]|0;s=n;return l|0}if((t[(t[u>>2]|0)+56>>2]|0)!=0?(t[c>>2]=tF(t[a>>2]|0,132760,t[o>>2]|0)|0,(t[c>>2]|0)!=0):0){t[f>>2]=t[c>>2];l=t[f>>2]|0;s=n;return l|0}t[c>>2]=cF(t[a>>2]|0,t[o>>2]|0)|0;t[f>>2]=t[c>>2];l=t[f>>2]|0;s=n;return l|0}function Uo(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0,S=0,g=0,y=0,F=0,O=0;n=s;s=s+80|0;f=n+68|0;a=n+64|0;o=n+60|0;c=n+56|0;l=n+52|0;b=n+48|0;k=n+44|0;h=n+40|0;w=n+36|0;d=n+32|0;v=n+28|0;m=n+24|0;_=n+20|0;p=n+16|0;E=n+12|0;S=n+8|0;g=n+4|0;y=n;t[a>>2]=e;t[o>>2]=i;t[c>>2]=r;t[h>>2]=0;t[w>>2]=0;t[b>>2]=IA(t[o>>2]|0)|0;if(!(t[b>>2]|0)){Io(t[a>>2]|0,t[(t[(t[(t[a>>2]|0)+16>>2]|0)+(t[c>>2]<<2)>>2]|0)+12>>2]|0,1605,132840,t[o>>2]|0);t[f>>2]=-1;F=t[f>>2]|0;s=n;return F|0}if(t[(t[b>>2]|0)+32>>2]|0){t[h>>2]=t[(t[b>>2]|0)+32>>2];t[(t[b>>2]|0)+32>>2]=0}if(((t[(t[a>>2]|0)+16>>2]|0)!=0?(t[(t[(t[a>>2]|0)+16>>2]|0)+(t[c>>2]<<2)>>2]|0)!=0:0)?(t[(t[(t[(t[a>>2]|0)+16>>2]|0)+(t[c>>2]<<2)>>2]|0)+4>>2]|0)!=0:0){if(t[h>>2]|0)pAi[t[135736>>2]&511](t[h>>2]|0);t[h>>2]=Yl(t[(t[(t[(t[a>>2]|0)+16>>2]|0)+(t[c>>2]<<2)>>2]|0)+4>>2]|0)|0}t[k>>2]=zA(t[b>>2]|0)|0;xA(t[b>>2]|0);if(!(t[k>>2]|0)){b=t[a>>2]|0;if(t[(t[a>>2]|0)+16>>2]|0)Io(b,t[(t[(t[(t[a>>2]|0)+16>>2]|0)+(t[c>>2]<<2)>>2]|0)+12>>2]|0,1605,132840,t[o>>2]|0);else Io(b,0,1605,132840,t[o>>2]|0);if(t[h>>2]|0)pAi[t[135736>>2]&511](t[h>>2]|0);t[f>>2]=-1;F=t[f>>2]|0;s=n;return F|0}do if((u[t[k>>2]>>0]|0|0)!=0?(u[t[k>>2]>>0]|0|0)!=35:0){if((t[t[a>>2]>>2]|0)!=0?(Xl(t[k>>2]|0,t[(t[t[a>>2]>>2]|0)+72>>2]|0)|0)!=0:0){O=22;break}t[w>>2]=0;while(1){if((t[w>>2]|0)>=(t[(t[a>>2]|0)+8>>2]|0))break;if((Xl(t[k>>2]|0,t[t[(t[(t[a>>2]|0)+16>>2]|0)+(t[w>>2]<<2)>>2]>>2]|0)|0)!=0?(t[(t[(t[(t[a>>2]|0)+16>>2]|0)+(t[w>>2]<<2)>>2]|0)+8>>2]|0)!=0:0){O=27;break}t[w>>2]=(t[w>>2]|0)+1}if((O|0)==27){t[l>>2]=t[(t[(t[(t[a>>2]|0)+16>>2]|0)+(t[w>>2]<<2)>>2]|0)+8>>2];break}t[d>>2]=t[(t[a>>2]|0)+60>>2];if(t[h>>2]|0){o=(t[a>>2]|0)+60|0;t[o>>2]=t[o>>2]|2}t[l>>2]=Yo(t[a>>2]|0,t[k>>2]|0)|0;t[(t[a>>2]|0)+60>>2]=t[d>>2];if(!(t[l>>2]|0)){pAi[t[135736>>2]&511](t[k>>2]|0);if(t[h>>2]|0)pAi[t[135736>>2]&511](t[h>>2]|0);t[f>>2]=-1;F=t[f>>2]|0;s=n;return F|0}t[(t[(t[(t[a>>2]|0)+16>>2]|0)+(t[c>>2]<<2)>>2]|0)+8>>2]=t[l>>2];if(!(Xl(t[k>>2]|0,t[(t[l>>2]|0)+72>>2]|0)|0)){pAi[t[135736>>2]&511](t[k>>2]|0);t[k>>2]=Yl(t[(t[l>>2]|0)+72>>2]|0)|0}t[w>>2]=(t[c>>2]|0)+1;while(1){if((t[w>>2]|0)>=(t[(t[a>>2]|0)+8>>2]|0))break;if(Xl(t[k>>2]|0,t[t[(t[(t[a>>2]|0)+16>>2]|0)+(t[w>>2]<<2)>>2]>>2]|0)|0){O=40;break}t[w>>2]=(t[w>>2]|0)+1}if((O|0)==40){o=(t[(t[(t[a>>2]|0)+16>>2]|0)+(t[c>>2]<<2)>>2]|0)+24|0;t[o>>2]=(t[o>>2]|0)+1}Go(t[a>>2]|0,t[t[a>>2]>>2]|0,t[l>>2]|0)|0;Wo(t[a>>2]|0,t[l>>2]|0,t[k>>2]|0)}else O=22;while(0);if((O|0)==22)t[l>>2]=0;d=(t[l>>2]|0)==0;do if(!(t[h>>2]|0)){o=t[a>>2]|0;if(d){b=Xy(t[(t[o>>2]|0)+12>>2]|0)|0;t[(t[(t[(t[a>>2]|0)+16>>2]|0)+(t[c>>2]<<2)>>2]|0)+16>>2]=b;break}else{b=Ko(o,t[t[a>>2]>>2]|0,t[l>>2]|0,t[(t[l>>2]|0)+12>>2]|0)|0;t[(t[(t[(t[a>>2]|0)+16>>2]|0)+(t[c>>2]<<2)>>2]|0)+16>>2]=b;break}}else{if(d)t[m>>2]=Ua(t[t[a>>2]>>2]|0,t[(t[(t[(t[a>>2]|0)+16>>2]|0)+(t[c>>2]<<2)>>2]|0)+12>>2]|0,0)|0;else t[m>>2]=Ua(t[l>>2]|0,0,0)|0;if(!(t[m>>2]|0)){Io(t[a>>2]|0,t[(t[(t[(t[a>>2]|0)+16>>2]|0)+(t[c>>2]<<2)>>2]|0)+12>>2]|0,1612,133056,0);pAi[t[135736>>2]&511](t[k>>2]|0);pAi[t[135736>>2]&511](t[h>>2]|0);t[f>>2]=-1;F=t[f>>2]|0;s=n;return F|0}t[v>>2]=ja(t[h>>2]|0,t[m>>2]|0)|0;if(!(t[v>>2]|0)){Io(t[a>>2]|0,t[(t[(t[(t[a>>2]|0)+16>>2]|0)+(t[c>>2]<<2)>>2]|0)+12>>2]|0,1612,133096,t[h>>2]|0);vf(t[m>>2]|0);pAi[t[135736>>2]&511](t[k>>2]|0);pAi[t[135736>>2]&511](t[h>>2]|0);t[f>>2]=-1;F=t[f>>2]|0;s=n;return F|0}switch(t[t[v>>2]>>2]|0){case 9:case 8:case 5:case 4:case 3:case 2:case 0:{Io(t[a>>2]|0,t[(t[(t[(t[a>>2]|0)+16>>2]|0)+(t[c>>2]<<2)>>2]|0)+12>>2]|0,1613,133136,t[h>>2]|0);vf(t[m>>2]|0);pAi[t[135736>>2]&511](t[k>>2]|0);pAi[t[135736>>2]&511](t[h>>2]|0);t[f>>2]=-1;F=t[f>>2]|0;s=n;return F|0}case 1:{O=56;break}default:{}}do if((O|0)==56){if((t[(t[v>>2]|0)+4>>2]|0)!=0?(t[t[(t[v>>2]|0)+4>>2]>>2]|0)>0:0)break;vf(t[m>>2]|0);pAi[t[135736>>2]&511](t[k>>2]|0);pAi[t[135736>>2]&511](t[h>>2]|0);t[f>>2]=-1;F=t[f>>2]|0;s=n;return F|0}while(0);t[_>>2]=t[(t[v>>2]|0)+4>>2];e:do if(t[_>>2]|0){t[w>>2]=0;while(1){if((t[w>>2]|0)>=(t[t[_>>2]>>2]|0))break e;i:do if(t[(t[(t[_>>2]|0)+8>>2]|0)+(t[w>>2]<<2)>>2]|0)switch(t[(t[(t[(t[_>>2]|0)+8>>2]|0)+(t[w>>2]<<2)>>2]|0)+4>>2]|0){case 10:case 11:case 12:case 14:case 15:case 16:case 17:case 19:case 20:{Io(t[a>>2]|0,t[(t[(t[(t[a>>2]|0)+16>>2]|0)+(t[c>>2]<<2)>>2]|0)+12>>2]|0,1613,133248,t[h>>2]|0);t[(t[(t[_>>2]|0)+8>>2]|0)+(t[w>>2]<<2)>>2]=0;t[(t[(t[_>>2]|0)+8>>2]|0)+(t[w>>2]<<2)>>2]=0;break i;break}case 18:{Io(t[a>>2]|0,t[(t[(t[(t[a>>2]|0)+16>>2]|0)+(t[c>>2]<<2)>>2]|0)+12>>2]|0,1613,133208,t[h>>2]|0);t[(t[(t[_>>2]|0)+8>>2]|0)+(t[w>>2]<<2)>>2]=0;break i;break}case 2:{Io(t[a>>2]|0,t[(t[(t[(t[a>>2]|0)+16>>2]|0)+(t[c>>2]<<2)>>2]|0)+12>>2]|0,1613,133168,t[h>>2]|0);t[(t[(t[_>>2]|0)+8>>2]|0)+(t[w>>2]<<2)>>2]=0;break i;break}default:break i}while(0);t[w>>2]=(t[w>>2]|0)+1}}while(0);if(!(t[l>>2]|0)){t[(t[(t[(t[a>>2]|0)+16>>2]|0)+(t[c>>2]<<2)>>2]|0)+28>>2]=t[v>>2];t[(t[(t[(t[a>>2]|0)+16>>2]|0)+(t[c>>2]<<2)>>2]|0)+16>>2]=0}else{b=Vo(t[a>>2]|0,t[t[a>>2]>>2]|0,t[l>>2]|0,t[v>>2]|0)|0;t[(t[(t[(t[a>>2]|0)+16>>2]|0)+(t[c>>2]<<2)>>2]|0)+16>>2]=b;_n(t[v>>2]|0)}vf(t[m>>2]|0);pAi[t[135736>>2]&511](t[h>>2]|0)}while(0);if(((t[l>>2]|0)!=0&(t[k>>2]|0)!=0?(t[(t[a>>2]|0)+60>>2]&262144|0)==0:0)?(t[(t[l>>2]|0)+88>>2]&262144|0)==0:0){t[E>>2]=tF(t[(t[(t[(t[a>>2]|0)+16>>2]|0)+(t[c>>2]<<2)>>2]|0)+12>>2]|0,133288,133296)|0;do if(!(t[E>>2]|0)){t[S>>2]=WA(t[k>>2]|0,t[(t[a>>2]|0)+64>>2]|0)|0;if(!(t[S>>2]|0)){Io(t[a>>2]|0,t[(t[(t[(t[a>>2]|0)+16>>2]|0)+(t[c>>2]<<2)>>2]|0)+12>>2]|0,1605,133336,t[k>>2]|0);break}if(es(t[S>>2]|0,47)|0){t[E>>2]=t[S>>2];break}else{pAi[t[135736>>2]&511](t[S>>2]|0);break}}while(0);if(t[E>>2]|0){t[p>>2]=t[(t[(t[(t[a>>2]|0)+16>>2]|0)+(t[c>>2]<<2)>>2]|0)+16>>2];while(1){if(!(t[p>>2]|0))break;do if((t[(t[p>>2]|0)+4>>2]|0)==1){t[S>>2]=oF(t[(t[p>>2]|0)+32>>2]|0,t[p>>2]|0)|0;if(!(t[S>>2]|0)){aF(t[p>>2]|0,t[E>>2]|0);break}l=(Xl(t[S>>2]|0,t[(t[(t[p>>2]|0)+32>>2]|0)+72>>2]|0)|0)!=0;h=t[p>>2]|0;if(!l){t[g>>2]=tF(h,133288,133296)|0;if(t[g>>2]|0){t[y>>2]=GA(t[g>>2]|0,t[E>>2]|0)|0;if(!(t[y>>2]|0))Io(t[a>>2]|0,t[(t[(t[(t[a>>2]|0)+16>>2]|0)+(t[c>>2]<<2)>>2]|0)+12>>2]|0,1605,133376,t[g>>2]|0);else{aF(t[p>>2]|0,t[y>>2]|0);pAi[t[135736>>2]&511](t[y>>2]|0)}pAi[t[135736>>2]&511](t[g>>2]|0)}}else aF(h,t[E>>2]|0);pAi[t[135736>>2]&511](t[S>>2]|0)}while(0);t[p>>2]=t[(t[p>>2]|0)+24>>2]}pAi[t[135736>>2]&511](t[E>>2]|0)}}if(((t[c>>2]|0)<(t[(t[a>>2]|0)+8>>2]|0)?(t[(t[(t[(t[a>>2]|0)+16>>2]|0)+(t[c>>2]<<2)>>2]|0)+8>>2]|0)!=0:0)?(t[(t[(t[(t[a>>2]|0)+16>>2]|0)+(t[c>>2]<<2)>>2]|0)+24>>2]|0)<=1:0){fy(t[(t[(t[(t[a>>2]|0)+16>>2]|0)+(t[c>>2]<<2)>>2]|0)+8>>2]|0);t[(t[(t[(t[a>>2]|0)+16>>2]|0)+(t[c>>2]<<2)>>2]|0)+8>>2]=0}pAi[t[135736>>2]&511](t[k>>2]|0);t[f>>2]=0;F=t[f>>2]|0;s=n;return F|0}function zo(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0,S=0,g=0,y=0,F=0,O=0,A=0;n=s;s=s+80|0;f=n+68|0;a=n+64|0;o=n+60|0;c=n+56|0;l=n+52|0;b=n+48|0;k=n+44|0;h=n+40|0;w=n+36|0;d=n+32|0;v=n+28|0;m=n+24|0;_=n+20|0;p=n+16|0;E=n+12|0;S=n+8|0;g=n+4|0;y=n;t[a>>2]=e;t[o>>2]=i;t[c>>2]=r;t[d>>2]=0;t[v>>2]=0;t[p>>2]=0;t[k>>2]=IA(t[o>>2]|0)|0;if(!(t[k>>2]|0)){Io(t[a>>2]|0,t[(t[(t[(t[a>>2]|0)+16>>2]|0)+(t[c>>2]<<2)>>2]|0)+12>>2]|0,1605,132840,t[o>>2]|0);t[f>>2]=-1;F=t[f>>2]|0;s=n;return F|0}if(t[(t[k>>2]|0)+32>>2]|0){Io(t[a>>2]|0,t[(t[(t[(t[a>>2]|0)+16>>2]|0)+(t[c>>2]<<2)>>2]|0)+12>>2]|0,1606,132864,t[(t[k>>2]|0)+32>>2]|0);xA(t[k>>2]|0);t[f>>2]=-1;F=t[f>>2]|0;s=n;return F|0}t[h>>2]=zA(t[k>>2]|0)|0;xA(t[k>>2]|0);if(!(t[h>>2]|0)){Io(t[a>>2]|0,t[(t[(t[(t[a>>2]|0)+16>>2]|0)+(t[c>>2]<<2)>>2]|0)+12>>2]|0,1605,132840,t[o>>2]|0);t[f>>2]=-1;F=t[f>>2]|0;s=n;return F|0}if(!(u[t[h>>2]>>0]|0)){Io(t[a>>2]|0,t[(t[(t[(t[a>>2]|0)+16>>2]|0)+(t[c>>2]<<2)>>2]|0)+12>>2]|0,1607,132912,0);pAi[t[135736>>2]&511](t[h>>2]|0);t[f>>2]=-1;F=t[f>>2]|0;s=n;return F|0}t[w>>2]=0;while(1){if((t[w>>2]|0)>=(t[(t[a>>2]|0)+20>>2]|0)){O=14;break}o=(Xl(t[h>>2]|0,t[(t[(t[a>>2]|0)+32>>2]|0)+(t[w>>2]<<2)>>2]|0)|0)!=0;A=t[w>>2]|0;if(o){O=12;break}t[w>>2]=A+1}do if((O|0)==12)t[b>>2]=Gy(t[(t[(t[a>>2]|0)+28>>2]|0)+(A<<2)>>2]|0,1)|0;else if((O|0)==14){if((t[(t[(t[a>>2]|0)+16>>2]|0)+(t[c>>2]<<2)>>2]|0)!=0?(t[(t[(t[(t[a>>2]|0)+16>>2]|0)+(t[c>>2]<<2)>>2]|0)+12>>2]|0)!=0:0)t[d>>2]=cF(t[(t[(t[(t[a>>2]|0)+16>>2]|0)+(t[c>>2]<<2)>>2]|0)+12>>2]|0,132960)|0;do if(t[d>>2]|0){t[v>>2]=B_(t[d>>2]|0)|0;if((t[v>>2]|0)!=-1){pAi[t[135736>>2]&511](t[d>>2]|0);break}Io(t[a>>2]|0,t[(t[(t[(t[a>>2]|0)+16>>2]|0)+(t[c>>2]<<2)>>2]|0)+12>>2]|0,1610,132976,t[d>>2]|0);pAi[t[135736>>2]&511](t[d>>2]|0);pAi[t[135736>>2]&511](t[h>>2]|0);t[f>>2]=-1;F=t[f>>2]|0;s=n;return F|0}while(0);t[m>>2]=zp()|0;t[_>>2]=uA(t[h>>2]|0,0,t[m>>2]|0)|0;if(!(t[_>>2]|0)){Up(t[m>>2]|0);pAi[t[135736>>2]&511](t[h>>2]|0);t[f>>2]=-1;F=t[f>>2]|0;s=n;return F|0}t[l>>2]=t[t[_>>2]>>2];if(!(t[l>>2]|0)){Dp(t[_>>2]|0);Up(t[m>>2]|0);pAi[t[135736>>2]&511](t[h>>2]|0);t[f>>2]=-1;F=t[f>>2]|0;s=n;return F|0}if(t[(t[l>>2]|0)+12>>2]|0)W_(t[(t[l>>2]|0)+12>>2]|0)|0;o=j_(t[v>>2]|0)|0;t[(t[l>>2]|0)+12>>2]=o;t[b>>2]=yy(0)|0;while(1){if((QO(t[l>>2]|0,128)|0)<=0){O=41;break}t[S>>2]=Os(t[(t[l>>2]|0)+16>>2]|0)|0;t[E>>2]=Ns(t[(t[l>>2]|0)+16>>2]|0)|0;t[w>>2]=0;while(1){if((t[w>>2]|0)>=(t[E>>2]|0)){O=40;break}t[g>>2]=Mp(0,(t[S>>2]|0)+(t[w>>2]|0)|0,y)|0;o=t[g>>2]|0;if((t[g>>2]|0)<256){if(!(9<=(o|0)&(t[g>>2]|0)<=10|(t[g>>2]|0)==13|32<=(t[g>>2]|0)))break}else if((!(256<=(o|0)&(t[g>>2]|0)<=55295)?!(57344<=(t[g>>2]|0)&(t[g>>2]|0)<=65533):0)?!(65536<=(t[g>>2]|0)&(t[g>>2]|0)<=1114111):0)break;t[p>>2]=0;bF(t[b>>2]|0,(t[S>>2]|0)+(t[w>>2]|0)|0,t[y>>2]|0);t[w>>2]=(t[w>>2]|0)+(t[y>>2]|0)}if((O|0)==40){O=0;ys(t[(t[l>>2]|0)+16>>2]|0,t[E>>2]|0)|0;continue}if((t[p>>2]|0)!=0?1:((t[E>>2]|0)-(t[w>>2]|0)|0)>=4)break;t[p>>2]=1;ys(t[(t[l>>2]|0)+16>>2]|0,t[w>>2]|0)|0}if((O|0)==41){Up(t[m>>2]|0);Xo(t[a>>2]|0,t[b>>2]|0,t[h>>2]|0);Dp(t[_>>2]|0);break}Io(t[a>>2]|0,t[(t[(t[(t[a>>2]|0)+16>>2]|0)+(t[c>>2]<<2)>>2]|0)+12>>2]|0,1608,133008,t[h>>2]|0);IO(t[l>>2]|0);pAi[t[135736>>2]&511](t[h>>2]|0);t[f>>2]=-1;F=t[f>>2]|0;s=n;return F|0}while(0);t[(t[(t[(t[a>>2]|0)+16>>2]|0)+(t[c>>2]<<2)>>2]|0)+16>>2]=t[b>>2];pAi[t[135736>>2]&511](t[h>>2]|0);t[f>>2]=0;F=t[f>>2]|0;s=n;return F|0}function jo(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0;n=s;s=s+32|0;f=n+20|0;u=n+16|0;a=n+12|0;o=n+8|0;c=n+4|0;l=n;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;t[l>>2]=0;if((t[a>>2]|0)!=0?!((t[u>>2]|0)==0?1:(t[(t[a>>2]|0)+4>>2]|0)==18):0){if(t[(t[a>>2]|0)+12>>2]|0){t[c>>2]=Eo(t[t[u>>2]>>2]|0)|0;if(!(t[c>>2]|0)){t[f>>2]=-1;b=t[f>>2]|0;s=n;return b|0}t[(t[c>>2]|0)+68>>2]=t[(t[u>>2]|0)+68>>2];r=Yl(t[(t[u>>2]|0)+64>>2]|0)|0;t[(t[c>>2]|0)+64>>2]=r;go(t[c>>2]|0,t[(t[u>>2]|0)+60>>2]|0)|0;t[l>>2]=To(t[c>>2]|0,t[t[u>>2]>>2]|0,t[(t[a>>2]|0)+12>>2]|0)|0;if((t[(t[u>>2]|0)+52>>2]|0)<=0){if((t[l>>2]|0)>0)t[l>>2]=0}else t[l>>2]=-1;So(t[c>>2]|0);c=Ky(t[t[u>>2]>>2]|0,t[(t[a>>2]|0)+12>>2]|0)|0;t[(t[(t[(t[u>>2]|0)+16>>2]|0)+(t[o>>2]<<2)>>2]|0)+16>>2]=c}else{t[(t[(t[(t[u>>2]|0)+16>>2]|0)+(t[o>>2]<<2)>>2]|0)+16>>2]=0;t[(t[(t[(t[u>>2]|0)+16>>2]|0)+(t[o>>2]<<2)>>2]|0)+32>>2]=1}t[f>>2]=t[l>>2];b=t[f>>2]|0;s=n;return b|0}t[f>>2]=-1;b=t[f>>2]|0;s=n;return b|0}function Vo(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0;f=s;s=s+48|0;u=f+44|0;a=f+40|0;o=f+36|0;c=f+32|0;l=f+28|0;b=f+24|0;k=f+20|0;h=f+16|0;w=f+12|0;d=f+8|0;v=f+4|0;m=f;t[a>>2]=e;t[o>>2]=i;t[c>>2]=r;t[l>>2]=n;t[b>>2]=0;t[k>>2]=0;if(!(t[c>>2]|0))t[c>>2]=t[t[a>>2]>>2];if((t[a>>2]|0)==0|(t[o>>2]|0)==0|(t[c>>2]|0)==0|(t[l>>2]|0)==0){t[u>>2]=0;_=t[u>>2]|0;s=f;return _|0}n=t[t[l>>2]>>2]|0;e:do if((n|0)==6){t[u>>2]=Jo(t[a>>2]|0,t[o>>2]|0,t[c>>2]|0,t[l>>2]|0)|0;_=t[u>>2]|0;s=f;return _|0}else if((n|0)==1){t[w>>2]=t[(t[l>>2]|0)+4>>2];if(!(t[w>>2]|0)){t[u>>2]=0;_=t[u>>2]|0;s=f;return _|0}t[h>>2]=0;while(1){if((t[h>>2]|0)>=(t[t[w>>2]>>2]|0))break e;i:do if(t[(t[(t[w>>2]|0)+8>>2]|0)+(t[h>>2]<<2)>>2]|0){switch(t[(t[(t[(t[w>>2]|0)+8>>2]|0)+(t[h>>2]<<2)>>2]|0)+4>>2]|0){case 2:case 18:case 10:case 11:case 12:case 14:case 15:case 16:case 17:{break i;break}case 19:break;default:{if(!(t[k>>2]|0)){r=Zo(t[a>>2]|0,t[o>>2]|0,t[c>>2]|0,t[(t[(t[w>>2]|0)+8>>2]|0)+(t[h>>2]<<2)>>2]|0)|0;t[k>>2]=r;t[b>>2]=r;break i}oy(t[k>>2]|0,Zo(t[a>>2]|0,t[o>>2]|0,t[c>>2]|0,t[(t[(t[w>>2]|0)+8>>2]|0)+(t[h>>2]<<2)>>2]|0)|0)|0;if(!(t[(t[k>>2]|0)+24>>2]|0))break i;t[k>>2]=t[(t[k>>2]|0)+24>>2];break i}}t[v>>2]=t[(t[(t[w>>2]|0)+8>>2]|0)+(t[h>>2]<<2)>>2];t[v>>2]=t[(t[v>>2]|0)+24>>2];while(1){if(!(t[v>>2]|0))break i;switch(t[(t[v>>2]|0)+4>>2]|0){case 8:case 7:case 6:case 5:case 1:case 4:case 3:break;default:break i}t[d>>2]=Zo(t[a>>2]|0,t[o>>2]|0,t[c>>2]|0,t[v>>2]|0)|0;if(!(t[k>>2]|0)){r=t[d>>2]|0;t[k>>2]=r;t[b>>2]=r}else{oy(t[k>>2]|0,t[d>>2]|0)|0;t[k>>2]=t[d>>2]}t[v>>2]=t[(t[v>>2]|0)+24>>2]}}while(0);t[h>>2]=(t[h>>2]|0)+1}}else if((n|0)==7){t[m>>2]=t[(t[l>>2]|0)+28>>2];if(!(t[m>>2]|0)){t[u>>2]=0;_=t[u>>2]|0;s=f;return _|0}t[h>>2]=0;while(1){if((t[h>>2]|0)>=(t[t[m>>2]>>2]|0))break e;if(!(t[k>>2]|0)){r=Vo(t[a>>2]|0,t[o>>2]|0,t[c>>2]|0,t[(t[(t[m>>2]|0)+8>>2]|0)+(t[h>>2]<<2)>>2]|0)|0;t[k>>2]=r;t[b>>2]=r}else{r=t[k>>2]|0;oy(r,Vo(t[a>>2]|0,t[o>>2]|0,t[c>>2]|0,t[(t[(t[m>>2]|0)+8>>2]|0)+(t[h>>2]<<2)>>2]|0)|0)|0}i:do if(t[k>>2]|0)while(1){if(!(t[(t[k>>2]|0)+24>>2]|0))break i;t[k>>2]=t[(t[k>>2]|0)+24>>2]}while(0);t[h>>2]=(t[h>>2]|0)+1}}while(0);t[u>>2]=t[b>>2];_=t[u>>2]|0;s=f;return _|0}function qo(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,l=0;n=s;s=s+32|0;f=n+16|0;u=n+12|0;a=n+8|0;o=n+4|0;c=n;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;t[c>>2]=gAi[t[135744>>2]&511](36)|0;if(!(t[c>>2]|0)){Mo(t[u>>2]|0,t[o>>2]|0,133672);t[f>>2]=0;l=t[f>>2]|0;s=n;return l|0}r=(t[c>>2]|0)+0|0;i=r+36|0;do{t[r>>2]=0;r=r+4|0}while((r|0)<(i|0));if(!(t[a>>2]|0))t[t[c>>2]>>2]=0;else{r=Yl(t[a>>2]|0)|0;t[t[c>>2]>>2]=r}t[(t[c>>2]|0)+4>>2]=0;t[(t[c>>2]|0)+12>>2]=t[o>>2];t[(t[c>>2]|0)+8>>2]=0;t[(t[c>>2]|0)+24>>2]=0;t[(t[c>>2]|0)+20>>2]=0;t[(t[c>>2]|0)+16>>2]=0;if((t[(t[u>>2]|0)+12>>2]|0)==0?(t[(t[u>>2]|0)+12>>2]=4,r=gAi[t[135744>>2]&511](t[(t[u>>2]|0)+12>>2]<<2)|0,t[(t[u>>2]|0)+16>>2]=r,(t[(t[u>>2]|0)+16>>2]|0)==0):0){Mo(t[u>>2]|0,t[o>>2]|0,133672);No(t[c>>2]|0);t[f>>2]=0;l=t[f>>2]|0;s=n;return l|0}if((t[(t[u>>2]|0)+8>>2]|0)>=(t[(t[u>>2]|0)+12>>2]|0)?(r=(t[u>>2]|0)+12|0,t[r>>2]=t[r>>2]<<1,r=MAi[t[135760>>2]&511](t[(t[u>>2]|0)+16>>2]|0,t[(t[u>>2]|0)+12>>2]<<2)|0,t[(t[u>>2]|0)+16>>2]=r,(t[(t[u>>2]|0)+16>>2]|0)==0):0){Mo(t[u>>2]|0,t[o>>2]|0,133672);No(t[c>>2]|0);t[f>>2]=0;l=t[f>>2]|0;s=n;return l|0}o=t[c>>2]|0;r=(t[u>>2]|0)+8|0;a=t[r>>2]|0;t[r>>2]=a+1;t[(t[(t[u>>2]|0)+16>>2]|0)+(a<<2)>>2]=o;t[f>>2]=t[c>>2];l=t[f>>2]|0;s=n;return l|0}function Yo(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0;r=s;s=s+32|0;n=r+20|0;f=r+16|0;u=r+12|0;a=r+8|0;o=r+4|0;c=r;t[f>>2]=e;t[u>>2]=i;rS();t[o>>2]=zp()|0;i=t[f>>2]|0;if(!(t[o>>2]|0)){Mo(i,0,133464);t[n>>2]=0;l=t[n>>2]|0;s=r;return l|0}t[(t[o>>2]|0)+272>>2]=t[i+68>>2];if((t[t[f>>2]>>2]|0)!=0?(t[(t[t[f>>2]>>2]|0)+80>>2]|0)!=0:0){if(t[(t[o>>2]|0)+296>>2]|0)bz(t[(t[o>>2]|0)+296>>2]|0);t[(t[o>>2]|0)+296>>2]=t[(t[t[f>>2]>>2]|0)+80>>2];sz(t[(t[o>>2]|0)+296>>2]|0)|0}mS(t[o>>2]|0,t[(t[f>>2]|0)+60>>2]|4)|0;t[c>>2]=uA(t[u>>2]|0,0,t[o>>2]|0)|0;f=t[o>>2]|0;if(!(t[c>>2]|0)){Up(f);t[n>>2]=0;l=t[n>>2]|0;s=r;return l|0}eE(f,t[c>>2]|0)|0;if(!(t[(t[o>>2]|0)+180>>2]|0)){c=rA(t[u>>2]|0)|0;t[(t[o>>2]|0)+180>>2]=c}c=(t[o>>2]|0)+276|0;t[c>>2]=t[c>>2]|2;iS(t[o>>2]|0)|0;if(t[(t[o>>2]|0)+12>>2]|0)t[a>>2]=t[(t[o>>2]|0)+8>>2];else{t[a>>2]=0;if(t[(t[o>>2]|0)+8>>2]|0)fy(t[(t[o>>2]|0)+8>>2]|0);t[(t[o>>2]|0)+8>>2]=0}Up(t[o>>2]|0);t[n>>2]=t[a>>2];l=t[n>>2]|0;s=r;return l|0}function Go(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0;n=s;s=s+48|0;f=n+40|0;u=n+36|0;a=n+32|0;o=n+28|0;c=n+24|0;l=n+20|0;b=n+16|0;k=n+8|0;h=n;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;if(!(t[u>>2]|0)){t[f>>2]=-1;w=t[f>>2]|0;s=n;return w|0}if((t[o>>2]|0)!=0?(t[(t[o>>2]|0)+44>>2]|0)!=0:0){t[l>>2]=t[(t[a>>2]|0)+44>>2];if(!(t[l>>2]|0)){t[c>>2]=eF(t[a>>2]|0)|0;if(!(t[c>>2]|0)){t[f>>2]=-1;w=t[f>>2]|0;s=n;return w|0}t[l>>2]=$g(t[a>>2]|0,t[(t[c>>2]|0)+8>>2]|0,0,0)|0;if(!(t[l>>2]|0)){t[f>>2]=-1;w=t[f>>2]|0;s=n;return w|0}}t[b>>2]=t[(t[o>>2]|0)+44>>2];if((t[b>>2]|0)!=0?(t[(t[b>>2]|0)+48>>2]|0)!=0:0){t[k+4>>2]=t[u>>2];t[k>>2]=t[a>>2];aO(t[(t[b>>2]|0)+48>>2]|0,314,k)}t[b>>2]=t[(t[o>>2]|0)+48>>2];if((((t[b>>2]|0)!=0?(t[(t[b>>2]|0)+48>>2]|0)!=0:0)?(t[h+4>>2]=t[u>>2],t[h>>2]=t[a>>2],(Xl(t[(t[l>>2]|0)+52>>2]|0,t[(t[b>>2]|0)+52>>2]|0)|0)==0):0)?(Xl(t[(t[l>>2]|0)+56>>2]|0,t[(t[b>>2]|0)+56>>2]|0)|0)==0:0)aO(t[(t[b>>2]|0)+48>>2]|0,314,h);t[f>>2]=0;w=t[f>>2]|0;s=n;return w|0}t[f>>2]=0;w=t[f>>2]|0;s=n;return w|0}function Wo(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0;n=s;s=s+32|0;f=n+16|0;u=n+12|0;a=n+4|0;o=n;t[f>>2]=e;t[u>>2]=i;t[n+8>>2]=r;t[a>>2]=Eo(t[u>>2]|0)|0;if(!(t[a>>2]|0)){s=n;return}t[(t[a>>2]|0)+68>>2]=t[(t[f>>2]|0)+68>>2];t[(t[a>>2]|0)+12>>2]=t[(t[f>>2]|0)+12>>2];t[(t[a>>2]|0)+8>>2]=t[(t[f>>2]|0)+8>>2];r=gAi[t[135744>>2]&511](t[(t[a>>2]|0)+12>>2]<<2)|0;t[(t[a>>2]|0)+16>>2]=r;r=t[f>>2]|0;if(!(t[(t[a>>2]|0)+16>>2]|0)){Mo(r,t[u>>2]|0,133408);pAi[t[135736>>2]&511](t[a>>2]|0);s=n;return}t[(t[a>>2]|0)+44>>2]=t[r+44>>2];t[(t[a>>2]|0)+40>>2]=t[(t[f>>2]|0)+40>>2];t[(t[a>>2]|0)+48>>2]=t[(t[f>>2]|0)+48>>2];r=Yl(t[(t[f>>2]|0)+64>>2]|0)|0;t[(t[a>>2]|0)+64>>2]=r;t[(t[a>>2]|0)+4>>2]=t[(t[f>>2]|0)+8>>2];t[o>>2]=0;while(1){if((t[o>>2]|0)>=(t[(t[f>>2]|0)+8>>2]|0))break;t[(t[(t[a>>2]|0)+16>>2]|0)+(t[o>>2]<<2)>>2]=t[(t[(t[f>>2]|0)+16>>2]|0)+(t[o>>2]<<2)>>2];r=(t[(t[(t[a>>2]|0)+16>>2]|0)+(t[o>>2]<<2)>>2]|0)+24|0;t[r>>2]=(t[r>>2]|0)+1;t[o>>2]=(t[o>>2]|0)+1}t[(t[a>>2]|0)+60>>2]=t[(t[f>>2]|0)+60>>2];r=t[a>>2]|0;i=t[u>>2]|0;To(r,i,eF(t[u>>2]|0)|0)|0;t[o>>2]=0;while(1){if((t[o>>2]|0)>=(t[(t[f>>2]|0)+8>>2]|0))break;u=(t[(t[(t[a>>2]|0)+16>>2]|0)+(t[o>>2]<<2)>>2]|0)+24|0;t[u>>2]=(t[u>>2]|0)+-1;t[(t[(t[a>>2]|0)+16>>2]|0)+(t[o>>2]<<2)>>2]=0;t[o>>2]=(t[o>>2]|0)+1}t[(t[f>>2]|0)+48>>2]=t[(t[a>>2]|0)+48>>2];t[(t[f>>2]|0)+44>>2]=t[(t[a>>2]|0)+44>>2];t[(t[a>>2]|0)+44>>2]=0;t[(t[a>>2]|0)+40>>2]=0;t[(t[a>>2]|0)+48>>2]=0;So(t[a>>2]|0);s=n;return}function Ko(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0;f=s;s=s+48|0;u=f+32|0;a=f+28|0;o=f+24|0;c=f+20|0;l=f+16|0;b=f+12|0;k=f+8|0;h=f+4|0;w=f;t[a>>2]=e;t[o>>2]=i;t[c>>2]=r;t[l>>2]=n;t[h>>2]=0;t[w>>2]=0;if((t[a>>2]|0)==0|(t[o>>2]|0)==0|(t[c>>2]|0)==0|(t[l>>2]|0)==0){t[u>>2]=0;d=t[u>>2]|0;s=f;return d|0}t[b>>2]=t[l>>2];while(1){if(!(t[b>>2]|0))break;t[k>>2]=Zo(t[a>>2]|0,t[o>>2]|0,t[c>>2]|0,t[b>>2]|0)|0;do if(t[k>>2]|0){l=t[k>>2]|0;if(!(t[h>>2]|0)){t[w>>2]=l;t[h>>2]=l;break}else{t[(t[w>>2]|0)+24>>2]=l;t[(t[k>>2]|0)+28>>2]=t[w>>2];t[w>>2]=t[k>>2];break}}while(0);t[b>>2]=t[(t[b>>2]|0)+24>>2]}t[u>>2]=t[h>>2];d=t[u>>2]|0;s=f;return d|0}function Xo(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0;n=s;s=s+16|0;f=n+8|0;u=n+4|0;a=n;t[f>>2]=e;t[u>>2]=i;t[a>>2]=r;if(!(t[(t[f>>2]|0)+24>>2]|0)){t[(t[f>>2]|0)+24>>2]=4;r=gAi[t[135744>>2]&511](t[(t[f>>2]|0)+24>>2]<<2)|0;t[(t[f>>2]|0)+28>>2]=r;if(!(t[(t[f>>2]|0)+28>>2]|0)){Mo(t[f>>2]|0,0,133040);s=n;return}r=gAi[t[135744>>2]&511](t[(t[f>>2]|0)+24>>2]<<2)|0;t[(t[f>>2]|0)+32>>2]=r;if(!(t[(t[f>>2]|0)+32>>2]|0)){Mo(t[f>>2]|0,0,133040);s=n;return}}if((t[(t[f>>2]|0)+20>>2]|0)>=(t[(t[f>>2]|0)+24>>2]|0)){r=(t[f>>2]|0)+24|0;t[r>>2]=t[r>>2]<<1;r=MAi[t[135760>>2]&511](t[(t[f>>2]|0)+28>>2]|0,t[(t[f>>2]|0)+24>>2]<<2)|0;t[(t[f>>2]|0)+28>>2]=r;if(!(t[(t[f>>2]|0)+28>>2]|0)){Mo(t[f>>2]|0,0,133040);s=n;return}r=MAi[t[135760>>2]&511](t[(t[f>>2]|0)+32>>2]|0,t[(t[f>>2]|0)+24>>2]<<2)|0;t[(t[f>>2]|0)+32>>2]=r;if(!(t[(t[f>>2]|0)+32>>2]|0)){Mo(t[f>>2]|0,0,133040);s=n;return}}t[(t[(t[f>>2]|0)+28>>2]|0)+(t[(t[f>>2]|0)+20>>2]<<2)>>2]=t[u>>2];u=Yl(t[a>>2]|0)|0;t[(t[(t[f>>2]|0)+32>>2]|0)+(t[(t[f>>2]|0)+20>>2]<<2)>>2]=u;u=(t[f>>2]|0)+20|0;t[u>>2]=(t[u>>2]|0)+1;s=n;return}function Zo(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0;f=s;s=s+32|0;u=f+20|0;a=f+16|0;o=f+12|0;c=f+8|0;l=f+4|0;b=f;t[a>>2]=e;t[o>>2]=i;t[c>>2]=r;t[l>>2]=n;t[b>>2]=0;if((t[a>>2]|0)==0|(t[o>>2]|0)==0|(t[c>>2]|0)==0|(t[l>>2]|0)==0){t[u>>2]=0;k=t[u>>2]|0;s=f;return k|0}if((t[(t[l>>2]|0)+4>>2]|0)==14){t[u>>2]=0;k=t[u>>2]|0;s=f;return k|0}if((t[(t[l>>2]|0)+4>>2]|0)==9)t[b>>2]=Ko(t[a>>2]|0,t[o>>2]|0,t[c>>2]|0,t[(t[l>>2]|0)+12>>2]|0)|0;else t[b>>2]=Wy(t[l>>2]|0,t[o>>2]|0,1)|0;t[u>>2]=t[b>>2];k=t[u>>2]|0;s=f;return k|0}function Jo(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0,S=0,g=0,y=0,F=0,O=0,A=0,M=0,R=0,N=0,T=0;f=s;s=s+96|0;u=f+84|0;a=f+80|0;o=f+76|0;c=f+72|0;l=f+68|0;b=f+64|0;k=f+60|0;h=f+56|0;w=f+52|0;d=f+48|0;v=f+44|0;m=f+40|0;_=f+36|0;p=f+32|0;E=f+28|0;S=f+24|0;g=f+20|0;y=f+16|0;F=f+12|0;O=f+8|0;A=f+4|0;M=f;t[a>>2]=e;t[o>>2]=i;t[c>>2]=r;t[l>>2]=n;t[b>>2]=0;t[k>>2]=0;t[h>>2]=0;t[S>>2]=0;t[g>>2]=0;t[y>>2]=0;t[F>>2]=0;if((t[a>>2]|0)==0|(t[o>>2]|0)==0|(t[c>>2]|0)==0|(t[l>>2]|0)==0){t[u>>2]=0;R=t[u>>2]|0;s=f;return R|0}if((t[t[l>>2]>>2]|0)!=6){t[u>>2]=0;R=t[u>>2]|0;s=f;return R|0}t[v>>2]=t[(t[l>>2]|0)+28>>2];if((t[v>>2]|0)!=0?(t[(t[v>>2]|0)+4>>2]|0)!=18:0){t[_>>2]=t[(t[l>>2]|0)+36>>2];if(!(t[_>>2]|0)){t[u>>2]=Wy(t[v>>2]|0,t[o>>2]|0,1)|0;R=t[u>>2]|0;s=f;return R|0}if((t[(t[_>>2]|0)+4>>2]|0)==18){t[u>>2]=0;R=t[u>>2]|0;s=f;return R|0}t[m>>2]=t[v>>2];t[p>>2]=t[(t[l>>2]|0)+32>>2];t[E>>2]=t[(t[l>>2]|0)+40>>2];e:while(1){if(!(t[m>>2]|0)){N=65;break}i:while(1){if((t[S>>2]|0)<0){while(1){if((t[S>>2]|0)>=0)break;t[d>>2]=Wy(t[h>>2]|0,t[o>>2]|0,2)|0;Hy(t[d>>2]|0,t[b>>2]|0)|0;t[b>>2]=t[d>>2];t[h>>2]=t[(t[h>>2]|0)+20>>2];t[S>>2]=(t[S>>2]|0)+1}t[k>>2]=t[b>>2];t[g>>2]=0}while(1){if((t[S>>2]|0)>=(t[g>>2]|0))break;t[k>>2]=t[(t[k>>2]|0)+20>>2];t[g>>2]=(t[g>>2]|0)+-1}T=t[m>>2]|0;if((t[m>>2]|0)==(t[_>>2]|0))break;do if((T|0)!=(t[v>>2]|0)){t[w>>2]=0;switch(t[(t[m>>2]|0)+4>>2]|0){case 2:case 20:case 19:case 17:case 6:case 16:case 15:case 14:break;default:t[w>>2]=Wy(t[m>>2]|0,t[o>>2]|0,2)|0}if(t[w>>2]|0){l=t[k>>2]|0;c=t[w>>2]|0;if((t[S>>2]|0)==(t[g>>2]|0))oy(l,c)|0;else{Hy(l,c)|0;t[g>>2]=t[S>>2]}t[k>>2]=t[w>>2]}}else{if((t[(t[m>>2]|0)+4>>2]|0)!=3?(t[(t[m>>2]|0)+4>>2]|0)!=4:0){t[w>>2]=Wy(t[m>>2]|0,t[o>>2]|0,2)|0;c=t[w>>2]|0;t[k>>2]=c;t[b>>2]=c;t[h>>2]=t[(t[m>>2]|0)+20>>2];if((t[p>>2]|0)>1){N=55;break i}else break}t[M>>2]=t[(t[m>>2]|0)+40>>2];if(!(t[M>>2]|0))t[w>>2]=Oy(0,0)|0;else{if((t[p>>2]|0)>1){t[M>>2]=(t[M>>2]|0)+((t[p>>2]|0)-1);t[p>>2]=0}t[w>>2]=yy(t[M>>2]|0)|0}c=t[w>>2]|0;t[b>>2]=c;t[k>>2]=c;t[h>>2]=t[(t[m>>2]|0)+20>>2]}while(0);t[m>>2]=Va(t[m>>2]|0,S)|0;if(!(t[F>>2]|0))continue e;if(!((t[m>>2]|0)!=0?(t[S>>2]|0)<(t[y>>2]|0):0)){N=65;break e}}if((N|0)==55){N=0;t[m>>2]=$o(t[m>>2]|0,(t[p>>2]|0)-1|0)|0;t[g>>2]=1;t[S>>2]=1;t[p>>2]=0;continue}if((t[T+4>>2]|0)==3)break;t[y>>2]=t[S>>2];t[F>>2]=1;t[w>>2]=Wy(t[m>>2]|0,t[o>>2]|0,2)|0;do if(t[b>>2]|0){c=t[k>>2]|0;l=t[w>>2]|0;if((t[S>>2]|0)==(t[g>>2]|0)){oy(c,l)|0;break}else{Hy(c,l)|0;t[g>>2]=t[S>>2];break}}else{t[b>>2]=t[w>>2];t[h>>2]=t[(t[m>>2]|0)+20>>2]}while(0);t[k>>2]=t[w>>2];if((t[E>>2]|0)>1){t[_>>2]=$o(t[m>>2]|0,(t[E>>2]|0)-1|0)|0;t[E>>2]=0}l=t[m>>2]|0;if((t[p>>2]|0)>1?(t[m>>2]|0)==(t[v>>2]|0):0){t[m>>2]=$o(l,(t[p>>2]|0)-1|0)|0;t[p>>2]=0}else t[m>>2]=t[l+12>>2];t[S>>2]=(t[S>>2]|0)+1;
	}if((N|0)==65){t[u>>2]=t[b>>2];R=t[u>>2]|0;s=f;return R|0}t[O>>2]=t[(t[m>>2]|0)+40>>2];if(!(t[O>>2]|0))t[w>>2]=Oy(0,0)|0;else{t[A>>2]=t[E>>2];if((t[p>>2]|0)>1?(t[m>>2]|0)==(t[v>>2]|0):0){t[O>>2]=(t[O>>2]|0)+((t[p>>2]|0)-1);t[A>>2]=(t[A>>2]|0)-((t[p>>2]|0)-1)}else t[A>>2]=t[E>>2];t[w>>2]=Oy(t[O>>2]|0,t[A>>2]|0)|0}if(!(t[b>>2]|0)){t[u>>2]=t[w>>2];R=t[u>>2]|0;s=f;return R|0}A=t[k>>2]|0;k=t[w>>2]|0;if((t[S>>2]|0)==(t[g>>2]|0))oy(A,k)|0;else Hy(A,k)|0;t[u>>2]=t[b>>2];R=t[u>>2]|0;s=f;return R|0}t[u>>2]=0;R=t[u>>2]|0;s=f;return R|0}function Qo(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,l=0;n=s;s=s+32|0;f=n+24|0;u=n+20|0;a=n+12|0;o=n+8|0;c=n+4|0;l=n;t[f>>2]=e;t[u>>2]=i;t[n+16>>2]=r;if((t[f>>2]|0)==0|(t[u>>2]|0)==0){s=n;return}t[l>>2]=t[(t[u>>2]|0)+4>>2];t[c>>2]=t[t[u>>2]>>2];if((t[l>>2]|0)==0|(t[c>>2]|0)==0){s=n;return}if(((t[(t[f>>2]|0)+48>>2]|0)+-4|0)>>>0<3){s=n;return}t[a>>2]=b_(t[c>>2]|0,t[(t[f>>2]|0)+8>>2]|0,t[(t[f>>2]|0)+48>>2]|0,t[(t[f>>2]|0)+52>>2]|0,t[(t[f>>2]|0)+56>>2]|0,t[(t[f>>2]|0)+40>>2]|0)|0;if(t[a>>2]|0){if(!(t[(t[f>>2]|0)+64>>2]|0)){s=n;return}u=Yl(t[(t[f>>2]|0)+64>>2]|0)|0;t[(t[a>>2]|0)+64>>2]=u;s=n;return}t[o>>2]=h_(t[c>>2]|0,t[(t[f>>2]|0)+8>>2]|0)|0;if(!(t[o>>2]|0)){s=n;return}do if((t[(t[f>>2]|0)+48>>2]|0)==(t[(t[o>>2]|0)+48>>2]|0)){if((t[(t[f>>2]|0)+56>>2]|0)!=0?(t[(t[o>>2]|0)+56>>2]|0)!=0:0){if(!(Xl(t[(t[f>>2]|0)+56>>2]|0,t[(t[o>>2]|0)+56>>2]|0)|0))break;s=n;return}if((t[(t[f>>2]|0)+52>>2]|0)!=0?(t[(t[o>>2]|0)+52>>2]|0)!=0:0){if(!(Xl(t[(t[f>>2]|0)+52>>2]|0,t[(t[o>>2]|0)+52>>2]|0)|0))break;s=n;return}if(((t[(t[f>>2]|0)+40>>2]|0)!=0?(t[(t[o>>2]|0)+40>>2]|0)!=0:0)?(Xl(t[(t[f>>2]|0)+40>>2]|0,t[(t[o>>2]|0)+40>>2]|0)|0)!=0:0){s=n;return}}while(0);switch(t[(t[f>>2]|0)+48>>2]|0){case 2:case 1:case 6:case 5:case 4:{s=n;return}default:{}}Io(t[l>>2]|0,t[f>>2]|0,1602,133424,t[(t[f>>2]|0)+8>>2]|0);s=n;return}function $o(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0;r=s;s=s+16|0;n=r+12|0;f=r+8|0;u=r+4|0;a=r;t[f>>2]=e;t[u>>2]=i;if((t[f>>2]|0)!=0?(t[(t[f>>2]|0)+4>>2]|0)!=18:0){t[f>>2]=t[(t[f>>2]|0)+12>>2];t[a>>2]=0;while(1){if((t[a>>2]|0)>(t[u>>2]|0)){o=13;break}c=t[f>>2]|0;if(!(t[f>>2]|0)){o=7;break}if(!(((t[c+4>>2]|0)!=1?(t[(t[f>>2]|0)+4>>2]|0)!=9:0)?(t[(t[f>>2]|0)+4>>2]|0)!=13:0))o=11;if((o|0)==11?(o=0,t[a>>2]=(t[a>>2]|0)+1,(t[a>>2]|0)==(t[u>>2]|0)):0){o=13;break}t[f>>2]=t[(t[f>>2]|0)+24>>2]}if((o|0)==7){t[n>>2]=c;l=t[n>>2]|0;s=r;return l|0}else if((o|0)==13){t[n>>2]=t[f>>2];l=t[n>>2]|0;s=r;return l|0}}t[n>>2]=0;l=t[n>>2]|0;s=r;return l|0}function ec(e){e=e|0;var i=0,r=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if(!(t[r>>2]|0)){s=i;return}if(t[(t[r>>2]|0)+60>>2]|0)dc(t[(t[r>>2]|0)+60>>2]|0);if(t[(t[r>>2]|0)+52>>2]|0)XF(t[(t[r>>2]|0)+52>>2]|0,315);pAi[t[135736>>2]&511](t[r>>2]|0);s=i;return}function ic(e){e=e|0;var i=0,r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0;i=s;s=s+32|0;r=i;n=i+28|0;f=i+24|0;u=i+20|0;a=i+16|0;o=i+12|0;c=i+8|0;l=i+4|0;t[f>>2]=e;t[o>>2]=0;t[a>>2]=zp()|0;if(!(t[a>>2]|0)){if(t[34014]|0)yAi[t[135968+88>>2]&511](0,133880,r);t[n>>2]=0;b=t[n>>2]|0;s=i;return b|0}t[l>>2]=zO(t[f>>2]|0,0)|0;r=t[a>>2]|0;if(!(t[l>>2]|0)){Up(r);t[n>>2]=0;b=t[n>>2]|0;s=i;return b|0}t[c>>2]=Cp(r)|0;if(!(t[c>>2]|0)){Up(t[a>>2]|0);t[n>>2]=0;b=t[n>>2]|0;s=i;return b|0}r=KA(t[f>>2]|0)|0;t[(t[c>>2]|0)+4>>2]=r;t[t[c>>2]>>2]=t[l>>2];zs(t[(t[l>>2]|0)+16>>2]|0,t[c>>2]|0)|0;eE(t[a>>2]|0,t[c>>2]|0)|0;if((t[o>>2]|0)==0?(t[(t[a>>2]|0)+180>>2]|0)==0:0)t[o>>2]=rA(t[f>>2]|0)|0;if((t[o>>2]|0)!=0?(t[(t[a>>2]|0)+180>>2]|0)==0:0)t[(t[a>>2]|0)+180>>2]=t[o>>2];t[(t[a>>2]|0)+100>>2]=0;t[(t[a>>2]|0)+104>>2]=0;t[(t[a>>2]|0)+276>>2]=0;t[(t[a>>2]|0)+268>>2]=0;t[(t[a>>2]|0)+364>>2]=1;iS(t[a>>2]|0)|0;if(t[(t[a>>2]|0)+12>>2]|0)t[u>>2]=t[(t[a>>2]|0)+8>>2];else{t[u>>2]=0;fy(t[(t[a>>2]|0)+8>>2]|0);t[(t[a>>2]|0)+8>>2]=0}Up(t[a>>2]|0);t[n>>2]=t[u>>2];b=t[n>>2]|0;s=i;return b|0}function rc(e){e=e|0;var i=0,r=0,n=0,f=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0;i=s;s=s+32|0;r=i+20|0;n=i+16|0;f=i+12|0;a=i+8|0;o=i+4|0;c=i;t[n>>2]=e;t[f>>2]=mc(t[n>>2]|0)|0;if(!(t[f>>2]|0)){t[r>>2]=0;l=t[r>>2]|0;s=i;return l|0}t[a>>2]=t[f>>2];while(1){if(((u[t[a>>2]>>0]|0|0)!=0?(u[t[a>>2]>>0]|0|0)!=45:0)?(u[t[a>>2]>>0]|0|0)!=60:0){if((u[t[a>>2]>>0]|0|0)>=65?(u[t[a>>2]>>0]|0|0)<=90:0)b=1;else if((u[t[a>>2]>>0]|0|0)>=97)b=(u[t[a>>2]>>0]|0|0)<=122;else b=0;k=b^1}else k=0;h=t[a>>2]|0;if(!k)break;t[a>>2]=h+1}a=t[33474]|0;do if((u[h>>0]|0|0)!=60){t[o>>2]=_c(2,a)|0;if(!(t[o>>2]|0)){pAi[t[135736>>2]&511](t[f>>2]|0);t[r>>2]=0;l=t[r>>2]|0;s=i;return l|0}t[c>>2]=pc(t[o>>2]|0,t[f>>2]|0,t[n>>2]|0,0)|0;if((t[c>>2]|0)<0){ec(t[o>>2]|0);pAi[t[135736>>2]&511](t[f>>2]|0);t[r>>2]=0;l=t[r>>2]|0;s=i;return l|0}}else{t[o>>2]=_c(1,a)|0;if(t[o>>2]|0){k=Ec(1,0,0,t[n>>2]|0,t[33474]|0,0)|0;t[(t[o>>2]|0)+60>>2]=k;break}pAi[t[135736>>2]&511](t[f>>2]|0);t[r>>2]=0;l=t[r>>2]|0;s=i;return l|0}while(0);pAi[t[135736>>2]&511](t[f>>2]|0);t[r>>2]=t[o>>2];l=t[r>>2]|0;s=i;return l|0}function nc(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0;n=s;s=s+32|0;f=n;u=n+28|0;a=n+24|0;o=n+20|0;c=n+16|0;l=n+12|0;b=n+8|0;t[a>>2]=e;t[o>>2]=i;t[c>>2]=r;t[l>>2]=0;if((t[o>>2]|0)==0&(t[c>>2]|0)==0|(t[a>>2]|0)==0){t[u>>2]=0;k=t[u>>2]|0;s=n;return k|0}do if(t[33468]|0){if((t[o>>2]|0)!=0&(t[c>>2]|0)!=0){r=t[33976]|0;i=t[33980]|0;e=t[c>>2]|0;t[f>>2]=t[o>>2];t[f+4>>2]=e;yAi[r&511](i,133904,f);break}i=t[33976]|0;r=t[33980]|0;if(t[o>>2]|0){t[f>>2]=t[o>>2];yAi[i&511](r,133936,f);break}else{t[f>>2]=t[c>>2];yAi[i&511](r,133960,f);break}}while(0);f=t[a>>2]|0;if((t[t[a>>2]>>2]|0)!=1){t[b>>2]=Fc(f,t[o>>2]|0,t[c>>2]|0)|0;if(t[b>>2]|0)t[l>>2]=Yl(t[b>>2]|0)|0}else{b=Sc(t[f+60>>2]|0,t[o>>2]|0,t[c>>2]|0)|0;t[l>>2]=b;t[l>>2]=(t[l>>2]|0)==(-1|0)?0:b}t[u>>2]=t[l>>2];k=t[u>>2]|0;s=n;return k|0}function fc(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0;r=s;s=s+32|0;n=r;f=r+20|0;u=r+16|0;a=r+12|0;o=r+8|0;c=r+4|0;t[u>>2]=e;t[a>>2]=i;t[o>>2]=0;if((t[a>>2]|0)==0|(t[u>>2]|0)==0){t[f>>2]=0;l=t[f>>2]|0;s=r;return l|0}if(t[33468]|0){i=t[33976]|0;e=t[33980]|0;t[n>>2]=t[a>>2];yAi[i&511](e,133984,n)}n=t[u>>2]|0;if((t[t[u>>2]>>2]|0)!=1){t[c>>2]=Fc(n,0,t[a>>2]|0)|0;if(t[c>>2]|0)t[o>>2]=Yl(t[c>>2]|0)|0}else{c=Oc(t[n+60>>2]|0,t[a>>2]|0)|0;t[o>>2]=c;t[o>>2]=(t[o>>2]|0)==(-1|0)?0:c}t[f>>2]=t[o>>2];l=t[f>>2]|0;s=r;return l|0}function tc(){var e=0,i=0,r=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0;e=s;s=s+32|0;i=e+20|0;r=e+16|0;f=e+12|0;u=e+8|0;a=e+4|0;o=e;if(t[33500]|0){s=e;return}Ac();el(t[33502]|0);if(ti(134016)|0)t[33468]=1;if((t[33510]|0)==0?(c=ti(134048)|0,t[i>>2]=c,t[i>>2]=(t[i>>2]|0)==0?134072:c,t[a>>2]=_c(1,t[33474]|0)|0,(t[a>>2]|0)!=0):0){t[f>>2]=t[i>>2];t[o>>2]=(t[a>>2]|0)+60;while(1){if(!(n[t[f>>2]>>0]|0))break;while(1){do if((n[t[f>>2]>>0]|0)==32)l=1;else{if(9<=(n[t[f>>2]>>0]|0)?(n[t[f>>2]>>0]|0)<=10:0){l=1;break}l=(n[t[f>>2]>>0]|0)==13}while(0);b=t[f>>2]|0;if(!l)break;t[f>>2]=b+1}if(!(n[b>>0]|0))continue;t[u>>2]=t[f>>2];while(1){if(!(n[t[f>>2]>>0]|0))break;do if((n[t[f>>2]>>0]|0)==32)k=1;else{if(9<=(n[t[f>>2]>>0]|0)?(n[t[f>>2]>>0]|0)<=10:0){k=1;break}k=(n[t[f>>2]>>0]|0)==13}while(0);if(!(k^1))break;t[f>>2]=(t[f>>2]|0)+1}t[r>>2]=ql(t[u>>2]|0,(t[f>>2]|0)-(t[u>>2]|0)|0)|0;if(!(t[r>>2]|0))continue;i=Ec(1,0,0,t[r>>2]|0,t[33474]|0,0)|0;t[t[o>>2]>>2]=i;if(t[t[o>>2]>>2]|0)t[o>>2]=t[t[o>>2]>>2];pAi[t[135736>>2]&511](t[r>>2]|0)}t[33510]=t[a>>2]}il(t[33502]|0);s=e;return}function uc(e){e=e|0;var i=0,r=0,n=0,f=0,u=0,a=0;i=s;s=s+16|0;r=i+12|0;n=i+8|0;f=i+4|0;u=i;t[n>>2]=e;if(!(t[33500]|0))Ac();el(t[33502]|0);if(t[33510]|0){t[f>>2]=Mc(t[33510]|0,t[n>>2]|0)|0;il(t[33502]|0);t[r>>2]=t[f>>2];a=t[r>>2]|0;s=i;return a|0}t[u>>2]=rc(t[n>>2]|0)|0;if(!(t[u>>2]|0)){il(t[33502]|0);t[r>>2]=-1;a=t[r>>2]|0;s=i;return a|0}else{t[33510]=t[u>>2];il(t[33502]|0);t[r>>2]=0;a=t[r>>2]|0;s=i;return a|0}return 0}function ac(e){e=e|0;var i=0,r=0,f=0,u=0,a=0,o=0,c=0,l=0;i=s;s=s+16|0;r=i+12|0;f=i+8|0;u=i+4|0;a=i;t[r>>2]=e;if(!(t[r>>2]|0)){s=i;return}t[f>>2]=t[r>>2];e:while(1){if(!(n[t[f>>2]>>0]|0))break;while(1){do if((n[t[f>>2]>>0]|0)==32)o=1;else{if(9<=(n[t[f>>2]>>0]|0)?(n[t[f>>2]>>0]|0)<=10:0){o=1;break}o=(n[t[f>>2]>>0]|0)==13}while(0);c=t[f>>2]|0;if(!o)break;t[f>>2]=c+1}if(n[c>>0]|0){t[u>>2]=t[f>>2];while(1){if(!(n[t[f>>2]>>0]|0))break;if((n[t[f>>2]>>0]|0)==58)break;do if((n[t[f>>2]>>0]|0)==32)l=1;else{if(9<=(n[t[f>>2]>>0]|0)?(n[t[f>>2]>>0]|0)<=10:0){l=1;break}l=(n[t[f>>2]>>0]|0)==13}while(0);if(!(l^1))break;t[f>>2]=(t[f>>2]|0)+1}t[a>>2]=ql(t[u>>2]|0,(t[f>>2]|0)-(t[u>>2]|0)|0)|0;if(t[a>>2]|0){uc(t[a>>2]|0)|0;pAi[t[135736>>2]&511](t[a>>2]|0)}}while(1){if((n[t[f>>2]>>0]|0)!=58)continue e;t[f>>2]=(t[f>>2]|0)+1}}s=i;return}function oc(){var e=0;e=s;s=s+16|0;if(!(t[33500]|0)){s=e;return}el(t[33502]|0);if(t[33468]|0)yAi[t[135904>>2]&511](t[33980]|0,134096,e);if(t[33530]|0)XF(t[33530]|0,316);t[33530]=0;if(t[33510]|0)ec(t[33510]|0);t[33510]=0;t[33468]=0;t[33500]=0;il(t[33502]|0);$c(t[33502]|0);s=e;return}function cc(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0;r=s;s=s+16|0;n=r+8|0;f=r+4|0;u=r;t[n>>2]=e;t[f>>2]=i;if(!(t[33500]|0))tc();t[u>>2]=nc(t[33510]|0,t[n>>2]|0,t[f>>2]|0)|0;s=r;return t[u>>2]|0}function lc(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i+4|0;n=i;t[r>>2]=e;if(!(t[33500]|0))tc();t[n>>2]=fc(t[33510]|0,t[r>>2]|0)|0;s=i;return t[n>>2]|0}function sc(){return t[33534]|0}function bc(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i+4|0;n=i;t[r>>2]=e;if(!(t[33500]|0))tc();t[n>>2]=t[r>>2];if(!(t[n>>2]|0)){s=i;return}dc(t[n>>2]|0);s=i;return}function kc(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0;r=s;s=s+32|0;n=r;f=r+20|0;u=r+16|0;a=r+12|0;o=r+8|0;c=r+4|0;t[u>>2]=e;t[a>>2]=i;if(!(t[33500]|0))tc();if(!(t[a>>2]|0)){t[f>>2]=t[u>>2];l=t[f>>2]|0;s=r;return l|0}if(t[33468]|0){i=t[33976]|0;e=t[33980]|0;t[n>>2]=t[a>>2];yAi[i&511](e,134144,n)}t[c>>2]=Ec(1,0,t[a>>2]|0,0,t[33474]|0,0)|0;a=t[u>>2]|0;if(!(t[c>>2]|0)){t[f>>2]=a;l=t[f>>2]|0;s=r;return l|0}t[o>>2]=a;if(!(t[o>>2]|0)){t[f>>2]=t[c>>2];l=t[f>>2]|0;s=r;return l|0}while(1){if(!(t[t[o>>2]>>2]|0))break;t[o>>2]=t[t[o>>2]>>2]}t[t[o>>2]>>2]=t[c>>2];t[f>>2]=t[u>>2];l=t[f>>2]|0;s=r;return l|0}function hc(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0;n=s;s=s+32|0;f=n;u=n+28|0;a=n+24|0;o=n+20|0;c=n+16|0;l=n+12|0;b=n+8|0;t[a>>2]=e;t[o>>2]=i;t[c>>2]=r;if(!(t[33500]|0))tc();if((t[o>>2]|0)==0&(t[c>>2]|0)==0){t[u>>2]=0;k=t[u>>2]|0;s=n;return k|0}do if(t[33468]|0){if((t[o>>2]|0)!=0&(t[c>>2]|0)!=0){r=t[33976]|0;i=t[33980]|0;e=t[c>>2]|0;t[f>>2]=t[o>>2];t[f+4>>2]=e;yAi[r&511](i,134176,f);break}i=t[33976]|0;r=t[33980]|0;if(t[o>>2]|0){t[f>>2]=t[o>>2];yAi[i&511](r,134216,f);break}else{t[f>>2]=t[c>>2];yAi[i&511](r,134248,f);break}}while(0);t[l>>2]=t[a>>2];if(!(t[l>>2]|0)){t[u>>2]=0;k=t[u>>2]|0;s=n;return k|0}t[b>>2]=Sc(t[l>>2]|0,t[o>>2]|0,t[c>>2]|0)|0;if((t[b>>2]|0)!=0&(t[b>>2]|0)!=(-1|0)){t[u>>2]=t[b>>2];k=t[u>>2]|0;s=n;return k|0}else{t[u>>2]=0;k=t[u>>2]|0;s=n;return k|0}return 0}function wc(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0;r=s;s=s+32|0;n=r;f=r+20|0;u=r+16|0;a=r+12|0;o=r+8|0;c=r+4|0;t[u>>2]=e;t[a>>2]=i;if(!(t[33500]|0))tc();if(!(t[a>>2]|0)){t[f>>2]=0;l=t[f>>2]|0;s=r;return l|0}if(t[33468]|0){i=t[33976]|0;e=t[33980]|0;t[n>>2]=t[a>>2];yAi[i&511](e,133984,n)}t[o>>2]=t[u>>2];if(!(t[o>>2]|0)){t[f>>2]=0;l=t[f>>2]|0;s=r;return l|0}t[c>>2]=Oc(t[o>>2]|0,t[a>>2]|0)|0;if((t[c>>2]|0)!=0&(t[c>>2]|0)!=(-1|0)){t[f>>2]=t[c>>2];l=t[f>>2]|0;s=r;return l|0}else{t[f>>2]=0;l=t[f>>2]|0;s=r;return l|0}return 0}function dc(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i+4|0;n=i;t[r>>2]=e;while(1){if(!(t[r>>2]|0))break;t[n>>2]=t[t[r>>2]>>2];vc(t[r>>2]|0);t[r>>2]=t[n>>2]}s=i;return}function vc(e){e=e|0;var i=0,r=0,n=0,f=0;i=s;s=s+16|0;r=i;n=i+4|0;t[n>>2]=e;if(!(t[n>>2]|0)){s=i;return}if((t[(t[n>>2]|0)+32>>2]|0)==1){s=i;return}do if(t[33468]|0){if(t[(t[n>>2]|0)+16>>2]|0){e=t[33976]|0;f=t[33980]|0;t[r>>2]=t[(t[n>>2]|0)+16>>2];yAi[e&511](f,135680,r);break}f=t[33976]|0;e=t[33980]|0;if(t[(t[n>>2]|0)+20>>2]|0){t[r>>2]=t[(t[n>>2]|0)+20>>2];yAi[f&511](e,135680,r);break}else{yAi[f&511](e,135704,r);break}}while(0);if(t[(t[n>>2]|0)+16>>2]|0)pAi[t[135736>>2]&511](t[(t[n>>2]|0)+16>>2]|0);if(t[(t[n>>2]|0)+20>>2]|0)pAi[t[135736>>2]&511](t[(t[n>>2]|0)+20>>2]|0);if(t[(t[n>>2]|0)+24>>2]|0)pAi[t[135736>>2]&511](t[(t[n>>2]|0)+24>>2]|0);pAi[t[135736>>2]&511](t[n>>2]|0);s=i;return}function mc(e){e=e|0;var i=0,r=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0;i=s;s=s+112|0;r=i+100|0;f=i+96|0;u=i+92|0;a=i+88|0;o=i+84|0;c=i+8|0;l=i+4|0;t[f>>2]=e;if(!(t[f>>2]|0)){t[r>>2]=0;b=t[r>>2]|0;s=i;return b|0}if((ri(t[f>>2]|0,c|0)|0)<0){t[r>>2]=0;b=t[r>>2]|0;s=i;return b|0}e=Ue(t[f>>2]|0,0,i|0)|0;t[u>>2]=e;if((e|0)<0){t[r>>2]=0;b=t[r>>2]|0;s=i;return b|0}t[o>>2]=t[c+36>>2];t[l>>2]=gAi[t[135752>>2]&511]((t[o>>2]|0)+10|0)|0;if(!(t[l>>2]|0)){Nc(135656);Ge(t[u>>2]|0)|0;t[r>>2]=0;b=t[r>>2]|0;s=i;return b|0}t[a>>2]=ai(t[u>>2]|0,t[l>>2]|0,t[o>>2]|0)|0;Ge(t[u>>2]|0)|0;if((t[a>>2]|0)<0){pAi[t[135736>>2]&511](t[l>>2]|0);t[r>>2]=0;b=t[r>>2]|0;s=i;return b|0}else{n[(t[l>>2]|0)+(t[a>>2]|0)>>0]=0;t[r>>2]=t[l>>2];b=t[r>>2]|0;s=i;return b|0}return 0}function _c(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0;r=s;s=s+16|0;n=r+12|0;f=r+8|0;u=r+4|0;a=r;t[f>>2]=e;t[u>>2]=i;t[a>>2]=gAi[t[135744>>2]&511](64)|0;if(!(t[a>>2]|0)){Nc(135632);t[n>>2]=0;o=t[n>>2]|0;s=r;return o|0}i=(t[a>>2]|0)+0|0;e=i+64|0;do{t[i>>2]=0;i=i+4|0}while((i|0)<(e|0));t[t[a>>2]>>2]=t[f>>2];t[(t[a>>2]|0)+44>>2]=0;t[(t[a>>2]|0)+48>>2]=10;t[(t[a>>2]|0)+56>>2]=t[u>>2];if((t[t[a>>2]>>2]|0)==2){u=WF(10)|0;t[(t[a>>2]|0)+52>>2]=u}t[n>>2]=t[a>>2];o=t[n>>2]|0;s=r;return o|0}function pc(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0,S=0,g=0,y=0,F=0,O=0,A=0,M=0,R=0,N=0,T=0;f=s;s=s+64|0;a=f+60|0;o=f+56|0;c=f+52|0;l=f+48|0;b=f+44|0;k=f+40|0;h=f+36|0;w=f+32|0;d=f+28|0;v=f+24|0;m=f+20|0;_=f+16|0;p=f+12|0;E=f+8|0;S=f+4|0;g=f;t[o>>2]=e;t[c>>2]=i;t[l>>2]=r;t[b>>2]=n;t[k>>2]=t[c>>2];t[h>>2]=0;if((t[k>>2]|0)==0|(t[l>>2]|0)==0){t[a>>2]=-1;y=t[a>>2]|0;s=f;return y|0}t[h>>2]=Yl(t[l>>2]|0)|0;e:while(1){if(!(t[k>>2]|0))break;while(1){if(!(u[t[k>>2]>>0]|0))break e;while(1){do if((u[t[k>>2]>>0]|0|0)==32)F=1;else{if(9<=(u[t[k>>2]>>0]|0|0)?(u[t[k>>2]>>0]|0|0)<=10:0){F=1;break}F=(u[t[k>>2]>>0]|0|0)==13}while(0);O=t[k>>2]|0;if(!F)break;t[k>>2]=O+1}if(!(u[O>>0]|0))break e;if((u[t[k>>2]>>0]|0|0)!=45)break;if((u[(t[k>>2]|0)+1>>0]|0|0)!=45)break;t[k>>2]=Tc(t[k>>2]|0)|0;if(!((t[k>>2]|0)!=0&(t[k>>2]|0)!=0))break e}t[d>>2]=0;t[v>>2]=0;t[m>>2]=0;t[k>>2]=Lc(t[k>>2]|0,v)|0;if(!(t[v>>2]|0))break;do if((u[t[k>>2]>>0]|0|0)!=32){if(9<=(u[t[k>>2]>>0]|0|0)?(u[t[k>>2]>>0]|0|0)<=10:0)break;if((u[t[k>>2]>>0]|0|0)!=13)break e}while(0);i:while(1){do if((u[t[k>>2]>>0]|0|0)!=32){if(9<=(u[t[k>>2]>>0]|0|0)?(u[t[k>>2]>>0]|0|0)<=10:0)break;if((u[t[k>>2]>>0]|0|0)!=13)break i}while(0);t[k>>2]=(t[k>>2]|0)+1}do if(!(Xl(t[v>>2]|0,134936)|0)){if(Xl(t[v>>2]|0,134944)|0){t[m>>2]=14;break}if(Xl(t[v>>2]|0,134952)|0){t[m>>2]=20;break}if(Xl(t[v>>2]|0,134968)|0){t[m>>2]=15;break}if(Xl(t[v>>2]|0,134976)|0){t[m>>2]=17;break}if(Xl(t[v>>2]|0,134984)|0){t[m>>2]=18;break}if(Xl(t[v>>2]|0,135e3)|0){t[m>>2]=19;break}if(Xl(t[v>>2]|0,135016)|0){t[m>>2]=24;break}if(Xl(t[v>>2]|0,135032)|0){t[m>>2]=23;break}if(Xl(t[v>>2]|0,135048)|0){t[m>>2]=22;break}if(Xl(t[v>>2]|0,135056)|0){t[m>>2]=21;break}if(Xl(t[v>>2]|0,135592)|0){pAi[t[135736>>2]&511](t[v>>2]|0);t[k>>2]=Lc(t[k>>2]|0,v)|0;if(!(t[v>>2]|0))break e;pAi[t[135736>>2]&511](t[v>>2]|0);continue e}}else t[m>>2]=13;while(0);pAi[t[135736>>2]&511](t[v>>2]|0);t[v>>2]=0;i:do switch(t[m>>2]|0){case 24:case 23:case 22:case 21:{t[k>>2]=Dc(t[k>>2]|0,d)|0;break}case 19:case 18:case 17:case 16:{A=54;break}case 20:case 13:case 14:{t[k>>2]=Dc(t[k>>2]|0,v)|0;if(t[k>>2]|0){do if((t[m>>2]|0)!=13?(t[_>>2]=Cc(t[v>>2]|0)|0,(t[_>>2]|0)!=0):0){if(t[v>>2]|0)pAi[t[135736>>2]&511](t[v>>2]|0);if(u[t[_>>2]>>0]|0){t[v>>2]=t[_>>2];break}else{pAi[t[135736>>2]&511](t[_>>2]|0);t[v>>2]=0;break}}while(0);do if((u[t[k>>2]>>0]|0|0)!=32){if(9<=(u[t[k>>2]>>0]|0|0)?(u[t[k>>2]>>0]|0|0)<=10:0)break;if((u[t[k>>2]>>0]|0|0)!=13)break i}while(0);while(1){do if((u[t[k>>2]>>0]|0|0)==32)M=1;else{if(9<=(u[t[k>>2]>>0]|0|0)?(u[t[k>>2]>>0]|0|0)<=10:0){M=1;break}M=(u[t[k>>2]>>0]|0|0)==13}while(0);R=t[k>>2]|0;if(!M)break;t[k>>2]=R+1}t[k>>2]=Dc(R,d)|0}break}case 15:{if((u[t[k>>2]>>0]|0|0)==37){t[m>>2]=16;A=54}else A=54;break}default:{}}while(0);i:do if((A|0)==54?(A=0,t[k>>2]=Lc(t[k>>2]|0,v)|0,(t[k>>2]|0)!=0):0){do if((u[t[k>>2]>>0]|0|0)!=32){if(9<=(u[t[k>>2]>>0]|0|0)?(u[t[k>>2]>>0]|0|0)<=10:0)break;if((u[t[k>>2]>>0]|0|0)!=13)break i}while(0);while(1){do if((u[t[k>>2]>>0]|0|0)==32)N=1;else{if(9<=(u[t[k>>2]>>0]|0|0)?(u[t[k>>2]>>0]|0|0)<=10:0){N=1;break}N=(u[t[k>>2]>>0]|0|0)==13}while(0);T=t[k>>2]|0;if(!N)break;t[k>>2]=T+1}t[k>>2]=Dc(T,d)|0}while(0);if(!(t[k>>2]|0)){A=87;break}do if((t[m>>2]|0)!=21){if((t[m>>2]|0)==14|(t[m>>2]|0)==13){t[p>>2]=GA(t[d>>2]|0,t[h>>2]|0)|0;if(!(t[p>>2]|0))break;t[E>>2]=Ec(t[m>>2]|0,t[v>>2]|0,t[p>>2]|0,0,0,0)|0;t[w>>2]=ZF(t[(t[o>>2]|0)+52>>2]|0,t[v>>2]|0,t[E>>2]|0)|0;if((t[w>>2]|0)<0)vc(t[E>>2]|0);pAi[t[135736>>2]&511](t[p>>2]|0);break}if((t[m>>2]|0)==22)if(t[b>>2]|0){t[S>>2]=Ec(t[m>>2]|0,t[d>>2]|0,0,0,0,0)|0;t[w>>2]=ZF(t[(t[o>>2]|0)+52>>2]|0,t[d>>2]|0,t[S>>2]|0)|0;if((t[w>>2]|0)>=0)break;vc(t[S>>2]|0);break}else{t[g>>2]=GA(t[d>>2]|0,t[h>>2]|0)|0;if(!(t[g>>2]|0))break;Mc(t[o>>2]|0,t[g>>2]|0)|0;pAi[t[135736>>2]&511](t[g>>2]|0);break}}else{if(t[h>>2]|0)pAi[t[135736>>2]&511](t[h>>2]|0);t[h>>2]=Yl(t[d>>2]|0)|0}while(0);if(t[v>>2]|0)pAi[t[135736>>2]&511](t[v>>2]|0);if(!(t[d>>2]|0))continue;pAi[t[135736>>2]&511](t[d>>2]|0)}if((A|0)==87){if(t[v>>2]|0)pAi[t[135736>>2]&511](t[v>>2]|0);if(t[d>>2]|0)pAi[t[135736>>2]&511](t[d>>2]|0)}if(t[h>>2]|0)pAi[t[135736>>2]&511](t[h>>2]|0);if(!(t[k>>2]|0)){t[a>>2]=-1;y=t[a>>2]|0;s=f;return y|0}else{t[a>>2]=0;y=t[a>>2]|0;s=f;return y|0}return 0}function Ec(e,i,r,n,f,a){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;a=a|0;var o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0;o=s;s=s+48|0;c=o+32|0;l=o+28|0;b=o+24|0;k=o+20|0;h=o+16|0;w=o+12|0;d=o+8|0;v=o+4|0;m=o;t[l>>2]=e;t[b>>2]=i;t[k>>2]=r;t[h>>2]=n;t[w>>2]=f;t[d>>2]=a;t[m>>2]=0;t[v>>2]=gAi[t[135744>>2]&511](44)|0;if(!(t[v>>2]|0)){Nc(135528);t[c>>2]=0;_=t[c>>2]|0;s=o;return _|0}t[t[v>>2]>>2]=0;t[(t[v>>2]|0)+4>>2]=0;t[(t[v>>2]|0)+8>>2]=0;t[(t[v>>2]|0)+12>>2]=t[l>>2];if((t[l>>2]|0)==5|(t[l>>2]|0)==8?(t[m>>2]=Cc(t[b>>2]|0)|0,(t[m>>2]|0)!=0):0)t[b>>2]=(u[t[m>>2]>>0]|0|0)!=0?t[m>>2]|0:0;if(t[b>>2]|0){l=Yl(t[b>>2]|0)|0;t[(t[v>>2]|0)+16>>2]=l}else t[(t[v>>2]|0)+16>>2]=0;if(t[m>>2]|0)pAi[t[135736>>2]&511](t[m>>2]|0);if(t[k>>2]|0){m=Yl(t[k>>2]|0)|0;t[(t[v>>2]|0)+20>>2]=m}else t[(t[v>>2]|0)+20>>2]=0;if(!(t[h>>2]|0))t[h>>2]=t[k>>2];if(t[h>>2]|0){k=Yl(t[h>>2]|0)|0;t[(t[v>>2]|0)+24>>2]=k}else t[(t[v>>2]|0)+24>>2]=0;t[(t[v>>2]|0)+28>>2]=t[w>>2];t[(t[v>>2]|0)+32>>2]=0;t[(t[v>>2]|0)+36>>2]=0;t[(t[v>>2]|0)+40>>2]=t[d>>2];t[c>>2]=t[v>>2];_=t[c>>2]|0;s=o;return _|0}function Sc(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0;n=s;s=s+32|0;f=n;a=n+28|0;o=n+24|0;c=n+20|0;l=n+16|0;b=n+12|0;k=n+8|0;h=n+4|0;t[o>>2]=e;t[c>>2]=i;t[l>>2]=r;t[b>>2]=0;t[k>>2]=0;if(!(t[o>>2]|0)){t[a>>2]=0;w=t[a>>2]|0;s=n;return w|0}if((t[c>>2]|0)==0&(t[l>>2]|0)==0){t[a>>2]=0;w=t[a>>2]|0;s=n;return w|0}t[h>>2]=Cc(t[c>>2]|0)|0;if(t[h>>2]|0)t[c>>2]=(u[t[h>>2]>>0]|0|0)!=0?t[h>>2]|0:0;if(!(Jl(t[c>>2]|0,135064,13)|0)){t[k>>2]=Pc(t[c>>2]|0)|0;do if(t[33468]|0){r=t[33976]|0;i=t[33980]|0;if(!(t[k>>2]|0)){t[f>>2]=t[c>>2];yAi[r&511](i,135256,f);break}else{t[f>>2]=t[k>>2];yAi[r&511](i,135296,f);break}}while(0);t[b>>2]=Sc(t[o>>2]|0,t[k>>2]|0,t[l>>2]|0)|0;if(t[k>>2]|0)pAi[t[135736>>2]&511](t[k>>2]|0);if(t[h>>2]|0)pAi[t[135736>>2]&511](t[h>>2]|0);t[a>>2]=t[b>>2];w=t[a>>2]|0;s=n;return w|0}if(Jl(t[l>>2]|0,135064,13)|0){while(1){if(!(t[o>>2]|0))break;if((t[(t[o>>2]|0)+12>>2]|0)==1){if(!(t[(t[o>>2]|0)+8>>2]|0))Bc(t[o>>2]|0)|0;if(t[(t[o>>2]|0)+8>>2]|0){t[b>>2]=Ic(t[(t[o>>2]|0)+8>>2]|0,t[c>>2]|0,t[l>>2]|0)|0;if(t[b>>2]|0)break;if((t[(t[o>>2]|0)+8>>2]|0)!=0?(t[(t[(t[o>>2]|0)+8>>2]|0)+36>>2]|0)>50:0){d=40;break}}}t[o>>2]=t[t[o>>2]>>2]}if((d|0)==40)t[b>>2]=0;if(t[h>>2]|0)pAi[t[135736>>2]&511](t[h>>2]|0);t[a>>2]=t[b>>2];w=t[a>>2]|0;s=n;return w|0}t[k>>2]=Pc(t[l>>2]|0)|0;do if(t[33468]|0){d=t[33976]|0;i=t[33980]|0;if(!(t[k>>2]|0)){t[f>>2]=t[l>>2];yAi[d&511](i,135328,f);break}else{t[f>>2]=t[k>>2];yAi[d&511](i,135368,f);break}}while(0);do if(t[c>>2]|0){f=(Xl(t[c>>2]|0,t[k>>2]|0)|0)!=0;l=t[o>>2]|0;i=t[c>>2]|0;if(f){t[b>>2]=Sc(l,i,0)|0;break}else{t[b>>2]=Sc(l,i,t[k>>2]|0)|0;break}}else t[b>>2]=Sc(t[o>>2]|0,t[k>>2]|0,0)|0;while(0);if(t[k>>2]|0)pAi[t[135736>>2]&511](t[k>>2]|0);if(t[h>>2]|0)pAi[t[135736>>2]&511](t[h>>2]|0);t[a>>2]=t[b>>2];w=t[a>>2]|0;s=n;return w|0}function gc(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0;r=s;s=s+16|0;n=r+12|0;f=r+8|0;u=r+4|0;a=r;t[f>>2]=e;t[u>>2]=i;do if(t[f>>2]|0){t[a>>2]=rO(t[f>>2]|0,t[u>>2]|0)|0;if(!(t[a>>2]|0)){t[n>>2]=0;break}if((t[(t[a>>2]|0)+12>>2]|0)==13){t[n>>2]=t[(t[a>>2]|0)+24>>2];break}else{t[n>>2]=0;break}}else t[n>>2]=0;while(0);s=r;return t[n>>2]|0}function yc(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,a=0,o=0,c=0,l=0;r=s;s=s+32|0;n=r+16|0;f=r+12|0;a=r+8|0;o=r+4|0;c=r;t[f>>2]=e;t[a>>2]=i;if(!(t[f>>2]|0)){t[n>>2]=0;l=t[n>>2]|0;s=r;return l|0}t[c>>2]=Cc(t[a>>2]|0)|0;if(t[c>>2]|0)t[a>>2]=(u[t[c>>2]>>0]|0|0)!=0?t[c>>2]|0:0;t[o>>2]=rO(t[f>>2]|0,t[a>>2]|0)|0;if(!(t[o>>2]|0)){if(t[c>>2]|0)pAi[t[135736>>2]&511](t[c>>2]|0);t[n>>2]=0;l=t[n>>2]|0;s=r;return l|0}a=(t[c>>2]|0)!=0;if((t[(t[o>>2]|0)+12>>2]|0)==14){if(a)pAi[t[135736>>2]&511](t[c>>2]|0);t[n>>2]=t[(t[o>>2]|0)+24>>2];l=t[n>>2]|0;s=r;return l|0}else{if(a)pAi[t[135736>>2]&511](t[c>>2]|0);t[n>>2]=0;l=t[n>>2]|0;s=r;return l|0}return 0}function Fc(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,l=0;n=s;s=s+32|0;f=n+16|0;u=n+12|0;a=n+8|0;o=n+4|0;c=n;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;t[c>>2]=0;if(!(t[(t[u>>2]|0)+52>>2]|0)){t[f>>2]=0;l=t[f>>2]|0;s=n;return l|0}if(t[a>>2]|0)t[c>>2]=yc(t[(t[u>>2]|0)+52>>2]|0,t[a>>2]|0)|0;if(t[c>>2]|0){t[f>>2]=t[c>>2];l=t[f>>2]|0;s=n;return l|0}if(t[o>>2]|0)t[c>>2]=gc(t[(t[u>>2]|0)+52>>2]|0,t[o>>2]|0)|0;if(t[c>>2]|0){t[f>>2]=t[c>>2];l=t[f>>2]|0;s=n;return l|0}else{t[f>>2]=0;l=t[f>>2]|0;s=n;return l|0}return 0}function Oc(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0;r=s;s=s+32|0;n=r;f=r+20|0;u=r+16|0;a=r+12|0;o=r+8|0;c=r+4|0;t[u>>2]=e;t[a>>2]=i;t[o>>2]=0;t[c>>2]=0;if(!(t[u>>2]|0)){t[f>>2]=0;l=t[f>>2]|0;s=r;return l|0}if(!(t[a>>2]|0)){t[f>>2]=0;l=t[f>>2]|0;s=r;return l|0}if(!(Jl(t[a>>2]|0,135064,13)|0)){t[c>>2]=Pc(t[a>>2]|0)|0;do if(t[33468]|0){i=t[33976]|0;e=t[33980]|0;if(!(t[c>>2]|0)){t[n>>2]=t[a>>2];yAi[i&511](e,135080,n);break}else{t[n>>2]=t[c>>2];yAi[i&511](e,135112,n);break}}while(0);t[o>>2]=Sc(t[u>>2]|0,t[c>>2]|0,0)|0;if(t[c>>2]|0)pAi[t[135736>>2]&511](t[c>>2]|0);t[f>>2]=t[o>>2];l=t[f>>2]|0;s=r;return l|0}while(1){if(!(t[u>>2]|0)){b=21;break}if((t[(t[u>>2]|0)+12>>2]|0)==1){if(!(t[(t[u>>2]|0)+8>>2]|0))Bc(t[u>>2]|0)|0;if((t[(t[u>>2]|0)+8>>2]|0)!=0?(t[o>>2]=Hc(t[(t[u>>2]|0)+8>>2]|0,t[a>>2]|0)|0,(t[o>>2]|0)!=0):0){b=19;break}}t[u>>2]=t[t[u>>2]>>2]}if((b|0)==19){t[f>>2]=t[o>>2];l=t[f>>2]|0;s=r;return l|0}else if((b|0)==21){t[f>>2]=t[o>>2];l=t[f>>2]|0;s=r;return l|0}return 0}function Ac(){var e=0;e=s;if(t[33500]|0){s=e;return}if(ti(134016)|0)t[33468]=1;t[33502]=Qc()|0;t[33500]=1;s=e;return}function Mc(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0;r=s;s=s+32|0;n=r+24|0;f=r+20|0;u=r+16|0;a=r+12|0;o=r+8|0;c=r+4|0;l=r;t[f>>2]=e;t[u>>2]=i;if((t[f>>2]|0)==0|(t[u>>2]|0)==0){t[n>>2]=-1;b=t[n>>2]|0;s=r;return b|0}i=t[u>>2]|0;do if((t[t[f>>2]>>2]|0)==2){t[o>>2]=mc(i)|0;if(!(t[o>>2]|0)){t[n>>2]=-1;b=t[n>>2]|0;s=r;return b|0}t[a>>2]=pc(t[f>>2]|0,t[o>>2]|0,t[u>>2]|0,0)|0;e=(t[a>>2]|0)<0;pAi[t[135736>>2]&511](t[o>>2]|0);if(e){t[n>>2]=-1;b=t[n>>2]|0;s=r;return b|0}}else{t[c>>2]=Ec(1,0,0,i,t[33474]|0,0)|0;t[l>>2]=t[(t[f>>2]|0)+60>>2];if(!(t[l>>2]|0)){t[(t[f>>2]|0)+60>>2]=t[c>>2];break}while(1){if(!(t[t[l>>2]>>2]|0))break;t[l>>2]=t[t[l>>2]>>2]}t[t[l>>2]>>2]=t[c>>2]}while(0);t[n>>2]=0;b=t[n>>2]|0;s=r;return b|0}function Rc(e){e=e|0;var i=0,r=0,n=0,f=0;i=s;s=s+16|0;r=i+8|0;n=i+4|0;f=i;t[r>>2]=e;if(!(t[r>>2]|0)){s=i;return}t[n>>2]=t[(t[r>>2]|0)+8>>2];while(1){if(!(t[n>>2]|0))break;t[f>>2]=t[t[n>>2]>>2];t[(t[n>>2]|0)+32>>2]=0;t[(t[n>>2]|0)+8>>2]=0;vc(t[n>>2]|0);t[n>>2]=t[f>>2]}t[(t[r>>2]|0)+32>>2]=0;vc(t[r>>2]|0);s=i;return}function Nc(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i;n=i+4|0;t[n>>2]=e;e=t[n>>2]|0;t[r>>2]=t[n>>2];cp(0,0,0,0,0,20,2,2,0,0,e,0,0,0,0,135560,r);s=i;return}function Tc(e){e=e|0;var i=0,r=0,n=0,f=0,a=0,o=0;i=s;s=s+16|0;r=i+4|0;n=i;t[n>>2]=e;if((u[t[n>>2]>>0]|0|0)==45?(u[(t[n>>2]|0)+1>>0]|0|0)==45:0){t[n>>2]=(t[n>>2]|0)+2;while(1){if(u[t[n>>2]>>0]|0)if((u[t[n>>2]>>0]|0|0)!=45)f=1;else f=(u[(t[n>>2]|0)+1>>0]|0|0)!=45;else f=0;a=t[n>>2]|0;if(!f)break;t[n>>2]=a+1}if(!(u[a>>0]|0)){t[r>>2]=0;o=t[r>>2]|0;s=i;return o|0}else{t[r>>2]=(t[n>>2]|0)+2;o=t[r>>2]|0;s=i;return o|0}}t[r>>2]=t[n>>2];o=t[r>>2]|0;s=i;return o|0}function Lc(e,i){e=e|0;i=i|0;var r=0,f=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0;r=s;s=s+128|0;f=r+16|0;a=r+12|0;o=r+8|0;c=r+20|0;l=r+4|0;b=r;t[a>>2]=e;t[o>>2]=i;t[l>>2]=0;t[t[o>>2]>>2]=0;t[b>>2]=u[t[a>>2]>>0];i=t[b>>2]|0;if((t[b>>2]|0)<256){if(((!(65<=(i|0)&(t[b>>2]|0)<=90)?!(97<=(t[b>>2]|0)&(t[b>>2]|0)<=122):0)?!(192<=(t[b>>2]|0)&(t[b>>2]|0)<=214):0)?!(216<=(t[b>>2]|0)&(t[b>>2]|0)<=246|248<=(t[b>>2]|0)):0)k=7}else if(!(dj(i,199744)|0))k=7;do if((k|0)==7){i=t[b>>2]|0;if((t[b>>2]|0)<256){if(!((i|0)!=95&(t[b>>2]|0)!=58))break}else{if(19968<=(i|0)&(t[b>>2]|0)<=40869|(t[b>>2]|0)==12295)break;if(!((12321<=(t[b>>2]|0)&(t[b>>2]|0)<=12329^1)&(t[b>>2]|0)!=95&(t[b>>2]|0)!=58))break}t[f>>2]=0;h=t[f>>2]|0;s=r;return h|0}while(0);e:while(1){i=t[b>>2]|0;if((t[b>>2]|0)<256){if(((!(65<=(i|0)&(t[b>>2]|0)<=90)?!(97<=(t[b>>2]|0)&(t[b>>2]|0)<=122):0)?!(192<=(t[b>>2]|0)&(t[b>>2]|0)<=214):0)?!(216<=(t[b>>2]|0)&(t[b>>2]|0)<=246|248<=(t[b>>2]|0)):0)k=18}else if(!(dj(i,199744)|0))k=18;do if((k|0)==18){k=0;if((t[b>>2]|0)>=256){if(19968<=(t[b>>2]|0)&(t[b>>2]|0)<=40869|(t[b>>2]|0)==12295)break;if(12321<=(t[b>>2]|0)&(t[b>>2]|0)<=12329)break}i=t[b>>2]|0;if((t[b>>2]|0)<256)if(48<=(i|0)&(t[b>>2]|0)<=57|(t[b>>2]|0)==46|(t[b>>2]|0)==45|(t[b>>2]|0)==95|(t[b>>2]|0)==58)break;else{k=26;break e}else{e=(dj(i,200216)|0)!=0;if(e|(t[b>>2]|0)==46|(t[b>>2]|0)==45|(t[b>>2]|0)==95|(t[b>>2]|0)==58)break;else{k=26;break e}}}while(0);e=t[b>>2]&255;i=t[l>>2]|0;t[l>>2]=i+1;n[c+i>>0]=e;t[a>>2]=(t[a>>2]|0)+1;t[b>>2]=u[t[a>>2]>>0];if((t[l>>2]|0)>=100){k=25;break}}if((k|0)==25){t[f>>2]=0;h=t[f>>2]|0;s=r;return h|0}else if((k|0)==26){k=ql(c,t[l>>2]|0)|0;t[t[o>>2]>>2]=k;t[f>>2]=t[a>>2];h=t[f>>2]|0;s=r;return h|0}return 0}function Dc(e,i){e=e|0;i=i|0;var r=0,f=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0;r=s;s=s+48|0;f=r+28|0;a=r+24|0;o=r+20|0;c=r+16|0;l=r+12|0;b=r+8|0;k=r+4|0;h=r+32|0;w=r;t[a>>2]=e;t[o>>2]=i;t[c>>2]=0;t[b>>2]=0;t[k>>2]=50;t[w>>2]=0;t[t[o>>2]>>2]=0;i=t[a>>2]|0;do if((u[t[a>>2]>>0]|0|0)!=34)if((u[i>>0]|0|0)==39){t[a>>2]=(t[a>>2]|0)+1;n[h>>0]=39;break}else{n[h>>0]=32;break}else{t[a>>2]=i+1;n[h>>0]=34}while(0);t[c>>2]=gAi[t[135752>>2]&511](t[k>>2]|0)|0;if(!(t[c>>2]|0)){Nc(135608);t[f>>2]=0;d=t[f>>2]|0;s=r;return d|0}while(1){if((u[198696+(u[t[a>>2]>>0]|0)>>0]|0|0)==0?(u[t[a>>2]>>0]|0|0)!=63:0)break;if((u[t[a>>2]>>0]|0|0)==(u[h>>0]|0|0)?(u[h>>0]|0|0)!=32:0)break;if((u[h>>0]|0|0)==32){if((u[t[a>>2]>>0]|0|0)==32)break;if(9<=(u[t[a>>2]>>0]|0|0)?(u[t[a>>2]>>0]|0|0)<=10:0)break;if((u[t[a>>2]>>0]|0|0)==13)break}if(((t[b>>2]|0)+1|0)>=(t[k>>2]|0)){t[k>>2]=t[k>>2]<<1;t[l>>2]=MAi[t[135760>>2]&511](t[c>>2]|0,t[k>>2]|0)|0;if(!(t[l>>2]|0)){v=19;break}t[c>>2]=t[l>>2]}i=n[t[a>>2]>>0]|0;e=t[b>>2]|0;t[b>>2]=e+1;n[(t[c>>2]|0)+e>>0]=i;t[w>>2]=(t[w>>2]|0)+1;t[a>>2]=(t[a>>2]|0)+1}if((v|0)==19){Nc(135608);pAi[t[135736>>2]&511](t[c>>2]|0);t[f>>2]=0;d=t[f>>2]|0;s=r;return d|0}n[(t[c>>2]|0)+(t[b>>2]|0)>>0]=0;b=u[t[a>>2]>>0]|0;do if((u[h>>0]|0|0)==32){if((b|0)!=32){if(9<=(u[t[a>>2]>>0]|0|0)?(u[t[a>>2]>>0]|0|0)<=10:0)break;if((u[t[a>>2]>>0]|0|0)!=13){pAi[t[135736>>2]&511](t[c>>2]|0);t[f>>2]=0;d=t[f>>2]|0;s=r;return d|0}}}else{if((b|0)==(u[h>>0]|0|0)){t[a>>2]=(t[a>>2]|0)+1;break}pAi[t[135736>>2]&511](t[c>>2]|0);t[f>>2]=0;d=t[f>>2]|0;s=r;return d|0}while(0);t[t[o>>2]>>2]=t[c>>2];t[f>>2]=t[a>>2];d=t[f>>2]|0;s=r;return d|0}function Cc(e){e=e|0;var i=0,r=0,f=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0;i=s;s=s+32|0;r=i+24|0;f=i+20|0;a=i+16|0;o=i+12|0;c=i+8|0;l=i+4|0;b=i;t[f>>2]=e;t[a>>2]=1;if(!(t[f>>2]|0)){t[r>>2]=0;k=t[r>>2]|0;s=i;return k|0}t[o>>2]=1;t[c>>2]=t[f>>2];while(1){if(!((t[a>>2]|0)!=0?(u[t[c>>2]>>0]|0|0)!=0:0))break;do if((u[t[c>>2]>>0]|0|0)!=32){if(9<=(u[t[c>>2]>>0]|0|0)?(u[t[c>>2]>>0]|0|0)<=10:0){h=10;break}if((u[t[c>>2]>>0]|0|0)!=13)t[o>>2]=0;else h=10}else h=10;while(0);do if((h|0)==10){h=0;if((t[o>>2]|0)!=0?1:(u[t[c>>2]>>0]|0|0)!=32){t[a>>2]=0;break}else{t[o>>2]=1;break}}while(0);t[c>>2]=(t[c>>2]|0)+1}if(!((t[a>>2]|0)==0|(t[o>>2]|0)!=0)){t[r>>2]=0;k=t[r>>2]|0;s=i;return k|0}t[l>>2]=Yl(t[f>>2]|0)|0;t[b>>2]=t[l>>2];t[o>>2]=0;t[c>>2]=t[f>>2];while(1){if(!(u[t[c>>2]>>0]|0))break;do if((u[t[c>>2]>>0]|0|0)!=32){if(9<=(u[t[c>>2]>>0]|0|0)?(u[t[c>>2]>>0]|0|0)<=10:0){h=22;break}if((u[t[c>>2]>>0]|0|0)!=13){if(t[o>>2]|0){f=t[b>>2]|0;t[b>>2]=f+1;n[f>>0]=32;t[o>>2]=0}f=n[t[c>>2]>>0]|0;a=t[b>>2]|0;t[b>>2]=a+1;n[a>>0]=f}else h=22}else h=22;while(0);if((h|0)==22?(h=0,(t[b>>2]|0)!=(t[l>>2]|0)):0)t[o>>2]=1;t[c>>2]=(t[c>>2]|0)+1}n[t[b>>2]>>0]=0;t[r>>2]=t[l>>2];k=t[r>>2]|0;s=i;return k|0}function Pc(e){e=e|0;var i=0,r=0,f=0,a=0,o=0,c=0,l=0,b=0,k=0;i=s;s=s+2016|0;r=i+8|0;f=i+4|0;a=i+16|0;o=i;t[f>>2]=e;t[o>>2]=0;if(Jl(t[f>>2]|0,135064,13)|0){t[r>>2]=0;c=t[r>>2]|0;s=i;return c|0}t[f>>2]=(t[f>>2]|0)+13;e:while(1){if((t[o>>2]|0)>>>0>1996?1:(u[t[f>>2]>>0]|0|0)==0)break;if((u[t[f>>2]>>0]|0|0)==43){e=t[o>>2]|0;t[o>>2]=e+1;n[a+e>>0]=32;t[f>>2]=(t[f>>2]|0)+1;continue}if((u[t[f>>2]>>0]|0|0)==58){e=t[o>>2]|0;t[o>>2]=e+1;n[a+e>>0]=47;e=t[o>>2]|0;t[o>>2]=e+1;n[a+e>>0]=47;t[f>>2]=(t[f>>2]|0)+1;continue}if((u[t[f>>2]>>0]|0|0)==59){e=t[o>>2]|0;t[o>>2]=e+1;n[a+e>>0]=58;e=t[o>>2]|0;t[o>>2]=e+1;n[a+e>>0]=58;t[f>>2]=(t[f>>2]|0)+1;continue}e=t[f>>2]|0;if((u[t[f>>2]>>0]|0|0)!=37){l=n[e>>0]|0;b=t[o>>2]|0;t[o>>2]=b+1;n[a+b>>0]=l;t[f>>2]=(t[f>>2]|0)+1;continue}if((u[e+1>>0]|0|0)==50?(u[(t[f>>2]|0)+2>>0]|0|0)==66:0){e=t[o>>2]|0;t[o>>2]=e+1;n[a+e>>0]=43}else k=15;do if((k|0)==15){k=0;if((u[(t[f>>2]|0)+1>>0]|0|0)==51?(u[(t[f>>2]|0)+2>>0]|0|0)==65:0){e=t[o>>2]|0;t[o>>2]=e+1;n[a+e>>0]=58;break}if((u[(t[f>>2]|0)+1>>0]|0|0)==50?(u[(t[f>>2]|0)+2>>0]|0|0)==70:0){e=t[o>>2]|0;t[o>>2]=e+1;n[a+e>>0]=47;break}if((u[(t[f>>2]|0)+1>>0]|0|0)==51?(u[(t[f>>2]|0)+2>>0]|0|0)==66:0){e=t[o>>2]|0;t[o>>2]=e+1;n[a+e>>0]=59;break}if((u[(t[f>>2]|0)+1>>0]|0|0)==50?(u[(t[f>>2]|0)+2>>0]|0|0)==55:0){e=t[o>>2]|0;t[o>>2]=e+1;n[a+e>>0]=39;break}if((u[(t[f>>2]|0)+1>>0]|0|0)==51?(u[(t[f>>2]|0)+2>>0]|0|0)==70:0){e=t[o>>2]|0;t[o>>2]=e+1;n[a+e>>0]=63;break}if((u[(t[f>>2]|0)+1>>0]|0|0)==50?(u[(t[f>>2]|0)+2>>0]|0|0)==51:0){e=t[o>>2]|0;t[o>>2]=e+1;n[a+e>>0]=35;break}if((u[(t[f>>2]|0)+1>>0]|0|0)==50?(u[(t[f>>2]|0)+2>>0]|0|0)==53:0){e=t[o>>2]|0;t[o>>2]=e+1;n[a+e>>0]=37;break}e=n[t[f>>2]>>0]|0;l=t[o>>2]|0;t[o>>2]=l+1;n[a+l>>0]=e;t[f>>2]=(t[f>>2]|0)+1;continue e}while(0);t[f>>2]=(t[f>>2]|0)+3}n[a+(t[o>>2]|0)>>0]=0;t[r>>2]=Yl(a)|0;c=t[r>>2]|0;s=i;return c|0}function Bc(e){e=e|0;var i=0,r=0,n=0,f=0,u=0,a=0,o=0,c=0;i=s;s=s+16|0;r=i;n=i+12|0;f=i+8|0;u=i+4|0;t[f>>2]=e;if(!(t[f>>2]|0)){t[n>>2]=-1;a=t[n>>2]|0;s=i;return a|0}if(!(t[(t[f>>2]|0)+24>>2]|0)){t[n>>2]=-1;a=t[n>>2]|0;s=i;return a|0}el(t[33502]|0);if(t[(t[f>>2]|0)+8>>2]|0){il(t[33502]|0);t[n>>2]=0;a=t[n>>2]|0;s=i;return a|0}do if(t[33530]|0){t[u>>2]=rO(t[33530]|0,t[(t[f>>2]|0)+24>>2]|0)|0;e=(t[33468]|0)!=0;if(!(t[u>>2]|0)){if(!e)break;o=t[33976]|0;c=t[33980]|0;t[r>>2]=t[(t[f>>2]|0)+24>>2];yAi[o&511](c,134304,r);break}if(e){e=t[33976]|0;c=t[33980]|0;t[r>>2]=t[(t[f>>2]|0)+24>>2];yAi[e&511](c,134280,r)}c=t[u>>2]|0;if((t[(t[f>>2]|0)+12>>2]|0)==1)t[(t[f>>2]|0)+8>>2]=t[c+8>>2];else t[(t[f>>2]|0)+8>>2]=c;t[(t[f>>2]|0)+32>>2]=0;il(t[33502]|0);t[n>>2]=0;a=t[n>>2]|0;s=i;return a|0}while(0);t[u>>2]=xc(t[(t[f>>2]|0)+28>>2]|0,t[(t[f>>2]|0)+24>>2]|0)|0;c=(t[f>>2]|0)+12|0;if(!(t[u>>2]|0)){t[c>>2]=2;il(t[33502]|0);t[n>>2]=-1;a=t[n>>2]|0;s=i;return a|0}e=t[u>>2]|0;if((t[c>>2]|0)==1)t[(t[f>>2]|0)+8>>2]=t[e+8>>2];else t[(t[f>>2]|0)+8>>2]=e;
	t[(t[u>>2]|0)+32>>2]=1;if(!(t[33530]|0))t[33530]=WF(10)|0;if(t[33530]|0){if(t[33468]|0){e=t[33976]|0;c=t[33980]|0;t[r>>2]=t[(t[f>>2]|0)+24>>2];yAi[e&511](c,134336,r)}ZF(t[33530]|0,t[(t[f>>2]|0)+24>>2]|0,t[u>>2]|0)|0}il(t[33502]|0);t[n>>2]=0;a=t[n>>2]|0;s=i;return a|0}function Ic(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0,S=0,g=0,y=0,F=0,O=0,A=0;n=s;s=s+480|0;f=n;u=n+464|0;a=n+460|0;o=n+456|0;c=n+452|0;l=n+448|0;b=n+444|0;k=n+440|0;h=n+436|0;w=n+432|0;d=n+428|0;v=n+424|0;m=n+224|0;_=n+220|0;p=n+216|0;E=n+16|0;S=n+12|0;g=n+8|0;t[a>>2]=e;t[o>>2]=i;t[c>>2]=r;t[l>>2]=0;t[k>>2]=0;t[h>>2]=0;r=t[a>>2]|0;if((t[(t[a>>2]|0)+36>>2]|0)>50){Uc(r,0,1654,135136,t[(t[a>>2]|0)+16>>2]|0,0,0);t[u>>2]=0;y=t[u>>2]|0;s=n;return y|0}i=r+36|0;t[i>>2]=(t[i>>2]|0)+1;if(t[c>>2]|0){t[w>>2]=0;t[d>>2]=0;t[b>>2]=t[a>>2];t[k>>2]=0;while(1){if(!(t[b>>2]|0))break;i=t[(t[b>>2]|0)+12>>2]|0;if((i|0)==7){t[v>>2]=rs(t[(t[b>>2]|0)+16>>2]|0)|0;if((t[v>>2]|0)>(t[d>>2]|0)?(Jl(t[c>>2]|0,t[(t[b>>2]|0)+16>>2]|0,t[v>>2]|0)|0)==0:0){t[d>>2]=t[v>>2];t[w>>2]=t[b>>2]}}else if((i|0)==3)t[h>>2]=(t[h>>2]|0)+1;else if((i|0)==6){if(Xl(t[c>>2]|0,t[(t[b>>2]|0)+16>>2]|0)|0){F=8;break}}else if((i|0)==9?(i=t[c>>2]|0,r=t[(t[b>>2]|0)+16>>2]|0,(Jl(i,r,rs(t[(t[b>>2]|0)+16>>2]|0)|0)|0)==0):0)t[k>>2]=(t[k>>2]|0)+1;t[b>>2]=t[t[b>>2]>>2]}if((F|0)==8){if(t[33468]|0){v=t[33976]|0;r=t[33980]|0;i=t[(t[b>>2]|0)+24>>2]|0;t[f>>2]=t[(t[b>>2]|0)+16>>2];t[f+4>>2]=i;yAi[v&511](r,135400,f)}r=(t[a>>2]|0)+36|0;t[r>>2]=(t[r>>2]|0)+-1;t[u>>2]=Yl(t[(t[b>>2]|0)+24>>2]|0)|0;y=t[u>>2]|0;s=n;return y|0}if(t[w>>2]|0){if(t[33468]|0){r=t[33976]|0;v=t[33980]|0;t[f>>2]=t[(t[w>>2]|0)+16>>2];yAi[r&511](v,135200,f)}t[l>>2]=Yl(t[(t[w>>2]|0)+24>>2]|0)|0;if(t[l>>2]|0)t[l>>2]=us(t[l>>2]|0,(t[c>>2]|0)+(t[d>>2]|0)|0)|0;d=(t[a>>2]|0)+36|0;t[d>>2]=(t[d>>2]|0)+-1;t[u>>2]=t[l>>2];y=t[u>>2]|0;s=n;return y|0}if(t[k>>2]|0){t[_>>2]=0;t[b>>2]=t[a>>2];while(1){if(!(t[b>>2]|0)){F=45;break}if((t[(t[b>>2]|0)+12>>2]|0)==9?(d=t[c>>2]|0,w=t[(t[b>>2]|0)+16>>2]|0,(Jl(d,w,rs(t[(t[b>>2]|0)+16>>2]|0)|0)|0)==0):0){t[p>>2]=0;while(1){if((t[p>>2]|0)>=(t[_>>2]|0))break;if(Xl(t[(t[b>>2]|0)+24>>2]|0,t[m+(t[p>>2]<<2)>>2]|0)|0)break;t[p>>2]=(t[p>>2]|0)+1}if((t[p>>2]|0)<(t[_>>2]|0)){t[b>>2]=t[t[b>>2]>>2];continue}if((t[_>>2]|0)<50){w=t[(t[b>>2]|0)+24>>2]|0;d=t[_>>2]|0;t[_>>2]=d+1;t[m+(d<<2)>>2]=w}if(!(t[(t[b>>2]|0)+8>>2]|0))Bc(t[b>>2]|0)|0;if(t[(t[b>>2]|0)+8>>2]|0){if(t[33468]|0){w=t[33976]|0;d=t[33980]|0;t[f>>2]=t[(t[b>>2]|0)+24>>2];yAi[w&511](d,135440,f)}t[l>>2]=Sc(t[(t[b>>2]|0)+8>>2]|0,0,t[c>>2]|0)|0;if(t[l>>2]|0){F=43;break}}}t[b>>2]=t[t[b>>2]>>2]}if((F|0)==43){m=(t[a>>2]|0)+36|0;t[m>>2]=(t[m>>2]|0)+-1;t[u>>2]=t[l>>2];y=t[u>>2]|0;s=n;return y|0}else if((F|0)==45){m=(t[a>>2]|0)+36|0;t[m>>2]=(t[m>>2]|0)+-1;t[u>>2]=-1;y=t[u>>2]|0;s=n;return y|0}}}if(t[o>>2]|0){t[b>>2]=t[a>>2];t[k>>2]=0;while(1){if(!(t[b>>2]|0))break;m=t[(t[b>>2]|0)+12>>2]|0;if((m|0)==8){_=t[o>>2]|0;p=t[(t[b>>2]|0)+16>>2]|0;if((Jl(_,p,rs(t[(t[b>>2]|0)+16>>2]|0)|0)|0)==0?(t[(t[b>>2]|0)+28>>2]|0)==1:0)t[k>>2]=(t[k>>2]|0)+1}else if((m|0)==3){if(!(t[c>>2]|0))t[h>>2]=(t[h>>2]|0)+1}else if((m|0)==5?(Xl(t[o>>2]|0,t[(t[b>>2]|0)+16>>2]|0)|0)!=0:0){F=51;break}t[b>>2]=t[t[b>>2]>>2]}if((F|0)==51){if(t[33468]|0){m=t[33976]|0;p=t[33980]|0;t[f>>2]=t[(t[b>>2]|0)+16>>2];yAi[m&511](p,135472,f)}p=(t[a>>2]|0)+36|0;t[p>>2]=(t[p>>2]|0)+-1;t[u>>2]=Yl(t[(t[b>>2]|0)+24>>2]|0)|0;y=t[u>>2]|0;s=n;return y|0}if(t[k>>2]|0){t[S>>2]=0;t[b>>2]=t[a>>2];while(1){if(!(t[b>>2]|0)){F=82;break}if(((t[(t[b>>2]|0)+12>>2]|0)==8?(t[(t[b>>2]|0)+28>>2]|0)==1:0)?(k=t[o>>2]|0,p=t[(t[b>>2]|0)+16>>2]|0,(Jl(k,p,rs(t[(t[b>>2]|0)+16>>2]|0)|0)|0)==0):0){t[g>>2]=0;while(1){if((t[g>>2]|0)>=(t[S>>2]|0))break;if(Xl(t[(t[b>>2]|0)+24>>2]|0,t[E+(t[g>>2]<<2)>>2]|0)|0)break;t[g>>2]=(t[g>>2]|0)+1}if((t[g>>2]|0)<(t[S>>2]|0)){t[b>>2]=t[t[b>>2]>>2];continue}if((t[S>>2]|0)<50){p=t[(t[b>>2]|0)+24>>2]|0;k=t[S>>2]|0;t[S>>2]=k+1;t[E+(k<<2)>>2]=p}if(!(t[(t[b>>2]|0)+8>>2]|0))Bc(t[b>>2]|0)|0;if(t[(t[b>>2]|0)+8>>2]|0){if(t[33468]|0){p=t[33976]|0;k=t[33980]|0;t[f>>2]=t[(t[b>>2]|0)+24>>2];yAi[p&511](k,135496,f)}t[l>>2]=Sc(t[(t[b>>2]|0)+8>>2]|0,t[o>>2]|0,0)|0;if(t[l>>2]|0){F=80;break}}}t[b>>2]=t[t[b>>2]>>2]}if((F|0)==80){f=(t[a>>2]|0)+36|0;t[f>>2]=(t[f>>2]|0)+-1;t[u>>2]=t[l>>2];y=t[u>>2]|0;s=n;return y|0}else if((F|0)==82){f=(t[a>>2]|0)+36|0;t[f>>2]=(t[f>>2]|0)+-1;t[u>>2]=-1;y=t[u>>2]|0;s=n;return y|0}}}e:do if(t[h>>2]|0){t[b>>2]=t[a>>2];while(1){if(!(t[b>>2]|0))break e;if((t[(t[b>>2]|0)+12>>2]|0)==3){if(!(t[(t[b>>2]|0)+8>>2]|0))Bc(t[b>>2]|0)|0;if(t[(t[b>>2]|0)+8>>2]|0){t[l>>2]=Sc(t[(t[b>>2]|0)+8>>2]|0,t[o>>2]|0,t[c>>2]|0)|0;O=(t[a>>2]|0)+36|0;A=t[O>>2]|0;if(t[l>>2]|0){F=91;break}if((A|0)>50){F=93;break}}}t[b>>2]=t[t[b>>2]>>2]}if((F|0)==91){t[O>>2]=A+-1;t[u>>2]=t[l>>2];y=t[u>>2]|0;s=n;return y|0}else if((F|0)==93){t[u>>2]=0;y=t[u>>2]|0;s=n;return y|0}}while(0);F=(t[a>>2]|0)+36|0;t[F>>2]=(t[F>>2]|0)+-1;t[u>>2]=0;y=t[u>>2]|0;s=n;return y|0}function Hc(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0;r=s;s=s+256|0;n=r;f=r+252|0;u=r+248|0;a=r+244|0;o=r+240|0;c=r+236|0;l=r+232|0;b=r+228|0;k=r+224|0;h=r+220|0;w=r+216|0;d=r+16|0;v=r+8|0;m=r+4|0;t[u>>2]=e;t[a>>2]=i;t[o>>2]=0;t[l>>2]=0;t[b>>2]=0;t[k>>2]=0;t[h>>2]=0;if(!(t[u>>2]|0)){t[f>>2]=0;_=t[f>>2]|0;s=r;return _|0}if(!(t[a>>2]|0)){t[f>>2]=0;_=t[f>>2]|0;s=r;return _|0}i=t[u>>2]|0;if((t[(t[u>>2]|0)+36>>2]|0)>50){Uc(i,0,1654,135136,t[(t[u>>2]|0)+16>>2]|0,0,0);t[f>>2]=0;_=t[f>>2]|0;s=r;return _|0}t[c>>2]=i;t[l>>2]=0;while(1){if(!(t[c>>2]|0))break;i=t[(t[c>>2]|0)+12>>2]|0;if((i|0)==10){if(Xl(t[a>>2]|0,t[(t[c>>2]|0)+16>>2]|0)|0){p=11;break}}else if((i|0)==12){e=t[a>>2]|0;E=t[(t[c>>2]|0)+16>>2]|0;if(!(Jl(e,E,rs(t[(t[c>>2]|0)+16>>2]|0)|0)|0))t[l>>2]=(t[l>>2]|0)+1}else if((i|0)==11){t[w>>2]=rs(t[(t[c>>2]|0)+16>>2]|0)|0;if((t[w>>2]|0)>(t[h>>2]|0)?(Jl(t[a>>2]|0,t[(t[c>>2]|0)+16>>2]|0,t[w>>2]|0)|0)==0:0){t[h>>2]=t[w>>2];t[k>>2]=t[c>>2]}}else if((i|0)==3)t[b>>2]=(t[b>>2]|0)+1;t[c>>2]=t[t[c>>2]>>2]}if((p|0)==11){if(t[33468]|0){w=t[33976]|0;i=t[33980]|0;t[n>>2]=t[(t[c>>2]|0)+16>>2];yAi[w&511](i,135176,n)}t[f>>2]=Yl(t[(t[c>>2]|0)+24>>2]|0)|0;_=t[f>>2]|0;s=r;return _|0}if(t[k>>2]|0){if(t[33468]|0){i=t[33976]|0;w=t[33980]|0;t[n>>2]=t[(t[k>>2]|0)+16>>2];yAi[i&511](w,135200,n)}t[o>>2]=Yl(t[(t[k>>2]|0)+24>>2]|0)|0;if(t[o>>2]|0)t[o>>2]=us(t[o>>2]|0,(t[a>>2]|0)+(t[h>>2]|0)|0)|0;t[f>>2]=t[o>>2];_=t[f>>2]|0;s=r;return _|0}if(!(t[l>>2]|0)){e:do if(t[b>>2]|0){t[c>>2]=t[u>>2];while(1){if(!(t[c>>2]|0))break e;if((t[(t[c>>2]|0)+12>>2]|0)==3){if(!(t[(t[c>>2]|0)+8>>2]|0))Bc(t[c>>2]|0)|0;if((t[(t[c>>2]|0)+8>>2]|0)!=0?(t[o>>2]=Oc(t[(t[c>>2]|0)+8>>2]|0,t[a>>2]|0)|0,(t[o>>2]|0)!=0):0)break}t[c>>2]=t[t[c>>2]>>2]}t[f>>2]=t[o>>2];_=t[f>>2]|0;s=r;return _|0}while(0);t[f>>2]=0;_=t[f>>2]|0;s=r;return _|0}t[v>>2]=0;t[c>>2]=t[u>>2];while(1){if(!(t[c>>2]|0)){p=49;break}if(!((t[(t[c>>2]|0)+12>>2]|0)!=9?(t[(t[c>>2]|0)+12>>2]|0)!=12:0))p=32;if((p|0)==32?(p=0,u=t[a>>2]|0,b=t[(t[c>>2]|0)+16>>2]|0,(Jl(u,b,rs(t[(t[c>>2]|0)+16>>2]|0)|0)|0)==0):0){t[m>>2]=0;while(1){if((t[m>>2]|0)>=(t[v>>2]|0))break;if(Xl(t[(t[c>>2]|0)+24>>2]|0,t[d+(t[m>>2]<<2)>>2]|0)|0)break;t[m>>2]=(t[m>>2]|0)+1}if((t[m>>2]|0)<(t[v>>2]|0)){t[c>>2]=t[t[c>>2]>>2];continue}if((t[v>>2]|0)<50){b=t[(t[c>>2]|0)+24>>2]|0;u=t[v>>2]|0;t[v>>2]=u+1;t[d+(u<<2)>>2]=b}if(!(t[(t[c>>2]|0)+8>>2]|0))Bc(t[c>>2]|0)|0;if(t[(t[c>>2]|0)+8>>2]|0){if(t[33468]|0){b=t[33976]|0;u=t[33980]|0;t[n>>2]=t[(t[c>>2]|0)+24>>2];yAi[b&511](u,135232,n)}t[o>>2]=Oc(t[(t[c>>2]|0)+8>>2]|0,t[a>>2]|0)|0;if(t[o>>2]|0){p=47;break}}}t[c>>2]=t[t[c>>2]>>2]}if((p|0)==47){t[f>>2]=t[o>>2];_=t[f>>2]|0;s=r;return _|0}else if((p|0)==49){t[f>>2]=-1;_=t[f>>2]|0;s=r;return _|0}return 0}function xc(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0;r=s;s=s+48|0;n=r;f=r+32|0;u=r+28|0;a=r+24|0;o=r+20|0;c=r+16|0;l=r+12|0;b=r+8|0;t[u>>2]=e;t[a>>2]=i;t[b>>2]=0;if(!(t[a>>2]|0)){t[f>>2]=0;k=t[f>>2]|0;s=r;return k|0}t[o>>2]=ic(t[a>>2]|0)|0;i=(t[33468]|0)!=0;if(!(t[o>>2]|0)){if(i){e=t[33976]|0;h=t[33980]|0;t[n>>2]=t[a>>2];yAi[e&511](h,134360,n)}t[f>>2]=0;k=t[f>>2]|0;s=r;return k|0}if(i){i=t[33976]|0;h=t[33980]|0;e=nl()|0;w=t[a>>2]|0;t[n>>2]=e;t[n+4>>2]=w;yAi[i&511](h,134392,n)}t[c>>2]=eF(t[o>>2]|0)|0;if(((((t[c>>2]|0)!=0?(Xl(t[(t[c>>2]|0)+8>>2]|0,134128)|0)!=0:0)?(t[(t[c>>2]|0)+36>>2]|0)!=0:0)?(t[(t[(t[c>>2]|0)+36>>2]|0)+8>>2]|0)!=0:0)?(Xl(t[(t[(t[c>>2]|0)+36>>2]|0)+8>>2]|0,134416)|0)!=0:0){t[b>>2]=Ec(1,0,t[a>>2]|0,0,t[u>>2]|0,0)|0;if(!(t[b>>2]|0)){fy(t[o>>2]|0);t[f>>2]=0;k=t[f>>2]|0;s=r;return k|0}t[l>>2]=cF(t[c>>2]|0,134464)|0;if(t[l>>2]|0){do if(!(Xl(t[l>>2]|0,134472)|0))if(Xl(t[l>>2]|0,134480)|0){t[u>>2]=1;break}else{Uc(0,t[c>>2]|0,1652,134488,t[l>>2]|0,0,0);break}else t[u>>2]=2;while(0);pAi[t[135736>>2]&511](t[l>>2]|0)}t[c>>2]=t[(t[c>>2]|0)+12>>2];zc(t[c>>2]|0,t[u>>2]|0,t[b>>2]|0,0);fy(t[o>>2]|0);t[f>>2]=t[b>>2];k=t[f>>2]|0;s=r;return k|0}Uc(0,t[o>>2]|0,1653,134520,t[a>>2]|0,0,0);fy(t[o>>2]|0);t[f>>2]=0;k=t[f>>2]|0;s=r;return k|0}function Uc(e,i,r,n,f,u,a){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;u=u|0;a=a|0;var o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0;o=s;s=s+48|0;c=o;l=o+36|0;b=o+32|0;k=o+28|0;h=o+24|0;w=o+20|0;d=o+16|0;v=o+12|0;t[l>>2]=e;t[b>>2]=i;t[k>>2]=r;t[h>>2]=n;t[w>>2]=f;t[d>>2]=u;t[v>>2]=a;a=t[l>>2]|0;l=t[b>>2]|0;b=t[k>>2]|0;k=t[w>>2]|0;u=t[d>>2]|0;f=t[v>>2]|0;n=t[h>>2]|0;h=t[d>>2]|0;d=t[v>>2]|0;t[c>>2]=t[w>>2];t[c+4>>2]=h;t[c+8>>2]=d;cp(0,0,0,a,l,20,b,2,0,0,k,u,f,0,0,n,c);s=o;return}function zc(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,u=0,a=0,o=0,c=0;f=s;s=s+16|0;u=f+12|0;a=f+8|0;o=f+4|0;c=f;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;t[c>>2]=n;while(1){if(!(t[u>>2]|0))break;if(((t[(t[u>>2]|0)+36>>2]|0)!=0?(t[(t[(t[u>>2]|0)+36>>2]|0)+8>>2]|0)!=0:0)?(Xl(t[(t[(t[u>>2]|0)+36>>2]|0)+8>>2]|0,134416)|0)!=0:0)jc(t[u>>2]|0,t[a>>2]|0,t[o>>2]|0,t[c>>2]|0);t[u>>2]=t[(t[u>>2]|0)+24>>2]}s=f;return}function jc(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0;f=s;s=s+48|0;u=f+32|0;a=f+28|0;o=f+24|0;c=f+20|0;l=f+16|0;b=f+12|0;k=f+8|0;h=f+4|0;w=f;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;t[c>>2]=n;t[l>>2]=0;t[b>>2]=0;if(!(t[u>>2]|0)){s=f;return}do if(!(Xl(t[(t[u>>2]|0)+8>>2]|0,134552)|0)){n=(Xl(t[(t[u>>2]|0)+8>>2]|0,134480)|0)!=0;r=t[u>>2]|0;if(n){t[b>>2]=Vc(r,5,134480,134616,134632,t[a>>2]|0,t[c>>2]|0)|0;break}n=(Xl(t[r+8>>2]|0,134472)|0)!=0;r=t[u>>2]|0;if(n){t[b>>2]=Vc(r,6,134472,134640,134632,t[a>>2]|0,t[c>>2]|0)|0;break}n=(Xl(t[r+8>>2]|0,134656)|0)!=0;r=t[u>>2]|0;if(n){t[b>>2]=Vc(r,7,134656,134672,134696,t[a>>2]|0,t[c>>2]|0)|0;break}n=(Xl(t[r+8>>2]|0,134712)|0)!=0;r=t[u>>2]|0;if(n){t[b>>2]=Vc(r,8,134712,134728,134128,t[a>>2]|0,t[c>>2]|0)|0;break}n=(Xl(t[r+8>>2]|0,134752)|0)!=0;r=t[u>>2]|0;if(n){t[b>>2]=Vc(r,9,134752,134672,134128,t[a>>2]|0,t[c>>2]|0)|0;break}n=(Xl(t[r+8>>2]|0,134632)|0)!=0;r=t[u>>2]|0;if(n){t[b>>2]=Vc(r,10,134632,134768,134632,t[a>>2]|0,t[c>>2]|0)|0;break}n=(Xl(t[r+8>>2]|0,134776)|0)!=0;r=t[u>>2]|0;if(n){t[b>>2]=Vc(r,11,134776,134792,134696,t[a>>2]|0,t[c>>2]|0)|0;break}n=(Xl(t[r+8>>2]|0,134808)|0)!=0;r=t[u>>2]|0;if(n){t[b>>2]=Vc(r,12,134808,134792,134128,t[a>>2]|0,t[c>>2]|0)|0;break}if(Xl(t[r+8>>2]|0,134824)|0)t[b>>2]=Vc(t[u>>2]|0,3,134824,0,134128,t[a>>2]|0,t[c>>2]|0)|0}else{t[h>>2]=0;t[k>>2]=cF(t[u>>2]|0,134464)|0;if(t[k>>2]|0){do if(!(Xl(t[k>>2]|0,134472)|0))if(Xl(t[k>>2]|0,134480)|0){t[a>>2]=1;break}else{Uc(t[o>>2]|0,t[u>>2]|0,1652,134488,t[k>>2]|0,0,0);break}else t[a>>2]=2;while(0);pAi[t[135736>>2]&511](t[k>>2]|0);t[h>>2]=t[a>>2]}t[k>>2]=cF(t[u>>2]|0,134560)|0;t[l>>2]=tF(t[u>>2]|0,134568,134576)|0;t[b>>2]=Ec(4,t[k>>2]|0,t[l>>2]|0,0,t[h>>2]|0,t[c>>2]|0)|0;pAi[t[135736>>2]&511](t[k>>2]|0)}while(0);if(t[b>>2]|0){do if(t[o>>2]|0){t[(t[b>>2]|0)+4>>2]=t[o>>2];if(!(t[(t[o>>2]|0)+8>>2]|0)){t[(t[o>>2]|0)+8>>2]=t[b>>2];break}t[w>>2]=t[(t[o>>2]|0)+8>>2];while(1){if(!(t[t[w>>2]>>2]|0))break;t[w>>2]=t[t[w>>2]>>2]}t[t[w>>2]>>2]=t[b>>2]}while(0);if((t[(t[b>>2]|0)+12>>2]|0)==4)zc(t[(t[u>>2]|0)+12>>2]|0,t[a>>2]|0,t[o>>2]|0,t[b>>2]|0)}if(!(t[l>>2]|0)){s=f;return}pAi[t[135736>>2]&511](t[l>>2]|0);s=f;return}function Vc(e,i,r,n,f,u,a){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;u=u|0;a=a|0;var o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0,S=0,g=0,y=0,F=0;o=s;s=s+80|0;c=o;l=o+64|0;b=o+60|0;k=o+56|0;h=o+52|0;w=o+48|0;d=o+44|0;v=o+40|0;m=o+36|0;_=o+32|0;p=o+28|0;E=o+24|0;S=o+20|0;g=o+16|0;y=o+12|0;t[b>>2]=e;t[k>>2]=i;t[h>>2]=r;t[w>>2]=n;t[d>>2]=f;t[v>>2]=u;t[m>>2]=a;t[_>>2]=1;t[E>>2]=0;t[S>>2]=0;t[g>>2]=0;t[y>>2]=0;if((t[w>>2]|0)!=0?(t[E>>2]=cF(t[b>>2]|0,t[w>>2]|0)|0,(t[E>>2]|0)==0):0){Uc(t[y>>2]|0,t[b>>2]|0,1650,134840,t[h>>2]|0,t[w>>2]|0,0);t[_>>2]=0}t[p>>2]=cF(t[b>>2]|0,t[d>>2]|0)|0;if(!(t[p>>2]|0)){Uc(t[y>>2]|0,t[b>>2]|0,1650,134840,t[h>>2]|0,t[d>>2]|0,0);t[_>>2]=0}if(!(t[_>>2]|0)){if(t[E>>2]|0)pAi[t[135736>>2]&511](t[E>>2]|0);if(t[p>>2]|0)pAi[t[135736>>2]&511](t[p>>2]|0);t[l>>2]=0;F=t[l>>2]|0;s=o;return F|0}t[S>>2]=oF(t[(t[b>>2]|0)+32>>2]|0,t[b>>2]|0)|0;t[g>>2]=GA(t[p>>2]|0,t[S>>2]|0)|0;if(t[g>>2]|0){do if((t[33468]|0)>1){_=t[33976]|0;w=t[33980]|0;a=t[h>>2]|0;if(t[E>>2]|0){u=t[E>>2]|0;f=t[g>>2]|0;t[c>>2]=a;t[c+4>>2]=u;t[c+8>>2]=f;yAi[_&511](w,134864,c);break}else{f=t[g>>2]|0;t[c>>2]=a;t[c+4>>2]=f;yAi[_&511](w,134888,c);break}}while(0);t[y>>2]=Ec(t[k>>2]|0,t[E>>2]|0,t[p>>2]|0,t[g>>2]|0,t[v>>2]|0,t[m>>2]|0)|0}else Uc(t[y>>2]|0,t[b>>2]|0,1651,134904,t[h>>2]|0,t[d>>2]|0,t[p>>2]|0);if(t[E>>2]|0)pAi[t[135736>>2]&511](t[E>>2]|0);if(t[p>>2]|0)pAi[t[135736>>2]&511](t[p>>2]|0);if(t[S>>2]|0)pAi[t[135736>>2]&511](t[S>>2]|0);if(t[g>>2]|0)pAi[t[135736>>2]&511](t[g>>2]|0);t[l>>2]=t[y>>2];F=t[l>>2]|0;s=o;return F|0}function qc(){var e=0;e=s;if(t[33932]|0){s=e;return}t[33932]=Kc()|0;s=e;return}function Yc(){var e=0;e=s;if(t[33932]|0){Xc(t[33932]|0);t[33932]=0}rl();s=e;return}function Gc(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i+4|0;n=i;t[r>>2]=e;t[n>>2]=t[33968];t[18774]=1;t[33968]=t[r>>2];s=i;return t[n>>2]|0}function Wc(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i+4|0;n=i;t[r>>2]=e;t[n>>2]=t[33970];t[18774]=1;t[33970]=t[r>>2];s=i;return t[n>>2]|0}function Kc(){var e=0,i=0,r=0,n=0;e=s;s=s+16|0;i=e+4|0;r=e;n=Xq(4)|0;t[r>>2]=n;if(!n)t[i>>2]=0;else t[i>>2]=t[r>>2];s=e;return t[i>>2]|0}function Xc(e){e=e|0;var i=0,r=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if(!(t[r>>2]|0)){s=i;return}Zq(t[r>>2]|0);s=i;return}function Zc(e){e=e|0;var i=0;i=s;s=s+16|0;t[i>>2]=e;s=i;return}function Jc(e){e=e|0;var i=0;i=s;s=s+16|0;t[i>>2]=e;s=i;return}function Qc(){var e=0,i=0,r=0,n=0;e=s;s=s+16|0;i=e+4|0;r=e;n=Xq(4)|0;t[r>>2]=n;if(!n)t[i>>2]=0;else t[i>>2]=t[r>>2];s=e;return t[i>>2]|0}function $c(e){e=e|0;var i=0,r=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if(!(t[r>>2]|0)){s=i;return}Zq(t[r>>2]|0);s=i;return}function el(e){e=e|0;var i=0;i=s;s=s+16|0;t[i>>2]=e;s=i;return}function il(e){e=e|0;var i=0;i=s;s=s+16|0;t[i>>2]=e;s=i;return}function rl(){return}function nl(){return 0}function fl(){return}function tl(){return}function ul(e,i,r,n,f,u,a){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;u=u|0;a=a|0;var o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0;o=s;s=s+48|0;c=o+40|0;l=o+36|0;b=o+32|0;k=o+28|0;h=o+24|0;w=o+20|0;d=o+16|0;v=o+12|0;m=o+8|0;_=o+4|0;p=o;t[l>>2]=e;t[b>>2]=i;t[k>>2]=r;t[h>>2]=n;t[w>>2]=f;t[d>>2]=u;t[v>>2]=a;t[_>>2]=0;if((t[v>>2]|0)==0|(t[l>>2]|0)==0){cl(136264);t[c>>2]=-1;E=t[c>>2]|0;s=o;return E|0}if((t[h>>2]|0)>>>0>=3){cl(136280);t[c>>2]=-1;E=t[c>>2]|0;s=o;return E|0}t[_>>2]=t[h>>2];h=t[l>>2]|0;if(t[(t[v>>2]|0)+12>>2]|0){ll(0,h,1951,136312);t[c>>2]=-1;E=t[c>>2]|0;s=o;return E|0}t[m>>2]=sl(h,t[b>>2]|0,t[k>>2]|0,t[_>>2]|0,t[w>>2]|0,t[d>>2]|0,t[v>>2]|0)|0;d=t[l>>2]|0;if(!(t[m>>2]|0)){ll(0,d,1950,136392);t[c>>2]=-1;E=t[c>>2]|0;s=o;return E|0}if((t[d+12>>2]|0)!=0?(t[p>>2]=bl(t[m>>2]|0,t[(t[l>>2]|0)+12>>2]|0)|0,(t[p>>2]|0)<0):0){kl(136440);hl(t[m>>2]|0);t[c>>2]=-1;E=t[c>>2]|0;s=o;return E|0}t[p>>2]=xO(t[v>>2]|0)|0;if((t[p>>2]|0)<0){kl(136472);hl(t[m>>2]|0);t[c>>2]=-1;E=t[c>>2]|0;s=o;return E|0}else{hl(t[m>>2]|0);t[c>>2]=t[p>>2];E=t[c>>2]|0;s=o;return E|0}return 0}function al(e,i,r,n,f,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;u=u|0;var a=0,o=0,c=0,l=0,b=0,k=0,h=0;a=s;s=s+32|0;o=a+20|0;c=a+16|0;l=a+12|0;b=a+8|0;k=a+4|0;h=a;t[o>>2]=e;t[c>>2]=i;t[l>>2]=r;t[b>>2]=n;t[k>>2]=f;t[h>>2]=u;u=ul(t[o>>2]|0,317,t[c>>2]|0,t[l>>2]|0,t[b>>2]|0,t[k>>2]|0,t[h>>2]|0)|0;s=a;return u|0}function ol(e,i,r,n,f,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;u=u|0;var a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0;a=s;s=s+48|0;o=a+32|0;c=a+28|0;l=a+24|0;b=a+20|0;k=a+16|0;h=a+12|0;w=a+8|0;d=a+4|0;v=a;t[c>>2]=e;t[l>>2]=i;t[b>>2]=r;t[k>>2]=n;t[h>>2]=f;t[w>>2]=u;if(!(t[w>>2]|0)){cl(136496);t[o>>2]=-1;m=t[o>>2]|0;s=a;return m|0}t[t[w>>2]>>2]=0;t[v>>2]=PO(0)|0;if(!(t[v>>2]|0)){dl(136520);t[o>>2]=-1;m=t[o>>2]|0;s=a;return m|0}t[d>>2]=al(t[c>>2]|0,t[l>>2]|0,t[b>>2]|0,t[k>>2]|0,t[h>>2]|0,t[v>>2]|0)|0;if((t[d>>2]|0)<0){kl(136544);HO(t[v>>2]|0)|0;t[o>>2]=-1;m=t[o>>2]|0;s=a;return m|0}t[d>>2]=Ts(t[(t[v>>2]|0)+16>>2]|0)|0;if((t[d>>2]|0)>0){h=Os(t[(t[v>>2]|0)+16>>2]|0)|0;k=ql(h,t[d>>2]|0)|0;t[t[w>>2]>>2]=k}HO(t[v>>2]|0)|0;if((t[d>>2]|0)>0?(t[t[w>>2]>>2]|0)==0:0){dl(136576);t[o>>2]=-1;m=t[o>>2]|0;s=a;return m|0}else{t[o>>2]=t[d>>2];m=t[o>>2]|0;s=a;return m|0}return 0}function cl(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i;n=i+4|0;t[n>>2]=e;e=t[n>>2]|0;t[r>>2]=t[n>>2];cp(0,0,0,0,0,21,1,2,0,0,e,0,0,0,0,138632,r);s=i;return}function ll(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,u=0,a=0,o=0,c=0,l=0;f=s;s=s+32|0;u=f;a=f+16|0;o=f+12|0;c=f+8|0;l=f+4|0;t[a>>2]=e;t[o>>2]=i;t[c>>2]=r;t[l>>2]=n;if(t[a>>2]|0)t[(t[a>>2]|0)+40>>2]=t[c>>2];n=t[a>>2]|0;a=t[o>>2]|0;o=t[c>>2]|0;t[u>>2]=t[l>>2];cp(0,0,0,n,a,21,o,2,0,0,0,0,0,0,0,138624,u);s=f;return}function sl(e,i,r,n,f,u,a){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;u=u|0;a=a|0;var o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0;o=s;s=s+48|0;c=o+32|0;l=o+28|0;b=o+24|0;k=o+20|0;h=o+16|0;w=o+12|0;d=o+8|0;v=o+4|0;m=o;t[l>>2]=e;t[b>>2]=i;t[k>>2]=r;t[h>>2]=n;t[w>>2]=f;t[d>>2]=u;t[v>>2]=a;t[m>>2]=0;if((t[l>>2]|0)==0|(t[v>>2]|0)==0){cl(138360);t[c>>2]=0;_=t[c>>2]|0;s=o;return _|0}if(t[(t[v>>2]|0)+12>>2]|0){ll(t[m>>2]|0,t[l>>2]|0,1951,138384);t[c>>2]=0;_=t[c>>2]|0;s=o;return _|0}if((t[(t[l>>2]|0)+76>>2]|0)!=1){ll(t[m>>2]|0,t[l>>2]|0,1951,138464);t[c>>2]=0;_=t[c>>2]|0;s=o;return _|0}t[m>>2]=gAi[t[135744>>2]&511](44)|0;if(!(t[m>>2]|0)){dl(138512);t[c>>2]=0;_=t[c>>2]|0;s=o;return _|0}a=(t[m>>2]|0)+0|0;u=a+44|0;do{t[a>>2]=0;a=a+4|0}while((a|0)<(u|0));t[t[m>>2]>>2]=t[l>>2];t[(t[m>>2]|0)+12>>2]=t[d>>2];t[(t[m>>2]|0)+4>>2]=t[b>>2];t[(t[m>>2]|0)+8>>2]=t[k>>2];t[(t[m>>2]|0)+16>>2]=t[v>>2];t[(t[m>>2]|0)+24>>2]=1;t[(t[m>>2]|0)+20>>2]=0;v=vl()|0;t[(t[m>>2]|0)+28>>2]=v;if(!(t[(t[m>>2]|0)+28>>2]|0)){ll(t[m>>2]|0,t[l>>2]|0,1952,138536);hl(t[m>>2]|0);t[c>>2]=0;_=t[c>>2]|0;s=o;return _|0}t[(t[m>>2]|0)+32>>2]=t[h>>2];if((t[(t[m>>2]|0)+32>>2]|0)==1)t[(t[m>>2]|0)+36>>2]=t[w>>2];t[c>>2]=t[m>>2];_=t[c>>2]|0;s=o;return _|0}function bl(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0;r=s;s=s+16|0;n=r+12|0;f=r+8|0;u=r+4|0;a=r;t[f>>2]=e;t[u>>2]=i;if(!(t[f>>2]|0)){cl(136712);t[n>>2]=-1;o=t[n>>2]|0;s=r;return o|0}t[a>>2]=0;while(1){if(!((t[u>>2]|0)!=0&(t[a>>2]|0)>=0))break;t[a>>2]=ml(t[f>>2]|0,t[u>>2]|0)|0;t[u>>2]=t[(t[u>>2]|0)+24>>2]}t[n>>2]=t[a>>2];o=t[n>>2]|0;s=r;return o|0}function kl(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i;n=i+4|0;t[n>>2]=e;e=t[n>>2]|0;t[r>>2]=t[n>>2];cp(0,0,0,0,0,21,1,2,0,0,e,0,0,0,0,136688,r);s=i;return}function hl(e){e=e|0;var i=0,r=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if(!(t[r>>2]|0)){cl(136640);s=i;return}if(t[(t[r>>2]|0)+28>>2]|0)_l(t[(t[r>>2]|0)+28>>2]|0);pAi[t[135736>>2]&511](t[r>>2]|0);s=i;return}function wl(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,l=0;n=s;s=s+48|0;f=n+36|0;u=n+32|0;a=n+28|0;o=n+24|0;c=n;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;if(!((t[u>>2]|0)!=0&(t[a>>2]|0)!=0)){t[f>>2]=1;l=t[f>>2]|0;s=n;return l|0}if((t[(t[a>>2]|0)+4>>2]|0)!=18){t[f>>2]=Tn(t[u>>2]|0,t[a>>2]|0)|0;l=t[f>>2]|0;s=n;return l|0}r=t[a>>2]|0;t[c+0>>2]=t[r+0>>2];t[c+4>>2]=t[r+4>>2];t[c+8>>2]=t[r+8>>2];t[c+12>>2]=t[r+12>>2];t[c+16>>2]=t[r+16>>2];t[c+20>>2]=t[r+20>>2];if((t[o>>2]|0)!=0?(t[(t[o>>2]|0)+4>>2]|0)==2:0)t[c>>2]=t[(t[o>>2]|0)+20>>2];else t[c>>2]=t[o>>2];t[f>>2]=Tn(t[u>>2]|0,c)|0;l=t[f>>2]|0;s=n;return l|0}function dl(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i;n=i+4|0;t[n>>2]=e;e=t[n>>2]|0;t[r>>2]=t[n>>2];cp(0,0,0,0,0,21,2,2,0,0,e,0,0,0,0,136608,r);s=i;return}function vl(){var e=0,i=0,r=0,n=0,f=0;e=s;s=s+16|0;i=e+4|0;r=e;t[r>>2]=gAi[t[135744>>2]&511](24)|0;if(!(t[r>>2]|0)){dl(138592);t[i>>2]=0;n=t[i>>2]|0;s=e;return n|0}else{f=t[r>>2]|0;t[f+0>>2]=0;t[f+4>>2]=0;t[f+8>>2]=0;t[f+12>>2]=0;t[f+16>>2]=0;t[f+20>>2]=0;t[i>>2]=t[r>>2];n=t[i>>2]|0;s=e;return n|0}return 0}function ml(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0;r=s;s=s+32|0;n=r+28|0;f=r+24|0;a=r+20|0;o=r+16|0;c=r+12|0;l=r+8|0;b=r+4|0;k=r;t[f>>2]=e;t[a>>2]=i;t[o>>2]=0;if((t[f>>2]|0)==0|(t[a>>2]|0)==0){cl(136736);t[n>>2]=-1;h=t[n>>2]|0;s=r;return h|0}if(t[(t[f>>2]|0)+4>>2]|0)w=dAi[t[(t[f>>2]|0)+4>>2]&511](t[(t[f>>2]|0)+8>>2]|0,t[a>>2]|0,t[(t[a>>2]|0)+20>>2]|0)|0;else w=1;t[c>>2]=w;e:do switch(t[(t[a>>2]|0)+4>>2]|0){case 8:{if((t[c>>2]|0)!=0?(t[(t[f>>2]|0)+12>>2]|0)!=0:0){w=t[(t[f>>2]|0)+16>>2]|0;if((t[(t[f>>2]|0)+20>>2]|0)==2)iA(w,136840)|0;else iA(w,136848)|0;do if(t[(t[a>>2]|0)+40>>2]|0){t[k>>2]=El(t[(t[a>>2]|0)+40>>2]|0,1)|0;if(t[k>>2]|0){iA(t[(t[f>>2]|0)+16>>2]|0,t[k>>2]|0)|0;pAi[t[135736>>2]&511](t[k>>2]|0);break}kl(136856);t[n>>2]=-1;h=t[n>>2]|0;s=r;return h|0}while(0);w=t[(t[f>>2]|0)+16>>2]|0;if(!(t[(t[f>>2]|0)+20>>2]|0)){iA(w,136888)|0;break e}else{iA(w,136896)|0;break e}}break}case 18:{Sl(136928,136736);t[n>>2]=-1;h=t[n>>2]|0;s=r;return h|0}case 7:{if(t[c>>2]|0){w=t[(t[f>>2]|0)+16>>2]|0;if((t[(t[f>>2]|0)+20>>2]|0)==2)iA(w,136776)|0;else iA(w,136784)|0;iA(t[(t[f>>2]|0)+16>>2]|0,t[(t[a>>2]|0)+8>>2]|0)|0;do if((t[(t[a>>2]|0)+40>>2]|0)!=0?(u[t[(t[a>>2]|0)+40>>2]>>0]|0|0)!=0:0){iA(t[(t[f>>2]|0)+16>>2]|0,136792)|0;t[b>>2]=El(t[(t[a>>2]|0)+40>>2]|0,2)|0;if(t[b>>2]|0){iA(t[(t[f>>2]|0)+16>>2]|0,t[b>>2]|0)|0;pAi[t[135736>>2]&511](t[b>>2]|0);break}kl(136800);t[n>>2]=-1;h=t[n>>2]|0;s=r;return h|0}while(0);w=t[(t[f>>2]|0)+16>>2]|0;if(!(t[(t[f>>2]|0)+20>>2]|0)){iA(w,136824)|0;break e}else{iA(w,136832)|0;break e}}break}case 3:case 4:{if((t[c>>2]|0)!=0?(t[(t[a>>2]|0)+40>>2]|0)!=0:0){t[l>>2]=El(t[(t[a>>2]|0)+40>>2]|0,3)|0;if(t[l>>2]|0){iA(t[(t[f>>2]|0)+16>>2]|0,t[l>>2]|0)|0;pAi[t[135736>>2]&511](t[l>>2]|0);break e}kl(136752);t[n>>2]=-1;h=t[n>>2]|0;s=r;return h|0}break}case 1:{t[o>>2]=pl(t[f>>2]|0,t[a>>2]|0,t[c>>2]|0)|0;break}case 2:{Sl(136904,136736);t[n>>2]=-1;h=t[n>>2]|0;s=r;return h|0}case 13:case 21:case 11:case 9:{if(t[(t[a>>2]|0)+12>>2]|0){t[(t[f>>2]|0)+20>>2]=0;t[(t[f>>2]|0)+24>>2]=1;t[o>>2]=bl(t[f>>2]|0,t[(t[a>>2]|0)+12>>2]|0)|0}break}case 6:{Sl(136976,136736);t[n>>2]=-1;h=t[n>>2]|0;s=r;return h|0}case 20:case 19:case 17:case 16:case 15:case 14:case 12:case 10:break;case 5:{Sl(136952,136736);t[n>>2]=-1;h=t[n>>2]|0;s=r;return h|0}default:{gl(t[(t[a>>2]|0)+4>>2]|0,136736);t[n>>2]=-1;h=t[n>>2]|0;s=r;return h|0}}while(0);t[n>>2]=t[o>>2];h=t[n>>2]|0;s=r;return h|0}function _l(e){e=e|0;var i=0,r=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if(!(t[r>>2]|0)){cl(136656);s=i;return}if(t[(t[r>>2]|0)+16>>2]|0){VY(t[(t[r>>2]|0)+16>>2]|0,0,t[(t[r>>2]|0)+12>>2]<<2|0)|0;pAi[t[135736>>2]&511](t[(t[r>>2]|0)+16>>2]|0)}if(t[(t[r>>2]|0)+20>>2]|0){VY(t[(t[r>>2]|0)+20>>2]|0,0,t[(t[r>>2]|0)+12>>2]<<2|0)|0;pAi[t[135736>>2]&511](t[(t[r>>2]|0)+20>>2]|0)}e=t[r>>2]|0;t[e+0>>2]=0;t[e+4>>2]=0;t[e+8>>2]=0;t[e+12>>2]=0;t[e+16>>2]=0;t[e+20>>2]=0;pAi[t[135736>>2]&511](t[r>>2]|0);s=i;return}function pl(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0;n=s;s=s+64|0;f=n+48|0;u=n+44|0;a=n+40|0;o=n+36|0;c=n+32|0;l=n+8|0;b=n;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;t[b>>2]=0;if(!((t[u>>2]|0)==0|(t[a>>2]|0)==0)?(t[(t[a>>2]|0)+4>>2]|0)==1:0){if((yl(t[u>>2]|0,t[a>>2]|0)|0)<0){kl(137128);t[f>>2]=-1;k=t[f>>2]|0;s=n;return k|0}t[l+0>>2]=0;t[l+4>>2]=0;t[l+8>>2]=0;t[l+12>>2]=0;t[l+16>>2]=0;t[l+20>>2]=0;Fl(t[(t[u>>2]|0)+28>>2]|0,l);if(t[o>>2]|0){if(t[(t[u>>2]|0)+24>>2]|0){t[b>>2]=t[(t[u>>2]|0)+24>>2];t[(t[u>>2]|0)+24>>2]=0;t[(t[u>>2]|0)+20>>2]=1}iA(t[(t[u>>2]|0)+16>>2]|0,137168)|0;if((t[(t[a>>2]|0)+36>>2]|0)!=0?(rs(t[(t[(t[a>>2]|0)+36>>2]|0)+12>>2]|0)|0)>0:0){iA(t[(t[u>>2]|0)+16>>2]|0,t[(t[(t[a>>2]|0)+36>>2]|0)+12>>2]|0)|0;iA(t[(t[u>>2]|0)+16>>2]|0,137176)|0}iA(t[(t[u>>2]|0)+16>>2]|0,t[(t[a>>2]|0)+8>>2]|0)|0}r=t[u>>2]|0;i=t[a>>2]|0;e=t[o>>2]|0;if((t[(t[u>>2]|0)+32>>2]|0)==1)t[c>>2]=Al(r,i,e)|0;else t[c>>2]=Ol(r,i,e)|0;if((t[c>>2]|0)<0){kl(137184);t[f>>2]=-1;k=t[f>>2]|0;s=n;return k|0}if(t[o>>2]|0)Ml(t[(t[u>>2]|0)+28>>2]|0);t[c>>2]=Rl(t[u>>2]|0,t[a>>2]|0,t[o>>2]|0)|0;if((t[c>>2]|0)<0){kl(137216);t[f>>2]=-1;k=t[f>>2]|0;s=n;return k|0}if(t[o>>2]|0)iA(t[(t[u>>2]|0)+16>>2]|0,137248)|0;if((t[(t[a>>2]|0)+12>>2]|0)!=0?(t[c>>2]=bl(t[u>>2]|0,t[(t[a>>2]|0)+12>>2]|0)|0,(t[c>>2]|0)<0):0){kl(137256);t[f>>2]=-1;k=t[f>>2]|0;s=n;return k|0}if(t[o>>2]|0){iA(t[(t[u>>2]|0)+16>>2]|0,137288)|0;if((t[(t[a>>2]|0)+36>>2]|0)!=0?(rs(t[(t[(t[a>>2]|0)+36>>2]|0)+12>>2]|0)|0)>0:0){iA(t[(t[u>>2]|0)+16>>2]|0,t[(t[(t[a>>2]|0)+36>>2]|0)+12>>2]|0)|0;iA(t[(t[u>>2]|0)+16>>2]|0,137176)|0}iA(t[(t[u>>2]|0)+16>>2]|0,t[(t[a>>2]|0)+8>>2]|0)|0;iA(t[(t[u>>2]|0)+16>>2]|0,137248)|0;if(t[b>>2]|0){t[(t[u>>2]|0)+24>>2]=t[b>>2];t[(t[u>>2]|0)+20>>2]=2}}Nl(t[(t[u>>2]|0)+28>>2]|0,l);t[f>>2]=0;k=t[f>>2]|0;s=n;return k|0}cl(137104);t[f>>2]=-1;k=t[f>>2]|0;s=n;return k|0}function El(e,i){e=e|0;i=i|0;var r=0,f=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0;r=s;s=s+32|0;f=r+28|0;a=r+24|0;o=r+20|0;c=r+16|0;l=r+12|0;b=r+8|0;k=r+4|0;h=r;t[a>>2]=e;t[o>>2]=i;t[c>>2]=t[a>>2];t[l>>2]=0;t[b>>2]=0;t[k>>2]=0;if(!(t[a>>2]|0)){t[f>>2]=0;w=t[f>>2]|0;s=r;return w|0}t[k>>2]=1e3;t[l>>2]=gAi[t[135752>>2]&511](t[k>>2]|0)|0;if(!(t[l>>2]|0)){dl(137064);t[f>>2]=0;w=t[f>>2]|0;s=r;return w|0}t[b>>2]=t[l>>2];while(1){d=t[b>>2]|0;if(!(u[t[c>>2]>>0]|0)){v=30;break}if((d-(t[l>>2]|0)|0)>((t[k>>2]|0)-10|0)){t[h>>2]=(t[b>>2]|0)-(t[l>>2]|0);t[k>>2]=t[k>>2]<<1;t[l>>2]=MAi[t[135760>>2]&511](t[l>>2]|0,t[k>>2]|0)|0;if(!(t[l>>2]|0)){v=9;break}t[b>>2]=(t[l>>2]|0)+(t[h>>2]|0)}if((u[t[c>>2]>>0]|0|0)==60?(t[o>>2]|0)==0|(t[o>>2]|0)==3:0){a=t[b>>2]|0;t[b>>2]=a+1;n[a>>0]=38;a=t[b>>2]|0;t[b>>2]=a+1;n[a>>0]=108;a=t[b>>2]|0;t[b>>2]=a+1;n[a>>0]=116;a=t[b>>2]|0;t[b>>2]=a+1;n[a>>0]=59}else v=14;do if((v|0)==14){v=0;if((t[o>>2]|0)==3?(u[t[c>>2]>>0]|0|0)==62:0){a=t[b>>2]|0;t[b>>2]=a+1;n[a>>0]=38;a=t[b>>2]|0;t[b>>2]=a+1;n[a>>0]=103;a=t[b>>2]|0;t[b>>2]=a+1;n[a>>0]=116;a=t[b>>2]|0;t[b>>2]=a+1;n[a>>0]=59;break}if((u[t[c>>2]>>0]|0|0)==38?(t[o>>2]|0)==0|(t[o>>2]|0)==3:0){a=t[b>>2]|0;t[b>>2]=a+1;n[a>>0]=38;a=t[b>>2]|0;t[b>>2]=a+1;n[a>>0]=97;a=t[b>>2]|0;t[b>>2]=a+1;n[a>>0]=109;a=t[b>>2]|0;t[b>>2]=a+1;n[a>>0]=112;a=t[b>>2]|0;t[b>>2]=a+1;n[a>>0]=59;break}if((t[o>>2]|0)==0?(u[t[c>>2]>>0]|0|0)==34:0){a=t[b>>2]|0;t[b>>2]=a+1;n[a>>0]=38;a=t[b>>2]|0;t[b>>2]=a+1;n[a>>0]=113;a=t[b>>2]|0;t[b>>2]=a+1;n[a>>0]=117;a=t[b>>2]|0;t[b>>2]=a+1;n[a>>0]=111;a=t[b>>2]|0;t[b>>2]=a+1;n[a>>0]=116;a=t[b>>2]|0;t[b>>2]=a+1;n[a>>0]=59;break}if((t[o>>2]|0)==0?(u[t[c>>2]>>0]|0|0)==9:0){a=t[b>>2]|0;t[b>>2]=a+1;n[a>>0]=38;a=t[b>>2]|0;t[b>>2]=a+1;n[a>>0]=35;a=t[b>>2]|0;t[b>>2]=a+1;n[a>>0]=120;a=t[b>>2]|0;t[b>>2]=a+1;n[a>>0]=57;a=t[b>>2]|0;t[b>>2]=a+1;n[a>>0]=59;break}if((t[o>>2]|0)==0?(u[t[c>>2]>>0]|0|0)==10:0){a=t[b>>2]|0;t[b>>2]=a+1;n[a>>0]=38;a=t[b>>2]|0;t[b>>2]=a+1;n[a>>0]=35;a=t[b>>2]|0;t[b>>2]=a+1;n[a>>0]=120;a=t[b>>2]|0;t[b>>2]=a+1;n[a>>0]=65;a=t[b>>2]|0;t[b>>2]=a+1;n[a>>0]=59;break}if((u[t[c>>2]>>0]|0|0)==13?(t[o>>2]|0)==0|(t[o>>2]|0)==3|(t[o>>2]|0)==1|(t[o>>2]|0)==2:0){a=t[b>>2]|0;t[b>>2]=a+1;n[a>>0]=38;a=t[b>>2]|0;t[b>>2]=a+1;n[a>>0]=35;a=t[b>>2]|0;t[b>>2]=a+1;n[a>>0]=120;a=t[b>>2]|0;t[b>>2]=a+1;n[a>>0]=68;a=t[b>>2]|0;t[b>>2]=a+1;n[a>>0]=59;break}a=n[t[c>>2]>>0]|0;i=t[b>>2]|0;t[b>>2]=i+1;n[i>>0]=a}while(0);t[c>>2]=(t[c>>2]|0)+1}if((v|0)==9){dl(137088);t[f>>2]=0;w=t[f>>2]|0;s=r;return w|0}else if((v|0)==30){n[d>>0]=0;t[f>>2]=t[l>>2];w=t[f>>2]|0;s=r;return w|0}return 0}function Sl(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0;r=s;s=s+16|0;n=r;f=r+12|0;u=r+8|0;t[f>>2]=e;t[u>>2]=i;i=t[u>>2]|0;e=t[u>>2]|0;t[n>>2]=t[f>>2];t[n+4>>2]=e;cp(0,0,0,0,0,21,1953,2,0,0,i,0,0,0,0,137032,n);s=r;return}function gl(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0;r=s;s=s+16|0;n=r;f=r+12|0;u=r+8|0;t[f>>2]=e;t[u>>2]=i;i=t[u>>2]|0;e=t[u>>2]|0;t[n>>2]=t[f>>2];t[n+4>>2]=e;cp(0,0,0,0,0,21,1954,2,0,0,i,0,0,0,0,136992,n);s=r;return}function yl(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0;r=s;s=s+32|0;n=r+16|0;f=r+12|0;u=r+8|0;a=r+4|0;o=r;t[f>>2]=e;t[u>>2]=i;if(!((t[f>>2]|0)==0|(t[u>>2]|0)==0)?(t[(t[u>>2]|0)+4>>2]|0)==1:0){t[a>>2]=t[(t[u>>2]|0)+48>>2];while(1){if(!(t[a>>2]|0)){c=17;break}if((rs(t[(t[a>>2]|0)+8>>2]|0)|0)>0){t[o>>2]=IA(t[(t[a>>2]|0)+8>>2]|0)|0;if(!(t[o>>2]|0)){c=8;break}u=(rs(t[t[o>>2]>>2]|0)|0)==0;l=t[t[o>>2]>>2]|0;if(u){c=10;break}if(((Ql(l,138296)|0)!=0?(Ql(t[t[o>>2]>>2]|0,138304)|0)!=0:0)?(rs(t[(t[o>>2]|0)+12>>2]|0)|0)==0:0){c=14;break}xA(t[o>>2]|0)}t[a>>2]=t[t[a>>2]>>2]}if((c|0)==8){kl(138272);t[n>>2]=-1;b=t[n>>2]|0;s=r;return b|0}else if((c|0)==10){Tl(l);xA(t[o>>2]|0);t[n>>2]=-1;b=t[n>>2]|0;s=r;return b|0}else if((c|0)==14){Tl(t[t[o>>2]>>2]|0);xA(t[o>>2]|0);t[n>>2]=-1;b=t[n>>2]|0;s=r;return b|0}else if((c|0)==17){t[n>>2]=0;b=t[n>>2]|0;s=r;return b|0}}cl(137128);t[n>>2]=-1;b=t[n>>2]|0;s=r;return b|0}function Fl(e,i){e=e|0;i=i|0;var r=0,n=0,f=0;r=s;s=s+16|0;n=r+4|0;f=r;t[n>>2]=e;t[f>>2]=i;if((t[n>>2]|0)==0|(t[f>>2]|0)==0){cl(138248);s=r;return}else{t[t[f>>2]>>2]=t[t[n>>2]>>2];t[(t[f>>2]|0)+4>>2]=t[(t[n>>2]|0)+4>>2];t[(t[f>>2]|0)+8>>2]=t[(t[n>>2]|0)+8>>2];s=r;return}}function Ol(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0;n=s;s=s+48|0;f=n+36|0;u=n+32|0;a=n+28|0;o=n+24|0;c=n+20|0;l=n+16|0;b=n+12|0;k=n+8|0;h=n+4|0;w=n;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;t[w>>2]=0;if(!((t[u>>2]|0)==0|(t[a>>2]|0)==0)?(t[(t[a>>2]|0)+4>>2]|0)==1:0){t[k>>2]=Eq(0,318)|0;if(!(t[k>>2]|0)){kl(138192);t[f>>2]=-1;d=t[f>>2]|0;s=n;return d|0}t[c>>2]=t[a>>2];while(1){if(!(t[c>>2]|0))break;t[l>>2]=t[(t[c>>2]|0)+48>>2];while(1){if(!(t[l>>2]|0))break;t[b>>2]=wF(t[(t[a>>2]|0)+32>>2]|0,t[a>>2]|0,t[(t[l>>2]|0)+12>>2]|0)|0;do if((t[b>>2]|0)==(t[l>>2]|0)?(Dl(t[l>>2]|0)|0)==0:0){if((t[(t[u>>2]|0)+4>>2]|0)!=0?(dAi[t[(t[u>>2]|0)+4>>2]&511](t[(t[u>>2]|0)+8>>2]|0,t[l>>2]|0,t[a>>2]|0)|0)==0:0)break;t[h>>2]=Cl(t[(t[u>>2]|0)+28>>2]|0,t[l>>2]|0)|0;if(t[o>>2]|0)Pl(t[(t[u>>2]|0)+28>>2]|0,t[l>>2]|0,t[a>>2]|0);if(!(t[h>>2]|0))gq(t[k>>2]|0,t[l>>2]|0)|0;if(!(rs(t[(t[l>>2]|0)+12>>2]|0)|0))t[w>>2]=1}while(0);t[l>>2]=t[t[l>>2]>>2]}t[c>>2]=t[(t[c>>2]|0)+20>>2]}if(!((t[o>>2]|0)==0|(t[w>>2]|0)!=0)?(t[34556]=0,t[34557]=0,t[34558]=0,t[34559]=0,t[34560]=0,t[34561]=0,(Cl(t[(t[u>>2]|0)+28>>2]|0,138224)|0)==0):0)Bl(138224,t[u>>2]|0)|0;Mq(t[k>>2]|0,319,t[u>>2]|0);Fq(t[k>>2]|0);t[f>>2]=0;d=t[f>>2]|0;s=n;return d|0}cl(138152);t[f>>2]=-1;d=t[f>>2]|0;s=n;return d|0}function Al(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0;n=s;s=s+64|0;f=n+48|0;u=n+44|0;a=n+40|0;o=n+36|0;c=n+32|0;l=n+28|0;b=n+24|0;k=n+20|0;h=n+16|0;w=n+12|0;d=n+8|0;v=n+4|0;m=n;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;t[h>>2]=0;t[w>>2]=0;t[d>>2]=0;if(!((t[u>>2]|0)==0|(t[a>>2]|0)==0)?(t[(t[a>>2]|0)+4>>2]|0)==1:0){if((t[(t[u>>2]|0)+32>>2]|0)!=1){cl(137816);t[f>>2]=-1;_=t[f>>2]|0;s=n;return _|0}t[l>>2]=Eq(0,318)|0;if(!(t[l>>2]|0)){kl(137856);t[f>>2]=-1;_=t[f>>2]|0;s=n;return _|0}e:do if(t[(t[u>>2]|0)+36>>2]|0){t[m>>2]=0;while(1){if(!(t[(t[(t[u>>2]|0)+36>>2]|0)+(t[m>>2]<<2)>>2]|0))break e;t[v>>2]=t[(t[(t[u>>2]|0)+36>>2]|0)+(t[m>>2]<<2)>>2];if(!((Xl(t[v>>2]|0,137896)|0)==0?(Xl(t[v>>2]|0,137704)|0)==0:0)){t[v>>2]=0;t[d>>2]=1}t[c>>2]=wF(t[(t[a>>2]|0)+32>>2]|0,t[a>>2]|0,t[v>>2]|0)|0;do if((t[c>>2]|0)!=0?(Dl(t[c>>2]|0)|0)==0:0){if((t[(t[u>>2]|0)+4>>2]|0)!=0?(dAi[t[(t[u>>2]|0)+4>>2]&511](t[(t[u>>2]|0)+8>>2]|0,t[c>>2]|0,t[a>>2]|0)|0)==0:0)break;t[k>>2]=Cl(t[(t[u>>2]|0)+28>>2]|0,t[c>>2]|0)|0;if(t[o>>2]|0)Pl(t[(t[u>>2]|0)+28>>2]|0,t[c>>2]|0,t[a>>2]|0);if(!(t[k>>2]|0))gq(t[l>>2]|0,t[c>>2]|0)|0;if(!(rs(t[(t[c>>2]|0)+12>>2]|0)|0))t[h>>2]=1}while(0);t[m>>2]=(t[m>>2]|0)+1}}while(0);m=t[a>>2]|0;if(t[(t[a>>2]|0)+36>>2]|0)t[c>>2]=t[m+36>>2];else{t[c>>2]=wF(t[m+32>>2]|0,t[a>>2]|0,0)|0;t[w>>2]=1}if((t[c>>2]|0)!=0?(Dl(t[c>>2]|0)|0)==0:0){
	do if(t[o>>2]|0){if((t[(t[u>>2]|0)+4>>2]|0)!=0?(dAi[t[(t[u>>2]|0)+4>>2]&511](t[(t[u>>2]|0)+8>>2]|0,t[c>>2]|0,t[a>>2]|0)|0)==0:0)break;if(!(Il(t[(t[u>>2]|0)+28>>2]|0,t[c>>2]|0,t[u>>2]|0)|0))gq(t[l>>2]|0,t[c>>2]|0)|0}while(0);if(t[o>>2]|0)Pl(t[(t[u>>2]|0)+28>>2]|0,t[c>>2]|0,t[a>>2]|0);if(!(rs(t[(t[c>>2]|0)+12>>2]|0)|0))t[h>>2]=1}t[b>>2]=t[(t[a>>2]|0)+44>>2];while(1){if(!(t[b>>2]|0))break;do if((t[(t[b>>2]|0)+36>>2]|0)!=0?(Dl(t[(t[b>>2]|0)+36>>2]|0)|0)==0:0){if((t[(t[u>>2]|0)+4>>2]|0)!=0?(dAi[t[(t[u>>2]|0)+4>>2]&511](t[(t[u>>2]|0)+8>>2]|0,t[b>>2]|0,t[a>>2]|0)|0)==0:0){p=49;break}t[k>>2]=Il(t[(t[u>>2]|0)+28>>2]|0,t[(t[b>>2]|0)+36>>2]|0,t[u>>2]|0)|0;Pl(t[(t[u>>2]|0)+28>>2]|0,t[(t[b>>2]|0)+36>>2]|0,t[a>>2]|0);if((t[k>>2]|0)==0&(t[o>>2]|0)!=0)gq(t[l>>2]|0,t[(t[b>>2]|0)+36>>2]|0)|0;if(!(rs(t[(t[(t[b>>2]|0)+36>>2]|0)+12>>2]|0)|0))t[h>>2]=1}else p=49;while(0);if((((p|0)==49?(p=0,(t[(t[b>>2]|0)+36>>2]|0)!=0):0)?(rs(t[(t[(t[b>>2]|0)+36>>2]|0)+12>>2]|0)|0)==0:0)?(rs(t[(t[(t[b>>2]|0)+36>>2]|0)+8>>2]|0)|0)==0:0)t[w>>2]=1;t[b>>2]=t[(t[b>>2]|0)+24>>2]}if((t[o>>2]|0)!=0&(t[w>>2]|0)!=0^1|(t[h>>2]|0)!=0|(t[d>>2]|0)!=0){if((((t[o>>2]|0)==0|(t[h>>2]|0)!=0)^1)&(t[d>>2]|0)!=0?(t[34484]=0,t[34485]=0,t[34486]=0,t[34487]=0,t[34488]=0,t[34489]=0,(Cl(t[(t[u>>2]|0)+28>>2]|0,137936)|0)==0):0)Bl(137936,t[u>>2]|0)|0}else{t[34478]=0;t[34479]=0;t[34480]=0;t[34481]=0;t[34482]=0;t[34483]=0;t[k>>2]=Il(t[(t[u>>2]|0)+28>>2]|0,137912,t[u>>2]|0)|0;if(!(t[k>>2]|0))Bl(137912,t[u>>2]|0)|0}Mq(t[l>>2]|0,319,t[u>>2]|0);Fq(t[l>>2]|0);t[f>>2]=0;_=t[f>>2]|0;s=n;return _|0}cl(137816);t[f>>2]=-1;_=t[f>>2]|0;s=n;return _|0}function Ml(e){e=e|0;var i=0,r=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if(!(t[r>>2]|0)){cl(137784);s=i;return}else{t[(t[r>>2]|0)+4>>2]=t[(t[r>>2]|0)+8>>2];t[(t[r>>2]|0)+8>>2]=t[t[r>>2]>>2];s=i;return}}function Rl(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0;n=s;s=s+48|0;f=n+44|0;u=n+40|0;a=n+36|0;o=n+32|0;c=n+28|0;l=n+24|0;b=n+20|0;k=n+16|0;h=n+12|0;w=n+8|0;d=n+4|0;v=n;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;t[b>>2]=0;t[k>>2]=0;t[h>>2]=0;t[w>>2]=0;if(!((t[u>>2]|0)==0|(t[a>>2]|0)==0)?(t[(t[a>>2]|0)+4>>2]|0)==1:0){t[l>>2]=Eq(0,320)|0;if(!(t[l>>2]|0)){kl(137328);t[f>>2]=-1;m=t[f>>2]|0;s=n;return m|0}r=t[(t[u>>2]|0)+32>>2]|0;e:do if((r|0)==2){t[c>>2]=t[(t[a>>2]|0)+44>>2];while(1){_=(t[o>>2]|0)!=0;if(!(t[c>>2]|0))break;do if(_?(xl(t[c>>2]|0)|0)!=0:0){t[v>>2]=0;if((t[v>>2]|0)==0&(t[h>>2]|0)==0?(Xl(t[(t[c>>2]|0)+8>>2]|0,137360)|0)!=0:0){t[h>>2]=t[c>>2];t[v>>2]=1}if((t[v>>2]|0)==0&(t[w>>2]|0)==0?(Xl(t[(t[c>>2]|0)+8>>2]|0,137368)|0)!=0:0){t[w>>2]=t[c>>2];t[v>>2]=1}if((t[v>>2]|0)==0&(t[k>>2]|0)==0?(Xl(t[(t[c>>2]|0)+8>>2]|0,137376)|0)!=0:0){t[k>>2]=t[c>>2];t[v>>2]=1}if(!(t[v>>2]|0)){if((t[(t[u>>2]|0)+4>>2]|0)!=0?(dAi[t[(t[u>>2]|0)+4>>2]&511](t[(t[u>>2]|0)+8>>2]|0,t[c>>2]|0,t[a>>2]|0)|0)==0:0)break;gq(t[l>>2]|0,t[c>>2]|0)|0}}else p=36;while(0);do if((p|0)==36){p=0;if((t[(t[u>>2]|0)+4>>2]|0)!=0?(dAi[t[(t[u>>2]|0)+4>>2]&511](t[(t[u>>2]|0)+8>>2]|0,t[c>>2]|0,t[a>>2]|0)|0)==0:0)break;gq(t[l>>2]|0,t[c>>2]|0)|0}while(0);t[c>>2]=t[(t[c>>2]|0)+24>>2]}if(_){if(!(t[h>>2]|0))t[h>>2]=Ul(t[u>>2]|0,t[(t[a>>2]|0)+20>>2]|0,137360,137384)|0;if(t[h>>2]|0)gq(t[l>>2]|0,t[h>>2]|0)|0;if(!(t[w>>2]|0))t[w>>2]=Ul(t[u>>2]|0,t[(t[a>>2]|0)+20>>2]|0,137368,137384)|0;if(t[w>>2]|0)gq(t[l>>2]|0,t[w>>2]|0)|0;if(!(t[k>>2]|0))t[k>>2]=Ul(t[u>>2]|0,t[(t[a>>2]|0)+20>>2]|0,137376,137384)|0;if((t[k>>2]|0)!=0?(t[k>>2]=zl(t[u>>2]|0,t[k>>2]|0)|0,(t[k>>2]|0)!=0):0){gq(t[l>>2]|0,t[k>>2]|0)|0;t[(t[k>>2]|0)+24>>2]=t[b>>2];t[b>>2]=t[k>>2]}}}else if(!r){t[c>>2]=t[(t[a>>2]|0)+44>>2];while(1){if(!(t[c>>2]|0))break;if(!((t[(t[u>>2]|0)+4>>2]|0)!=0?(dAi[t[(t[u>>2]|0)+4>>2]&511](t[(t[u>>2]|0)+8>>2]|0,t[c>>2]|0,t[a>>2]|0)|0)==0:0))gq(t[l>>2]|0,t[c>>2]|0)|0;t[c>>2]=t[(t[c>>2]|0)+24>>2]}if((((t[o>>2]|0)!=0?(t[(t[a>>2]|0)+20>>2]|0)!=0:0)?(t[(t[u>>2]|0)+4>>2]|0)!=0:0)?(dAi[t[(t[u>>2]|0)+4>>2]&511](t[(t[u>>2]|0)+8>>2]|0,t[(t[a>>2]|0)+20>>2]|0,t[(t[(t[a>>2]|0)+20>>2]|0)+20>>2]|0)|0)==0:0){t[d>>2]=t[(t[a>>2]|0)+20>>2];while(1){if(!(t[d>>2]|0))break e;t[c>>2]=t[(t[d>>2]|0)+44>>2];while(1){if(!(t[c>>2]|0))break;if((xl(t[c>>2]|0)|0)!=0?(Sq(t[l>>2]|0,t[c>>2]|0)|0)==0:0)gq(t[l>>2]|0,t[c>>2]|0)|0;t[c>>2]=t[(t[c>>2]|0)+24>>2]}t[d>>2]=t[(t[d>>2]|0)+20>>2]}}}else if((r|0)==1){t[c>>2]=t[(t[a>>2]|0)+44>>2];while(1){if(!(t[c>>2]|0))break e;if(!((t[(t[u>>2]|0)+4>>2]|0)!=0?(dAi[t[(t[u>>2]|0)+4>>2]&511](t[(t[u>>2]|0)+8>>2]|0,t[c>>2]|0,t[a>>2]|0)|0)==0:0))gq(t[l>>2]|0,t[c>>2]|0)|0;t[c>>2]=t[(t[c>>2]|0)+24>>2]}}while(0);Mq(t[l>>2]|0,321,t[u>>2]|0);dy(t[b>>2]|0);Fq(t[l>>2]|0);t[f>>2]=0;m=t[f>>2]|0;s=n;return m|0}cl(137216);t[f>>2]=-1;m=t[f>>2]|0;s=n;return m|0}function Nl(e,i){e=e|0;i=i|0;var r=0,n=0,f=0;r=s;s=s+16|0;n=r+4|0;f=r;t[n>>2]=e;t[f>>2]=i;if((t[n>>2]|0)==0|(t[f>>2]|0)==0){cl(137296);s=r;return}else{t[t[n>>2]>>2]=t[t[f>>2]>>2];t[(t[n>>2]|0)+4>>2]=t[(t[f>>2]|0)+4>>2];t[(t[n>>2]|0)+8>>2]=t[(t[f>>2]|0)+8>>2];s=r;return}}function Tl(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i;n=i+4|0;t[n>>2]=e;t[r>>2]=t[n>>2];cp(0,0,0,0,0,21,1955,2,0,0,0,0,0,0,0,138312,r);s=i;return}function Ll(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0;r=s;s=s+16|0;n=r+8|0;f=r+4|0;u=r;t[f>>2]=e;t[u>>2]=i;do if((t[f>>2]|0)!=(t[u>>2]|0)){if(!(t[f>>2]|0)){t[n>>2]=-1;break}if(!(t[u>>2]|0)){t[n>>2]=1;break}else{t[n>>2]=Kl(t[(t[f>>2]|0)+12>>2]|0,t[(t[u>>2]|0)+12>>2]|0)|0;break}}else t[n>>2]=0;while(0);s=r;return t[n>>2]|0}function Dl(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if((t[r>>2]|0)!=0?(Xl(t[(t[r>>2]|0)+12>>2]|0,137776)|0)!=0:0)n=(Xl(t[(t[r>>2]|0)+8>>2]|0,137384)|0)!=0;else n=0;s=i;return n&1|0}function Cl(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0;r=s;s=s+48|0;n=r+32|0;f=r+28|0;u=r+24|0;a=r+20|0;o=r+16|0;c=r+12|0;l=r+8|0;b=r+4|0;k=r;t[f>>2]=e;t[u>>2]=i;if(!(t[f>>2]|0)){cl(138112);t[n>>2]=0;h=t[n>>2]|0;s=r;return h|0}if((t[u>>2]|0)!=0?(t[(t[u>>2]|0)+12>>2]|0)!=0:0)w=t[(t[u>>2]|0)+12>>2]|0;else w=137704;t[o>>2]=w;if((t[u>>2]|0)!=0?(t[(t[u>>2]|0)+8>>2]|0)!=0:0)d=t[(t[u>>2]|0)+8>>2]|0;else d=137704;t[c>>2]=d;if(Vl(t[o>>2]|0,0)|0)v=(Vl(t[c>>2]|0,0)|0)!=0;else v=0;t[l>>2]=v&1;e:do if(t[(t[f>>2]|0)+16>>2]|0){if(t[l>>2]|0)m=0;else m=t[(t[f>>2]|0)+4>>2]|0;t[b>>2]=m;t[a>>2]=(t[t[f>>2]>>2]|0)-1;while(1){if((t[a>>2]|0)<(t[b>>2]|0))break e;t[k>>2]=t[(t[(t[f>>2]|0)+16>>2]|0)+(t[a>>2]<<2)>>2];if(t[k>>2]|0)_=t[(t[k>>2]|0)+12>>2]|0;else _=0;if(Vl(t[o>>2]|0,_)|0)break;t[a>>2]=(t[a>>2]|0)+-1}if(t[k>>2]|0)p=t[(t[k>>2]|0)+8>>2]|0;else p=0;t[n>>2]=Vl(t[c>>2]|0,p)|0;h=t[n>>2]|0;s=r;return h|0}while(0);t[n>>2]=t[l>>2];h=t[n>>2]|0;s=r;return h|0}function Pl(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,l=0;n=s;s=s+32|0;f=n+16|0;u=n+12|0;a=n+8|0;o=n+4|0;c=n;t[f>>2]=e;t[u>>2]=i;t[a>>2]=r;do if(t[f>>2]|0){if((t[(t[f>>2]|0)+16>>2]|0)==0?(t[(t[f>>2]|0)+20>>2]|0)!=0:0)break;if((t[(t[f>>2]|0)+16>>2]|0)!=0?(t[(t[f>>2]|0)+20>>2]|0)==0:0)break;do if((t[(t[f>>2]|0)+16>>2]|0)==0?(t[(t[f>>2]|0)+20>>2]|0)==0:0){r=gAi[t[135744>>2]&511](64)|0;t[(t[f>>2]|0)+16>>2]=r;r=gAi[t[135744>>2]&511](64)|0;t[(t[f>>2]|0)+20>>2]=r;if((t[(t[f>>2]|0)+16>>2]|0)!=0?(t[(t[f>>2]|0)+20>>2]|0)!=0:0){r=(t[(t[f>>2]|0)+16>>2]|0)+0|0;i=r+64|0;do{t[r>>2]=0;r=r+4|0}while((r|0)<(i|0));r=(t[(t[f>>2]|0)+20>>2]|0)+0|0;i=r+64|0;do{t[r>>2]=0;r=r+4|0}while((r|0)<(i|0));t[(t[f>>2]|0)+12>>2]=16;break}dl(138088);s=n;return}else l=13;while(0);do if((l|0)==13?(t[(t[f>>2]|0)+12>>2]|0)==(t[t[f>>2]>>2]|0):0){t[c>>2]=t[(t[f>>2]|0)+12>>2]<<1;t[o>>2]=MAi[t[135760>>2]&511](t[(t[f>>2]|0)+16>>2]|0,t[c>>2]<<2)|0;if(!(t[o>>2]|0)){dl(138088);s=n;return}t[(t[f>>2]|0)+16>>2]=t[o>>2];t[o>>2]=MAi[t[135760>>2]&511](t[(t[f>>2]|0)+20>>2]|0,t[c>>2]<<2)|0;if(t[o>>2]|0){t[(t[f>>2]|0)+20>>2]=t[o>>2];t[(t[f>>2]|0)+12>>2]=t[c>>2];break}dl(138088);s=n;return}while(0);t[(t[(t[f>>2]|0)+16>>2]|0)+(t[t[f>>2]>>2]<<2)>>2]=t[u>>2];t[(t[(t[f>>2]|0)+20>>2]|0)+(t[t[f>>2]>>2]<<2)>>2]=t[a>>2];r=t[f>>2]|0;t[r>>2]=(t[r>>2]|0)+1;s=n;return}while(0);cl(138056);s=n;return}function Bl(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0;r=s;s=s+16|0;n=r+8|0;f=r+4|0;u=r;t[f>>2]=e;t[u>>2]=i;if((t[f>>2]|0)==0|(t[u>>2]|0)==0){cl(137960);t[n>>2]=0;a=t[n>>2]|0;s=r;return a|0}i=t[(t[u>>2]|0)+16>>2]|0;if(t[(t[f>>2]|0)+12>>2]|0){iA(i,137984)|0;iA(t[(t[u>>2]|0)+16>>2]|0,t[(t[f>>2]|0)+12>>2]|0)|0;iA(t[(t[u>>2]|0)+16>>2]|0,137992)|0}else iA(i,138e3)|0;i=t[(t[u>>2]|0)+16>>2]|0;if(t[(t[f>>2]|0)+8>>2]|0)xs(t[i+16>>2]|0,t[(t[f>>2]|0)+8>>2]|0)|0;else iA(i,138008)|0;t[n>>2]=1;a=t[n>>2]|0;s=r;return a|0}function Il(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0,S=0;n=s;s=s+48|0;f=n+36|0;u=n+32|0;a=n+28|0;o=n+24|0;c=n+20|0;l=n+16|0;b=n+12|0;k=n+8|0;h=n+4|0;w=n;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;if(!(t[u>>2]|0)){cl(138016);t[f>>2]=0;d=t[f>>2]|0;s=n;return d|0}if((t[a>>2]|0)!=0?(t[(t[a>>2]|0)+12>>2]|0)!=0:0)v=t[(t[a>>2]|0)+12>>2]|0;else v=137704;t[l>>2]=v;if((t[a>>2]|0)!=0?(t[(t[a>>2]|0)+8>>2]|0)!=0:0)m=t[(t[a>>2]|0)+8>>2]|0;else m=137704;t[b>>2]=m;if(Vl(t[l>>2]|0,0)|0)_=(Vl(t[b>>2]|0,0)|0)!=0;else _=0;t[k>>2]=_&1;e:do if(t[(t[u>>2]|0)+16>>2]|0){t[h>>2]=0;t[c>>2]=(t[t[u>>2]>>2]|0)-1;while(1){if((t[c>>2]|0)<(t[h>>2]|0))break e;t[w>>2]=t[(t[(t[u>>2]|0)+16>>2]|0)+(t[c>>2]<<2)>>2];if(t[w>>2]|0)p=t[(t[w>>2]|0)+12>>2]|0;else p=0;if(Vl(t[l>>2]|0,p)|0)break;t[c>>2]=(t[c>>2]|0)+-1}if(t[w>>2]|0)E=t[(t[w>>2]|0)+8>>2]|0;else E=0;if(!(Vl(t[b>>2]|0,E)|0)){t[f>>2]=0;d=t[f>>2]|0;s=n;return d|0}if(t[(t[o>>2]|0)+4>>2]|0)S=dAi[t[(t[o>>2]|0)+4>>2]&511](t[(t[o>>2]|0)+8>>2]|0,t[w>>2]|0,t[(t[(t[u>>2]|0)+20>>2]|0)+(t[c>>2]<<2)>>2]|0)|0;else S=1;t[f>>2]=S;d=t[f>>2]|0;s=n;return d|0}while(0);t[f>>2]=t[k>>2];d=t[f>>2]|0;s=n;return d|0}function Hl(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0;r=s;s=s+16|0;n=r+12|0;f=r+8|0;u=r+4|0;a=r;t[f>>2]=e;t[u>>2]=i;t[a>>2]=0;do if((t[f>>2]|0)==(t[u>>2]|0))t[n>>2]=0;else{if(!(t[f>>2]|0)){t[n>>2]=-1;break}if(!(t[u>>2]|0)){t[n>>2]=1;break}i=t[f>>2]|0;if((t[(t[f>>2]|0)+36>>2]|0)==(t[(t[u>>2]|0)+36>>2]|0)){t[n>>2]=Kl(t[i+8>>2]|0,t[(t[u>>2]|0)+8>>2]|0)|0;break}if(!(t[i+36>>2]|0)){t[n>>2]=-1;break}if(!(t[(t[u>>2]|0)+36>>2]|0)){t[n>>2]=1;break}if(!(t[(t[(t[f>>2]|0)+36>>2]|0)+12>>2]|0)){t[n>>2]=-1;break}if(!(t[(t[(t[u>>2]|0)+36>>2]|0)+12>>2]|0)){t[n>>2]=1;break}t[a>>2]=Kl(t[(t[(t[f>>2]|0)+36>>2]|0)+8>>2]|0,t[(t[(t[u>>2]|0)+36>>2]|0)+8>>2]|0)|0;if(!(t[a>>2]|0))t[a>>2]=Kl(t[(t[f>>2]|0)+8>>2]|0,t[(t[u>>2]|0)+8>>2]|0)|0;t[n>>2]=t[a>>2]}while(0);s=r;return t[n>>2]|0}function xl(e){e=e|0;var i=0,r=0,n=0,f=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if(!(t[(t[r>>2]|0)+36>>2]|0)){n=0;f=n&1;s=i;return f|0}n=(Dl(t[(t[r>>2]|0)+36>>2]|0)|0)!=0;f=n&1;s=i;return f|0}function Ul(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0;f=s;s=s+32|0;u=f+20|0;a=f+16|0;o=f+12|0;c=f+8|0;l=f+4|0;b=f;t[a>>2]=e;t[o>>2]=i;t[c>>2]=r;t[l>>2]=n;while(1){if(!(t[o>>2]|0)){k=9;break}if(t[(t[a>>2]|0)+4>>2]|0)h=dAi[t[(t[a>>2]|0)+4>>2]&511](t[(t[a>>2]|0)+8>>2]|0,t[o>>2]|0,t[(t[o>>2]|0)+20>>2]|0)|0;else h=1;if(!((h|0)!=0^1)){k=9;break}t[b>>2]=xy(t[o>>2]|0,t[c>>2]|0,t[l>>2]|0)|0;if(t[b>>2]|0){k=7;break}t[o>>2]=t[(t[o>>2]|0)+20>>2]}if((k|0)==7){t[u>>2]=t[b>>2];w=t[u>>2]|0;s=f;return w|0}else if((k|0)==9){t[u>>2]=0;w=t[u>>2]|0;s=f;return w|0}return 0}function zl(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0;r=s;s=s+48|0;n=r+32|0;f=r+28|0;a=r+24|0;o=r+20|0;c=r+16|0;l=r+12|0;b=r+8|0;k=r+4|0;h=r;t[f>>2]=e;t[a>>2]=i;t[o>>2]=0;if(!((t[f>>2]|0)==0|(t[a>>2]|0)==0)?(t[(t[a>>2]|0)+20>>2]|0)!=0:0){t[o>>2]=sy(t[t[f>>2]>>2]|0,t[(t[a>>2]|0)+12>>2]|0,1)|0;if(!(t[o>>2]|0)){kl(137528);t[n>>2]=0;w=t[n>>2]|0;s=r;return w|0}t[c>>2]=t[(t[(t[a>>2]|0)+20>>2]|0)+20>>2];while(1){if(!(t[c>>2]|0)){d=23;break}if(t[(t[f>>2]|0)+4>>2]|0)v=dAi[t[(t[f>>2]|0)+4>>2]&511](t[(t[f>>2]|0)+8>>2]|0,t[c>>2]|0,t[(t[c>>2]|0)+20>>2]|0)|0;else v=1;if(!((v|0)!=0^1)){d=23;break}t[l>>2]=xy(t[c>>2]|0,137376,137384)|0;if(t[l>>2]|0){t[b>>2]=sy(t[t[f>>2]>>2]|0,t[(t[l>>2]|0)+12>>2]|0,1)|0;if(!(t[b>>2]|0)){d=13;break}t[h>>2]=rs(t[b>>2]|0)|0;if((t[h>>2]|0)>1?(u[(t[b>>2]|0)+((t[h>>2]|0)-2)>>0]|0|0)==46:0){t[k>>2]=us(t[b>>2]|0,137584)|0;if(!(t[k>>2]|0)){d=17;break}t[b>>2]=t[k>>2]}t[k>>2]=GA(t[o>>2]|0,t[b>>2]|0)|0;i=(t[k>>2]|0)==0;pAi[t[135736>>2]&511](t[b>>2]|0);pAi[t[135736>>2]&511](t[o>>2]|0);if(i){d=20;break}t[o>>2]=t[k>>2]}t[c>>2]=t[(t[c>>2]|0)+20>>2]}if((d|0)==13){pAi[t[135736>>2]&511](t[o>>2]|0);kl(137528);t[n>>2]=0;w=t[n>>2]|0;s=r;return w|0}else if((d|0)==17){pAi[t[135736>>2]&511](t[b>>2]|0);pAi[t[135736>>2]&511](t[o>>2]|0);kl(137592);t[n>>2]=0;w=t[n>>2]|0;s=r;return w|0}else if((d|0)==20){kl(137648);t[n>>2]=0;w=t[n>>2]|0;s=r;return w|0}else if((d|0)==23){if((t[o>>2]|0)!=0?(Xl(t[o>>2]|0,137704)|0)==0:0){t[l>>2]=ky(0,t[(t[a>>2]|0)+36>>2]|0,137376,t[o>>2]|0)|0;a=(t[l>>2]|0)==0;pAi[t[135736>>2]&511](t[o>>2]|0);if(a){kl(137712);t[n>>2]=0;w=t[n>>2]|0;s=r;return w|0}else{t[n>>2]=t[l>>2];w=t[n>>2]|0;s=r;return w|0}}pAi[t[135736>>2]&511](t[o>>2]|0);t[n>>2]=0;w=t[n>>2]|0;s=r;return w|0}}cl(137496);t[n>>2]=0;w=t[n>>2]|0;s=r;return w|0}function jl(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0;r=s;s=s+32|0;n=r+16|0;f=r+12|0;u=r+8|0;a=r+4|0;o=r;t[f>>2]=e;t[u>>2]=i;if((t[f>>2]|0)==0|(t[u>>2]|0)==0){cl(137424);t[n>>2]=0;c=t[n>>2]|0;s=r;return c|0}iA(t[(t[u>>2]|0)+16>>2]|0,136792)|0;if((t[(t[f>>2]|0)+36>>2]|0)!=0?(rs(t[(t[(t[f>>2]|0)+36>>2]|0)+12>>2]|0)|0)>0:0){iA(t[(t[u>>2]|0)+16>>2]|0,t[(t[(t[f>>2]|0)+36>>2]|0)+12>>2]|0)|0;iA(t[(t[u>>2]|0)+16>>2]|0,137176)|0}iA(t[(t[u>>2]|0)+16>>2]|0,t[(t[f>>2]|0)+8>>2]|0)|0;iA(t[(t[u>>2]|0)+16>>2]|0,137448)|0;t[a>>2]=sy(t[t[u>>2]>>2]|0,t[(t[f>>2]|0)+12>>2]|0,1)|0;do if(t[a>>2]|0){t[o>>2]=El(t[a>>2]|0,0)|0;pAi[t[135736>>2]&511](t[a>>2]|0);if(t[o>>2]|0){iA(t[(t[u>>2]|0)+16>>2]|0,t[o>>2]|0)|0;pAi[t[135736>>2]&511](t[o>>2]|0);break}kl(137456);t[n>>2]=0;c=t[n>>2]|0;s=r;return c|0}while(0);iA(t[(t[u>>2]|0)+16>>2]|0,137488)|0;t[n>>2]=1;c=t[n>>2]|0;s=r;return c|0}function Vl(e,i){e=e|0;i=i|0;var r=0,f=0,a=0,o=0,c=0;r=s;s=s+16|0;f=r+8|0;a=r+4|0;o=r;t[a>>2]=e;t[o>>2]=i;do if((t[a>>2]|0)!=(t[o>>2]|0)){i=t[o>>2]|0;if(!(t[a>>2]|0)){t[f>>2]=(u[i>>0]|0)==0&1;break}if(!i){t[f>>2]=(u[t[a>>2]>>0]|0)==0&1;break}while(1){i=t[a>>2]|0;t[a>>2]=i+1;if((u[i>>0]|0)!=(u[t[o>>2]>>0]|0)){c=8;break}i=t[o>>2]|0;t[o>>2]=i+1;if(!(n[i>>0]|0)){c=10;break}}if((c|0)==8){t[f>>2]=0;break}else if((c|0)==10){t[f>>2]=1;break}}else t[f>>2]=1;while(0);s=r;return t[f>>2]|0}function ql(e,i){e=e|0;i=i|0;var r=0,f=0,u=0,a=0,o=0,c=0;r=s;s=s+16|0;f=r+12|0;u=r+8|0;a=r+4|0;o=r;t[u>>2]=e;t[a>>2]=i;if((t[u>>2]|0)==0|(t[a>>2]|0)<0){t[f>>2]=0;c=t[f>>2]|0;s=r;return c|0}t[o>>2]=gAi[t[135752>>2]&511]((t[a>>2]|0)+1|0)|0;if(!(t[o>>2]|0)){Sp(0,0);t[f>>2]=0;c=t[f>>2]|0;s=r;return c|0}else{YY(t[o>>2]|0,t[u>>2]|0,t[a>>2]|0)|0;n[(t[o>>2]|0)+(t[a>>2]|0)>>0]=0;t[f>>2]=t[o>>2];c=t[f>>2]|0;s=r;return c|0}return 0}function Yl(e){e=e|0;var i=0,r=0,n=0,f=0,a=0;i=s;s=s+16|0;r=i+8|0;n=i+4|0;f=i;t[n>>2]=e;t[f>>2]=t[n>>2];if(!(t[n>>2]|0)){t[r>>2]=0;a=t[r>>2]|0;s=i;return a|0}while(1){if(!(u[t[f>>2]>>0]|0))break;t[f>>2]=(t[f>>2]|0)+1}t[r>>2]=ql(t[n>>2]|0,(t[f>>2]|0)-(t[n>>2]|0)|0)|0;a=t[r>>2]|0;s=i;return a|0}function Gl(e,i){e=e|0;i=i|0;var r=0,f=0,a=0,o=0,c=0,l=0,b=0,k=0;r=s;s=s+32|0;f=r+16|0;a=r+12|0;o=r+8|0;c=r+4|0;l=r;t[a>>2]=e;t[o>>2]=i;if((t[a>>2]|0)==0|(t[o>>2]|0)<0){t[f>>2]=0;b=t[f>>2]|0;s=r;return b|0}t[l>>2]=gAi[t[135752>>2]&511]((t[o>>2]|0)+1|0)|0;if(!(t[l>>2]|0)){Sp(0,0);t[f>>2]=0;b=t[f>>2]|0;s=r;return b|0}t[c>>2]=0;while(1){if((t[c>>2]|0)>=(t[o>>2]|0)){k=10;break}n[(t[l>>2]|0)+(t[c>>2]|0)>>0]=n[(t[a>>2]|0)+(t[c>>2]|0)>>0]|0;if(!(u[(t[l>>2]|0)+(t[c>>2]|0)>>0]|0)){k=8;break}t[c>>2]=(t[c>>2]|0)+1}if((k|0)==8){t[f>>2]=t[l>>2];b=t[f>>2]|0;s=r;return b|0}else if((k|0)==10){n[(t[l>>2]|0)+(t[o>>2]|0)>>0]=0;t[f>>2]=t[l>>2];b=t[f>>2]|0;s=r;return b|0}return 0}function Wl(e){e=e|0;var i=0,r=0,f=0,u=0,a=0;i=s;s=s+16|0;r=i+8|0;f=i+4|0;u=i;t[f>>2]=e;t[u>>2]=t[f>>2];if(!(t[f>>2]|0)){t[r>>2]=0;a=t[r>>2]|0;s=i;return a|0}while(1){if(!(n[t[u>>2]>>0]|0))break;t[u>>2]=(t[u>>2]|0)+1}t[r>>2]=Gl(t[f>>2]|0,(t[u>>2]|0)-(t[f>>2]|0)|0)|0;a=t[r>>2]|0;s=i;return a|0}function Kl(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,a=0,o=0,c=0;r=s;s=s+16|0;n=r+12|0;f=r+8|0;a=r+4|0;o=r;t[f>>2]=e;t[a>>2]=i;do if((t[f>>2]|0)!=(t[a>>2]|0)){if(!(t[f>>2]|0)){t[n>>2]=-1;break}if(!(t[a>>2]|0)){t[n>>2]=1;break}while(1){i=t[f>>2]|0;t[f>>2]=i+1;t[o>>2]=(u[i>>0]|0)-(u[t[a>>2]>>0]|0);if(t[o>>2]|0){c=8;break}i=t[a>>2]|0;t[a>>2]=i+1;if(!(u[i>>0]|0)){c=10;break}}if((c|0)==8){t[n>>2]=t[o>>2];break}else if((c|0)==10){t[n>>2]=0;break}}else t[n>>2]=0;while(0);s=r;return t[n>>2]|0}function Xl(e,i){e=e|0;i=i|0;var r=0,f=0,a=0,o=0,c=0;r=s;s=s+16|0;f=r+8|0;a=r+4|0;o=r;t[a>>2]=e;t[o>>2]=i;do if((t[a>>2]|0)!=(t[o>>2]|0)){if(!(t[a>>2]|0)){t[f>>2]=0;break}if(!(t[o>>2]|0)){t[f>>2]=0;break}while(1){i=t[a>>2]|0;t[a>>2]=i+1;if((u[i>>0]|0)!=(u[t[o>>2]>>0]|0)){c=8;break}i=t[o>>2]|0;t[o>>2]=i+1;if(!(n[i>>0]|0)){c=10;break}}if((c|0)==8){t[f>>2]=0;break}else if((c|0)==10){t[f>>2]=1;break}}else t[f>>2]=1;while(0);s=r;return t[f>>2]|0}function Zl(e,i,r){e=e|0;i=i|0;r=r|0;var f=0,a=0,o=0,c=0,l=0,b=0;f=s;s=s+16|0;a=f+12|0;o=f+8|0;c=f+4|0;l=f;t[o>>2]=e;t[c>>2]=i;t[l>>2]=r;r=t[c>>2]|0;do if(t[o>>2]|0){if(!r){t[a>>2]=0;break}if(!(t[l>>2]|0)){t[a>>2]=0;break}do{i=t[o>>2]|0;t[o>>2]=i+1;if((u[i>>0]|0)!=(u[t[l>>2]>>0]|0)){b=8;break}i=t[l>>2]|0;t[l>>2]=i+1;if(!(u[i>>0]|0))break}while((u[t[o>>2]>>0]|0)!=0);if((b|0)==8){t[a>>2]=0;break}i=t[l>>2]|0;t[l>>2]=i+1;if((u[i>>0]|0)!=58){t[a>>2]=0;break}while(1){i=t[c>>2]|0;t[c>>2]=i+1;if((u[i>>0]|0)!=(u[t[l>>2]>>0]|0)){b=14;break}i=t[l>>2]|0;t[l>>2]=i+1;if(!(n[i>>0]|0)){b=16;break}}if((b|0)==14){t[a>>2]=0;break}else if((b|0)==16){t[a>>2]=1;break}}else t[a>>2]=Xl(r,t[l>>2]|0)|0;while(0);s=f;return t[a>>2]|0}function Jl(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0;n=s;s=s+32|0;f=n+16|0;u=n+12|0;a=n+8|0;o=n+4|0;c=n;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;do if((t[o>>2]|0)>0){if((t[u>>2]|0)==(t[a>>2]|0)){t[f>>2]=0;break}if(!(t[u>>2]|0)){t[f>>2]=-1;break}if(!(t[a>>2]|0)){t[f>>2]=1;break}else{t[c>>2]=RY(t[u>>2]|0,t[a>>2]|0,t[o>>2]|0)|0;t[f>>2]=t[c>>2];break}}else t[f>>2]=0;while(0);s=n;return t[f>>2]|0}function Ql(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,a=0,o=0,c=0;r=s;s=s+16|0;n=r+12|0;f=r+8|0;a=r+4|0;o=r;t[f>>2]=e;t[a>>2]=i;do if((t[f>>2]|0)!=(t[a>>2]|0)){if(!(t[f>>2]|0)){t[n>>2]=-1;break}if(!(t[a>>2]|0)){t[n>>2]=1;break}while(1){i=t[f>>2]|0;t[f>>2]=i+1;t[o>>2]=(u[138656+(u[i>>0]|0)>>0]|0)-(u[138656+(u[t[a>>2]>>0]|0)>>0]|0);if(t[o>>2]|0){c=8;break}i=t[a>>2]|0;t[a>>2]=i+1;if(!(u[i>>0]|0)){c=10;break}}if((c|0)==8){t[n>>2]=t[o>>2];break}else if((c|0)==10){t[n>>2]=0;break}}else t[n>>2]=0;while(0);s=r;return t[n>>2]|0}function $l(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,a=0,o=0,c=0,l=0,b=0;n=s;s=s+32|0;f=n+16|0;a=n+12|0;o=n+8|0;c=n+4|0;l=n;t[a>>2]=e;t[o>>2]=i;t[c>>2]=r;do if((t[c>>2]|0)>0){if((t[a>>2]|0)==(t[o>>2]|0)){t[f>>2]=0;break}if(!(t[a>>2]|0)){t[f>>2]=-1;break}if(!(t[o>>2]|0)){t[f>>2]=1;break}while(1){r=t[a>>2]|0;t[a>>2]=r+1;t[l>>2]=(u[138656+(u[r>>0]|0)>>0]|0)-(u[138656+(u[t[o>>2]>>0]|0)>>0]|0);if(t[l>>2]|0){b=11;break}r=(t[c>>2]|0)+-1|0;t[c>>2]=r;if(!r){b=11;break}r=t[o>>2]|0;t[o>>2]=r+1;if(!(u[r>>0]|0)){b=13;break}}if((b|0)==11){t[f>>2]=t[l>>2];break}else if((b|0)==13){t[f>>2]=0;break}}else t[f>>2]=0;while(0);s=n;return t[f>>2]|0}function es(e,i){e=e|0;i=i|0;var r=0,f=0,a=0,o=0,c=0,l=0;r=s;s=s+16|0;f=r+4|0;a=r;o=r+8|0;t[a>>2]=e;n[o>>0]=i;do if(t[a>>2]|0){while(1){if(!(u[t[a>>2]>>0]|0)){c=7;break}l=t[a>>2]|0;if((u[t[a>>2]>>0]|0|0)==(u[o>>0]|0|0)){c=5;break}t[a>>2]=l+1}if((c|0)==5){t[f>>2]=l;break}else if((c|0)==7){t[f>>2]=0;break}}else t[f>>2]=0;while(0);s=r;return t[f>>2]|0}function is(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,a=0,o=0,c=0;r=s;s=s+16|0;n=r+12|0;f=r+8|0;a=r+4|0;o=r;t[f>>2]=e;t[a>>2]=i;do if(t[f>>2]|0){if(!(t[a>>2]|0)){t[n>>2]=0;break}t[o>>2]=rs(t[a>>2]|0)|0;if(!(t[o>>2]|0)){t[n>>2]=t[f>>2];break}while(1){if(!(u[t[f>>2]>>0]|0)){c=12;break}if((u[t[f>>2]>>0]|0|0)==(u[t[a>>2]>>0]|0|0)?(Jl(t[f>>2]|0,t[a>>2]|0,t[o>>2]|0)|0)==0:0){c=10;break}t[f>>2]=(t[f>>2]|0)+1}if((c|0)==10){t[n>>2]=t[f>>2];break}else if((c|0)==12){t[n>>2]=0;break}}else t[n>>2]=0;while(0);s=r;return t[n>>2]|0}function rs(e){e=e|0;var i=0,r=0,n=0,f=0,a=0;i=s;s=s+16|0;r=i+8|0;n=i+4|0;f=i;t[n>>2]=e;t[f>>2]=0;if(!(t[n>>2]|0)){t[r>>2]=0;a=t[r>>2]|0;s=i;return a|0}while(1){if(!(u[t[n>>2]>>0]|0))break;t[n>>2]=(t[n>>2]|0)+1;t[f>>2]=(t[f>>2]|0)+1}t[r>>2]=t[f>>2];a=t[r>>2]|0;s=i;return a|0}function ns(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,a=0,o=0,c=0;r=s;s=s+16|0;n=r+12|0;f=r+8|0;a=r+4|0;o=r;t[f>>2]=e;t[a>>2]=i;do if(t[f>>2]|0){if(!(t[a>>2]|0)){t[n>>2]=0;break}t[o>>2]=rs(t[a>>2]|0)|0;if(!(t[o>>2]|0)){t[n>>2]=t[f>>2];break}while(1){if(!(u[t[f>>2]>>0]|0)){c=12;break}if((u[138656+(u[t[f>>2]>>0]|0)>>0]|0|0)==(u[138656+(u[t[a>>2]>>0]|0)>>0]|0|0)?($l(t[f>>2]|0,t[a>>2]|0,t[o>>2]|0)|0)==0:0){c=10;break}t[f>>2]=(t[f>>2]|0)+1}if((c|0)==10){t[n>>2]=t[f>>2];break}else if((c|0)==12){t[n>>2]=0;break}}else t[n>>2]=0;while(0);s=r;return t[n>>2]|0}function fs(e,i,r){e=e|0;i=i|0;r=r|0;var f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0;f=s;s=s+32|0;u=f+20|0;a=f+16|0;o=f+12|0;c=f+8|0;l=f+4|0;b=f;t[a>>2]=e;t[o>>2]=i;t[c>>2]=r;if((t[o>>2]|0)==0|(t[c>>2]|0)==0){t[u>>2]=t[a>>2];k=t[u>>2]|0;s=f;return k|0}if((t[c>>2]|0)<0){t[u>>2]=0;k=t[u>>2]|0;s=f;return k|0}if(!(t[a>>2]|0)){t[u>>2]=ql(t[o>>2]|0,t[c>>2]|0)|0;k=t[u>>2]|0;s=f;return k|0}t[l>>2]=rs(t[a>>2]|0)|0;t[b>>2]=MAi[t[135760>>2]&511](t[a>>2]|0,(t[l>>2]|0)+(t[c>>2]|0)+1|0)|0;if(!(t[b>>2]|0)){Sp(0,0);t[u>>2]=t[a>>2];k=t[u>>2]|0;s=f;return k|0}else{YY((t[b>>2]|0)+(t[l>>2]|0)|0,t[o>>2]|0,t[c>>2]|0)|0;n[(t[b>>2]|0)+((t[l>>2]|0)+(t[c>>2]|0))>>0]=0;t[u>>2]=t[b>>2];k=t[u>>2]|0;s=f;return k|0}return 0}function ts(e,i,r){e=e|0;i=i|0;r=r|0;var f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0;f=s;s=s+32|0;u=f+20|0;a=f+16|0;o=f+12|0;c=f+8|0;l=f+4|0;b=f;t[a>>2]=e;t[o>>2]=i;t[c>>2]=r;if((t[c>>2]|0)<0)t[c>>2]=rs(t[o>>2]|0)|0;r=t[a>>2]|0;if((t[o>>2]|0)==0|(t[c>>2]|0)==0){t[u>>2]=Yl(r)|0;k=t[u>>2]|0;s=f;return k|0}if(!r){t[u>>2]=ql(t[o>>2]|0,t[c>>2]|0)|0;k=t[u>>2]|0;s=f;return k|0}t[l>>2]=rs(t[a>>2]|0)|0;t[b>>2]=gAi[t[135744>>2]&511]((t[l>>2]|0)+(t[c>>2]|0)+1|0)|0;if(!(t[b>>2]|0)){Sp(0,0);t[u>>2]=ql(t[a>>2]|0,t[l>>2]|0)|0;k=t[u>>2]|0;s=f;return k|0}else{YY(t[b>>2]|0,t[a>>2]|0,t[l>>2]|0)|0;YY((t[b>>2]|0)+(t[l>>2]|0)|0,t[o>>2]|0,t[c>>2]|0)|0;n[(t[b>>2]|0)+((t[l>>2]|0)+(t[c>>2]|0))>>0]=0;t[u>>2]=t[b>>2];k=t[u>>2]|0;s=f;return k|0}return 0}function us(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,a=0,o=0,c=0;r=s;s=s+16|0;n=r+12|0;f=r+8|0;a=r+4|0;o=r;t[f>>2]=e;t[a>>2]=i;t[o>>2]=t[a>>2];i=t[f>>2]|0;if(!(t[a>>2]|0)){t[n>>2]=i;c=t[n>>2]|0;s=r;return c|0}if(!i){t[n>>2]=Yl(t[a>>2]|0)|0;c=t[n>>2]|0;s=r;return c|0}while(1){if(!(u[t[o>>2]>>0]|0))break;t[o>>2]=(t[o>>2]|0)+1}t[n>>2]=fs(t[f>>2]|0,t[a>>2]|0,(t[o>>2]|0)-(t[a>>2]|0)|0)|0;c=t[n>>2]|0;s=r;return c|0}function as(e,i,r,f){e=e|0;i=i|0;r=r|0;f=f|0;var u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0;u=s;s=s+48|0;a=u+36|0;o=u+32|0;c=u+28|0;l=u+24|0;b=u+8|0;k=u;t[o>>2]=e;t[c>>2]=i;t[l>>2]=r;if((t[o>>2]|0)==0|(t[l>>2]|0)==0){t[a>>2]=-1;h=t[a>>2]|0;s=u;return h|0}else{t[b>>2]=f;t[k>>2]=yY(t[o>>2]|0,t[c>>2]|0,t[l>>2]|0,b)|0;n[(t[o>>2]|0)+((t[c>>2]|0)-1)>>0]=0;t[a>>2]=t[k>>2];h=t[a>>2]|0;s=u;return h|0}return 0}function os(e){e=e|0;var i=0,r=0,n=0,f=0,a=0,o=0,c=0;i=s;s=s+16|0;r=i+8|0;n=i+4|0;f=i;t[n>>2]=e;t[f>>2]=0;if(!(t[n>>2]|0)){t[r>>2]=-1;a=t[r>>2]|0;s=i;return a|0}e:while(1){if(!(u[t[n>>2]>>0]|0)){o=19;break}e=(t[n>>2]|0)+1|0;do if((u[t[n>>2]>>0]|0)&128){if(((u[e>>0]|0)&192|0)!=128){o=6;break e}c=(t[n>>2]|0)+2|0;if(((u[t[n>>2]>>0]|0)&224|0)!=224){t[n>>2]=c;break}if(((u[c>>0]|0)&192|0)!=128){o=9;break e}c=t[n>>2]|0;if(((u[t[n>>2]>>0]|0)&240|0)!=240){t[n>>2]=c+3;break}if(((u[c>>0]|0)&248|0)!=240){o=13;break e}if(((u[(t[n>>2]|0)+3>>0]|0)&192|0)!=128){o=13;break e}t[n>>2]=(t[n>>2]|0)+4}else t[n>>2]=e;while(0);t[f>>2]=(t[f>>2]|0)+1}if((o|0)==6){t[r>>2]=-1;a=t[r>>2]|0;s=i;return a|0}else if((o|0)==9){t[r>>2]=-1;a=t[r>>2]|0;s=i;return a|0}else if((o|0)==13){t[r>>2]=-1;a=t[r>>2]|0;s=i;return a|0}else if((o|0)==19){t[r>>2]=t[f>>2];a=t[r>>2]|0;s=i;return a|0}return 0}function cs(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,a=0,o=0,c=0;r=s;s=s+16|0;n=r+12|0;f=r+8|0;a=r+4|0;o=r;t[f>>2]=e;t[a>>2]=i;e:do if(!((t[f>>2]|0)==0|(t[a>>2]|0)==0)?(t[t[a>>2]>>2]|0)>=1:0){t[o>>2]=u[t[f>>2]>>0];i=t[a>>2]|0;do if(t[o>>2]&128){if((t[i>>2]|0)<2)break e;if(((u[(t[f>>2]|0)+1>>0]|0)&192|0)!=128)break e;e=t[a>>2]|0;if((t[o>>2]&224|0)!=224){t[e>>2]=2;t[o>>2]=((u[t[f>>2]>>0]|0)&31)<<6;t[o>>2]=t[o>>2]|(u[(t[f>>2]|0)+1>>0]|0)&63;break}if((t[e>>2]|0)<3)break e;if(((u[(t[f>>2]|0)+2>>0]|0)&192|0)!=128)break e;e=t[a>>2]|0;if((t[o>>2]&240|0)!=240){t[e>>2]=3;t[o>>2]=((u[t[f>>2]>>0]|0)&15)<<12;t[o>>2]=t[o>>2]|((u[(t[f>>2]|0)+1>>0]|0)&63)<<6;t[o>>2]=t[o>>2]|(u[(t[f>>2]|0)+2>>0]|0)&63;break}if((t[e>>2]|0)<4)break e;if((t[o>>2]&248|0)!=240)break e;if(((u[(t[f>>2]|0)+3>>0]|0)&192|0)!=128)break e;t[t[a>>2]>>2]=4;t[o>>2]=((u[t[f>>2]>>0]|0)&7)<<18;t[o>>2]=t[o>>2]|((u[(t[f>>2]|0)+1>>0]|0)&63)<<12;t[o>>2]=t[o>>2]|((u[(t[f>>2]|0)+2>>0]|0)&63)<<6;t[o>>2]=t[o>>2]|(u[(t[f>>2]|0)+3>>0]|0)&63}else t[i>>2]=1;while(0);t[n>>2]=t[o>>2];c=t[n>>2]|0;s=r;return c|0}while(0);if(t[a>>2]|0)t[t[a>>2]>>2]=0;t[n>>2]=-1;c=t[n>>2]|0;s=r;return c|0}function ls(e){e=e|0;var i=0,r=0,f=0,a=0,o=0,c=0,l=0;i=s;s=s+16|0;r=i+8|0;f=i+4|0;a=i;o=i+12|0;t[f>>2]=e;if(!(t[f>>2]|0)){t[r>>2]=0;c=t[r>>2]|0;s=i;return c|0}t[a>>2]=0;while(1){e=n[(t[f>>2]|0)+(t[a>>2]|0)>>0]|0;n[o>>0]=e;if(!(e<<24>>24)){l=23;break}if(!((u[o>>0]|0)&128)){t[a>>2]=(t[a>>2]|0)+1;continue}if(((u[o>>0]|0)&224|0)==192){if(((u[(t[f>>2]|0)+((t[a>>2]|0)+1)>>0]|0)&192|0)!=128){l=9;break}t[a>>2]=(t[a>>2]|0)+2;continue}if(((u[o>>0]|0)&240|0)==224){if(((u[(t[f>>2]|0)+((t[a>>2]|0)+1)>>0]|0)&192|0)!=128){l=14;break}if(((u[(t[f>>2]|0)+((t[a>>2]|0)+2)>>0]|0)&192|0)!=128){l=14;break}t[a>>2]=(t[a>>2]|0)+3;continue}if(((u[o>>0]|0)&248|0)!=240){l=22;break}if(((u[(t[f>>2]|0)+((t[a>>2]|0)+1)>>0]|0)&192|0)!=128){l=20;break}if(((u[(t[f>>2]|0)+((t[a>>2]|0)+2)>>0]|0)&192|0)!=128){l=20;break}if(((u[(t[f>>2]|0)+((t[a>>2]|0)+3)>>0]|0)&192|0)!=128){l=20;break}t[a>>2]=(t[a>>2]|0)+4}if((l|0)==9){t[r>>2]=0;c=t[r>>2]|0;s=i;return c|0}else if((l|0)==14){t[r>>2]=0;c=t[r>>2]|0;s=i;return c|0}else if((l|0)==20){t[r>>2]=0;c=t[r>>2]|0;s=i;return c|0}else if((l|0)==22){t[r>>2]=0;c=t[r>>2]|0;s=i;return c|0}else if((l|0)==23){t[r>>2]=1;c=t[r>>2]|0;s=i;return c|0}return 0}function ss(e,i){e=e|0;i=i|0;var r=0,f=0,a=0,o=0,c=0,l=0,b=0;r=s;s=s+32|0;f=r+12|0;a=r+8|0;o=r+4|0;c=r;l=r+16|0;t[a>>2]=e;t[o>>2]=i;t[c>>2]=t[a>>2];if(!(t[a>>2]|0)){t[f>>2]=0;b=t[f>>2]|0;s=r;return b|0}if((t[o>>2]|0)<=0){t[f>>2]=0;b=t[f>>2]|0;s=r;return b|0}e:while(1){i=t[o>>2]|0;t[o>>2]=i+-1;if((i|0)<=0)break;if(!(n[t[c>>2]>>0]|0))break;i=t[c>>2]|0;t[c>>2]=i+1;e=n[i>>0]|0;n[l>>0]=e;if(!(e&128))continue;while(1){e=u[l>>0]<<1&255;n[l>>0]=e;if(!(e&128))continue e;t[c>>2]=(t[c>>2]|0)+1;if(!(u[t[c>>2]>>0]|0))continue e}}t[f>>2]=(t[c>>2]|0)-(t[a>>2]|0);b=t[f>>2]|0;s=r;return b|0}function bs(e,i){e=e|0;i=i|0;var r=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0;r=s;s=s+32|0;f=r;u=r+20|0;a=r+16|0;o=r+12|0;c=r+8|0;l=r+4|0;t[a>>2]=e;t[o>>2]=i;if((t[a>>2]|0)==0|(t[o>>2]|0)<0){t[u>>2]=0;b=t[u>>2]|0;s=r;return b|0}t[l>>2]=ss(t[a>>2]|0,t[o>>2]|0)|0;t[c>>2]=gAi[t[135752>>2]&511]((t[l>>2]|0)+1|0)|0;if(!(t[c>>2]|0)){i=t[33976]|0;e=t[33980]|0;t[f>>2]=(t[o>>2]|0)+1;yAi[i&511](e,138912,f);t[u>>2]=0;b=t[u>>2]|0;s=r;return b|0}else{YY(t[c>>2]|0,t[a>>2]|0,t[l>>2]|0)|0;n[(t[c>>2]|0)+(t[l>>2]|0)>>0]=0;t[u>>2]=t[c>>2];b=t[u>>2]|0;s=r;return b|0}return 0}function ks(e,i){e=e|0;i=i|0;var r=0,f=0,a=0,o=0,c=0,l=0,b=0;r=s;s=s+16|0;f=r+8|0;a=r+4|0;o=r;c=r+12|0;t[a>>2]=e;t[o>>2]=i;do if(t[a>>2]|0){if((t[o>>2]|0)<0){t[f>>2]=0;break}e:while(1){i=t[o>>2]|0;t[o>>2]=i+-1;l=t[a>>2]|0;if(!i){b=14;break}t[a>>2]=l+1;i=n[l>>0]|0;n[c>>0]=i;if(!(i&255)){b=7;break}if(!((u[c>>0]|0)&128))continue;if(((u[c>>0]|0)&192|0)!=192){b=10;break}while(1){i=(u[c>>0]|0)<<1&255;n[c>>0]=i;if(!(i&128))continue e;i=t[a>>2]|0;t[a>>2]=i+1;if(((u[i>>0]|0)&192|0)!=128){b=13;break e}}}if((b|0)==7){t[f>>2]=0;break}else if((b|0)==10){t[f>>2]=0;break}else if((b|0)==13){t[f>>2]=0;break}else if((b|0)==14){t[f>>2]=l;break}}else t[f>>2]=0;while(0);s=r;return t[f>>2]|0}function hs(e,i){e=e|0;i=i|0;var r=0,f=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0;r=s;s=s+32|0;f=r+16|0;a=r+12|0;o=r+8|0;c=r+4|0;l=r;b=r+20|0;t[a>>2]=e;t[o>>2]=i;if((t[a>>2]|0)==0|(t[o>>2]|0)==0){t[f>>2]=-1;k=t[f>>2]|0;s=r;return k|0}t[l>>2]=ss(t[o>>2]|0,1)|0;t[c>>2]=0;e:while(1){i=n[t[a>>2]>>0]|0;n[b>>0]=i;if(!(i&255)){h=14;break}if(!(Jl(t[a>>2]|0,t[o>>2]|0,t[l>>2]|0)|0)){h=6;break}t[a>>2]=(t[a>>2]|0)+1;i:do if((u[b>>0]|0)&128){if(((u[b>>0]|0)&192|0)!=192){h=9;break e}while(1){i=(u[b>>0]|0)<<1&255;n[b>>0]=i;if(!(i&128))break i;i=t[a>>2]|0;t[a>>2]=i+1;if(((u[i>>0]|0)&192|0)!=128){h=12;break e}}}while(0);t[c>>2]=(t[c>>2]|0)+1}if((h|0)==6){t[f>>2]=t[c>>2];k=t[f>>2]|0;s=r;return k|0}else if((h|0)==9){t[f>>2]=-1;k=t[f>>2]|0;s=r;return k|0}else if((h|0)==12){t[f>>2]=-1;k=t[f>>2]|0;s=r;return k|0}else if((h|0)==14){t[f>>2]=-1;k=t[f>>2]|0;s=r;return k|0}return 0}function ws(e,i,r){e=e|0;i=i|0;r=r|0;var f=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0;f=s;s=s+32|0;a=f+16|0;o=f+12|0;c=f+8|0;l=f+4|0;b=f;k=f+20|0;t[o>>2]=e;t[c>>2]=i;t[l>>2]=r;do if(t[o>>2]|0){if((t[c>>2]|0)<0){t[a>>2]=0;break}if((t[l>>2]|0)<0){t[a>>2]=0;break}t[b>>2]=0;e:while(1){h=t[o>>2]|0;if((t[b>>2]|0)>=(t[c>>2]|0)){w=18;break}t[o>>2]=h+1;r=n[h>>0]|0;n[k>>0]=r;if(!(r&255)){w=10;break}i:do if((u[k>>0]|0)&128){if(((u[k>>0]|0)&192|0)!=192){w=13;break e}while(1){r=(u[k>>0]|0)<<1&255;n[k>>0]=r;if(!(r&128))break i;r=t[o>>2]|0;t[o>>2]=r+1;if(((u[r>>0]|0)&192|0)!=128){w=16;break e}}}while(0);t[b>>2]=(t[b>>2]|0)+1}if((w|0)==10){t[a>>2]=0;break}else if((w|0)==13){t[a>>2]=0;break}else if((w|0)==16){t[a>>2]=0;break}else if((w|0)==18){t[a>>2]=bs(h,t[l>>2]|0)|0;break}}else t[a>>2]=0;while(0);s=f;return t[a>>2]|0}function ds(){var e=0,i=0,r=0,f=0,u=0;e=s;s=s+16|0;i=e+4|0;r=e;t[r>>2]=gAi[t[135744>>2]&511](36)|0;if(!(t[r>>2]|0)){qs(0,138944);t[i>>2]=0;f=t[i>>2]|0;s=e;return f|0}t[(t[r>>2]|0)+4>>2]=0;t[(t[r>>2]|0)+20>>2]=0;t[(t[r>>2]|0)+32>>2]=0;t[(t[r>>2]|0)+28>>2]=0;t[(t[r>>2]|0)+24>>2]=t[33950];t[(t[r>>2]|0)+8>>2]=t[33950];t[(t[r>>2]|0)+12>>2]=t[33948];u=gAi[t[135752>>2]&511](t[(t[r>>2]|0)+24>>2]|0)|0;t[t[r>>2]>>2]=u;u=t[r>>2]|0;if(!(t[t[r>>2]>>2]|0)){qs(u,138944);pAi[t[135736>>2]&511](t[r>>2]|0);t[i>>2]=0;f=t[i>>2]|0;s=e;return f|0}else{n[t[u>>2]>>0]=0;t[(t[r>>2]|0)+16>>2]=0;t[i>>2]=t[r>>2];f=t[i>>2]|0;s=e;return f|0}return 0}function vs(e){e=e|0;var i=0,r=0,f=0,u=0,a=0,o=0;i=s;s=s+16|0;r=i+8|0;f=i+4|0;u=i;t[f>>2]=e;t[u>>2]=gAi[t[135744>>2]&511](36)|0;if(!(t[u>>2]|0)){qs(0,138944);t[r>>2]=0;a=t[r>>2]|0;s=i;return a|0}t[(t[u>>2]|0)+4>>2]=0;t[(t[u>>2]|0)+20>>2]=0;t[(t[u>>2]|0)+32>>2]=0;t[(t[u>>2]|0)+28>>2]=0;t[(t[u>>2]|0)+12>>2]=t[33948];if(t[f>>2]|0)o=(t[f>>2]|0)+2|0;else o=0;t[(t[u>>2]|0)+24>>2]=o;t[(t[u>>2]|0)+8>>2]=t[(t[u>>2]|0)+24>>2];do if(t[(t[u>>2]|0)+24>>2]|0){o=gAi[t[135752>>2]&511](t[(t[u>>2]|0)+24>>2]|0)|0;t[t[u>>2]>>2]=o;o=t[u>>2]|0;if(t[t[u>>2]>>2]|0){n[t[o>>2]>>0]=0;break}qs(o,138944);pAi[t[135736>>2]&511](t[u>>2]|0);t[r>>2]=0;a=t[r>>2]|0;s=i;return a|0}else t[t[u>>2]>>2]=0;while(0);t[(t[u>>2]|0)+16>>2]=0;t[r>>2]=t[u>>2];a=t[r>>2]|0;s=i;return a|0}function ms(e){e=e|0;var i=0,r=0,n=0,f=0;i=s;s=s+16|0;r=i+8|0;n=i+4|0;f=i;t[n>>2]=e;do if(t[n>>2]|0){if((t[(t[n>>2]|0)+12>>2]|0)==2){t[r>>2]=0;break}if(t[(t[n>>2]|0)+28>>2]|0){t[r>>2]=0;break}if(t[(t[n>>2]|0)+32>>2]|0){t[r>>2]=0;break}else{t[f>>2]=t[t[n>>2]>>2];t[t[n>>2]>>2]=0;t[(t[n>>2]|0)+24>>2]=0;t[(t[n>>2]|0)+20>>2]=0;t[(t[n>>2]|0)+4>>2]=0;t[(t[n>>2]|0)+8>>2]=0;t[r>>2]=t[f>>2];break}}else t[r>>2]=0;while(0);s=i;return t[r>>2]|0}function _s(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0;r=s;s=s+16|0;n=r+12|0;f=r+8|0;u=r+4|0;a=r;t[f>>2]=e;t[u>>2]=i;if((t[f>>2]|0)==0|(t[u>>2]|0)==0){t[n>>2]=0;o=t[n>>2]|0;s=r;return o|0}t[a>>2]=gAi[t[135744>>2]&511](36)|0;if(!(t[a>>2]|0)){qs(0,138944);t[n>>2]=0;o=t[n>>2]|0;s=r;return o|0}if((t[u>>2]|0)>>>0<2147483647){t[(t[a>>2]|0)+4>>2]=t[u>>2];t[(t[a>>2]|0)+8>>2]=t[u>>2]}else{t[(t[a>>2]|0)+4>>2]=2147483647;t[(t[a>>2]|0)+8>>2]=2147483647}t[(t[a>>2]|0)+20>>2]=t[u>>2];t[(t[a>>2]|0)+24>>2]=t[u>>2];t[(t[a>>2]|0)+12>>2]=2;
	t[t[a>>2]>>2]=t[f>>2];t[(t[a>>2]|0)+32>>2]=0;t[(t[a>>2]|0)+28>>2]=0;t[n>>2]=t[a>>2];o=t[n>>2]|0;s=r;return o|0}function ps(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i+4|0;n=i;t[n>>2]=e;if(!(t[n>>2]|0))t[r>>2]=-1;else t[r>>2]=t[(t[n>>2]|0)+12>>2];s=i;return t[r>>2]|0}function Es(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0;r=s;s=s+16|0;n=r+8|0;f=r+4|0;u=r;t[f>>2]=e;t[u>>2]=i;if((t[f>>2]|0)!=0?(t[(t[f>>2]|0)+32>>2]|0)==0:0){if((t[(t[f>>2]|0)+12>>2]|0)!=2?(t[(t[f>>2]|0)+12>>2]|0)!=3:0){i=t[u>>2]|0;if((t[u>>2]|0)==0|(t[u>>2]|0)==1|(t[u>>2]|0)==4|(t[u>>2]|0)==2){t[(t[f>>2]|0)+12>>2]=i;if(t[(t[f>>2]|0)+28>>2]|0)t[(t[(t[f>>2]|0)+28>>2]|0)+12>>2]=t[u>>2];t[n>>2]=0;a=t[n>>2]|0;s=r;return a|0}else{if((i|0)==3){t[(t[f>>2]|0)+12>>2]=3;t[(t[f>>2]|0)+16>>2]=t[t[f>>2]>>2]}t[n>>2]=-1;a=t[n>>2]|0;s=r;return a|0}}t[n>>2]=-1;a=t[n>>2]|0;s=r;return a|0}t[n>>2]=-1;a=t[n>>2]|0;s=r;return a|0}function Ss(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if(!(t[r>>2]|0)){s=i;return}if((t[(t[r>>2]|0)+12>>2]|0)==3?(t[(t[r>>2]|0)+16>>2]|0)!=0:0)pAi[t[135736>>2]&511](t[(t[r>>2]|0)+16>>2]|0);else n=5;if(((n|0)==5?(t[t[r>>2]>>2]|0)!=0:0)?(t[(t[r>>2]|0)+12>>2]|0)!=2:0)pAi[t[135736>>2]&511](t[t[r>>2]>>2]|0);pAi[t[135736>>2]&511](t[r>>2]|0);s=i;return}function gs(e){e=e|0;var i=0,r=0,f=0,u=0;i=s;s=s+16|0;r=i+4|0;f=i;t[r>>2]=e;if(!(t[r>>2]|0)){s=i;return}if(t[(t[r>>2]|0)+32>>2]|0){s=i;return}if(!(t[t[r>>2]>>2]|0)){s=i;return}if((t[(t[r>>2]|0)+24>>2]|0)!=(t[(t[r>>2]|0)+8>>2]|0)?(t[(t[r>>2]|0)+8>>2]|0)>>>0<2147483647:0)t[(t[r>>2]|0)+24>>2]=t[(t[r>>2]|0)+8>>2];if((t[(t[r>>2]|0)+20>>2]|0)!=(t[(t[r>>2]|0)+4>>2]|0)?(t[(t[r>>2]|0)+4>>2]|0)>>>0<2147483647:0)t[(t[r>>2]|0)+20>>2]=t[(t[r>>2]|0)+4>>2];t[(t[r>>2]|0)+20>>2]=0;e=t[r>>2]|0;do if((t[(t[r>>2]|0)+12>>2]|0)==2)t[e>>2]=138960;else{if((t[e+12>>2]|0)==3?(t[(t[r>>2]|0)+16>>2]|0)!=0:0){t[f>>2]=(t[t[r>>2]>>2]|0)-(t[(t[r>>2]|0)+16>>2]|0);u=(t[r>>2]|0)+24|0;t[u>>2]=(t[u>>2]|0)+(t[f>>2]|0);t[t[r>>2]>>2]=t[(t[r>>2]|0)+16>>2];n[t[t[r>>2]>>2]>>0]=0;break}n[t[t[r>>2]>>2]>>0]=0}while(0);f=t[r>>2]|0;if((t[(t[r>>2]|0)+24>>2]|0)>>>0<2147483647)t[(t[r>>2]|0)+8>>2]=t[f+24>>2];else t[f+8>>2]=2147483647;f=t[r>>2]|0;if((t[(t[r>>2]|0)+20>>2]|0)>>>0<2147483647){t[(t[r>>2]|0)+4>>2]=t[f+20>>2];s=i;return}else{t[f+4>>2]=2147483647;s=i;return}}function ys(e,i){e=e|0;i=i|0;var r=0,f=0,u=0,a=0,o=0,c=0,l=0;r=s;s=s+16|0;f=r+12|0;u=r+8|0;a=r+4|0;o=r;t[u>>2]=e;t[a>>2]=i;if((t[u>>2]|0)!=0?(t[(t[u>>2]|0)+32>>2]|0)==0:0){if((t[(t[u>>2]|0)+24>>2]|0)!=(t[(t[u>>2]|0)+8>>2]|0)?(t[(t[u>>2]|0)+8>>2]|0)>>>0<2147483647:0)t[(t[u>>2]|0)+24>>2]=t[(t[u>>2]|0)+8>>2];if((t[(t[u>>2]|0)+20>>2]|0)!=(t[(t[u>>2]|0)+4>>2]|0)?(t[(t[u>>2]|0)+4>>2]|0)>>>0<2147483647:0)t[(t[u>>2]|0)+20>>2]=t[(t[u>>2]|0)+4>>2];if(!(t[a>>2]|0)){t[f>>2]=0;c=t[f>>2]|0;s=r;return c|0}if((t[a>>2]|0)>>>0>(t[(t[u>>2]|0)+20>>2]|0)>>>0){t[f>>2]=0;c=t[f>>2]|0;s=r;return c|0}i=(t[u>>2]|0)+20|0;t[i>>2]=(t[i>>2]|0)-(t[a>>2]|0);do if((t[(t[u>>2]|0)+12>>2]|0)==2)l=17;else{if((t[(t[u>>2]|0)+12>>2]|0)==3?(t[(t[u>>2]|0)+16>>2]|0)!=0:0){l=17;break}GY(t[t[u>>2]>>2]|0,(t[t[u>>2]>>2]|0)+(t[a>>2]|0)|0,t[(t[u>>2]|0)+20>>2]|0)|0;n[(t[t[u>>2]>>2]|0)+(t[(t[u>>2]|0)+20>>2]|0)>>0]=0}while(0);if((((l|0)==17?(l=t[u>>2]|0,t[l>>2]=(t[l>>2]|0)+(t[a>>2]|0),l=(t[u>>2]|0)+24|0,t[l>>2]=(t[l>>2]|0)-(t[a>>2]|0),(t[(t[u>>2]|0)+12>>2]|0)==3):0)?(t[(t[u>>2]|0)+16>>2]|0)!=0:0)?(t[o>>2]=(t[t[u>>2]>>2]|0)-(t[(t[u>>2]|0)+16>>2]|0),(t[o>>2]|0)>>>0>=(t[(t[u>>2]|0)+24>>2]|0)>>>0):0){GY(t[(t[u>>2]|0)+16>>2]|0,t[t[u>>2]>>2]|0,t[(t[u>>2]|0)+20>>2]|0)|0;t[t[u>>2]>>2]=t[(t[u>>2]|0)+16>>2];n[(t[t[u>>2]>>2]|0)+(t[(t[u>>2]|0)+20>>2]|0)>>0]=0;l=(t[u>>2]|0)+24|0;t[l>>2]=(t[l>>2]|0)+(t[o>>2]|0)}o=t[u>>2]|0;if((t[(t[u>>2]|0)+24>>2]|0)>>>0<2147483647)t[(t[u>>2]|0)+8>>2]=t[o+24>>2];else t[o+8>>2]=2147483647;o=t[u>>2]|0;if((t[(t[u>>2]|0)+20>>2]|0)>>>0<2147483647)t[(t[u>>2]|0)+4>>2]=t[o+20>>2];else t[o+4>>2]=2147483647;t[f>>2]=t[a>>2];c=t[f>>2]|0;s=r;return c|0}t[f>>2]=0;c=t[f>>2]|0;s=r;return c|0}function Fs(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0;r=s;s=s+16|0;n=r+12|0;f=r+8|0;u=r+4|0;a=r;t[f>>2]=e;t[u>>2]=i;do if(!((t[f>>2]|0)==0|(t[u>>2]|0)<0)){if(!(t[u>>2]|0)){t[n>>2]=0;break}t[a>>2]=Ys(t[f>>2]|0,t[u>>2]|0)|0;if(t[(t[f>>2]|0)+32>>2]|0){t[n>>2]=-1;break}else{t[n>>2]=t[a>>2];break}}else t[n>>2]=-1;while(0);s=r;return t[n>>2]|0}function Os(e){e=e|0;var i=0,r=0,n=0,f=0;i=s;s=s+16|0;r=i+4|0;n=i;t[n>>2]=e;if((t[n>>2]|0)!=0?(t[(t[n>>2]|0)+32>>2]|0)==0:0){t[r>>2]=t[t[n>>2]>>2];f=t[r>>2]|0;s=i;return f|0}t[r>>2]=0;f=t[r>>2]|0;s=i;return f|0}function As(e){e=e|0;var i=0,r=0,n=0,f=0;i=s;s=s+16|0;r=i+4|0;n=i;t[n>>2]=e;if((t[n>>2]|0)!=0?(t[(t[n>>2]|0)+32>>2]|0)==0:0){if((t[(t[n>>2]|0)+24>>2]|0)!=(t[(t[n>>2]|0)+8>>2]|0)?(t[(t[n>>2]|0)+8>>2]|0)>>>0<2147483647:0)t[(t[n>>2]|0)+24>>2]=t[(t[n>>2]|0)+8>>2];if((t[(t[n>>2]|0)+20>>2]|0)!=(t[(t[n>>2]|0)+4>>2]|0)?(t[(t[n>>2]|0)+4>>2]|0)>>>0<2147483647:0)t[(t[n>>2]|0)+20>>2]=t[(t[n>>2]|0)+4>>2];t[r>>2]=(t[t[n>>2]>>2]|0)+(t[(t[n>>2]|0)+20>>2]|0);f=t[r>>2]|0;s=i;return f|0}t[r>>2]=0;f=t[r>>2]|0;s=i;return f|0}function Ms(e,i){e=e|0;i=i|0;var r=0,f=0,u=0,a=0,o=0;r=s;s=s+16|0;f=r+8|0;u=r+4|0;a=r;t[u>>2]=e;t[a>>2]=i;if((t[u>>2]|0)!=0?(t[(t[u>>2]|0)+32>>2]|0)==0:0){if((t[(t[u>>2]|0)+24>>2]|0)!=(t[(t[u>>2]|0)+8>>2]|0)?(t[(t[u>>2]|0)+8>>2]|0)>>>0<2147483647:0)t[(t[u>>2]|0)+24>>2]=t[(t[u>>2]|0)+8>>2];if((t[(t[u>>2]|0)+20>>2]|0)!=(t[(t[u>>2]|0)+4>>2]|0)?(t[(t[u>>2]|0)+4>>2]|0)>>>0<2147483647:0)t[(t[u>>2]|0)+20>>2]=t[(t[u>>2]|0)+4>>2];if((t[a>>2]|0)>>>0>((t[(t[u>>2]|0)+24>>2]|0)-(t[(t[u>>2]|0)+20>>2]|0)|0)>>>0){t[f>>2]=-1;o=t[f>>2]|0;s=r;return o|0}i=(t[u>>2]|0)+20|0;t[i>>2]=(t[i>>2]|0)+(t[a>>2]|0);a=t[u>>2]|0;if((t[(t[u>>2]|0)+24>>2]|0)>>>0<2147483647)t[(t[u>>2]|0)+8>>2]=t[a+24>>2];else t[a+8>>2]=2147483647;a=t[u>>2]|0;if((t[(t[u>>2]|0)+20>>2]|0)>>>0<2147483647)t[(t[u>>2]|0)+4>>2]=t[a+20>>2];else t[a+4>>2]=2147483647;if((t[(t[u>>2]|0)+24>>2]|0)>>>0>(t[(t[u>>2]|0)+20>>2]|0)>>>0){n[(t[t[u>>2]>>2]|0)+(t[(t[u>>2]|0)+20>>2]|0)>>0]=0;t[f>>2]=0;o=t[f>>2]|0;s=r;return o|0}else{t[f>>2]=-1;o=t[f>>2]|0;s=r;return o|0}}t[f>>2]=-1;o=t[f>>2]|0;s=r;return o|0}function Rs(e,i){e=e|0;i=i|0;var r=0,f=0,u=0,a=0,o=0;r=s;s=s+16|0;f=r+8|0;u=r+4|0;a=r;t[u>>2]=e;t[a>>2]=i;if((t[u>>2]|0)!=0?(t[(t[u>>2]|0)+32>>2]|0)==0:0){if((t[(t[u>>2]|0)+24>>2]|0)!=(t[(t[u>>2]|0)+8>>2]|0)?(t[(t[u>>2]|0)+8>>2]|0)>>>0<2147483647:0)t[(t[u>>2]|0)+24>>2]=t[(t[u>>2]|0)+8>>2];if((t[(t[u>>2]|0)+20>>2]|0)!=(t[(t[u>>2]|0)+4>>2]|0)?(t[(t[u>>2]|0)+4>>2]|0)>>>0<2147483647:0)t[(t[u>>2]|0)+20>>2]=t[(t[u>>2]|0)+4>>2];if((t[a>>2]|0)>>>0>(t[(t[u>>2]|0)+20>>2]|0)>>>0){t[f>>2]=-1;o=t[f>>2]|0;s=r;return o|0}i=(t[u>>2]|0)+20|0;t[i>>2]=(t[i>>2]|0)-(t[a>>2]|0);n[(t[t[u>>2]>>2]|0)+(t[(t[u>>2]|0)+20>>2]|0)>>0]=0;a=t[u>>2]|0;if((t[(t[u>>2]|0)+24>>2]|0)>>>0<2147483647)t[(t[u>>2]|0)+8>>2]=t[a+24>>2];else t[a+8>>2]=2147483647;a=t[u>>2]|0;if((t[(t[u>>2]|0)+20>>2]|0)>>>0<2147483647)t[(t[u>>2]|0)+4>>2]=t[a+20>>2];else t[a+4>>2]=2147483647;t[f>>2]=0;o=t[f>>2]|0;s=r;return o|0}t[f>>2]=-1;o=t[f>>2]|0;s=r;return o|0}function Ns(e){e=e|0;var i=0,r=0,n=0,f=0;i=s;s=s+16|0;r=i+4|0;n=i;t[n>>2]=e;if((t[n>>2]|0)!=0?(t[(t[n>>2]|0)+32>>2]|0)==0:0){if((t[(t[n>>2]|0)+24>>2]|0)!=(t[(t[n>>2]|0)+8>>2]|0)?(t[(t[n>>2]|0)+8>>2]|0)>>>0<2147483647:0)t[(t[n>>2]|0)+24>>2]=t[(t[n>>2]|0)+8>>2];if((t[(t[n>>2]|0)+20>>2]|0)!=(t[(t[n>>2]|0)+4>>2]|0)?(t[(t[n>>2]|0)+4>>2]|0)>>>0<2147483647:0)t[(t[n>>2]|0)+20>>2]=t[(t[n>>2]|0)+4>>2];t[r>>2]=t[(t[n>>2]|0)+20>>2];f=t[r>>2]|0;s=i;return f|0}t[r>>2]=0;f=t[r>>2]|0;s=i;return f|0}function Ts(e){e=e|0;var i=0,r=0,n=0,f=0;i=s;s=s+16|0;r=i+4|0;n=i;t[n>>2]=e;if((t[n>>2]|0)!=0?(t[(t[n>>2]|0)+32>>2]|0)==0:0){if((t[(t[n>>2]|0)+24>>2]|0)!=(t[(t[n>>2]|0)+8>>2]|0)?(t[(t[n>>2]|0)+8>>2]|0)>>>0<2147483647:0)t[(t[n>>2]|0)+24>>2]=t[(t[n>>2]|0)+8>>2];if((t[(t[n>>2]|0)+20>>2]|0)!=(t[(t[n>>2]|0)+4>>2]|0)?(t[(t[n>>2]|0)+4>>2]|0)>>>0<2147483647:0)t[(t[n>>2]|0)+20>>2]=t[(t[n>>2]|0)+4>>2];t[r>>2]=t[(t[n>>2]|0)+20>>2];f=t[r>>2]|0;s=i;return f|0}t[r>>2]=0;f=t[r>>2]|0;s=i;return f|0}function Ls(e){e=e|0;var i=0,r=0,n=0,f=0;i=s;s=s+16|0;r=i+4|0;n=i;t[n>>2]=e;if((t[n>>2]|0)!=0?(t[(t[n>>2]|0)+32>>2]|0)==0:0){if((t[(t[n>>2]|0)+24>>2]|0)!=(t[(t[n>>2]|0)+8>>2]|0)?(t[(t[n>>2]|0)+8>>2]|0)>>>0<2147483647:0)t[(t[n>>2]|0)+24>>2]=t[(t[n>>2]|0)+8>>2];if((t[(t[n>>2]|0)+20>>2]|0)!=(t[(t[n>>2]|0)+4>>2]|0)?(t[(t[n>>2]|0)+4>>2]|0)>>>0<2147483647:0)t[(t[n>>2]|0)+20>>2]=t[(t[n>>2]|0)+4>>2];t[r>>2]=(t[(t[n>>2]|0)+24>>2]|0)-(t[(t[n>>2]|0)+20>>2]|0);f=t[r>>2]|0;s=i;return f|0}t[r>>2]=0;f=t[r>>2]|0;s=i;return f|0}function Ds(e){e=e|0;var i=0,r=0,n=0,f=0;i=s;s=s+16|0;r=i+4|0;n=i;t[n>>2]=e;if((t[n>>2]|0)!=0?(t[(t[n>>2]|0)+32>>2]|0)==0:0){if((t[(t[n>>2]|0)+24>>2]|0)!=(t[(t[n>>2]|0)+8>>2]|0)?(t[(t[n>>2]|0)+8>>2]|0)>>>0<2147483647:0)t[(t[n>>2]|0)+24>>2]=t[(t[n>>2]|0)+8>>2];if((t[(t[n>>2]|0)+20>>2]|0)!=(t[(t[n>>2]|0)+4>>2]|0)?(t[(t[n>>2]|0)+4>>2]|0)>>>0<2147483647:0)t[(t[n>>2]|0)+20>>2]=t[(t[n>>2]|0)+4>>2];t[r>>2]=(t[(t[n>>2]|0)+20>>2]|0)==0&1;f=t[r>>2]|0;s=i;return f|0}t[r>>2]=-1;f=t[r>>2]|0;s=i;return f|0}function Cs(e,i){e=e|0;i=i|0;var r=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0;r=s;s=s+32|0;f=r+20|0;u=r+16|0;a=r+12|0;o=r+8|0;c=r+4|0;l=r;t[u>>2]=e;t[a>>2]=i;t[c>>2]=0;if((t[u>>2]|0)!=0?(t[(t[u>>2]|0)+32>>2]|0)==0:0){if((t[(t[u>>2]|0)+24>>2]|0)!=(t[(t[u>>2]|0)+8>>2]|0)?(t[(t[u>>2]|0)+8>>2]|0)>>>0<2147483647:0)t[(t[u>>2]|0)+24>>2]=t[(t[u>>2]|0)+8>>2];if((t[(t[u>>2]|0)+20>>2]|0)!=(t[(t[u>>2]|0)+4>>2]|0)?(t[(t[u>>2]|0)+4>>2]|0)>>>0<2147483647:0)t[(t[u>>2]|0)+20>>2]=t[(t[u>>2]|0)+4>>2];if((t[(t[u>>2]|0)+12>>2]|0)==2){t[f>>2]=0;b=t[f>>2]|0;s=r;return b|0}if((t[a>>2]|0)>>>0<(t[(t[u>>2]|0)+24>>2]|0)>>>0){t[f>>2]=1;b=t[f>>2]|0;s=r;return b|0}i=t[(t[u>>2]|0)+12>>2]|0;e:do if((i|0)==4){if((t[(t[u>>2]|0)+20>>2]|0)>>>0<4096){t[o>>2]=t[a>>2];break}t[o>>2]=t[(t[u>>2]|0)+24>>2]<<1;while(1){if((t[a>>2]|0)>>>0<=(t[o>>2]|0)>>>0)break e;if((t[o>>2]|0)>>>0>2147483647)break;t[o>>2]=t[o>>2]<<1}qs(t[u>>2]|0,138968);t[f>>2]=0;b=t[f>>2]|0;s=r;return b|0}else if((i|0)==0|(i|0)==3){if(t[(t[u>>2]|0)+24>>2]|0)k=t[(t[u>>2]|0)+24>>2]<<1;else k=(t[a>>2]|0)+10|0;t[o>>2]=k;while(1){if((t[a>>2]|0)>>>0<=(t[o>>2]|0)>>>0)break e;if((t[o>>2]|0)>>>0>2147483647)break;t[o>>2]=t[o>>2]<<1}qs(t[u>>2]|0,138968);t[f>>2]=0;b=t[f>>2]|0;s=r;return b|0}else if((i|0)==1)t[o>>2]=(t[a>>2]|0)+10;else t[o>>2]=(t[a>>2]|0)+10;while(0);do if((t[(t[u>>2]|0)+12>>2]|0)==3?(t[(t[u>>2]|0)+16>>2]|0)!=0:0){t[l>>2]=(t[t[u>>2]>>2]|0)-(t[(t[u>>2]|0)+16>>2]|0);if((t[l>>2]|0)>>>0>(t[o>>2]|0)>>>0){GY(t[(t[u>>2]|0)+16>>2]|0,t[t[u>>2]>>2]|0,t[(t[u>>2]|0)+20>>2]|0)|0;t[t[u>>2]>>2]=t[(t[u>>2]|0)+16>>2];n[(t[t[u>>2]>>2]|0)+(t[(t[u>>2]|0)+20>>2]|0)>>0]=0;a=(t[u>>2]|0)+24|0;t[a>>2]=(t[a>>2]|0)+(t[l>>2]|0);break}t[c>>2]=MAi[t[135760>>2]&511](t[(t[u>>2]|0)+16>>2]|0,(t[l>>2]|0)+(t[o>>2]|0)|0)|0;if(t[c>>2]|0){t[(t[u>>2]|0)+16>>2]=t[c>>2];t[t[u>>2]>>2]=(t[c>>2]|0)+(t[l>>2]|0);break}qs(t[u>>2]|0,138968);t[f>>2]=0;b=t[f>>2]|0;s=r;return b|0}else h=39;while(0);do if((h|0)==39){do if(t[t[u>>2]>>2]|0){if(((t[(t[u>>2]|0)+24>>2]|0)-(t[(t[u>>2]|0)+20>>2]|0)|0)>>>0<100){t[c>>2]=MAi[t[135760>>2]&511](t[t[u>>2]>>2]|0,t[o>>2]|0)|0;break}t[c>>2]=gAi[t[135752>>2]&511](t[o>>2]|0)|0;if(t[c>>2]|0){YY(t[c>>2]|0,t[t[u>>2]>>2]|0,t[(t[u>>2]|0)+20>>2]|0)|0;pAi[t[135736>>2]&511](t[t[u>>2]>>2]|0);n[(t[c>>2]|0)+(t[(t[u>>2]|0)+20>>2]|0)>>0]=0}}else t[c>>2]=gAi[t[135752>>2]&511](t[o>>2]|0)|0;while(0);if(t[c>>2]|0){t[t[u>>2]>>2]=t[c>>2];break}qs(t[u>>2]|0,138968);t[f>>2]=0;b=t[f>>2]|0;s=r;return b|0}while(0);t[(t[u>>2]|0)+24>>2]=t[o>>2];o=t[u>>2]|0;if((t[(t[u>>2]|0)+24>>2]|0)>>>0<2147483647)t[(t[u>>2]|0)+8>>2]=t[o+24>>2];else t[o+8>>2]=2147483647;o=t[u>>2]|0;if((t[(t[u>>2]|0)+20>>2]|0)>>>0<2147483647)t[(t[u>>2]|0)+4>>2]=t[o+20>>2];else t[o+4>>2]=2147483647;t[f>>2]=1;b=t[f>>2]|0;s=r;return b|0}t[f>>2]=0;b=t[f>>2]|0;s=r;return b|0}function Ps(e,i,r){e=e|0;i=i|0;r=r|0;var f=0,u=0,a=0,o=0,c=0,l=0,b=0;f=s;s=s+32|0;u=f+16|0;a=f+12|0;o=f+8|0;c=f+4|0;l=f;t[a>>2]=e;t[o>>2]=i;t[c>>2]=r;if(!((t[o>>2]|0)==0|(t[a>>2]|0)==0)?(t[(t[a>>2]|0)+32>>2]|0)==0:0){if((t[(t[a>>2]|0)+24>>2]|0)!=(t[(t[a>>2]|0)+8>>2]|0)?(t[(t[a>>2]|0)+8>>2]|0)>>>0<2147483647:0)t[(t[a>>2]|0)+24>>2]=t[(t[a>>2]|0)+8>>2];if((t[(t[a>>2]|0)+20>>2]|0)!=(t[(t[a>>2]|0)+4>>2]|0)?(t[(t[a>>2]|0)+4>>2]|0)>>>0<2147483647:0)t[(t[a>>2]|0)+20>>2]=t[(t[a>>2]|0)+4>>2];if((t[(t[a>>2]|0)+12>>2]|0)==2){t[u>>2]=-1;b=t[u>>2]|0;s=f;return b|0}if((t[c>>2]|0)<-1){t[u>>2]=-1;b=t[u>>2]|0;s=f;return b|0}if(!(t[c>>2]|0)){t[u>>2]=0;b=t[u>>2]|0;s=f;return b|0}if((t[c>>2]|0)<0)t[c>>2]=rs(t[o>>2]|0)|0;if((t[c>>2]|0)<0){t[u>>2]=-1;b=t[u>>2]|0;s=f;return b|0}if(!(t[c>>2]|0)){t[u>>2]=0;b=t[u>>2]|0;s=f;return b|0}t[l>>2]=(t[(t[a>>2]|0)+20>>2]|0)+(t[c>>2]|0)+2;if((t[l>>2]|0)>>>0>(t[(t[a>>2]|0)+24>>2]|0)>>>0?(Cs(t[a>>2]|0,t[l>>2]|0)|0)==0:0){qs(t[a>>2]|0,138968);t[u>>2]=2;b=t[u>>2]|0;s=f;return b|0}GY((t[t[a>>2]>>2]|0)+(t[(t[a>>2]|0)+20>>2]|0)|0,t[o>>2]|0,t[c>>2]|0)|0;o=(t[a>>2]|0)+20|0;t[o>>2]=(t[o>>2]|0)+(t[c>>2]|0);n[(t[t[a>>2]>>2]|0)+(t[(t[a>>2]|0)+20>>2]|0)>>0]=0;c=t[a>>2]|0;if((t[(t[a>>2]|0)+24>>2]|0)>>>0<2147483647)t[(t[a>>2]|0)+8>>2]=t[c+24>>2];else t[c+8>>2]=2147483647;c=t[a>>2]|0;if((t[(t[a>>2]|0)+20>>2]|0)>>>0<2147483647)t[(t[a>>2]|0)+4>>2]=t[c+20>>2];else t[c+4>>2]=2147483647;t[u>>2]=0;b=t[u>>2]|0;s=f;return b|0}t[u>>2]=-1;b=t[u>>2]|0;s=f;return b|0}function Bs(e,i,r){e=e|0;i=i|0;r=r|0;var f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0;f=s;s=s+32|0;u=f+20|0;a=f+16|0;o=f+12|0;c=f+8|0;l=f+4|0;b=f;t[a>>2]=e;t[o>>2]=i;t[c>>2]=r;if((t[a>>2]|0)!=0?(t[(t[a>>2]|0)+32>>2]|0)==0:0){if((t[(t[a>>2]|0)+24>>2]|0)!=(t[(t[a>>2]|0)+8>>2]|0)?(t[(t[a>>2]|0)+8>>2]|0)>>>0<2147483647:0)t[(t[a>>2]|0)+24>>2]=t[(t[a>>2]|0)+8>>2];if((t[(t[a>>2]|0)+20>>2]|0)!=(t[(t[a>>2]|0)+4>>2]|0)?(t[(t[a>>2]|0)+4>>2]|0)>>>0<2147483647:0)t[(t[a>>2]|0)+20>>2]=t[(t[a>>2]|0)+4>>2];if((t[(t[a>>2]|0)+12>>2]|0)==2){t[u>>2]=-1;k=t[u>>2]|0;s=f;return k|0}if(!(t[o>>2]|0)){t[u>>2]=-1;k=t[u>>2]|0;s=f;return k|0}if((t[c>>2]|0)<-1){t[u>>2]=-1;k=t[u>>2]|0;s=f;return k|0}if(!(t[c>>2]|0)){t[u>>2]=0;k=t[u>>2]|0;s=f;return k|0}if((t[c>>2]|0)<0)t[c>>2]=rs(t[o>>2]|0)|0;if((t[c>>2]|0)<=0){t[u>>2]=-1;k=t[u>>2]|0;s=f;return k|0}if(((t[(t[a>>2]|0)+12>>2]|0)==3?(t[(t[a>>2]|0)+16>>2]|0)!=0:0)?(t[b>>2]=(t[t[a>>2]>>2]|0)-(t[(t[a>>2]|0)+16>>2]|0),(t[b>>2]|0)>>>0>(t[c>>2]|0)>>>0):0){b=t[a>>2]|0;t[b>>2]=(t[b>>2]|0)+(0-(t[c>>2]|0));GY(t[t[a>>2]>>2]|0,t[o>>2]|0,t[c>>2]|0)|0;b=(t[a>>2]|0)+20|0;t[b>>2]=(t[b>>2]|0)+(t[c>>2]|0);b=(t[a>>2]|0)+24|0;t[b>>2]=(t[b>>2]|0)+(t[c>>2]|0);b=t[a>>2]|0;if((t[(t[a>>2]|0)+24>>2]|0)>>>0<2147483647)t[(t[a>>2]|0)+8>>2]=t[b+24>>2];else t[b+8>>2]=2147483647;b=t[a>>2]|0;if((t[(t[a>>2]|0)+20>>2]|0)>>>0<2147483647)t[(t[a>>2]|0)+4>>2]=t[b+20>>2];else t[b+4>>2]=2147483647;t[u>>2]=0;k=t[u>>2]|0;s=f;return k|0}t[l>>2]=(t[(t[a>>2]|0)+20>>2]|0)+(t[c>>2]|0)+2;if((t[l>>2]|0)>>>0>(t[(t[a>>2]|0)+24>>2]|0)>>>0?(Cs(t[a>>2]|0,t[l>>2]|0)|0)==0:0){qs(t[a>>2]|0,138968);t[u>>2]=2;k=t[u>>2]|0;s=f;return k|0}GY((t[t[a>>2]>>2]|0)+(t[c>>2]|0)|0,t[t[a>>2]>>2]|0,t[(t[a>>2]|0)+20>>2]|0)|0;GY(t[t[a>>2]>>2]|0,t[o>>2]|0,t[c>>2]|0)|0;o=(t[a>>2]|0)+20|0;t[o>>2]=(t[o>>2]|0)+(t[c>>2]|0);n[(t[t[a>>2]>>2]|0)+(t[(t[a>>2]|0)+20>>2]|0)>>0]=0;c=t[a>>2]|0;if((t[(t[a>>2]|0)+24>>2]|0)>>>0<2147483647)t[(t[a>>2]|0)+8>>2]=t[c+24>>2];else t[c+8>>2]=2147483647;c=t[a>>2]|0;if((t[(t[a>>2]|0)+20>>2]|0)>>>0<2147483647)t[(t[a>>2]|0)+4>>2]=t[c+20>>2];else t[c+4>>2]=2147483647;t[u>>2]=0;k=t[u>>2]|0;s=f;return k|0}t[u>>2]=-1;k=t[u>>2]|0;s=f;return k|0}function Is(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0;r=s;s=s+16|0;n=r+8|0;f=r+4|0;u=r;t[f>>2]=e;t[u>>2]=i;if((t[f>>2]|0)!=0?(t[(t[f>>2]|0)+32>>2]|0)==0:0){if((t[(t[f>>2]|0)+24>>2]|0)!=(t[(t[f>>2]|0)+8>>2]|0)?(t[(t[f>>2]|0)+8>>2]|0)>>>0<2147483647:0)t[(t[f>>2]|0)+24>>2]=t[(t[f>>2]|0)+8>>2];if((t[(t[f>>2]|0)+20>>2]|0)!=(t[(t[f>>2]|0)+4>>2]|0)?(t[(t[f>>2]|0)+4>>2]|0)>>>0<2147483647:0)t[(t[f>>2]|0)+20>>2]=t[(t[f>>2]|0)+4>>2];if((t[(t[f>>2]|0)+12>>2]|0)==2){t[n>>2]=-1;a=t[n>>2]|0;s=r;return a|0}if(!(t[u>>2]|0)){t[n>>2]=-1;a=t[n>>2]|0;s=r;return a|0}else{t[n>>2]=Ps(t[f>>2]|0,t[u>>2]|0,-1)|0;a=t[n>>2]|0;s=r;return a|0}}t[n>>2]=-1;a=t[n>>2]|0;s=r;return a|0}function Hs(e,i){e=e|0;i=i|0;var r=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0;r=s;s=s+16|0;f=r+12|0;u=r+8|0;a=r+4|0;o=r;t[u>>2]=e;t[a>>2]=i;if((t[u>>2]|0)!=0?(t[(t[u>>2]|0)+32>>2]|0)==0:0){if((t[(t[u>>2]|0)+24>>2]|0)!=(t[(t[u>>2]|0)+8>>2]|0)?(t[(t[u>>2]|0)+8>>2]|0)>>>0<2147483647:0)t[(t[u>>2]|0)+24>>2]=t[(t[u>>2]|0)+8>>2];if((t[(t[u>>2]|0)+20>>2]|0)!=(t[(t[u>>2]|0)+4>>2]|0)?(t[(t[u>>2]|0)+4>>2]|0)>>>0<2147483647:0)t[(t[u>>2]|0)+20>>2]=t[(t[u>>2]|0)+4>>2];if((t[(t[u>>2]|0)+12>>2]|0)==2){t[f>>2]=-1;c=t[f>>2]|0;s=r;return c|0}if(!(t[a>>2]|0)){t[f>>2]=-1;c=t[f>>2]|0;s=r;return c|0}t[o>>2]=t[a>>2];while(1){l=t[(t[u>>2]|0)+20>>2]|0;if(!(n[t[o>>2]>>0]|0))break;if((l+10|0)>>>0>=(t[(t[u>>2]|0)+24>>2]|0)>>>0?(Cs(t[u>>2]|0,(t[(t[u>>2]|0)+20>>2]|0)+10|0)|0)==0:0){b=18;break}a=n[t[o>>2]>>0]|0;i=(t[u>>2]|0)+20|0;e=t[i>>2]|0;t[i>>2]=e+1;n[(t[t[u>>2]>>2]|0)+e>>0]=a;t[o>>2]=(t[o>>2]|0)+1}if((b|0)==18){qs(t[u>>2]|0,138968);t[f>>2]=2;c=t[f>>2]|0;s=r;return c|0}n[(t[t[u>>2]>>2]|0)+l>>0]=0;l=t[u>>2]|0;if((t[(t[u>>2]|0)+24>>2]|0)>>>0<2147483647)t[(t[u>>2]|0)+8>>2]=t[l+24>>2];else t[l+8>>2]=2147483647;l=t[u>>2]|0;if((t[(t[u>>2]|0)+20>>2]|0)>>>0<2147483647)t[(t[u>>2]|0)+4>>2]=t[l+20>>2];else t[l+4>>2]=2147483647;t[f>>2]=0;c=t[f>>2]|0;s=r;return c|0}t[f>>2]=-1;c=t[f>>2]|0;s=r;return c|0}function xs(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,a=0,o=0,c=0,l=0;r=s;s=s+32|0;n=r+16|0;f=r+12|0;a=r+8|0;o=r+4|0;c=r;t[f>>2]=e;t[a>>2]=i;if((t[f>>2]|0)!=0?(t[(t[f>>2]|0)+32>>2]|0)==0:0){if((t[(t[f>>2]|0)+24>>2]|0)!=(t[(t[f>>2]|0)+8>>2]|0)?(t[(t[f>>2]|0)+8>>2]|0)>>>0<2147483647:0)t[(t[f>>2]|0)+24>>2]=t[(t[f>>2]|0)+8>>2];if((t[(t[f>>2]|0)+20>>2]|0)!=(t[(t[f>>2]|0)+4>>2]|0)?(t[(t[f>>2]|0)+4>>2]|0)>>>0<2147483647:0)t[(t[f>>2]|0)+20>>2]=t[(t[f>>2]|0)+4>>2];if((t[(t[f>>2]|0)+12>>2]|0)==2){t[n>>2]=-1;l=t[n>>2]|0;s=r;return l|0}do if(es(t[a>>2]|0,34)|0){i=(es(t[a>>2]|0,39)|0)!=0;e=t[f>>2]|0;if(!i){Hs(e,139e3)|0;Is(t[f>>2]|0,t[a>>2]|0)|0;Hs(t[f>>2]|0,139e3)|0;break}Hs(e,138984)|0;e=t[a>>2]|0;t[o>>2]=e;t[c>>2]=e;while(1){if(!(u[t[o>>2]>>0]|0))break;if((u[t[o>>2]>>0]|0|0)!=34){t[o>>2]=(t[o>>2]|0)+1;continue}if((t[c>>2]|0)!=(t[o>>2]|0))Ps(t[f>>2]|0,t[c>>2]|0,(t[o>>2]|0)-(t[c>>2]|0)|0)|0;Ps(t[f>>2]|0,138992,6)|0;t[o>>2]=(t[o>>2]|0)+1;t[c>>2]=t[o>>2]}if((t[c>>2]|0)!=(t[o>>2]|0))Ps(t[f>>2]|0,t[c>>2]|0,(t[o>>2]|0)-(t[c>>2]|0)|0)|0;Hs(t[f>>2]|0,138984)|0}else{Hs(t[f>>2]|0,138984)|0;Is(t[f>>2]|0,t[a>>2]|0)|0;Hs(t[f>>2]|0,138984)|0}while(0);t[n>>2]=0;l=t[n>>2]|0;s=r;return l|0}t[n>>2]=-1;l=t[n>>2]|0;s=r;return l|0}function Us(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0;r=s;s=s+16|0;n=r+12|0;f=r+8|0;u=r+4|0;a=r;t[f>>2]=e;t[u>>2]=i;t[a>>2]=0;if((t[f>>2]|0)!=0?(t[(t[f>>2]|0)+32>>2]|0)==0:0){if((t[(t[f>>2]|0)+24>>2]|0)!=(t[(t[f>>2]|0)+8>>2]|0)?(t[(t[f>>2]|0)+8>>2]|0)>>>0<2147483647:0)t[(t[f>>2]|0)+24>>2]=t[(t[f>>2]|0)+8>>2];if((t[(t[f>>2]|0)+20>>2]|0)!=(t[(t[f>>2]|0)+4>>2]|0)?(t[(t[f>>2]|0)+4>>2]|0)>>>0<2147483647:0)t[(t[f>>2]|0)+20>>2]=t[(t[f>>2]|0)+4>>2];if(((t[u>>2]|0)!=0?(t[t[u>>2]>>2]|0)!=0:0)?(t[(t[u>>2]|0)+4>>2]|0)>>>0>0:0)t[a>>2]=Ps(t[f>>2]|0,t[t[u>>2]>>2]|0,t[(t[u>>2]|0)+4>>2]|0)|0;yF(t[u>>2]|0);t[n>>2]=t[a>>2];o=t[n>>2]|0;s=r;return o|0}yF(t[u>>2]|0);t[n>>2]=-1;o=t[n>>2]|0;s=r;return o|0}function zs(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0;r=s;s=s+16|0;n=r+8|0;f=r+4|0;u=r;t[f>>2]=e;t[u>>2]=i;if(!((t[u>>2]|0)==0|(t[f>>2]|0)==0)?(t[(t[f>>2]|0)+32>>2]|0)==0:0){if((t[(t[f>>2]|0)+24>>2]|0)!=(t[(t[f>>2]|0)+8>>2]|0)?(t[(t[f>>2]|0)+8>>2]|0)>>>0<2147483647:0)t[(t[f>>2]|0)+24>>2]=t[(t[f>>2]|0)+8>>2];if((t[(t[f>>2]|0)+20>>2]|0)!=(t[(t[f>>2]|0)+4>>2]|0)?(t[(t[f>>2]|0)+4>>2]|0)>>>0<2147483647:0)t[(t[f>>2]|0)+20>>2]=t[(t[f>>2]|0)+4>>2];i=t[t[f>>2]>>2]|0;t[(t[u>>2]|0)+16>>2]=i;t[(t[u>>2]|0)+12>>2]=i;t[(t[u>>2]|0)+20>>2]=(t[t[f>>2]>>2]|0)+(t[(t[f>>2]|0)+20>>2]|0);t[n>>2]=0;a=t[n>>2]|0;s=r;return a|0}t[n>>2]=-1;a=t[n>>2]|0;s=r;return a|0}function js(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0;r=s;s=s+16|0;n=r+12|0;f=r+8|0;u=r+4|0;a=r;t[f>>2]=e;t[u>>2]=i;if(!((t[u>>2]|0)==0|(t[f>>2]|0)==0)?(t[(t[f>>2]|0)+32>>2]|0)==0:0){if((t[(t[f>>2]|0)+24>>2]|0)!=(t[(t[f>>2]|0)+8>>2]|0)?(t[(t[f>>2]|0)+8>>2]|0)>>>0<2147483647:0)t[(t[f>>2]|0)+24>>2]=t[(t[f>>2]|0)+8>>2];if((t[(t[f>>2]|0)+20>>2]|0)!=(t[(t[f>>2]|0)+4>>2]|0)?(t[(t[f>>2]|0)+4>>2]|0)>>>0<2147483647:0)t[(t[f>>2]|0)+20>>2]=t[(t[f>>2]|0)+4>>2];t[a>>2]=(t[(t[u>>2]|0)+12>>2]|0)-(t[t[f>>2]>>2]|0);if((t[a>>2]|0)>>>0>(t[(t[f>>2]|0)+24>>2]|0)>>>0){Gs(t[f>>2]|0,139008);t[a>>2]=0}t[n>>2]=t[a>>2];o=t[n>>2]|0;s=r;return o|0}t[n>>2]=-1;o=t[n>>2]|0;s=r;return o|0}function Vs(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,u=0,a=0,o=0,c=0,l=0,b=0;f=s;s=s+32|0;u=f+16|0;a=f+12|0;o=f+8|0;c=f+4|0;l=f;t[a>>2]=e;t[o>>2]=i;t[c>>2]=r;t[l>>2]=n;if(!((t[o>>2]|0)==0|(t[a>>2]|0)==0)?(t[(t[a>>2]|0)+32>>2]|0)==0:0){if((t[(t[a>>2]|0)+24>>2]|0)!=(t[(t[a>>2]|0)+8>>2]|0)?(t[(t[a>>2]|0)+8>>2]|0)>>>0<2147483647:0)t[(t[a>>2]|0)+24>>2]=t[(t[a>>2]|0)+8>>2];if((t[(t[a>>2]|0)+20>>2]|0)!=(t[(t[a>>2]|0)+4>>2]|0)?(t[(t[a>>2]|0)+4>>2]|0)>>>0<2147483647:0)t[(t[a>>2]|0)+20>>2]=t[(t[a>>2]|0)+4>>2];t[(t[o>>2]|0)+12>>2]=(t[t[a>>2]>>2]|0)+(t[c>>2]|0);t[(t[o>>2]|0)+16>>2]=(t[(t[o>>2]|0)+12>>2]|0)+(t[l>>2]|0);t[(t[o>>2]|0)+20>>2]=(t[t[a>>2]>>2]|0)+(t[(t[a>>2]|0)+20>>2]|0);t[u>>2]=0;b=t[u>>2]|0;s=f;return b|0}t[u>>2]=-1;b=t[u>>2]|0;s=f;return b|0}function qs(e,i){e=e|0;i=i|0;var r=0,n=0,f=0;r=s;s=s+16|0;n=r+4|0;f=r;t[n>>2]=e;t[f>>2]=i;dp(29,2,0,0,t[f>>2]|0);if(!(t[n>>2]|0)){s=r;return}if(t[(t[n>>2]|0)+32>>2]|0){s=r;return}t[(t[n>>2]|0)+32>>2]=2;s=r;return}function Ys(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0;r=s;s=s+32|0;n=r+20|0;f=r+16|0;u=r+12|0;a=r+8|0;o=r+4|0;c=r;t[f>>2]=e;t[u>>2]=i;if((t[f>>2]|0)!=0?(t[(t[f>>2]|0)+32>>2]|0)==0:0){if((t[(t[f>>2]|0)+24>>2]|0)!=(t[(t[f>>2]|0)+8>>2]|0)?(t[(t[f>>2]|0)+8>>2]|0)>>>0<2147483647:0)t[(t[f>>2]|0)+24>>2]=t[(t[f>>2]|0)+8>>2];if((t[(t[f>>2]|0)+20>>2]|0)!=(t[(t[f>>2]|0)+4>>2]|0)?(t[(t[f>>2]|0)+4>>2]|0)>>>0<2147483647:0)t[(t[f>>2]|0)+20>>2]=t[(t[f>>2]|0)+4>>2];if((t[(t[f>>2]|0)+12>>2]|0)==2){t[n>>2]=0;l=t[n>>2]|0;s=r;return l|0}i=t[(t[f>>2]|0)+24>>2]|0;if(((t[(t[f>>2]|0)+20>>2]|0)+(t[u>>2]|0)|0)>>>0<(t[(t[f>>2]|0)+24>>2]|0)>>>0){t[n>>2]=i-(t[(t[f>>2]|0)+20>>2]|0);l=t[n>>2]|0;s=r;return l|0}e=t[f>>2]|0;if(i>>>0>(t[u>>2]|0)>>>0)t[a>>2]=t[e+24>>2]<<1;else t[a>>2]=(t[e+20>>2]|0)+(t[u>>2]|0)+100;do if((t[(t[f>>2]|0)+12>>2]|0)==3?(t[(t[f>>2]|0)+16>>2]|0)!=0:0){t[c>>2]=(t[t[f>>2]>>2]|0)-(t[(t[f>>2]|0)+16>>2]|0);t[o>>2]=MAi[t[135760>>2]&511](t[(t[f>>2]|0)+16>>2]|0,(t[c>>2]|0)+(t[a>>2]|0)|0)|0;if(t[o>>2]|0){t[(t[f>>2]|0)+16>>2]=t[o>>2];t[t[f>>2]>>2]=(t[o>>2]|0)+(t[c>>2]|0);break}qs(t[f>>2]|0,138968);t[n>>2]=0;l=t[n>>2]|0;s=r;return l|0}else b=22;while(0);do if((b|0)==22){t[o>>2]=MAi[t[135760>>2]&511](t[t[f>>2]>>2]|0,t[a>>2]|0)|0;if(t[o>>2]|0){t[t[f>>2]>>2]=t[o>>2];break}qs(t[f>>2]|0,138968);t[n>>2]=0;l=t[n>>2]|0;s=r;return l|0}while(0);t[(t[f>>2]|0)+24>>2]=t[a>>2];a=t[f>>2]|0;if((t[(t[f>>2]|0)+24>>2]|0)>>>0<2147483647)t[(t[f>>2]|0)+8>>2]=t[a+24>>2];else t[a+8>>2]=2147483647;a=t[f>>2]|0;if((t[(t[f>>2]|0)+20>>2]|0)>>>0<2147483647)t[(t[f>>2]|0)+4>>2]=t[a+20>>2];else t[a+4>>2]=2147483647;t[n>>2]=(t[(t[f>>2]|0)+24>>2]|0)-(t[(t[f>>2]|0)+20>>2]|0);l=t[n>>2]|0;s=r;return l|0}t[n>>2]=0;l=t[n>>2]|0;s=r;return l|0}function Gs(e,i){e=e|0;i=i|0;var r=0,n=0,f=0;r=s;s=s+16|0;n=r+4|0;f=r;t[n>>2]=e;t[f>>2]=i;dp(29,7e3,0,0,t[f>>2]|0);if(!(t[n>>2]|0)){s=r;return}if(t[(t[n>>2]|0)+32>>2]|0){s=r;return}t[(t[n>>2]|0)+32>>2]=7e3;s=r;return}function Ws(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,l=0;n=s;s=s+32|0;f=n+16|0;u=n+12|0;a=n+8|0;o=n+4|0;c=n;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;if(!(t[u>>2]|0)){t[f>>2]=0;l=t[f>>2]|0;s=n;return l|0}if((t[(t[u>>2]|0)+40>>2]|0)==0?(t[(t[u>>2]|0)+8>>2]|0)==0:0){t[f>>2]=0;l=t[f>>2]|0;s=n;return l|0}t[c>>2]=gAi[t[135744>>2]&511](92)|0;if(!(t[c>>2]|0)){Eb(0,139048);t[f>>2]=0;l=t[f>>2]|0;s=n;return l|0}r=(t[c>>2]|0)+0|0;i=r+92|0;do{t[r>>2]=0;r=r+4|0}while((r|0)<(i|0));t[(t[c>>2]|0)+64>>2]=0;t[(t[c>>2]|0)+56>>2]=0;t[(t[c>>2]|0)+4>>2]=1;t[(t[c>>2]|0)+32>>2]=0;t[(t[c>>2]|0)+36>>2]=0;t[(t[c>>2]|0)+40>>2]=0;t[t[c>>2]>>2]=0;t[(t[c>>2]|0)+8>>2]=t[u>>2];if(!(t[(t[u>>2]|0)+40>>2]|0))t[(t[c>>2]|0)+20>>2]=t[t[(t[u>>2]|0)+8>>2]>>2];t[(t[c>>2]|0)+24>>2]=0;t[(t[c>>2]|0)+28>>2]=0;t[(t[c>>2]|0)+12>>2]=t[a>>2];t[(t[c>>2]|0)+16>>2]=t[o>>2];do if((t[(t[u>>2]|0)+20>>2]|0)>0){o=gAi[t[135744>>2]&511](t[(t[u>>2]|0)+20>>2]<<2<<1)|0;t[(t[c>>2]|0)+44>>2]=o;if(t[(t[c>>2]|0)+44>>2]|0){VY(t[(t[c>>2]|0)+44>>2]|0,0,t[(t[u>>2]|0)+20>>2]<<2<<1|0)|0;t[(t[c>>2]|0)+84>>2]=(t[(t[c>>2]|0)+44>>2]|0)+(t[(t[u>>2]|0)+20>>2]<<2);break}Eb(0,139048);pAi[t[135736>>2]&511](t[c>>2]|0);t[f>>2]=0;l=t[f>>2]|0;s=n;return l|0}else{t[(t[c>>2]|0)+44>>2]=0;t[(t[c>>2]|0)+84>>2]=0}while(0);t[(t[c>>2]|0)+48>>2]=0;t[(t[c>>2]|0)+52>>2]=0;t[(t[c>>2]|0)+68>>2]=0;t[(t[c>>2]|0)+72>>2]=-1;t[(t[c>>2]|0)+80>>2]=0;t[(t[c>>2]|0)+88>>2]=0;t[f>>2]=t[c>>2];l=t[f>>2]|0;s=n;return l|0}function Ks(e){e=e|0;var i=0,r=0,n=0,f=0;i=s;s=s+16|0;r=i+8|0;n=i+4|0;f=i;t[r>>2]=e;if(!(t[r>>2]|0)){s=i;return}if(t[(t[r>>2]|0)+40>>2]|0){e:do if(t[(t[r>>2]|0)+44>>2]|0){t[n>>2]=0;while(1){if((t[n>>2]|0)>=(t[(t[r>>2]|0)+32>>2]|0))break e;if(t[(t[(t[r>>2]|0)+40>>2]|0)+(t[n>>2]<<4)+12>>2]|0)pAi[t[135736>>2]&511](t[(t[(t[r>>2]|0)+40>>2]|0)+(t[n>>2]<<4)+12>>2]|0);t[n>>2]=(t[n>>2]|0)+1}}while(0);pAi[t[135736>>2]&511](t[(t[r>>2]|0)+40>>2]|0)}if(t[(t[r>>2]|0)+44>>2]|0)pAi[t[135736>>2]&511](t[(t[r>>2]|0)+44>>2]|0);if(t[(t[r>>2]|0)+68>>2]|0){t[f>>2]=0;while(1){if((t[f>>2]|0)>=(t[(t[r>>2]|0)+52>>2]|0))break;if(t[(t[(t[r>>2]|0)+68>>2]|0)+(t[f>>2]<<3)>>2]|0)pAi[t[135736>>2]&511](t[(t[(t[r>>2]|0)+68>>2]|0)+(t[f>>2]<<3)>>2]|0);t[f>>2]=(t[f>>2]|0)+1}pAi[t[135736>>2]&511](t[(t[r>>2]|0)+68>>2]|0)}if(t[(t[r>>2]|0)+80>>2]|0)pAi[t[135736>>2]&511](t[(t[r>>2]|0)+80>>2]|0);pAi[t[135736>>2]&511](t[r>>2]|0);s=i;return}function Xs(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0;n=s;s=s+16|0;f=n+8|0;u=n+4|0;a=n;t[f>>2]=e;t[u>>2]=i;t[a>>2]=r;r=Sb(t[f>>2]|0,t[u>>2]|0,t[a>>2]|0,0)|0;s=n;return r|0}function Zs(e,i,r,f){e=e|0;i=i|0;r=r|0;f=f|0;var u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0;u=s;s=s+192|0;a=u+32|0;o=u+28|0;c=u+24|0;l=u+20|0;b=u+16|0;k=u+36|0;h=u+12|0;w=u+8|0;d=u+4|0;v=u;t[o>>2]=e;t[c>>2]=i;t[l>>2]=r;t[b>>2]=f;if(!(t[o>>2]|0)){t[a>>2]=-1;m=t[a>>2]|0;s=u;return m|0}if(!(t[(t[o>>2]|0)+8>>2]|0)){t[a>>2]=-1;m=t[a>>2]|0;s=u;return m|0}if(t[t[o>>2]>>2]|0){t[a>>2]=t[t[o>>2]>>2];m=t[a>>2]|0;s=u;return m|0}if(!(t[l>>2]|0)){t[a>>2]=Xs(t[o>>2]|0,t[c>>2]|0,t[b>>2]|0)|0;m=t[a>>2]|0;s=u;return m|0}t[h>>2]=HY(t[l>>2]|0)|0;t[w>>2]=HY(t[c>>2]|0)|0;if(150<((t[h>>2]|0)+(t[w>>2]|0)+2|0)){t[v>>2]=gAi[t[135752>>2]&511]((t[h>>2]|0)+(t[w>>2]|0)+2|0)|0;if(!(t[v>>2]|0)){t[t[o>>2]>>2]=-1;t[a>>2]=-1;m=t[a>>2]|0;s=u;return m|0}}else t[v>>2]=k;YY(t[v>>2]|0,t[c>>2]|0,t[w>>2]|0)|0;n[(t[v>>2]|0)+(t[w>>2]|0)>>0]=124;YY((t[v>>2]|0)+((t[w>>2]|0)+1)|0,t[l>>2]|0,t[h>>2]|0)|0;n[(t[v>>2]|0)+((t[h>>2]|0)+(t[w>>2]|0)+1)>>0]=0;w=t[o>>2]|0;if(t[(t[(t[o>>2]|0)+8>>2]|0)+40>>2]|0)t[d>>2]=gb(w,t[(t[o>>2]|0)+8>>2]|0,t[v>>2]|0,t[b>>2]|0)|0;else t[d>>2]=Sb(w,t[v>>2]|0,t[b>>2]|0,1)|0;if((t[v>>2]|0)!=(k|0))pAi[t[135736>>2]&511](t[v>>2]|0);t[a>>2]=t[d>>2];m=t[a>>2]|0;s=u;return m|0}function Js(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;var u=0,a=0,o=0,c=0,l=0,b=0;u=s;s=s+32|0;a=u+16|0;o=u+12|0;c=u+8|0;l=u+4|0;b=u;t[a>>2]=e;t[o>>2]=i;t[c>>2]=r;t[l>>2]=n;t[b>>2]=f;f=yb(t[a>>2]|0,0,t[o>>2]|0,t[c>>2]|0,t[l>>2]|0,t[b>>2]|0)|0;s=u;return f|0}function Qs(e,i,r,n,f,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;u=u|0;var a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0;a=s;s=s+32|0;o=a+24|0;c=a+20|0;l=a+16|0;b=a+12|0;k=a+8|0;h=a+4|0;w=a;t[c>>2]=e;t[l>>2]=i;t[b>>2]=r;t[k>>2]=n;t[h>>2]=f;t[w>>2]=u;if(!(t[c>>2]|0)){t[o>>2]=-1;d=t[o>>2]|0;s=a;return d|0}do if(t[l>>2]|0)if(t[t[c>>2]>>2]|0){t[t[l>>2]>>2]=t[(t[c>>2]|0)+80>>2];break}else{t[t[l>>2]>>2]=0;break}while(0);t[o>>2]=yb(t[c>>2]|0,1,t[b>>2]|0,t[k>>2]|0,t[h>>2]|0,t[w>>2]|0)|0;d=t[o>>2]|0;s=a;return d|0}function $s(e){e=e|0;var i=0,r=0,n=0,f=0,a=0,o=0;i=s;s=s+16|0;r=i+12|0;n=i+8|0;f=i+4|0;a=i;t[n>>2]=e;t[a>>2]=Fb(t[n>>2]|0)|0;if(!(t[a>>2]|0)){t[r>>2]=0;o=t[r>>2]|0;s=i;return o|0}t[(t[a>>2]|0)+20>>2]=0;n=Ob(t[a>>2]|0)|0;t[(t[a>>2]|0)+24>>2]=n;t[(t[a>>2]|0)+16>>2]=n;Ab(t[a>>2]|0,t[(t[a>>2]|0)+16>>2]|0)|0;Mb(t[a>>2]|0,1);if(u[t[(t[a>>2]|0)+4>>2]>>0]|0){t[(t[a>>2]|0)+8>>2]=1450;Rb(t[a>>2]|0,139080)}n=t[a>>2]|0;if(t[(t[a>>2]|0)+8>>2]|0){Nb(n);t[r>>2]=0;o=t[r>>2]|0;s=i;return o|0}t[(t[a>>2]|0)+20>>2]=t[n+24>>2];t[t[(t[a>>2]|0)+16>>2]>>2]=1;t[t[(t[a>>2]|0)+20>>2]>>2]=2;Tb(t[a>>2]|0);n=t[a>>2]|0;if(t[(t[a>>2]|0)+8>>2]|0){Nb(n);t[r>>2]=0;o=t[r>>2]|0;s=i;return o|0}else{t[f>>2]=Lb(n)|0;Nb(t[a>>2]|0);t[r>>2]=t[f>>2];o=t[r>>2]|0;s=i;return o|0}return 0}function eb(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0;r=s;s=s+16|0;n=r+8|0;f=r+4|0;u=r;t[f>>2]=e;t[u>>2]=i;if((t[f>>2]|0)==0|(t[u>>2]|0)==0){t[n>>2]=-1;a=t[n>>2]|0;s=r;return a|0}else{t[n>>2]=Db(t[f>>2]|0,t[u>>2]|0)|0;a=t[n>>2]|0;s=r;return a|0}return 0}function ib(e){e=e|0;var i=0,r=0,n=0,f=0,u=0,a=0,o=0;i=s;s=s+32|0;r=i+16|0;n=i+12|0;f=i+8|0;u=i+4|0;a=i;t[n>>2]=e;if(!(t[n>>2]|0)){t[r>>2]=-1;o=t[r>>2]|0;s=i;return o|0}if((t[(t[n>>2]|0)+28>>2]|0)!=-1){t[r>>2]=t[(t[n>>2]|0)+28>>2];o=t[r>>2]|0;s=i;return o|0}t[f>>2]=rb()|0;if(t[(t[f>>2]|0)+52>>2]|0){t[a>>2]=0;while(1){if((t[a>>2]|0)>=(t[(t[f>>2]|0)+48>>2]|0))break;Cb(t[(t[(t[f>>2]|0)+52>>2]|0)+(t[a>>2]<<2)>>2]|0);t[a>>2]=(t[a>>2]|0)+1}pAi[t[135736>>2]&511](t[(t[f>>2]|0)+52>>2]|0)}t[(t[f>>2]|0)+36>>2]=t[(t[n>>2]|0)+12>>2];t[(t[f>>2]|0)+40>>2]=t[(t[n>>2]|0)+16>>2];t[(t[f>>2]|0)+48>>2]=t[(t[n>>2]|0)+4>>2];t[(t[f>>2]|0)+52>>2]=t[(t[n>>2]|0)+8>>2];t[(t[f>>2]|0)+68>>2]=-1;t[(t[f>>2]|0)+76>>2]=t[(t[n>>2]|0)+32>>2];t[u>>2]=Pb(t[f>>2]|0)|0;t[(t[f>>2]|0)+40>>2]=0;t[(t[f>>2]|0)+52>>2]=0;nb(t[f>>2]|0);t[(t[n>>2]|0)+28>>2]=t[u>>2];t[r>>2]=t[u>>2];o=t[r>>2]|0;s=i;return o|0}function rb(){var e=0,i=0,r=0,n=0,f=0,u=0;e=s;s=s+16|0;i=e+4|0;r=e;t[r>>2]=Fb(0)|0;if(!(t[r>>2]|0)){t[i>>2]=0;n=t[i>>2]|0;s=e;return n|0}t[(t[r>>2]|0)+20>>2]=0;f=Ob(t[r>>2]|0)|0;t[(t[r>>2]|0)+24>>2]=f;t[(t[r>>2]|0)+16>>2]=f;f=t[r>>2]|0;if(!(t[(t[r>>2]|0)+16>>2]|0)){nb(f);t[i>>2]=0;n=t[i>>2]|0;s=e;return n|0}t[t[f+16>>2]>>2]=1;f=(Ab(t[r>>2]|0,t[(t[r>>2]|0)+16>>2]|0)|0)<0;u=t[r>>2]|0;if(f){Cb(t[u+16>>2]|0);nb(t[r>>2]|0);t[i>>2]=0;n=t[i>>2]|0;s=e;return n|0}else{t[u+76>>2]=0;t[i>>2]=t[r>>2];n=t[i>>2]|0;s=e;return n|0}return 0}function nb(e){e=e|0;var i=0,r=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if(!(t[r>>2]|0)){s=i;return}Nb(t[r>>2]|0);s=i;return}function fb(e){e=e|0;var i=0,r=0,n=0,f=0;i=s;s=s+16|0;r=i+4|0;n=i;t[r>>2]=e;if(!(t[r>>2]|0)){s=i;return}if(t[t[r>>2]>>2]|0)pAi[t[135736>>2]&511](t[t[r>>2]>>2]|0);if(t[(t[r>>2]|0)+8>>2]|0){t[n>>2]=0;while(1){if((t[n>>2]|0)>=(t[(t[r>>2]|0)+4>>2]|0))break;Cb(t[(t[(t[r>>2]|0)+8>>2]|0)+(t[n>>2]<<2)>>2]|0);t[n>>2]=(t[n>>2]|0)+1}pAi[t[135736>>2]&511](t[(t[r>>2]|0)+8>>2]|0)}if(t[(t[r>>2]|0)+16>>2]|0){t[n>>2]=0;while(1){if((t[n>>2]|0)>=(t[(t[r>>2]|0)+12>>2]|0))break;Bb(t[(t[(t[r>>2]|0)+16>>2]|0)+(t[n>>2]<<2)>>2]|0);t[n>>2]=(t[n>>2]|0)+1}pAi[t[135736>>2]&511](t[(t[r>>2]|0)+16>>2]|0)}if(t[(t[r>>2]|0)+24>>2]|0)pAi[t[135736>>2]&511](t[(t[r>>2]|0)+24>>2]|0);if(t[(t[r>>2]|0)+40>>2]|0)pAi[t[135736>>2]&511](t[(t[r>>2]|0)+40>>2]|0);if(t[(t[r>>2]|0)+44>>2]|0)pAi[t[135736>>2]&511](t[(t[r>>2]|0)+44>>2]|0);if(t[(t[r>>2]|0)+52>>2]|0){t[n>>2]=0;while(1){f=t[33934]|0;if((t[n>>2]|0)>=(t[(t[r>>2]|0)+48>>2]|0))break;pAi[f&511](t[(t[(t[r>>2]|0)+52>>2]|0)+(t[n>>2]<<2)>>2]|0);t[n>>2]=(t[n>>2]|0)+1}pAi[f&511](t[(t[r>>2]|0)+52>>2]|0)}pAi[t[135736>>2]&511](t[r>>2]|0);s=i;return}function tb(e,i){e=e|0;i=i|0;var r=0,n=0,f=0;r=s;s=s+16|0;n=r+4|0;f=r;t[n>>2]=e;t[f>>2]=i;if(!(t[n>>2]|0)){s=r;return}i=(t[n>>2]|0)+76|0;t[i>>2]=t[i>>2]|t[f>>2];s=r;return}function ub(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i+4|0;n=i;t[n>>2]=e;if(!(t[n>>2]|0))t[r>>2]=0;else t[r>>2]=t[(t[n>>2]|0)+16>>2];s=i;return t[r>>2]|0}function ab(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0;r=s;s=s+16|0;n=r+8|0;f=r+4|0;u=r;t[f>>2]=e;t[u>>2]=i;if((t[f>>2]|0)==0|(t[u>>2]|0)==0){t[n>>2]=-1;a=t[n>>2]|0;s=r;return a|0}else{t[t[u>>2]>>2]=2;t[n>>2]=0;a=t[n>>2]|0;s=r;return a|0}return 0}function ob(e,i,r,n,f){e=e|0;i=i|0;r=r|0;
	n=n|0;f=f|0;var u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0;u=s;s=s+32|0;a=u+24|0;o=u+20|0;c=u+16|0;l=u+12|0;b=u+8|0;k=u+4|0;h=u;t[o>>2]=e;t[c>>2]=i;t[l>>2]=r;t[b>>2]=n;t[k>>2]=f;if((t[o>>2]|0)==0|(t[c>>2]|0)==0|(t[b>>2]|0)==0){t[a>>2]=0;w=t[a>>2]|0;s=u;return w|0}t[h>>2]=Ib(t[o>>2]|0,5)|0;if(!(t[h>>2]|0)){t[a>>2]=0;w=t[a>>2]|0;s=u;return w|0}t[(t[h>>2]|0)+60>>2]=t[k>>2];k=Yl(t[b>>2]|0)|0;t[(t[h>>2]|0)+20>>2]=k;if((Hb(t[o>>2]|0,t[c>>2]|0,t[l>>2]|0,t[h>>2]|0)|0)<0){Bb(t[h>>2]|0);t[a>>2]=0;w=t[a>>2]|0;s=u;return w|0}if(!(t[l>>2]|0)){t[a>>2]=t[(t[o>>2]|0)+24>>2];w=t[a>>2]|0;s=u;return w|0}else{t[a>>2]=t[l>>2];w=t[a>>2]|0;s=u;return w|0}return 0}function cb(e,i,r,f,a,o){e=e|0;i=i|0;r=r|0;f=f|0;a=a|0;o=o|0;var c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0,S=0,g=0;c=s;s=s+48|0;l=c+40|0;b=c+36|0;k=c+32|0;h=c+28|0;w=c+24|0;d=c+20|0;v=c+16|0;m=c+12|0;_=c+8|0;p=c+4|0;E=c;t[b>>2]=e;t[k>>2]=i;t[h>>2]=r;t[w>>2]=f;t[d>>2]=a;t[v>>2]=o;if((t[b>>2]|0)==0|(t[k>>2]|0)==0|(t[w>>2]|0)==0){t[l>>2]=0;S=t[l>>2]|0;s=c;return S|0}t[m>>2]=Ib(t[b>>2]|0,5)|0;if(!(t[m>>2]|0)){t[l>>2]=0;S=t[l>>2]|0;s=c;return S|0}t[(t[m>>2]|0)+60>>2]=t[v>>2];do if((t[d>>2]|0)!=0?(u[t[d>>2]>>0]|0|0)!=0:0){t[_>>2]=HY(t[d>>2]|0)|0;t[p>>2]=HY(t[w>>2]|0)|0;t[E>>2]=gAi[t[135752>>2]&511]((t[_>>2]|0)+(t[p>>2]|0)+2|0)|0;if(t[E>>2]|0){YY(t[E>>2]|0,t[w>>2]|0,t[p>>2]|0)|0;n[(t[E>>2]|0)+(t[p>>2]|0)>>0]=124;YY((t[E>>2]|0)+((t[p>>2]|0)+1)|0,t[d>>2]|0,t[_>>2]|0)|0;n[(t[E>>2]|0)+((t[_>>2]|0)+(t[p>>2]|0)+1)>>0]=0;t[(t[m>>2]|0)+20>>2]=t[E>>2];break}Bb(t[m>>2]|0);t[l>>2]=0;S=t[l>>2]|0;s=c;return S|0}else g=7;while(0);if((g|0)==7){g=Yl(t[w>>2]|0)|0;t[(t[m>>2]|0)+20>>2]=g}if((Hb(t[b>>2]|0,t[k>>2]|0,t[h>>2]|0,t[m>>2]|0)|0)<0){Bb(t[m>>2]|0);t[l>>2]=0;S=t[l>>2]|0;s=c;return S|0}if(!(t[h>>2]|0)){t[l>>2]=t[(t[b>>2]|0)+24>>2];S=t[l>>2]|0;s=c;return S|0}else{t[l>>2]=t[h>>2];S=t[l>>2]|0;s=c;return S|0}return 0}function lb(e,i,r,f,a,o){e=e|0;i=i|0;r=r|0;f=f|0;a=a|0;o=o|0;var c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0,S=0,g=0,y=0,F=0;c=s;s=s+256|0;l=c;b=c+44|0;k=c+40|0;h=c+36|0;w=c+32|0;d=c+28|0;v=c+24|0;m=c+20|0;_=c+16|0;p=c+48|0;E=c+12|0;S=c+8|0;g=c+4|0;t[k>>2]=e;t[h>>2]=i;t[w>>2]=r;t[d>>2]=f;t[v>>2]=a;t[m>>2]=o;if((t[k>>2]|0)==0|(t[h>>2]|0)==0|(t[d>>2]|0)==0){t[b>>2]=0;y=t[b>>2]|0;s=c;return y|0}t[_>>2]=Ib(t[k>>2]|0,5)|0;if(!(t[_>>2]|0)){t[b>>2]=0;y=t[b>>2]|0;s=c;return y|0}t[(t[_>>2]|0)+60>>2]=t[m>>2];t[(t[_>>2]|0)+28>>2]=1;do if((t[v>>2]|0)!=0?(u[t[v>>2]>>0]|0|0)!=0:0){t[E>>2]=HY(t[v>>2]|0)|0;t[S>>2]=HY(t[d>>2]|0)|0;t[g>>2]=gAi[t[135752>>2]&511]((t[E>>2]|0)+(t[S>>2]|0)+2|0)|0;if(t[g>>2]|0){YY(t[g>>2]|0,t[d>>2]|0,t[S>>2]|0)|0;n[(t[g>>2]|0)+(t[S>>2]|0)>>0]=124;YY((t[g>>2]|0)+((t[S>>2]|0)+1)|0,t[v>>2]|0,t[E>>2]|0)|0;n[(t[g>>2]|0)+((t[E>>2]|0)+(t[S>>2]|0)+1)>>0]=0;t[(t[_>>2]|0)+20>>2]=t[g>>2];break}Bb(t[_>>2]|0);t[b>>2]=0;y=t[b>>2]|0;s=c;return y|0}else F=7;while(0);if((F|0)==7){F=Yl(t[d>>2]|0)|0;t[(t[_>>2]|0)+20>>2]=F}t[l>>2]=t[(t[_>>2]|0)+20>>2];SY(p,199,139120,l)|0;n[p+199>>0]=0;l=Yl(p)|0;t[(t[_>>2]|0)+24>>2]=l;if((Hb(t[k>>2]|0,t[h>>2]|0,t[w>>2]|0,t[_>>2]|0)|0)<0){Bb(t[_>>2]|0);t[b>>2]=0;y=t[b>>2]|0;s=c;return y|0}_=(t[k>>2]|0)+72|0;t[_>>2]=(t[_>>2]|0)+1;if(!(t[w>>2]|0)){t[b>>2]=t[(t[k>>2]|0)+24>>2];y=t[b>>2]|0;s=c;return y|0}else{t[b>>2]=t[w>>2];y=t[b>>2]|0;s=c;return y|0}return 0}function sb(e,i,r,f,a,o,c,l){e=e|0;i=i|0;r=r|0;f=f|0;a=a|0;o=o|0;c=c|0;l=l|0;var b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0,S=0,g=0,y=0,F=0,O=0,A=0,M=0;b=s;s=s+64|0;k=b+52|0;h=b+48|0;w=b+44|0;d=b+40|0;v=b+36|0;m=b+32|0;_=b+28|0;p=b+24|0;E=b+20|0;S=b+16|0;g=b+12|0;y=b+8|0;F=b+4|0;O=b;t[h>>2]=e;t[w>>2]=i;t[d>>2]=r;t[v>>2]=f;t[m>>2]=a;t[_>>2]=o;t[p>>2]=c;t[E>>2]=l;if((t[h>>2]|0)==0|(t[w>>2]|0)==0|(t[v>>2]|0)==0){t[k>>2]=0;A=t[k>>2]|0;s=b;return A|0}if((t[_>>2]|0)<0){t[k>>2]=0;A=t[k>>2]|0;s=b;return A|0}if((t[p>>2]|0)<1?1:(t[p>>2]|0)<(t[_>>2]|0)){t[k>>2]=0;A=t[k>>2]|0;s=b;return A|0}t[S>>2]=Ib(t[h>>2]|0,5)|0;if(!(t[S>>2]|0)){t[k>>2]=0;A=t[k>>2]|0;s=b;return A|0}do if((t[m>>2]|0)!=0?(u[t[m>>2]>>0]|0|0)!=0:0){t[y>>2]=HY(t[m>>2]|0)|0;t[F>>2]=HY(t[v>>2]|0)|0;t[O>>2]=gAi[t[135752>>2]&511]((t[y>>2]|0)+(t[F>>2]|0)+2|0)|0;if(t[O>>2]|0){YY(t[O>>2]|0,t[v>>2]|0,t[F>>2]|0)|0;n[(t[O>>2]|0)+(t[F>>2]|0)>>0]=124;YY((t[O>>2]|0)+((t[F>>2]|0)+1)|0,t[m>>2]|0,t[y>>2]|0)|0;n[(t[O>>2]|0)+((t[y>>2]|0)+(t[F>>2]|0)+1)>>0]=0;t[(t[S>>2]|0)+20>>2]=t[O>>2];break}Bb(t[S>>2]|0);t[k>>2]=0;A=t[k>>2]|0;s=b;return A|0}else M=11;while(0);if((M|0)==11){M=Yl(t[v>>2]|0)|0;t[(t[S>>2]|0)+20>>2]=M}t[(t[S>>2]|0)+60>>2]=t[E>>2];if(!(t[_>>2]|0))t[(t[S>>2]|0)+12>>2]=1;else t[(t[S>>2]|0)+12>>2]=t[_>>2];t[(t[S>>2]|0)+16>>2]=t[p>>2];t[g>>2]=xb(t[h>>2]|0)|0;t[(t[(t[h>>2]|0)+64>>2]|0)+(t[g>>2]<<3)>>2]=t[_>>2];t[(t[(t[h>>2]|0)+64>>2]|0)+(t[g>>2]<<3)+4>>2]=t[p>>2];if(!(t[d>>2]|0)){t[d>>2]=Ob(t[h>>2]|0)|0;Ab(t[h>>2]|0,t[d>>2]|0)|0}Ub(t[h>>2]|0,t[w>>2]|0,t[S>>2]|0,t[d>>2]|0,t[g>>2]|0,-1);zb(t[h>>2]|0,t[S>>2]|0)|0;t[(t[h>>2]|0)+24>>2]=t[d>>2];if(!(t[d>>2]|0))t[d>>2]=t[(t[h>>2]|0)+24>>2];if(!(t[d>>2]|0)){t[k>>2]=0;A=t[k>>2]|0;s=b;return A|0}if(!(t[_>>2]|0))jb(t[h>>2]|0,t[w>>2]|0,t[d>>2]|0);t[k>>2]=t[d>>2];A=t[k>>2]|0;s=b;return A|0}function bb(e,i,r,f,a,o,c,l){e=e|0;i=i|0;r=r|0;f=f|0;a=a|0;o=o|0;c=c|0;l=l|0;var b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0,S=0,g=0,y=0,F=0,O=0,A=0,M=0;b=s;s=s+64|0;k=b+52|0;h=b+48|0;w=b+44|0;d=b+40|0;v=b+36|0;m=b+32|0;_=b+28|0;p=b+24|0;E=b+20|0;S=b+16|0;g=b+12|0;y=b+8|0;F=b+4|0;O=b;t[h>>2]=e;t[w>>2]=i;t[d>>2]=r;t[v>>2]=f;t[m>>2]=a;t[_>>2]=o;t[p>>2]=c;t[E>>2]=l;if((t[h>>2]|0)==0|(t[w>>2]|0)==0|(t[v>>2]|0)==0){t[k>>2]=0;A=t[k>>2]|0;s=b;return A|0}if((t[_>>2]|0)<1){t[k>>2]=0;A=t[k>>2]|0;s=b;return A|0}if((t[p>>2]|0)<1?1:(t[p>>2]|0)<(t[_>>2]|0)){t[k>>2]=0;A=t[k>>2]|0;s=b;return A|0}t[S>>2]=Ib(t[h>>2]|0,5)|0;if(!(t[S>>2]|0)){t[k>>2]=0;A=t[k>>2]|0;s=b;return A|0}do if((t[m>>2]|0)!=0?(u[t[m>>2]>>0]|0|0)!=0:0){t[y>>2]=HY(t[m>>2]|0)|0;t[F>>2]=HY(t[v>>2]|0)|0;t[O>>2]=gAi[t[135752>>2]&511]((t[y>>2]|0)+(t[F>>2]|0)+2|0)|0;if(t[O>>2]|0){YY(t[O>>2]|0,t[v>>2]|0,t[F>>2]|0)|0;n[(t[O>>2]|0)+(t[F>>2]|0)>>0]=124;YY((t[O>>2]|0)+((t[F>>2]|0)+1)|0,t[m>>2]|0,t[y>>2]|0)|0;n[(t[O>>2]|0)+((t[y>>2]|0)+(t[F>>2]|0)+1)>>0]=0;t[(t[S>>2]|0)+20>>2]=t[O>>2];break}Bb(t[S>>2]|0);t[k>>2]=0;A=t[k>>2]|0;s=b;return A|0}else M=11;while(0);if((M|0)==11){M=Yl(t[v>>2]|0)|0;t[(t[S>>2]|0)+20>>2]=M}t[(t[S>>2]|0)+60>>2]=t[E>>2];t[(t[S>>2]|0)+8>>2]=6;t[(t[S>>2]|0)+12>>2]=t[_>>2];t[(t[S>>2]|0)+16>>2]=t[p>>2];t[g>>2]=xb(t[h>>2]|0)|0;t[(t[(t[h>>2]|0)+64>>2]|0)+(t[g>>2]<<3)>>2]=1;t[(t[(t[h>>2]|0)+64>>2]|0)+(t[g>>2]<<3)+4>>2]=1;if(!(t[d>>2]|0)){t[d>>2]=Ob(t[h>>2]|0)|0;Ab(t[h>>2]|0,t[d>>2]|0)|0}Ub(t[h>>2]|0,t[w>>2]|0,t[S>>2]|0,t[d>>2]|0,t[g>>2]|0,-1);zb(t[h>>2]|0,t[S>>2]|0)|0;t[(t[h>>2]|0)+24>>2]=t[d>>2];t[k>>2]=t[d>>2];A=t[k>>2]|0;s=b;return A|0}function kb(e){e=e|0;var i=0,r=0,n=0,f=0,u=0;i=s;s=s+16|0;r=i+8|0;n=i+4|0;f=i;t[n>>2]=e;if(!(t[n>>2]|0)){t[r>>2]=0;u=t[r>>2]|0;s=i;return u|0}else{t[f>>2]=Ob(t[n>>2]|0)|0;Ab(t[n>>2]|0,t[f>>2]|0)|0;t[r>>2]=t[f>>2];u=t[r>>2]|0;s=i;return u|0}return 0}function hb(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0;n=s;s=s+16|0;f=n+12|0;u=n+8|0;a=n+4|0;o=n;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;if((t[u>>2]|0)==0|(t[a>>2]|0)==0){t[f>>2]=0;c=t[f>>2]|0;s=n;return c|0}jb(t[u>>2]|0,t[a>>2]|0,t[o>>2]|0);if(!(t[o>>2]|0)){t[f>>2]=t[(t[u>>2]|0)+24>>2];c=t[f>>2]|0;s=n;return c|0}else{t[f>>2]=t[o>>2];c=t[f>>2]|0;s=n;return c|0}return 0}function wb(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,u=0,a=0,o=0,c=0,l=0,b=0;f=s;s=s+32|0;u=f+16|0;a=f+12|0;o=f+8|0;c=f+4|0;l=f;t[a>>2]=e;t[o>>2]=i;t[c>>2]=r;t[l>>2]=n;if((t[a>>2]|0)==0|(t[o>>2]|0)==0){t[u>>2]=0;b=t[u>>2]|0;s=f;return b|0}Vb(t[a>>2]|0,t[o>>2]|0,t[c>>2]|0,t[l>>2]|0);if(!(t[c>>2]|0)){t[u>>2]=t[(t[a>>2]|0)+24>>2];b=t[u>>2]|0;s=f;return b|0}else{t[u>>2]=t[c>>2];b=t[u>>2]|0;s=f;return b|0}return 0}function db(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,l=0;n=s;s=s+32|0;f=n+16|0;u=n+12|0;a=n+8|0;o=n+4|0;c=n;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;if(!(t[u>>2]|0)){t[f>>2]=-1;l=t[f>>2]|0;s=n;return l|0}t[c>>2]=xb(t[u>>2]|0)|0;if((t[c>>2]|0)<0){t[f>>2]=-1;l=t[f>>2]|0;s=n;return l|0}else{t[(t[(t[u>>2]|0)+64>>2]|0)+(t[c>>2]<<3)>>2]=t[a>>2];t[(t[(t[u>>2]|0)+64>>2]|0)+(t[c>>2]<<3)+4>>2]=t[o>>2];t[f>>2]=t[c>>2];l=t[f>>2]|0;s=n;return l|0}return 0}function vb(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,u=0,a=0,o=0,c=0,l=0,b=0;f=s;s=s+32|0;u=f+16|0;a=f+12|0;o=f+8|0;c=f+4|0;l=f;t[a>>2]=e;t[o>>2]=i;t[c>>2]=r;t[l>>2]=n;if((t[a>>2]|0)==0|(t[o>>2]|0)==0|(t[l>>2]|0)<0){t[u>>2]=0;b=t[u>>2]|0;s=f;return b|0}qb(t[a>>2]|0,t[o>>2]|0,t[c>>2]|0,t[l>>2]|0);if(!(t[c>>2]|0)){t[u>>2]=t[(t[a>>2]|0)+24>>2];b=t[u>>2]|0;s=f;return b|0}else{t[u>>2]=t[c>>2];b=t[u>>2]|0;s=f;return b|0}return 0}function mb(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,u=0,a=0,o=0,c=0,l=0,b=0;f=s;s=s+32|0;u=f+16|0;a=f+12|0;o=f+8|0;c=f+4|0;l=f;t[a>>2]=e;t[o>>2]=i;t[c>>2]=r;t[l>>2]=n;if((t[a>>2]|0)==0|(t[o>>2]|0)==0|(t[l>>2]|0)<0){t[u>>2]=0;b=t[u>>2]|0;s=f;return b|0}Yb(t[a>>2]|0,t[o>>2]|0,t[c>>2]|0,t[l>>2]|0);if(!(t[c>>2]|0)){t[u>>2]=t[(t[a>>2]|0)+24>>2];b=t[u>>2]|0;s=f;return b|0}else{t[u>>2]=t[c>>2];b=t[u>>2]|0;s=f;return b|0}return 0}function _b(e){e=e|0;var i=0,r=0,n=0,f=0,u=0;i=s;s=s+16|0;r=i+8|0;n=i+4|0;f=i;t[n>>2]=e;if((t[n>>2]|0)!=0?(t[(t[n>>2]|0)+8>>2]|0)==0:0){Tb(t[n>>2]|0);t[f>>2]=Lb(t[n>>2]|0)|0;t[r>>2]=t[f>>2];u=t[r>>2]|0;s=i;return u|0}t[r>>2]=0;u=t[r>>2]|0;s=i;return u|0}function pb(e){e=e|0;var i=0,r=0,n=0,f=0,u=0;i=s;s=s+16|0;r=i+8|0;n=i+4|0;f=i;t[n>>2]=e;if(!(t[n>>2]|0)){t[r>>2]=-1;u=t[r>>2]|0;s=i;return u|0}else{t[f>>2]=Pb(t[n>>2]|0)|0;t[r>>2]=t[f>>2];u=t[r>>2]|0;s=i;return u|0}return 0}function Eb(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0;r=s;s=s+16|0;n=r;f=r+12|0;u=r+8|0;a=r+4|0;t[f>>2]=e;t[u>>2]=i;t[a>>2]=0;if(t[f>>2]|0){t[a>>2]=t[t[f>>2]>>2];t[(t[f>>2]|0)+8>>2]=2}f=t[u>>2]|0;i=t[a>>2]|0;t[n>>2]=t[u>>2];cp(0,0,0,0,0,14,2,3,0,0,f,i,0,0,0,140264,n);s=r;return}function Sb(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,m=0,_=0,p=0,E=0,S=0,g=0,y=0,F=0,O=0,A=0,M=0,R=0,N=0,T=0,L=0,D=0,C=0,P=0,B=0,I=0;f=s;s=s+112|0;u=f;a=f+100|0;o=f+96|0;c=f+92|0;l=f+88|0;b=f+84|0;k=f+80|0;h=f+76|0;w=f+72|0;d=f+68|0;m=f+64|0;_=f+60|0;p=f+56|0;E=f+52|0;S=f+48|0;g=f+44|0;y=f+40|0;F=f+36|0;O=f+32|0;A=f+28|0;M=f+24|0;R=f+20|0;N=f+16|0;T=f+12|0;L=f+8|0;D=f+4|0;t[o>>2]=e;t[c>>2]=i;t[l>>2]=r;t[b>>2]=n;t[d>>2]=0;t[m>>2]=1;if(!(t[o>>2]|0)){t[a>>2]=-1;C=t[a>>2]|0;s=f;return C|0}if(!(t[(t[o>>2]|0)+8>>2]|0)){t[a>>2]=-1;C=t[a>>2]|0;s=f;return C|0}n=t[o>>2]|0;if(t[t[o>>2]>>2]|0){t[a>>2]=t[n>>2];C=t[a>>2]|0;s=f;return C|0}if(t[(t[n+8>>2]|0)+40>>2]|0){t[a>>2]=gb(t[o>>2]|0,t[(t[o>>2]|0)+8>>2]|0,t[c>>2]|0,t[l>>2]|0)|0;C=t[a>>2]|0;s=f;return C|0}do if(!(t[c>>2]|0)){if((t[t[(t[o>>2]|0)+20>>2]>>2]|0)!=2){t[d>>2]=1;break}t[a>>2]=1;C=t[a>>2]|0;s=f;return C|0}while(0);if((t[c>>2]|0)!=0?(t[(t[o>>2]|0)+52>>2]|0)>0:0){Gb(t[o>>2]|0,t[c>>2]|0,t[l>>2]|0);t[c>>2]=t[(t[(t[o>>2]|0)+68>>2]|0)+(t[(t[o>>2]|0)+56>>2]<<3)>>2];t[l>>2]=t[(t[(t[o>>2]|0)+68>>2]|0)+(t[(t[o>>2]|0)+56>>2]<<3)+4>>2]}e:while(1){if(t[t[o>>2]>>2]|0)break;if(!(t[c>>2]|0)){if((t[d>>2]|0)!=1)break;if((t[t[(t[o>>2]|0)+20>>2]>>2]|0)==2)break}if(!((t[c>>2]|0)==0?(t[(t[o>>2]|0)+44>>2]|0)==0:0))P=22;i:do if((P|0)==22){P=0;t[(t[o>>2]|0)+28>>2]=0;r:while(1){if((t[(t[o>>2]|0)+24>>2]|0)>=(t[(t[(t[o>>2]|0)+20>>2]|0)+24>>2]|0))break;t[k>>2]=(t[(t[(t[o>>2]|0)+20>>2]|0)+28>>2]|0)+((t[(t[o>>2]|0)+24>>2]|0)*20|0);if((t[(t[k>>2]|0)+4>>2]|0)>=0){t[h>>2]=t[t[k>>2]>>2];t[w>>2]=0;n:do if((t[(t[k>>2]|0)+12>>2]|0)==1193047){t[w>>2]=0;if((t[c>>2]|0)==0&(t[d>>2]|0)!=0){t[w>>2]=1;break}if(t[c>>2]|0){t[_>>2]=0;f:while(1){if((t[_>>2]|0)>=(t[(t[(t[o>>2]|0)+20>>2]|0)+24>>2]|0))break n;t[E>>2]=(t[(t[(t[o>>2]|0)+20>>2]|0)+28>>2]|0)+((t[_>>2]|0)*20|0);do if((t[(t[E>>2]|0)+8>>2]|0)>=0){if((t[E>>2]|0)==(t[k>>2]|0))break;t[S>>2]=(t[(t[(t[o>>2]|0)+8>>2]|0)+24>>2]|0)+(t[(t[E>>2]|0)+8>>2]<<3);t[p>>2]=t[(t[(t[o>>2]|0)+44>>2]|0)+(t[(t[E>>2]|0)+8>>2]<<2)>>2];do if((t[p>>2]|0)<(t[(t[S>>2]|0)+4>>2]|0)){if(!(t[t[E>>2]>>2]|0))break;if(Xl(t[c>>2]|0,t[(t[t[E>>2]>>2]|0)+20>>2]|0)|0){P=36;break f}}while(0);if((t[p>>2]|0)<(t[t[S>>2]>>2]|0))break;if((t[p>>2]|0)>=(t[(t[S>>2]|0)+4>>2]|0))break;if(!(t[t[E>>2]>>2]|0))break;if(Xl(t[c>>2]|0,t[(t[t[E>>2]>>2]|0)+20>>2]|0)|0){P=41;break f}}while(0);t[_>>2]=(t[_>>2]|0)+1}if((P|0)==36){P=0;t[w>>2]=0;break}else if((P|0)==41){P=0;t[w>>2]=1;break}}}else{if((t[(t[k>>2]|0)+12>>2]|0)==1193046){t[w>>2]=1;t[g>>2]=0;f:while(1){if((t[g>>2]|0)>=(t[(t[(t[o>>2]|0)+20>>2]|0)+24>>2]|0))break n;t[F>>2]=(t[(t[(t[o>>2]|0)+20>>2]|0)+28>>2]|0)+((t[g>>2]|0)*20|0);do if((t[(t[F>>2]|0)+8>>2]|0)>=0){if((t[F>>2]|0)==(t[k>>2]|0))break;t[O>>2]=(t[(t[(t[o>>2]|0)+8>>2]|0)+24>>2]|0)+(t[(t[F>>2]|0)+8>>2]<<3);t[y>>2]=t[(t[(t[o>>2]|0)+44>>2]|0)+(t[(t[F>>2]|0)+8>>2]<<2)>>2];if((t[y>>2]|0)<(t[t[O>>2]>>2]|0))break f;if((t[y>>2]|0)>(t[(t[O>>2]|0)+4>>2]|0))break f}while(0);t[g>>2]=(t[g>>2]|0)+1}t[w>>2]=0;break}if((t[(t[k>>2]|0)+12>>2]|0)>=0){t[A>>2]=t[(t[(t[o>>2]|0)+44>>2]|0)+(t[(t[k>>2]|0)+12>>2]<<2)>>2];t[M>>2]=(t[(t[(t[o>>2]|0)+8>>2]|0)+24>>2]|0)+(t[(t[k>>2]|0)+12>>2]<<3);if((t[A>>2]|0)>=(t[t[M>>2]>>2]|0))B=(t[A>>2]|0)<=(t[(t[M>>2]|0)+4>>2]|0);else B=0;t[w>>2]=B&1;break}if(!(t[h>>2]|0)){P=57;break r}if(!(t[c>>2]|0))break;t[w>>2]=Wb(t[(t[h>>2]|0)+20>>2]|0,t[c>>2]|0)|0;if(t[(t[h>>2]|0)+28>>2]|0){n=((t[w>>2]|0)!=0^1)&1;t[w>>2]=n;t[w>>2]=(t[b>>2]|0)!=0?n:0}do if((t[w>>2]|0)==1){if((t[(t[k>>2]|0)+8>>2]|0)<0)break;t[N>>2]=t[(t[(t[o>>2]|0)+44>>2]|0)+(t[(t[k>>2]|0)+8>>2]<<2)>>2];t[R>>2]=(t[(t[(t[o>>2]|0)+8>>2]|0)+24>>2]|0)+(t[(t[k>>2]|0)+8>>2]<<3);if((t[N>>2]|0)<(t[(t[R>>2]|0)+4>>2]|0))break;t[w>>2]=0}while(0);if((t[w>>2]|0)!=1)break;if((t[(t[h>>2]|0)+12>>2]|0)<=0)break;if((t[(t[h>>2]|0)+16>>2]|0)<=0)break;t[T>>2]=t[(t[(t[(t[o>>2]|0)+8>>2]|0)+8>>2]|0)+(t[(t[k>>2]|0)+4>>2]<<2)>>2];if((t[(t[(t[o>>2]|0)+20>>2]|0)+24>>2]|0)>((t[(t[o>>2]|0)+24>>2]|0)+1|0)){if((t[(t[o>>2]|0)+52>>2]|0)<=0)Gb(t[o>>2]|0,t[c>>2]|0,t[l>>2]|0);Kb(t[o>>2]|0)}t[(t[o>>2]|0)+28>>2]=1;do{if((t[(t[o>>2]|0)+28>>2]|0)==(t[(t[h>>2]|0)+16>>2]|0))break;n=(t[o>>2]|0)+56|0;t[n>>2]=(t[n>>2]|0)+1;t[c>>2]=t[(t[(t[o>>2]|0)+68>>2]|0)+(t[(t[o>>2]|0)+56>>2]<<3)>>2];t[l>>2]=t[(t[(t[o>>2]|0)+68>>2]|0)+(t[(t[o>>2]|0)+56>>2]<<3)+4>>2];I=t[o>>2]|0;if(!(t[c>>2]|0)){P=75;break}if((t[I+28>>2]|0)>=(t[(t[h>>2]|0)+12>>2]|0)){t[L>>2]=t[(t[o>>2]|0)+24>>2];t[D>>2]=t[(t[o>>2]|0)+20>>2];t[(t[o>>2]|0)+24>>2]=-1;t[(t[o>>2]|0)+20>>2]=t[T>>2];if((t[(t[o>>2]|0)+52>>2]|0)<=0)Gb(t[o>>2]|0,t[c>>2]|0,t[l>>2]|0);Kb(t[o>>2]|0);t[(t[o>>2]|0)+24>>2]=t[L>>2];t[(t[o>>2]|0)+20>>2]=t[D>>2]}t[w>>2]=Xl(t[c>>2]|0,t[(t[h>>2]|0)+20>>2]|0)|0;n=(t[o>>2]|0)+28|0;t[n>>2]=(t[n>>2]|0)+1}while((t[w>>2]|0)==1);if((P|0)==75){P=0;n=I+56|0;t[n>>2]=(t[n>>2]|0)+-1}if((t[(t[o>>2]|0)+28>>2]|0)<(t[(t[h>>2]|0)+12>>2]|0))t[w>>2]=0;if((t[w>>2]|0)<0)t[w>>2]=0;if(!(t[w>>2]|0))break i}while(0);if((t[w>>2]|0)==1){P=87;break}if((t[w>>2]|0)<0){P=110;break}}n=(t[o>>2]|0)+24|0;t[n>>2]=(t[n>>2]|0)+1}if((P|0)==57){P=0;xe(t[v>>2]|0,139424,u|0)|0;t[t[o>>2]>>2]=-2}else if((P|0)==87){P=0;if(((t[h>>2]|0)!=0?(t[(t[o>>2]|0)+12>>2]|0)!=0:0)&(t[l>>2]|0)!=0)NAi[t[(t[o>>2]|0)+12>>2]&511](t[(t[o>>2]|0)+16>>2]|0,t[(t[h>>2]|0)+20>>2]|0,t[(t[h>>2]|0)+60>>2]|0,t[l>>2]|0);if((t[(t[(t[o>>2]|0)+20>>2]|0)+24>>2]|0)>((t[(t[o>>2]|0)+24>>2]|0)+1|0)){if((t[(t[o>>2]|0)+52>>2]|0)<=0)Gb(t[o>>2]|0,t[c>>2]|0,t[l>>2]|0);Kb(t[o>>2]|0)}if((t[(t[k>>2]|0)+8>>2]|0)>=0){n=(t[(t[o>>2]|0)+44>>2]|0)+(t[(t[k>>2]|0)+8>>2]<<2)|0;t[n>>2]=(t[n>>2]|0)+1}if((t[(t[k>>2]|0)+12>>2]|0)>=0?(t[(t[k>>2]|0)+12>>2]|0)<1193046:0)t[(t[(t[o>>2]|0)+44>>2]|0)+(t[(t[k>>2]|0)+12>>2]<<2)>>2]=0;if((t[(t[(t[(t[o>>2]|0)+8>>2]|0)+8>>2]|0)+(t[(t[k>>2]|0)+4>>2]<<2)>>2]|0)!=0?(t[t[(t[(t[(t[o>>2]|0)+8>>2]|0)+8>>2]|0)+(t[(t[k>>2]|0)+4>>2]<<2)>>2]>>2]|0)==4:0){if(t[(t[o>>2]|0)+80>>2]|0)pAi[t[135736>>2]&511](t[(t[o>>2]|0)+80>>2]|0);n=Yl(t[c>>2]|0)|0;t[(t[o>>2]|0)+80>>2]=n;t[(t[o>>2]|0)+76>>2]=t[(t[o>>2]|0)+20>>2];YY(t[(t[o>>2]|0)+84>>2]|0,t[(t[o>>2]|0)+44>>2]|0,t[(t[(t[o>>2]|0)+8>>2]|0)+20>>2]<<2|0)|0}t[(t[o>>2]|0)+20>>2]=t[(t[(t[(t[o>>2]|0)+8>>2]|0)+8>>2]|0)+(t[(t[k>>2]|0)+4>>2]<<2)>>2];t[(t[o>>2]|0)+24>>2]=0;do if(t[t[k>>2]>>2]|0){if(!(t[(t[o>>2]|0)+68>>2]|0)){t[c>>2]=0;t[l>>2]=0;break}n=(t[o>>2]|0)+56|0;t[n>>2]=(t[n>>2]|0)+1;if((t[(t[o>>2]|0)+56>>2]|0)<(t[(t[o>>2]|0)+52>>2]|0)){t[c>>2]=t[(t[(t[o>>2]|0)+68>>2]|0)+(t[(t[o>>2]|0)+56>>2]<<3)>>2];t[l>>2]=t[(t[(t[o>>2]|0)+68>>2]|0)+(t[(t[o>>2]|0)+56>>2]<<3)+4>>2];break}else{t[c>>2]=0;t[l>>2]=0;break}}while(0);t[m>>2]=1;continue e}else if((P|0)==110){P=0;t[t[o>>2]>>2]=-4}if((t[(t[o>>2]|0)+24>>2]|0)==0?(t[(t[(t[o>>2]|0)+20>>2]|0)+24>>2]|0)!=0:0)continue e}while(0);if(((t[m>>2]|0)!=0?(t[(t[o>>2]|0)+20>>2]|0)!=0:0)?(t[t[(t[o>>2]|0)+20>>2]>>2]|0)!=4:0){t[m>>2]=0;if(t[(t[o>>2]|0)+80>>2]|0)pAi[t[135736>>2]&511](t[(t[o>>2]|0)+80>>2]|0);n=Yl(t[c>>2]|0)|0;t[(t[o>>2]|0)+80>>2]=n;t[(t[o>>2]|0)+76>>2]=t[(t[o>>2]|0)+20>>2];YY(t[(t[o>>2]|0)+84>>2]|0,t[(t[o>>2]|0)+44>>2]|0,t[(t[(t[o>>2]|0)+8>>2]|0)+20>>2]<<2|0)|0}t[(t[o>>2]|0)+4>>2]=0;Xb(t[o>>2]|0);if(!(t[(t[o>>2]|0)+68>>2]|0))continue;if(t[t[o>>2]>>2]|0)continue;t[c>>2]=t[(t[(t[o>>2]|0)+68>>2]|0)+(t[(t[o>>2]|0)+56>>2]<<3)>>2];t[l>>2]=t[(t[(t[o>>2]|0)+68>>2]|0)+(t[(t[o>>2]|0)+56>>2]<<3)+4>>2]}l=t[o>>2]|0;if(!(t[t[o>>2]>>2]|0)){t[a>>2]=(t[t[l+20>>2]>>2]|0)==2&1;C=t[a>>2]|0;s=f;return C|0}else{t[a>>2]=t[l>>2];C=t[a>>2]|0;s=f;return C|0}return 0}function gb(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0;f=s;s=s+32|0;u=f+28|0;a=f+24|0;o=f+20|0;c=f+16|0;l=f+12|0;b=f+8|0;k=f+4|0;h=f;t[a>>2]=e;t[o>>2]=i;t[c>>2]=r;t[l>>2]=n;t[b>>2]=t[(t[a>>2]|0)+56>>2];if(((t[o>>2]|0)!=0?(t[(t[o>>2]|0)+40>>2]|0)!=0:0)?(t[(t[o>>2]|0)+52>>2]|0)!=0:0){if(!(t[c>>2]|0)){n=te(t[b>>2]|0,(t[(t[o>>2]|0)+48>>2]|0)+1|0)|0;if((t[(t[(t[o>>2]|0)+40>>2]|0)+(n<<2)>>2]|0)==2){t[u>>2]=1;w=t[u>>2]|0;s=f;return w|0}else{t[u>>2]=0;w=t[u>>2]|0;s=f;return w|0}}t[k>>2]=0;while(1){if((t[k>>2]|0)>=(t[(t[o>>2]|0)+48>>2]|0))break;n=te(t[b>>2]|0,(t[(t[o>>2]|0)+48>>2]|0)+1|0)|0;t[h>>2]=t[(t[(t[o>>2]|0)+40>>2]|0)+(n+(t[k>>2]|0)+1<<2)>>2];if(((t[h>>2]|0)>0?(t[h>>2]|0)<=(t[(t[o>>2]|0)+36>>2]|0):0)?(t[h>>2]=(t[h>>2]|0)+-1,(Wb(t[(t[(t[o>>2]|0)+52>>2]|0)+(t[k>>2]<<2)>>2]|0,t[c>>2]|0)|0)!=0):0){d=14;break}t[k>>2]=(t[k>>2]|0)+1}if((d|0)==14){t[(t[a>>2]|0)+56>>2]=t[h>>2];if((t[(t[a>>2]|0)+12>>2]|0)!=0?(t[(t[o>>2]|0)+44>>2]|0)!=0:0){d=te(t[b>>2]|0,t[(t[o>>2]|0)+48>>2]|0)|0;NAi[t[(t[a>>2]|0)+12>>2]&511](t[(t[a>>2]|0)+16>>2]|0,t[c>>2]|0,t[(t[(t[o>>2]|0)+44>>2]|0)+(d+(t[k>>2]|0)<<2)>>2]|0,t[l>>2]|0)}l=te(t[h>>2]|0,(t[(t[o>>2]|0)+48>>2]|0)+1|0)|0;if((t[(t[(t[o>>2]|0)+40>>2]|0)+(l<<2)>>2]|0)!=4){l=te(t[h>>2]|0,(t[(t[o>>2]|0)+48>>2]|0)+1|0)|0;if((t[(t[(t[o>>2]|0)+40>>2]|0)+(l<<2)>>2]|0)==2){t[u>>2]=1;w=t[u>>2]|0;s=f;return w|0}else{t[u>>2]=0;w=t[u>>2]|0;s=f;return w|0}}}if(t[(t[a>>2]|0)+80>>2]|0)pAi[t[135736>>2]&511](t[(t[a>>2]|0)+80>>2]|0);l=Yl(t[c>>2]|0)|0;t[(t[a>>2]|0)+80>>2]=l;t[(t[a>>2]|0)+72>>2]=t[b>>2];t[t[a>>2]>>2]=-1;t[u>>2]=-1;w=t[u>>2]|0;s=f;return w|0}t[u>>2]=-1;w=t[u>>2]|0;s=f;return w|0}function yb(e,i,r,n,f,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;u=u|0;var a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0,S=0,g=0,y=0,F=0,O=0,A=0,M=0,R=0,N=0;a=s;s=s+96|0;o=a;c=a+80|0;l=a+76|0;b=a+72|0;k=a+68|0;h=a+64|0;w=a+60|0;d=a+56|0;v=a+52|0;m=a+48|0;_=a+44|0;p=a+40|0;E=a+36|0;S=a+32|0;g=a+28|0;y=a+24|0;F=a+20|0;O=a+16|0;A=a+12|0;M=a+8|0;t[l>>2]=e;t[b>>2]=i;t[k>>2]=r;t[h>>2]=n;t[w>>2]=f;t[d>>2]=u;t[m>>2]=0;if(!((t[l>>2]|0)==0|(t[k>>2]|0)==0|(t[h>>2]|0)==0|(t[w>>2]|0)==0)?(t[t[k>>2]>>2]|0)>0:0){t[v>>2]=t[t[k>>2]>>2];t[t[k>>2]>>2]=0;t[t[h>>2]>>2]=0;e:do if((t[(t[l>>2]|0)+8>>2]|0)!=0?(t[(t[(t[l>>2]|0)+8>>2]|0)+40>>2]|0)!=0:0){t[_>>2]=t[(t[l>>2]|0)+8>>2];u=t[l>>2]|0;do if(t[b>>2]|0){if((t[u+72>>2]|0)!=-1){t[S>>2]=t[(t[l>>2]|0)+72>>2];break}t[c>>2]=-1;R=t[c>>2]|0;s=a;return R|0}else t[S>>2]=t[u+56>>2];while(0);do if(t[d>>2]|0){u=te(t[S>>2]|0,(t[(t[_>>2]|0)+48>>2]|0)+1|0)|0;f=t[d>>2]|0;if((t[(t[(t[_>>2]|0)+40>>2]|0)+(u<<2)>>2]|0)==2){t[f>>2]=1;break}else{t[f>>2]=0;break}}while(0);t[E>>2]=0;while(1){if((t[E>>2]|0)>=(t[(t[_>>2]|0)+48>>2]|0))break;if((t[m>>2]|0)>=(t[v>>2]|0))break;f=te(t[S>>2]|0,(t[(t[_>>2]|0)+48>>2]|0)+1|0)|0;t[p>>2]=t[(t[(t[_>>2]|0)+40>>2]|0)+(f+(t[E>>2]|0)+1<<2)>>2];if(((t[p>>2]|0)>0?(t[p>>2]|0)<=(t[(t[_>>2]|0)+36>>2]|0):0)?(f=te((t[p>>2]|0)-1|0,(t[(t[_>>2]|0)+48>>2]|0)+1|0)|0,(t[(t[(t[_>>2]|0)+40>>2]|0)+(f<<2)>>2]|0)!=4):0){f=t[(t[(t[_>>2]|0)+52>>2]|0)+(t[E>>2]<<2)>>2]|0;u=t[m>>2]|0;t[m>>2]=u+1;t[(t[w>>2]|0)+(u<<2)>>2]=f;f=t[k>>2]|0;t[f>>2]=(t[f>>2]|0)+1}t[E>>2]=(t[E>>2]|0)+1}t[E>>2]=0;while(1){if((t[E>>2]|0)>=(t[(t[_>>2]|0)+48>>2]|0))break e;if((t[m>>2]|0)>=(t[v>>2]|0))break e;f=te(t[S>>2]|0,(t[(t[_>>2]|0)+48>>2]|0)+1|0)|0;t[p>>2]=t[(t[(t[_>>2]|0)+40>>2]|0)+(f+(t[E>>2]|0)+1<<2)>>2];if(((t[p>>2]|0)>0?(t[p>>2]|0)<=(t[(t[_>>2]|0)+36>>2]|0):0)?(f=te((t[p>>2]|0)-1|0,(t[(t[_>>2]|0)+48>>2]|0)+1|0)|0,(t[(t[(t[_>>2]|0)+40>>2]|0)+(f<<2)>>2]|0)==4):0){f=t[(t[(t[_>>2]|0)+52>>2]|0)+(t[E>>2]<<2)>>2]|0;u=t[m>>2]|0;t[m>>2]=u+1;t[(t[w>>2]|0)+(u<<2)>>2]=f;f=t[h>>2]|0;t[f>>2]=(t[f>>2]|0)+1}t[E>>2]=(t[E>>2]|0)+1}}else N=31;while(0);e:do if((N|0)==31){do if(t[d>>2]|0){E=t[d>>2]|0;if((t[t[(t[l>>2]|0)+20>>2]>>2]|0)==2){t[E>>2]=1;break}else{t[E>>2]=0;break}}while(0);E=t[l>>2]|0;do if(t[b>>2]|0){if(t[E+76>>2]|0){t[O>>2]=t[(t[l>>2]|0)+76>>2];break}t[c>>2]=-1;R=t[c>>2]|0;s=a;return R|0}else{if(t[E+20>>2]|0){t[O>>2]=t[(t[l>>2]|0)+20>>2];break}t[c>>2]=-1;R=t[c>>2]|0;s=a;return R|0}while(0);t[g>>2]=0;while(1){if((t[g>>2]|0)>=(t[(t[O>>2]|0)+24>>2]|0))break;if((t[m>>2]|0)>=(t[v>>2]|0))break;t[y>>2]=(t[(t[O>>2]|0)+28>>2]|0)+((t[g>>2]|0)*20|0);do if(((t[(t[y>>2]|0)+4>>2]|0)>=0?(t[F>>2]=t[t[y>>2]>>2],(t[F>>2]|0)!=0):0)?(t[(t[F>>2]|0)+20>>2]|0)!=0:0){if((t[(t[y>>2]|0)+12>>2]|0)==1193047){E=t[33976]|0;_=t[33980]|0;t[o>>2]=140216;t[o+4>>2]=4289;yAi[E&511](_,140184,o);break}if((t[(t[y>>2]|0)+12>>2]|0)==1193046){_=t[33976]|0;E=t[33980]|0;t[o>>2]=140216;t[o+4>>2]=4292;yAi[_&511](E,140184,o);break}if((t[(t[y>>2]|0)+8>>2]|0)<0){if(!(t[(t[l>>2]|0)+8>>2]|0))break;if(!(t[(t[(t[(t[l>>2]|0)+8>>2]|0)+8>>2]|0)+(t[(t[y>>2]|0)+4>>2]<<2)>>2]|0))break;if((t[t[(t[(t[(t[l>>2]|0)+8>>2]|0)+8>>2]|0)+(t[(t[y>>2]|0)+4>>2]<<2)>>2]>>2]|0)==4)break;E=t[F>>2]|0;if(t[(t[F>>2]|0)+28>>2]|0){_=t[E+24>>2]|0;p=t[m>>2]|0;t[m>>2]=p+1;t[(t[w>>2]|0)+(p<<2)>>2]=_}else{_=t[E+20>>2]|0;E=t[m>>2]|0;t[m>>2]=E+1;t[(t[w>>2]|0)+(E<<2)>>2]=_}_=t[k>>2]|0;t[_>>2]=(t[_>>2]|0)+1;break}t[A>>2]=0;_=t[(t[y>>2]|0)+8>>2]|0;E=t[l>>2]|0;if(t[b>>2]|0)t[M>>2]=t[(t[E+84>>2]|0)+(_<<2)>>2];else t[M>>2]=t[(t[E+44>>2]|0)+(_<<2)>>2];if(t[(t[l>>2]|0)+8>>2]|0)t[A>>2]=(t[(t[(t[l>>2]|0)+8>>2]|0)+24>>2]|0)+(t[(t[y>>2]|0)+8>>2]<<3);if((t[A>>2]|0)!=0?(t[M>>2]|0)>=(t[(t[A>>2]|0)+4>>2]|0):0)break;_=t[F>>2]|0;if(t[(t[F>>2]|0)+28>>2]|0){E=t[_+24>>2]|0;p=t[m>>2]|0;t[m>>2]=p+1;t[(t[w>>2]|0)+(p<<2)>>2]=E}else{E=t[_+20>>2]|0;_=t[m>>2]|0;t[m>>2]=_+1;t[(t[w>>2]|0)+(_<<2)>>2]=E}E=t[k>>2]|0;t[E>>2]=(t[E>>2]|0)+1}while(0);t[g>>2]=(t[g>>2]|0)+1}t[g>>2]=0;while(1){if((t[g>>2]|0)>=(t[(t[O>>2]|0)+24>>2]|0))break e;if((t[m>>2]|0)>=(t[v>>2]|0))break e;t[y>>2]=(t[(t[O>>2]|0)+28>>2]|0)+((t[g>>2]|0)*20|0);if((((((((t[(t[y>>2]|0)+4>>2]|0)>=0?(t[F>>2]=t[t[y>>2]>>2],(t[F>>2]|0)!=0):0)?(t[(t[F>>2]|0)+20>>2]|0)!=0:0)?(t[(t[y>>2]|0)+12>>2]|0)!=1193047:0)?(t[(t[y>>2]|0)+12>>2]|0)!=1193046:0)?(t[(t[y>>2]|0)+8>>2]|0)<0:0)?(t[(t[(t[(t[l>>2]|0)+8>>2]|0)+8>>2]|0)+(t[(t[y>>2]|0)+4>>2]<<2)>>2]|0)!=0:0)?(t[t[(t[(t[(t[l>>2]|0)+8>>2]|0)+8>>2]|0)+(t[(t[y>>2]|0)+4>>2]<<2)>>2]>>2]|0)==4:0){E=t[F>>2]|0;if(t[(t[F>>2]|0)+28>>2]|0){_=t[E+24>>2]|0;p=t[m>>2]|0;t[m>>2]=p+1;t[(t[w>>2]|0)+(p<<2)>>2]=_}else{_=t[E+20>>2]|0;E=t[m>>2]|0;t[m>>2]=E+1;t[(t[w>>2]|0)+(E<<2)>>2]=_}_=t[h>>2]|0;t[_>>2]=(t[_>>2]|0)+1}t[g>>2]=(t[g>>2]|0)+1}}while(0);t[c>>2]=0;R=t[c>>2]|0;s=a;return R|0}t[c>>2]=-1;R=t[c>>2]|0;s=a;return R|0}function Fb(e){e=e|0;var i=0,r=0,n=0,f=0,u=0,a=0;i=s;s=s+16|0;r=i+8|0;n=i+4|0;f=i;t[n>>2]=e;t[f>>2]=gAi[t[135744>>2]&511](80)|0;if(!(t[f>>2]|0)){t[r>>2]=0;u=t[r>>2]|0;s=i;return u|0}e=(t[f>>2]|0)+0|0;a=e+80|0;do{t[e>>2]=0;e=e+4|0}while((e|0)<(a|0));if(t[n>>2]|0){e=Yl(t[n>>2]|0)|0;t[t[f>>2]>>2]=e}t[(t[f>>2]|0)+4>>2]=t[t[f>>2]>>2];t[(t[f>>2]|0)+12>>2]=0;t[(t[f>>2]|0)+72>>2]=0;t[(t[f>>2]|0)+8>>2]=0;t[(t[f>>2]|0)+68>>2]=-1;t[r>>2]=t[f>>2];u=t[r>>2]|0;s=i;return u|0}function Ob(e){e=e|0;var i=0,r=0,n=0,f=0,u=0;i=s;s=s+16|0;r=i+8|0;n=i+4|0;f=i;t[n>>2]=e;t[f>>2]=gAi[t[135744>>2]&511](44)|0;if(!(t[f>>2]|0)){Eb(t[n>>2]|0,140160);t[r>>2]=0;u=t[r>>2]|0;s=i;return u|0}else{n=(t[f>>2]|0)+0|0;e=n+44|0;do{t[n>>2]=0;n=n+4|0}while((n|0)<(e|0));t[t[f>>2]>>2]=3;t[(t[f>>2]|0)+4>>2]=0;t[r>>2]=t[f>>2];u=t[r>>2]|0;s=i;return u|0}return 0}function Ab(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0;r=s;s=s+16|0;n=r+12|0;f=r+8|0;u=r+4|0;a=r;t[f>>2]=e;t[u>>2]=i;if(!(t[u>>2]|0)){t[n>>2]=-1;o=t[n>>2]|0;s=r;return o|0}i=t[f>>2]|0;do if(!(t[(t[f>>2]|0)+44>>2]|0)){t[i+44>>2]=4;e=gAi[t[135744>>2]&511](t[(t[f>>2]|0)+44>>2]<<2)|0;t[(t[f>>2]|0)+52>>2]=e;if(!(t[(t[f>>2]|0)+52>>2]|0)){Eb(t[f>>2]|0,140144);t[(t[f>>2]|0)+44>>2]=0;t[n>>2]=-1;o=t[n>>2]|0;s=r;return o|0}}else if((t[i+48>>2]|0)>=(t[(t[f>>2]|0)+44>>2]|0)){e=(t[f>>2]|0)+44|0;t[e>>2]=t[e>>2]<<1;t[a>>2]=MAi[t[135760>>2]&511](t[(t[f>>2]|0)+52>>2]|0,t[(t[f>>2]|0)+44>>2]<<2)|0;if(t[a>>2]|0){t[(t[f>>2]|0)+52>>2]=t[a>>2];break}Eb(t[f>>2]|0,140144);e=(t[f>>2]|0)+44|0;t[e>>2]=(t[e>>2]|0)/2|0;t[n>>2]=-1;o=t[n>>2]|0;s=r;return o|0}while(0);t[(t[u>>2]|0)+16>>2]=t[(t[f>>2]|0)+48>>2];a=t[u>>2]|0;u=(t[f>>2]|0)+48|0;i=t[u>>2]|0;t[u>>2]=i+1;t[(t[(t[f>>2]|0)+52>>2]|0)+(i<<2)>>2]=a;t[n>>2]=0;o=t[n>>2]|0;s=r;return o|0}function Mb(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,a=0,o=0,c=0;r=s;s=s+16|0;n=r+12|0;f=r+8|0;a=r+4|0;o=r;t[n>>2]=e;t[f>>2]=i;t[a>>2]=t[(t[n>>2]|0)+24>>2];t[(t[n>>2]|0)+20>>2]=0;Zb(t[n>>2]|0,0)|0;if(t[f>>2]|0)t[t[(t[n>>2]|0)+24>>2]>>2]=2;i=t[(t[n>>2]|0)+24>>2]|0;if((u[t[(t[n>>2]|0)+4>>2]>>0]|0|0)!=124){t[(t[n>>2]|0)+20>>2]=i;s=r;return}t[o>>2]=i;while(1){if((u[t[(t[n>>2]|0)+4>>2]>>0]|0|0)!=124)break;if(t[(t[n>>2]|0)+8>>2]|0)break;i=(t[n>>2]|0)+4|0;t[i>>2]=(t[i>>2]|0)+1;if(!(u[t[(t[n>>2]|0)+4>>2]>>0]|0)){c=9;break}t[(t[n>>2]|0)+24>>2]=t[a>>2];t[(t[n>>2]|0)+20>>2]=0;Zb(t[n>>2]|0,t[o>>2]|0)|0}if((c|0)==9){t[(t[n>>2]|0)+8>>2]=1450;Rb(t[n>>2]|0,139560);s=r;return}if(t[f>>2]|0){s=r;return}t[(t[n>>2]|0)+24>>2]=t[o>>2];t[(t[n>>2]|0)+20>>2]=t[o>>2];s=r;return}function Rb(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0;r=s;s=s+32|0;n=r;f=r+16|0;u=r+12|0;a=r+8|0;o=r+4|0;t[f>>2]=e;t[u>>2]=i;t[a>>2]=0;t[o>>2]=0;if(t[f>>2]|0){t[a>>2]=t[t[f>>2]>>2];t[o>>2]=(t[(t[f>>2]|0)+4>>2]|0)-(t[t[f>>2]>>2]|0);t[(t[f>>2]|0)+8>>2]=1450}f=t[u>>2]|0;i=t[a>>2]|0;a=t[o>>2]|0;t[n>>2]=t[u>>2];cp(0,0,0,0,0,14,1450,3,0,0,f,i,0,a,0,139536,n);s=r;return}function Nb(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i+4|0;n=i;t[r>>2]=e;if(!(t[r>>2]|0)){s=i;return}if(t[t[r>>2]>>2]|0)pAi[t[135736>>2]&511](t[t[r>>2]>>2]|0);if(t[(t[r>>2]|0)+52>>2]|0){t[n>>2]=0;while(1){if((t[n>>2]|0)>=(t[(t[r>>2]|0)+48>>2]|0))break;Cb(t[(t[(t[r>>2]|0)+52>>2]|0)+(t[n>>2]<<2)>>2]|0);t[n>>2]=(t[n>>2]|0)+1}pAi[t[135736>>2]&511](t[(t[r>>2]|0)+52>>2]|0)}if(t[(t[r>>2]|0)+40>>2]|0){t[n>>2]=0;while(1){if((t[n>>2]|0)>=(t[(t[r>>2]|0)+36>>2]|0))break;Bb(t[(t[(t[r>>2]|0)+40>>2]|0)+(t[n>>2]<<2)>>2]|0);t[n>>2]=(t[n>>2]|0)+1}pAi[t[135736>>2]&511](t[(t[r>>2]|0)+40>>2]|0)}if(t[(t[r>>2]|0)+64>>2]|0)pAi[t[135736>>2]&511](t[(t[r>>2]|0)+64>>2]|0);pAi[t[135736>>2]&511](t[r>>2]|0);s=i;return}function Tb(e){e=e|0;var i=0,r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0;i=s;s=s+48|0;r=i+32|0;n=i+28|0;f=i+24|0;u=i+20|0;a=i+16|0;o=i+12|0;c=i+8|0;l=i+4|0;b=i;t[r>>2]=e;if(!(t[(t[r>>2]|0)+52>>2]|0)){s=i;return}Jb(t[r>>2]|0);t[n>>2]=0;while(1){if((t[n>>2]|0)>=(t[(t[r>>2]|0)+48>>2]|0))break;t[u>>2]=t[(t[(t[r>>2]|0)+52>>2]|0)+(t[n>>2]<<2)>>2];if((t[u>>2]|0)!=0?(t[t[u>>2]>>2]|0)==5:0){Cb(t[u>>2]|0);t[(t[(t[r>>2]|0)+52>>2]|0)+(t[n>>2]<<2)>>2]=0}t[n>>2]=(t[n>>2]|0)+1}t[a>>2]=0;t[n>>2]=(t[(t[r>>2]|0)+48>>2]|0)-1;while(1){if((t[n>>2]|0)<0)break;t[u>>2]=t[(t[(t[r>>2]|0)+52>>2]|0)+(t[n>>2]<<2)>>2];e:do if(t[u>>2]|0){if((t[(t[u>>2]|0)+24>>2]|0)==0?(t[t[u>>2]>>2]|0)!=2:0)t[t[u>>2]>>2]=4;t[f>>2]=0;while(1){if((t[f>>2]|0)>=(t[(t[u>>2]|0)+24>>2]|0))break e;do if((t[(t[(t[u>>2]|0)+28>>2]|0)+((t[f>>2]|0)*20|0)>>2]|0)==0?(t[(t[(t[u>>2]|0)+28>>2]|0)+((t[f>>2]|0)*20|0)+4>>2]|0)>=0:0){e=(t[(t[u>>2]|0)+28>>2]|0)+((t[f>>2]|0)*20|0)|0;if((t[(t[(t[u>>2]|0)+28>>2]|0)+((t[f>>2]|0)*20|0)+4>>2]|0)==(t[n>>2]|0)){t[e+4>>2]=-1;break}if((t[e+12>>2]|0)<0){t[o>>2]=t[(t[(t[u>>2]|0)+28>>2]|0)+((t[f>>2]|0)*20|0)+4>>2];t[a>>2]=1;t[(t[(t[u>>2]|0)+28>>2]|0)+((t[f>>2]|0)*20|0)+4>>2]=-2;t[(t[u>>2]|0)+4>>2]=1;Qb(t[r>>2]|0,t[n>>2]|0,t[o>>2]|0,t[(t[(t[u>>2]|0)+28>>2]|0)+((t[f>>2]|0)*20|0)+8>>2]|0);t[(t[u>>2]|0)+4>>2]=0}}while(0);t[f>>2]=(t[f>>2]|0)+1}}while(0);t[n>>2]=(t[n>>2]|0)+-1}e:do if(t[a>>2]|0){t[n>>2]=0;while(1){if((t[n>>2]|0)>=(t[(t[r>>2]|0)+48>>2]|0))break e;t[u>>2]=t[(t[(t[r>>2]|0)+52>>2]|0)+(t[n>>2]<<2)>>2];i:do if(t[u>>2]|0){t[f>>2]=0;while(1){if((t[f>>2]|0)>=(t[(t[u>>2]|0)+24>>2]|0))break i;t[c>>2]=(t[(t[u>>2]|0)+28>>2]|0)+((t[f>>2]|0)*20|0);if(((t[t[c>>2]>>2]|0)==0?(t[(t[c>>2]|0)+12>>2]|0)<0:0)?(t[(t[c>>2]|0)+4>>2]|0)>=0:0)t[(t[c>>2]|0)+4>>2]=-1;t[f>>2]=(t[f>>2]|0)+1}}while(0);t[n>>2]=(t[n>>2]|0)+1}}while(0);t[n>>2]=0;while(1){if((t[n>>2]|0)>=(t[(t[r>>2]|0)+48>>2]|0))break;t[u>>2]=t[(t[(t[r>>2]|0)+52>>2]|0)+(t[n>>2]<<2)>>2];if(t[u>>2]|0)t[(t[u>>2]|0)+12>>2]=0;t[n>>2]=(t[n>>2]|0)+1}t[u>>2]=t[t[(t[r>>2]|0)+52>>2]>>2];if(t[u>>2]|0)t[(t[u>>2]|0)+12>>2]=1;while(1){if(!(t[u>>2]|0))break;t[l>>2]=0;t[(t[u>>2]|0)+12>>2]=2;t[f>>2]=0;while(1){if((t[f>>2]|0)>=(t[(t[u>>2]|0)+24>>2]|0))break;do if((t[(t[(t[u>>2]|0)+28>>2]|0)+((t[f>>2]|0)*20|0)+4>>2]|0)>=0){if((t[(t[(t[u>>2]|0)+28>>2]|0)+((t[f>>2]|0)*20|0)>>2]|0)==0?(t[(t[(t[u>>2]|0)+28>>2]|0)+((t[f>>2]|0)*20|0)+12>>2]|0)<0:0)break;t[b>>2]=t[(t[(t[u>>2]|0)+28>>2]|0)+((t[f>>2]|0)*20|0)+4>>2];if((t[(t[(t[r>>2]|0)+52>>2]|0)+(t[b>>2]<<2)>>2]|0)!=0?(t[(t[(t[(t[r>>2]|0)+52>>2]|0)+(t[b>>2]<<2)>>2]|0)+12>>2]|0)==0:0){t[(t[(t[(t[r>>2]|0)+52>>2]|0)+(t[b>>2]<<2)>>2]|0)+12>>2]=1;t[l>>2]=t[(t[(t[r>>2]|0)+52>>2]|0)+(t[b>>2]<<2)>>2]}}while(0);t[f>>2]=(t[f>>2]|0)+1}e:do if(!(t[l>>2]|0)){t[n>>2]=1;while(1){if((t[n>>2]|0)>=(t[(t[r>>2]|0)+48>>2]|0))break e;t[u>>2]=t[(t[(t[r>>2]|0)+52>>2]|0)+(t[n>>2]<<2)>>2];if((t[u>>2]|0)!=0?(t[(t[u>>2]|0)+12>>2]|0)==1:0)break;t[n>>2]=(t[n>>2]|0)+1}t[l>>2]=t[u>>2]}while(0);t[u>>2]=t[l>>2]}t[n>>2]=0;while(1){if((t[n>>2]|0)>=(t[(t[r>>2]|0)+48>>2]|0))break;t[u>>2]=t[(t[(t[r>>2]|0)+52>>2]|0)+(t[n>>2]<<2)>>2];if((t[u>>2]|0)!=0?(t[(t[u>>2]|0)+12>>2]|0)==0:0){Cb(t[u>>2]|0);t[(t[(t[r>>2]|0)+52>>2]|0)+(t[n>>2]<<2)>>2]=0}t[n>>2]=(t[n>>2]|0)+1}s=i;return}function Lb(e){e=e|0;var i=0,r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0,S=0,g=0,y=0,F=0,O=0,A=0,M=0,R=0;i=s;s=s+80|0;r=i+72|0;n=i+68|0;f=i+64|0;u=i+60|0;a=i+56|0;o=i+52|0;c=i+48|0;l=i+44|0;b=i+40|0;k=i+36|0;h=i+32|0;w=i+28|0;d=i+24|0;v=i+20|0;m=i+16|0;_=i+12|0;p=i+8|0;E=i+4|0;S=i;t[n>>2]=e;t[f>>2]=gAi[t[135744>>2]&511](56)|0;if(!(t[f>>2]|0)){Eb(t[n>>2]|0,139512);t[r>>2]=0;g=t[r>>2]|0;s=i;return g|0}e=(t[f>>2]|0)+0|0;y=e+56|0;do{t[e>>2]=0;e=e+4|0}while((e|0)<(y|0));t[t[f>>2]>>2]=t[t[n>>2]>>2];t[(t[f>>2]|0)+4>>2]=t[(t[n>>2]|0)+48>>2];t[(t[f>>2]|0)+8>>2]=t[(t[n>>2]|0)+52>>2];t[(t[f>>2]|0)+12>>2]=t[(t[n>>2]|0)+36>>2];t[(t[f>>2]|0)+16>>2]=t[(t[n>>2]|0)+40>>2];t[(t[f>>2]|0)+20>>2]=t[(t[n>>2]|0)+60>>2];t[(t[f>>2]|0)+24>>2]=t[(t[n>>2]|0)+64>>2];t[(t[f>>2]|0)+28>>2]=t[(t[n>>2]|0)+68>>2];t[(t[f>>2]|0)+32>>2]=t[(t[n>>2]|0)+76>>2];if((t[(t[f>>2]|0)+28>>2]|0)==-1)ib(t[f>>2]|0)|0;do if((((((t[(t[f>>2]|0)+28>>2]|0)!=0?(t[(t[f>>2]|0)+20>>2]|0)==0:0)?(t[(t[n>>2]|0)+72>>2]|0)==0:0)?(t[(t[f>>2]|0)+16>>2]|0)!=0:0)?(t[t[(t[f>>2]|0)+16>>2]>>2]|0)!=0:0)?(t[(t[t[(t[f>>2]|0)+16>>2]>>2]|0)+4>>2]|0)==5:0){t[o>>2]=0;t[c>>2]=0;t[l>>2]=gAi[t[135744>>2]&511](t[(t[f>>2]|0)+4>>2]<<2)|0;if(!(t[l>>2]|0)){Eb(t[n>>2]|0,139512);pAi[t[135736>>2]&511](t[f>>2]|0);t[r>>2]=0;g=t[r>>2]|0;s=i;return g|0}t[u>>2]=0;while(1){if((t[u>>2]|0)>=(t[(t[f>>2]|0)+4>>2]|0))break;if(t[(t[(t[f>>2]|0)+8>>2]|0)+(t[u>>2]<<2)>>2]|0){t[(t[l>>2]|0)+(t[u>>2]<<2)>>2]=t[o>>2];t[o>>2]=(t[o>>2]|0)+1}else t[(t[l>>2]|0)+(t[u>>2]<<2)>>2]=-1;t[u>>2]=(t[u>>2]|0)+1}t[w>>2]=gAi[t[135744>>2]&511](t[(t[f>>2]|0)+12>>2]<<2)|0;if(!(t[w>>2]|0)){Eb(t[n>>2]|0,139512);
	pAi[t[135736>>2]&511](t[l>>2]|0);pAi[t[135736>>2]&511](t[f>>2]|0);t[r>>2]=0;g=t[r>>2]|0;s=i;return g|0}t[b>>2]=gAi[t[135744>>2]&511](t[(t[f>>2]|0)+12>>2]<<2)|0;if(!(t[b>>2]|0)){Eb(t[n>>2]|0,139512);pAi[t[135736>>2]&511](t[w>>2]|0);pAi[t[135736>>2]&511](t[l>>2]|0);pAi[t[135736>>2]&511](t[f>>2]|0);t[r>>2]=0;g=t[r>>2]|0;s=i;return g|0}t[u>>2]=0;while(1){if((t[u>>2]|0)>=(t[(t[f>>2]|0)+12>>2]|0)){F=44;break}if((t[(t[(t[(t[f>>2]|0)+16>>2]|0)+(t[u>>2]<<2)>>2]|0)+4>>2]|0)!=5){F=39;break}if((t[(t[(t[(t[f>>2]|0)+16>>2]|0)+(t[u>>2]<<2)>>2]|0)+8>>2]|0)!=2){F=39;break}t[d>>2]=t[(t[(t[(t[f>>2]|0)+16>>2]|0)+(t[u>>2]<<2)>>2]|0)+20>>2];t[a>>2]=0;while(1){if((t[a>>2]|0)>=(t[c>>2]|0))break;e=(Xl(t[(t[w>>2]|0)+(t[a>>2]<<2)>>2]|0,t[d>>2]|0)|0)!=0;O=t[a>>2]|0;if(e){F=30;break}t[a>>2]=O+1}if((F|0)==30){F=0;t[(t[b>>2]|0)+(t[u>>2]<<2)>>2]=O}if((t[a>>2]|0)>=(t[c>>2]|0)){t[(t[b>>2]|0)+(t[u>>2]<<2)>>2]=t[c>>2];e=Yl(t[d>>2]|0)|0;t[(t[w>>2]|0)+(t[c>>2]<<2)>>2]=e;if(!(t[(t[w>>2]|0)+(t[c>>2]<<2)>>2]|0)){F=34;break}t[c>>2]=(t[c>>2]|0)+1}t[u>>2]=(t[u>>2]|0)+1}if((F|0)==34){t[u>>2]=0;while(1){A=t[33934]|0;if((t[u>>2]|0)>=(t[c>>2]|0))break;pAi[A&511](t[(t[w>>2]|0)+(t[u>>2]<<2)>>2]|0);t[u>>2]=(t[u>>2]|0)+1}pAi[A&511](t[b>>2]|0);pAi[t[135736>>2]&511](t[w>>2]|0);pAi[t[135736>>2]&511](t[l>>2]|0);pAi[t[135736>>2]&511](t[f>>2]|0);t[r>>2]=0;g=t[r>>2]|0;s=i;return g|0}else if((F|0)==39){pAi[t[135736>>2]&511](t[l>>2]|0);pAi[t[135736>>2]&511](t[b>>2]|0);t[u>>2]=0;while(1){M=t[33934]|0;if((t[u>>2]|0)>=(t[c>>2]|0))break;pAi[M&511](t[(t[w>>2]|0)+(t[u>>2]<<2)>>2]|0);t[u>>2]=(t[u>>2]|0)+1}pAi[M&511](t[w>>2]|0);pAi[t[135736>>2]&511](t[f>>2]|0);t[r>>2]=0;g=t[r>>2]|0;s=i;return g|0}else if((F|0)==44){e=(te((t[o>>2]|0)+1|0,(t[c>>2]|0)+1|0)|0)<<2;t[k>>2]=gAi[t[135744>>2]&511](e)|0;if(!(t[k>>2]|0)){pAi[t[135736>>2]&511](t[l>>2]|0);pAi[t[135736>>2]&511](t[b>>2]|0);pAi[t[135736>>2]&511](t[w>>2]|0);pAi[t[135736>>2]&511](t[f>>2]|0);t[r>>2]=0;g=t[r>>2]|0;s=i;return g|0}VY(t[k>>2]|0,0,(te((t[o>>2]|0)+1|0,(t[c>>2]|0)+1|0)|0)<<2|0)|0;t[h>>2]=0;t[u>>2]=0;e:while(1){if((t[u>>2]|0)>=(t[(t[f>>2]|0)+4>>2]|0))break;t[v>>2]=t[(t[l>>2]|0)+(t[u>>2]<<2)>>2];i:do if((t[v>>2]|0)!=-1){t[E>>2]=t[(t[(t[f>>2]|0)+8>>2]|0)+(t[u>>2]<<2)>>2];e=te(t[v>>2]|0,(t[c>>2]|0)+1|0)|0;t[(t[k>>2]|0)+(e<<2)>>2]=t[t[E>>2]>>2];t[a>>2]=0;r:while(1){if((t[a>>2]|0)>=(t[(t[E>>2]|0)+24>>2]|0))break i;t[S>>2]=(t[(t[E>>2]|0)+28>>2]|0)+((t[a>>2]|0)*20|0);do if((t[(t[S>>2]|0)+4>>2]|0)!=-1){if(!(t[t[S>>2]>>2]|0))break;t[m>>2]=t[(t[b>>2]|0)+(t[t[t[S>>2]>>2]>>2]<<2)>>2];if((t[h>>2]|0)==0?(t[(t[t[S>>2]>>2]|0)+60>>2]|0)!=0:0){e=(te(t[o>>2]|0,t[c>>2]|0)|0)<<2;t[h>>2]=gAi[t[135744>>2]&511](e)|0;if(!(t[h>>2]|0))break r;VY(t[h>>2]|0,0,(te(t[o>>2]|0,t[c>>2]|0)|0)<<2|0)|0}t[_>>2]=t[(t[l>>2]|0)+(t[(t[S>>2]|0)+4>>2]<<2)>>2];e=te(t[v>>2]|0,(t[c>>2]|0)+1|0)|0;t[p>>2]=t[(t[k>>2]|0)+(e+(t[m>>2]|0)+1<<2)>>2];if(t[p>>2]|0)if((t[p>>2]|0)!=((t[_>>2]|0)+1|0)){F=59;break e}else break;e=te(t[v>>2]|0,(t[c>>2]|0)+1|0)|0;t[(t[k>>2]|0)+(e+(t[m>>2]|0)+1<<2)>>2]=(t[_>>2]|0)+1;if(!(t[h>>2]|0))break;e=te(t[v>>2]|0,t[c>>2]|0)|0;t[(t[h>>2]|0)+(e+(t[m>>2]|0)<<2)>>2]=t[(t[t[S>>2]>>2]|0)+60>>2]}while(0);t[a>>2]=(t[a>>2]|0)+1}Eb(t[n>>2]|0,139512)}while(0);t[u>>2]=(t[u>>2]|0)+1}if((F|0)==59){t[(t[f>>2]|0)+28>>2]=0;if(t[h>>2]|0)pAi[t[135736>>2]&511](t[h>>2]|0);pAi[t[135736>>2]&511](t[k>>2]|0);pAi[t[135736>>2]&511](t[l>>2]|0);pAi[t[135736>>2]&511](t[b>>2]|0);t[u>>2]=0;while(1){R=t[33934]|0;if((t[u>>2]|0)>=(t[c>>2]|0))break;pAi[R&511](t[(t[w>>2]|0)+(t[u>>2]<<2)>>2]|0);t[u>>2]=(t[u>>2]|0)+1}pAi[R&511](t[w>>2]|0);break}t[(t[f>>2]|0)+28>>2]=1;if(t[(t[f>>2]|0)+8>>2]|0){t[u>>2]=0;while(1){if((t[u>>2]|0)>=(t[(t[f>>2]|0)+4>>2]|0))break;Cb(t[(t[(t[f>>2]|0)+8>>2]|0)+(t[u>>2]<<2)>>2]|0);t[u>>2]=(t[u>>2]|0)+1}pAi[t[135736>>2]&511](t[(t[f>>2]|0)+8>>2]|0)}t[(t[f>>2]|0)+8>>2]=0;t[(t[f>>2]|0)+4>>2]=0;if(t[(t[f>>2]|0)+16>>2]|0){t[u>>2]=0;while(1){if((t[u>>2]|0)>=(t[(t[f>>2]|0)+12>>2]|0))break;Bb(t[(t[(t[f>>2]|0)+16>>2]|0)+(t[u>>2]<<2)>>2]|0);t[u>>2]=(t[u>>2]|0)+1}pAi[t[135736>>2]&511](t[(t[f>>2]|0)+16>>2]|0)}t[(t[f>>2]|0)+16>>2]=0;t[(t[f>>2]|0)+12>>2]=0;t[(t[f>>2]|0)+40>>2]=t[k>>2];t[(t[f>>2]|0)+44>>2]=t[h>>2];t[(t[f>>2]|0)+52>>2]=t[w>>2];t[(t[f>>2]|0)+48>>2]=t[c>>2];t[(t[f>>2]|0)+36>>2]=t[o>>2];pAi[t[135736>>2]&511](t[l>>2]|0);pAi[t[135736>>2]&511](t[b>>2]|0);break}}while(0);t[t[n>>2]>>2]=0;t[(t[n>>2]|0)+48>>2]=0;t[(t[n>>2]|0)+52>>2]=0;t[(t[n>>2]|0)+36>>2]=0;t[(t[n>>2]|0)+40>>2]=0;t[(t[n>>2]|0)+60>>2]=0;t[(t[n>>2]|0)+64>>2]=0;t[r>>2]=t[f>>2];g=t[r>>2]|0;s=i;return g|0}function Db(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,m=0,_=0,p=0,E=0,S=0,g=0,y=0,F=0,O=0,A=0,M=0;r=s;s=s+176|0;n=r;f=r+164|0;a=r+160|0;o=r+156|0;c=r+60|0;l=r+56|0;b=r+52|0;k=r+48|0;h=r+44|0;w=r+40|0;d=r+36|0;m=r+32|0;_=r+28|0;p=r+24|0;E=r+20|0;S=r+16|0;g=r+12|0;y=r+8|0;F=r+4|0;t[a>>2]=e;t[o>>2]=i;t[c>>2]=r+64;t[b>>2]=0;t[(t[c>>2]|0)+64>>2]=t[o>>2];t[(t[c>>2]|0)+56>>2]=0;t[(t[c>>2]|0)+88>>2]=0;t[(t[c>>2]|0)+4>>2]=1;t[(t[c>>2]|0)+32>>2]=0;t[(t[c>>2]|0)+36>>2]=0;t[(t[c>>2]|0)+40>>2]=0;t[t[c>>2]>>2]=0;t[(t[c>>2]|0)+8>>2]=t[a>>2];t[(t[c>>2]|0)+20>>2]=t[t[(t[a>>2]|0)+8>>2]>>2];t[(t[c>>2]|0)+24>>2]=0;t[(t[c>>2]|0)+28>>2]=0;t[(t[c>>2]|0)+68>>2]=0;t[(t[c>>2]|0)+48>>2]=0;do if((t[(t[a>>2]|0)+20>>2]|0)>0){o=gAi[t[135744>>2]&511](t[(t[a>>2]|0)+20>>2]<<2)|0;t[(t[c>>2]|0)+44>>2]=o;if(t[(t[c>>2]|0)+44>>2]|0){VY(t[(t[c>>2]|0)+44>>2]|0,0,t[(t[a>>2]|0)+20>>2]<<2|0)|0;break}Eb(0,139408);t[f>>2]=-1;O=t[f>>2]|0;s=r;return O|0}else t[(t[c>>2]|0)+44>>2]=0;while(0);e:while(1){if(t[t[c>>2]>>2]|0)break;if(!(t[(t[c>>2]|0)+20>>2]|0))break;if(!(u[(t[(t[c>>2]|0)+64>>2]|0)+(t[(t[c>>2]|0)+56>>2]|0)>>0]|0)){if(!(t[(t[c>>2]|0)+20>>2]|0))break;if((t[t[(t[c>>2]|0)+20>>2]>>2]|0)==2)break}t[k>>2]=1;if((u[(t[(t[c>>2]|0)+64>>2]|0)+(t[(t[c>>2]|0)+56>>2]|0)>>0]|0|0)==0?(t[(t[c>>2]|0)+44>>2]|0)==0:0){if((t[(t[c>>2]|0)+24>>2]|0)<(t[(t[(t[c>>2]|0)+20>>2]|0)+24>>2]|0)){t[w>>2]=(t[(t[(t[c>>2]|0)+20>>2]|0)+28>>2]|0)+((t[(t[c>>2]|0)+24>>2]|0)*20|0);if((t[(t[w>>2]|0)+4>>2]|0)>=0){t[d>>2]=t[t[w>>2]>>2];if((t[(t[d>>2]|0)+12>>2]|0)==0?(t[(t[d>>2]|0)+16>>2]|0)>0:0)A=17}else A=17}}else A=17;i:do if((A|0)==17){A=0;t[(t[c>>2]|0)+28>>2]=0;r:while(1){if((t[(t[c>>2]|0)+24>>2]|0)>=(t[(t[(t[c>>2]|0)+20>>2]|0)+24>>2]|0)){A=88;break}t[w>>2]=(t[(t[(t[c>>2]|0)+20>>2]|0)+28>>2]|0)+((t[(t[c>>2]|0)+24>>2]|0)*20|0);n:do if((t[(t[w>>2]|0)+4>>2]|0)>=0){t[d>>2]=t[t[w>>2]>>2];t[l>>2]=0;t[h>>2]=1;do if((t[(t[w>>2]|0)+12>>2]|0)>=0){if(!(t[(t[c>>2]|0)+44>>2]|0)){A=22;break e}t[m>>2]=t[(t[(t[c>>2]|0)+44>>2]|0)+(t[(t[w>>2]|0)+12>>2]<<2)>>2];t[_>>2]=(t[(t[(t[c>>2]|0)+8>>2]|0)+24>>2]|0)+(t[(t[w>>2]|0)+12>>2]<<3);if((t[m>>2]|0)>=(t[t[_>>2]>>2]|0))M=(t[m>>2]|0)<=(t[(t[_>>2]|0)+4>>2]|0);else M=0;t[l>>2]=M&1;if((t[l>>2]|0)!=0?(t[t[_>>2]>>2]|0)!=(t[(t[_>>2]|0)+4>>2]|0):0)t[h>>2]=0}else{if(!(t[d>>2]|0)){A=29;break r}if(!(u[(t[(t[c>>2]|0)+64>>2]|0)+(t[(t[c>>2]|0)+56>>2]|0)>>0]|0)){if(t[(t[d>>2]|0)+12>>2]|0)break;if((t[(t[d>>2]|0)+16>>2]|0)<=0)break;t[(t[c>>2]|0)+28>>2]=1;t[k>>2]=0;t[l>>2]=1;break}t[b>>2]=Mp(0,(t[(t[c>>2]|0)+64>>2]|0)+(t[(t[c>>2]|0)+56>>2]|0)|0,k)|0;t[l>>2]=$b(t[d>>2]|0,t[b>>2]|0)|0;if(((t[l>>2]|0)==1?(t[(t[d>>2]|0)+12>>2]|0)>=0:0)?(t[(t[d>>2]|0)+16>>2]|0)>0:0){t[p>>2]=t[(t[(t[a>>2]|0)+8>>2]|0)+(t[(t[w>>2]|0)+4>>2]<<2)>>2];if((t[(t[w>>2]|0)+8>>2]|0)>=0){if(!(t[(t[c>>2]|0)+44>>2]|0)){A=38;break e}if(!(t[(t[c>>2]|0)+8>>2]|0)){A=38;break e}if(!(t[(t[(t[c>>2]|0)+8>>2]|0)+24>>2]|0)){A=38;break e}t[E>>2]=(t[(t[(t[c>>2]|0)+8>>2]|0)+24>>2]|0)+(t[(t[w>>2]|0)+8>>2]<<3);if((t[(t[(t[c>>2]|0)+44>>2]|0)+(t[(t[w>>2]|0)+8>>2]<<2)>>2]|0)>=(t[(t[E>>2]|0)+4>>2]|0))break n;o=(t[(t[c>>2]|0)+44>>2]|0)+(t[(t[w>>2]|0)+8>>2]<<2)|0;t[o>>2]=(t[o>>2]|0)+1}if((t[(t[(t[c>>2]|0)+20>>2]|0)+24>>2]|0)>((t[(t[c>>2]|0)+24>>2]|0)+1|0))Kb(t[c>>2]|0);t[(t[c>>2]|0)+28>>2]=1;do{if((t[(t[c>>2]|0)+28>>2]|0)==(t[(t[d>>2]|0)+16>>2]|0))break;o=(t[c>>2]|0)+56|0;t[o>>2]=(t[o>>2]|0)+(t[k>>2]|0);if(!(u[(t[(t[c>>2]|0)+64>>2]|0)+(t[(t[c>>2]|0)+56>>2]|0)>>0]|0)){A=46;break}if((t[(t[c>>2]|0)+28>>2]|0)>=(t[(t[d>>2]|0)+12>>2]|0)){t[S>>2]=t[(t[c>>2]|0)+24>>2];t[g>>2]=t[(t[c>>2]|0)+20>>2];t[(t[c>>2]|0)+24>>2]=-1;t[(t[c>>2]|0)+20>>2]=t[p>>2];Kb(t[c>>2]|0);t[(t[c>>2]|0)+24>>2]=t[S>>2];t[(t[c>>2]|0)+20>>2]=t[g>>2]}t[b>>2]=Mp(0,(t[(t[c>>2]|0)+64>>2]|0)+(t[(t[c>>2]|0)+56>>2]|0)|0,k)|0;t[l>>2]=$b(t[d>>2]|0,t[b>>2]|0)|0;o=(t[c>>2]|0)+28|0;t[o>>2]=(t[o>>2]|0)+1}while((t[l>>2]|0)==1);if((A|0)==46){A=0;o=(t[c>>2]|0)+56|0;t[o>>2]=(t[o>>2]|0)-(t[k>>2]|0)}if((t[(t[c>>2]|0)+28>>2]|0)<(t[(t[d>>2]|0)+12>>2]|0))t[l>>2]=0;if((t[l>>2]|0)<0)t[l>>2]=0;if(!(t[l>>2]|0))break i;if((t[(t[w>>2]|0)+8>>2]|0)<0)break;if(!(t[(t[c>>2]|0)+44>>2]|0)){A=57;break e}o=(t[(t[c>>2]|0)+44>>2]|0)+(t[(t[w>>2]|0)+8>>2]<<2)|0;t[o>>2]=(t[o>>2]|0)+-1;break}if(((t[l>>2]|0)==0?(t[(t[d>>2]|0)+12>>2]|0)==0:0)?(t[(t[d>>2]|0)+16>>2]|0)>0:0){t[(t[c>>2]|0)+28>>2]=1;t[k>>2]=0;t[l>>2]=1}}while(0);if((t[l>>2]|0)!=1)if((t[l>>2]|0)<0){A=86;break r}else break;if((t[(t[w>>2]|0)+16>>2]|0)!=1){if(((t[h>>2]|0)==0?(t[(t[w>>2]|0)+12>>2]|0)>=0:0)?(t[(t[(t[c>>2]|0)+20>>2]|0)+24>>2]|0)>((t[(t[c>>2]|0)+24>>2]|0)+1|0):0)A=70}else A=70;if((A|0)==70){A=0;Kb(t[c>>2]|0)}if((t[(t[w>>2]|0)+8>>2]|0)<0)break r;if(!(t[(t[c>>2]|0)+44>>2]|0)){A=75;break e}if(!(t[(t[c>>2]|0)+8>>2]|0)){A=75;break e}if(!(t[(t[(t[c>>2]|0)+8>>2]|0)+24>>2]|0)){A=75;break e}t[y>>2]=(t[(t[(t[c>>2]|0)+8>>2]|0)+24>>2]|0)+(t[(t[w>>2]|0)+8>>2]<<3);if((t[(t[(t[c>>2]|0)+44>>2]|0)+(t[(t[w>>2]|0)+8>>2]<<2)>>2]|0)<(t[(t[y>>2]|0)+4>>2]|0)){A=77;break r}}while(0);o=(t[c>>2]|0)+24|0;t[o>>2]=(t[o>>2]|0)+1}if((A|0)==29){A=0;xe(t[v>>2]|0,139424,n|0)|0;t[t[c>>2]>>2]=-2;A=88}else if((A|0)==77){A=0;o=(t[(t[c>>2]|0)+44>>2]|0)+(t[(t[w>>2]|0)+8>>2]<<2)|0;t[o>>2]=(t[o>>2]|0)+1}else if((A|0)==86){A=0;t[t[c>>2]>>2]=-4;A=88}if((A|0)==88){A=0;if(t[(t[c>>2]|0)+24>>2]|0)break;if(!(t[(t[(t[c>>2]|0)+20>>2]|0)+24>>2]|0))break;else continue e}if((t[(t[w>>2]|0)+12>>2]|0)>=0?(t[(t[w>>2]|0)+12>>2]|0)<1193046:0){if(!(t[(t[c>>2]|0)+44>>2]|0)){A=81;break e}t[(t[(t[c>>2]|0)+44>>2]|0)+(t[(t[w>>2]|0)+12>>2]<<2)>>2]=0}t[(t[c>>2]|0)+20>>2]=t[(t[(t[a>>2]|0)+8>>2]|0)+(t[(t[w>>2]|0)+4>>2]<<2)>>2];t[(t[c>>2]|0)+24>>2]=0;if(!(t[t[w>>2]>>2]|0))continue e;o=(t[c>>2]|0)+56|0;t[o>>2]=(t[o>>2]|0)+(t[k>>2]|0);continue e}while(0);t[(t[c>>2]|0)+4>>2]=0;Xb(t[c>>2]|0)}if((A|0)==22)t[t[c>>2]>>2]=-1;else if((A|0)==38)t[t[c>>2]>>2]=-1;else if((A|0)==57)t[t[c>>2]>>2]=-1;else if((A|0)==75)t[t[c>>2]>>2]=-1;else if((A|0)==81)t[t[c>>2]>>2]=-1;if(t[(t[c>>2]|0)+40>>2]|0){e:do if(t[(t[c>>2]|0)+44>>2]|0){t[F>>2]=0;while(1){if((t[F>>2]|0)>=(t[(t[c>>2]|0)+32>>2]|0))break e;if(t[(t[(t[c>>2]|0)+40>>2]|0)+(t[F>>2]<<4)+12>>2]|0)pAi[t[135736>>2]&511](t[(t[(t[c>>2]|0)+40>>2]|0)+(t[F>>2]<<4)+12>>2]|0);t[F>>2]=(t[F>>2]|0)+1}}while(0);pAi[t[135736>>2]&511](t[(t[c>>2]|0)+40>>2]|0)}if(!(t[(t[c>>2]|0)+20>>2]|0)){t[f>>2]=-1;O=t[f>>2]|0;s=r;return O|0}if(t[(t[c>>2]|0)+44>>2]|0)pAi[t[135736>>2]&511](t[(t[c>>2]|0)+44>>2]|0);if(!(t[t[c>>2]>>2]|0)){t[f>>2]=1;O=t[f>>2]|0;s=r;return O|0}F=t[c>>2]|0;if((t[t[c>>2]>>2]|0)!=-1){t[f>>2]=t[F>>2];O=t[f>>2]|0;s=r;return O|0}if((t[F+88>>2]|0)>1e7){t[f>>2]=-1;O=t[f>>2]|0;s=r;return O|0}else{t[f>>2]=0;O=t[f>>2]|0;s=r;return O|0}return 0}function Cb(e){e=e|0;var i=0,r=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if(!(t[r>>2]|0)){s=i;return}if(t[(t[r>>2]|0)+28>>2]|0)pAi[t[135736>>2]&511](t[(t[r>>2]|0)+28>>2]|0);if(t[(t[r>>2]|0)+40>>2]|0)pAi[t[135736>>2]&511](t[(t[r>>2]|0)+40>>2]|0);pAi[t[135736>>2]&511](t[r>>2]|0);s=i;return}function Pb(e){e=e|0;var i=0,r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0;i=s;s=s+48|0;r=i+40|0;n=i+36|0;f=i+32|0;u=i+28|0;a=i+24|0;o=i+20|0;c=i+16|0;l=i+12|0;b=i+8|0;k=i+4|0;h=i;t[n>>2]=e;t[k>>2]=1;t[h>>2]=1;e=t[n>>2]|0;if((t[(t[n>>2]|0)+68>>2]|0)!=-1){t[r>>2]=t[e+68>>2];w=t[r>>2]|0;s=i;return w|0}if(t[e+76>>2]&1)t[h>>2]=0;t[f>>2]=0;while(1){if((t[f>>2]|0)>=(t[(t[n>>2]|0)+48>>2]|0))break;t[a>>2]=t[(t[(t[n>>2]|0)+52>>2]|0)+(t[f>>2]<<2)>>2];e:do if((t[a>>2]|0)!=0?(t[(t[a>>2]|0)+24>>2]|0)>=2:0){t[u>>2]=0;while(1){if((t[u>>2]|0)>=(t[(t[a>>2]|0)+24>>2]|0))break e;t[o>>2]=(t[(t[a>>2]|0)+28>>2]|0)+((t[u>>2]|0)*20|0);i:do if((t[t[o>>2]>>2]|0)!=0?(t[(t[o>>2]|0)+4>>2]|0)!=-1:0){t[b>>2]=0;while(1){if((t[b>>2]|0)>=(t[u>>2]|0))break i;t[c>>2]=(t[(t[a>>2]|0)+28>>2]|0)+((t[b>>2]|0)*20|0);do if(((((t[(t[c>>2]|0)+4>>2]|0)!=-1?(t[t[c>>2]>>2]|0)!=0:0)?(t[(t[o>>2]|0)+4>>2]|0)==(t[(t[c>>2]|0)+4>>2]|0):0)?(ek(t[t[o>>2]>>2]|0,t[t[c>>2]>>2]|0,t[h>>2]|0)|0)!=0:0)?(t[(t[o>>2]|0)+8>>2]|0)==(t[(t[c>>2]|0)+8>>2]|0):0){if((t[(t[o>>2]|0)+12>>2]|0)!=(t[(t[c>>2]|0)+12>>2]|0))break;t[(t[c>>2]|0)+4>>2]=-1}while(0);t[b>>2]=(t[b>>2]|0)+1}}while(0);t[u>>2]=(t[u>>2]|0)+1}}while(0);t[f>>2]=(t[f>>2]|0)+1}t[f>>2]=0;while(1){if((t[f>>2]|0)>=(t[(t[n>>2]|0)+48>>2]|0))break;t[a>>2]=t[(t[(t[n>>2]|0)+52>>2]|0)+(t[f>>2]<<2)>>2];if((t[a>>2]|0)!=0?(t[(t[a>>2]|0)+24>>2]|0)>=2:0){t[l>>2]=0;t[u>>2]=0;while(1){if((t[u>>2]|0)>=(t[(t[a>>2]|0)+24>>2]|0))break;t[o>>2]=(t[(t[a>>2]|0)+28>>2]|0)+((t[u>>2]|0)*20|0);e:do if((t[t[o>>2]>>2]|0)!=0?(t[(t[o>>2]|0)+4>>2]|0)!=-1:0){t[b>>2]=0;while(1){if((t[b>>2]|0)>=(t[u>>2]|0))break e;t[c>>2]=(t[(t[a>>2]|0)+28>>2]|0)+((t[b>>2]|0)*20|0);do if((t[(t[c>>2]|0)+4>>2]|0)!=-1){h=t[o>>2]|0;if(t[t[c>>2]>>2]|0){if(!(ik(t[h>>2]|0,t[t[c>>2]>>2]|0,1)|0))break;t[k>>2]=0;t[(t[o>>2]|0)+16>>2]=1;t[(t[c>>2]|0)+16>>2]=1;t[l>>2]=t[o>>2];break}if((t[h+4>>2]|0)!=-1?(t[k>>2]=rk(t[n>>2]|0,t[(t[(t[n>>2]|0)+52>>2]|0)+(t[(t[o>>2]|0)+4>>2]<<2)>>2]|0,t[(t[c>>2]|0)+4>>2]|0,t[t[c>>2]>>2]|0)|0,(t[k>>2]|0)==0):0){t[(t[o>>2]|0)+16>>2]=1;t[l>>2]=t[o>>2]}}while(0);t[b>>2]=(t[b>>2]|0)+1}}while(0);t[u>>2]=(t[u>>2]|0)+1}if(t[l>>2]|0)t[(t[l>>2]|0)+16>>2]=2}t[f>>2]=(t[f>>2]|0)+1}t[(t[n>>2]|0)+68>>2]=t[k>>2];t[r>>2]=t[k>>2];w=t[r>>2]|0;s=i;return w|0}function Bb(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i+4|0;n=i;t[r>>2]=e;if(!(t[r>>2]|0)){s=i;return}t[n>>2]=0;while(1){if((t[n>>2]|0)>=(t[(t[r>>2]|0)+52>>2]|0))break;nk(t[(t[(t[r>>2]|0)+56>>2]|0)+(t[n>>2]<<2)>>2]|0);t[n>>2]=(t[n>>2]|0)+1}if(t[(t[r>>2]|0)+56>>2]|0)pAi[t[135736>>2]&511](t[(t[r>>2]|0)+56>>2]|0);if((t[(t[r>>2]|0)+4>>2]|0)==5?(t[(t[r>>2]|0)+20>>2]|0)!=0:0)pAi[t[135736>>2]&511](t[(t[r>>2]|0)+20>>2]|0);if((t[(t[r>>2]|0)+4>>2]|0)==5?(t[(t[r>>2]|0)+24>>2]|0)!=0:0)pAi[t[135736>>2]&511](t[(t[r>>2]|0)+24>>2]|0);if((t[(t[r>>2]|0)+4>>2]|0)==136?(t[(t[r>>2]|0)+20>>2]|0)!=0:0)pAi[t[135736>>2]&511](t[(t[r>>2]|0)+20>>2]|0);pAi[t[135736>>2]&511](t[r>>2]|0);s=i;return}function Ib(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0;r=s;s=s+16|0;n=r+12|0;f=r+8|0;u=r+4|0;a=r;t[f>>2]=e;t[u>>2]=i;t[a>>2]=gAi[t[135744>>2]&511](64)|0;if(!(t[a>>2]|0)){Eb(t[f>>2]|0,139360);t[n>>2]=0;o=t[n>>2]|0;s=r;return o|0}else{f=(t[a>>2]|0)+0|0;i=f+64|0;do{t[f>>2]=0;f=f+4|0}while((f|0)<(i|0));t[(t[a>>2]|0)+4>>2]=t[u>>2];t[(t[a>>2]|0)+8>>2]=2;t[(t[a>>2]|0)+12>>2]=0;t[(t[a>>2]|0)+16>>2]=0;t[n>>2]=t[a>>2];o=t[n>>2]|0;s=r;return o|0}return 0}function Hb(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0;f=s;s=s+48|0;u=f+40|0;a=f+36|0;o=f+32|0;c=f+28|0;l=f+24|0;b=f+20|0;k=f+16|0;h=f+12|0;w=f+8|0;d=f+4|0;v=f;t[a>>2]=e;t[o>>2]=i;t[c>>2]=r;t[l>>2]=n;if(!(t[l>>2]|0)){t[(t[a>>2]|0)+8>>2]=1450;Rb(t[a>>2]|0,139280);t[u>>2]=-1;m=t[u>>2]|0;s=f;return m|0}if((t[(t[l>>2]|0)+4>>2]|0)==4){if((zb(t[a>>2]|0,t[l>>2]|0)|0)<0){t[u>>2]=-1;m=t[u>>2]|0;s=f;return m|0}if(((t[c>>2]|0)!=0?(t[(t[l>>2]|0)+44>>2]|0)!=(t[c>>2]|0):0)?(t[(t[l>>2]|0)+8>>2]|0)!=8:0)jb(t[a>>2]|0,t[(t[l>>2]|0)+44>>2]|0,t[c>>2]|0);n=t[(t[l>>2]|0)+8>>2]|0;do if((n|0)==8){if(t[c>>2]|0)t[w>>2]=t[c>>2];else{t[w>>2]=Ob(t[a>>2]|0)|0;Ab(t[a>>2]|0,t[w>>2]|0)|0}do if((t[(t[l>>2]|0)+12>>2]|0)==0?(t[(t[l>>2]|0)+40>>2]|0)==0:0){t[d>>2]=fk(t[a>>2]|0,t[l>>2]|0)|0;if(!(t[d>>2]|0)){t[u>>2]=-1;m=t[u>>2]|0;s=f;return m|0}t[(t[d>>2]|0)+8>>2]=2;t[(t[d>>2]|0)+12>>2]=0;t[(t[d>>2]|0)+16>>2]=0;if((Hb(t[a>>2]|0,t[(t[l>>2]|0)+36>>2]|0,0,t[d>>2]|0)|0)>=0){t[h>>2]=t[(t[a>>2]|0)+24>>2];t[k>>2]=xb(t[a>>2]|0)|0;t[(t[(t[a>>2]|0)+64>>2]|0)+(t[k>>2]<<3)>>2]=(t[(t[l>>2]|0)+12>>2]|0)-1;t[(t[(t[a>>2]|0)+64>>2]|0)+(t[k>>2]<<3)+4>>2]=(t[(t[l>>2]|0)+16>>2]|0)-1;qb(t[a>>2]|0,t[h>>2]|0,t[(t[l>>2]|0)+44>>2]|0,t[k>>2]|0);Yb(t[a>>2]|0,t[h>>2]|0,t[w>>2]|0,t[k>>2]|0);jb(t[a>>2]|0,t[(t[l>>2]|0)+36>>2]|0,t[w>>2]|0);break}t[u>>2]=-1;m=t[u>>2]|0;s=f;return m|0}else _=26;while(0);if((_|0)==26?(t[k>>2]=xb(t[a>>2]|0)|0,t[(t[(t[a>>2]|0)+64>>2]|0)+(t[k>>2]<<3)>>2]=(t[(t[l>>2]|0)+12>>2]|0)-1,t[(t[(t[a>>2]|0)+64>>2]|0)+(t[k>>2]<<3)+4>>2]=(t[(t[l>>2]|0)+16>>2]|0)-1,qb(t[a>>2]|0,t[(t[l>>2]|0)+44>>2]|0,t[(t[l>>2]|0)+36>>2]|0,t[k>>2]|0),Yb(t[a>>2]|0,t[(t[l>>2]|0)+44>>2]|0,t[w>>2]|0,t[k>>2]|0),(t[(t[l>>2]|0)+12>>2]|0)==0):0)jb(t[a>>2]|0,t[(t[l>>2]|0)+40>>2]|0,t[w>>2]|0);t[(t[l>>2]|0)+12>>2]=0;t[(t[l>>2]|0)+16>>2]=0;t[(t[l>>2]|0)+8>>2]=2;t[(t[a>>2]|0)+24>>2]=t[w>>2]}else if((n|0)==4){t[(t[l>>2]|0)+8>>2]=2;jb(t[a>>2]|0,t[(t[l>>2]|0)+36>>2]|0,t[(t[l>>2]|0)+44>>2]|0);jb(t[a>>2]|0,t[(t[l>>2]|0)+44>>2]|0,t[(t[l>>2]|0)+36>>2]|0)}else if((n|0)==3){t[(t[l>>2]|0)+8>>2]=2;r=t[a>>2]|0;i=t[(t[l>>2]|0)+36>>2]|0;if(!(t[c>>2]|0)){jb(r,i,0);jb(t[a>>2]|0,t[(t[l>>2]|0)+44>>2]|0,t[(t[a>>2]|0)+24>>2]|0);break}else{jb(r,i,t[c>>2]|0);break}}else if((n|0)==5){t[(t[l>>2]|0)+8>>2]=2;jb(t[a>>2]|0,t[(t[l>>2]|0)+44>>2]|0,t[(t[l>>2]|0)+36>>2]|0)}while(0);t[u>>2]=0;m=t[u>>2]|0;s=f;return m|0}else{if(((t[(t[l>>2]|0)+12>>2]|0)==0?(t[(t[l>>2]|0)+16>>2]|0)==0:0)?(t[(t[l>>2]|0)+8>>2]|0)==8:0){do if(!(t[c>>2]|0)){t[c>>2]=Ob(t[a>>2]|0)|0;if(t[c>>2]|0){Ab(t[a>>2]|0,t[c>>2]|0)|0;break}t[u>>2]=-1;m=t[u>>2]|0;s=f;return m|0}while(0);jb(t[a>>2]|0,t[o>>2]|0,t[c>>2]|0);t[(t[a>>2]|0)+24>>2]=t[c>>2];Bb(t[l>>2]|0);t[u>>2]=0;m=t[u>>2]|0;s=f;return m|0}do if(!(t[c>>2]|0)){t[c>>2]=Ob(t[a>>2]|0)|0;if(t[c>>2]|0){Ab(t[a>>2]|0,t[c>>2]|0)|0;break}t[u>>2]=-1;m=t[u>>2]|0;s=f;return m|0}while(0);t[b>>2]=t[c>>2];if(!((t[(t[l>>2]|0)+8>>2]|0)!=4?(t[(t[l>>2]|0)+8>>2]|0)!=5:0))_=44;do if((_|0)==44){t[v>>2]=Ob(t[a>>2]|0)|0;if(t[v>>2]|0){Ab(t[a>>2]|0,t[v>>2]|0)|0;jb(t[a>>2]|0,t[v>>2]|0,t[c>>2]|0);t[c>>2]=t[v>>2];break}t[u>>2]=-1;m=t[u>>2]|0;s=f;return m|0}while(0);if((zb(t[a>>2]|0,t[l>>2]|0)|0)<0){t[u>>2]=-1;m=t[u>>2]|0;s=f;return m|0}Ub(t[a>>2]|0,t[o>>2]|0,t[l>>2]|0,t[c>>2]|0,-1,-1);t[(t[a>>2]|0)+24>>2]=t[b>>2];b=t[(t[l>>2]|0)+8>>2]|0;if((b|0)==5){t[(t[l>>2]|0)+8>>2]=2;Ub(t[a>>2]|0,t[c>>2]|0,t[l>>2]|0,t[c>>2]|0,-1,-1)}else if((b|0)==3){t[(t[l>>2]|0)+8>>2]=2;jb(t[a>>2]|0,t[o>>2]|0,t[c>>2]|0)}else if((b|0)==4){t[(t[l>>2]|0)+8>>2]=2;jb(t[a>>2]|0,t[o>>2]|0,t[c>>2]|0);Ub(t[a>>2]|0,t[c>>2]|0,t[l>>2]|0,t[c>>2]|0,-1,-1)}t[u>>2]=0;m=t[u>>2]|0;s=f;return m|0}return 0}function xb(e){e=e|0;var i=0,r=0,n=0,f=0,u=0,a=0;i=s;s=s+16|0;r=i+8|0;n=i+4|0;f=i;t[n>>2]=e;e=t[n>>2]|0;do if(!(t[(t[n>>2]|0)+56>>2]|0)){t[e+56>>2]=4;u=gAi[t[135744>>2]&511](t[(t[n>>2]|0)+56>>2]<<3)|0;t[(t[n>>2]|0)+64>>2]=u;if(!(t[(t[n>>2]|0)+64>>2]|0)){Eb(t[n>>2]|0,139168);t[(t[n>>2]|0)+56>>2]=0;t[r>>2]=-1;a=t[r>>2]|0;s=i;return a|0}}else if((t[e+60>>2]|0)>=(t[(t[n>>2]|0)+56>>2]|0)){u=(t[n>>2]|0)+56|0;t[u>>2]=t[u>>2]<<1;t[f>>2]=MAi[t[135760>>2]&511](t[(t[n>>2]|0)+64>>2]|0,t[(t[n>>2]|0)+56>>2]<<3)|0;if(t[f>>2]|0){t[(t[n>>2]|0)+64>>2]=t[f>>2];break}Eb(t[n>>2]|0,139168);u=(t[n>>2]|0)+56|0;t[u>>2]=(t[u>>2]|0)/2|0;t[r>>2]=-1;a=t[r>>2]|0;s=i;return a|0}while(0);t[(t[(t[n>>2]|0)+64>>2]|0)+(t[(t[n>>2]|0)+60>>2]<<3)>>2]=-1;t[(t[(t[n>>2]|0)+64>>2]|0)+(t[(t[n>>2]|0)+60>>2]<<3)+4>>2]=-1;f=(t[n>>2]|0)+60|0;n=t[f>>2]|0;t[f>>2]=n+1;t[r>>2]=n;a=t[r>>2]|0;s=i;return a|0}function Ub(e,i,r,n,f,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;u=u|0;var a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0;a=s;s=s+48|0;o=a+32|0;c=a+28|0;l=a+24|0;b=a+20|0;k=a+16|0;h=a+12|0;w=a+8|0;d=a+4|0;v=a;t[o>>2]=e;t[c>>2]=i;t[l>>2]=r;t[b>>2]=n;t[k>>2]=f;t[h>>2]=u;if(!(t[c>>2]|0)){t[(t[o>>2]|0)+8>>2]=1450;Rb(t[o>>2]|0,139192);s=a;return}if(!(t[b>>2]|0)){t[(t[o>>2]|0)+8>>2]=1450;Rb(t[o>>2]|0,139224);s=a;return}t[w>>2]=(t[(t[c>>2]|0)+24>>2]|0)-1;while(1){if((t[w>>2]|0)<0)break;t[d>>2]=(t[(t[c>>2]|0)+28>>2]|0)+((t[w>>2]|0)*20|0);if((((t[t[d>>2]>>2]|0)==(t[l>>2]|0)?(t[(t[d>>2]|0)+4>>2]|0)==(t[(t[b>>2]|0)+16>>2]|0):0)?(t[(t[d>>2]|0)+8>>2]|0)==(t[k>>2]|0):0)?(t[(t[d>>2]|0)+12>>2]|0)==(t[h>>2]|0):0){m=20;break}t[w>>2]=(t[w>>2]|0)+-1}if((m|0)==20){s=a;return}m=t[c>>2]|0;do if(!(t[(t[c>>2]|0)+20>>2]|0)){t[m+20>>2]=8;w=gAi[t[135744>>2]&511]((t[(t[c>>2]|0)+20>>2]|0)*20|0)|0;t[(t[c>>2]|0)+28>>2]=w;if(!(t[(t[c>>2]|0)+28>>2]|0)){Eb(t[o>>2]|0,139256);t[(t[c>>2]|0)+20>>2]=0;s=a;return}}else if((t[m+24>>2]|0)>=(t[(t[c>>2]|0)+20>>2]|0)){w=(t[c>>2]|0)+20|0;t[w>>2]=t[w>>2]<<1;t[v>>2]=MAi[t[135760>>2]&511](t[(t[c>>2]|0)+28>>2]|0,(t[(t[c>>2]|0)+20>>2]|0)*20|0)|0;if(t[v>>2]|0){t[(t[c>>2]|0)+28>>2]=t[v>>2];break}Eb(t[o>>2]|0,139256);w=(t[c>>2]|0)+20|0;t[w>>2]=(t[w>>2]|0)/2|0;s=a;return}while(0);t[(t[(t[c>>2]|0)+28>>2]|0)+((t[(t[c>>2]|0)+24>>2]|0)*20|0)>>2]=t[l>>2];t[(t[(t[c>>2]|0)+28>>2]|0)+((t[(t[c>>2]|0)+24>>2]|0)*20|0)+4>>2]=t[(t[b>>2]|0)+16>>2];t[(t[(t[c>>2]|0)+28>>2]|0)+((t[(t[c>>2]|0)+24>>2]|0)*20|0)+8>>2]=t[k>>2];t[(t[(t[c>>2]|0)+28>>2]|0)+((t[(t[c>>2]|0)+24>>2]|0)*20|0)+12>>2]=t[h>>2];t[(t[(t[c>>2]|0)+28>>2]|0)+((t[(t[c>>2]|0)+24>>2]|0)*20|0)+16>>2]=0;h=(t[c>>2]|0)+24|0;t[h>>2]=(t[h>>2]|0)+1;tk(t[o>>2]|0,t[b>>2]|0,t[(t[c>>2]|0)+16>>2]|0);s=a;return}function zb(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0;r=s;s=s+16|0;n=r+12|0;f=r+8|0;u=r+4|0;a=r;t[f>>2]=e;t[u>>2]=i;i=t[f>>2]|0;if(!(t[u>>2]|0)){t[i+8>>2]=1450;Rb(t[f>>2]|0,139128);t[n>>2]=-1;o=t[n>>2]|0;s=r;return o|0}e=t[f>>2]|0;do if(!(t[i+32>>2]|0)){t[e+32>>2]=4;c=gAi[t[135744>>2]&511](t[(t[f>>2]|0)+32>>2]<<2)|0;t[(t[f>>2]|0)+40>>2]=c;if(!(t[(t[f>>2]|0)+40>>2]|0)){Eb(t[f>>2]|0,139152);t[(t[f>>2]|0)+32>>2]=0;t[n>>2]=-1;o=t[n>>2]|0;s=r;return o|0}}else if((t[e+36>>2]|0)>=(t[(t[f>>2]|0)+32>>2]|0)){c=(t[f>>2]|0)+32|0;t[c>>2]=t[c>>2]<<1;t[a>>2]=MAi[t[135760>>2]&511](t[(t[f>>2]|0)+40>>2]|0,t[(t[f>>2]|0)+32>>2]<<2)|0;if(t[a>>2]|0){t[(t[f>>2]|0)+40>>2]=t[a>>2];break}Eb(t[f>>2]|0,139168);c=(t[f>>2]|0)+32|0;t[c>>2]=(t[c>>2]|0)/2|0;t[n>>2]=-1;o=t[n>>2]|0;s=r;return o|0}while(0);t[t[u>>2]>>2]=t[(t[f>>2]|0)+36>>2];a=t[u>>2]|0;u=(t[f>>2]|0)+36|0;e=t[u>>2]|0;t[u>>2]=e+1;t[(t[(t[f>>2]|0)+40>>2]|0)+(e<<2)>>2]=a;t[n>>2]=0;o=t[n>>2]|0;s=r;return o|0}function jb(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0;n=s;s=s+16|0;f=n+8|0;u=n+4|0;a=n;t[f>>2]=e;t[u>>2]=i;t[a>>2]=r;if(!(t[a>>2]|0)){t[a>>2]=Ob(t[f>>2]|0)|0;Ab(t[f>>2]|0,t[a>>2]|0)|0;t[(t[f>>2]|0)+24>>2]=t[a>>2]}Ub(t[f>>2]|0,t[u>>2]|0,0,t[a>>2]|0,-1,-1);s=n;return}function Vb(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,u=0,a=0,o=0,c=0;f=s;s=s+16|0;u=f+12|0;a=f+8|0;o=f+4|0;c=f;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;t[c>>2]=n;if(!(t[o>>2]|0)){t[o>>2]=Ob(t[u>>2]|0)|0;Ab(t[u>>2]|0,t[o>>2]|0)|0;t[(t[u>>2]|0)+24>>2]=t[o>>2]}n=t[u>>2]|0;u=t[a>>2]|0;a=t[o>>2]|0;if(t[c>>2]|0){Ub(n,u,0,a,-1,1193047);s=f;return}else{Ub(n,u,0,a,-1,1193046);s=f;return}}function qb(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,u=0,a=0,o=0,c=0;f=s;s=s+16|0;u=f+12|0;a=f+8|0;o=f+4|0;c=f;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;t[c>>2]=n;if(!(t[o>>2]|0)){t[o>>2]=Ob(t[u>>2]|0)|0;Ab(t[u>>2]|0,t[o>>2]|0)|0;t[(t[u>>2]|0)+24>>2]=t[o>>2]}Ub(t[u>>2]|0,t[a>>2]|0,0,t[o>>2]|0,t[c>>2]|0,-1);s=f;return}function Yb(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,u=0,a=0,o=0,c=0;f=s;s=s+16|0;u=f+12|0;a=f+8|0;o=f+4|0;c=f;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;t[c>>2]=n;if(!(t[o>>2]|0)){t[o>>2]=Ob(t[u>>2]|0)|0;Ab(t[u>>2]|0,t[o>>2]|0)|0;t[(t[u>>2]|0)+24>>2]=t[o>>2]}Ub(t[u>>2]|0,t[a>>2]|0,0,t[o>>2]|0,-1,t[c>>2]|0);s=f;return}function Gb(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0;n=s;s=s+16|0;f=n+12|0;u=n+8|0;a=n+4|0;o=n;t[f>>2]=e;t[u>>2]=i;t[a>>2]=r;r=t[f>>2]|0;do if(!(t[(t[f>>2]|0)+48>>2]|0)){t[r+48>>2]=4;i=gAi[t[135744>>2]&511](t[(t[f>>2]|0)+48>>2]<<3)|0;t[(t[f>>2]|0)+68>>2]=i;if(!(t[(t[f>>2]|0)+68>>2]|0)){Eb(0,140240);t[(t[f>>2]|0)+48>>2]=0;s=n;return}}else if(((t[r+52>>2]|0)+1|0)>=(t[(t[f>>2]|0)+48>>2]|0)){i=(t[f>>2]|0)+48|0;t[i>>2]=t[i>>2]<<1;t[o>>2]=MAi[t[135760>>2]&511](t[(t[f>>2]|0)+68>>2]|0,t[(t[f>>2]|0)+48>>2]<<3)|0;if(t[o>>2]|0){t[(t[f>>2]|0)+68>>2]=t[o>>2];break}Eb(0,140240);i=(t[f>>2]|0)+48|0;t[i>>2]=(t[i>>2]|0)/2|0;s=n;return}while(0);o=Yl(t[u>>2]|0)|0;t[(t[(t[f>>2]|0)+68>>2]|0)+(t[(t[f>>2]|0)+52>>2]<<3)>>2]=o;t[(t[(t[f>>2]|0)+68>>2]|0)+(t[(t[f>>2]|0)+52>>2]<<3)+4>>2]=t[a>>2];a=(t[f>>2]|0)+52|0;t[a>>2]=(t[a>>2]|0)+1;t[(t[(t[f>>2]|0)+68>>2]|0)+(t[(t[f>>2]|0)+52>>2]<<3)>>2]=0;t[(t[(t[f>>2]|0)+68>>2]|0)+(t[(t[f>>2]|0)+52>>2]<<3)+4>>2]=0;s=n;return}function Wb(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,a=0,o=0,c=0,l=0;r=s;s=s+16|0;n=r+12|0;f=r+8|0;a=r+4|0;o=r;t[f>>2]=e;t[a>>2]=i;if((t[f>>2]|0)==(t[a>>2]|0)){t[n>>2]=1;c=t[n>>2]|0;s=r;return c|0}if(!(t[f>>2]|0)){t[n>>2]=0;c=t[n>>2]|0;s=r;return c|0}if(!(t[a>>2]|0)){t[n>>2]=0;c=t[n>>2]|0;s=r;return c|0}e:do i:do if((u[t[f>>2]>>0]|0|0)!=(u[t[a>>2]>>0]|0|0)){if((u[t[a>>2]>>0]|0|0)==42){t[o>>2]=t[a>>2];t[a>>2]=t[f>>2];t[f>>2]=t[o>>2]}if(!(u[t[a>>2]>>0]|0)){l=15;break e}if(!(u[t[f>>2]>>0]|0)){l=15;break e}i=t[f>>2]|0;t[f>>2]=i+1;if((u[i>>0]|0|0)!=42){l=15;break e}do{if((u[t[a>>2]>>0]|0|0)==124)break i;t[a>>2]=(t[a>>2]|0)+1}while((u[t[a>>2]>>0]|0|0)!=0)}else{t[f>>2]=(t[f>>2]|0)+1;t[a>>2]=(t[a>>2]|0)+1}while(0);while((u[t[a>>2]>>0]|0|0)!=0);if((l|0)==15){t[n>>2]=0;c=t[n>>2]|0;s=r;return c|0}if(u[t[f>>2]>>0]|0){t[n>>2]=0;c=t[n>>2]|0;s=r;return c|0}else{t[n>>2]=1;c=t[n>>2]|0;s=r;return c|0}return 0}function Kb(e){e=e|0;var i=0,r=0,n=0,f=0,u=0;i=s;s=s+16|0;r=i+8|0;n=i+4|0;f=i;t[r>>2]=e;if((t[(t[r>>2]|0)+88>>2]|0)>1e7){s=i;return}e=(t[r>>2]|0)+88|0;t[e>>2]=(t[e>>2]|0)+1;e=t[r>>2]|0;do if(t[(t[r>>2]|0)+32>>2]|0){if((t[e+36>>2]|0)>=(t[(t[r>>2]|0)+32>>2]|0)){t[f>>2]=t[(t[r>>2]|0)+32>>2];u=(t[r>>2]|0)+32|0;t[u>>2]=t[u>>2]<<1;t[n>>2]=MAi[t[135760>>2]&511](t[(t[r>>2]|0)+40>>2]|0,t[(t[r>>2]|0)+32>>2]<<4)|0;if(t[n>>2]|0){t[(t[r>>2]|0)+40>>2]=t[n>>2];t[n>>2]=(t[(t[r>>2]|0)+40>>2]|0)+(t[f>>2]<<4);VY(t[n>>2]|0,0,(t[(t[r>>2]|0)+32>>2]|0)-(t[f>>2]|0)<<4|0)|0;break}Eb(0,139496);u=(t[r>>2]|0)+32|0;t[u>>2]=(t[u>>2]|0)/2|0;s=i;return}}else{t[e+32>>2]=4;u=gAi[t[135744>>2]&511](t[(t[r>>2]|0)+32>>2]<<4)|0;t[(t[r>>2]|0)+40>>2]=u;if(t[(t[r>>2]|0)+40>>2]|0){VY(t[(t[r>>2]|0)+40>>2]|0,0,t[(t[r>>2]|0)+32>>2]<<4|0)|0;break}Eb(0,139496);t[(t[r>>2]|0)+32>>2]=0;s=i;return}while(0);t[(t[(t[r>>2]|0)+40>>2]|0)+(t[(t[r>>2]|0)+36>>2]<<4)>>2]=t[(t[r>>2]|0)+20>>2];t[(t[(t[r>>2]|0)+40>>2]|0)+(t[(t[r>>2]|0)+36>>2]<<4)+4>>2]=t[(t[r>>2]|0)+56>>2];t[(t[(t[r>>2]|0)+40>>2]|0)+(t[(t[r>>2]|0)+36>>2]<<4)+8>>2]=(t[(t[r>>2]|0)+24>>2]|0)+1;if((t[(t[(t[r>>2]|0)+8>>2]|0)+20>>2]|0)>0){if((t[(t[(t[r>>2]|0)+40>>2]|0)+(t[(t[r>>2]|0)+36>>2]<<4)+12>>2]|0)==0?(e=gAi[t[135744>>2]&511](t[(t[(t[r>>2]|0)+8>>2]|0)+20>>2]<<2)|0,t[(t[(t[r>>2]|0)+40>>2]|0)+(t[(t[r>>2]|0)+36>>2]<<4)+12>>2]=e,(t[(t[(t[r>>2]|0)+40>>2]|0)+(t[(t[r>>2]|0)+36>>2]<<4)+12>>2]|0)==0):0){Eb(0,139496);t[t[r>>2]>>2]=-5;s=i;return}YY(t[(t[(t[r>>2]|0)+40>>2]|0)+(t[(t[r>>2]|0)+36>>2]<<4)+12>>2]|0,t[(t[r>>2]|0)+44>>2]|0,t[(t[(t[r>>2]|0)+8>>2]|0)+20>>2]<<2|0)|0}e=(t[r>>2]|0)+36|0;t[e>>2]=(t[e>>2]|0)+1;s=i;return}function Xb(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i+4|0;t[r>>2]=e;e=t[r>>2]|0;if((t[(t[r>>2]|0)+36>>2]|0)<=0){t[e>>2]=-1;s=i;return}n=e+36|0;t[n>>2]=(t[n>>2]|0)+-1;t[(t[r>>2]|0)+20>>2]=t[(t[(t[r>>2]|0)+40>>2]|0)+(t[(t[r>>2]|0)+36>>2]<<4)>>2];t[(t[r>>2]|0)+56>>2]=t[(t[(t[r>>2]|0)+40>>2]|0)+(t[(t[r>>2]|0)+36>>2]<<4)+4>>2];t[(t[r>>2]|0)+24>>2]=t[(t[(t[r>>2]|0)+40>>2]|0)+(t[(t[r>>2]|0)+36>>2]<<4)+8>>2];if((t[(t[(t[r>>2]|0)+8>>2]|0)+20>>2]|0)<=0){s=i;return}if(!(t[(t[(t[r>>2]|0)+40>>2]|0)+(t[(t[r>>2]|0)+36>>2]<<4)+12>>2]|0)){xe(t[v>>2]|0,139464,i|0)|0;t[t[r>>2]>>2]=-6;s=i;return}if(!(t[(t[r>>2]|0)+44>>2]|0)){s=i;return}YY(t[(t[r>>2]|0)+44>>2]|0,t[(t[(t[r>>2]|0)+40>>2]|0)+(t[(t[r>>2]|0)+36>>2]<<4)+12>>2]|0,t[(t[(t[r>>2]|0)+8>>2]|0)+20>>2]<<2|0)|0;s=i;return}function Zb(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0;r=s;s=s+32|0;n=r+16|0;f=r+12|0;a=r+8|0;o=r+4|0;c=r;t[f>>2]=e;t[a>>2]=i;t[o>>2]=t[(t[f>>2]|0)+24>>2];t[c>>2]=uk(t[f>>2]|0)|0;do if(t[c>>2]|0){i=t[f>>2]|0;e=t[o>>2]|0;if((u[t[(t[f>>2]|0)+4>>2]>>0]|0|0)!=124?(u[t[(t[f>>2]|0)+4>>2]>>0]|0|0)!=41:0)l=0;else l=t[a>>2]|0;if((Hb(i,e,l,t[(t[f>>2]|0)+28>>2]|0)|0)>=0){t[o>>2]=t[(t[f>>2]|0)+24>>2];t[(t[f>>2]|0)+28>>2]=0;break}t[n>>2]=-1;b=t[n>>2]|0;s=r;return b|0}while(0);while(1){if(!(t[c>>2]|0)){k=17;break}if(t[(t[f>>2]|0)+8>>2]|0){k=17;break}t[c>>2]=uk(t[f>>2]|0)|0;if(!(t[c>>2]|0))continue;l=t[f>>2]|0;e=t[o>>2]|0;if((u[t[(t[f>>2]|0)+4>>2]>>0]|0|0)!=124?(u[t[(t[f>>2]|0)+4>>2]>>0]|0|0)!=41:0)h=0;else h=t[a>>2]|0;if((Hb(l,e,h,t[(t[f>>2]|0)+28>>2]|0)|0)<0){k=15;break}t[o>>2]=t[(t[f>>2]|0)+24>>2];t[(t[f>>2]|0)+28>>2]=0}if((k|0)==15){t[n>>2]=-1;b=t[n>>2]|0;s=r;return b|0}else if((k|0)==17){t[n>>2]=0;b=t[n>>2]|0;s=r;return b|0}return 0}function Jb(e){e=e|0;var i=0,r=0,n=0,f=0,u=0,a=0,o=0,c=0;i=s;s=s+32|0;r=i+24|0;n=i+20|0;f=i+16|0;u=i+12|0;a=i+8|0;o=i+4|0;c=i;t[r>>2]=e;t[n>>2]=0;while(1){if((t[n>>2]|0)>=(t[(t[r>>2]|0)+48>>2]|0))break;t[o>>2]=t[(t[(t[r>>2]|0)+52>>2]|0)+(t[n>>2]<<2)>>2];if(((((((((t[o>>2]|0)!=0?(t[(t[o>>2]|0)+24>>2]|0)==1:0)?(t[t[o>>2]>>2]|0)!=5:0)?(t[t[(t[o>>2]|0)+28>>2]>>2]|0)==0:0)?(t[(t[(t[o>>2]|0)+28>>2]|0)+4>>2]|0)>=0:0)?(t[(t[(t[o>>2]|0)+28>>2]|0)+4>>2]|0)!=(t[n>>2]|0):0)?(t[(t[(t[o>>2]|0)+28>>2]|0)+8>>2]|0)<0:0)?(t[(t[(t[o>>2]|0)+28>>2]|0)+12>>2]|0)<0:0)?(t[a>>2]=t[(t[(t[o>>2]|0)+28>>2]|0)+4>>2],(t[t[o>>2]>>2]|0)!=1):0){t[f>>2]=0;while(1){if((t[f>>2]|0)>=(t[(t[o>>2]|0)+36>>2]|0))break;t[c>>2]=t[(t[(t[r>>2]|0)+52>>2]|0)+(t[(t[(t[o>>2]|0)+40>>2]|0)+(t[f>>2]<<2)>>2]<<2)>>2];t[u>>2]=0;while(1){if((t[u>>2]|0)>=(t[(t[c>>2]|0)+24>>2]|0))break;if((t[(t[(t[c>>2]|0)+28>>2]|0)+((t[u>>2]|0)*20|0)+4>>2]|0)==(t[n>>2]|0)){t[(t[(t[c>>2]|0)+28>>2]|0)+((t[u>>2]|0)*20|0)+4>>2]=-1;Ub(t[r>>2]|0,t[c>>2]|0,t[(t[(t[c>>2]|0)+28>>2]|0)+((t[u>>2]|0)*20|0)>>2]|0,t[(t[(t[r>>2]|0)+52>>2]|0)+(t[a>>2]<<2)>>2]|0,t[(t[(t[c>>2]|0)+28>>2]|0)+((t[u>>2]|0)*20|0)+8>>2]|0,t[(t[(t[c>>2]|0)+28>>2]|0)+((t[u>>2]|0)*20|0)+12>>2]|0)}t[u>>2]=(t[u>>2]|0)+1}t[f>>2]=(t[f>>2]|0)+1}if((t[t[o>>2]>>2]|0)==2)t[t[(t[(t[r>>2]|0)+52>>2]|0)+(t[a>>2]<<2)>>2]>>2]=2;t[(t[o>>2]|0)+24>>2]=0;t[t[o>>2]>>2]=5}t[n>>2]=(t[n>>2]|0)+1}s=i;return}function Qb(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0;f=s;s=s+48|0;u=f+32|0;a=f+28|0;o=f+24|0;c=f+20|0;l=f+16|0;b=f+12|0;k=f+8|0;h=f+4|0;w=f;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;t[c>>2]=n;t[b>>2]=t[(t[(t[u>>2]|0)+52>>2]|0)+(t[a>>2]<<2)>>2];if(!(t[b>>2]|0)){s=f;return}t[k>>2]=t[(t[(t[u>>2]|0)+52>>2]|0)+(t[o>>2]<<2)>>2];if(!(t[k>>2]|0)){s=f;return}if((t[(t[k>>2]|0)+4>>2]|0)==1){s=f;return}if((t[(t[k>>2]|0)+4>>2]|0)==2){s=f;return}t[(t[k>>2]|0)+4>>2]=2;if((t[t[k>>2]>>2]|0)==2)t[t[b>>2]>>2]=2;t[l>>2]=0;while(1){if((t[l>>2]|0)>=(t[(t[k>>2]|0)+24>>2]|0))break;do if((t[(t[(t[k>>2]|0)+28>>2]|0)+((t[l>>2]|0)*20|0)+4>>2]|0)>=0){o=t[(t[(t[k>>2]|0)+28>>2]|0)+((t[l>>2]|0)*20|0)+4>>2]|0;if(t[(t[(t[k>>2]|0)+28>>2]|0)+((t[l>>2]|0)*20|0)>>2]|0){t[w>>2]=o;n=t[u>>2]|0;r=t[b>>2]|0;i=t[(t[(t[k>>2]|0)+28>>2]|0)+((t[l>>2]|0)*20|0)>>2]|0;e=t[(t[(t[u>>2]|0)+52>>2]|0)+(t[w>>2]<<2)>>2]|0;if((t[(t[(t[k>>2]|0)+28>>2]|0)+((t[l>>2]|0)*20|0)+8>>2]|0)>=0){Ub(n,r,i,e,t[(t[(t[k>>2]|0)+28>>2]|0)+((t[l>>2]|0)*20|0)+8>>2]|0,-1);break}else{Ub(n,r,i,e,t[c>>2]|0,-1);break}}if((o|0)!=(t[a>>2]|0)){o=(t[(t[k>>2]|0)+28>>2]|0)+((t[l>>2]|0)*20|0)|0;if((t[(t[(t[k>>2]|0)+28>>2]|0)+((t[l>>2]|0)*20|0)+12>>2]|0)>=0){t[h>>2]=t[o+4>>2];Ub(t[u>>2]|0,t[b>>2]|0,0,t[(t[(t[u>>2]|0)+52>>2]|0)+(t[h>>2]<<2)>>2]|0,-1,t[(t[(t[k>>2]|0)+28>>2]|0)+((t[l>>2]|0)*20|0)+12>>2]|0);break}e=t[u>>2]|0;i=t[a>>2]|0;r=t[(t[(t[k>>2]|0)+28>>2]|0)+((t[l>>2]|0)*20|0)+4>>2]|0;if((t[o+8>>2]|0)>=0){Qb(e,i,r,t[(t[(t[k>>2]|0)+28>>2]|0)+((t[l>>2]|0)*20|0)+8>>2]|0);break}else{Qb(e,i,r,t[c>>2]|0);break}}}while(0);t[l>>2]=(t[l>>2]|0)+1}t[(t[k>>2]|0)+4>>2]=0;s=f;return}function $b(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0;r=s;s=s+32|0;n=r;f=r+28|0;u=r+24|0;a=r+20|0;o=r+16|0;c=r+12|0;l=r+8|0;b=r+4|0;t[u>>2]=e;t[a>>2]=i;t[c>>2]=0;do if(t[u>>2]|0){i=t[a>>2]|0;if((t[a>>2]|0)<256){if(!(9<=(i|0)&(t[a>>2]|0)<=10|(t[a>>2]|0)==13|32<=(t[a>>2]|0)))break}else if((!(256<=(i|0)&(t[a>>2]|0)<=55295)?!(57344<=(t[a>>2]|0)&(t[a>>2]|0)<=65533):0)?!(65536<=(t[a>>2]|0)&(t[a>>2]|0)<=1114111):0)break;switch(t[(t[u>>2]|0)+4>>2]|0){case 136:case 135:case 134:case 133:case 132:case 131:case 130:case 129:
	case 128:case 127:case 126:case 125:case 124:case 123:case 122:case 121:case 120:case 119:case 118:case 117:case 116:case 115:case 114:case 113:case 112:case 111:case 110:case 109:case 108:case 107:case 106:case 105:case 104:case 103:case 102:case 101:case 100:case 16:case 15:case 14:case 13:case 12:case 11:case 10:case 9:case 8:case 7:case 6:{t[c>>2]=ak(t[(t[u>>2]|0)+4>>2]|0,t[a>>2]|0,0,0,0,t[(t[u>>2]|0)+20>>2]|0)|0;if(t[(t[u>>2]|0)+28>>2]|0)t[c>>2]=((t[c>>2]|0)!=0^1)&1;break}case 2:{t[f>>2]=(t[a>>2]|0)==(t[(t[u>>2]|0)+32>>2]|0)&1;k=t[f>>2]|0;s=r;return k|0}case 3:{t[b>>2]=0;t[o>>2]=0;e:while(1){if((t[o>>2]|0)>=(t[(t[u>>2]|0)+52>>2]|0)){h=23;break}t[l>>2]=t[(t[(t[u>>2]|0)+56>>2]|0)+(t[o>>2]<<2)>>2];i=t[l>>2]|0;do if((t[t[l>>2]>>2]|0)==2){t[c>>2]=ak(t[i+4>>2]|0,t[a>>2]|0,0,t[(t[l>>2]|0)+8>>2]|0,t[(t[l>>2]|0)+12>>2]|0,t[(t[l>>2]|0)+16>>2]|0)|0;if(t[c>>2]|0){h=15;break e}}else{e=(t[i>>2]|0)!=0;t[c>>2]=ak(t[(t[l>>2]|0)+4>>2]|0,t[a>>2]|0,0,t[(t[l>>2]|0)+8>>2]|0,t[(t[l>>2]|0)+12>>2]|0,t[(t[l>>2]|0)+16>>2]|0)|0;w=t[c>>2]|0;if(e){if(w){h=19;break e}t[b>>2]=1;break}else{if(!w)break;t[b>>2]=1;break}}while(0);t[o>>2]=(t[o>>2]|0)+1}if((h|0)==15){t[f>>2]=0;k=t[f>>2]|0;s=r;return k|0}else if((h|0)==19){t[f>>2]=0;k=t[f>>2]|0;s=r;return k|0}else if((h|0)==23){t[f>>2]=t[b>>2];k=t[f>>2]|0;s=r;return k|0}break}case 5:{Je(139376,n|0)|0;t[f>>2]=-1;k=t[f>>2]|0;s=r;return k|0}case 1:case 4:{t[f>>2]=-1;k=t[f>>2]|0;s=r;return k|0}default:{}}t[f>>2]=t[c>>2];k=t[f>>2]|0;s=r;return k|0}while(0);t[f>>2]=-1;k=t[f>>2]|0;s=r;return k|0}function ek(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,l=0;n=s;s=s+32|0;f=n+16|0;u=n+12|0;a=n+8|0;o=n+4|0;c=n;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;t[c>>2]=0;if((t[u>>2]|0)==(t[a>>2]|0)){t[f>>2]=1;l=t[f>>2]|0;s=n;return l|0}if((t[u>>2]|0)==0|(t[a>>2]|0)==0){t[f>>2]=0;l=t[f>>2]|0;s=n;return l|0}if((t[(t[u>>2]|0)+4>>2]|0)!=(t[(t[a>>2]|0)+4>>2]|0)){t[f>>2]=0;l=t[f>>2]|0;s=n;return l|0}r=t[(t[u>>2]|0)+4>>2]|0;do if((r|0)==1)t[c>>2]=0;else if((r|0)==2)t[c>>2]=(t[(t[u>>2]|0)+32>>2]|0)==(t[(t[a>>2]|0)+32>>2]|0)&1;else if((r|0)==3)t[c>>2]=0;else if((r|0)==5){i=t[(t[u>>2]|0)+20>>2]|0;e=t[(t[a>>2]|0)+20>>2]|0;if(t[o>>2]|0){t[c>>2]=Xl(i,e)|0;break}else{t[c>>2]=(i|0)==(e|0)&1;break}}while(0);t[f>>2]=t[c>>2];l=t[f>>2]|0;s=n;return l|0}function ik(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0;n=s;s=s+48|0;f=n+40|0;u=n+36|0;a=n+32|0;o=n+28|0;c=n+24|0;l=n+20|0;b=n+16|0;k=n+12|0;h=n+8|0;w=n+4|0;d=n;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;t[c>>2]=1;if((t[u>>2]|0)==(t[a>>2]|0)){t[f>>2]=1;v=t[f>>2]|0;s=n;return v|0}if((t[u>>2]|0)==0|(t[a>>2]|0)==0){t[f>>2]=0;v=t[f>>2]|0;s=n;return v|0}if((t[(t[u>>2]|0)+4>>2]|0)!=6?(t[(t[a>>2]|0)+4>>2]|0)!=6:0){if((t[(t[u>>2]|0)+4>>2]|0)>>>0>(t[(t[a>>2]|0)+4>>2]|0)>>>0){t[l>>2]=t[u>>2];t[u>>2]=t[a>>2];t[a>>2]=t[l>>2]}if((t[(t[u>>2]|0)+4>>2]|0)!=(t[(t[a>>2]|0)+4>>2]|0)?(t[c>>2]=ok(t[(t[u>>2]|0)+4>>2]|0,t[(t[a>>2]|0)+4>>2]|0)|0,(t[c>>2]|0)==0):0){t[f>>2]=0;v=t[f>>2]|0;s=n;return v|0}l=t[(t[u>>2]|0)+4>>2]|0;do if((l|0)==5){r=t[(t[u>>2]|0)+20>>2]|0;i=t[(t[a>>2]|0)+20>>2]|0;if(t[o>>2]|0){t[c>>2]=Wb(r,i)|0;m=30;break}else{t[c>>2]=(r|0)!=(i|0)&1;m=30;break}}else if((l|0)==2)if((t[(t[a>>2]|0)+4>>2]|0)==2){t[c>>2]=(t[(t[u>>2]|0)+32>>2]|0)==(t[(t[a>>2]|0)+32>>2]|0)&1;m=30;break}else{i=$b(t[a>>2]|0,t[(t[u>>2]|0)+32>>2]|0)|0;t[c>>2]=i;t[c>>2]=(t[c>>2]|0)<0?1:i;m=30;break}else if((l|0)==3)if((t[(t[a>>2]|0)+4>>2]|0)==3){t[b>>2]=0;e:while(1){if((t[b>>2]|0)>=(t[(t[u>>2]|0)+52>>2]|0)){m=29;break}t[k>>2]=0;while(1){_=t[b>>2]|0;if((t[k>>2]|0)>=(t[(t[a>>2]|0)+52>>2]|0))break;t[w>>2]=t[(t[(t[u>>2]|0)+56>>2]|0)+(_<<2)>>2];t[d>>2]=t[(t[(t[a>>2]|0)+56>>2]|0)+(t[k>>2]<<2)>>2];t[h>>2]=ck(t[w>>2]|0,t[d>>2]|0)|0;if((t[h>>2]|0)==1){m=26;break e}t[k>>2]=(t[k>>2]|0)+1}t[b>>2]=_+1}if((m|0)==26){t[c>>2]=1;m=30;break}else if((m|0)==29){t[c>>2]=0;m=30;break}}else m=30;while(0);if((m|0)==30){if((t[(t[u>>2]|0)+28>>2]|0)!=(t[(t[a>>2]|0)+28>>2]|0))t[c>>2]=((t[c>>2]|0)!=0^1)&1;if(!(t[c>>2]|0)){t[f>>2]=0;v=t[f>>2]|0;s=n;return v|0}}t[f>>2]=1;v=t[f>>2]|0;s=n;return v|0}t[f>>2]=1;v=t[f>>2]|0;s=n;return v|0}function rk(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0;f=s;s=s+48|0;u=f+40|0;a=f+36|0;o=f+32|0;c=f+28|0;l=f+24|0;b=f+20|0;k=f+16|0;h=f+12|0;w=f+8|0;d=f+4|0;v=f;t[a>>2]=e;t[o>>2]=i;t[c>>2]=r;t[l>>2]=n;t[b>>2]=1;t[v>>2]=1;if(!(t[o>>2]|0)){t[u>>2]=t[b>>2];m=t[u>>2]|0;s=f;return m|0}if((t[(t[o>>2]|0)+8>>2]|0)==2){t[u>>2]=t[b>>2];m=t[u>>2]|0;s=f;return m|0}if(t[(t[a>>2]|0)+76>>2]&1)t[v>>2]=0;t[w>>2]=t[(t[o>>2]|0)+24>>2];t[h>>2]=0;while(1){if((t[h>>2]|0)>=(t[w>>2]|0))break;t[d>>2]=(t[(t[o>>2]|0)+28>>2]|0)+((t[h>>2]|0)*20|0);n=t[(t[d>>2]|0)+4>>2]|0;if(!(t[t[d>>2]>>2]|0)){if((n|0)>=0?(t[(t[o>>2]|0)+8>>2]=2,t[k>>2]=rk(t[a>>2]|0,t[(t[(t[a>>2]|0)+52>>2]|0)+(t[(t[d>>2]|0)+4>>2]<<2)>>2]|0,t[c>>2]|0,t[l>>2]|0)|0,t[(t[o>>2]|0)+8>>2]=0,(t[k>>2]|0)==0):0)t[b>>2]=0}else if((n|0)==(t[c>>2]|0)?(ik(t[t[d>>2]>>2]|0,t[l>>2]|0,t[v>>2]|0)|0)!=0:0){t[b>>2]=0;t[(t[d>>2]|0)+16>>2]=1}t[h>>2]=(t[h>>2]|0)+1}t[u>>2]=t[b>>2];m=t[u>>2]|0;s=f;return m|0}function nk(e){e=e|0;var i=0,r=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if(!(t[r>>2]|0)){s=i;return}if(t[(t[r>>2]|0)+16>>2]|0)pAi[t[135736>>2]&511](t[(t[r>>2]|0)+16>>2]|0);pAi[t[135736>>2]&511](t[r>>2]|0);s=i;return}function fk(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0;r=s;s=s+32|0;n=r+16|0;f=r+12|0;u=r+8|0;a=r+4|0;o=r;t[f>>2]=e;t[u>>2]=i;t[a>>2]=gAi[t[135744>>2]&511](64)|0;if(!(t[a>>2]|0)){Eb(t[f>>2]|0,139320);t[n>>2]=0;c=t[n>>2]|0;s=r;return c|0}i=(t[a>>2]|0)+0|0;e=i+64|0;do{t[i>>2]=0;i=i+4|0}while((i|0)<(e|0));t[(t[a>>2]|0)+4>>2]=t[(t[u>>2]|0)+4>>2];t[(t[a>>2]|0)+8>>2]=t[(t[u>>2]|0)+8>>2];t[(t[a>>2]|0)+12>>2]=t[(t[u>>2]|0)+12>>2];t[(t[a>>2]|0)+16>>2]=t[(t[u>>2]|0)+16>>2];e:do if((t[(t[u>>2]|0)+52>>2]|0)>0){i=gAi[t[135744>>2]&511](t[(t[u>>2]|0)+52>>2]<<2)|0;t[(t[a>>2]|0)+56>>2]=i;i:do if(!(t[(t[a>>2]|0)+56>>2]|0))Eb(t[f>>2]|0,139320);else{t[o>>2]=0;while(1){if((t[o>>2]|0)>=(t[(t[u>>2]|0)+52>>2]|0))break e;i=lk(t[f>>2]|0,t[(t[(t[u>>2]|0)+56>>2]|0)+(t[o>>2]<<2)>>2]|0)|0;t[(t[(t[a>>2]|0)+56>>2]|0)+(t[o>>2]<<2)>>2]=i;if(!(t[(t[(t[a>>2]|0)+56>>2]|0)+(t[o>>2]<<2)>>2]|0))break i;t[(t[a>>2]|0)+52>>2]=(t[o>>2]|0)+1;t[o>>2]=(t[o>>2]|0)+1}}while(0);Bb(t[a>>2]|0);t[n>>2]=0;c=t[n>>2]|0;s=r;return c|0}while(0);t[n>>2]=t[a>>2];c=t[n>>2]|0;s=r;return c|0}function tk(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0;n=s;s=s+16|0;f=n+12|0;u=n+8|0;a=n+4|0;o=n;t[f>>2]=e;t[u>>2]=i;t[a>>2]=r;r=t[u>>2]|0;do if(!(t[(t[u>>2]|0)+32>>2]|0)){t[r+32>>2]=8;i=gAi[t[135744>>2]&511](t[(t[u>>2]|0)+32>>2]<<2)|0;t[(t[u>>2]|0)+40>>2]=i;if(!(t[(t[u>>2]|0)+40>>2]|0)){Eb(t[f>>2]|0,139256);t[(t[u>>2]|0)+32>>2]=0;s=n;return}}else if((t[r+36>>2]|0)>=(t[(t[u>>2]|0)+32>>2]|0)){i=(t[u>>2]|0)+32|0;t[i>>2]=t[i>>2]<<1;t[o>>2]=MAi[t[135760>>2]&511](t[(t[u>>2]|0)+40>>2]|0,t[(t[u>>2]|0)+32>>2]<<2)|0;if(t[o>>2]|0){t[(t[u>>2]|0)+40>>2]=t[o>>2];break}Eb(t[f>>2]|0,139256);i=(t[u>>2]|0)+32|0;t[i>>2]=(t[i>>2]|0)/2|0;s=n;return}while(0);t[(t[(t[u>>2]|0)+40>>2]|0)+(t[(t[u>>2]|0)+36>>2]<<2)>>2]=t[a>>2];a=(t[u>>2]|0)+36|0;t[a>>2]=(t[a>>2]|0)+1;s=n;return}function uk(e){e=e|0;var i=0,r=0,n=0,f=0,u=0;i=s;s=s+16|0;r=i+8|0;n=i+4|0;f=i;t[n>>2]=e;t[(t[n>>2]|0)+28>>2]=0;t[f>>2]=sk(t[n>>2]|0)|0;if(!(t[f>>2]|0)){t[r>>2]=0;u=t[r>>2]|0;s=i;return u|0}if(!(t[(t[n>>2]|0)+28>>2]|0)){t[(t[n>>2]|0)+8>>2]=1450;Rb(t[n>>2]|0,139592)}bk(t[n>>2]|0)|0;t[r>>2]=1;u=t[r>>2]|0;s=i;return u|0}function ak(e,i,r,n,f,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;u=u|0;var a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0,S=0,g=0,y=0;a=s;s=s+32|0;o=a+28|0;c=a+24|0;l=a+20|0;b=a+16|0;k=a+12|0;h=a+8|0;w=a+4|0;d=a;t[c>>2]=e;t[l>>2]=i;t[b>>2]=r;t[k>>2]=n;t[h>>2]=f;t[w>>2]=u;t[d>>2]=0;do switch(t[c>>2]|0){case 128:{t[d>>2]=pI(t[l>>2]|0)|0;break}case 104:{t[d>>2]=$B(t[l>>2]|0)|0;break}case 109:{t[d>>2]=tI(t[l>>2]|0)|0;break}case 108:{t[d>>2]=fI(t[l>>2]|0)|0;break}case 10:{t[b>>2]=((t[b>>2]|0)!=0^1)&1;v=14;break}case 112:{t[d>>2]=cI(t[l>>2]|0)|0;break}case 105:{t[d>>2]=eI(t[l>>2]|0)|0;break}case 9:{v=14;break}case 113:{t[d>>2]=lI(t[l>>2]|0)|0;break}case 110:{t[d>>2]=aI(t[l>>2]|0)|0;break}case 116:{t[d>>2]=kI(t[l>>2]|0)|0;break}case 115:{t[d>>2]=bI(t[l>>2]|0)|0;break}case 102:{t[d>>2]=QB(t[l>>2]|0)|0;break}case 15:{t[b>>2]=((t[b>>2]|0)!=0^1)&1;v=49;break}case 121:{t[d>>2]=vI(t[l>>2]|0)|0;break}case 136:{t[d>>2]=GB(t[l>>2]|0,t[w>>2]|0)|0;break}case 134:{t[d>>2]=ZB(t[l>>2]|0)|0;break}case 135:{t[d>>2]=0;break}case 122:{t[d>>2]=yI(t[l>>2]|0)|0;break}case 6:{if((t[l>>2]|0)!=10)m=(t[l>>2]|0)!=13;else m=0;t[d>>2]=m&1;break}case 13:{v=47;break}case 111:{t[d>>2]=oI(t[l>>2]|0)|0;break}case 11:{v=27;break}case 12:{t[b>>2]=((t[b>>2]|0)!=0^1)&1;v=27;break}case 107:{t[d>>2]=uI(t[l>>2]|0)|0;break}case 123:{t[d>>2]=AI(t[l>>2]|0)|0;break}case 7:{v=10;break}case 8:{t[b>>2]=((t[b>>2]|0)!=0^1)&1;v=10;break}case 2:{if((t[l>>2]|0)>=(t[k>>2]|0))_=(t[l>>2]|0)<=(t[h>>2]|0);else _=0;t[d>>2]=_&1;break}case 133:{t[d>>2]=XB(t[l>>2]|0)|0;break}case 118:{t[d>>2]=hI(t[l>>2]|0)|0;break}case 124:{t[d>>2]=FI(t[l>>2]|0)|0;break}case 131:{t[d>>2]=WB(t[l>>2]|0)|0;break}case 132:{t[d>>2]=KB(t[l>>2]|0)|0;break}case 100:{t[d>>2]=JB(t[l>>2]|0)|0;break}case 103:{t[d>>2]=iI(t[l>>2]|0)|0;break}case 14:{t[b>>2]=((t[b>>2]|0)!=0^1)&1;v=47;break}case 1:case 3:case 4:case 5:{t[o>>2]=-1;p=t[o>>2]|0;s=a;return p|0}case 129:{t[d>>2]=EI(t[l>>2]|0)|0;break}case 130:{t[d>>2]=gI(t[l>>2]|0)|0;break}case 106:{t[d>>2]=nI(t[l>>2]|0)|0;break}case 125:{t[d>>2]=OI(t[l>>2]|0)|0;break}case 117:{t[d>>2]=mI(t[l>>2]|0)|0;break}case 101:{t[d>>2]=rI(t[l>>2]|0)|0;break}case 16:{v=49;break}case 126:{t[d>>2]=_I(t[l>>2]|0)|0;break}case 127:{t[d>>2]=SI(t[l>>2]|0)|0;break}case 120:{t[d>>2]=wI(t[l>>2]|0)|0;break}case 119:{t[d>>2]=dI(t[l>>2]|0)|0;break}case 114:{t[d>>2]=sI(t[l>>2]|0)|0;break}default:{}}while(0);if((v|0)==10){if((t[l>>2]|0)==10|(t[l>>2]|0)==13|(t[l>>2]|0)==9)E=1;else E=(t[l>>2]|0)==32;t[d>>2]=E&1}else if((v|0)==14){E=t[l>>2]|0;if((t[l>>2]|0)<256)if(((!(65<=(E|0)&(t[l>>2]|0)<=90)?!(97<=(t[l>>2]|0)&(t[l>>2]|0)<=122):0)?!(192<=(t[l>>2]|0)&(t[l>>2]|0)<=214):0)?!(216<=(t[l>>2]|0)&(t[l>>2]|0)<=246|248<=(t[l>>2]|0)):0)v=20;else S=1;else if(dj(E,199744)|0)S=1;else v=20;do if((v|0)==20){E=t[l>>2]|0;if((t[l>>2]|0)<256){if((E|0)==95){S=1;break}}else{if(19968<=(E|0)&(t[l>>2]|0)<=40869|(t[l>>2]|0)==12295){S=1;break}if(12321<=(t[l>>2]|0)&(t[l>>2]|0)<=12329|(t[l>>2]|0)==95){S=1;break}}S=(t[l>>2]|0)==58}while(0);t[d>>2]=S&1}else if((v|0)==27){S=t[l>>2]|0;if((t[l>>2]|0)<256)if(((!(65<=(S|0)&(t[l>>2]|0)<=90)?!(97<=(t[l>>2]|0)&(t[l>>2]|0)<=122):0)?!(192<=(t[l>>2]|0)&(t[l>>2]|0)<=214):0)?!(216<=(t[l>>2]|0)&(t[l>>2]|0)<=246|248<=(t[l>>2]|0)):0)v=33;else g=1;else if(dj(S,199744)|0)g=1;else v=33;do if((v|0)==33){if((t[l>>2]|0)>=256){if(19968<=(t[l>>2]|0)&(t[l>>2]|0)<=40869|(t[l>>2]|0)==12295){g=1;break}if(12321<=(t[l>>2]|0)&(t[l>>2]|0)<=12329){g=1;break}}S=t[l>>2]|0;if((t[l>>2]|0)<256){if(48<=(S|0)&(t[l>>2]|0)<=57|(t[l>>2]|0)==46|(t[l>>2]|0)==45|(t[l>>2]|0)==95|(t[l>>2]|0)==58){g=1;break}}else{E=(dj(S,200216)|0)!=0;if(E|(t[l>>2]|0)==46|(t[l>>2]|0)==45|(t[l>>2]|0)==95|(t[l>>2]|0)==58){g=1;break}}if((t[l>>2]|0)>=256?(dj(t[l>>2]|0,200144)|0)!=0:0){g=1;break}E=t[l>>2]|0;if((t[l>>2]|0)<256)y=(E|0)==183&1;else y=dj(E,200272)|0;g=(y|0)!=0}while(0);t[d>>2]=g&1}else if((v|0)==47)t[d>>2]=oI(t[l>>2]|0)|0;else if((v|0)==49){t[d>>2]=sI(t[l>>2]|0)|0;if(!(t[d>>2]|0))t[d>>2]=yI(t[l>>2]|0)|0;if(!(t[d>>2]|0))t[d>>2]=WB(t[l>>2]|0)|0}l=t[d>>2]|0;if(t[b>>2]|0){t[o>>2]=((l|0)!=0^1)&1;p=t[o>>2]|0;s=a;return p|0}else{t[o>>2]=l;p=t[o>>2]|0;s=a;return p|0}return 0}function ok(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0;r=s;s=s+16|0;n=r+12|0;f=r+8|0;u=r+4|0;a=r;t[f>>2]=e;t[u>>2]=i;e:do if((t[f>>2]|0)==1|(t[f>>2]|0)==2|(t[f>>2]|0)==3|(t[f>>2]|0)==4|(t[f>>2]|0)==5|(t[f>>2]|0)==6)t[n>>2]=1;else{if((t[u>>2]|0)==1|(t[u>>2]|0)==2|(t[u>>2]|0)==3|(t[u>>2]|0)==4|(t[u>>2]|0)==5|(t[u>>2]|0)==6){t[n>>2]=1;break}if((t[f>>2]|0)==(t[u>>2]|0)){t[n>>2]=1;break}if((t[f>>2]|0)>>>0>(t[u>>2]|0)>>>0){t[a>>2]=t[f>>2];t[f>>2]=t[u>>2];t[u>>2]=t[a>>2]}i:do switch(t[f>>2]|0){case 100:{if((t[u>>2]|0)>>>0<=105){t[n>>2]=1;break e}else{t[n>>2]=0;break e}break}case 132:case 133:case 134:case 135:{t[n>>2]=0;break e;break}case 126:{if((t[u>>2]|0)>>>0<=130){t[n>>2]=1;break e}else{t[n>>2]=0;break e}break}case 106:{if((t[u>>2]|0)>>>0<=109){t[n>>2]=1;break e}else{t[n>>2]=0;break e}break}case 13:{if((((((!((t[u>>2]|0)==14|(t[u>>2]|0)==15)?!((t[u>>2]|0)>>>0>=100&(t[u>>2]|0)>>>0<=105):0)?!((t[u>>2]|0)>>>0>=106&(t[u>>2]|0)>>>0<=109):0)?!((t[u>>2]|0)>>>0>=114&(t[u>>2]|0)>>>0<=121):0)?!((t[u>>2]|0)>>>0>=122&(t[u>>2]|0)>>>0<=125):0)?!((t[u>>2]|0)>>>0>=126&(t[u>>2]|0)>>>0<=130):0)?!((t[u>>2]|0)>>>0>=131&(t[u>>2]|0)>>>0<=135):0)break i;t[n>>2]=0;break e;break}case 131:{if((t[u>>2]|0)>>>0<=135){t[n>>2]=1;break e}else{t[n>>2]=0;break e}break}case 15:{if((((((t[u>>2]|0)!=14?!((t[u>>2]|0)>>>0>=106&(t[u>>2]|0)>>>0<=109):0)?!((t[u>>2]|0)>>>0>=114&(t[u>>2]|0)>>>0<=121):0)?!((t[u>>2]|0)>>>0>=122&(t[u>>2]|0)>>>0<=125):0)?!((t[u>>2]|0)>>>0>=126&(t[u>>2]|0)>>>0<=130):0)?!((t[u>>2]|0)>>>0>=131&(t[u>>2]|0)>>>0<=135):0)break i;t[n>>2]=0;break e;break}case 7:{if((((((t[u>>2]|0)!=8?!((t[u>>2]|0)>>>0>=100&(t[u>>2]|0)>>>0<=105):0)?!((t[u>>2]|0)>>>0>=110&(t[u>>2]|0)>>>0<=113):0)?!((t[u>>2]|0)>>>0>=106&(t[u>>2]|0)>>>0<=109):0)?!((t[u>>2]|0)>>>0>=114&(t[u>>2]|0)>>>0<=121):0)?!((t[u>>2]|0)>>>0>=126&(t[u>>2]|0)>>>0<=130):0)break i;t[n>>2]=0;break e;break}case 125:case 124:case 123:{t[n>>2]=0;break e;break}case 105:case 104:case 103:case 102:case 101:{t[n>>2]=0;break e;break}case 11:{if((((((t[u>>2]|0)!=12?!((t[u>>2]|0)>>>0>=106&(t[u>>2]|0)>>>0<=109):0)?!((t[u>>2]|0)>>>0>=114&(t[u>>2]|0)>>>0<=121):0)?!((t[u>>2]|0)>>>0>=122&(t[u>>2]|0)>>>0<=125):0)?!((t[u>>2]|0)>>>0>=126&(t[u>>2]|0)>>>0<=130):0)?!((t[u>>2]|0)>>>0>=131&(t[u>>2]|0)>>>0<=135):0)break i;t[n>>2]=0;break e;break}case 110:{if((t[u>>2]|0)>>>0<=113){t[n>>2]=1;break e}else{t[n>>2]=0;break e}break}case 121:case 120:case 119:case 118:case 117:case 116:case 115:{t[n>>2]=0;break e;break}case 9:{if(((((((t[u>>2]|0)!=10?!((t[u>>2]|0)>>>0>=110&(t[u>>2]|0)>>>0<=113):0)?!((t[u>>2]|0)>>>0>=106&(t[u>>2]|0)>>>0<=109):0)?!((t[u>>2]|0)>>>0>=122&(t[u>>2]|0)>>>0<=125):0)?!((t[u>>2]|0)>>>0>=114&(t[u>>2]|0)>>>0<=121):0)?!((t[u>>2]|0)>>>0>=126&(t[u>>2]|0)>>>0<=130):0)?!((t[u>>2]|0)>>>0>=131&(t[u>>2]|0)>>>0<=135):0)break i;t[n>>2]=0;break e;break}case 122:{if((t[u>>2]|0)>>>0<=125){t[n>>2]=1;break e}else{t[n>>2]=0;break e}break}case 114:{if((t[u>>2]|0)>>>0<=121){t[n>>2]=1;break e}else{t[n>>2]=0;break e}break}case 130:case 129:case 128:case 127:{t[n>>2]=0;break e;break}case 113:case 112:case 111:{t[n>>2]=0;break e;break}case 109:case 108:case 107:{t[n>>2]=0;break e;break}default:{}}while(0);t[n>>2]=1}while(0);s=r;return t[n>>2]|0}function ck(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0;r=s;s=s+32|0;n=r+24|0;f=r+20|0;u=r+16|0;a=r+12|0;o=r+8|0;c=r+4|0;l=r;t[f>>2]=e;t[u>>2]=i;t[a>>2]=0;if((((((t[(t[f>>2]|0)+4>>2]|0)!=3?(t[(t[u>>2]|0)+4>>2]|0)!=3:0)?(t[(t[u>>2]|0)+4>>2]|0)!=4:0)?(t[(t[f>>2]|0)+4>>2]|0)!=4:0)?(t[(t[f>>2]|0)+4>>2]|0)!=5:0)?(t[(t[u>>2]|0)+4>>2]|0)!=5:0){if((t[(t[f>>2]|0)+4>>2]|0)>>>0>(t[(t[u>>2]|0)+4>>2]|0)>>>0){t[o>>2]=t[f>>2];t[f>>2]=t[u>>2];t[u>>2]=t[o>>2]}e:do if((t[(t[f>>2]|0)+4>>2]|0)!=6?(t[(t[u>>2]|0)+4>>2]|0)!=6:0){if((t[(t[f>>2]|0)+4>>2]|0)!=1?(t[(t[u>>2]|0)+4>>2]|0)!=1:0){o=t[(t[f>>2]|0)+4>>2]|0;if((t[(t[f>>2]|0)+4>>2]|0)==(t[(t[u>>2]|0)+4>>2]|0)){if((o|0)!=2){t[a>>2]=1;break}if((t[(t[f>>2]|0)+12>>2]|0)>=(t[(t[u>>2]|0)+8>>2]|0)?(t[(t[u>>2]|0)+12>>2]|0)>=(t[(t[f>>2]|0)+8>>2]|0):0){t[a>>2]=1;break}t[a>>2]=0;break}if((o|0)==2){t[l>>2]=0;if((t[t[f>>2]>>2]|0)==0?(t[t[u>>2]>>2]|0)!=0:0)b=28;else b=26;if(((b|0)==26?(t[t[f>>2]>>2]|0)!=0:0)?(t[t[u>>2]>>2]|0)==0:0)b=28;if((b|0)==28)t[l>>2]=1;t[c>>2]=t[(t[f>>2]|0)+8>>2];while(1){if((t[c>>2]|0)>(t[(t[f>>2]|0)+12>>2]|0)){b=37;break}t[a>>2]=ak(t[(t[u>>2]|0)+4>>2]|0,t[c>>2]|0,0,t[(t[u>>2]|0)+8>>2]|0,t[(t[u>>2]|0)+12>>2]|0,t[(t[u>>2]|0)+16>>2]|0)|0;if((t[a>>2]|0)<0){b=32;break}if((t[l>>2]|0)==1&(t[a>>2]|0)==0){b=35;break}if((t[l>>2]|0)==0&(t[a>>2]|0)==1){b=35;break}t[c>>2]=(t[c>>2]|0)+1}if((b|0)==32){t[n>>2]=-1;k=t[n>>2]|0;s=r;return k|0}else if((b|0)==35){t[n>>2]=1;k=t[n>>2]|0;s=r;return k|0}else if((b|0)==37){t[n>>2]=0;k=t[n>>2]|0;s=r;return k|0}}if((t[(t[f>>2]|0)+4>>2]|0)!=136?(t[(t[u>>2]|0)+4>>2]|0)!=136:0){do if((t[(t[f>>2]|0)+4>>2]|0)>>>0>=100){if((t[(t[u>>2]|0)+4>>2]|0)>>>0<100)break;t[a>>2]=0;switch(t[(t[f>>2]|0)+4>>2]|0){case 106:{do if((t[(t[u>>2]|0)+4>>2]|0)!=107){if((t[(t[u>>2]|0)+4>>2]|0)==108)break;if((t[(t[u>>2]|0)+4>>2]|0)!=109)break e}while(0);t[a>>2]=1;break e;break}case 110:{do if((t[(t[u>>2]|0)+4>>2]|0)!=111){if((t[(t[u>>2]|0)+4>>2]|0)==112)break;if((t[(t[u>>2]|0)+4>>2]|0)!=113)break e}while(0);t[a>>2]=1;break e;break}case 114:{do if((t[(t[u>>2]|0)+4>>2]|0)!=115){if((t[(t[u>>2]|0)+4>>2]|0)==116)break;if((t[(t[u>>2]|0)+4>>2]|0)==117)break;if((t[(t[u>>2]|0)+4>>2]|0)==118)break;if((t[(t[u>>2]|0)+4>>2]|0)==119)break;if((t[(t[u>>2]|0)+4>>2]|0)==120)break;if((t[(t[u>>2]|0)+4>>2]|0)!=121)break e}while(0);t[a>>2]=1;break e;break}case 100:{do if((t[(t[u>>2]|0)+4>>2]|0)!=101){if((t[(t[u>>2]|0)+4>>2]|0)==102)break;if((t[(t[u>>2]|0)+4>>2]|0)==103)break;if((t[(t[u>>2]|0)+4>>2]|0)==104)break;if((t[(t[u>>2]|0)+4>>2]|0)!=105)break e}while(0);t[a>>2]=1;break e;break}case 131:{do if((t[(t[u>>2]|0)+4>>2]|0)!=132){if((t[(t[u>>2]|0)+4>>2]|0)==133)break;if((t[(t[u>>2]|0)+4>>2]|0)!=134)break e}while(0);t[a>>2]=1;break e;break}case 126:{do if((t[(t[u>>2]|0)+4>>2]|0)!=127){if((t[(t[u>>2]|0)+4>>2]|0)==128)break;if((t[(t[u>>2]|0)+4>>2]|0)==129)break;if((t[(t[u>>2]|0)+4>>2]|0)!=130)break e}while(0);t[a>>2]=1;break e;break}case 122:{do if((t[(t[u>>2]|0)+4>>2]|0)!=123){if((t[(t[u>>2]|0)+4>>2]|0)==124)break;if((t[(t[u>>2]|0)+4>>2]|0)!=125)break e}while(0);t[a>>2]=1;break e;break}default:{do if((t[(t[u>>2]|0)+4>>2]|0)>>>0>=100){if((t[(t[u>>2]|0)+4>>2]|0)>>>0>=136)break;t[a>>2]=0;break e}while(0);t[n>>2]=1;k=t[n>>2]|0;s=r;return k|0}}}while(0);do if((t[(t[f>>2]|0)+4>>2]|0)==7){if((t[(t[u>>2]|0)+4>>2]|0)!=8)break;t[a>>2]=0;break e}while(0);do if((t[(t[f>>2]|0)+4>>2]|0)==9){if((t[(t[u>>2]|0)+4>>2]|0)!=10)break;t[a>>2]=0;break e}while(0);do if((t[(t[f>>2]|0)+4>>2]|0)==11){if((t[(t[u>>2]|0)+4>>2]|0)!=12)break;t[a>>2]=0;break e}while(0);do if((t[(t[f>>2]|0)+4>>2]|0)==13){if((t[(t[u>>2]|0)+4>>2]|0)!=14)break;t[a>>2]=0;break e}while(0);do if((t[(t[f>>2]|0)+4>>2]|0)==15){if((t[(t[u>>2]|0)+4>>2]|0)!=16)break;t[a>>2]=0;break e}while(0);t[n>>2]=1;k=t[n>>2]|0;s=r;return k|0}if((t[(t[f>>2]|0)+4>>2]|0)==(t[(t[u>>2]|0)+4>>2]|0)){t[a>>2]=Xl(t[(t[f>>2]|0)+16>>2]|0,t[(t[u>>2]|0)+16>>2]|0)|0;break}t[n>>2]=1;k=t[n>>2]|0;s=r;return k|0}t[n>>2]=0;k=t[n>>2]|0;s=r;return k|0}else b=12;while(0);if((b|0)==12)t[a>>2]=1;if((t[t[f>>2]>>2]|0)==0?(t[t[u>>2]>>2]|0)!=0:0)b=105;else b=103;if(((b|0)==103?(t[t[f>>2]>>2]|0)!=0:0)?(t[t[u>>2]>>2]|0)==0:0)b=105;if((b|0)==105)t[a>>2]=((t[a>>2]|0)!=0^1)&1;t[n>>2]=t[a>>2];k=t[n>>2]|0;s=r;return k|0}t[n>>2]=-1;k=t[n>>2]|0;s=r;return k|0}function lk(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0;r=s;s=s+16|0;n=r+12|0;f=r+8|0;u=r+4|0;a=r;t[f>>2]=e;t[u>>2]=i;if(!(t[u>>2]|0)){t[n>>2]=0;o=t[n>>2]|0;s=r;return o|0}t[a>>2]=kk(t[f>>2]|0,t[t[u>>2]>>2]|0,t[(t[u>>2]|0)+4>>2]|0,t[(t[u>>2]|0)+8>>2]|0,t[(t[u>>2]|0)+12>>2]|0)|0;if(!(t[a>>2]|0)){t[n>>2]=0;o=t[n>>2]|0;s=r;return o|0}if((t[(t[u>>2]|0)+16>>2]|0)!=0?(i=Yl(t[(t[u>>2]|0)+16>>2]|0)|0,t[(t[a>>2]|0)+16>>2]=i,(t[(t[a>>2]|0)+16>>2]|0)==0):0){Eb(t[f>>2]|0,139336);nk(t[a>>2]|0);t[n>>2]=0;o=t[n>>2]|0;s=r;return o|0}t[n>>2]=t[a>>2];o=t[n>>2]|0;s=r;return o|0}function sk(e){e=e|0;var i=0,r=0,n=0,f=0,a=0,o=0,c=0,l=0,b=0,k=0;i=s;s=s+32|0;r=i+24|0;n=i+20|0;f=i+16|0;a=i+12|0;o=i+8|0;c=i+4|0;l=i;t[n>>2]=e;t[f>>2]=hk(t[n>>2]|0)|0;e=t[n>>2]|0;if((t[f>>2]|0)>0){b=Ib(e,2)|0;t[(t[n>>2]|0)+28>>2]=b;if(!(t[(t[n>>2]|0)+28>>2]|0)){t[r>>2]=-1;k=t[r>>2]|0;s=i;return k|0}else{t[f>>2]=Mp(0,t[(t[n>>2]|0)+4>>2]|0,a)|0;t[(t[(t[n>>2]|0)+28>>2]|0)+32>>2]=t[f>>2];f=(t[n>>2]|0)+4|0;t[f>>2]=(t[f>>2]|0)+(t[a>>2]|0);t[r>>2]=1;k=t[r>>2]|0;s=i;return k|0}}if((u[t[e+4>>2]>>0]|0|0)==124){t[r>>2]=0;k=t[r>>2]|0;s=i;return k|0}if(!(u[t[(t[n>>2]|0)+4>>2]>>0]|0)){t[r>>2]=0;k=t[r>>2]|0;s=i;return k|0}if((u[t[(t[n>>2]|0)+4>>2]>>0]|0|0)==41){t[r>>2]=0;k=t[r>>2]|0;s=i;return k|0}e=(t[n>>2]|0)+4|0;a=t[e>>2]|0;if((u[t[(t[n>>2]|0)+4>>2]>>0]|0|0)!=40){if(((u[a>>0]|0|0)!=91?(u[t[(t[n>>2]|0)+4>>2]>>0]|0|0)!=92:0)?(u[t[(t[n>>2]|0)+4>>2]>>0]|0|0)!=46:0){t[r>>2]=0;k=t[r>>2]|0;s=i;return k|0}wk(t[n>>2]|0);t[r>>2]=1;k=t[r>>2]|0;s=i;return k|0}t[e>>2]=a+1;jb(t[n>>2]|0,t[(t[n>>2]|0)+24>>2]|0,0);t[l>>2]=t[(t[n>>2]|0)+24>>2];jb(t[n>>2]|0,t[(t[n>>2]|0)+24>>2]|0,0);t[o>>2]=t[(t[n>>2]|0)+24>>2];t[c>>2]=t[(t[n>>2]|0)+20>>2];t[(t[n>>2]|0)+20>>2]=0;t[(t[n>>2]|0)+28>>2]=0;Mb(t[n>>2]|0,0);a=t[n>>2]|0;if((u[t[(t[n>>2]|0)+4>>2]>>0]|0|0)==41){e=a+4|0;t[e>>2]=(t[e>>2]|0)+1}else{t[a+8>>2]=1450;Rb(t[n>>2]|0,139672)}a=Ib(t[n>>2]|0,4)|0;t[(t[n>>2]|0)+28>>2]=a;if(!(t[(t[n>>2]|0)+28>>2]|0)){t[r>>2]=-1;k=t[r>>2]|0;s=i;return k|0}else{t[(t[(t[n>>2]|0)+28>>2]|0)+36>>2]=t[o>>2];t[(t[(t[n>>2]|0)+28>>2]|0)+40>>2]=t[l>>2];t[(t[(t[n>>2]|0)+28>>2]|0)+44>>2]=t[(t[n>>2]|0)+24>>2];t[(t[n>>2]|0)+20>>2]=t[c>>2];t[r>>2]=1;k=t[r>>2]|0;s=i;return k|0}return 0}function bk(e){e=e|0;var i=0,r=0,n=0,f=0,a=0,o=0,c=0;i=s;s=s+32|0;r=i+16|0;n=i+12|0;f=i+8|0;a=i+4|0;o=i;t[n>>2]=e;t[f>>2]=u[t[(t[n>>2]|0)+4>>2]>>0];if((t[f>>2]|0)==63|(t[f>>2]|0)==42|(t[f>>2]|0)==43){do if(t[(t[n>>2]|0)+28>>2]|0){if((t[f>>2]|0)==63){t[(t[(t[n>>2]|0)+28>>2]|0)+8>>2]=3;break}if((t[f>>2]|0)==42){t[(t[(t[n>>2]|0)+28>>2]|0)+8>>2]=4;break}if((t[f>>2]|0)==43)t[(t[(t[n>>2]|0)+28>>2]|0)+8>>2]=5}while(0);e=(t[n>>2]|0)+4|0;t[e>>2]=(t[e>>2]|0)+1;t[r>>2]=1;c=t[r>>2]|0;s=i;return c|0}if((t[f>>2]|0)!=123){t[r>>2]=0;c=t[r>>2]|0;s=i;return c|0}t[a>>2]=0;t[o>>2]=0;e=(t[n>>2]|0)+4|0;t[e>>2]=(t[e>>2]|0)+1;t[f>>2]=dk(t[n>>2]|0)|0;if((t[f>>2]|0)>=0)t[a>>2]=t[f>>2];do if((u[t[(t[n>>2]|0)+4>>2]>>0]|0|0)==44){e=(t[n>>2]|0)+4|0;t[e>>2]=(t[e>>2]|0)+1;if((u[t[(t[n>>2]|0)+4>>2]>>0]|0|0)==125){t[o>>2]=2147483647;break}t[f>>2]=dk(t[n>>2]|0)|0;if((t[f>>2]|0)>=0){t[o>>2]=t[f>>2];break}else{t[(t[n>>2]|0)+8>>2]=1450;Rb(t[n>>2]|0,139624);break}}while(0);f=t[n>>2]|0;if((u[t[(t[n>>2]|0)+4>>2]>>0]|0|0)==125){e=f+4|0;t[e>>2]=(t[e>>2]|0)+1}else{t[f+8>>2]=1450;Rb(t[n>>2]|0,139648)}if(!(t[o>>2]|0))t[o>>2]=t[a>>2];if(t[(t[n>>2]|0)+28>>2]|0){t[(t[(t[n>>2]|0)+28>>2]|0)+8>>2]=8;t[(t[(t[n>>2]|0)+28>>2]|0)+12>>2]=t[a>>2];t[(t[(t[n>>2]|0)+28>>2]|0)+16>>2]=t[o>>2]}t[r>>2]=1;c=t[r>>2]|0;s=i;return c|0}function kk(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;var u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0;u=s;s=s+32|0;a=u+24|0;o=u+20|0;c=u+16|0;l=u+12|0;b=u+8|0;k=u+4|0;h=u;t[o>>2]=e;t[c>>2]=i;t[l>>2]=r;t[b>>2]=n;t[k>>2]=f;t[h>>2]=gAi[t[135744>>2]&511](20)|0;if(!(t[h>>2]|0)){Eb(t[o>>2]|0,139336);t[a>>2]=0;w=t[a>>2]|0;s=u;return w|0}else{t[t[h>>2]>>2]=t[c>>2];t[(t[h>>2]|0)+4>>2]=t[l>>2];t[(t[h>>2]|0)+8>>2]=t[b>>2];t[(t[h>>2]|0)+12>>2]=t[k>>2];t[a>>2]=t[h>>2];w=t[a>>2]|0;s=u;return w|0}return 0}function hk(e){e=e|0;var i=0,r=0,n=0,f=0,u=0;i=s;s=s+16|0;r=i+12|0;n=i+8|0;f=i+4|0;t[n>>2]=e;t[f>>2]=Mp(0,t[(t[n>>2]|0)+4>>2]|0,i)|0;if((t[f>>2]|0)==46|(t[f>>2]|0)==92|(t[f>>2]|0)==63|(t[f>>2]|0)==42|(t[f>>2]|0)==43|(t[f>>2]|0)==40|(t[f>>2]|0)==41|(t[f>>2]|0)==124|(t[f>>2]|0)==91|(t[f>>2]|0)==93|(t[f>>2]|0)==0){t[r>>2]=-1;u=t[r>>2]|0;s=i;return u|0}else{t[r>>2]=t[f>>2];u=t[r>>2]|0;s=i;return u|0}return 0}function wk(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i;t[r>>2]=e;e=t[r>>2]|0;if((u[t[(t[r>>2]|0)+4>>2]>>0]|0|0)!=91){mk(e);s=i;return}n=e+4|0;t[n>>2]=(t[n>>2]|0)+1;n=Ib(t[r>>2]|0,3)|0;t[(t[r>>2]|0)+28>>2]=n;if(!(t[(t[r>>2]|0)+28>>2]|0)){s=i;return}vk(t[r>>2]|0);n=t[r>>2]|0;if((u[t[(t[r>>2]|0)+4>>2]>>0]|0|0)==93){e=n+4|0;t[e>>2]=(t[e>>2]|0)+1;s=i;return}else{t[n+8>>2]=1450;Rb(t[r>>2]|0,139704);s=i;return}}function dk(e){e=e|0;var i=0,r=0,n=0,f=0,a=0,o=0;i=s;s=s+16|0;r=i+12|0;n=i+8|0;f=i+4|0;a=i;t[n>>2]=e;t[f>>2]=0;t[a>>2]=0;while(1){if((u[t[(t[n>>2]|0)+4>>2]>>0]|0|0)<48)break;if((u[t[(t[n>>2]|0)+4>>2]>>0]|0|0)>57)break;t[f>>2]=((t[f>>2]|0)*10|0)+((u[t[(t[n>>2]|0)+4>>2]>>0]|0)-48);t[a>>2]=1;e=(t[n>>2]|0)+4|0;t[e>>2]=(t[e>>2]|0)+1}if((t[a>>2]|0)!=1){t[r>>2]=-1;o=t[r>>2]|0;s=i;return o|0}else{t[r>>2]=t[f>>2];o=t[r>>2]|0;s=i;return o|0}return 0}function vk(e){e=e|0;var i=0,r=0,n=0,f=0,a=0,o=0,c=0,l=0,b=0,k=0;i=s;s=s+16|0;r=i+12|0;n=i+8|0;f=i+4|0;a=i;t[r>>2]=e;t[n>>2]=t[(t[r>>2]|0)+12>>2];while(1){if((u[t[(t[r>>2]|0)+4>>2]>>0]|0|0)==93){o=13;break}if(t[(t[r>>2]|0)+8>>2]|0){o=13;break}e=t[r>>2]|0;if((u[t[(t[r>>2]|0)+4>>2]>>0]|0|0)==94){t[f>>2]=t[e+12>>2];c=(t[r>>2]|0)+4|0;t[c>>2]=(t[c>>2]|0)+1;t[(t[r>>2]|0)+12>>2]=((t[(t[r>>2]|0)+12>>2]|0)!=0^1)&1;_k(t[r>>2]|0);t[(t[r>>2]|0)+12>>2]=t[f>>2];continue}if((u[t[e+4>>2]>>0]|0|0)==45?(u[(t[(t[r>>2]|0)+4>>2]|0)+1>>0]|0|0)==91:0){o=8;break}if((u[t[(t[r>>2]|0)+4>>2]>>0]|0|0)==93)continue;_k(t[r>>2]|0)}if((o|0)==8){t[a>>2]=t[(t[r>>2]|0)+12>>2];t[(t[r>>2]|0)+12>>2]=2;f=(t[r>>2]|0)+4|0;t[f>>2]=(t[f>>2]|0)+1;f=(t[r>>2]|0)+4|0;t[f>>2]=(t[f>>2]|0)+1;vk(t[r>>2]|0);f=t[r>>2]|0;if((u[t[(t[r>>2]|0)+4>>2]>>0]|0|0)==93){e=f+4|0;t[e>>2]=(t[e>>2]|0)+1;t[(t[r>>2]|0)+12>>2]=t[a>>2];l=t[n>>2]|0;b=t[r>>2]|0;k=b+12|0;t[k>>2]=l;s=i;return}else{t[f+8>>2]=1450;Rb(t[r>>2]|0,139968);l=t[n>>2]|0;b=t[r>>2]|0;k=b+12|0;t[k>>2]=l;s=i;return}}else if((o|0)==13){l=t[n>>2]|0;b=t[r>>2]|0;k=b+12|0;t[k>>2]=l;s=i;return}}function mk(e){e=e|0;var i=0,r=0,n=0,f=0,a=0,o=0;i=s;s=s+16|0;r=i+8|0;n=i+4|0;f=i;t[r>>2]=e;e=t[r>>2]|0;if((u[t[(t[r>>2]|0)+4>>2]>>0]|0|0)==46){a=t[r>>2]|0;if(t[e+28>>2]|0){if((t[(t[a+28>>2]|0)+4>>2]|0)==3)pk(t[r>>2]|0,t[(t[r>>2]|0)+28>>2]|0,t[(t[r>>2]|0)+12>>2]|0,6,0,0,0)}else{o=Ib(a,6)|0;t[(t[r>>2]|0)+28>>2]=o}o=(t[r>>2]|0)+4|0;t[o>>2]=(t[o>>2]|0)+1;s=i;return}o=t[r>>2]|0;if((u[t[e+4>>2]>>0]|0|0)!=92){t[o+8>>2]=1450;Rb(t[r>>2]|0,139744);s=i;return}e=o+4|0;t[e>>2]=(t[e>>2]|0)+1;t[n>>2]=u[t[(t[r>>2]|0)+4>>2]>>0];if((t[n>>2]|0)==112){e=(t[r>>2]|0)+4|0;t[e>>2]=(t[e>>2]|0)+1;e=t[r>>2]|0;if((u[t[(t[r>>2]|0)+4>>2]>>0]|0|0)!=123){t[e+8>>2]=1450;Rb(t[r>>2]|0,139776);s=i;return}o=e+4|0;t[o>>2]=(t[o>>2]|0)+1;Ek(t[r>>2]|0);o=t[r>>2]|0;if((u[t[(t[r>>2]|0)+4>>2]>>0]|0|0)!=125){t[o+8>>2]=1450;Rb(t[r>>2]|0,139792);s=i;return}else{e=o+4|0;t[e>>2]=(t[e>>2]|0)+1;s=i;return}}if((t[n>>2]|0)==80){e=(t[r>>2]|0)+4|0;t[e>>2]=(t[e>>2]|0)+1;e=t[r>>2]|0;if((u[t[(t[r>>2]|0)+4>>2]>>0]|0|0)!=123){t[e+8>>2]=1450;Rb(t[r>>2]|0,139776);s=i;return}o=e+4|0;t[o>>2]=(t[o>>2]|0)+1;Ek(t[r>>2]|0);t[(t[(t[r>>2]|0)+28>>2]|0)+28>>2]=1;o=t[r>>2]|0;if((u[t[(t[r>>2]|0)+4>>2]>>0]|0|0)!=125){t[o+8>>2]=1450;Rb(t[r>>2]|0,139792);s=i;return}else{e=o+4|0;t[e>>2]=(t[e>>2]|0)+1;s=i;return}}if((t[n>>2]|0)==110|(t[n>>2]|0)==114|(t[n>>2]|0)==116|(t[n>>2]|0)==92|(t[n>>2]|0)==124|(t[n>>2]|0)==46|(t[n>>2]|0)==63|(t[n>>2]|0)==42|(t[n>>2]|0)==43|(t[n>>2]|0)==40|(t[n>>2]|0)==41|(t[n>>2]|0)==123|(t[n>>2]|0)==125|(t[n>>2]|0)==45|(t[n>>2]|0)==91|(t[n>>2]|0)==93|(t[n>>2]|0)==94){e=t[r>>2]|0;do if(!(t[(t[r>>2]|0)+28>>2]|0)){o=Ib(e,2)|0;t[(t[r>>2]|0)+28>>2]=o;if(t[(t[r>>2]|0)+28>>2]|0){o=t[n>>2]|0;if((o|0)==116){t[(t[(t[r>>2]|0)+28>>2]|0)+32>>2]=9;break}else if((o|0)==110){t[(t[(t[r>>2]|0)+28>>2]|0)+32>>2]=10;break}else if((o|0)==114){t[(t[(t[r>>2]|0)+28>>2]|0)+32>>2]=13;break}else{t[(t[(t[r>>2]|0)+28>>2]|0)+32>>2]=t[n>>2];break}}}else if((t[(t[e+28>>2]|0)+4>>2]|0)==3){o=t[n>>2]|0;if((o|0)==110)t[n>>2]=10;else if((o|0)==114)t[n>>2]=13;else if((o|0)==116)t[n>>2]=9;pk(t[r>>2]|0,t[(t[r>>2]|0)+28>>2]|0,t[(t[r>>2]|0)+12>>2]|0,2,t[n>>2]|0,t[n>>2]|0,0)}while(0);e=(t[r>>2]|0)+4|0;t[e>>2]=(t[e>>2]|0)+1;s=i;return}if(!((t[n>>2]|0)==115|(t[n>>2]|0)==83|(t[n>>2]|0)==105|(t[n>>2]|0)==73|(t[n>>2]|0)==99|(t[n>>2]|0)==67|(t[n>>2]|0)==100|(t[n>>2]|0)==68|(t[n>>2]|0)==119|(t[n>>2]|0)==87)){t[(t[r>>2]|0)+8>>2]=1450;Rb(t[r>>2]|0,139808);s=i;return}t[f>>2]=7;do switch(t[n>>2]|0){case 115:{t[f>>2]=7;break}case 83:{t[f>>2]=8;break}case 99:{t[f>>2]=11;break}case 67:{t[f>>2]=12;break}case 119:{t[f>>2]=15;break}case 87:{t[f>>2]=16;break}case 105:{t[f>>2]=9;break}case 73:{t[f>>2]=10;break}case 100:{t[f>>2]=13;break}case 68:{t[f>>2]=14;break}default:{}}while(0);n=(t[r>>2]|0)+4|0;t[n>>2]=(t[n>>2]|0)+1;n=t[r>>2]|0;if(!(t[(t[r>>2]|0)+28>>2]|0)){e=Ib(n,t[f>>2]|0)|0;t[(t[r>>2]|0)+28>>2]=e;s=i;return}if((t[(t[n+28>>2]|0)+4>>2]|0)!=3){s=i;return}pk(t[r>>2]|0,t[(t[r>>2]|0)+28>>2]|0,t[(t[r>>2]|0)+12>>2]|0,t[f>>2]|0,0,0,0);s=i;return}function _k(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i;t[r>>2]=e;while(1){e=t[r>>2]|0;if((u[t[(t[r>>2]|0)+4>>2]>>0]|0|0)==92)mk(e);else Sk(e);if((u[t[(t[r>>2]|0)+4>>2]>>0]|0|0)==93){n=10;break}if((u[t[(t[r>>2]|0)+4>>2]>>0]|0|0)==94){n=10;break}if((u[t[(t[r>>2]|0)+4>>2]>>0]|0|0)==45){n=10;break}if(!(u[t[(t[r>>2]|0)+4>>2]>>0]|0)){n=10;break}if(t[(t[r>>2]|0)+8>>2]|0){n=10;break}}if((n|0)==10){s=i;return}}function pk(e,i,r,n,f,u,a){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;u=u|0;a=a|0;var o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0;o=s;s=s+48|0;c=o+32|0;l=o+28|0;b=o+24|0;k=o+20|0;h=o+16|0;w=o+12|0;d=o+8|0;v=o+4|0;m=o;t[c>>2]=e;t[l>>2]=i;t[b>>2]=r;t[k>>2]=n;t[h>>2]=f;t[w>>2]=u;t[d>>2]=a;if(!(t[l>>2]|0)){t[(t[c>>2]|0)+8>>2]=1450;Rb(t[c>>2]|0,139896);s=o;return}if((t[(t[l>>2]|0)+4>>2]|0)!=3){t[(t[c>>2]|0)+8>>2]=1450;Rb(t[c>>2]|0,139920);s=o;return}a=t[l>>2]|0;do if(!(t[(t[l>>2]|0)+48>>2]|0)){t[a+48>>2]=4;u=gAi[t[135744>>2]&511](t[(t[l>>2]|0)+48>>2]<<2)|0;t[(t[l>>2]|0)+56>>2]=u;if(!(t[(t[l>>2]|0)+56>>2]|0)){Eb(t[c>>2]|0,139952);t[(t[l>>2]|0)+48>>2]=0;s=o;return}}else if((t[a+52>>2]|0)>=(t[(t[l>>2]|0)+48>>2]|0)){u=(t[l>>2]|0)+48|0;t[u>>2]=t[u>>2]<<1;t[m>>2]=MAi[t[135760>>2]&511](t[(t[l>>2]|0)+56>>2]|0,t[(t[l>>2]|0)+48>>2]<<2)|0;if(t[m>>2]|0){t[(t[l>>2]|0)+56>>2]=t[m>>2];break}Eb(t[c>>2]|0,139952);u=(t[l>>2]|0)+48|0;t[u>>2]=(t[u>>2]|0)/2|0;s=o;return}while(0);t[v>>2]=kk(t[c>>2]|0,t[b>>2]|0,t[k>>2]|0,t[h>>2]|0,t[w>>2]|0)|0;if(!(t[v>>2]|0)){s=o;return}t[(t[v>>2]|0)+16>>2]=t[d>>2];d=t[v>>2]|0;v=(t[l>>2]|0)+52|0;w=t[v>>2]|0;t[v>>2]=w+1;t[(t[(t[l>>2]|0)+56>>2]|0)+(w<<2)>>2]=d;s=o;return}function Ek(e){e=e|0;var i=0,r=0,n=0,f=0,a=0,o=0,c=0,l=0;i=s;s=s+32|0;r=i+16|0;n=i+12|0;f=i+8|0;a=i+4|0;o=i;t[r>>2]=e;t[f>>2]=0;t[a>>2]=0;t[n>>2]=u[t[(t[r>>2]|0)+4>>2]>>0];do if((t[n>>2]|0)==76){e=(t[r>>2]|0)+4|0;t[e>>2]=(t[e>>2]|0)+1;t[n>>2]=u[t[(t[r>>2]|0)+4>>2]>>0];if((t[n>>2]|0)==117){e=(t[r>>2]|0)+4|0;t[e>>2]=(t[e>>2]|0)+1;t[f>>2]=101;break}if((t[n>>2]|0)==108){e=(t[r>>2]|0)+4|0;t[e>>2]=(t[e>>2]|0)+1;t[f>>2]=102;break}if((t[n>>2]|0)==116){e=(t[r>>2]|0)+4|0;t[e>>2]=(t[e>>2]|0)+1;t[f>>2]=103;break}if((t[n>>2]|0)==109){e=(t[r>>2]|0)+4|0;t[e>>2]=(t[e>>2]|0)+1;t[f>>2]=104;break}if((t[n>>2]|0)==111){e=(t[r>>2]|0)+4|0;t[e>>2]=(t[e>>2]|0)+1;t[f>>2]=105;break}else{t[f>>2]=100;break}}else{if((t[n>>2]|0)==77){e=(t[r>>2]|0)+4|0;t[e>>2]=(t[e>>2]|0)+1;t[n>>2]=u[t[(t[r>>2]|0)+4>>2]>>0];if((t[n>>2]|0)==110){e=(t[r>>2]|0)+4|0;t[e>>2]=(t[e>>2]|0)+1;t[f>>2]=107;break}if((t[n>>2]|0)==99){e=(t[r>>2]|0)+4|0;t[e>>2]=(t[e>>2]|0)+1;t[f>>2]=108;break}if((t[n>>2]|0)==101){e=(t[r>>2]|0)+4|0;t[e>>2]=(t[e>>2]|0)+1;t[f>>2]=109;break}else{t[f>>2]=106;break}}if((t[n>>2]|0)==78){e=(t[r>>2]|0)+4|0;t[e>>2]=(t[e>>2]|0)+1;t[n>>2]=u[t[(t[r>>2]|0)+4>>2]>>0];if((t[n>>2]|0)==100){e=(t[r>>2]|0)+4|0;t[e>>2]=(t[e>>2]|0)+1;t[f>>2]=111;break}if((t[n>>2]|0)==108){e=(t[r>>2]|0)+4|0;t[e>>2]=(t[e>>2]|0)+1;t[f>>2]=112;break}if((t[n>>2]|0)==111){e=(t[r>>2]|0)+4|0;t[e>>2]=(t[e>>2]|0)+1;t[f>>2]=113;break}else{t[f>>2]=110;break}}if((t[n>>2]|0)==80){e=(t[r>>2]|0)+4|0;t[e>>2]=(t[e>>2]|0)+1;t[n>>2]=u[t[(t[r>>2]|0)+4>>2]>>0];if((t[n>>2]|0)==99){e=(t[r>>2]|0)+4|0;t[e>>2]=(t[e>>2]|0)+1;t[f>>2]=115;break}if((t[n>>2]|0)==100){e=(t[r>>2]|0)+4|0;t[e>>2]=(t[e>>2]|0)+1;t[f>>2]=116;break}if((t[n>>2]|0)==115){e=(t[r>>2]|0)+4|0;t[e>>2]=(t[e>>2]|0)+1;t[f>>2]=117;break}if((t[n>>2]|0)==101){e=(t[r>>2]|0)+4|0;t[e>>2]=(t[e>>2]|0)+1;t[f>>2]=118;break}if((t[n>>2]|0)==105){e=(t[r>>2]|0)+4|0;t[e>>2]=(t[e>>2]|0)+1;t[f>>2]=119;break}if((t[n>>2]|0)==102){e=(t[r>>2]|0)+4|0;t[e>>2]=(t[e>>2]|0)+1;t[f>>2]=120;break}if((t[n>>2]|0)==111){e=(t[r>>2]|0)+4|0;t[e>>2]=(t[e>>2]|0)+1;t[f>>2]=121;break}else{t[f>>2]=114;break}}if((t[n>>2]|0)==90){e=(t[r>>2]|0)+4|0;t[e>>2]=(t[e>>2]|0)+1;
	t[n>>2]=u[t[(t[r>>2]|0)+4>>2]>>0];if((t[n>>2]|0)==115){e=(t[r>>2]|0)+4|0;t[e>>2]=(t[e>>2]|0)+1;t[f>>2]=123;break}if((t[n>>2]|0)==108){e=(t[r>>2]|0)+4|0;t[e>>2]=(t[e>>2]|0)+1;t[f>>2]=124;break}if((t[n>>2]|0)==112){e=(t[r>>2]|0)+4|0;t[e>>2]=(t[e>>2]|0)+1;t[f>>2]=125;break}else{t[f>>2]=122;break}}if((t[n>>2]|0)==83){e=(t[r>>2]|0)+4|0;t[e>>2]=(t[e>>2]|0)+1;t[n>>2]=u[t[(t[r>>2]|0)+4>>2]>>0];if((t[n>>2]|0)==109){e=(t[r>>2]|0)+4|0;t[e>>2]=(t[e>>2]|0)+1;t[f>>2]=127;break}if((t[n>>2]|0)==99){e=(t[r>>2]|0)+4|0;t[e>>2]=(t[e>>2]|0)+1;t[f>>2]=128;break}if((t[n>>2]|0)==107){e=(t[r>>2]|0)+4|0;t[e>>2]=(t[e>>2]|0)+1;t[f>>2]=129;break}if((t[n>>2]|0)==111){e=(t[r>>2]|0)+4|0;t[e>>2]=(t[e>>2]|0)+1;t[f>>2]=130;break}else{t[f>>2]=126;break}}if((t[n>>2]|0)==67){e=(t[r>>2]|0)+4|0;t[e>>2]=(t[e>>2]|0)+1;t[n>>2]=u[t[(t[r>>2]|0)+4>>2]>>0];if((t[n>>2]|0)==99){e=(t[r>>2]|0)+4|0;t[e>>2]=(t[e>>2]|0)+1;t[f>>2]=132;break}if((t[n>>2]|0)==102){e=(t[r>>2]|0)+4|0;t[e>>2]=(t[e>>2]|0)+1;t[f>>2]=133;break}if((t[n>>2]|0)==111){e=(t[r>>2]|0)+4|0;t[e>>2]=(t[e>>2]|0)+1;t[f>>2]=134;break}if((t[n>>2]|0)==110){e=(t[r>>2]|0)+4|0;t[e>>2]=(t[e>>2]|0)+1;t[f>>2]=135;break}else{t[f>>2]=131;break}}e=t[r>>2]|0;if((t[n>>2]|0)!=73){t[e+8>>2]=1450;Rb(t[r>>2]|0,139872);s=i;return}c=e+4|0;t[c>>2]=(t[c>>2]|0)+1;t[n>>2]=u[t[(t[r>>2]|0)+4>>2]>>0];c=t[r>>2]|0;if((t[n>>2]|0)!=115){t[c+8>>2]=1450;Rb(t[r>>2]|0,139856);s=i;return}e=c+4|0;t[e>>2]=(t[e>>2]|0)+1;t[o>>2]=t[(t[r>>2]|0)+4>>2];t[n>>2]=u[t[(t[r>>2]|0)+4>>2]>>0];if(!((!((t[n>>2]|0)>=97&(t[n>>2]|0)<=122)?!((t[n>>2]|0)>=65&(t[n>>2]|0)<=90):0)?!((t[n>>2]|0)>=48&(t[n>>2]|0)<=57|(t[n>>2]|0)==45):0))l=79;e:do if((l|0)==79){e=(t[r>>2]|0)+4|0;t[e>>2]=(t[e>>2]|0)+1;t[n>>2]=u[t[(t[r>>2]|0)+4>>2]>>0];while(1){if((!((t[n>>2]|0)>=97&(t[n>>2]|0)<=122)?!((t[n>>2]|0)>=65&(t[n>>2]|0)<=90):0)?!((t[n>>2]|0)>=48&(t[n>>2]|0)<=57|(t[n>>2]|0)==45):0)break e;e=(t[r>>2]|0)+4|0;t[e>>2]=(t[e>>2]|0)+1;t[n>>2]=u[t[(t[r>>2]|0)+4>>2]>>0]}}while(0);t[f>>2]=136;t[a>>2]=ql(t[o>>2]|0,(t[(t[r>>2]|0)+4>>2]|0)-(t[o>>2]|0)|0)|0}while(0);o=t[r>>2]|0;if(!(t[(t[r>>2]|0)+28>>2]|0)){n=Ib(o,t[f>>2]|0)|0;t[(t[r>>2]|0)+28>>2]=n;if(!(t[(t[r>>2]|0)+28>>2]|0)){s=i;return}t[(t[(t[r>>2]|0)+28>>2]|0)+20>>2]=t[a>>2];s=i;return}else{if((t[(t[o+28>>2]|0)+4>>2]|0)!=3){s=i;return}pk(t[r>>2]|0,t[(t[r>>2]|0)+28>>2]|0,t[(t[r>>2]|0)+12>>2]|0,t[f>>2]|0,0,0,t[a>>2]|0);s=i;return}}function Sk(e){e=e|0;var i=0,r=0,n=0,f=0,a=0,o=0,c=0;i=s;s=s+32|0;r=i+16|0;n=i+12|0;f=i+8|0;a=i+4|0;o=i;t[r>>2]=e;t[a>>2]=-1;t[o>>2]=-1;e=t[r>>2]|0;if(!(u[t[(t[r>>2]|0)+4>>2]>>0]|0)){t[e+8>>2]=1450;Rb(t[r>>2]|0,14e4);s=i;return}t[n>>2]=u[t[e+4>>2]>>0];do if((t[n>>2]|0)==92){e=(t[r>>2]|0)+4|0;t[e>>2]=(t[e>>2]|0)+1;t[n>>2]=u[t[(t[r>>2]|0)+4>>2]>>0];switch(t[n>>2]|0){case 93:case 91:case 41:case 40:case 125:case 123:case 43:case 42:case 63:case 94:case 45:case 46:case 124:case 92:{t[a>>2]=t[n>>2];break}case 114:{t[a>>2]=13;break}case 116:{t[a>>2]=9;break}case 110:{t[a>>2]=10;break}default:{t[(t[r>>2]|0)+8>>2]=1450;Rb(t[r>>2]|0,140016);s=i;return}}t[o>>2]=t[a>>2];t[f>>2]=1}else{e=t[r>>2]|0;if((t[n>>2]|0)!=91&(t[n>>2]|0)!=93){c=Mp(0,t[e+4>>2]|0,f)|0;t[a>>2]=c;t[o>>2]=c;break}t[e+8>>2]=1450;Rb(t[r>>2]|0,140040);s=i;return}while(0);if((((t[a>>2]|0)==45?(u[(t[(t[r>>2]|0)+4>>2]|0)+1>>0]|0|0)!=93:0)?(u[(t[(t[r>>2]|0)+4>>2]|0)+-1>>0]|0|0)!=91:0)?(u[(t[(t[r>>2]|0)+4>>2]|0)+-1>>0]|0|0)!=94:0){e=(t[r>>2]|0)+4|0;t[e>>2]=(t[e>>2]|0)+(t[f>>2]|0);s=i;return}e=(t[r>>2]|0)+4|0;t[e>>2]=(t[e>>2]|0)+(t[f>>2]|0);t[n>>2]=u[t[(t[r>>2]|0)+4>>2]>>0];if((t[n>>2]|0)==45?(u[(t[(t[r>>2]|0)+4>>2]|0)+1>>0]|0|0)!=93:0){e=(t[r>>2]|0)+4|0;t[e>>2]=(t[e>>2]|0)+1;t[n>>2]=u[t[(t[r>>2]|0)+4>>2]>>0];do if((t[n>>2]|0)==92){e=(t[r>>2]|0)+4|0;t[e>>2]=(t[e>>2]|0)+1;t[n>>2]=u[t[(t[r>>2]|0)+4>>2]>>0];switch(t[n>>2]|0){case 93:case 91:case 41:case 40:case 125:case 123:case 43:case 42:case 63:case 94:case 45:case 46:case 124:case 92:{t[o>>2]=t[n>>2];break}case 110:{t[o>>2]=10;break}case 114:{t[o>>2]=13;break}case 116:{t[o>>2]=9;break}default:{t[(t[r>>2]|0)+8>>2]=1450;Rb(t[r>>2]|0,140016);s=i;return}}t[f>>2]=1}else{e=t[r>>2]|0;if((t[n>>2]|0)!=91&(t[n>>2]|0)!=93){t[o>>2]=Mp(0,t[e+4>>2]|0,f)|0;break}t[e+8>>2]=1450;Rb(t[r>>2]|0,140064);s=i;return}while(0);n=(t[r>>2]|0)+4|0;t[n>>2]=(t[n>>2]|0)+(t[f>>2]|0);f=t[r>>2]|0;if((t[o>>2]|0)<(t[a>>2]|0)){t[f+8>>2]=1450;Rb(t[r>>2]|0,140104);s=i;return}else{pk(f,t[(t[r>>2]|0)+28>>2]|0,t[(t[r>>2]|0)+12>>2]|0,2,t[a>>2]|0,t[o>>2]|0,0);s=i;return}}pk(t[r>>2]|0,t[(t[r>>2]|0)+28>>2]|0,t[(t[r>>2]|0)+12>>2]|0,2,t[a>>2]|0,t[o>>2]|0,0);s=i;return}function gk(){var e=0,i=0,r=0,n=0,f=0,u=0;e=s;s=s+16|0;i=e+4|0;r=e;t[r>>2]=gAi[t[135744>>2]&511](40)|0;if(!(t[r>>2]|0)){t[i>>2]=0;n=t[i>>2]|0;s=e;return n|0}else{f=(t[r>>2]|0)+0|0;u=f+40|0;do{t[f>>2]=0;f=f+4|0}while((f|0)<(u|0));t[i>>2]=t[r>>2];n=t[i>>2]|0;s=e;return n|0}return 0}function yk(e){e=e|0;var i=0,r=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if(!(t[r>>2]|0)){s=i;return}if(t[(t[r>>2]|0)+8>>2]|0)Yk(t[(t[r>>2]|0)+8>>2]|0);if(t[(t[r>>2]|0)+32>>2]|0)Gk(t[(t[r>>2]|0)+32>>2]|0);if(t[(t[r>>2]|0)+36>>2]|0)pAi[t[135736>>2]&511](t[(t[r>>2]|0)+36>>2]|0);pAi[t[135736>>2]&511](t[r>>2]|0);s=i;return}function Fk(e){e=e|0;var i=0,r=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if(!(t[r>>2]|0)){s=i;return}if(t[(t[r>>2]|0)+32>>2]|0)MD(t[(t[r>>2]|0)+32>>2]|0);if(t[(t[r>>2]|0)+36>>2]|0)fb(t[(t[r>>2]|0)+36>>2]|0);if(t[(t[r>>2]|0)+16>>2]|0)Yk(t[(t[r>>2]|0)+16>>2]|0);pAi[t[135736>>2]&511](t[r>>2]|0);s=i;return}function Ok(e){e=e|0;var i=0,r=0,n=0,f=0,u=0,a=0;i=s;s=s+32|0;r=i+16|0;n=i+12|0;f=i+8|0;u=i+4|0;a=i;t[r>>2]=e;if(!(t[r>>2]|0)){s=i;return}if(t[(t[r>>2]|0)+24>>2]|0)Yk(t[(t[r>>2]|0)+24>>2]|0);e:do if(t[(t[r>>2]|0)+68>>2]|0){t[n>>2]=t[(t[r>>2]|0)+68>>2];while(1){if(!(t[n>>2]|0))break e;t[f>>2]=t[(t[n>>2]|0)+4>>2];Fk(t[n>>2]|0);t[n>>2]=t[f>>2]}}while(0);if(t[(t[r>>2]|0)+116>>2]|0)Wk(t[(t[r>>2]|0)+116>>2]|0);if(t[(t[r>>2]|0)+92>>2]|0)Kk(t[(t[r>>2]|0)+92>>2]|0);if(t[(t[r>>2]|0)+96>>2]|0){t[a>>2]=t[(t[r>>2]|0)+96>>2];do{t[u>>2]=t[t[a>>2]>>2];pAi[t[135736>>2]&511](t[a>>2]|0);t[a>>2]=t[u>>2]}while((t[a>>2]|0)!=0)}if(t[(t[r>>2]|0)+108>>2]|0)fb(t[(t[r>>2]|0)+108>>2]|0);pAi[t[135736>>2]&511](t[r>>2]|0);s=i;return}function Ak(e){e=e|0;var i=0,r=0,n=0,f=0,u=0,a=0;i=s;s=s+32|0;r=i;n=i+16|0;f=i+12|0;u=i+8|0;t[n>>2]=e;if(!(t[n>>2]|0)){s=i;return}if(t[(t[n>>2]|0)+80>>2]|0){e=t[33976]|0;a=t[33980]|0;t[r>>2]=140328;t[r+4>>2]=4118;yAi[e&511](a,140296,r)}if(t[(t[n>>2]|0)+44>>2]|0)XF(t[(t[n>>2]|0)+44>>2]|0,0);if(t[(t[n>>2]|0)+32>>2]|0)XF(t[(t[n>>2]|0)+32>>2]|0,0);if(t[(t[n>>2]|0)+36>>2]|0)XF(t[(t[n>>2]|0)+36>>2]|0,0);if(t[(t[n>>2]|0)+40>>2]|0)XF(t[(t[n>>2]|0)+40>>2]|0,0);if(t[(t[n>>2]|0)+28>>2]|0)XF(t[(t[n>>2]|0)+28>>2]|0,0);if(t[(t[n>>2]|0)+56>>2]|0)XF(t[(t[n>>2]|0)+56>>2]|0,0);if(t[(t[n>>2]|0)+76>>2]|0)XF(t[(t[n>>2]|0)+76>>2]|0,0);if(t[(t[n>>2]|0)+48>>2]|0)XF(t[(t[n>>2]|0)+48>>2]|0,322);if(t[(t[n>>2]|0)+64>>2]|0){t[f>>2]=t[(t[n>>2]|0)+64>>2];t[u>>2]=0;while(1){if((t[u>>2]|0)>=(t[(t[f>>2]|0)+4>>2]|0))break;Xk(t[(t[t[f>>2]>>2]|0)+(t[u>>2]<<2)>>2]|0);t[u>>2]=(t[u>>2]|0)+1}Wk(t[f>>2]|0)}if(t[(t[n>>2]|0)+20>>2]|0)Yk(t[(t[n>>2]|0)+20>>2]|0);bz(t[(t[n>>2]|0)+60>>2]|0);pAi[t[135736>>2]&511](t[n>>2]|0);s=i;return}function Mk(e){e=e|0;var i=0,r=0,n=0,f=0,u=0;i=s;s=s+16|0;r=i+8|0;n=i+4|0;f=i;t[n>>2]=e;if(!(t[n>>2]|0)){t[r>>2]=0;u=t[r>>2]|0;s=i;return u|0}t[f>>2]=Zk()|0;if(!(t[f>>2]|0)){t[r>>2]=0;u=t[r>>2]|0;s=i;return u|0}else{e=lz()|0;t[(t[f>>2]|0)+80>>2]=e;e=kz(t[(t[f>>2]|0)+80>>2]|0,t[n>>2]|0,-1)|0;t[(t[f>>2]|0)+44>>2]=e;t[r>>2]=t[f>>2];u=t[r>>2]|0;s=i;return u|0}return 0}function Rk(e){e=e|0;var i=0,r=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if(!(t[r>>2]|0)){s=i;return}if((t[(t[r>>2]|0)+48>>2]|0)!=0?(t[(t[r>>2]|0)+52>>2]|0)==0:0)fy(t[(t[r>>2]|0)+48>>2]|0);if(t[(t[r>>2]|0)+92>>2]|0)Nk(t[(t[r>>2]|0)+92>>2]|0);if((t[(t[r>>2]|0)+32>>2]|0)!=0?(t[(t[r>>2]|0)+28>>2]|0)!=0:0){Jk(t[(t[r>>2]|0)+28>>2]|0);t[(t[r>>2]|0)+28>>2]=0;t[(t[r>>2]|0)+32>>2]=0}if(t[(t[r>>2]|0)+128>>2]|0)Wk(t[(t[r>>2]|0)+128>>2]|0);bz(t[(t[r>>2]|0)+80>>2]|0);pAi[t[135736>>2]&511](t[r>>2]|0);s=i;return}function Nk(e){e=e|0;var i=0,r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0;i=s;s=s+48|0;r=i+36|0;n=i+32|0;f=i+28|0;u=i+24|0;a=i+20|0;o=i+16|0;c=i+12|0;l=i+8|0;b=i+4|0;k=i;t[r>>2]=e;if(!(t[r>>2]|0)){s=i;return}if(t[(t[r>>2]|0)+72>>2]|0)MD(t[(t[r>>2]|0)+72>>2]|0);if(t[(t[r>>2]|0)+88>>2]|0)Rk(t[(t[r>>2]|0)+88>>2]|0);if(t[(t[r>>2]|0)+128>>2]|0){t[n>>2]=0;while(1){if((t[n>>2]|0)>=(t[(t[r>>2]|0)+132>>2]|0))break;t[f>>2]=t[(t[(t[r>>2]|0)+128>>2]|0)+(t[n>>2]<<2)>>2];pAi[t[135736>>2]&511](t[(t[f>>2]|0)+4>>2]|0);pAi[t[135736>>2]&511](t[f>>2]|0);t[n>>2]=(t[n>>2]|0)+1}pAi[t[135736>>2]&511](t[(t[r>>2]|0)+128>>2]|0)}if(t[(t[r>>2]|0)+140>>2]|0){t[u>>2]=0;while(1){if((t[u>>2]|0)>=(t[(t[r>>2]|0)+144>>2]|0))break;Qk(t[(t[(t[r>>2]|0)+140>>2]|0)+(t[u>>2]<<2)>>2]|0);t[u>>2]=(t[u>>2]|0)+1}pAi[t[135736>>2]&511](t[(t[r>>2]|0)+140>>2]|0)}if(t[(t[r>>2]|0)+116>>2]|0){$k(t[(t[r>>2]|0)+116>>2]|0);t[(t[r>>2]|0)+116>>2]=0}if(t[(t[r>>2]|0)+120>>2]|0){$k(t[(t[r>>2]|0)+120>>2]|0);t[(t[r>>2]|0)+120>>2]=0}if(t[(t[r>>2]|0)+112>>2]|0){t[a>>2]=t[(t[r>>2]|0)+112>>2];do{t[o>>2]=t[t[a>>2]>>2];pAi[t[135736>>2]&511](t[a>>2]|0);t[a>>2]=t[o>>2]}while((t[a>>2]|0)!=0)}if(t[(t[r>>2]|0)+164>>2]|0){if(t[(t[r>>2]|0)+168>>2]|0)eh(t[r>>2]|0);t[c>>2]=0;while(1){if((t[c>>2]|0)>=(t[(t[r>>2]|0)+172>>2]|0))break;t[l>>2]=t[(t[(t[r>>2]|0)+164>>2]|0)+(t[c>>2]<<2)>>2];pAi[t[135736>>2]&511](t[l>>2]|0);t[c>>2]=(t[c>>2]|0)+1}pAi[t[135736>>2]&511](t[(t[r>>2]|0)+164>>2]|0)}if(t[(t[r>>2]|0)+100>>2]|0){t[b>>2]=0;while(1){if((t[b>>2]|0)>=(t[(t[r>>2]|0)+104>>2]|0))break;t[k>>2]=t[(t[(t[r>>2]|0)+100>>2]|0)+(t[b>>2]<<2)>>2];if(!(t[k>>2]|0))break;ih(t[r>>2]|0,t[k>>2]|0);pAi[t[135736>>2]&511](t[k>>2]|0);t[b>>2]=(t[b>>2]|0)+1}pAi[t[135736>>2]&511](t[(t[r>>2]|0)+100>>2]|0)}if(t[(t[r>>2]|0)+180>>2]|0)Wk(t[(t[r>>2]|0)+180>>2]|0);if(t[(t[r>>2]|0)+156>>2]|0)bz(t[(t[r>>2]|0)+156>>2]|0);if(t[(t[r>>2]|0)+48>>2]|0)pAi[t[135736>>2]&511](t[(t[r>>2]|0)+48>>2]|0);pAi[t[135736>>2]&511](t[r>>2]|0);s=i;return}function Tk(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0;f=s;s=s+48|0;u=f;a=f+40|0;o=f+36|0;c=f+32|0;l=f+28|0;b=f+20|0;k=f+16|0;h=f+12|0;w=f+8|0;t[o>>2]=e;t[c>>2]=i;t[l>>2]=r;t[f+24>>2]=n;t[b>>2]=0;if((t[o>>2]|0)==0|(t[c>>2]|0)==0){t[a>>2]=-1;d=t[a>>2]|0;s=f;return d|0}if(!(t[l>>2]|0))t[k>>2]=0;else t[k>>2]=1;e:do switch(t[t[o>>2]>>2]|0){case 1007:case 1003:case 1002:case 1001:case 1e3:{n=t[c>>2]|0;if((t[t[c>>2]>>2]|0)!=1){t[h>>2]=t[n+64>>2];if(!(t[h>>2]|0)){rh(t[l>>2]|0,140360,140384);t[a>>2]=-1;d=t[a>>2]|0;s=f;return d|0}}else t[h>>2]=n;if((t[k>>2]|0)==0?(t[l>>2]=Mk(140432)|0,(t[l>>2]|0)==0):0){t[a>>2]=-1;d=t[a>>2]|0;s=f;return d|0}t[b>>2]=nh(t[l>>2]|0,t[(t[o>>2]|0)+20>>2]|0,t[h>>2]|0,t[(t[o>>2]|0)+8>>2]|0,(t[o>>2]|0)+32|0,1,1,0)|0;if(!(t[b>>2]|0)){if(t[(t[o>>2]|0)+32>>2]|0){v=45;break e}if(t[k>>2]|0)rh(t[l>>2]|0,140360,140632);n=t[33976]|0;r=t[33980]|0;t[u>>2]=140328;t[u+4>>2]=18739;yAi[n&511](r,140296,u);v=45;break e}if((t[b>>2]|0)<0){if(!(t[k>>2]|0)){v=48;break e}r=t[l>>2]|0;n=t[(t[o>>2]|0)+20>>2]|0;i=t[(t[o>>2]|0)+8>>2]|0;th(r,3069,n,0,140440,i,fh(t[t[o>>2]>>2]|0)|0);v=48;break e}t[b>>2]=1717;if((t[k>>2]|0)!=0?(t[w>>2]=0,i=t[l>>2]|0,n=t[b>>2]|0,r=t[(t[o>>2]|0)+20>>2]|0,e=t[o>>2]|0,m=t[(t[o>>2]|0)+8>>2]|0,th(i,n,r,e,140552,m,uh(w,t[(t[h>>2]|0)+112>>2]|0,t[(t[h>>2]|0)+8>>2]|0)|0),(t[w>>2]|0)!=0):0){pAi[t[135736>>2]&511](t[w>>2]|0);t[w>>2]=0;v=45}else v=45;break}case 1011:case 1010:case 1009:case 1005:case 1004:{if((t[t[o>>2]>>2]|0)==1004){m=ED(34)|0;t[b>>2]=CD(m,t[(t[o>>2]|0)+8>>2]|0,(t[o>>2]|0)+32|0)|0}else{m=ED(33)|0;t[b>>2]=CD(m,t[(t[o>>2]|0)+8>>2]|0,(t[o>>2]|0)+32|0)|0}if(t[b>>2]|0)if((t[b>>2]|0)<0){if(!(t[k>>2]|0)){v=48;break e}rh(t[l>>2]|0,140360,140728);v=48;break e}else{t[b>>2]=1717;if(!(t[k>>2]|0)){v=45;break e}m=t[l>>2]|0;e=t[b>>2]|0;r=t[(t[o>>2]|0)+20>>2]|0;n=t[c>>2]|0;i=t[(t[o>>2]|0)+8>>2]|0;_=fh(t[t[o>>2]>>2]|0)|0;ah(m,e,r,n,140752,i,_,(t[t[o>>2]>>2]|0)!=1004?140808:140832,0);v=45;break e}else v=45;break}case 1006:{_=$s(t[(t[o>>2]|0)+8>>2]|0)|0;t[(t[o>>2]|0)+36>>2]=_;if((t[(t[o>>2]|0)+36>>2]|0)==0?(t[b>>2]=1756,(t[k>>2]|0)!=0):0){th(t[l>>2]|0,t[b>>2]|0,t[(t[o>>2]|0)+20>>2]|0,t[c>>2]|0,140656,t[(t[o>>2]|0)+8>>2]|0,0);v=45}else v=45;break}case 1008:{_=(Xl(t[(t[o>>2]|0)+8>>2]|0,140848)|0)!=0;i=t[o>>2]|0;if(_){t[i+28>>2]=1;v=45;break e}_=(Xl(t[i+8>>2]|0,140864)|0)!=0;i=t[o>>2]|0;if(_){t[i+28>>2]=2;v=45;break e}if(Xl(t[i+8>>2]|0,140872)|0){t[(t[o>>2]|0)+28>>2]=3;v=45;break e}t[b>>2]=1717;if(t[k>>2]|0){th(t[l>>2]|0,t[b>>2]|0,t[(t[o>>2]|0)+20>>2]|0,t[c>>2]|0,140888,t[(t[o>>2]|0)+8>>2]|0,0);v=45}else v=45;break}default:v=45}while(0);if((v|0)==45){if((t[k>>2]|0)==0&(t[l>>2]|0)!=0)Rk(t[l>>2]|0);t[a>>2]=t[b>>2];d=t[a>>2]|0;s=f;return d|0}else if((v|0)==48){if((t[k>>2]|0)==0&(t[l>>2]|0)!=0)Rk(t[l>>2]|0);t[a>>2]=-1;d=t[a>>2]|0;s=f;return d|0}return 0}function Lk(e){e=e|0;var i=0,r=0,n=0,f=0,u=0,a=0,o=0,c=0;i=s;s=s+32|0;r=i+16|0;n=i+12|0;f=i+8|0;u=i+4|0;a=i;t[n>>2]=e;t[f>>2]=0;t[u>>2]=0;mD();if(!(t[n>>2]|0)){t[r>>2]=0;o=t[r>>2]|0;s=i;return o|0}t[(t[n>>2]|0)+20>>2]=0;t[(t[n>>2]|0)+16>>2]=0;t[(t[n>>2]|0)+40>>2]=0;t[f>>2]=oh(t[n>>2]|0)|0;e:do if(t[f>>2]|0){do if(!(t[(t[n>>2]|0)+28>>2]|0)){e=ch(t[(t[n>>2]|0)+80>>2]|0)|0;t[(t[n>>2]|0)+28>>2]=e;if(t[(t[n>>2]|0)+28>>2]|0){t[(t[n>>2]|0)+32>>2]=1;break}t[r>>2]=0;o=t[r>>2]|0;s=i;return o|0}while(0);t[t[(t[n>>2]|0)+28>>2]>>2]=t[f>>2];t[a>>2]=lh(t[n>>2]|0,0,t[(t[n>>2]|0)+44>>2]|0,t[(t[n>>2]|0)+48>>2]|0,t[(t[n>>2]|0)+56>>2]|0,t[(t[n>>2]|0)+60>>2]|0,0,0,0,u)|0;if((t[a>>2]|0)!=-1){do if(!(t[a>>2]|0)){e=t[n>>2]|0;if(!(t[u>>2]|0)){c=t[n>>2]|0;if(t[e+44>>2]|0){th(c,1757,0,0,140944,t[(t[n>>2]|0)+44>>2]|0,0);break}else{th(c,1757,0,0,141e3,0,0);break}}else{if((sh(e,t[f>>2]|0,t[u>>2]|0)|0)==-1)break e;if(t[(t[n>>2]|0)+20>>2]|0)break;t[(t[f>>2]|0)+16>>2]=t[(t[u>>2]|0)+20>>2];t[(t[f>>2]|0)+68>>2]=t[(t[n>>2]|0)+52>>2];t[(t[n>>2]|0)+36>>2]=t[f>>2];if((bh(t[n>>2]|0,t[(t[(t[n>>2]|0)+28>>2]|0)+4>>2]|0)|0)==-1)break e;else break}}while(0);if(t[(t[n>>2]|0)+20>>2]|0){if(t[f>>2]|0){Ak(t[f>>2]|0);t[f>>2]=0}if(t[(t[n>>2]|0)+28>>2]|0){Jk(t[(t[n>>2]|0)+28>>2]|0);t[(t[n>>2]|0)+28>>2]=0;t[(t[n>>2]|0)+32>>2]=0}}t[(t[n>>2]|0)+36>>2]=0;t[r>>2]=t[f>>2];o=t[r>>2]|0;s=i;return o|0}}while(0);if(t[f>>2]|0){Ak(t[f>>2]|0);t[f>>2]=0}if(t[(t[n>>2]|0)+28>>2]|0){Jk(t[(t[n>>2]|0)+28>>2]|0);t[(t[n>>2]|0)+28>>2]=0;t[(t[n>>2]|0)+32>>2]=0}rh(t[n>>2]|0,141048,141064);t[(t[n>>2]|0)+36>>2]=0;t[r>>2]=0;o=t[r>>2]|0;s=i;return o|0}function Dk(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,u=0,a=0,o=0,c=0;f=s;s=s+16|0;u=f+12|0;a=f+8|0;o=f+4|0;c=f;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;t[c>>2]=n;if(!(t[u>>2]|0)){s=f;return}t[(t[u>>2]|0)+8>>2]=t[a>>2];t[(t[u>>2]|0)+12>>2]=t[o>>2];t[(t[u>>2]|0)+4>>2]=t[c>>2];if(!(t[(t[u>>2]|0)+92>>2]|0)){s=f;return}Ck(t[(t[u>>2]|0)+92>>2]|0,t[a>>2]|0,t[o>>2]|0,t[c>>2]|0);s=f;return}function Ck(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,u=0,a=0,o=0,c=0;f=s;s=s+16|0;u=f+12|0;a=f+8|0;o=f+4|0;c=f;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;t[c>>2]=n;if(!(t[u>>2]|0)){s=f;return}t[(t[u>>2]|0)+8>>2]=t[a>>2];t[(t[u>>2]|0)+12>>2]=t[o>>2];t[(t[u>>2]|0)+4>>2]=t[c>>2];if(!(t[(t[u>>2]|0)+88>>2]|0)){s=f;return}Dk(t[(t[u>>2]|0)+88>>2]|0,t[a>>2]|0,t[o>>2]|0,t[c>>2]|0);s=f;return}function Pk(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0;n=s;s=s+16|0;f=n+8|0;u=n+4|0;a=n;t[f>>2]=e;t[u>>2]=i;t[a>>2]=r;if(!(t[f>>2]|0)){s=n;return}t[(t[f>>2]|0)+24>>2]=t[u>>2];t[(t[f>>2]|0)+4>>2]=t[a>>2];if(!(t[(t[f>>2]|0)+92>>2]|0)){s=n;return}Bk(t[(t[f>>2]|0)+92>>2]|0,t[u>>2]|0,t[a>>2]|0);s=n;return}function Bk(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0;n=s;s=s+16|0;f=n+8|0;u=n+4|0;a=n;t[f>>2]=e;t[u>>2]=i;t[a>>2]=r;if(!(t[f>>2]|0)){s=n;return}t[(t[f>>2]|0)+16>>2]=t[u>>2];t[(t[f>>2]|0)+8>>2]=0;t[(t[f>>2]|0)+12>>2]=0;t[(t[f>>2]|0)+4>>2]=t[a>>2];if(!(t[(t[f>>2]|0)+88>>2]|0)){s=n;return}Pk(t[(t[f>>2]|0)+88>>2]|0,t[u>>2]|0,t[a>>2]|0);s=n;return}function Ik(e){e=e|0;var i=0,r=0,n=0,f=0,u=0;i=s;s=s+16|0;r=i+8|0;n=i+4|0;f=i;t[n>>2]=e;t[f>>2]=gAi[t[135744>>2]&511](204)|0;if(!(t[f>>2]|0)){kh(0,141096,0);t[r>>2]=0;u=t[r>>2]|0;s=i;return u|0}else{VY(t[f>>2]|0,0,204)|0;t[t[f>>2]>>2]=2;e=lz()|0;t[(t[f>>2]|0)+156>>2]=e;e=hh()|0;t[(t[f>>2]|0)+180>>2]=e;t[(t[f>>2]|0)+20>>2]=t[n>>2];t[r>>2]=t[f>>2];u=t[r>>2]|0;s=i;return u|0}return 0}function Hk(e,i){e=e|0;i=i|0;var r=0,n=0,f=0;r=s;s=s+16|0;n=r+4|0;f=r;t[n>>2]=e;t[f>>2]=i;if(!(t[n>>2]|0)){s=r;return}if(t[(t[n>>2]|0)+48>>2]|0)pAi[t[135736>>2]&511](t[(t[n>>2]|0)+48>>2]|0);if(t[f>>2]|0){i=Yl(t[f>>2]|0)|0;t[(t[n>>2]|0)+48>>2]=i;s=r;return}else{t[(t[n>>2]|0)+48>>2]=0;s=r;return}}function xk(e){e=e|0;var i=0,r=0,n=0,f=0;i=s;s=s+16|0;r=i+4|0;n=i;t[n>>2]=e;if(!(t[n>>2]|0)){t[r>>2]=-1;f=t[r>>2]|0;s=i;return f|0}else{t[r>>2]=(t[(t[n>>2]|0)+52>>2]|0)==0&1;f=t[r>>2]|0;s=i;return f|0}return 0}function Uk(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0;r=s;s=s+16|0;n=r+8|0;f=r+4|0;u=r;t[f>>2]=e;t[u>>2]=i;if((t[f>>2]|0)==0|(t[u>>2]|0)==0){t[n>>2]=-1;a=t[n>>2]|0;s=r;return a|0}t[(t[f>>2]|0)+24>>2]=t[u>>2];i=eF(t[u>>2]|0)|0;t[(t[f>>2]|0)+60>>2]=i;i=t[f>>2]|0;if(!(t[(t[f>>2]|0)+60>>2]|0)){th(i,1872,t[u>>2]|0,0,141128,0,0);t[n>>2]=t[(t[f>>2]|0)+52>>2];a=t[n>>2]|0;s=r;return a|0}else{t[(t[f>>2]|0)+84>>2]=t[i+60>>2];t[n>>2]=wh(t[f>>2]|0)|0;a=t[n>>2]|0;s=r;return a|0}return 0}function zk(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0;n=s;s=s+32|0;f=n+20|0;u=n+16|0;a=n+12|0;o=n+8|0;c=n+4|0;l=n;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;if((t[u>>2]|0)==0|(t[a>>2]|0)==0|(t[o>>2]|0)==0){t[f>>2]=0;b=t[f>>2]|0;s=n;return b|0}t[l>>2]=t[t[a>>2]>>2];if((t[l>>2]|0)!=0?(t[(t[l>>2]|0)+108>>2]|0)!=-554844497:0){t[f>>2]=0;b=t[f>>2]|0;s=n;return b|0}do if(((t[l>>2]|0)!=0?(t[(t[l>>2]|0)+116>>2]|0)==0:0)?(t[(t[l>>2]|0)+120>>2]|0)==0:0){if((t[(t[l>>2]|0)+56>>2]|0)==0?(t[(t[l>>2]|0)+60>>2]|0)==0:0)break;t[f>>2]=0;b=t[f>>2]|0;s=n;return b|0}while(0);t[c>>2]=gAi[t[135744>>2]&511](152)|0;if(!(t[c>>2]|0)){t[f>>2]=0;b=t[f>>2]|0;s=n;return b|0}VY(t[c>>2]|0,0,152)|0;t[t[c>>2]>>2]=-599541215;t[(t[c>>2]|0)+128>>2]=-554844497;t[(t[c>>2]|0)+148>>2]=t[u>>2];t[(t[c>>2]|0)+4>>2]=t[a>>2];t[(t[c>>2]|0)+8>>2]=t[l>>2];if(!(t[l>>2]|0)){t[(t[c>>2]|0)+136>>2]=323;t[(t[c>>2]|0)+140>>2]=324;t[(t[c>>2]|0)+92>>2]=325;t[(t[c>>2]|0)+88>>2]=325;t[(t[c>>2]|0)+120>>2]=326;t[(t[c>>2]|0)+84>>2]=327;t[(t[c>>2]|0)+16>>2]=t[u>>2];t[t[o>>2]>>2]=t[u>>2]}else{if(t[t[l>>2]>>2]|0)t[(t[c>>2]|0)+20>>2]=328;if(t[(t[l>>2]|0)+4>>2]|0)t[(t[c>>2]|0)+24>>2]=329;if(t[(t[l>>2]|0)+8>>2]|0)t[(t[c>>2]|0)+28>>2]=330;if(t[(t[l>>2]|0)+12>>2]|0)t[(t[c>>2]|0)+32>>2]=331;if(t[(t[l>>2]|0)+16>>2]|0)t[(t[c>>2]|0)+36>>2]=332;if(t[(t[l>>2]|0)+20>>2]|0)t[(t[c>>2]|0)+40>>2]=333;if(t[(t[l>>2]|0)+24>>2]|0)t[(t[c>>2]|0)+44>>2]=334;if(t[(t[l>>2]|0)+28>>2]|0)t[(t[c>>2]|0)+48>>2]=335;if(t[(t[l>>2]|0)+32>>2]|0)t[(t[c>>2]|0)+52>>2]=336;if(t[(t[l>>2]|0)+36>>2]|0)t[(t[c>>2]|0)+56>>2]=337;if(t[(t[l>>2]|0)+40>>2]|0)t[(t[c>>2]|0)+60>>2]=338;if(t[(t[l>>2]|0)+44>>2]|0)t[(t[c>>2]|0)+64>>2]=339;if(t[(t[l>>2]|0)+48>>2]|0)t[(t[c>>2]|0)+68>>2]=340;if(t[(t[l>>2]|0)+52>>2]|0)t[(t[c>>2]|0)+72>>2]=341;if(t[(t[l>>2]|0)+76>>2]|0)t[(t[c>>2]|0)+96>>2]=342;if(t[(t[l>>2]|0)+80>>2]|0)t[(t[c>>2]|0)+100>>2]=343;if(t[(t[l>>2]|0)+84>>2]|0)t[(t[c>>2]|0)+104>>2]=344;if(t[(t[l>>2]|0)+88>>2]|0)t[(t[c>>2]|0)+108>>2]=345;if(t[(t[l>>2]|0)+92>>2]|0)t[(t[c>>2]|0)+112>>2]=346;if(t[(t[l>>2]|0)+96>>2]|0)t[(t[c>>2]|0)+116>>2]=347;if(t[(t[l>>2]|0)+104>>2]|0)t[(t[c>>2]|0)+124>>2]=348;t[(t[c>>2]|0)+88>>2]=349;do if(t[(t[l>>2]|0)+72>>2]|0){if((t[(t[l>>2]|0)+72>>2]|0)==(t[(t[l>>2]|0)+68>>2]|0)){k=61;break}t[(t[c>>2]|0)+92>>2]=350}else k=61;while(0);if((k|0)==61)t[(t[c>>2]|0)+92>>2]=349;t[(t[c>>2]|0)+120>>2]=351;t[(t[c>>2]|0)+84>>2]=352;t[(t[c>>2]|0)+136>>2]=353;t[(t[c>>2]|0)+140>>2]=354;t[(t[c>>2]|0)+12>>2]=t[o>>2];t[(t[c>>2]|0)+16>>2]=t[t[o>>2]>>2];t[t[o>>2]>>2]=t[c>>2]}t[t[a>>2]>>2]=(t[c>>2]|0)+20;t[(t[u>>2]|0)+36>>2]=t[t[a>>2]>>2];a=(t[u>>2]|0)+152|0;t[a>>2]=t[a>>2]|1;Kh(t[u>>2]|0)|0;t[f>>2]=t[c>>2];b=t[f>>2]|0;s=n;return b|0}function jk(e){e=e|0;var i=0,r=0,n=0,f=0,u=0,a=0;i=s;s=s+16|0;r=i+12|0;n=i+8|0;f=i+4|0;u=i;t[n>>2]=e;if((t[n>>2]|0)!=0?(t[t[n>>2]>>2]|0)==-599541215:0){t[t[n>>2]>>2]=0;Xh(t[(t[n>>2]|0)+148>>2]|0);t[f>>2]=t[(t[n>>2]|0)+4>>2];t[t[f>>2]>>2]=t[(t[n>>2]|0)+8>>2];if(t[(t[n>>2]|0)+8>>2]|0){t[u>>2]=t[(t[n>>2]|0)+12>>2];t[t[u>>2]>>2]=t[(t[n>>2]|0)+16>>2]}pAi[t[135736>>2]&511](t[n>>2]|0);t[r>>2]=0;a=t[r>>2]|0;s=i;return a|0}t[r>>2]=-1;a=t[r>>2]|0;s=i;return a|0}function Vk(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0;n=s;s=s+16|0;f=n+8|0;u=n+4|0;a=n;t[f>>2]=e;t[u>>2]=i;t[a>>2]=r;if(!(t[f>>2]|0)){s=n;return}t[(t[f>>2]|0)+196>>2]=t[u>>2];t[(t[f>>2]|0)+200>>2]=t[a>>2];s=n;return}function qk(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;var u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0;u=s;s=s+48|0;a=u+40|0;o=u+36|0;c=u+32|0;l=u+28|0;b=u+24|0;k=u+20|0;h=u+16|0;w=u+12|0;d=u+8|0;v=u+4|0;m=u;t[o>>2]=e;t[c>>2]=i;t[l>>2]=r;t[b>>2]=n;t[k>>2]=f;t[h>>2]=0;t[w>>2]=0;t[d>>2]=0;t[v>>2]=0;if((t[o>>2]|0)==0|(t[c>>2]|0)==0){t[a>>2]=-1;_=t[a>>2]|0;s=u;return _|0}t[d>>2]=zp()|0;if(!(t[d>>2]|0)){t[a>>2]=-1;_=t[a>>2]|0;s=u;return _|0}t[w>>2]=t[t[d>>2]>>2];t[t[d>>2]>>2]=t[b>>2];t[(t[d>>2]|0)+4>>2]=t[k>>2];t[(t[d>>2]|0)+280>>2]=1;Vk(t[o>>2]|0,355,t[d>>2]|0);t[v>>2]=Pp(t[d>>2]|0,t[c>>2]|0,t[l>>2]|0)|0;do if(t[v>>2]|0){eE(t[d>>2]|0,t[v>>2]|0)|0;t[(t[o>>2]|0)+40>>2]=t[d>>2];t[(t[o>>2]|0)+28>>2]=t[c>>2];t[h>>2]=zk(t[o>>2]|0,t[d>>2]|0,(t[d>>2]|0)+4|0)|0;if(!(t[h>>2]|0)){t[m>>2]=-1;break}t[(t[o>>2]|0)+28>>2]=t[c>>2];t[(t[o>>2]|0)+32>>2]=t[l>>2];t[(t[o>>2]|0)+36>>2]=t[t[d>>2]>>2];k=(t[o>>2]|0)+152|0;t[k>>2]=t[k>>2]|1;t[m>>2]=wh(t[o>>2]|0)|0;if((t[m>>2]|0)==0?(t[(t[(t[o>>2]|0)+40>>2]|0)+12>>2]|0)==0:0){k=t[(t[(t[o>>2]|0)+40>>2]|0)+84>>2]|0;t[m>>2]=k;t[m>>2]=(t[m>>2]|0)==0?1:k}}else t[m>>2]=-1;while(0);t[(t[o>>2]|0)+40>>2]=0;t[(t[o>>2]|0)+36>>2]=0;t[(t[o>>2]|0)+28>>2]=0;if(t[h>>2]|0)jk(t[h>>2]|0)|0;if(t[d>>2]|0){t[t[d>>2]>>2]=t[w>>2];Up(t[d>>2]|0)}t[a>>2]=t[m>>2];_=t[a>>2]|0;s=u;return _|0}function Yk(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i+4|0;n=i;t[r>>2]=e;if(!(t[r>>2]|0)){s=i;return}if(!(t[t[r>>2]>>2]|0)){pAi[t[135736>>2]&511](t[r>>2]|0);s=i;return}else{do{t[n>>2]=t[r>>2];t[r>>2]=t[t[r>>2]>>2];pAi[t[135736>>2]&511](t[n>>2]|0)}while((t[r>>2]|0)!=0);s=i;return}}function Gk(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i+4|0;n=i;t[r>>2]=e;while(1){if(!(t[r>>2]|0))break;t[n>>2]=t[t[r>>2]>>2];pAi[t[135736>>2]&511](t[r>>2]|0);t[r>>2]=t[n>>2]}s=i;return}function Wk(e){e=e|0;var i=0,r=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if(!(t[r>>2]|0)){s=i;return}if(t[t[r>>2]>>2]|0)pAi[t[135736>>2]&511](t[t[r>>2]>>2]|0);pAi[t[135736>>2]&511](t[r>>2]|0);s=i;return}function Kk(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i+4|0;n=i;t[r>>2]=e;while(1){if(!(t[r>>2]|0))break;t[n>>2]=t[t[r>>2]>>2];pAi[t[135736>>2]&511](t[r>>2]|0);t[r>>2]=t[n>>2]}s=i;return}function Xk(e){e=e|0;var i=0,r=0,n=0,f=0;i=s;s=s+16|0;r=i+8|0;n=i+4|0;f=i;t[r>>2]=e;if(!(t[r>>2]|0)){s=i;return}if(t[(t[r>>2]|0)+44>>2]|0){Jh(t[(t[r>>2]|0)+44>>2]|0);Wk(t[(t[r>>2]|0)+44>>2]|0)}if(t[(t[r>>2]|0)+48>>2]|0){Jh(t[(t[r>>2]|0)+48>>2]|0);Wk(t[(t[r>>2]|0)+48>>2]|0)}if(t[(t[r>>2]|0)+24>>2]|0){t[f>>2]=t[(t[r>>2]|0)+24>>2];do{t[n>>2]=t[f>>2];t[f>>2]=t[t[f>>2]>>2];pAi[t[135736>>2]&511](t[n>>2]|0)}while((t[f>>2]|0)!=0)}if((t[(t[r>>2]|0)+40>>2]|0)==0?(t[(t[r>>2]|0)+20>>2]|0)!=0:0)fy(t[(t[r>>2]|0)+20>>2]|0);if((t[t[r>>2]>>2]|0)==1?(t[(t[r>>2]|0)+52>>2]|0)!=0:0)Ak(t[(t[r>>2]|0)+52>>2]|0);pAi[t[135736>>2]&511](t[r>>2]|0);s=i;return}function Zk(){var e=0,i=0,r=0,n=0,f=0;e=s;s=s+16|0;i=e+4|0;r=e;t[r>>2]=gAi[t[135744>>2]&511](132)|0;if(!(t[r>>2]|0)){Qh(0,170240,0);t[i>>2]=0;n=t[i>>2]|0;s=e;return n|0}VY(t[r>>2]|0,0,132)|0;t[t[r>>2]>>2]=1;f=hh()|0;t[(t[r>>2]|0)+128>>2]=f;if(!(t[(t[r>>2]|0)+128>>2]|0)){pAi[t[135736>>2]&511](t[r>>2]|0);t[i>>2]=0;n=t[i>>2]|0;s=e;return n|0}else{t[i>>2]=t[r>>2];n=t[i>>2]|0;s=e;return n|0}return 0}function Jk(e){e=e|0;var i=0,r=0,n=0,f=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if(t[(t[r>>2]|0)+12>>2]|0)Wk(t[(t[r>>2]|0)+12>>2]|0);if(t[(t[r>>2]|0)+20>>2]|0)Wk(t[(t[r>>2]|0)+20>>2]|0);if(t[(t[r>>2]|0)+24>>2]|0)XF(t[(t[r>>2]|0)+24>>2]|0,356);if(t[(t[r>>2]|0)+28>>2]|0)ew(t[(t[r>>2]|0)+28>>2]|0);if(!(t[(t[r>>2]|0)+8>>2]|0)){n=t[33934]|0;f=t[r>>2]|0;pAi[n&511](f);s=i;return}bz(t[(t[r>>2]|0)+8>>2]|0);n=t[33934]|0;f=t[r>>2]|0;pAi[n&511](f);s=i;return}function Qk(e){e=e|0;var i=0,r=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if(t[(t[r>>2]|0)+4>>2]|0)MD(t[(t[r>>2]|0)+4>>2]|0);pAi[t[135736>>2]&511](t[r>>2]|0);s=i;return}function $k(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i+4|0;n=i;t[r>>2]=e;while(1){if(!(t[r>>2]|0))break;t[n>>2]=t[(t[r>>2]|0)+4>>2];if(t[(t[r>>2]|0)+12>>2]|0)pAi[t[135736>>2]&511](t[(t[r>>2]|0)+12>>2]|0);if(t[(t[r>>2]|0)+32>>2]|0)_j(t[(t[r>>2]|0)+32>>2]|0);pAi[t[135736>>2]&511](t[r>>2]|0);t[r>>2]=t[n>>2]}s=i;return}function eh(e){e=e|0;var i=0,r=0,n=0,f=0,u=0;i=s;s=s+16|0;r=i+8|0;n=i+4|0;f=i;t[r>>2]=e;if(!(t[(t[r>>2]|0)+168>>2]|0)){s=i;return}t[n>>2]=0;while(1){if((t[n>>2]|0)>=(t[(t[r>>2]|0)+168>>2]|0))break;t[f>>2]=t[(t[(t[r>>2]|0)+164>>2]|0)+(t[n>>2]<<2)>>2];if(t[(t[f>>2]|0)+32>>2]&1){if(t[(t[f>>2]|0)+12>>2]|0)pAi[t[135736>>2]&511](t[(t[f>>2]|0)+12>>2]|0);if(t[(t[f>>2]|0)+16>>2]|0)pAi[t[135736>>2]&511](t[(t[f>>2]|0)+16>>2]|0)}if((t[(t[f>>2]|0)+32>>2]&2|0)!=0?(t[(t[f>>2]|0)+20>>2]|0)!=0:0)pAi[t[135736>>2]&511](t[(t[f>>2]|0)+20>>2]|0);if(t[(t[f>>2]|0)+24>>2]|0){MD(t[(t[f>>2]|0)+24>>2]|0);t[(t[f>>2]|0)+24>>2]=0}e=(t[f>>2]|0)+0|0;u=e+60|0;do{t[e>>2]=0;e=e+4|0}while((e|0)<(u|0));t[n>>2]=(t[n>>2]|0)+1}t[(t[r>>2]|0)+168>>2]=0;s=i;return}function ih(e,i){e=e|0;i=i|0;var r=0,n=0,f=0;r=s;s=s+16|0;n=r+4|0;f=r;t[n>>2]=e;t[f>>2]=i;t[(t[f>>2]|0)+76>>2]=0;t[(t[f>>2]|0)+80>>2]=0;i=(t[f>>2]|0)+12|0;if(t[(t[f>>2]|0)+32>>2]&1){if(t[i>>2]|0){pAi[t[135736>>2]&511](t[(t[f>>2]|0)+12>>2]|0);t[(t[f>>2]|0)+12>>2]=0}if(t[(t[f>>2]|0)+16>>2]|0){pAi[t[135736>>2]&511](t[(t[f>>2]|0)+16>>2]|0);t[(t[f>>2]|0)+16>>2]=0}}else{t[i>>2]=0;t[(t[f>>2]|0)+16>>2]=0}i=(t[f>>2]|0)+20|0;if(t[(t[f>>2]|0)+32>>2]&2){if(t[i>>2]|0){pAi[t[135736>>2]&511](t[(t[f>>2]|0)+20>>2]|0);t[(t[f>>2]|0)+20>>2]=0}}else t[i>>2]=0;if(t[(t[f>>2]|0)+24>>2]|0){MD(t[(t[f>>2]|0)+24>>2]|0);t[(t[f>>2]|0)+24>>2]=0}if(t[(t[f>>2]|0)+56>>2]|0){iw(t[n>>2]|0,t[(t[f>>2]|0)+56>>2]|0);t[(t[f>>2]|0)+56>>2]=0}if(t[(t[f>>2]|0)+52>>2]|0){rw(t[(t[f>>2]|0)+52>>2]|0);t[(t[f>>2]|0)+52>>2]=0}if(t[(t[f>>2]|0)+60>>2]|0){Ks(t[(t[f>>2]|0)+60>>2]|0);t[(t[f>>2]|0)+60>>2]=0}if(!(t[(t[f>>2]|0)+64>>2]|0)){s=r;return}pAi[t[135736>>2]&511](t[(t[f>>2]|0)+64>>2]|0);t[(t[f>>2]|0)+64>>2]=0;t[(t[f>>2]|0)+68>>2]=0;t[(t[f>>2]|0)+72>>2]=0;s=r;return}function rh(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0;n=s;s=s+16|0;f=n+8|0;u=n+4|0;a=n;t[f>>2]=e;t[u>>2]=i;t[a>>2]=r;nw(t[f>>2]|0,t[u>>2]|0,t[a>>2]|0,0,0);s=n;return}function nh(e,i,r,n,f,a,o,c){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;a=a|0;o=o|0;c=c|0;var l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0,S=0,g=0,y=0,F=0,O=0,A=0,M=0,R=0,N=0,T=0,L=0,D=0,C=0,P=0,B=0,I=0,H=0,x=0,U=0,z=0,j=0;l=s;s=s+96|0;b=l;k=l+92|0;h=l+88|0;w=l+84|0;d=l+80|0;v=l+76|0;m=l+72|0;_=l+68|0;p=l+64|0;E=l+60|0;S=l+56|0;g=l+52|0;y=l+48|0;F=l+44|0;O=l+40|0;A=l+36|0;M=l+32|0;R=l+28|0;N=l+24|0;T=l+20|0;L=l+16|0;D=l+12|0;C=l+8|0;t[h>>2]=e;t[w>>2]=i;t[d>>2]=r;t[v>>2]=n;t[m>>2]=f;t[_>>2]=a;t[p>>2]=o;t[E>>2]=c;t[S>>2]=0;t[g>>2]=(t[m>>2]|0)!=0?1:0;t[y>>2]=0;t[F>>2]=0;if((t[m>>2]|0)!=0?(t[t[m>>2]>>2]|0)!=0:0){MD(t[t[m>>2]>>2]|0);t[t[m>>2]>>2]=0}if((t[g>>2]|0)==0?(t[(t[d>>2]|0)+48>>2]&2097152|0)!=0:0)t[g>>2]=1;if(!(t[v>>2]|0))t[v>>2]=142672;if((t[t[d>>2]>>2]|0)==1?(t[(t[d>>2]|0)+88>>2]|0)==46:0)P=12;else P=11;e:do if((P|0)==11)if(!(t[(t[d>>2]|0)+48>>2]&256)){if(!(t[(t[d>>2]|0)+48>>2]&64)){if(!(t[(t[d>>2]|0)+48>>2]&128))break;t[C>>2]=cw(t[d>>2]|0)|0;if(!(t[C>>2]|0)){rh(t[h>>2]|0,156240,156464);P=149;break}while(1){if(!(t[C>>2]|0))break;c=t[h>>2]|0;o=t[w>>2]|0;a=t[(t[C>>2]|0)+4>>2]|0;f=t[v>>2]|0;if(t[g>>2]|0)t[S>>2]=nh(c,o,a,f,y,0,1,0)|0;else t[S>>2]=nh(c,o,a,f,0,0,1,0)|0;if((t[S>>2]|0)<=0)break;t[C>>2]=t[t[C>>2]>>2]}do if(t[S>>2]|0)if((t[S>>2]|0)<0){rh(t[h>>2]|0,156240,156504);P=149;break e}else{t[S>>2]=1826;break}while(0);do if((t[S>>2]|0)==0?(t[(t[d>>2]|0)+48>>2]&134217728|0)!=0:0){do if(!(t[E>>2]|0)){if((t[p>>2]|0)==0?(t[(t[d>>2]|0)+48>>2]&268435456|0)==0:0)break;t[F>>2]=fw(t[(t[C>>2]|0)+4>>2]|0,t[v>>2]|0)|0;if(t[F>>2]|0)t[v>>2]=t[F>>2];t[E>>2]=1}while(0);t[S>>2]=aw(t[h>>2]|0,t[w>>2]|0,t[d>>2]|0,0,t[v>>2]|0,t[y>>2]|0,0,t[_>>2]|0)|0;if(t[S>>2]|0)if((t[S>>2]|0)<0){rh(t[h>>2]|0,156240,156544);P=149;break e}else{t[S>>2]=1826;break}}while(0);if(!((t[_>>2]|0)!=0&(t[S>>2]|0)>0))break;ow(t[h>>2]|0,t[S>>2]|0,t[w>>2]|0,t[v>>2]|0,t[d>>2]|0,1);break}t[N>>2]=0;t[T>>2]=0;t[L>>2]=0;t[D>>2]=0;do if(!(t[E>>2]|0)){if((t[p>>2]|0)==0?(t[(t[d>>2]|0)+48>>2]&268435456|0)==0:0)break;t[F>>2]=fw(t[d>>2]|0,t[v>>2]|0)|0;if(t[F>>2]|0)t[v>>2]=t[F>>2];t[E>>2]=1}while(0);t[A>>2]=t[(t[d>>2]|0)+28>>2];t[M>>2]=t[v>>2];while(1){do if((u[t[M>>2]>>0]|0|0)==32)B=1;else{if(9<=(u[t[M>>2]>>0]|0|0)?(u[t[M>>2]>>0]|0|0)<=10:0){B=1;break}B=(u[t[M>>2]>>0]|0|0)==13}while(0);f=t[M>>2]|0;if(B){t[M>>2]=f+1;continue}t[R>>2]=f;while(1){if(u[t[R>>2]>>0]|0){do if((u[t[R>>2]>>0]|0|0)==32)I=1;else{if(9<=(u[t[R>>2]>>0]|0|0)?(u[t[R>>2]>>0]|0|0)<=10:0){I=1;break}I=(u[t[R>>2]>>0]|0|0)==13}while(0);H=I^1}else H=0;x=t[R>>2]|0;if(!H)break;t[R>>2]=x+1}if((x|0)==(t[M>>2]|0))break;t[N>>2]=ql(t[M>>2]|0,(t[R>>2]|0)-(t[M>>2]|0)|0)|0;t[T>>2]=(t[T>>2]|0)+1;f=t[h>>2]|0;a=t[w>>2]|0;o=t[A>>2]|0;c=t[N>>2]|0;n=t[_>>2]|0;if(t[g>>2]|0)t[S>>2]=nh(f,a,o,c,D,n,0,1)|0;else t[S>>2]=nh(f,a,o,c,0,n,0,1)|0;if(t[N>>2]|0){pAi[t[135736>>2]&511](t[N>>2]|0);t[N>>2]=0}if(t[D>>2]|0){if(!(t[y>>2]|0))t[y>>2]=t[D>>2];else SD(t[L>>2]|0,t[D>>2]|0)|0;t[L>>2]=t[D>>2];t[D>>2]=0}if(t[S>>2]|0){P=92;break}t[M>>2]=t[R>>2];if(!(u[t[M>>2]>>0]|0))break}do if((P|0)==92)if((t[S>>2]|0)<0){rh(t[h>>2]|0,156240,156384);P=149;break e}else{t[S>>2]=1825;break}while(0);if(t[N>>2]|0){pAi[t[135736>>2]&511](t[N>>2]|0);t[N>>2]=0}do if(((t[S>>2]|0)==0?(t[(t[d>>2]|0)+48>>2]&134217728|0)!=0:0)?(t[S>>2]=aw(t[h>>2]|0,t[w>>2]|0,t[d>>2]|0,0,t[v>>2]|0,t[y>>2]|0,t[T>>2]|0,t[_>>2]|0)|0,(t[S>>2]|0)!=0):0)if((t[S>>2]|0)<0){rh(t[h>>2]|0,156240,156424);P=149;break e}else{t[S>>2]=1825;break}while(0);if((t[_>>2]|0)!=0&(t[S>>2]|0)>0){t[p>>2]=1;do if(!(t[E>>2]|0)){if((t[p>>2]|0)==0?(t[(t[d>>2]|0)+48>>2]&268435456|0)==0:0)break;t[F>>2]=fw(t[d>>2]|0,t[v>>2]|0)|0;if(t[F>>2]|0)t[v>>2]=t[F>>2];t[E>>2]=1}while(0);ow(t[h>>2]|0,t[S>>2]|0,t[w>>2]|0,t[v>>2]|0,t[d>>2]|0,1)}}else P=12;while(0);e:do if((P|0)==12){do if(!(t[E>>2]|0)){if((t[p>>2]|0)==0?(t[(t[d>>2]|0)+48>>2]&268435456|0)==0:0)break;t[F>>2]=fw(t[d>>2]|0,t[v>>2]|0)|0;if(t[F>>2]|0)t[v>>2]=t[F>>2];t[E>>2]=1}while(0);T=t[d>>2]|0;if((t[t[d>>2]>>2]|0)!=1){t[O>>2]=t[T+64>>2];while(1){if(t[O>>2]|0)U=(t[t[O>>2]>>2]|0)!=1;else U=0;z=t[O>>2]|0;if(!U)break;t[O>>2]=t[z+64>>2]}if(!z){rh(t[h>>2]|0,156240,156272);P=149;break}}else t[O>>2]=T;do if((t[t[h>>2]>>2]|0)==2){N=t[(t[O>>2]|0)+88>>2]|0;if((N|0)==21){t[S>>2]=uw(t[h>>2]|0,t[v>>2]|0,y,t[g>>2]|0)|0;break}else if((N|0)!=28){N=t[O>>2]|0;M=t[v>>2]|0;R=t[w>>2]|0;if(t[g>>2]|0){t[S>>2]=DD(N,M,y,R)|0;break}else{t[S>>2]=DD(N,M,0,R)|0;break}}else{t[S>>2]=tw(t[h>>2]|0,t[(t[h>>2]|0)+20>>2]|0,0,t[v>>2]|0,y,t[g>>2]|0)|0;break}}else{if((t[t[h>>2]>>2]|0)!=1){R=t[33976]|0;M=t[33980]|0;t[b>>2]=140328;t[b+4>>2]=24593;yAi[R&511](M,140296,b);P=149;break e}if((t[(t[O>>2]|0)+88>>2]|0)==28){t[S>>2]=tw(0,t[(t[h>>2]|0)+36>>2]|0,t[w>>2]|0,t[v>>2]|0,y,t[g>>2]|0)|0;break}M=t[O>>2]|0;R=t[v>>2]|0;N=t[w>>2]|0;if(t[g>>2]|0){t[S>>2]=DD(M,R,y,N)|0;break}else{t[S>>2]=DD(M,R,0,N)|0;break}}while(0);do if(t[S>>2]|0){if((t[S>>2]|0)<0){rh(t[h>>2]|0,156240,156304);P=149;break e}if(t[(t[d>>2]|0)+48>>2]&64){t[S>>2]=1825;break}else{t[S>>2]=1824;break}}while(0);do if(((t[S>>2]|0)==0?(t[(t[d>>2]|0)+48>>2]&134217728|0)!=0:0)?(t[S>>2]=aw(t[h>>2]|0,t[w>>2]|0,t[d>>2]|0,t[(t[O>>2]|0)+88>>2]|0,t[v>>2]|0,t[y>>2]|0,0,t[_>>2]|0)|0,(t[S>>2]|0)!=0):0){if((t[S>>2]|0)<0){rh(t[h>>2]|0,156240,156344);P=149;break e}if(t[(t[d>>2]|0)+48>>2]&64){t[S>>2]=1825;break}else{t[S>>2]=1824;break}}while(0);if((t[_>>2]|0)!=0&(t[S>>2]|0)>0)ow(t[h>>2]|0,t[S>>2]|0,t[w>>2]|0,t[v>>2]|0,t[d>>2]|0,1)}while(0);if((P|0)==149){if(t[F>>2]|0)pAi[t[135736>>2]&511](t[F>>2]|0);if(t[y>>2]|0)MD(t[y>>2]|0);t[k>>2]=-1;j=t[k>>2]|0;s=l;return j|0}if(t[F>>2]|0)pAi[t[135736>>2]&511](t[F>>2]|0);
	do if(!(t[S>>2]|0)){F=t[y>>2]|0;if(t[m>>2]|0){t[t[m>>2]>>2]=F;break}if(F)MD(t[y>>2]|0)}else if(t[y>>2]|0)MD(t[y>>2]|0);while(0);t[k>>2]=t[S>>2];j=t[k>>2]|0;s=l;return j|0}function fh(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i+4|0;n=i;t[n>>2]=e;do switch(t[n>>2]|0){case 1e3:{t[r>>2]=157848;break}case 1010:{t[r>>2]=157904;break}case 1002:{t[r>>2]=157816;break}case 1001:{t[r>>2]=157832;break}case 1003:{t[r>>2]=157800;break}case 1004:{t[r>>2]=157936;break}case 1009:{t[r>>2]=157896;break}case 1005:{t[r>>2]=157952;break}case 1007:{t[r>>2]=157880;break}case 1006:{t[r>>2]=157792;break}case 1011:{t[r>>2]=157920;break}case 1008:{t[r>>2]=157864;break}default:t[r>>2]=157968}while(0);s=i;return t[r>>2]|0}function th(e,i,r,n,f,u,a){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;u=u|0;a=a|0;var o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0;o=s;s=s+32|0;c=o+24|0;l=o+20|0;b=o+16|0;k=o+12|0;h=o+8|0;w=o+4|0;d=o;t[c>>2]=e;t[l>>2]=i;t[b>>2]=r;t[k>>2]=n;t[h>>2]=f;t[w>>2]=u;t[d>>2]=a;ah(t[c>>2]|0,t[l>>2]|0,t[b>>2]|0,t[k>>2]|0,t[h>>2]|0,t[w>>2]|0,t[d>>2]|0,0,0);s=o;return}function uh(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0;n=s;s=s+16|0;f=n+12|0;u=n+8|0;a=n+4|0;o=n;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;if(t[t[u>>2]>>2]|0){pAi[t[135736>>2]&511](t[t[u>>2]>>2]|0);t[t[u>>2]>>2]=0}if(t[a>>2]|0){r=Yl(144432)|0;t[t[u>>2]>>2]=r;r=us(t[t[u>>2]>>2]|0,t[a>>2]|0)|0;t[t[u>>2]>>2]=r;r=us(t[t[u>>2]>>2]|0,144440)|0;t[t[u>>2]>>2]=r}do if(t[o>>2]|0){if(t[a>>2]|0){r=us(t[t[u>>2]>>2]|0,t[o>>2]|0)|0;t[t[u>>2]>>2]=r;break}t[f>>2]=t[o>>2];c=t[f>>2]|0;s=n;return c|0}else{r=us(t[t[u>>2]>>2]|0,170232)|0;t[t[u>>2]>>2]=r}while(0);t[f>>2]=t[t[u>>2]>>2];c=t[f>>2]|0;s=n;return c|0}function ah(e,i,r,n,f,u,a,o,c){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;u=u|0;a=a|0;o=o|0;c=c|0;var l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0;l=s;s=s+48|0;b=l+36|0;k=l+32|0;h=l+28|0;w=l+24|0;d=l+20|0;v=l+16|0;m=l+12|0;_=l+8|0;p=l+4|0;E=l;t[b>>2]=e;t[k>>2]=i;t[h>>2]=r;t[w>>2]=n;t[d>>2]=f;t[v>>2]=u;t[m>>2]=a;t[_>>2]=o;t[p>>2]=c;t[E>>2]=0;if((t[h>>2]|0)==0&(t[w>>2]|0)!=0?(t[t[b>>2]>>2]|0)==1:0){t[h>>2]=lw(t[w>>2]|0)|0;sw(E,0,t[w>>2]|0,0)|0;t[E>>2]=us(t[E>>2]|0,152080)|0}else bw(E,t[b>>2]|0,t[h>>2]|0)|0;t[E>>2]=us(t[E>>2]|0,t[d>>2]|0)|0;t[E>>2]=us(t[E>>2]|0,142704)|0;kw(t[b>>2]|0,t[k>>2]|0,t[h>>2]|0,t[E>>2]|0,t[v>>2]|0,t[m>>2]|0,t[_>>2]|0,t[p>>2]|0);if(!(t[E>>2]|0)){s=l;return}pAi[t[135736>>2]&511](t[E>>2]|0);t[E>>2]=0;s=l;return}function oh(e){e=e|0;var i=0,r=0,n=0,f=0,u=0,a=0;i=s;s=s+16|0;r=i+8|0;n=i+4|0;f=i;t[n>>2]=e;t[f>>2]=gAi[t[135744>>2]&511](84)|0;if(!(t[f>>2]|0)){Qh(t[n>>2]|0,170208,0);t[r>>2]=0;u=t[r>>2]|0;s=i;return u|0}else{e=(t[f>>2]|0)+0|0;a=e+84|0;do{t[e>>2]=0;e=e+4|0}while((e|0)<(a|0));t[(t[f>>2]|0)+60>>2]=t[(t[n>>2]|0)+80>>2];sz(t[(t[f>>2]|0)+60>>2]|0)|0;t[r>>2]=t[f>>2];u=t[r>>2]|0;s=i;return u|0}return 0}function ch(e){e=e|0;var i=0,r=0,n=0,f=0,u=0,a=0;i=s;s=s+16|0;r=i+8|0;n=i+4|0;f=i;t[n>>2]=e;t[f>>2]=gAi[t[135744>>2]&511](36)|0;if(!(t[f>>2]|0)){Qh(0,170080,0);t[r>>2]=0;u=t[r>>2]|0;s=i;return u|0}e=(t[f>>2]|0)+0|0;a=e+36|0;do{t[e>>2]=0;e=e+4|0}while((e|0)<(a|0));e=hh()|0;t[(t[f>>2]|0)+12>>2]=e;if(!(t[(t[f>>2]|0)+12>>2]|0)){Qh(0,170120,0);pAi[t[135736>>2]&511](t[f>>2]|0);t[r>>2]=0;u=t[r>>2]|0;s=i;return u|0}e=hh()|0;t[(t[f>>2]|0)+20>>2]=e;if(!(t[(t[f>>2]|0)+20>>2]|0)){Qh(0,170160,0);Jk(t[f>>2]|0);t[r>>2]=0;u=t[r>>2]|0;s=i;return u|0}else{t[(t[f>>2]|0)+8>>2]=t[n>>2];sz(t[n>>2]|0)|0;t[r>>2]=t[f>>2];u=t[r>>2]|0;s=i;return u|0}return 0}function lh(e,i,r,n,f,u,a,o,c,l){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;u=u|0;a=a|0;o=o|0;c=c|0;l=l|0;var b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0,S=0,g=0,y=0,F=0,O=0,A=0,M=0,R=0,N=0,T=0,L=0,D=0,C=0,P=0,B=0,I=0;b=s;s=s+96|0;k=b+88|0;h=b+84|0;w=b+80|0;d=b+76|0;v=b+72|0;m=b+68|0;_=b+64|0;p=b+60|0;E=b+56|0;S=b+52|0;g=b+48|0;y=b+44|0;F=b+40|0;O=b+36|0;A=b+32|0;M=b+28|0;R=b+24|0;N=b+20|0;T=b+16|0;L=b+12|0;D=b+8|0;C=b+4|0;P=b;t[h>>2]=e;t[w>>2]=i;t[d>>2]=r;t[v>>2]=n;t[m>>2]=f;t[_>>2]=u;t[p>>2]=a;t[E>>2]=o;t[S>>2]=c;t[g>>2]=l;t[y>>2]=0;t[F>>2]=0;t[O>>2]=0;t[A>>2]=0;t[M>>2]=0;t[R>>2]=0;t[N>>2]=0;t[T>>2]=0;if(t[g>>2]|0)t[t[g>>2]>>2]=0;l=t[w>>2]|0;if((l|0)==2)t[M>>2]=3050;else if((l|0)==3)t[M>>2]=3081;else if((l|0)==0|(l|0)==1)t[M>>2]=3082;e:do if(((t[w>>2]|0)!=0?(t[(t[(t[h>>2]|0)+28>>2]|0)+12>>2]|0)!=0:0)?(t[(t[(t[(t[h>>2]|0)+28>>2]|0)+12>>2]|0)+4>>2]|0)>0:0){if(((t[d>>2]|0)!=0?(t[T>>2]=hw(t[h>>2]|0,t[d>>2]|0)|0,(t[T>>2]|0)!=0):0)?(t[(t[(t[h>>2]|0)+28>>2]|0)+16>>2]|0)==(t[T>>2]|0):0){th(t[h>>2]|0,t[M>>2]|0,t[p>>2]|0,0,169048,0,0);B=92;break}t[F>>2]=ww()|0;if(!(t[F>>2]|0)){t[k>>2]=-1;I=t[k>>2]|0;s=b;return I|0}dw(t[(t[(t[h>>2]|0)+28>>2]|0)+16>>2]|0,t[F>>2]|0);t[(t[F>>2]|0)+4>>2]=t[w>>2];if((t[w>>2]|0)==0|(t[w>>2]|0)==1){t[(t[F>>2]|0)+8>>2]=t[S>>2];if(!(t[d>>2]|0)){B=92;break}t[y>>2]=t[S>>2]}do if(t[T>>2]|0){if((t[w>>2]|0)==0|(t[w>>2]|0)==1?(t[(t[T>>2]|0)+36>>2]|0)==0:0){if(!(t[d>>2]|0))t[d>>2]=169104;if(Xl(t[d>>2]|0,t[(t[T>>2]|0)+8>>2]|0)|0)break;th(t[h>>2]|0,t[M>>2]|0,t[p>>2]|0,0,169128,t[d>>2]|0,0);B=92;break e}if(!((t[w>>2]|0)==0|(t[w>>2]|0)==1)?(t[(t[T>>2]|0)+36>>2]|0)!=0:0){if(!(t[d>>2]|0))t[d>>2]=169104;if(!(Xl(t[d>>2]|0,t[(t[T>>2]|0)+8>>2]|0)|0)){th(t[h>>2]|0,t[M>>2]|0,t[p>>2]|0,0,169216,t[d>>2]|0,0);B=92;break e}}}while(0);l=(t[T>>2]|0)!=0;do if((t[w>>2]|0)==0|(t[w>>2]|0)==1){if(l){t[(t[F>>2]|0)+12>>2]=t[T>>2];B=92;break e}t[T>>2]=vw(t[h>>2]|0,t[S>>2]|0,1)|0;if(t[T>>2]|0){t[(t[F>>2]|0)+12>>2]=t[T>>2];c=t[d>>2]|0;o=(t[T>>2]|0)+8|0;if(!(t[(t[T>>2]|0)+8>>2]|0)){t[o>>2]=c;break}if(Xl(c,t[o>>2]|0)|0){B=92;break e}if(!(t[d>>2]|0))t[d>>2]=169104;mw(t[h>>2]|0,3083,t[p>>2]|0,0,169304,t[d>>2]|0,t[S>>2]|0,t[(t[T>>2]|0)+8>>2]|0);B=92;break e}}else if(l){if((t[(t[T>>2]|0)+12>>2]|0)==0?(t[(t[T>>2]|0)+16>>2]|0)!=(t[E>>2]|0):0){t[L>>2]=_w(t[h>>2]|0,t[d>>2]|0,t[E>>2]|0)|0;if(t[L>>2]|0){t[(t[F>>2]|0)+12>>2]=t[L>>2];B=92;break e}else{t[T>>2]=0;break}}t[(t[F>>2]|0)+12>>2]=t[T>>2];B=92;break e}while(0);if((t[T>>2]|0)!=0?(t[(t[T>>2]|0)+20>>2]|0)!=0:0)rh(t[h>>2]|0,169448,169472);else B=52}else B=52;while(0);e:do if((B|0)==52){do if(t[v>>2]|0){t[O>>2]=t[v>>2];t[N>>2]=1;if(t[(t[v>>2]|0)+72>>2]|0){t[d>>2]=kz(t[(t[h>>2]|0)+80>>2]|0,t[(t[v>>2]|0)+72>>2]|0,-1)|0;B=73;break}else{t[d>>2]=169104;B=73;break}}else{if(!((t[d>>2]|0)!=0|(t[m>>2]|0)!=0)){pw(t[h>>2]|0,0,1758,169640,0,0);break e}t[D>>2]=zp()|0;if(!(t[D>>2]|0)){Qh(0,169552,0);break e}if((t[(t[h>>2]|0)+80>>2]|0)!=0?(t[(t[D>>2]|0)+296>>2]|0)!=0:0){bz(t[(t[D>>2]|0)+296>>2]|0);t[(t[D>>2]|0)+296>>2]=t[(t[h>>2]|0)+80>>2];sz(t[(t[D>>2]|0)+296>>2]|0)|0}if(!(t[d>>2]|0)){if((t[m>>2]|0)!=0?(t[O>>2]=yS(t[D>>2]|0,t[m>>2]|0,t[_>>2]|0,0,0,2)|0,t[d>>2]=169104,(t[O>>2]|0)!=0):0){L=Yl(t[d>>2]|0)|0;t[(t[O>>2]|0)+72>>2]=L}}else t[O>>2]=gS(t[D>>2]|0,t[d>>2]|0,0,2)|0;do if(!(t[O>>2]|0)){t[C>>2]=vp()|0;if((t[C>>2]|0)!=0?(t[t[C>>2]>>2]|0)==8:0)break;t[R>>2]=1;t[A>>2]=3067;th(t[h>>2]|0,t[A>>2]|0,t[p>>2]|0,0,169600,t[d>>2]|0,0)}while(0);Up(t[D>>2]|0);if(!((t[O>>2]|0)==0&(t[R>>2]|0)!=0))B=73}while(0);i:do if((B|0)==73){do if(t[O>>2]|0){t[P>>2]=0;t[R>>2]=1;t[P>>2]=eF(t[O>>2]|0)|0;L=t[h>>2]|0;if(!(t[P>>2]|0)){th(L,1759,t[p>>2]|0,0,169720,t[d>>2]|0,0);break i}Ew(L,t[P>>2]|0);if((((t[P>>2]|0)!=0?(t[(t[P>>2]|0)+36>>2]|0)!=0:0)?(Xl(t[(t[P>>2]|0)+8>>2]|0,169768)|0)!=0:0)?(Xl(t[(t[(t[P>>2]|0)+36>>2]|0)+8>>2]|0,t[38526]|0)|0)!=0:0){t[y>>2]=Sw(t[h>>2]|0,t[P>>2]|0,168888)|0;break}th(t[h>>2]|0,1772,t[p>>2]|0,0,169776,t[d>>2]|0,0);break i}while(0);if((t[T>>2]|0)==0&(t[R>>2]|0)!=0?(t[T>>2]=gw(t[h>>2]|0,t[w>>2]|0,t[y>>2]|0)|0,(t[T>>2]|0)==0):0)break e;if(!(t[T>>2]|0)){B=92;break e}t[(t[T>>2]|0)+8>>2]=t[d>>2];t[(t[T>>2]|0)+28>>2]=t[R>>2];if((t[O>>2]|0)!=0?(t[(t[T>>2]|0)+20>>2]=t[O>>2],t[(t[T>>2]|0)+16>>2]=t[y>>2],t[(t[T>>2]|0)+12>>2]=t[y>>2],(t[N>>2]|0)!=0):0)t[(t[T>>2]|0)+40>>2]=1;if((t[w>>2]|0)==0|(t[w>>2]|0)==1){L=(t[T>>2]|0)+36|0;t[L>>2]=(t[L>>2]|0)+1}if(!(t[F>>2]|0)){B=92;break e}t[(t[F>>2]|0)+12>>2]=t[T>>2];B=92;break e}while(0);if(!((t[O>>2]|0)==0|(t[N>>2]|0)!=0)?(fy(t[O>>2]|0),(t[T>>2]|0)!=0):0)t[(t[T>>2]|0)+20>>2]=0;t[k>>2]=t[(t[h>>2]|0)+16>>2];I=t[k>>2]|0;s=b;return I|0}while(0);if((B|0)==92){if(t[g>>2]|0)t[t[g>>2]>>2]=t[T>>2];t[k>>2]=0;I=t[k>>2]|0;s=b;return I|0}if(!((t[O>>2]|0)==0|(t[N>>2]|0)!=0)?(fy(t[O>>2]|0),(t[T>>2]|0)!=0):0)t[(t[T>>2]|0)+20>>2]=0;t[k>>2]=-1;I=t[k>>2]|0;s=b;return I|0}function sh(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0;n=s;s=s+48|0;f=n+32|0;u=n+28|0;a=n+24|0;o=n+20|0;c=n+16|0;l=n+12|0;b=n+8|0;k=n+4|0;h=n;t[f>>2]=e;t[u>>2]=i;t[a>>2]=r;t[h>>2]=t[(t[(t[f>>2]|0)+28>>2]|0)+16>>2];t[o>>2]=t[(t[u>>2]|0)+24>>2];t[c>>2]=t[(t[u>>2]|0)+16>>2];if(t[(t[u>>2]|0)+24>>2]|0)yw(t[u>>2]|0);t[(t[u>>2]|0)+16>>2]=t[(t[a>>2]|0)+20>>2];t[(t[f>>2]|0)+36>>2]=t[u>>2];t[(t[f>>2]|0)+112>>2]=t[(t[a>>2]|0)+16>>2];t[(t[(t[f>>2]|0)+28>>2]|0)+16>>2]=t[a>>2];if((t[(t[a>>2]|0)+16>>2]|0)!=0?(Xl(t[(t[a>>2]|0)+16>>2]|0,t[38526]|0)|0)!=0:0)t[(t[f>>2]|0)+96>>2]=1;r=(t[a>>2]|0)+32|0;t[r>>2]=(t[r>>2]|0)+1;t[l>>2]=eF(t[(t[a>>2]|0)+20>>2]|0)|0;t[b>>2]=Fw(t[f>>2]|0,t[u>>2]|0,t[l>>2]|0)|0;if((((t[b>>2]|0)==0?(t[(t[l>>2]|0)+12>>2]|0)!=0:0)?(t[k>>2]=t[(t[f>>2]|0)+20>>2],t[b>>2]=Ow(t[f>>2]|0,t[u>>2]|0,t[(t[l>>2]|0)+12>>2]|0)|0,(t[b>>2]|0)==0&(t[b>>2]|0)==0):0)?(t[k>>2]|0)!=(t[(t[f>>2]|0)+20>>2]|0):0)t[b>>2]=t[(t[f>>2]|0)+16>>2];t[(t[(t[f>>2]|0)+28>>2]|0)+16>>2]=t[h>>2];t[(t[u>>2]|0)+16>>2]=t[c>>2];t[(t[u>>2]|0)+24>>2]=t[o>>2];s=n;return t[b>>2]|0}function bh(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0;r=s;s=s+48|0;n=r+40|0;f=r+36|0;u=r+32|0;a=r+28|0;o=r+24|0;c=r+20|0;l=r+16|0;b=r+12|0;k=r+8|0;h=r+4|0;w=r;t[f>>2]=e;t[u>>2]=i;t[a>>2]=t[(t[f>>2]|0)+28>>2];t[k>>2]=0;t[h>>2]=t[(t[a>>2]|0)+16>>2];if((t[(t[a>>2]|0)+20>>2]|0)!=0?(t[(t[(t[a>>2]|0)+20>>2]|0)+4>>2]|0)!=0:0){if(!(t[(t[a>>2]|0)+16>>2]|0))t[(t[a>>2]|0)+16>>2]=t[u>>2];Aw(t[f>>2]|0)|0;Mw(t[f>>2]|0,t[u>>2]|0)|0;t[(t[f>>2]|0)+84>>2]=0;t[c>>2]=t[t[(t[a>>2]|0)+20>>2]>>2];t[l>>2]=t[(t[(t[a>>2]|0)+20>>2]|0)+4>>2];t[b>>2]=0;e:while(1){if((t[b>>2]|0)>=(t[l>>2]|0)){d=20;break}t[o>>2]=t[(t[c>>2]|0)+(t[b>>2]<<2)>>2];switch(t[t[o>>2]>>2]|0){case 26:{Lw(t[o>>2]|0,t[f>>2]|0)|0;if((t[(t[f>>2]|0)+16>>2]|0)==3069){d=115;break e}break}case 8:case 7:case 6:{Cw(t[f>>2]|0,t[o>>2]|0);if((t[(t[f>>2]|0)+16>>2]|0)==3069){d=115;break e}break}case 4:case 5:{Nw(t[o>>2]|0,t[f>>2]|0);if((t[(t[f>>2]|0)+16>>2]|0)==3069){d=115;break e}break}case 14:{Rw(t[o>>2]|0,t[f>>2]|0);if((t[(t[f>>2]|0)+16>>2]|0)==3069){d=115;break e}break}case 15:{Tw(t[o>>2]|0,t[f>>2]|0)|0;if((t[(t[f>>2]|0)+16>>2]|0)==3069){d=115;break e}break}case 2e3:{if((t[(t[o>>2]|0)+8>>2]|0)==16)Dw(t[o>>2]|0,t[f>>2]|0)|0;if((t[(t[f>>2]|0)+16>>2]|0)==3069){d=115;break e}break}case 2001:{Bw(t[o>>2]|0,t[f>>2]|0)|0;if((t[(t[f>>2]|0)+16>>2]|0)==3069){d=115;break e}break}case 24:case 22:case 23:{Pw(t[o>>2]|0,t[f>>2]|0)|0;if((t[(t[f>>2]|0)+16>>2]|0)==3069){d=115;break e}break}default:{}}t[b>>2]=(t[b>>2]|0)+1}e:do if((d|0)==20){i:do if(!(t[(t[f>>2]|0)+20>>2]|0)){t[b>>2]=0;while(1){if((t[b>>2]|0)>=(t[l>>2]|0))break;t[o>>2]=t[(t[c>>2]|0)+(t[b>>2]<<2)>>2];u=t[t[o>>2]>>2]|0;if((u|0)==16){xw(t[o>>2]|0,t[f>>2]|0)|0;if((t[(t[f>>2]|0)+16>>2]|0)==3069){d=115;break e}if(t[(t[f>>2]|0)+20>>2]|0)break i}else if((u|0)==4|(u|0)==5){Iw(t[o>>2]|0,t[f>>2]|0);if((t[(t[f>>2]|0)+16>>2]|0)==3069){d=115;break e}if(t[(t[f>>2]|0)+20>>2]|0)break i}else if((u|0)==17){Hw(t[o>>2]|0,t[f>>2]|0);if((t[(t[f>>2]|0)+16>>2]|0)==3069){d=115;break e}if(t[(t[f>>2]|0)+20>>2]|0)break i}t[b>>2]=(t[b>>2]|0)+1}if(!(t[(t[f>>2]|0)+20>>2]|0)){t[b>>2]=0;while(1){if((t[b>>2]|0)>=(t[l>>2]|0))break;t[o>>2]=t[(t[c>>2]|0)+(t[b>>2]<<2)>>2];if(((t[t[o>>2]>>2]|0)+-6|0)>>>0<2)Uw(t[f>>2]|0,t[o>>2]|0);t[b>>2]=(t[b>>2]|0)+1}if(!(t[(t[f>>2]|0)+20>>2]|0)){t[b>>2]=0;while(1){if((t[b>>2]|0)>=(t[l>>2]|0))break;t[o>>2]=t[(t[c>>2]|0)+(t[b>>2]<<2)>>2];if((((t[t[o>>2]>>2]|0)==16?(t[(t[o>>2]|0)+36>>2]&1|0)==0:0)?(t[(t[o>>2]|0)+36>>2]&16|0)!=0:0)?(zw(t[f>>2]|0,t[o>>2]|0)|0,(t[(t[f>>2]|0)+16>>2]|0)==3069):0){d=115;break e}t[b>>2]=(t[b>>2]|0)+1}if(!(t[(t[f>>2]|0)+20>>2]|0)){t[b>>2]=0;while(1){if((t[b>>2]|0)>=(t[l>>2]|0))break;t[o>>2]=t[(t[c>>2]|0)+(t[b>>2]<<2)>>2];if((((t[t[o>>2]>>2]|0)==4?(t[t[o>>2]>>2]|0)!=1:0)?(t[(t[o>>2]|0)+48>>2]&536870912|0)==0:0)?(jw(t[f>>2]|0,t[o>>2]|0)|0,(t[(t[f>>2]|0)+16>>2]|0)==3069):0){d=115;break e}t[b>>2]=(t[b>>2]|0)+1}if(!(t[(t[f>>2]|0)+20>>2]|0)){t[b>>2]=0;while(1){if((t[b>>2]|0)>=(t[l>>2]|0))break;t[o>>2]=t[(t[c>>2]|0)+(t[b>>2]<<2)>>2];if(((t[t[o>>2]>>2]|0)==4?(t[(t[o>>2]|0)+92>>2]|0)!=0:0)?(Vw(t[f>>2]|0,t[o>>2]|0)|0,(t[(t[f>>2]|0)+16>>2]|0)==3069):0){d=115;break e}t[b>>2]=(t[b>>2]|0)+1}if(!(t[(t[f>>2]|0)+20>>2]|0)){t[b>>2]=0;while(1){if((t[b>>2]|0)>=(t[l>>2]|0))break;t[o>>2]=t[(t[c>>2]|0)+(t[b>>2]<<2)>>2];if((((t[t[o>>2]>>2]|0)==4?(t[t[o>>2]>>2]|0)!=1:0)?(t[(t[o>>2]|0)+48>>2]&4194304|0)==0:0)?(qw(t[f>>2]|0,t[o>>2]|0)|0,(t[(t[f>>2]|0)+16>>2]|0)==3069):0){d=115;break e}t[b>>2]=(t[b>>2]|0)+1}if(!(t[(t[f>>2]|0)+20>>2]|0)){t[b>>2]=0;while(1){if((t[b>>2]|0)>=(t[l>>2]|0))break;t[o>>2]=t[(t[c>>2]|0)+(t[b>>2]<<2)>>2];if((t[t[o>>2]>>2]|0)==15?(Yw(t[f>>2]|0,t[o>>2]|0)|0,(t[(t[f>>2]|0)+16>>2]|0)==3069):0){d=115;break e}t[b>>2]=(t[b>>2]|0)+1}if(!(t[(t[f>>2]|0)+20>>2]|0)){t[b>>2]=0;while(1){if((t[b>>2]|0)>=(t[l>>2]|0))break;t[o>>2]=t[(t[c>>2]|0)+(t[b>>2]<<2)>>2];if(((t[t[o>>2]>>2]|0)==26?(t[(t[o>>2]|0)+28>>2]|0)!=0:0)?(Gw(t[f>>2]|0,t[o>>2]|0)|0,(t[(t[f>>2]|0)+16>>2]|0)==3069):0){d=115;break e}t[b>>2]=(t[b>>2]|0)+1}if(!(t[(t[f>>2]|0)+20>>2]|0)){t[b>>2]=0;while(1){if((t[b>>2]|0)>=(t[l>>2]|0))break;t[o>>2]=t[(t[c>>2]|0)+(t[b>>2]<<2)>>2];do if((t[t[o>>2]>>2]|0)==16?(t[(t[o>>2]|0)+56>>2]|0)!=0:0){if((t[(t[(t[o>>2]|0)+56>>2]|0)+4>>2]|0)<=1)break;Ww(t[f>>2]|0,t[o>>2]|0)|0;if((t[(t[f>>2]|0)+16>>2]|0)==3069){d=115;break e}}while(0);t[b>>2]=(t[b>>2]|0)+1}if(!(t[(t[f>>2]|0)+20>>2]|0)){if(t[(t[(t[f>>2]|0)+28>>2]|0)+28>>2]|0)Kw(t[f>>2]|0)|0;if(!(t[(t[f>>2]|0)+20>>2]|0)){t[b>>2]=0;while(1){if((t[b>>2]|0)>=(t[l>>2]|0))break;t[o>>2]=t[(t[t[(t[a>>2]|0)+20>>2]>>2]|0)+(t[b>>2]<<2)>>2];do if((t[t[o>>2]>>2]|0)==5){if((t[t[o>>2]>>2]|0)==1)break;if(t[(t[o>>2]|0)+48>>2]&4194304)break;Xw(t[f>>2]|0,t[o>>2]|0)|0;if((t[(t[f>>2]|0)+16>>2]|0)==3069){d=115;break e}}while(0);t[b>>2]=(t[b>>2]|0)+1}if(!(t[(t[f>>2]|0)+20>>2]|0)){t[c>>2]=t[t[(t[a>>2]|0)+20>>2]>>2];t[l>>2]=t[(t[(t[a>>2]|0)+20>>2]|0)+4>>2];t[b>>2]=0;while(1){if((t[b>>2]|0)>=(t[l>>2]|0))break;t[o>>2]=t[(t[c>>2]|0)+(t[b>>2]<<2)>>2];do if((t[t[o>>2]>>2]|0)==14){t[w>>2]=t[o>>2];if(t[(t[w>>2]|0)+48>>2]&262144)break;Zw(t[w>>2]|0,t[f>>2]|0);if((t[(t[f>>2]|0)+16>>2]|0)==3069){d=115;break e}}while(0);t[b>>2]=(t[b>>2]|0)+1}if(!(t[(t[f>>2]|0)+20>>2]|0)){t[b>>2]=0;while(1){if((t[b>>2]|0)>=(t[l>>2]|0))break;t[o>>2]=t[(t[c>>2]|0)+(t[b>>2]<<2)>>2];if((t[t[o>>2]>>2]|0)==5)Jw(t[o>>2]|0,t[f>>2]|0);t[b>>2]=(t[b>>2]|0)+1}if(!(t[(t[f>>2]|0)+20>>2]|0))break e}}}}}}}}}}}}}while(0);t[k>>2]=t[(t[f>>2]|0)+16>>2]}while(0);if((d|0)==115)t[k>>2]=-1;t[(t[a>>2]|0)+16>>2]=t[h>>2];t[(t[(t[a>>2]|0)+20>>2]|0)+4>>2]=0;if(t[(t[a>>2]|0)+24>>2]|0){XF(t[(t[a>>2]|0)+24>>2]|0,356);t[(t[a>>2]|0)+24>>2]=0}if(t[(t[a>>2]|0)+28>>2]|0){ew(t[(t[a>>2]|0)+28>>2]|0);t[(t[a>>2]|0)+28>>2]=0}t[n>>2]=t[k>>2];v=t[n>>2]|0;s=r;return v|0}t[n>>2]=0;v=t[n>>2]|0;s=r;return v|0}function kh(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0;n=s;s=s+16|0;f=n+8|0;u=n+4|0;a=n;t[f>>2]=e;t[u>>2]=i;t[a>>2]=r;if(t[f>>2]|0){r=(t[f>>2]|0)+56|0;t[r>>2]=(t[r>>2]|0)+1;t[(t[f>>2]|0)+52>>2]=1818}dp(17,2,t[a>>2]|0,0,t[u>>2]|0);s=n;return}function hh(){var e=0,i=0,r=0,n=0,f=0;e=s;s=s+16|0;i=e+4|0;r=e;t[r>>2]=gAi[t[135744>>2]&511](12)|0;if(!(t[r>>2]|0)){Qh(0,156200,0);t[i>>2]=0;n=t[i>>2]|0;s=e;return n|0}else{f=t[r>>2]|0;t[f+0>>2]=0;t[f+4>>2]=0;t[f+8>>2]=0;t[i>>2]=t[r>>2];n=t[i>>2]|0;s=e;return n|0}return 0}function wh(e){e=e|0;var i=0,r=0,n=0,f=0,u=0;i=s;s=s+16|0;r=i+8|0;n=i+4|0;f=i;t[n>>2]=e;t[f>>2]=0;if((Kh(t[n>>2]|0)|0)<0){t[r>>2]=-1;u=t[r>>2]|0;s=i;return u|0}e=t[n>>2]|0;do if(!(t[(t[n>>2]|0)+24>>2]|0)){if(!(t[e+160>>2]|0)){if((t[(t[n>>2]|0)+36>>2]|0)!=0?(t[(t[n>>2]|0)+40>>2]|0)!=0:0){t[f>>2]=iS(t[(t[n>>2]|0)+40>>2]|0)|0;break}rh(t[n>>2]|0,155872,155888);t[f>>2]=-1}}else t[f>>2]=Qw(e)|0;while(0);Xh(t[n>>2]|0);if(!(t[f>>2]|0))t[f>>2]=t[(t[n>>2]|0)+52>>2];t[r>>2]=t[f>>2];u=t[r>>2]|0;s=i;return u|0}function dh(e,i,r,n,f,a,o,c,l){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;a=a|0;o=o|0;c=c|0;l=l|0;var b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0,S=0,g=0,y=0,F=0,O=0;b=s;s=s+64|0;k=b+56|0;h=b+52|0;w=b+44|0;d=b+40|0;v=b+36|0;m=b+32|0;_=b+24|0;p=b+20|0;E=b+16|0;S=b+12|0;g=b+8|0;y=b+4|0;F=b;t[k>>2]=e;t[h>>2]=i;t[b+48>>2]=r;t[w>>2]=n;t[d>>2]=f;t[v>>2]=a;t[m>>2]=o;t[b+28>>2]=c;t[_>>2]=l;t[p>>2]=t[k>>2];k=(t[p>>2]|0)+96|0;t[k>>2]=(t[k>>2]|0)+1;if((t[(t[p>>2]|0)+176>>2]|0)!=-1?(t[(t[p>>2]|0)+96>>2]|0)>=(t[(t[p>>2]|0)+176>>2]|0):0){s=b;return}k=($w(t[p>>2]|0)|0)==-1;l=t[p>>2]|0;e:do if(!k){t[S>>2]=t[l+108>>2];c=Oz(t[(t[p>>2]|0)+40>>2]|0)|0;t[(t[S>>2]|0)+8>>2]=c;t[(t[S>>2]|0)+12>>2]=t[h>>2];t[(t[S>>2]|0)+16>>2]=t[w>>2];c=(t[S>>2]|0)+32|0;t[c>>2]=t[c>>2]|32;i:do if(t[d>>2]|0){t[g>>2]=0;t[y>>2]=0;while(1){if((t[g>>2]|0)>=(t[d>>2]|0))break i;if(t[(t[S>>2]|0)+64>>2]|0){if((t[(t[S>>2]|0)+72>>2]|0)<=(t[(t[S>>2]|0)+68>>2]|0)?(c=(t[S>>2]|0)+72|0,t[c>>2]=t[c>>2]<<1,c=MAi[t[135760>>2]&511](t[(t[S>>2]|0)+64>>2]|0,t[(t[S>>2]|0)+72>>2]<<1<<2)|0,t[(t[S>>2]|0)+64>>2]=c,(t[(t[S>>2]|0)+64>>2]|0)==0):0){O=14;break}}else{c=gAi[t[135744>>2]&511](40)|0;t[(t[S>>2]|0)+64>>2]=c;if(!(t[(t[S>>2]|0)+64>>2]|0)){O=10;break}t[(t[S>>2]|0)+68>>2]=0;t[(t[S>>2]|0)+72>>2]=5}t[(t[(t[S>>2]|0)+64>>2]|0)+(t[(t[S>>2]|0)+68>>2]<<1<<2)>>2]=t[(t[v>>2]|0)+(t[y>>2]<<2)>>2];if(!(u[t[(t[v>>2]|0)+((t[y>>2]|0)+1<<2)>>2]>>0]|0))t[(t[(t[S>>2]|0)+64>>2]|0)+((t[(t[S>>2]|0)+68>>2]<<1)+1<<2)>>2]=0;else t[(t[(t[S>>2]|0)+64>>2]|0)+((t[(t[S>>2]|0)+68>>2]<<1)+1<<2)>>2]=t[(t[v>>2]|0)+((t[y>>2]|0)+1<<2)>>2];c=(t[S>>2]|0)+68|0;t[c>>2]=(t[c>>2]|0)+1;t[g>>2]=(t[g>>2]|0)+1;t[y>>2]=(t[y>>2]|0)+2}if((O|0)==10){kh(t[p>>2]|0,144584,0);break e}else if((O|0)==14){kh(t[p>>2]|0,144640,0);break e}}while(0);i:do if(t[m>>2]|0){t[y>>2]=0;t[g>>2]=0;while(1){if((t[g>>2]|0)>=(t[m>>2]|0))break i;t[F>>2]=ql(t[(t[_>>2]|0)+((t[y>>2]|0)+3<<2)>>2]|0,(t[(t[_>>2]|0)+((t[y>>2]|0)+4<<2)>>2]|0)-(t[(t[_>>2]|0)+((t[y>>2]|0)+3<<2)>>2]|0)|0)|0;t[E>>2]=ed(t[p>>2]|0,0,t[(t[S>>2]|0)+8>>2]|0,t[(t[_>>2]|0)+(t[y>>2]<<2)>>2]|0,t[(t[_>>2]|0)+((t[y>>2]|0)+2<<2)>>2]|0,0,t[F>>2]|0,1)|0;if((t[E>>2]|0)==-1)break;t[g>>2]=(t[g>>2]|0)+1;t[y>>2]=(t[y>>2]|0)+5}rh(t[p>>2]|0,144504,144696);break e}while(0);t[E>>2]=id(t[p>>2]|0)|0;if((t[E>>2]|0)!=0&(t[E>>2]|0)==-1){rh(t[p>>2]|0,144504,144744);break}else{s=b;return}}else rh(l,144504,144544);while(0);t[(t[p>>2]|0)+52>>2]=-1;tS(t[(t[p>>2]|0)+40>>2]|0);s=b;return}function vh(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,u=0,a=0,o=0,c=0,l=0;f=s;s=s+32|0;u=f+20|0;a=f+16|0;o=f+8|0;c=f+4|0;l=f;t[u>>2]=e;t[a>>2]=i;t[f+12>>2]=r;t[o>>2]=n;t[c>>2]=t[u>>2];do if((t[(t[c>>2]|0)+176>>2]|0)!=-1){u=t[c>>2]|0;if((t[(t[c>>2]|0)+96>>2]|0)<=(t[(t[c>>2]|0)+176>>2]|0)){t[u+176>>2]=-1;break}n=u+96|0;t[n>>2]=(t[n>>2]|0)+-1;s=f;return}while(0);if(!((Xl(t[(t[(t[c>>2]|0)+108>>2]|0)+12>>2]|0,t[a>>2]|0)|0)!=0?(Xl(t[(t[(t[c>>2]|0)+108>>2]|0)+16>>2]|0,t[o>>2]|0)|0)!=0:0))rh(t[c>>2]|0,141632,141664);t[l>>2]=rd(t[c>>2]|0)|0;if(!((t[l>>2]|0)!=0&(t[l>>2]|0)<0)){s=f;return}rh(t[c>>2]|0,141632,141688);t[(t[c>>2]|0)+52>>2]=-1;tS(t[(t[c>>2]|0)+40>>2]|0);s=f;return}function mh(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0;n=s;s=s+16|0;f=n+12|0;u=n+8|0;a=n+4|0;o=n;t[f>>2]=e;t[u>>2]=i;t[a>>2]=r;t[o>>2]=t[f>>2];if((t[(t[o>>2]|0)+96>>2]|0)<0){s=n;return}if((t[(t[o>>2]|0)+176>>2]|0)!=-1?(t[(t[o>>2]|0)+96>>2]|0)>=(t[(t[o>>2]|0)+176>>2]|0):0){s=n;return}if(t[(t[(t[o>>2]|0)+108>>2]|0)+32>>2]&32){f=(t[(t[o>>2]|0)+108>>2]|0)+32|0;t[f>>2]=t[f>>2]^32}if((nd(t[o>>2]|0,3,t[u>>2]|0,t[a>>2]|0,3,0)|0)!=-1){s=n;return}rh(t[o>>2]|0,141304,141336);t[(t[o>>2]|0)+52>>2]=-1;tS(t[(t[o>>2]|0)+40>>2]|0);s=n;return}function _h(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0;n=s;s=s+16|0;f=n+12|0;u=n+8|0;a=n+4|0;o=n;t[f>>2]=e;t[u>>2]=i;t[a>>2]=r;t[o>>2]=t[f>>2];if((t[(t[o>>2]|0)+96>>2]|0)<0){s=n;return}if((t[(t[o>>2]|0)+176>>2]|0)!=-1?(t[(t[o>>2]|0)+96>>2]|0)>=(t[(t[o>>2]|0)+176>>2]|0):0){s=n;return}if(t[(t[(t[o>>2]|0)+108>>2]|0)+32>>2]&32){f=(t[(t[o>>2]|0)+108>>2]|0)+32|0;t[f>>2]=t[f>>2]^32}if((nd(t[o>>2]|0,4,t[u>>2]|0,t[a>>2]|0,3,0)|0)!=-1){s=n;return}rh(t[o>>2]|0,141304,141336);t[(t[o>>2]|0)+52>>2]=-1;tS(t[(t[o>>2]|0)+40>>2]|0);s=n;return}function ph(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0;r=s;s=s+32|0;n=r;f=r+16|0;u=r+8|0;t[f>>2]=e;t[r+12>>2]=i;t[u>>2]=t[f>>2];if((t[(t[u>>2]|0)+96>>2]|0)<0){s=r;return}if((t[(t[u>>2]|0)+176>>2]|0)!=-1?(t[(t[u>>2]|0)+96>>2]|0)>=(t[(t[u>>2]|0)+176>>2]|0):0){s=r;return}u=t[33976]|0;f=t[33980]|0;t[n>>2]=140328;t[n+4>>2]=27281;yAi[u&511](f,140296,n);s=r;return}function Eh(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,u=0,a=0,o=0,c=0,l=0;f=s;s=s+32|0;u=f+16|0;a=f+12|0;o=f+8|0;c=f+4|0;l=f;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;t[c>>2]=n;t[l>>2]=t[u>>2];if(!(t[l>>2]|0)){s=f;return}if(!(t[(t[l>>2]|0)+8>>2]|0)){s=f;return}if(!(t[t[(t[l>>2]|0)+8>>2]>>2]|0)){s=f;return}NAi[t[t[(t[l>>2]|0)+8>>2]>>2]&511](t[(t[l>>2]|0)+16>>2]|0,t[a>>2]|0,t[o>>2]|0,t[c>>2]|0);s=f;return}function Sh(e){e=e|0;var i=0,r=0,n=0,f=0,u=0;i=s;s=s+16|0;r=i+8|0;n=i+4|0;f=i;t[n>>2]=e;t[f>>2]=t[n>>2];if(((t[f>>2]|0)!=0?(t[(t[f>>2]|0)+8>>2]|0)!=0:0)?(t[(t[(t[f>>2]|0)+8>>2]|0)+4>>2]|0)!=0:0){t[r>>2]=gAi[t[(t[(t[f>>2]|0)+8>>2]|0)+4>>2]&511](t[(t[f>>2]|0)+16>>2]|0)|0;u=t[r>>2]|0;s=i;return u|0}t[r>>2]=0;u=t[r>>2]|0;s=i;return u|0}function gh(e){e=e|0;var i=0,r=0,n=0,f=0,u=0;i=s;s=s+16|0;r=i+8|0;n=i+4|0;f=i;t[n>>2]=e;t[f>>2]=t[n>>2];if(((t[f>>2]|0)!=0?(t[(t[f>>2]|0)+8>>2]|0)!=0:0)?(t[(t[(t[f>>2]|0)+8>>2]|0)+8>>2]|0)!=0:0){t[r>>2]=gAi[t[(t[(t[f>>2]|0)+8>>2]|0)+8>>2]&511](t[(t[f>>2]|0)+16>>2]|0)|0;u=t[r>>2]|0;s=i;return u|0}t[r>>2]=0;u=t[r>>2]|0;s=i;return u|0}function yh(e){e=e|0;var i=0,r=0,n=0,f=0,u=0;i=s;s=s+16|0;r=i+8|0;n=i+4|0;f=i;t[n>>2]=e;t[f>>2]=t[n>>2];if(((t[f>>2]|0)!=0?(t[(t[f>>2]|0)+8>>2]|0)!=0:0)?(t[(t[(t[f>>2]|0)+8>>2]|0)+12>>2]|0)!=0:0){t[r>>2]=gAi[t[(t[(t[f>>2]|0)+8>>2]|0)+12>>2]&511](t[(t[f>>2]|0)+16>>2]|0)|0;u=t[r>>2]|0;s=i;return u|0}t[r>>2]=0;u=t[r>>2]|0;s=i;return u|0}function Fh(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,l=0;n=s;s=s+32|0;f=n+16|0;u=n+12|0;a=n+8|0;o=n+4|0;c=n;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;t[c>>2]=t[u>>2];if(((t[c>>2]|0)!=0?(t[(t[c>>2]|0)+8>>2]|0)!=0:0)?(t[(t[(t[c>>2]|0)+8>>2]|0)+16>>2]|0)!=0:0){t[f>>2]=dAi[t[(t[(t[c>>2]|0)+8>>2]|0)+16>>2]&511](t[(t[c>>2]|0)+16>>2]|0,t[a>>2]|0,t[o>>2]|0)|0;l=t[f>>2]|0;s=n;return l|0}t[f>>2]=0;l=t[f>>2]|0;s=n;return l|0}function Oh(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0;r=s;s=s+16|0;n=r+12|0;f=r+8|0;u=r+4|0;a=r;t[f>>2]=e;t[u>>2]=i;t[a>>2]=t[f>>2];if(((t[a>>2]|0)!=0?(t[(t[a>>2]|0)+8>>2]|0)!=0:0)?(t[(t[(t[a>>2]|0)+8>>2]|0)+20>>2]|0)!=0:0){t[n>>2]=MAi[t[(t[(t[a>>2]|0)+8>>2]|0)+20>>2]&511](t[(t[a>>2]|0)+16>>2]|0,t[u>>2]|0)|0;o=t[n>>2]|0;s=r;return o|0}t[n>>2]=0;o=t[n>>2]|0;s=r;return o|0}function Ah(e,i,r,n,f,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;u=u|0;var a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0;a=s;s=s+32|0;o=a+24|0;c=a+20|0;l=a+16|0;b=a+12|0;k=a+8|0;h=a+4|0;w=a;t[o>>2]=e;t[c>>2]=i;t[l>>2]=r;t[b>>2]=n;t[k>>2]=f;t[h>>2]=u;t[w>>2]=t[o>>2];if(!(t[w>>2]|0)){s=a;return}if(!(t[(t[w>>2]|0)+8>>2]|0)){s=a;return}if(!(t[(t[(t[w>>2]|0)+8>>2]|0)+24>>2]|0)){s=a;return}AAi[t[(t[(t[w>>2]|0)+8>>2]|0)+24>>2]&511](t[(t[w>>2]|0)+16>>2]|0,t[c>>2]|0,t[l>>2]|0,t[b>>2]|0,t[k>>2]|0,t[h>>2]|0);s=a;return}function Mh(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,u=0,a=0,o=0,c=0,l=0;f=s;s=s+32|0;u=f+16|0;a=f+12|0;o=f+8|0;c=f+4|0;l=f;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;t[c>>2]=n;t[l>>2]=t[u>>2];if(!(t[l>>2]|0)){s=f;return}if(!(t[(t[l>>2]|0)+8>>2]|0)){s=f;return}if(!(t[(t[(t[l>>2]|0)+8>>2]|0)+28>>2]|0)){s=f;return}NAi[t[(t[(t[l>>2]|0)+8>>2]|0)+28>>2]&511](t[(t[l>>2]|0)+16>>2]|0,t[a>>2]|0,t[o>>2]|0,t[c>>2]|0);s=f;return}function Rh(e,i,r,n,f,u,a){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;u=u|0;a=a|0;var o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0;o=s;s=s+32|0;c=o+28|0;l=o+24|0;b=o+20|0;k=o+16|0;h=o+12|0;w=o+8|0;d=o+4|0;v=o;t[c>>2]=e;t[l>>2]=i;t[b>>2]=r;t[k>>2]=n;t[h>>2]=f;t[w>>2]=u;t[d>>2]=a;t[v>>2]=t[c>>2];if(((t[v>>2]|0)!=0?(t[(t[v>>2]|0)+8>>2]|0)!=0:0)?(t[(t[(t[v>>2]|0)+8>>2]|0)+32>>2]|0)!=0:0){vAi[t[(t[(t[v>>2]|0)+8>>2]|0)+32>>2]&511](t[(t[v>>2]|0)+16>>2]|0,t[l>>2]|0,t[b>>2]|0,t[k>>2]|0,t[h>>2]|0,t[w>>2]|0,t[d>>2]|0);s=o;return}NM(t[d>>2]|0);s=o;return}function Nh(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,u=0,a=0,o=0,c=0,l=0;f=s;s=s+32|0;u=f+16|0;a=f+12|0;o=f+8|0;c=f+4|0;l=f;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;t[c>>2]=n;t[l>>2]=t[u>>2];if(!(t[l>>2]|0)){s=f;return}if(!(t[(t[l>>2]|0)+8>>2]|0)){s=f;return}if(!(t[(t[(t[l>>2]|0)+8>>2]|0)+36>>2]|0)){s=f;return}NAi[t[(t[(t[l>>2]|0)+8>>2]|0)+36>>2]&511](t[(t[l>>2]|0)+16>>2]|0,t[a>>2]|0,t[o>>2]|0,t[c>>2]|0);s=f;return}function Th(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;var u=0,a=0,o=0,c=0,l=0,b=0,k=0;u=s;s=s+32|0;a=u+20|0;o=u+16|0;c=u+12|0;l=u+8|0;b=u+4|0;k=u;t[a>>2]=e;t[o>>2]=i;t[c>>2]=r;t[l>>2]=n;t[b>>2]=f;t[k>>2]=t[a>>2];if(!(t[k>>2]|0)){s=u;return}if(!(t[(t[k>>2]|0)+8>>2]|0)){s=u;return}if(!(t[(t[(t[k>>2]|0)+8>>2]|0)+40>>2]|0)){s=u;return}mAi[t[(t[(t[k>>2]|0)+8>>2]|0)+40>>2]&511](t[(t[k>>2]|0)+16>>2]|0,t[o>>2]|0,t[c>>2]|0,t[l>>2]|0,t[b>>2]|0);s=u;return}function Lh(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0;r=s;s=s+16|0;n=r+8|0;f=r+4|0;u=r;t[n>>2]=e;t[f>>2]=i;t[u>>2]=t[n>>2];if(!(t[u>>2]|0)){s=r;return}if(!(t[(t[u>>2]|0)+8>>2]|0)){s=r;return}if(!(t[(t[(t[u>>2]|0)+8>>2]|0)+44>>2]|0)){s=r;return}EAi[t[(t[(t[u>>2]|0)+8>>2]|0)+44>>2]&511](t[(t[u>>2]|0)+16>>2]|0,t[f>>2]|0);s=r;return}function Dh(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i+4|0;n=i;t[r>>2]=e;t[n>>2]=t[r>>2];if(!(t[n>>2]|0)){s=i;return}if(!(t[(t[n>>2]|0)+8>>2]|0)){s=i;return}if(!(t[(t[(t[n>>2]|0)+8>>2]|0)+48>>2]|0)){s=i;return}pAi[t[(t[(t[n>>2]|0)+8>>2]|0)+48>>2]&511](t[(t[n>>2]|0)+16>>2]|0);s=i;return}function Ch(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i+4|0;n=i;t[r>>2]=e;t[n>>2]=t[r>>2];if(!(t[n>>2]|0)){s=i;return}if(!(t[(t[n>>2]|0)+8>>2]|0)){s=i;return}if(!(t[(t[(t[n>>2]|0)+8>>2]|0)+52>>2]|0)){s=i;return}pAi[t[(t[(t[n>>2]|0)+8>>2]|0)+52>>2]&511](t[(t[n>>2]|0)+16>>2]|0);s=i;return}function Ph(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0;n=s;s=s+16|0;f=n+12|0;u=n+8|0;a=n+4|0;o=n;t[f>>2]=e;t[u>>2]=i;t[a>>2]=r;t[o>>2]=t[f>>2];if(!(t[o>>2]|0)){s=n;return}if(!(t[(t[o>>2]|0)+8>>2]|0)){s=n;return}if(!(t[(t[(t[o>>2]|0)+8>>2]|0)+76>>2]|0)){s=n;return}yAi[t[(t[(t[o>>2]|0)+8>>2]|0)+76>>2]&511](t[(t[o>>2]|0)+16>>2]|0,t[u>>2]|0,t[a>>2]|0);s=n;return}function Bh(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0;r=s;s=s+16|0;n=r+8|0;f=r+4|0;u=r;t[n>>2]=e;t[f>>2]=i;t[u>>2]=t[n>>2];if(!(t[u>>2]|0)){s=r;return}if(!(t[(t[u>>2]|0)+8>>2]|0)){s=r;return}if(!(t[(t[(t[u>>2]|0)+8>>2]|0)+80>>2]|0)){s=r;return}EAi[t[(t[(t[u>>2]|0)+8>>2]|0)+80>>2]&511](t[(t[u>>2]|0)+16>>2]|0,t[f>>2]|0);s=r;return}function Ih(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0;r=s;s=s+32|0;n=r;f=r+16|0;u=r+8|0;t[f>>2]=e;t[r+12>>2]=i;t[u>>2]=t[f>>2];if(!(t[u>>2]|0)){s=r;return}if(!(t[(t[u>>2]|0)+8>>2]|0)){s=r;return}if(!(t[(t[(t[u>>2]|0)+8>>2]|0)+84>>2]|0)){s=r;return}u=t[33976]|0;f=t[33980]|0;t[n>>2]=140328;t[n+4>>2]=28421;yAi[u&511](f,140296,n);s=r;return}function Hh(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0;r=s;s=s+32|0;n=r;f=r+16|0;u=r+8|0;t[f>>2]=e;t[r+12>>2]=i;t[u>>2]=t[f>>2];if(!(t[u>>2]|0)){s=r;return}if(!(t[(t[u>>2]|0)+8>>2]|0)){s=r;return}if(!(t[(t[(t[u>>2]|0)+8>>2]|0)+88>>2]|0)){s=r;return}u=t[33976]|0;f=t[33980]|0;t[n>>2]=140328;t[n+4>>2]=28429;yAi[u&511](f,140296,n);s=r;return}function xh(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0;r=s;s=s+32|0;n=r;f=r+16|0;u=r+8|0;t[f>>2]=e;t[r+12>>2]=i;t[u>>2]=t[f>>2];if(!(t[u>>2]|0)){s=r;return}if(!(t[(t[u>>2]|0)+8>>2]|0)){s=r;return}if(!(t[(t[(t[u>>2]|0)+8>>2]|0)+92>>2]|0)){s=r;return}u=t[33976]|0;f=t[33980]|0;t[n>>2]=140328;t[n+4>>2]=28437;yAi[u&511](f,140296,n);s=r;return}function Uh(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0;r=s;s=s+16|0;n=r+12|0;f=r+8|0;u=r+4|0;a=r;t[f>>2]=e;t[u>>2]=i;t[a>>2]=t[f>>2];if(((t[a>>2]|0)!=0?(t[(t[a>>2]|0)+8>>2]|0)!=0:0)?(t[(t[(t[a>>2]|0)+8>>2]|0)+96>>2]|0)!=0:0){t[n>>2]=MAi[t[(t[(t[a>>2]|0)+8>>2]|0)+96>>2]&511](t[(t[a>>2]|0)+16>>2]|0,t[u>>2]|0)|0;o=t[n>>2]|0;s=r;return o|0}t[n>>2]=0;o=t[n>>2]|0;s=r;return o|0}function zh(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,u=0,a=0,o=0,c=0,l=0;f=s;s=s+32|0;u=f+16|0;a=f+12|0;o=f+8|0;c=f+4|0;l=f;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;t[c>>2]=n;t[l>>2]=t[u>>2];if(!(t[l>>2]|0)){s=f;return}if(!(t[(t[l>>2]|0)+8>>2]|0)){s=f;return}if(!(t[(t[(t[l>>2]|0)+8>>2]|0)+104>>2]|0)){s=f;return}NAi[t[(t[(t[l>>2]|0)+8>>2]|0)+104>>2]&511](t[(t[l>>2]|0)+16>>2]|0,t[a>>2]|0,t[o>>2]|0,t[c>>2]|0);s=f;return}function jh(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0;n=s;s=s+16|0;f=n+12|0;u=n+8|0;a=n+4|0;o=n;t[f>>2]=e;t[u>>2]=i;t[a>>2]=r;t[o>>2]=t[f>>2];if(!(t[o>>2]|0)){s=n;return}if((t[(t[o>>2]|0)+8>>2]|0)!=0?(t[(t[(t[o>>2]|0)+8>>2]|0)+68>>2]|0)!=0:0)yAi[t[(t[(t[o>>2]|0)+8>>2]|0)+68>>2]&511](t[(t[o>>2]|0)+16>>2]|0,t[u>>2]|0,t[a>>2]|0);if(!(t[(t[o>>2]|0)+148>>2]|0)){s=n;return}mh(t[(t[o>>2]|0)+148>>2]|0,t[u>>2]|0,t[a>>2]|0);s=n;return}function Vh(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0;n=s;s=s+16|0;f=n+12|0;u=n+8|0;a=n+4|0;o=n;t[f>>2]=e;t[u>>2]=i;t[a>>2]=r;t[o>>2]=t[f>>2];if(!(t[o>>2]|0)){s=n;return}if((t[(t[o>>2]|0)+8>>2]|0)!=0?(t[(t[(t[o>>2]|0)+8>>2]|0)+72>>2]|0)!=0:0)yAi[t[(t[(t[o>>2]|0)+8>>2]|0)+72>>2]&511](t[(t[o>>2]|0)+16>>2]|0,t[u>>2]|0,t[a>>2]|0);if(!(t[(t[o>>2]|0)+148>>2]|0)){s=n;return}mh(t[(t[o>>2]|0)+148>>2]|0,t[u>>2]|0,t[a>>2]|0);s=n;return}function qh(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0;n=s;s=s+16|0;f=n+12|0;u=n+8|0;a=n+4|0;o=n;t[f>>2]=e;t[u>>2]=i;t[a>>2]=r;t[o>>2]=t[f>>2];if(!(t[o>>2]|0)){s=n;return}if((t[(t[o>>2]|0)+8>>2]|0)!=0?(t[(t[(t[o>>2]|0)+8>>2]|0)+100>>2]|0)!=0:0)yAi[t[(t[(t[o>>2]|0)+8>>2]|0)+100>>2]&511](t[(t[o>>2]|0)+16>>2]|0,t[u>>2]|0,t[a>>2]|0);if(!(t[(t[o>>2]|0)+148>>2]|0)){s=n;return}_h(t[(t[o>>2]|0)+148>>2]|0,t[u>>2]|0,t[a>>2]|0);s=n;return}function Yh(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0;r=s;s=s+16|0;n=r+8|0;f=r+4|0;u=r;t[n>>2]=e;t[f>>2]=i;t[u>>2]=t[n>>2];if(!(t[u>>2]|0)){s=r;return}if(((t[u>>2]|0)!=0?(t[(t[u>>2]|0)+8>>2]|0)!=0:0)?(t[(t[(t[u>>2]|0)+8>>2]|0)+64>>2]|0)!=0:0)EAi[t[(t[(t[u>>2]|0)+8>>2]|0)+64>>2]&511](t[(t[u>>2]|0)+16>>2]|0,t[f>>2]|0);if(!(t[(t[u>>2]|0)+148>>2]|0)){s=r;return}ph(t[(t[u>>2]|0)+16>>2]|0,t[f>>2]|0);s=r;return}function Gh(e,i,r,n,f,u,a,o,c){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;u=u|0;a=a|0;o=o|0;c=c|0;var l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0;l=s;s=s+48|0;b=l+36|0;k=l+32|0;h=l+28|0;w=l+24|0;d=l+20|0;v=l+16|0;m=l+12|0;_=l+8|0;p=l+4|0;E=l;t[b>>2]=e;t[k>>2]=i;t[h>>2]=r;t[w>>2]=n;t[d>>2]=f;t[v>>2]=u;t[m>>2]=a;t[_>>2]=o;t[p>>2]=c;t[E>>2]=t[b>>2];if(!(t[E>>2]|0)){s=l;return}if((t[(t[E>>2]|0)+8>>2]|0)!=0?(t[(t[(t[E>>2]|0)+8>>2]|0)+116>>2]|0)!=0:0)FAi[t[(t[(t[E>>2]|0)+8>>2]|0)+116>>2]&511](t[(t[E>>2]|0)+16>>2]|0,t[k>>2]|0,t[h>>2]|0,t[w>>2]|0,t[d>>2]|0,t[v>>2]|0,t[m>>2]|0,t[_>>2]|0,t[p>>2]|0);if(!(t[(t[E>>2]|0)+148>>2]|0)){s=l;return}dh(t[(t[E>>2]|0)+148>>2]|0,t[k>>2]|0,t[h>>2]|0,t[w>>2]|0,t[d>>2]|0,t[v>>2]|0,t[m>>2]|0,t[_>>2]|0,t[p>>2]|0);s=l;return}function Wh(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,u=0,a=0,o=0,c=0,l=0;f=s;s=s+32|0;u=f+16|0;a=f+12|0;o=f+8|0;c=f+4|0;l=f;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;t[c>>2]=n;t[l>>2]=t[u>>2];if(!(t[l>>2]|0)){s=f;return}if((t[(t[l>>2]|0)+8>>2]|0)!=0?(t[(t[(t[l>>2]|0)+8>>2]|0)+120>>2]|0)!=0:0)NAi[t[(t[(t[l>>2]|0)+8>>2]|0)+120>>2]&511](t[(t[l>>2]|0)+16>>2]|0,t[a>>2]|0,t[o>>2]|0,t[c>>2]|0);if(!(t[(t[l>>2]|0)+148>>2]|0)){s=f;return}vh(t[(t[l>>2]|0)+148>>2]|0,t[a>>2]|0,t[o>>2]|0,t[c>>2]|0);s=f;return}function Kh(e){e=e|0;var i=0,r=0,n=0,f=0,u=0;i=s;s=s+16|0;r=i+8|0;n=i+4|0;f=i;t[n>>2]=e;t[(t[n>>2]|0)+52>>2]=0;t[(t[n>>2]|0)+56>>2]=0;t[(t[n>>2]|0)+96>>2]=-1;t[(t[n>>2]|0)+176>>2]=-1;t[(t[n>>2]|0)+92>>2]=0;t[(t[n>>2]|0)+184>>2]=0;t[(t[n>>2]|0)+188>>2]=0;do if(!(t[(t[n>>2]|0)+20>>2]|0)){t[(t[n>>2]|0)+92>>2]=1;if((t[(t[n>>2]|0)+88>>2]|0)==0?(fd(t[n>>2]|0)|0)==-1:0){t[r>>2]=-1;u=t[r>>2]|0;s=i;return u|0}t[f>>2]=t[(t[n>>2]|0)+88>>2];t[(t[f>>2]|0)+104>>2]=1;e=oh(t[f>>2]|0)|0;t[(t[n>>2]|0)+20>>2]=e;if(!(t[(t[n>>2]|0)+20>>2]|0)){t[r>>2]=-1;u=t[r>>2]|0;s=i;return u|0}e=ch(t[(t[f>>2]|0)+80>>2]|0)|0;t[(t[f>>2]|0)+28>>2]=e;if(t[(t[f>>2]|0)+28>>2]|0){t[t[(t[f>>2]|0)+28>>2]>>2]=t[(t[n>>2]|0)+20>>2];
	t[(t[f>>2]|0)+32>>2]=1;break}t[r>>2]=-1;u=t[r>>2]|0;s=i;return u|0}while(0);aO(t[(t[(t[n>>2]|0)+20>>2]|0)+48>>2]|0,357,t[n>>2]|0);t[r>>2]=0;u=t[r>>2]|0;s=i;return u|0}function Xh(e){e=e|0;var i=0,r=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if((t[(t[r>>2]|0)+92>>2]|0)!=0?(t[(t[r>>2]|0)+20>>2]|0)!=0:0){Ak(t[(t[r>>2]|0)+20>>2]|0);t[(t[r>>2]|0)+20>>2]=0}ud(t[r>>2]|0);s=i;return}function Zh(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,l=0;n=s;s=s+32|0;f=n+16|0;u=n+12|0;a=n+8|0;o=n+4|0;c=n;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;if((t[u>>2]|0)!=0?!((t[a>>2]|0)==0&(t[o>>2]|0)==0):0){if(t[a>>2]|0)t[t[a>>2]>>2]=0;if(t[o>>2]|0)t[t[o>>2]>>2]=0;t[c>>2]=t[u>>2];if(!(t[(t[c>>2]|0)+36>>2]|0)){t[f>>2]=-1;l=t[f>>2]|0;s=n;return l|0}if(t[a>>2]|0)t[t[a>>2]>>2]=t[(t[(t[c>>2]|0)+36>>2]|0)+4>>2];if(t[o>>2]|0)t[t[o>>2]>>2]=t[(t[(t[c>>2]|0)+36>>2]|0)+28>>2];t[f>>2]=0;l=t[f>>2]|0;s=n;return l|0}t[f>>2]=-1;l=t[f>>2]|0;s=n;return l|0}function Jh(e){e=e|0;var i=0,r=0,n=0,f=0,u=0;i=s;s=s+16|0;r=i+12|0;n=i+8|0;f=i+4|0;u=i;t[r>>2]=e;if(!(t[r>>2]|0)){s=i;return}if(!(t[(t[r>>2]|0)+4>>2]|0)){s=i;return}t[f>>2]=t[t[r>>2]>>2];t[u>>2]=0;while(1){if((t[u>>2]|0)>=(t[(t[r>>2]|0)+4>>2]|0))break;t[n>>2]=t[(t[f>>2]|0)+(t[u>>2]<<2)>>2];e:do if(t[n>>2]|0)do switch(t[t[n>>2]>>2]|0){case 18:{wd(t[n>>2]|0);break e;break}case 26:{od(t[n>>2]|0);break e;break}case 8:case 7:case 6:{sd(t[n>>2]|0);break e;break}case 14:{ld(t[n>>2]|0);break e;break}case 2e3:{dd(t[n>>2]|0);break e;break}case 25:{if(t[(t[n>>2]|0)+4>>2]|0)Yk(t[(t[n>>2]|0)+4>>2]|0);pAi[t[135736>>2]&511](t[n>>2]|0);break e;break}case 5:case 4:{Ok(t[n>>2]|0);break e;break}case 15:{ad(t[n>>2]|0);break e;break}case 17:{kd(t[n>>2]|0);break e;break}case 16:{bd(t[n>>2]|0);break e;break}case 2001:{cd(t[n>>2]|0);break e;break}case 24:case 22:case 23:{hd(t[n>>2]|0);break e;break}case 21:case 2:{yk(t[n>>2]|0);break e;break}default:{md(0,170280,vd(t[n>>2]|0)|0);break e}}while(0);while(0);t[u>>2]=(t[u>>2]|0)+1}t[(t[r>>2]|0)+4>>2]=0;s=i;return}function Qh(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0;n=s;s=s+16|0;f=n+8|0;u=n+4|0;a=n;t[f>>2]=e;t[u>>2]=i;t[a>>2]=r;if(t[f>>2]|0){r=(t[f>>2]|0)+20|0;t[r>>2]=(t[r>>2]|0)+1}dp(16,2,t[a>>2]|0,0,t[u>>2]|0);s=n;return}function $h(e){e=e|0;var i=0,r=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if(!(t[r>>2]|0)){s=i;return}if(t[(t[r>>2]|0)+4>>2]|0)Wk(t[(t[r>>2]|0)+4>>2]|0);pAi[t[135736>>2]&511](t[r>>2]|0);s=i;return}function ew(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i+4|0;n=i;t[r>>2]=e;while(1){if(!(t[r>>2]|0))break;t[n>>2]=t[r>>2];t[r>>2]=t[t[r>>2]>>2];pAi[t[135736>>2]&511](t[n>>2]|0)}s=i;return}function iw(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0;r=s;s=s+32|0;n=r+20|0;f=r+16|0;u=r+12|0;a=r+8|0;o=r+4|0;c=r;t[n>>2]=e;t[f>>2]=i;while(1){if(!(t[f>>2]|0))break;t[u>>2]=t[(t[f>>2]|0)+8>>2];e:do if(t[(t[f>>2]|0)+24>>2]|0){t[a>>2]=0;while(1){if((t[a>>2]|0)>=(t[(t[f>>2]|0)+28>>2]|0))break e;if(t[(t[(t[f>>2]|0)+24>>2]|0)+(t[a>>2]<<2)>>2]|0){pAi[t[135736>>2]&511](t[(t[(t[f>>2]|0)+24>>2]|0)+(t[a>>2]<<2)>>2]|0);t[(t[(t[f>>2]|0)+24>>2]|0)+(t[a>>2]<<2)>>2]=0}t[a>>2]=(t[a>>2]|0)+1}}while(0);if(t[(t[f>>2]|0)+32>>2]|0){e:do if((t[(t[f>>2]|0)+20>>2]|0)==24){t[o>>2]=0;while(1){if((t[o>>2]|0)>=(t[(t[(t[f>>2]|0)+32>>2]|0)+4>>2]|0))break e;t[c>>2]=t[(t[t[(t[f>>2]|0)+32>>2]>>2]|0)+(t[o>>2]<<2)>>2];pAi[t[135736>>2]&511](t[(t[c>>2]|0)+4>>2]|0);pAi[t[135736>>2]&511](t[c>>2]|0);t[o>>2]=(t[o>>2]|0)+1}}while(0);Wk(t[(t[f>>2]|0)+32>>2]|0);t[(t[f>>2]|0)+32>>2]=0}t[(t[f>>2]|0)+8>>2]=0;if(t[(t[n>>2]|0)+124>>2]|0)t[(t[f>>2]|0)+12>>2]=t[(t[n>>2]|0)+124>>2];t[(t[n>>2]|0)+124>>2]=t[f>>2];t[f>>2]=t[u>>2]}s=r;return}function rw(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i+4|0;n=i;t[r>>2]=e;while(1){if(!(t[r>>2]|0))break;t[n>>2]=t[r>>2];t[r>>2]=t[t[r>>2]>>2];_d(t[n>>2]|0)}s=i;return}function nw(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;var u=0,a=0,o=0,c=0,l=0,b=0,k=0;u=s;s=s+32|0;a=u+20|0;o=u+16|0;c=u+12|0;l=u+8|0;b=u+4|0;k=u;t[a>>2]=e;t[o>>2]=i;t[c>>2]=r;t[l>>2]=n;t[b>>2]=f;t[k>>2]=0;if(!(t[a>>2]|0)){s=u;return}t[k>>2]=Yl(158256)|0;t[k>>2]=us(t[k>>2]|0,t[o>>2]|0)|0;t[k>>2]=us(t[k>>2]|0,144448)|0;t[k>>2]=us(t[k>>2]|0,t[c>>2]|0)|0;t[k>>2]=us(t[k>>2]|0,142704)|0;c=t[a>>2]|0;if((t[t[a>>2]>>2]|0)!=2){if((t[c>>2]|0)==1)pd(t[a>>2]|0,3069,0,t[k>>2]|0,t[l>>2]|0,t[b>>2]|0)}else pd(c,1818,0,t[k>>2]|0,t[l>>2]|0,t[b>>2]|0);if(!(t[k>>2]|0)){s=u;return}pAi[t[135736>>2]&511](t[k>>2]|0);t[k>>2]=0;s=u;return}function fw(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0;r=s;s=s+16|0;n=r+8|0;f=r+4|0;u=r;t[f>>2]=e;t[u>>2]=i;i=Ed(t[f>>2]|0)|0;if((i|0)==3)t[n>>2]=TD(t[u>>2]|0)|0;else if((i|0)==2)t[n>>2]=ND(t[u>>2]|0)|0;else t[n>>2]=0;s=r;return t[n>>2]|0}function tw(e,i,r,n,f,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;u=u|0;var a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0;a=s;s=s+48|0;o=a+44|0;c=a+40|0;l=a+36|0;b=a+32|0;k=a+28|0;h=a+24|0;w=a+20|0;d=a+16|0;v=a+12|0;m=a+8|0;_=a+4|0;p=a;t[c>>2]=e;t[l>>2]=i;t[b>>2]=r;t[k>>2]=n;t[h>>2]=f;t[w>>2]=u;if((t[c>>2]|0)!=0?(t[(t[c>>2]|0)+20>>2]|0)==0:0){rh(t[c>>2]|0,157712,157744);t[o>>2]=-1;E=t[o>>2]|0;s=a;return E|0}t[d>>2]=qg(t[k>>2]|0,1)|0;if(t[d>>2]|0){t[o>>2]=t[d>>2];E=t[o>>2]|0;s=a;return E|0}t[v>>2]=0;t[m>>2]=0;t[v>>2]=zg(t[k>>2]|0,m)|0;if(!(t[m>>2]|0)){if(!(gd(t[l>>2]|0,t[k>>2]|0,0)|0)){t[o>>2]=1;E=t[o>>2]|0;s=a;return E|0}if((t[w>>2]|0)!=0&(t[h>>2]|0)!=0?(u=OD(Yl(t[k>>2]|0)|0,0)|0,t[t[h>>2]>>2]=u,(t[t[h>>2]>>2]|0)==0):0)t[d>>2]=-1}else{t[_>>2]=0;do if(!(t[c>>2]|0))if(t[b>>2]|0){t[p>>2]=wF(t[(t[b>>2]|0)+32>>2]|0,t[b>>2]|0,t[m>>2]|0)|0;if(!(t[p>>2]|0))break;t[_>>2]=t[(t[p>>2]|0)+8>>2];break}else{pAi[t[135736>>2]&511](t[m>>2]|0);pAi[t[135736>>2]&511](t[v>>2]|0);t[o>>2]=1;E=t[o>>2]|0;s=a;return E|0}else t[_>>2]=Sd(t[c>>2]|0,t[m>>2]|0)|0;while(0);if(!(t[_>>2]|0)){pAi[t[135736>>2]&511](t[m>>2]|0);pAi[t[135736>>2]&511](t[v>>2]|0);t[o>>2]=1;E=t[o>>2]|0;s=a;return E|0}if(gd(t[l>>2]|0,t[v>>2]|0,t[_>>2]|0)|0){if((t[w>>2]|0)!=0&(t[h>>2]|0)!=0?(w=Yl(t[v>>2]|0)|0,l=OD(w,Yl(t[_>>2]|0)|0)|0,t[t[h>>2]>>2]=l,(t[t[h>>2]>>2]|0)==0):0)t[d>>2]=-1}else t[d>>2]=1;pAi[t[135736>>2]&511](t[m>>2]|0);pAi[t[135736>>2]&511](t[v>>2]|0)}t[o>>2]=t[d>>2];E=t[o>>2]|0;s=a;return E|0}function uw(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0;f=s;s=s+48|0;u=f+32|0;a=f+28|0;o=f+24|0;c=f+20|0;l=f+16|0;b=f+12|0;k=f+8|0;h=f+4|0;w=f;t[a>>2]=e;t[o>>2]=i;t[c>>2]=r;t[l>>2]=n;t[w>>2]=0;t[b>>2]=qg(t[o>>2]|0,1)|0;if(t[b>>2]|0)if((t[b>>2]|0)==-1){rh(t[a>>2]|0,157656,157680);t[u>>2]=-1;d=t[u>>2]|0;s=f;return d|0}else{t[u>>2]=1824;d=t[u>>2]|0;s=f;return d|0}t[h>>2]=zg(t[o>>2]|0,w)|0;if(!(t[h>>2]|0))t[h>>2]=Yl(t[o>>2]|0)|0;t[k>>2]=Sd(t[a>>2]|0,t[w>>2]|0)|0;if((t[w>>2]|0)!=0?(pAi[t[135736>>2]&511](t[w>>2]|0),(t[k>>2]|0)==0):0){t[b>>2]=1824;w=t[a>>2]|0;a=t[b>>2]|0;n=ED(21)|0;th(w,a,0,n,154112,t[o>>2]|0,0);if(t[h>>2]|0)pAi[t[135736>>2]&511](t[h>>2]|0);t[u>>2]=t[b>>2];d=t[u>>2]|0;s=f;return d|0}do if((t[l>>2]|0)!=0&(t[c>>2]|0)!=0)if(t[k>>2]|0){b=Yl(t[k>>2]|0)|0;o=AD(b,t[h>>2]|0)|0;t[t[c>>2]>>2]=o;break}else{o=AD(0,t[h>>2]|0)|0;t[t[c>>2]>>2]=o;break}else pAi[t[135736>>2]&511](t[h>>2]|0);while(0);t[u>>2]=0;d=t[u>>2]|0;s=f;return d|0}function aw(e,i,r,n,f,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;u=u|0;a=a|0;o=o|0;var c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0,S=0,g=0,y=0,F=0,O=0,A=0,M=0,R=0,N=0;c=s;s=s+80|0;l=c+68|0;b=c+64|0;k=c+60|0;h=c+56|0;w=c+52|0;d=c+48|0;v=c+44|0;m=c+40|0;_=c+36|0;p=c+32|0;E=c+28|0;S=c+24|0;g=c+20|0;y=c+16|0;F=c+12|0;O=c+8|0;A=c+4|0;M=c;t[b>>2]=e;t[k>>2]=i;t[h>>2]=r;t[w>>2]=n;t[d>>2]=f;t[v>>2]=u;t[m>>2]=a;t[_>>2]=o;t[E>>2]=0;t[F>>2]=0;if((t[t[h>>2]>>2]|0)==1){t[l>>2]=0;R=t[l>>2]|0;s=c;return R|0}e:do if(t[(t[h>>2]|0)+96>>2]|0){o=t[h>>2]|0;i:do if(t[(t[h>>2]|0)+48>>2]&256){t[S>>2]=yd(o)|0;do if((t[(t[S>>2]|0)+88>>2]|0)==1)N=9;else{if((t[t[S>>2]>>2]|0)==1?(t[(t[S>>2]|0)+88>>2]|0)==46:0){N=9;break}t[O>>2]=3}while(0);if((N|0)==9)t[O>>2]=Ed(t[h>>2]|0)|0;if(!(t[v>>2]|0))t[w>>2]=t[w>>2];else t[w>>2]=qD(t[v>>2]|0)|0;t[p>>2]=0;t[g>>2]=t[(t[h>>2]|0)+96>>2];while(1){if(!(t[g>>2]|0))break i;switch(t[t[(t[g>>2]|0)+4>>2]>>2]|0){case 1010:case 1011:case 1009:{t[p>>2]=zD(t[(t[g>>2]|0)+4>>2]|0,t[w>>2]|0,t[d>>2]|0,t[v>>2]|0,F,t[O>>2]|0)|0;N=19;break}case 1007:case 1006:case 1008:break;default:{t[p>>2]=jD(t[(t[g>>2]|0)+4>>2]|0,t[O>>2]|0,t[w>>2]|0,t[d>>2]|0,t[v>>2]|0,t[O>>2]|0)|0;N=19}}if((N|0)==19){N=0;if((t[p>>2]|0)<0){N=20;break}if((t[p>>2]|0)>0){if(!(t[_>>2]|0)){N=24;break}Fd(t[b>>2]|0,t[p>>2]|0,t[k>>2]|0,t[d>>2]|0,t[F>>2]|0,t[h>>2]|0,t[(t[g>>2]|0)+4>>2]|0,0,0,0);if(!(t[E>>2]|0))t[E>>2]=t[p>>2]}t[p>>2]=0}t[g>>2]=t[t[g>>2]>>2]}if((N|0)==20){rh(t[b>>2]|0,156584,156608);t[l>>2]=-1;R=t[l>>2]|0;s=c;return R|0}else if((N|0)==24){t[l>>2]=t[p>>2];R=t[l>>2]|0;s=c;return R|0}}else if(!(t[o+48>>2]&64))break e;while(0);if(t[(t[h>>2]|0)+48>>2]&64){t[p>>2]=0;t[g>>2]=t[(t[h>>2]|0)+96>>2];while(1){if(!(t[g>>2]|0))break e;if(((t[t[(t[g>>2]|0)+4>>2]>>2]|0)+-1009|0)>>>0<3){t[p>>2]=xD(t[(t[g>>2]|0)+4>>2]|0,t[d>>2]|0,t[m>>2]|0,0)|0;if((t[p>>2]|0)<0){N=33;break}if((t[p>>2]|0)>0){if(!(t[_>>2]|0)){N=37;break}Fd(t[b>>2]|0,t[p>>2]|0,t[k>>2]|0,t[d>>2]|0,t[m>>2]|0,t[h>>2]|0,t[(t[g>>2]|0)+4>>2]|0,0,0,0);if(!(t[E>>2]|0))t[E>>2]=t[p>>2]}t[p>>2]=0}t[g>>2]=t[t[g>>2]>>2]}if((N|0)==33){rh(t[b>>2]|0,156584,156648);t[l>>2]=-1;R=t[l>>2]|0;s=c;return R|0}else if((N|0)==37){t[l>>2]=t[p>>2];R=t[l>>2]|0;s=c;return R|0}}}while(0);do if((t[E>>2]|0)>=0){t[A>>2]=0;t[p>>2]=0;t[S>>2]=t[h>>2];e:do{t[y>>2]=t[(t[S>>2]|0)+68>>2];while(1){if(!(t[y>>2]|0))break;if((t[t[y>>2]>>2]|0)==1007){t[A>>2]=1;t[p>>2]=Od(t[(t[y>>2]|0)+32>>2]|0,t[v>>2]|0)|0;if((t[p>>2]|0)==1)break;if((t[p>>2]|0)<0){N=48;break e}}t[y>>2]=t[(t[y>>2]|0)+4>>2]}if((t[p>>2]|0)!=0|(t[A>>2]|0)!=0)break;t[S>>2]=t[(t[S>>2]|0)+64>>2];if(!(t[S>>2]|0))break}while((t[t[S>>2]>>2]|0)!=1);if((N|0)==48){rh(t[b>>2]|0,156584,156688);t[l>>2]=-1;R=t[l>>2]|0;s=c;return R|0}if((t[A>>2]|0)!=0&(t[p>>2]|0)==0){t[p>>2]=1840;if(t[_>>2]|0){Fd(t[b>>2]|0,t[p>>2]|0,t[k>>2]|0,t[d>>2]|0,0,t[h>>2]|0,0,0,0,0);if(t[E>>2]|0)break;t[E>>2]=t[p>>2];break}else{t[l>>2]=t[p>>2];R=t[l>>2]|0;s=c;return R|0}}}while(0);e:do if((t[E>>2]|0)>=0){t[S>>2]=t[h>>2];t[y>>2]=0;i:while(1){t[M>>2]=0;t[g>>2]=t[(t[S>>2]|0)+96>>2];while(1){if(!(t[g>>2]|0))break;if((t[t[(t[g>>2]|0)+4>>2]>>2]|0)==1006){t[M>>2]=1;t[p>>2]=eb(t[(t[(t[g>>2]|0)+4>>2]|0)+36>>2]|0,t[d>>2]|0)|0;if((t[p>>2]|0)==1)break;if((t[p>>2]|0)<0){N=65;break i}t[y>>2]=t[(t[g>>2]|0)+4>>2]}t[g>>2]=t[t[g>>2]>>2]}if((t[M>>2]|0)!=0&(t[p>>2]|0)!=1)break;t[S>>2]=t[(t[S>>2]|0)+64>>2];if(!(t[S>>2]|0))break e;if((t[t[S>>2]>>2]|0)==1)break e}if((N|0)==65){rh(t[b>>2]|0,156584,156728);t[l>>2]=-1;R=t[l>>2]|0;s=c;return R|0}t[p>>2]=1839;if(t[_>>2]|0){Fd(t[b>>2]|0,t[p>>2]|0,t[k>>2]|0,t[d>>2]|0,0,t[h>>2]|0,t[y>>2]|0,0,0,0);if(t[E>>2]|0)break;t[E>>2]=t[p>>2];break}else{t[l>>2]=t[p>>2];R=t[l>>2]|0;s=c;return R|0}}while(0);t[l>>2]=t[E>>2];R=t[l>>2]|0;s=c;return R|0}function ow(e,i,r,n,f,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;u=u|0;var a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0;a=s;s=s+32|0;o=a+28|0;c=a+24|0;l=a+20|0;b=a+16|0;k=a+12|0;h=a+8|0;w=a+4|0;d=a;t[o>>2]=e;t[c>>2]=i;t[l>>2]=r;t[b>>2]=n;t[k>>2]=f;t[h>>2]=u;t[w>>2]=0;bw(w,t[o>>2]|0,t[l>>2]|0)|0;if((t[h>>2]|0)==0?(Ad(t[o>>2]|0,t[l>>2]|0)|0)!=2:0)t[w>>2]=us(t[w>>2]|0,154288)|0;else t[w>>2]=us(t[w>>2]|0,154256)|0;u=(Md(t[k>>2]|0)|0)!=0;f=t[w>>2]|0;if(u)t[w>>2]=us(f,154352)|0;else t[w>>2]=us(f,154336)|0;do if(!(t[(t[k>>2]|0)+48>>2]&256)){if(t[(t[k>>2]|0)+48>>2]&64){t[w>>2]=us(t[w>>2]|0,147936)|0;break}if(t[(t[k>>2]|0)+48>>2]&128)t[w>>2]=us(t[w>>2]|0,147952)|0}else t[w>>2]=us(t[w>>2]|0,147920)|0;while(0);if(Md(t[k>>2]|0)|0){t[d>>2]=0;t[w>>2]=us(t[w>>2]|0,143656)|0;f=t[w>>2]|0;if(t[(t[k>>2]|0)+88>>2]|0){t[w>>2]=us(f,154360)|0;t[w>>2]=us(t[w>>2]|0,t[(t[k>>2]|0)+8>>2]|0)|0}else t[w>>2]=us(f,uh(d,t[(t[k>>2]|0)+112>>2]|0,t[(t[k>>2]|0)+8>>2]|0)|0)|0;t[w>>2]=us(t[w>>2]|0,142568)|0;if(t[d>>2]|0){pAi[t[135736>>2]&511](t[d>>2]|0);t[d>>2]=0}}t[w>>2]=us(t[w>>2]|0,142704)|0;if((t[h>>2]|0)==0?(Ad(t[o>>2]|0,t[l>>2]|0)|0)!=2:0)pd(t[o>>2]|0,t[c>>2]|0,t[l>>2]|0,t[w>>2]|0,0,0);else pd(t[o>>2]|0,t[c>>2]|0,t[l>>2]|0,t[w>>2]|0,t[b>>2]|0,0);if(!(t[w>>2]|0)){s=a;return}pAi[t[135736>>2]&511](t[w>>2]|0);t[w>>2]=0;s=a;return}function cw(e){e=e|0;var i=0,r=0,n=0,f=0,u=0,a=0;i=s;s=s+16|0;r=i+4|0;n=i;t[n>>2]=e;while(1){if(!(t[n>>2]|0)){f=7;break}if((t[t[n>>2]>>2]|0)!=4){f=7;break}u=t[n>>2]|0;if(t[(t[n>>2]|0)+92>>2]|0){f=5;break}t[n>>2]=t[u+64>>2]}if((f|0)==5){t[r>>2]=t[u+92>>2];a=t[r>>2]|0;s=i;return a|0}else if((f|0)==7){t[r>>2]=0;a=t[r>>2]|0;s=i;return a|0}return 0}function lw(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i+4|0;n=i;t[n>>2]=e;do switch(t[t[n>>2]>>2]|0){case 21:case 2:{t[r>>2]=t[(t[n>>2]|0)+12>>2];break}case 15:{t[r>>2]=t[(t[n>>2]|0)+52>>2];break}case 16:{t[r>>2]=t[(t[n>>2]|0)+32>>2];break}case 2e3:{t[r>>2]=t[(t[n>>2]|0)+20>>2];break}case 24:case 23:case 22:{t[r>>2]=t[(t[n>>2]|0)+12>>2];break}case 8:case 7:case 6:{t[r>>2]=t[(t[n>>2]|0)+16>>2];break}case 25:{t[r>>2]=t[(t[n>>2]|0)+24>>2];break}case 26:{t[r>>2]=t[(t[n>>2]|0)+20>>2];break}case 17:{t[r>>2]=t[(t[n>>2]|0)+24>>2];break}case 4:case 5:{t[r>>2]=t[(t[n>>2]|0)+36>>2];break}case 14:{t[r>>2]=t[(t[n>>2]|0)+36>>2];break}default:t[r>>2]=0}while(0);s=i;return t[r>>2]|0}function sw(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0;f=s;s=s+64|0;u=f+48|0;a=f+44|0;o=f+40|0;c=f+36|0;l=f+32|0;b=f+28|0;k=f+24|0;h=f+20|0;w=f+16|0;d=f+12|0;v=f+8|0;m=f+4|0;_=f;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;t[c>>2]=n;t[l>>2]=0;t[b>>2]=1;if(t[t[u>>2]>>2]|0){pAi[t[135736>>2]&511](t[t[u>>2]>>2]|0);t[t[u>>2]>>2]=0}e:do if(t[a>>2]|0){n=Yl(t[a>>2]|0)|0;t[t[u>>2]>>2]=n}else{if(!(t[o>>2]|0)){t[b>>2]=0;break}do switch(t[t[o>>2]>>2]|0){case 4:{t[h>>2]=t[o>>2];if(t[(t[h>>2]|0)+48>>2]&8){n=Yl(142672)|0;t[t[u>>2]>>2]=n}else{n=Yl(147912)|0;t[t[u>>2]>>2]=n}do if(!(t[(t[h>>2]|0)+48>>2]&256)){if(t[(t[h>>2]|0)+48>>2]&64){n=us(t[t[u>>2]>>2]|0,147936)|0;t[t[u>>2]>>2]=n;break}n=t[t[u>>2]>>2]|0;if(t[(t[h>>2]|0)+48>>2]&128){r=us(n,147952)|0;t[t[u>>2]>>2]=r;break}else{r=us(n,147968)|0;t[t[u>>2]>>2]=r;break}}else{r=us(t[t[u>>2]>>2]|0,147920)|0;t[t[u>>2]>>2]=r}while(0);if(!(t[(t[h>>2]|0)+48>>2]&8))break e;r=us(t[t[u>>2]>>2]|0,143656)|0;t[t[u>>2]>>2]=r;r=us(t[t[u>>2]>>2]|0,t[(t[h>>2]|0)+8>>2]|0)|0;t[t[u>>2]>>2]=r;r=us(t[t[u>>2]>>2]|0,142568)|0;t[t[u>>2]>>2]=r;break e;break}case 15:{t[v>>2]=t[o>>2];r=Yl(148032)|0;t[t[u>>2]>>2]=r;r=us(t[t[u>>2]>>2]|0,143656)|0;t[t[u>>2]>>2]=r;r=us(t[t[u>>2]>>2]|0,uh(l,t[(t[v>>2]|0)+56>>2]|0,t[(t[v>>2]|0)+8>>2]|0)|0)|0;t[t[u>>2]>>2]=r;if(t[l>>2]|0){pAi[t[135736>>2]&511](t[l>>2]|0);t[l>>2]=0}r=us(t[t[u>>2]>>2]|0,142568)|0;t[t[u>>2]>>2]=r;break e;break}case 16:{Nd(t[u>>2]|0,t[o>>2]|0)|0;break e;break}case 5:{t[w>>2]=t[o>>2];if(t[(t[w>>2]|0)+48>>2]&8){r=Yl(142672)|0;t[t[u>>2]>>2]=r}else{r=Yl(147912)|0;t[t[u>>2]>>2]=r}r=us(t[t[u>>2]>>2]|0,147984)|0;t[t[u>>2]>>2]=r;if(!(t[(t[w>>2]|0)+48>>2]&8))break e;r=us(t[t[u>>2]>>2]|0,143656)|0;t[t[u>>2]>>2]=r;r=us(t[t[u>>2]>>2]|0,t[(t[w>>2]|0)+8>>2]|0)|0;t[t[u>>2]>>2]=r;r=us(t[t[u>>2]>>2]|0,142568)|0;t[t[u>>2]>>2]=r;break e;break}case 24:case 23:case 22:{do if((t[t[o>>2]>>2]|0)!=22)if((t[t[o>>2]>>2]|0)==23){r=Yl(148080)|0;t[t[u>>2]>>2]=r;break}else{r=Yl(148088)|0;t[t[u>>2]>>2]=r;break}else{r=Yl(148064)|0;t[t[u>>2]>>2]=r}while(0);r=us(t[t[u>>2]>>2]|0,t[(t[o>>2]|0)+16>>2]|0)|0;t[t[u>>2]>>2]=r;r=us(t[t[u>>2]>>2]|0,142568)|0;t[t[u>>2]>>2]=r;break e;break}case 14:{t[m>>2]=t[o>>2];r=Yl(148048)|0;t[t[u>>2]>>2]=r;r=us(t[t[u>>2]>>2]|0,143656)|0;t[t[u>>2]>>2]=r;r=us(t[t[u>>2]>>2]|0,uh(l,t[(t[m>>2]|0)+52>>2]|0,t[(t[m>>2]|0)+8>>2]|0)|0)|0;t[t[u>>2]>>2]=r;r=us(t[t[u>>2]>>2]|0,142568)|0;t[t[u>>2]>>2]=r;break e;break}case 1:{t[k>>2]=t[o>>2];do if(!(t[(t[k>>2]|0)+48>>2]&256)){if(t[(t[k>>2]|0)+48>>2]&64){r=Yl(147856)|0;t[t[u>>2]>>2]=r;break}if(t[(t[k>>2]|0)+48>>2]&128){r=Yl(147872)|0;t[t[u>>2]>>2]=r;break}else{r=Yl(147888)|0;t[t[u>>2]>>2]=r;break}}else{r=Yl(147832)|0;t[t[u>>2]>>2]=r}while(0);r=us(t[t[u>>2]>>2]|0,t[(t[k>>2]|0)+8>>2]|0)|0;t[t[u>>2]>>2]=r;r=us(t[t[u>>2]>>2]|0,142568)|0;t[t[u>>2]>>2]=r;break e;break}case 17:{r=Yl(148128)|0;t[t[u>>2]>>2]=r;r=us(t[t[u>>2]>>2]|0,143656)|0;t[t[u>>2]>>2]=r;r=us(t[t[u>>2]>>2]|0,Rd(l,t[o>>2]|0)|0)|0;t[t[u>>2]>>2]=r;r=us(t[t[u>>2]>>2]|0,142568)|0;t[t[u>>2]>>2]=r;if(!(t[l>>2]|0))break e;pAi[t[135736>>2]&511](t[l>>2]|0);t[l>>2]=0;break e;break}case 25:case 8:case 7:case 6:{r=Yl(vd(t[o>>2]|0)|0)|0;t[t[u>>2]>>2]=r;break e;break}case 21:case 2:{r=Yl(Td(t[(t[o>>2]|0)+24>>2]|0)|0)|0;t[t[u>>2]>>2]=r;r=us(t[t[u>>2]>>2]|0,148104)|0;t[t[u>>2]>>2]=r;break e;break}case 18:{r=Yl(vd(t[o>>2]|0)|0)|0;t[t[u>>2]>>2]=r;r=us(t[t[u>>2]>>2]|0,143656)|0;t[t[u>>2]>>2]=r;r=us(t[t[u>>2]>>2]|0,Rd(l,t[o>>2]|0)|0)|0;t[t[u>>2]>>2]=r;r=us(t[t[u>>2]>>2]|0,142568)|0;t[t[u>>2]>>2]=r;if(t[l>>2]|0){pAi[t[135736>>2]&511](t[l>>2]|0);t[l>>2]=0}break}case 1011:case 1010:case 1009:case 1008:case 1007:case 1006:case 1005:case 1004:case 1003:case 1002:case 1001:case 1e3:{r=Yl(148120)|0;t[t[u>>2]>>2]=r;r=us(t[t[u>>2]>>2]|0,fh(t[t[o>>2]>>2]|0)|0)|0;t[t[u>>2]>>2]=r;r=us(t[t[u>>2]>>2]|0,142568)|0;t[t[u>>2]>>2]=r;break e;break}case 26:{t[d>>2]=t[o>>2];r=Yl(148e3)|0;t[t[u>>2]>>2]=r;r=t[t[u>>2]>>2]|0;if(!(t[(t[d>>2]|0)+12>>2]|0)){n=us(r,148016)|0;t[t[u>>2]>>2]=n;break e}n=us(r,142568)|0;t[t[u>>2]>>2]=n;n=us(t[t[u>>2]>>2]|0,Rd(l,t[(t[d>>2]|0)+12>>2]|0)|0)|0;t[t[u>>2]>>2]=n;if(t[l>>2]|0){pAi[t[135736>>2]&511](t[l>>2]|0);t[l>>2]=0}n=us(t[t[u>>2]>>2]|0,142568)|0;t[t[u>>2]>>2]=n;break e;break}default:{}}while(0);t[b>>2]=0}while(0);if((t[b>>2]|0)==0&(t[c>>2]|0)!=0){b=t[c>>2]|0;if((t[(t[c>>2]|0)+4>>2]|0)==2)t[_>>2]=t[b+20>>2];else t[_>>2]=b;b=Yl(144464)|0;t[t[u>>2]>>2]=b;b=t[t[u>>2]>>2]|0;d=t[_>>2]|0;if(t[(t[_>>2]|0)+36>>2]|0){o=us(b,uh(l,t[(t[d+36>>2]|0)+8>>2]|0,t[(t[_>>2]|0)+8>>2]|0)|0)|0;t[t[u>>2]>>2]=o;if(t[l>>2]|0){pAi[t[135736>>2]&511](t[l>>2]|0);t[l>>2]=0}}else{o=us(b,t[d+8>>2]|0)|0;t[t[u>>2]>>2]=o}o=us(t[t[u>>2]>>2]|0,142568)|0;t[t[u>>2]>>2]=o}if((t[c>>2]|0)!=0?(t[(t[c>>2]|0)+4>>2]|0)==2:0){o=us(t[t[u>>2]>>2]|0,148152)|0;t[t[u>>2]>>2]=o;o=t[t[u>>2]>>2]|0;d=t[c>>2]|0;if(t[(t[c>>2]|0)+36>>2]|0){b=us(o,uh(l,t[(t[d+36>>2]|0)+8>>2]|0,t[(t[c>>2]|0)+8>>2]|0)|0)|0;t[t[u>>2]>>2]=b;if(t[l>>2]|0){pAi[t[135736>>2]&511](t[l>>2]|0);t[l>>2]=0}}else{b=us(o,t[d+8>>2]|0)|0;t[t[u>>2]>>2]=b}b=us(t[t[u>>2]>>2]|0,142568)|0;t[t[u>>2]>>2]=b}if(!(t[l>>2]|0)){p=t[u>>2]|0;E=t[p>>2]|0;s=f;return E|0}pAi[t[135736>>2]&511](t[l>>2]|0);t[l>>2]=0;p=t[u>>2]|0;E=t[p>>2]|0;s=f;return E|0}function bw(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0;n=s;s=s+48|0;f=n;u=n+36|0;a=n+32|0;o=n+28|0;c=n+24|0;l=n+20|0;b=n+16|0;k=n+12|0;h=n+8|0;t[a>>2]=e;t[o>>2]=i;t[c>>2]=r;t[l>>2]=0;t[t[a>>2]>>2]=0;if(((t[c>>2]|0)!=0?(t[(t[c>>2]|0)+4>>2]|0)!=1:0)?(t[(t[c>>2]|0)+4>>2]|0)!=2:0){r=Yl(142672)|0;t[t[a>>2]>>2]=r;t[u>>2]=t[t[a>>2]>>2];w=t[u>>2]|0;s=n;return w|0}do if(t[c>>2]|0){if((t[(t[c>>2]|0)+4>>2]|0)==2){t[b>>2]=t[(t[c>>2]|0)+20>>2];r=Yl(144464)|0;t[t[a>>2]>>2]=r;r=t[t[a>>2]>>2]|0;i=t[b>>2]|0;if(t[(t[b>>2]|0)+36>>2]|0){e=us(r,uh(l,t[(t[i+36>>2]|0)+8>>2]|0,t[(t[b>>2]|0)+8>>2]|0)|0)|0;t[t[a>>2]>>2]=e}else{e=us(r,uh(l,0,t[i+8>>2]|0)|0)|0;t[t[a>>2]>>2]=e}if(t[l>>2]|0){pAi[t[135736>>2]&511](t[l>>2]|0);t[l>>2]=0}e=us(t[t[a>>2]>>2]|0,142656)|0;t[t[a>>2]>>2]=e;e=us(t[t[a>>2]>>2]|0,144480)|0;t[t[a>>2]>>2]=e}else{e=Yl(144464)|0;t[t[a>>2]>>2]=e}e=t[t[a>>2]>>2]|0;i=t[c>>2]|0;if(t[(t[c>>2]|0)+36>>2]|0){r=us(e,uh(l,t[(t[i+36>>2]|0)+8>>2]|0,t[(t[c>>2]|0)+8>>2]|0)|0)|0;t[t[a>>2]>>2]=r}else{r=us(e,uh(l,0,t[i+8>>2]|0)|0)|0;t[t[a>>2]>>2]=r}if(t[l>>2]|0){pAi[t[135736>>2]&511](t[l>>2]|0);t[l>>2]=0}r=us(t[t[a>>2]>>2]|0,144496)|0;t[t[a>>2]>>2]=r}else{r=t[o>>2]|0;if((t[t[o>>2]>>2]|0)!=2){if((t[r>>2]|0)==1){i=Yl(142672)|0;t[t[a>>2]>>2]=i;break}i=t[33976]|0;e=t[33980]|0;t[f>>2]=140328;t[f+4>>2]=2246;yAi[i&511](e,140296,f);t[u>>2]=0;w=t[u>>2]|0;s=n;return w|0}t[k>>2]=r;if((t[t[(t[k>>2]|0)+108>>2]>>2]|0)==2){t[h>>2]=t[(t[(t[k>>2]|0)+100>>2]|0)+(t[(t[k>>2]|0)+96>>2]<<2)>>2];r=Yl(144464)|0;t[t[a>>2]>>2]=r;r=t[t[a>>2]>>2]|0;e=us(r,uh(l,t[(t[h>>2]|0)+16>>2]|0,t[(t[h>>2]|0)+12>>2]|0)|0)|0;t[t[a>>2]>>2]=e;if(t[l>>2]|0){pAi[t[135736>>2]&511](t[l>>2]|0);t[l>>2]=0}e=us(t[t[a>>2]>>2]|0,142656)|0;t[t[a>>2]>>2]=e;e=us(t[t[a>>2]>>2]|0,144480)|0;t[t[a>>2]>>2]=e}else{e=Yl(144464)|0;t[t[a>>2]>>2]=e}e=t[t[a>>2]>>2]|0;r=us(e,uh(l,t[(t[(t[k>>2]|0)+108>>2]|0)+16>>2]|0,t[(t[(t[k>>2]|0)+108>>2]|0)+12>>2]|0)|0)|0;t[t[a>>2]>>2]=r;if(t[l>>2]|0){pAi[t[135736>>2]&511](t[l>>2]|0);t[l>>2]=0}r=us(t[t[a>>2]>>2]|0,144496)|0;t[t[a>>2]>>2]=r}while(0);t[u>>2]=t[t[a>>2]>>2];w=t[u>>2]|0;s=n;return w|0}function kw(e,i,r,n,f,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;u=u|0;a=a|0;o=o|0;var c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0;c=s;s=s+32|0;l=c+28|0;b=c+24|0;k=c+20|0;h=c+16|0;w=c+12|0;d=c+8|0;v=c+4|0;m=c;t[l>>2]=e;t[b>>2]=i;t[k>>2]=r;t[h>>2]=n;t[w>>2]=f;t[d>>2]=u;t[v>>2]=a;t[m>>2]=o;Ld(t[l>>2]|0,2,t[b>>2]|0,t[k>>2]|0,0,t[h>>2]|0,t[w>>2]|0,t[d>>2]|0,t[v>>2]|0,t[m>>2]|0);s=c;return}function hw(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0;r=s;s=s+32|0;n=r+20|0;f=r+16|0;u=r+12|0;a=r+8|0;o=r+4|0;c=r;t[f>>2]=e;t[u>>2]=i;t[o>>2]=t[(t[(t[f>>2]|0)+28>>2]|0)+12>>2];if(!(t[(t[o>>2]|0)+4>>2]|0)){t[n>>2]=0;l=t[n>>2]|0;s=r;return l|0}t[c>>2]=0;while(1){if((t[c>>2]|0)>=(t[(t[o>>2]|0)+4>>2]|0)){b=8;break}t[a>>2]=t[(t[t[o>>2]>>2]|0)+(t[c>>2]<<2)>>2];if((t[(t[a>>2]|0)+8>>2]|0)==(t[u>>2]|0)){b=6;break}t[c>>2]=(t[c>>2]|0)+1}if((b|0)==6){t[n>>2]=t[a>>2];l=t[n>>2]|0;s=r;return l|0}else if((b|0)==8){t[n>>2]=0;l=t[n>>2]|0;s=r;return l|0}return 0}function ww(){var e=0,i=0,r=0,n=0,f=0;e=s;s=s+16|0;i=e+4|0;r=e;t[r>>2]=gAi[t[135744>>2]&511](16)|0;if(!(t[r>>2]|0)){Qh(0,170048,0);t[i>>2]=0;n=t[i>>2]|0;s=e;return n|0}else{f=t[r>>2]|0;t[f+0>>2]=0;t[f+4>>2]=0;t[f+8>>2]=0;t[f+12>>2]=0;t[i>>2]=t[r>>2];n=t[i>>2]|0;s=e;return n|0}return 0}function dw(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0;r=s;s=s+16|0;n=r+8|0;f=r+4|0;u=r;t[n>>2]=e;t[f>>2]=i;t[u>>2]=t[(t[n>>2]|0)+24>>2];if(!(t[u>>2]|0)){t[(t[n>>2]|0)+24>>2]=t[f>>2];s=r;return}while(1){if(!(t[t[u>>2]>>2]|0))break;t[u>>2]=t[t[u>>2]>>2]}t[t[u>>2]>>2]=t[f>>2];s=r;return}function vw(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0;n=s;s=s+32|0;f=n+24|0;u=n+20|0;a=n+16|0;o=n+12|0;c=n+8|0;l=n+4|0;b=n;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;t[l>>2]=t[(t[(t[u>>2]|0)+28>>2]|0)+12>>2];if(!(t[(t[l>>2]|0)+4>>2]|0)){t[f>>2]=0;k=t[f>>2]|0;s=n;return k|0}t[b>>2]=0;while(1){if((t[b>>2]|0)>=(t[(t[l>>2]|0)+4>>2]|0)){h=14;break}t[c>>2]=t[(t[t[l>>2]>>2]|0)+(t[b>>2]<<2)>>2];if(!((t[(t[c>>2]|0)+20>>2]|0)==0?(t[(t[c>>2]|0)+8>>2]|0)!=0:0))h=7;if((h|0)==7?(h=0,(t[(t[c>>2]|0)+12>>2]|0)==(t[a>>2]|0)):0){if((t[o>>2]|0)!=0?(t[(t[c>>2]|0)+36>>2]|0)!=0:0){h=12;break}if((t[o>>2]|0)==0?(t[(t[c>>2]|0)+36>>2]|0)==0:0){h=12;break}}t[b>>2]=(t[b>>2]|0)+1}if((h|0)==12){t[f>>2]=t[c>>2];k=t[f>>2]|0;s=n;return k|0}else if((h|0)==14){t[f>>2]=0;k=t[f>>2]|0;s=n;return k|0}return 0}function mw(e,i,r,n,f,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;u=u|0;a=a|0;o=o|0;var c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0;c=s;s=s+48|0;l=c+32|0;b=c+28|0;k=c+24|0;h=c+16|0;w=c+12|0;d=c+8|0;v=c+4|0;m=c;t[l>>2]=e;t[b>>2]=i;t[k>>2]=r;t[c+20>>2]=n;t[h>>2]=f;t[w>>2]=u;t[d>>2]=a;t[v>>2]=o;t[m>>2]=0;bw(m,t[l>>2]|0,t[k>>2]|0)|0;t[m>>2]=us(t[m>>2]|0,t[h>>2]|0)|0;t[m>>2]=us(t[m>>2]|0,142704)|0;Ld(t[l>>2]|0,1,t[b>>2]|0,t[k>>2]|0,0,t[m>>2]|0,t[w>>2]|0,t[d>>2]|0,t[v>>2]|0,0);if(!(t[m>>2]|0)){s=c;return}pAi[t[135736>>2]&511](t[m>>2]|0);t[m>>2]=0;s=c;return}function _w(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0;n=s;s=s+32|0;f=n+24|0;u=n+20|0;a=n+16|0;o=n+12|0;c=n+8|0;l=n+4|0;b=n;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;t[l>>2]=t[(t[(t[u>>2]|0)+28>>2]|0)+12>>2];if(!(t[(t[l>>2]|0)+4>>2]|0)){t[f>>2]=0;k=t[f>>2]|0;s=n;return k|0}t[b>>2]=0;while(1){if((t[b>>2]|0)>=(t[(t[l>>2]|0)+4>>2]|0)){h=10;break}t[c>>2]=t[(t[t[l>>2]>>2]|0)+(t[b>>2]<<2)>>2];if(((t[(t[c>>2]|0)+12>>2]|0)==0?(t[(t[c>>2]|0)+8>>2]|0)==(t[a>>2]|0):0)?(t[(t[c>>2]|0)+16>>2]|0)==(t[o>>2]|0):0){h=8;break}t[b>>2]=(t[b>>2]|0)+1}if((h|0)==8){t[f>>2]=t[c>>2];k=t[f>>2]|0;s=n;return k|0}else if((h|0)==10){t[f>>2]=0;k=t[f>>2]|0;s=n;return k|0}return 0}function pw(e,i,r,n,f,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;u=u|0;var a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0;a=s;s=s+48|0;o=a;c=a+40|0;l=a+36|0;b=a+32|0;k=a+28|0;h=a+24|0;w=a+20|0;d=a+16|0;v=a+12|0;m=a+8|0;t[c>>2]=e;t[l>>2]=i;t[b>>2]=r;t[k>>2]=n;t[h>>2]=f;t[w>>2]=u;t[d>>2]=0;t[v>>2]=0;t[m>>2]=0;if(t[c>>2]|0){u=(t[c>>2]|0)+20|0;t[u>>2]=(t[u>>2]|0)+1;t[(t[c>>2]|0)+16>>2]=t[b>>2];t[d>>2]=t[(t[c>>2]|0)+8>>2];t[m>>2]=t[(t[c>>2]|0)+4>>2];t[v>>2]=t[(t[c>>2]|0)+24>>2]}u=t[v>>2]|0;v=t[d>>2]|0;d=t[m>>2]|0;m=t[c>>2]|0;c=t[l>>2]|0;l=t[b>>2]|0;b=t[h>>2]|0;f=t[w>>2]|0;n=t[k>>2]|0;k=t[w>>2]|0;t[o>>2]=t[h>>2];t[o+4>>2]=k;cp(u,v,d,m,c,16,l,2,0,0,b,f,0,0,0,n,o);s=a;return}function Ew(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0;r=s;s=s+16|0;n=r+12|0;f=r+8|0;u=r+4|0;a=r;t[n>>2]=e;t[f>>2]=i;if((t[n>>2]|0)==0|(t[f>>2]|0)==0){s=r;return}t[u>>2]=0;t[a>>2]=t[f>>2];e:while(1){o=(t[u>>2]|0)!=0;if(!(t[a>>2]|0))break;if(o){iy(t[u>>2]|0);ry(t[u>>2]|0);t[u>>2]=0}n=t[(t[a>>2]|0)+4>>2]|0;if((t[(t[a>>2]|0)+4>>2]|0)==3)if(((n|0)==3?(Dd(t[(t[a>>2]|0)+40>>2]|0,-1)|0)!=0:0)?(uF(t[a>>2]|0)|0)!=1:0){t[u>>2]=t[a>>2];c=14}else c=14;else if((n|0)!=1?(t[(t[a>>2]|0)+4>>2]|0)!=4:0)t[u>>2]=t[a>>2];else c=14;if(((((c|0)==14?(c=0,(t[(t[a>>2]|0)+12>>2]|0)!=0):0)?(t[(t[(t[a>>2]|0)+12>>2]|0)+4>>2]|0)!=17:0)?(t[(t[(t[a>>2]|0)+12>>2]|0)+4>>2]|0)!=5:0)?(t[(t[(t[a>>2]|0)+12>>2]|0)+4>>2]|0)!=6:0){t[a>>2]=t[(t[a>>2]|0)+12>>2];continue}if(t[(t[a>>2]|0)+24>>2]|0){t[a>>2]=t[(t[a>>2]|0)+24>>2];continue}while(1){t[a>>2]=t[(t[a>>2]|0)+20>>2];if(!(t[a>>2]|0))continue e;if((t[a>>2]|0)==(t[f>>2]|0)){c=23;break}l=t[a>>2]|0;if(t[(t[a>>2]|0)+24>>2]|0){c=25;break}if(!l)continue e}if((c|0)==23){c=0;t[a>>2]=0;continue}else if((c|0)==25){c=0;t[a>>2]=t[l+24>>2];continue}}if(!o){s=r;return}iy(t[u>>2]|0);ry(t[u>>2]|0);t[u>>2]=0;s=r;return}function Sw(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0;n=s;s=s+32|0;f=n+20|0;u=n+16|0;a=n+12|0;o=n+8|0;c=n+4|0;l=n;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;t[c>>2]=vF(t[a>>2]|0,t[o>>2]|0)|0;if(!(t[c>>2]|0)){t[f>>2]=0;b=t[f>>2]|0;s=n;return b|0}else{t[l>>2]=kz(t[(t[u>>2]|0)+80>>2]|0,t[c>>2]|0,-1)|0;pAi[t[135736>>2]&511](t[c>>2]|0);t[f>>2]=t[l>>2];b=t[f>>2]|0;s=n;return b|0}return 0}function gw(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0;n=s;s=s+32|0;f=n+28|0;u=n+24|0;a=n+20|0;o=n+16|0;c=n+12|0;l=n+8|0;b=n+4|0;k=n;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;r=t[u>>2]|0;if(!(t[t[(t[u>>2]|0)+28>>2]>>2]|0)){rh(r,169824,169848);t[f>>2]=0;h=t[f>>2]|0;s=n;return h|0}t[b>>2]=t[t[r+28>>2]>>2];t[l>>2]=56;t[c>>2]=gAi[t[135744>>2]&511](t[l>>2]|0)|0;if(!(t[c>>2]|0)){Qh(0,169880,0);t[f>>2]=0;h=t[f>>2]|0;s=n;return h|0}VY(t[c>>2]|0,0,t[l>>2]|0)|0;t[(t[c>>2]|0)+16>>2]=t[o>>2];t[t[c>>2]>>2]=t[a>>2];l=hh()|0;t[(t[c>>2]|0)+44>>2]=l;if(!(t[(t[c>>2]|0)+44>>2]|0)){pAi[t[135736>>2]&511](t[c>>2]|0);t[f>>2]=0;h=t[f>>2]|0;s=n;return h|0}l=hh()|0;t[(t[c>>2]|0)+48>>2]=l;if(!(t[(t[c>>2]|0)+48>>2]|0)){pAi[t[135736>>2]&511](t[c>>2]|0);t[f>>2]=0;h=t[f>>2]|0;s=n;return h|0}do if((t[(t[(t[u>>2]|0)+28>>2]|0)+12>>2]|0)!=0?(t[(t[(t[(t[u>>2]|0)+28>>2]|0)+12>>2]|0)+4>>2]|0)>0:0){if(!(t[a>>2]|0)){rh(t[u>>2]|0,169824,169960);Xk(t[c>>2]|0);t[f>>2]=0;h=t[f>>2]|0;s=n;return h|0}if((t[a>>2]|0)==1){l=oh(t[u>>2]|0)|0;t[(t[c>>2]|0)+52>>2]=l;if(t[(t[c>>2]|0)+52>>2]|0){t[(t[(t[c>>2]|0)+52>>2]|0)+4>>2]=t[o>>2];break}Xk(t[c>>2]|0);t[f>>2]=0;h=t[f>>2]|0;s=n;return h|0}}else w=11;while(0);do if((w|0)==11){if(!((t[a>>2]|0)==2|(t[a>>2]|0)==3)){t[t[c>>2]>>2]=0;t[(t[(t[u>>2]|0)+28>>2]|0)+4>>2]=t[c>>2];t[(t[c>>2]|0)+52>>2]=t[b>>2];t[(t[b>>2]|0)+4>>2]=t[o>>2];break}rh(t[u>>2]|0,169824,169912);Xk(t[c>>2]|0);t[f>>2]=0;h=t[f>>2]|0;s=n;return h|0}while(0);if((t[a>>2]|0)==0|(t[a>>2]|0)==1){if((t[(t[b>>2]|0)+48>>2]|0)==0?(a=KF(5,t[(t[(t[u>>2]|0)+28>>2]|0)+8>>2]|0)|0,t[(t[b>>2]|0)+48>>2]=a,(t[(t[b>>2]|0)+48>>2]|0)==0):0){Xk(t[c>>2]|0);t[f>>2]=0;h=t[f>>2]|0;s=n;return h|0}a=t[(t[b>>2]|0)+48>>2]|0;if(!(t[o>>2]|0))t[k>>2]=ZF(a,145792,t[c>>2]|0)|0;else t[k>>2]=ZF(a,t[o>>2]|0,t[c>>2]|0)|0;if(t[k>>2]|0){rh(t[u>>2]|0,169824,17e4);Xk(t[c>>2]|0);t[f>>2]=0;h=t[f>>2]|0;s=n;return h|0}}else{if((t[t[(t[(t[u>>2]|0)+28>>2]|0)+16>>2]>>2]|0)!=0?(t[t[(t[(t[u>>2]|0)+28>>2]|0)+16>>2]>>2]|0)!=1:0)t[(t[c>>2]|0)+52>>2]=t[(t[(t[(t[u>>2]|0)+28>>2]|0)+16>>2]|0)+52>>2];else t[(t[c>>2]|0)+52>>2]=t[(t[(t[u>>2]|0)+28>>2]|0)+16>>2];if((t[(t[b>>2]|0)+64>>2]|0)==0?(k=hh()|0,t[(t[b>>2]|0)+64>>2]=k,(t[(t[b>>2]|0)+64>>2]|0)==0):0){Xk(t[c>>2]|0);t[f>>2]=0;h=t[f>>2]|0;s=n;return h|0}Cd(t[(t[b>>2]|0)+64>>2]|0,t[c>>2]|0)|0}if((Cd(t[(t[(t[u>>2]|0)+28>>2]|0)+12>>2]|0,t[c>>2]|0)|0)==-1){t[f>>2]=0;h=t[f>>2]|0;s=n;return h|0}else{t[f>>2]=t[c>>2];h=t[f>>2]|0;s=n;return h|0}return 0}function yw(e){e=e|0;var i=0,r=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if(t[(t[r>>2]|0)+24>>2]&1){e=(t[r>>2]|0)+24|0;t[e>>2]=t[e>>2]^1}if(t[(t[r>>2]|0)+24>>2]&2){e=(t[r>>2]|0)+24|0;t[e>>2]=t[e>>2]^2}if(t[(t[r>>2]|0)+24>>2]&4){e=(t[r>>2]|0)+24|0;t[e>>2]=t[e>>2]^4}if(t[(t[r>>2]|0)+24>>2]&8){e=(t[r>>2]|0)+24|0;t[e>>2]=t[e>>2]^8}if(t[(t[r>>2]|0)+24>>2]&16){e=(t[r>>2]|0)+24|0;t[e>>2]=t[e>>2]^16}if(t[(t[r>>2]|0)+24>>2]&32){e=(t[r>>2]|0)+24|0;t[e>>2]=t[e>>2]^32}if(t[(t[r>>2]|0)+24>>2]&64){e=(t[r>>2]|0)+24|0;t[e>>2]=t[e>>2]^64}if(t[(t[r>>2]|0)+24>>2]&128){e=(t[r>>2]|0)+24|0;t[e>>2]=t[e>>2]^128}if(!(t[(t[r>>2]|0)+24>>2]&256)){s=i;return}e=(t[r>>2]|0)+24|0;t[e>>2]=t[e>>2]^256;s=i;return}function Fw(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0;n=s;s=s+32|0;f=n+28|0;u=n+24|0;a=n+20|0;o=n+16|0;c=n+12|0;l=n+8|0;b=n+4|0;k=n;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;t[b>>2]=0;t[k>>2]=t[(t[u>>2]|0)+20>>2];t[b>>2]=Pd(t[u>>2]|0,t[o>>2]|0,161384)|0;do if((t[b>>2]|0)!=-1){t[c>>2]=Bd(t[o>>2]|0,168888)|0;if(t[c>>2]|0){r=t[u>>2]|0;i=t[c>>2]|0;t[b>>2]=Id(r,0,i,ED(29)|0,0)|0;if((t[b>>2]|0)==-1)break;if(t[b>>2]|0)t[(t[u>>2]|0)+108>>2]=3037;else h=6}else h=6;if((h|0)==6){t[c>>2]=Bd(t[o>>2]|0,168904)|0;if(t[c>>2]|0){t[l>>2]=Hd(t[u>>2]|0,t[c>>2]|0)|0;t[b>>2]=xd(t[l>>2]|0,(t[a>>2]|0)+24|0,1)|0;if((t[b>>2]|0)==-1)break;if(t[b>>2]|0)Ud(t[u>>2]|0,1705,0,t[c>>2]|0,0,163568,t[l>>2]|0,0,0,0)}t[c>>2]=Bd(t[o>>2]|0,168928)|0;if(t[c>>2]|0){t[l>>2]=Hd(t[u>>2]|0,t[c>>2]|0)|0;t[b>>2]=xd(t[l>>2]|0,(t[a>>2]|0)+24|0,2)|0;if((t[b>>2]|0)==-1)break;if(t[b>>2]|0)Ud(t[u>>2]|0,1701,0,t[c>>2]|0,0,163568,t[l>>2]|0,0,0,0)}t[c>>2]=Bd(t[o>>2]|0,168952)|0;if(t[c>>2]|0){t[l>>2]=Hd(t[u>>2]|0,t[c>>2]|0)|0;t[b>>2]=zd(t[l>>2]|0,(t[a>>2]|0)+24|0,-1,4,8,-1,16,32)|0;if((t[b>>2]|0)==-1)break;if(t[b>>2]|0)Ud(t[u>>2]|0,3037,0,t[c>>2]|0,0,168968,t[l>>2]|0,0,0,0)}t[c>>2]=Bd(t[o>>2]|0,169032)|0;if(t[c>>2]|0){t[l>>2]=Hd(t[u>>2]|0,t[c>>2]|0)|0;t[b>>2]=zd(t[l>>2]|0,(t[a>>2]|0)+24|0,-1,64,128,256,-1,-1)|0;if((t[b>>2]|0)==-1)break;if(t[b>>2]|0)Ud(t[u>>2]|0,3037,0,t[c>>2]|0,0,164576,t[l>>2]|0,0,0,0)}}if((t[k>>2]|0)!=(t[(t[u>>2]|0)+20>>2]|0))t[b>>2]=t[(t[u>>2]|0)+16>>2];t[f>>2]=t[b>>2];w=t[f>>2]|0;s=n;return w|0}while(0);t[f>>2]=-1;w=t[f>>2]|0;s=n;return w|0}function Ow(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0;n=s;s=s+48|0;f=n+32|0;u=n+28|0;a=n+24|0;o=n+20|0;c=n+16|0;l=n+12|0;b=n+8|0;k=n+4|0;h=n;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;t[b>>2]=0;if((t[u>>2]|0)==0|(t[a>>2]|0)==0|(t[o>>2]|0)==0){t[f>>2]=-1;w=t[f>>2]|0;s=n;return w|0}t[k>>2]=t[(t[u>>2]|0)+20>>2];t[c>>2]=t[o>>2];e:while(1){if(!((((t[c>>2]|0)!=0?(t[(t[c>>2]|0)+36>>2]|0)!=0:0)?(Xl(t[(t[c>>2]|0)+8>>2]|0,160960)|0)!=0:0)?(Xl(t[(t[(t[c>>2]|0)+36>>2]|0)+8>>2]|0,t[38526]|0)|0)!=0:0))d=8;do if((d|0)==8){d=0;if((((t[c>>2]|0)!=0?(t[(t[c>>2]|0)+36>>2]|0)!=0:0)?(Xl(t[(t[c>>2]|0)+8>>2]|0,160968)|0)!=0:0)?(Xl(t[(t[(t[c>>2]|0)+36>>2]|0)+8>>2]|0,t[38526]|0)|0)!=0:0)break;if((((t[c>>2]|0)!=0?(t[(t[c>>2]|0)+36>>2]|0)!=0:0)?(Xl(t[(t[c>>2]|0)+8>>2]|0,160976)|0)!=0:0)?(Xl(t[(t[(t[c>>2]|0)+36>>2]|0)+8>>2]|0,t[38526]|0)|0)!=0:0)break;if(!(t[c>>2]|0)){d=49;break e}if(!(t[(t[c>>2]|0)+36>>2]|0)){d=49;break e}if(!(Xl(t[(t[c>>2]|0)+8>>2]|0,160992)|0)){d=49;break e}if(!(Xl(t[(t[(t[c>>2]|0)+36>>2]|0)+8>>2]|0,t[38526]|0)|0)){d=49;break e}}while(0);do if((((t[c>>2]|0)!=0?(t[(t[c>>2]|0)+36>>2]|0)!=0:0)?(Xl(t[(t[c>>2]|0)+8>>2]|0,160992)|0)!=0:0)?(Xl(t[(t[(t[c>>2]|0)+36>>2]|0)+8>>2]|0,t[38526]|0)|0)!=0:0){t[l>>2]=jd(t[u>>2]|0,t[c>>2]|0,1)|0;
	o=t[l>>2]|0;if(!(t[(t[a>>2]|0)+20>>2]|0)){t[(t[a>>2]|0)+20>>2]=o;break}else{Yk(o);break}}else d=27;while(0);do if((d|0)==27){d=0;if((((t[c>>2]|0)!=0?(t[(t[c>>2]|0)+36>>2]|0)!=0:0)?(Xl(t[(t[c>>2]|0)+8>>2]|0,160968)|0)!=0:0)?(Xl(t[(t[(t[c>>2]|0)+36>>2]|0)+8>>2]|0,t[38526]|0)|0)!=0:0){t[h>>2]=t[(t[u>>2]|0)+20>>2];t[b>>2]=Vd(t[u>>2]|0,t[a>>2]|0,t[c>>2]|0)|0;if((t[b>>2]|0)==-1){d=97;break e}if(t[(t[u>>2]|0)+108>>2]|0)break e;if((t[h>>2]|0)!=(t[(t[u>>2]|0)+20>>2]|0))break e;else break}if((((t[c>>2]|0)!=0?(t[(t[c>>2]|0)+36>>2]|0)!=0:0)?(Xl(t[(t[c>>2]|0)+8>>2]|0,160960)|0)!=0:0)?(Xl(t[(t[(t[c>>2]|0)+36>>2]|0)+8>>2]|0,t[38526]|0)|0)!=0:0){t[h>>2]=t[(t[u>>2]|0)+20>>2];t[b>>2]=qd(t[u>>2]|0,t[a>>2]|0,t[c>>2]|0)|0;if((t[b>>2]|0)==-1){d=97;break e}if(t[(t[u>>2]|0)+108>>2]|0)break e;if((t[h>>2]|0)!=(t[(t[u>>2]|0)+20>>2]|0))break e;else break}if((((t[c>>2]|0)!=0?(t[(t[c>>2]|0)+36>>2]|0)!=0:0)?(Xl(t[(t[c>>2]|0)+8>>2]|0,160976)|0)!=0:0)?(Xl(t[(t[(t[c>>2]|0)+36>>2]|0)+8>>2]|0,t[38526]|0)|0)!=0:0){t[h>>2]=t[(t[u>>2]|0)+20>>2];t[b>>2]=Yd(t[u>>2]|0,t[a>>2]|0,t[c>>2]|0)|0;if((t[b>>2]|0)==-1){d=97;break e}if(t[(t[u>>2]|0)+108>>2]|0)break e;if((t[h>>2]|0)!=(t[(t[u>>2]|0)+20>>2]|0))break e}}while(0);t[c>>2]=t[(t[c>>2]|0)+24>>2]}if((d|0)==97){t[f>>2]=-1;w=t[f>>2]|0;s=n;return w|0}e:do if((d|0)==49)i:while(1){d=0;if(!(t[c>>2]|0))break e;if((((t[c>>2]|0)!=0?(t[(t[c>>2]|0)+36>>2]|0)!=0:0)?(Xl(t[(t[c>>2]|0)+8>>2]|0,161008)|0)!=0:0)?(Xl(t[(t[(t[c>>2]|0)+36>>2]|0)+8>>2]|0,t[38526]|0)|0)!=0:0){Gd(t[u>>2]|0,t[a>>2]|0,t[c>>2]|0,1)|0;t[c>>2]=t[(t[c>>2]|0)+24>>2]}else d=55;do if((d|0)==55){d=0;if((((t[c>>2]|0)!=0?(t[(t[c>>2]|0)+36>>2]|0)!=0:0)?(Xl(t[(t[c>>2]|0)+8>>2]|0,161024)|0)!=0:0)?(Xl(t[(t[(t[c>>2]|0)+36>>2]|0)+8>>2]|0,t[38526]|0)|0)!=0:0){Wd(t[u>>2]|0,t[a>>2]|0,t[c>>2]|0,1)|0;t[c>>2]=t[(t[c>>2]|0)+24>>2];break}if((((t[c>>2]|0)!=0?(t[(t[c>>2]|0)+36>>2]|0)!=0:0)?(Xl(t[(t[c>>2]|0)+8>>2]|0,161040)|0)!=0:0)?(Xl(t[(t[(t[c>>2]|0)+36>>2]|0)+8>>2]|0,t[38526]|0)|0)!=0:0){Kd(t[u>>2]|0,t[a>>2]|0,t[c>>2]|0,0,1)|0;t[c>>2]=t[(t[c>>2]|0)+24>>2];break}if((((t[c>>2]|0)!=0?(t[(t[c>>2]|0)+36>>2]|0)!=0:0)?(Xl(t[(t[c>>2]|0)+8>>2]|0,161048)|0)!=0:0)?(Xl(t[(t[(t[c>>2]|0)+36>>2]|0)+8>>2]|0,t[38526]|0)|0)!=0:0){Xd(t[u>>2]|0,t[a>>2]|0,t[c>>2]|0)|0;t[c>>2]=t[(t[c>>2]|0)+24>>2];break}if((((t[c>>2]|0)!=0?(t[(t[c>>2]|0)+36>>2]|0)!=0:0)?(Xl(t[(t[c>>2]|0)+8>>2]|0,161064)|0)!=0:0)?(Xl(t[(t[(t[c>>2]|0)+36>>2]|0)+8>>2]|0,t[38526]|0)|0)!=0:0){Zd(t[u>>2]|0,t[a>>2]|0,t[c>>2]|0)|0;t[c>>2]=t[(t[c>>2]|0)+24>>2];break}if((((t[c>>2]|0)!=0?(t[(t[c>>2]|0)+36>>2]|0)!=0:0)?(Xl(t[(t[c>>2]|0)+8>>2]|0,161080)|0)!=0:0)?(Xl(t[(t[(t[c>>2]|0)+36>>2]|0)+8>>2]|0,t[38526]|0)|0)!=0:0){Jd(t[u>>2]|0,t[a>>2]|0,t[c>>2]|0)|0;t[c>>2]=t[(t[c>>2]|0)+24>>2];break}if((((t[c>>2]|0)!=0?(t[(t[c>>2]|0)+36>>2]|0)!=0:0)?(Xl(t[(t[c>>2]|0)+8>>2]|0,161088)|0)!=0:0)?(Xl(t[(t[(t[c>>2]|0)+36>>2]|0)+8>>2]|0,t[38526]|0)|0)!=0:0){Qd(t[u>>2]|0,t[a>>2]|0,t[c>>2]|0)|0;t[c>>2]=t[(t[c>>2]|0)+24>>2];break}$d(t[u>>2]|0,3033,0,t[(t[c>>2]|0)+20>>2]|0,t[c>>2]|0,0,161104);t[c>>2]=t[(t[c>>2]|0)+24>>2]}while(0);while(1){if(!(t[c>>2]|0)){d=49;continue i}if(!(t[(t[c>>2]|0)+36>>2]|0)){d=49;continue i}if(!(Xl(t[(t[c>>2]|0)+8>>2]|0,160992)|0)){d=49;continue i}if(!(Xl(t[(t[(t[c>>2]|0)+36>>2]|0)+8>>2]|0,t[38526]|0)|0)){d=49;continue i}t[l>>2]=jd(t[u>>2]|0,t[c>>2]|0,1)|0;h=t[l>>2]|0;if(!(t[(t[a>>2]|0)+20>>2]|0))t[(t[a>>2]|0)+20>>2]=h;else Yk(h);t[c>>2]=t[(t[c>>2]|0)+24>>2]}}while(0);t[(t[u>>2]|0)+84>>2]=0;if((t[k>>2]|0)!=(t[(t[u>>2]|0)+20>>2]|0))t[b>>2]=t[(t[u>>2]|0)+16>>2];t[f>>2]=t[b>>2];w=t[f>>2]|0;s=n;return w|0}function Aw(e){e=e|0;var i=0,r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0;i=s;s=s+48|0;r=i+40|0;n=i+36|0;f=i+32|0;u=i+28|0;a=i+24|0;o=i+20|0;c=i+16|0;l=i+12|0;b=i+8|0;k=i+4|0;h=i;t[n>>2]=e;t[f>>2]=0;t[u>>2]=t[(t[(t[n>>2]|0)+28>>2]|0)+28>>2];if(!(t[u>>2]|0)){t[r>>2]=0;w=t[r>>2]|0;s=i;return w|0}e:while(1){t[o>>2]=t[(t[u>>2]|0)+4>>2];t[a>>2]=ev(t[(t[u>>2]|0)+24>>2]|0,t[t[o>>2]>>2]|0,t[(t[u>>2]|0)+16>>2]|0,t[(t[u>>2]|0)+20>>2]|0)|0;do if(!(t[a>>2]|0)){t[l>>2]=0;if(t[(t[u>>2]|0)+8>>2]|0)t[b>>2]=lw(t[(t[u>>2]|0)+8>>2]|0)|0;else t[b>>2]=lw(t[o>>2]|0)|0;e=t[n>>2]|0;d=t[b>>2]|0;v=vd(t[o>>2]|0)|0;th(e,3081,d,0,160712,v,uh(l,t[(t[u>>2]|0)+20>>2]|0,t[(t[u>>2]|0)+16>>2]|0)|0);if(t[l>>2]|0){pAi[t[135736>>2]&511](t[l>>2]|0);t[l>>2]=0}t[f>>2]=t[(t[n>>2]|0)+16>>2];t[u>>2]=t[t[u>>2]>>2]}else{t[c>>2]=0;v=t[t[o>>2]>>2]|0;do if((v|0)==4|(v|0)==5)if(t[(t[a>>2]|0)+48>>2]&1073741824){t[c>>2]=1;break}else{d=(t[a>>2]|0)+48|0;t[d>>2]=t[d>>2]|1073741824;t[(t[o>>2]|0)+64>>2]=t[a>>2];break}else if((v|0)==17){if(t[(t[a>>2]|0)+28>>2]&2){t[c>>2]=1;break}d=(t[a>>2]|0)+28|0;t[d>>2]=t[d>>2]|2;if(t[(t[u>>2]|0)+8>>2]|0)t[(t[(t[u>>2]|0)+8>>2]|0)+12>>2]=t[a>>2];t[(t[u>>2]|0)+12>>2]=t[a>>2]}else if((v|0)==16){if(t[(t[a>>2]|0)+36>>2]&8){t[c>>2]=1;break}d=(t[a>>2]|0)+36|0;t[d>>2]=t[d>>2]|8;d=t[a>>2]|0;e=t[u>>2]|0;if(t[(t[u>>2]|0)+8>>2]|0){t[(t[e+8>>2]|0)+4>>2]=d;t[(t[u>>2]|0)+12>>2]=0;break}else{t[e+12>>2]=d;break}}else{m=24;break e}while(0);if(!(t[c>>2]|0)){t[u>>2]=t[t[u>>2]>>2];break}t[k>>2]=0;v=t[u>>2]|0;if(t[(t[u>>2]|0)+8>>2]|0)t[h>>2]=lw(t[v+8>>2]|0)|0;else t[h>>2]=lw(t[v+4>>2]|0)|0;v=t[n>>2]|0;d=t[h>>2]|0;th(v,3081,d,0,160856,Nd(k,t[a>>2]|0)|0,0);if(t[k>>2]|0){pAi[t[135736>>2]&511](t[k>>2]|0);t[k>>2]=0}t[f>>2]=t[(t[n>>2]|0)+16>>2];t[u>>2]=t[t[u>>2]>>2]}while(0);if(!(t[u>>2]|0)){m=34;break}}if((m|0)==24){rh(t[n>>2]|0,160784,160816);t[r>>2]=-1;w=t[r>>2]|0;s=i;return w|0}else if((m|0)==34){t[r>>2]=t[f>>2];w=t[r>>2]|0;s=i;return w|0}return 0}function Mw(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0;r=s;s=s+48|0;n=r+36|0;f=r+32|0;u=r+28|0;a=r+24|0;o=r+20|0;c=r+16|0;l=r+12|0;b=r+8|0;k=r+4|0;h=r;t[f>>2]=e;t[u>>2]=i;if(!(t[u>>2]|0)){t[n>>2]=-1;w=t[n>>2]|0;s=r;return w|0}if(t[(t[u>>2]|0)+4>>2]&2){t[n>>2]=0;w=t[n>>2]|0;s=r;return w|0}i=(t[u>>2]|0)+4|0;t[i>>2]=t[i>>2]|2;t[b>>2]=0;while(1){if((t[b>>2]|0)>=(t[(t[(t[u>>2]|0)+44>>2]|0)+4>>2]|0))break;t[a>>2]=t[(t[t[(t[u>>2]|0)+44>>2]>>2]|0)+(t[b>>2]<<2)>>2];t[c>>2]=0;e:do switch(t[t[a>>2]>>2]|0){case 4:case 5:{if(!(t[(t[a>>2]|0)+48>>2]&1073741824)){t[l>>2]=t[(t[a>>2]|0)+8>>2];if((t[t[u>>2]>>2]|0)!=0?(t[t[u>>2]>>2]|0)!=1:0){t[c>>2]=(t[(t[(t[u>>2]|0)+52>>2]|0)+52>>2]|0)+28;d=40;break e}t[c>>2]=(t[(t[u>>2]|0)+52>>2]|0)+28;d=40}break}case 18:{t[l>>2]=t[(t[a>>2]|0)+4>>2];if((t[t[u>>2]>>2]|0)!=0?(t[t[u>>2]>>2]|0)!=1:0){t[c>>2]=(t[(t[(t[u>>2]|0)+52>>2]|0)+52>>2]|0)+44;d=40;break e}t[c>>2]=(t[(t[u>>2]|0)+52>>2]|0)+44;d=40;break}case 14:{t[l>>2]=t[(t[a>>2]|0)+8>>2];if((t[t[u>>2]>>2]|0)!=0?(t[t[u>>2]>>2]|0)!=1:0){t[c>>2]=(t[(t[(t[u>>2]|0)+52>>2]|0)+52>>2]|0)+40;d=40;break e}t[c>>2]=(t[(t[u>>2]|0)+52>>2]|0)+40;d=40;break}case 16:{if(!(t[(t[a>>2]|0)+36>>2]&8)){t[l>>2]=t[(t[a>>2]|0)+8>>2];if((t[t[u>>2]>>2]|0)!=0?(t[t[u>>2]>>2]|0)!=1:0){t[c>>2]=(t[(t[(t[u>>2]|0)+52>>2]|0)+52>>2]|0)+36;d=40;break e}t[c>>2]=(t[(t[u>>2]|0)+52>>2]|0)+36;d=40}break}case 24:case 22:case 23:{t[l>>2]=t[(t[a>>2]|0)+16>>2];if((t[t[u>>2]>>2]|0)!=0?(t[t[u>>2]>>2]|0)!=1:0){t[c>>2]=(t[(t[(t[u>>2]|0)+52>>2]|0)+52>>2]|0)+76;d=40;break e}t[c>>2]=(t[(t[u>>2]|0)+52>>2]|0)+76;d=40;break}case 17:{if(!(t[(t[a>>2]|0)+28>>2]&2)){t[l>>2]=t[(t[a>>2]|0)+16>>2];if((t[t[u>>2]>>2]|0)!=0?(t[t[u>>2]>>2]|0)!=1:0){t[c>>2]=(t[(t[(t[u>>2]|0)+52>>2]|0)+52>>2]|0)+56;d=40;break e}t[c>>2]=(t[(t[u>>2]|0)+52>>2]|0)+56;d=40}break}case 15:{t[l>>2]=t[(t[a>>2]|0)+8>>2];if((t[t[u>>2]>>2]|0)!=0?(t[t[u>>2]>>2]|0)!=1:0){t[c>>2]=(t[(t[(t[u>>2]|0)+52>>2]|0)+52>>2]|0)+32;d=40;break e}t[c>>2]=(t[(t[u>>2]|0)+52>>2]|0)+32;d=40;break}default:rh(t[f>>2]|0,160568,160592)}while(0);if((d|0)==40){d=0;if((t[t[c>>2]>>2]|0)==0?(i=KF(10,t[(t[f>>2]|0)+80>>2]|0)|0,t[t[c>>2]>>2]=i,(t[t[c>>2]>>2]|0)==0):0){d=42;break}t[o>>2]=ZF(t[t[c>>2]>>2]|0,t[l>>2]|0,t[a>>2]|0)|0;if((t[o>>2]|0)!=0?(t[k>>2]=0,i=t[f>>2]|0,e=lw(t[a>>2]|0)|0,v=t[a>>2]|0,m=vd(t[a>>2]|0)|0,th(i,1761,e,v,160672,m,Rd(k,t[a>>2]|0)|0),(t[k>>2]|0)!=0):0){pAi[t[135736>>2]&511](t[k>>2]|0);t[k>>2]=0}}t[b>>2]=(t[b>>2]|0)+1}if((d|0)==42){rh(t[f>>2]|0,160568,160632);t[n>>2]=-1;w=t[n>>2]|0;s=r;return w|0}e:do if(t[(t[u>>2]|0)+24>>2]|0){t[h>>2]=t[(t[u>>2]|0)+24>>2];while(1){if(((t[(t[h>>2]|0)+12>>2]|0)!=0?(t[(t[(t[h>>2]|0)+12>>2]|0)+4>>2]&2|0)==0:0)?(Mw(t[f>>2]|0,t[(t[h>>2]|0)+12>>2]|0)|0)==-1:0)break;t[h>>2]=t[t[h>>2]>>2];if(!(t[h>>2]|0))break e}t[n>>2]=-1;w=t[n>>2]|0;s=r;return w|0}while(0);t[n>>2]=0;w=t[n>>2]|0;s=r;return w|0}function Rw(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0;r=s;s=s+16|0;n=r+12|0;f=r+8|0;u=r+4|0;a=r;t[n>>2]=e;t[f>>2]=i;if((t[f>>2]|0)==0|(t[n>>2]|0)==0){s=r;return}if((t[n>>2]|0)!=0?(t[(t[n>>2]|0)+48>>2]&256|0)!=0:0){s=r;return}i=(t[n>>2]|0)+48|0;t[i>>2]=t[i>>2]|256;do if((t[(t[n>>2]|0)+28>>2]|0)==0?(t[(t[n>>2]|0)+56>>2]|0)!=0:0){t[u>>2]=iv(t[(t[f>>2]|0)+36>>2]|0,t[(t[n>>2]|0)+56>>2]|0,t[(t[n>>2]|0)+60>>2]|0)|0;if(!(t[u>>2]|0)){rv(t[f>>2]|0,3004,t[n>>2]|0,t[(t[n>>2]|0)+36>>2]|0,155448,t[(t[n>>2]|0)+56>>2]|0,t[(t[n>>2]|0)+60>>2]|0,1,160528);break}else{t[(t[n>>2]|0)+28>>2]=t[u>>2];break}}while(0);do if(t[(t[n>>2]|0)+64>>2]|0){t[a>>2]=nv(t[(t[f>>2]|0)+36>>2]|0,t[(t[n>>2]|0)+64>>2]|0,t[(t[n>>2]|0)+68>>2]|0)|0;if(!(t[a>>2]|0)){rv(t[f>>2]|0,3004,t[n>>2]|0,0,160544,t[(t[n>>2]|0)+64>>2]|0,t[(t[n>>2]|0)+68>>2]|0,14,0);break}Rw(t[a>>2]|0,t[f>>2]|0);t[(t[n>>2]|0)+80>>2]=t[a>>2];if(!(t[(t[n>>2]|0)+28>>2]|0))t[(t[n>>2]|0)+28>>2]=t[(t[a>>2]|0)+28>>2]}while(0);if(t[(t[n>>2]|0)+28>>2]|0){s=r;return}if(t[(t[n>>2]|0)+56>>2]|0){s=r;return}if(t[(t[n>>2]|0)+64>>2]|0){s=r;return}a=ED(45)|0;t[(t[n>>2]|0)+28>>2]=a;s=r;return}function Nw(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0;r=s;s=s+16|0;n=r+12|0;f=r+8|0;u=r+4|0;a=r;t[n>>2]=e;t[f>>2]=i;if(!(t[n>>2]|0)){s=r;return}if((t[(t[n>>2]|0)+64>>2]|0)==0?(i=iv(t[(t[f>>2]|0)+36>>2]|0,t[(t[n>>2]|0)+56>>2]|0,t[(t[n>>2]|0)+60>>2]|0)|0,t[(t[n>>2]|0)+64>>2]=i,(t[(t[n>>2]|0)+64>>2]|0)==0):0){rv(t[f>>2]|0,3004,t[n>>2]|0,t[(t[n>>2]|0)+36>>2]|0,151424,t[(t[n>>2]|0)+56>>2]|0,t[(t[n>>2]|0)+60>>2]|0,4,0);s=r;return}do if((t[t[n>>2]>>2]|0)!=4){if((t[t[n>>2]>>2]|0)==1?(t[(t[n>>2]|0)+88>>2]|0)!=45:0)break;if(!(t[(t[n>>2]|0)+28>>2]|0)){s=r;return}if((t[t[(t[n>>2]|0)+28>>2]>>2]|0)!=25){s=r;return}if(!(t[(t[(t[n>>2]|0)+28>>2]|0)+12>>2]|0)){s=r;return}if((t[t[(t[(t[n>>2]|0)+28>>2]|0)+12>>2]>>2]|0)!=2e3){s=r;return}t[u>>2]=t[(t[(t[n>>2]|0)+28>>2]|0)+12>>2];t[(t[(t[n>>2]|0)+28>>2]|0)+12>>2]=0;t[a>>2]=tv(t[(t[f>>2]|0)+36>>2]|0,t[(t[u>>2]|0)+8>>2]|0,t[(t[u>>2]|0)+12>>2]|0,t[(t[u>>2]|0)+16>>2]|0)|0;if(!(t[a>>2]|0)){i=t[f>>2]|0;e=lw(t[(t[n>>2]|0)+28>>2]|0)|0;rv(i,3004,0,e,160064,t[(t[u>>2]|0)+12>>2]|0,t[(t[u>>2]|0)+16>>2]|0,t[(t[u>>2]|0)+8>>2]|0,0);t[(t[n>>2]|0)+28>>2]=0;s=r;return}if(!(t[(t[a>>2]|0)+12>>2]|0)){t[(t[n>>2]|0)+28>>2]=0;s=r;return}t[(t[(t[n>>2]|0)+28>>2]|0)+12>>2]=t[(t[a>>2]|0)+12>>2];if((t[t[(t[a>>2]|0)+12>>2]>>2]|0)!=8){s=r;return}if((t[(t[(t[n>>2]|0)+28>>2]|0)+20>>2]|0)==1){s=r;return}e=t[f>>2]|0;th(e,3091,lw(t[(t[n>>2]|0)+28>>2]|0)|0,0,160416,0,0);s=r;return}while(0);if(t[(t[n>>2]|0)+48>>2]&128){fv(t[f>>2]|0,t[n>>2]|0)|0;s=r;return}if(!(t[(t[n>>2]|0)+48>>2]&64)){s=r;return}if(t[(t[n>>2]|0)+28>>2]|0){s=r;return}if(!(t[(t[n>>2]|0)+56>>2]|0)){s=r;return}a=iv(t[(t[f>>2]|0)+36>>2]|0,t[(t[n>>2]|0)+56>>2]|0,t[(t[n>>2]|0)+60>>2]|0)|0;t[(t[n>>2]|0)+28>>2]=a;if(t[(t[n>>2]|0)+28>>2]|0){if((t[t[(t[n>>2]|0)+28>>2]>>2]|0)==4){s=r;return}if((t[t[(t[n>>2]|0)+28>>2]>>2]|0)==1?(t[(t[(t[n>>2]|0)+28>>2]|0)+88>>2]|0)!=45:0){s=r;return}}t[(t[n>>2]|0)+28>>2]=0;rv(t[f>>2]|0,3004,t[n>>2]|0,t[(t[n>>2]|0)+36>>2]|0,160400,t[(t[n>>2]|0)+56>>2]|0,t[(t[n>>2]|0)+60>>2]|0,4,0);s=r;return}function Tw(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0;r=s;s=s+16|0;n=r+12|0;f=r+8|0;u=r+4|0;a=r;t[f>>2]=e;t[u>>2]=i;if(t[(t[f>>2]|0)+60>>2]&256){t[n>>2]=0;o=t[n>>2]|0;s=r;return o|0}i=(t[f>>2]|0)+60|0;t[i>>2]=t[i>>2]|256;if(t[(t[f>>2]|0)+48>>2]|0){t[n>>2]=0;o=t[n>>2]|0;s=r;return o|0}e:do if(t[(t[f>>2]|0)+24>>2]|0){t[a>>2]=iv(t[(t[u>>2]|0)+36>>2]|0,t[(t[f>>2]|0)+24>>2]|0,t[(t[f>>2]|0)+28>>2]|0)|0;do if(t[a>>2]|0){if((t[t[a>>2]>>2]|0)!=4){if((t[t[a>>2]>>2]|0)!=1)break;if((t[(t[a>>2]|0)+88>>2]|0)==45)break}t[(t[f>>2]|0)+48>>2]=t[a>>2];break e}while(0);rv(t[u>>2]|0,3004,t[f>>2]|0,t[(t[f>>2]|0)+52>>2]|0,155448,t[(t[f>>2]|0)+24>>2]|0,t[(t[f>>2]|0)+28>>2]|0,4,0);t[n>>2]=t[(t[u>>2]|0)+16>>2];o=t[n>>2]|0;s=r;return o|0}else{i=ED(46)|0;t[(t[f>>2]|0)+48>>2]=i}while(0);t[n>>2]=0;o=t[n>>2]|0;s=r;return o|0}function Lw(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0;r=s;s=s+16|0;n=r+12|0;f=r+8|0;u=r+4|0;a=r;t[f>>2]=e;t[u>>2]=i;if((t[u>>2]|0)==0|(t[f>>2]|0)==0){t[n>>2]=-1;o=t[n>>2]|0;s=r;return o|0}if((t[(t[f>>2]|0)+12>>2]|0)!=0?(t[t[(t[f>>2]|0)+12>>2]>>2]|0)==2e3:0){t[a>>2]=t[(t[f>>2]|0)+12>>2];i=uv(t[(t[u>>2]|0)+36>>2]|0,t[(t[a>>2]|0)+12>>2]|0,t[(t[a>>2]|0)+16>>2]|0)|0;t[(t[f>>2]|0)+12>>2]=i;if(!(t[(t[f>>2]|0)+12>>2]|0)){rv(t[u>>2]|0,3004,t[f>>2]|0,t[(t[f>>2]|0)+20>>2]|0,160064,t[(t[a>>2]|0)+12>>2]|0,t[(t[a>>2]|0)+16>>2]|0,15,0);t[n>>2]=t[(t[u>>2]|0)+16>>2];o=t[n>>2]|0;s=r;return o|0}else{t[n>>2]=0;o=t[n>>2]|0;s=r;return o|0}}t[n>>2]=0;o=t[n>>2]|0;s=r;return o|0}function Dw(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0;r=s;s=s+16|0;n=r+12|0;f=r+8|0;u=r+4|0;a=r;t[f>>2]=e;t[u>>2]=i;if(t[(t[f>>2]|0)+4>>2]|0){t[n>>2]=0;o=t[n>>2]|0;s=r;return o|0}t[a>>2]=av(t[(t[u>>2]|0)+36>>2]|0,t[(t[f>>2]|0)+12>>2]|0,t[(t[f>>2]|0)+16>>2]|0)|0;if(!(t[a>>2]|0)){rv(t[u>>2]|0,3004,0,t[(t[f>>2]|0)+20>>2]|0,160064,t[(t[f>>2]|0)+12>>2]|0,t[(t[f>>2]|0)+16>>2]|0,t[(t[f>>2]|0)+8>>2]|0,0);t[n>>2]=t[(t[u>>2]|0)+16>>2];o=t[n>>2]|0;s=r;return o|0}else{t[(t[f>>2]|0)+4>>2]=t[a>>2];t[n>>2]=0;o=t[n>>2]|0;s=r;return o|0}return 0}function Cw(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0;r=s;s=s+32|0;n=r+16|0;f=r+12|0;u=r+8|0;a=r+4|0;o=r;t[n>>2]=e;t[f>>2]=i;t[u>>2]=t[(t[f>>2]|0)+12>>2];while(1){if(!(t[u>>2]|0))break;do if((t[(t[u>>2]|0)+12>>2]|0)!=0?(t[t[(t[u>>2]|0)+12>>2]>>2]|0)==2e3:0){t[a>>2]=t[(t[u>>2]|0)+12>>2];t[(t[u>>2]|0)+12>>2]=0;t[o>>2]=tv(t[(t[n>>2]|0)+36>>2]|0,t[(t[a>>2]|0)+8>>2]|0,t[(t[a>>2]|0)+12>>2]|0,t[(t[a>>2]|0)+16>>2]|0)|0;if(!(t[o>>2]|0)){f=t[n>>2]|0;i=lw(t[u>>2]|0)|0;rv(f,3004,0,i,160064,t[(t[a>>2]|0)+12>>2]|0,t[(t[a>>2]|0)+16>>2]|0,t[(t[a>>2]|0)+8>>2]|0,0);break}i=t[o>>2]|0;if((t[t[o>>2]>>2]|0)!=17){t[(t[u>>2]|0)+12>>2]=i;break}if(t[i+12>>2]|0)if((t[t[(t[o>>2]|0)+12>>2]>>2]|0)==8){i=t[n>>2]|0;th(i,3091,lw(t[u>>2]|0)|0,0,160280,0,0);break}else{t[(t[u>>2]|0)+12>>2]=t[o>>2];break}}while(0);t[u>>2]=t[(t[u>>2]|0)+8>>2]}s=r;return}function Pw(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0;r=s;s=s+32|0;n=r+16|0;f=r+12|0;u=r+8|0;a=r+4|0;o=r;t[f>>2]=e;t[u>>2]=i;if((t[t[f>>2]>>2]|0)!=24){t[n>>2]=0;c=t[n>>2]|0;s=r;return c|0}if(t[(t[(t[f>>2]|0)+36>>2]|0)+12>>2]|0){i=ov(t[(t[u>>2]|0)+36>>2]|0,t[(t[(t[f>>2]|0)+36>>2]|0)+12>>2]|0,t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)|0;t[(t[(t[f>>2]|0)+36>>2]|0)+4>>2]=i;if(!(t[(t[(t[f>>2]|0)+36>>2]|0)+4>>2]|0)){rv(t[u>>2]|0,3004,t[f>>2]|0,t[(t[f>>2]|0)+12>>2]|0,160144,t[(t[(t[f>>2]|0)+36>>2]|0)+12>>2]|0,t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0,23,0);t[n>>2]=t[(t[u>>2]|0)+16>>2];c=t[n>>2]|0;s=r;return c|0}if((t[t[(t[(t[f>>2]|0)+36>>2]|0)+4>>2]>>2]|0)==24){th(t[u>>2]|0,3080,0,t[f>>2]|0,160152,0,0);t[(t[(t[f>>2]|0)+36>>2]|0)+4>>2]=0;t[n>>2]=t[(t[u>>2]|0)+16>>2];c=t[n>>2]|0;s=r;return c|0}if((t[(t[f>>2]|0)+32>>2]|0)!=(t[(t[(t[(t[f>>2]|0)+36>>2]|0)+4>>2]|0)+32>>2]|0)){t[a>>2]=0;t[o>>2]=t[(t[(t[f>>2]|0)+36>>2]|0)+4>>2];i=t[u>>2]|0;e=t[f>>2]|0;th(i,3080,0,e,160184,uh(a,t[(t[o>>2]|0)+20>>2]|0,t[(t[o>>2]|0)+16>>2]|0)|0,0);if(t[a>>2]|0){pAi[t[135736>>2]&511](t[a>>2]|0);t[a>>2]=0}t[n>>2]=t[(t[u>>2]|0)+16>>2];c=t[n>>2]|0;s=r;return c|0}}t[n>>2]=0;c=t[n>>2]|0;s=r;return c|0}function Bw(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0;r=s;s=s+16|0;n=r+8|0;f=r+4|0;u=r;t[f>>2]=e;t[u>>2]=i;if(!(uv(t[(t[u>>2]|0)+36>>2]|0,t[(t[f>>2]|0)+8>>2]|0,t[(t[f>>2]|0)+12>>2]|0)|0)){rv(t[u>>2]|0,3004,0,t[(t[f>>2]|0)+4>>2]|0,160064,t[(t[f>>2]|0)+8>>2]|0,t[(t[f>>2]|0)+12>>2]|0,15,0);t[n>>2]=3004;a=t[n>>2]|0;s=r;return a|0}else{t[n>>2]=0;a=t[n>>2]|0;s=r;return a|0}return 0}function Iw(e,i){e=e|0;i=i|0;var r=0,n=0,f=0;r=s;s=s+16|0;n=r+4|0;f=r;t[n>>2]=e;t[f>>2]=i;if(!(t[n>>2]|0)){s=r;return}if((t[t[n>>2]>>2]|0)==1){s=r;return}if(!(t[(t[n>>2]|0)+64>>2]|0)){s=r;return}cv(t[f>>2]|0,t[n>>2]|0,t[(t[n>>2]|0)+64>>2]|0)|0;s=r;return}function Hw(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0;r=s;s=s+16|0;n=r+12|0;f=r+8|0;u=r+4|0;a=r;t[n>>2]=e;t[f>>2]=i;if(!(t[n>>2]|0)){s=r;return}if((t[t[n>>2]>>2]|0)!=17){s=r;return}if(!(t[(t[n>>2]|0)+12>>2]|0)){s=r;return}t[u>>2]=lv(t[n>>2]|0,t[(t[(t[n>>2]|0)+12>>2]|0)+12>>2]|0)|0;if(!(t[u>>2]|0)){s=r;return}t[a>>2]=0;i=t[f>>2]|0;f=lw(t[u>>2]|0)|0;sv(i,3075,0,f,159968,uh(a,t[(t[n>>2]|0)+20>>2]|0,t[(t[n>>2]|0)+16>>2]|0)|0);if(t[a>>2]|0){pAi[t[135736>>2]&511](t[a>>2]|0);t[a>>2]=0}t[(t[u>>2]|0)+12>>2]=0;s=r;return}function xw(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0;r=s;s=s+32|0;n=r+16|0;f=r+12|0;u=r+8|0;a=r+4|0;o=r;t[f>>2]=e;t[u>>2]=i;if(!(t[(t[f>>2]|0)+56>>2]|0)){t[n>>2]=0;c=t[n>>2]|0;s=r;return c|0}if(!(t[(t[f>>2]|0)+36>>2]&16)){t[n>>2]=0;c=t[n>>2]|0;s=r;return c|0}t[a>>2]=bv(t[f>>2]|0,t[(t[f>>2]|0)+56>>2]|0)|0;if(!(t[a>>2]|0)){t[n>>2]=0;c=t[n>>2]|0;s=r;return c|0}t[o>>2]=0;i=t[u>>2]|0;e=lw(t[a>>2]|0)|0;sv(i,3073,0,e,159912,Rd(o,t[f>>2]|0)|0);if(t[o>>2]|0){pAi[t[135736>>2]&511](t[o>>2]|0);t[o>>2]=0}t[(t[a>>2]|0)+4>>2]=0;t[n>>2]=t[(t[u>>2]|0)+16>>2];c=t[n>>2]|0;s=r;return c|0}function Uw(e,i){e=e|0;i=i|0;var r=0,n=0,f=0;r=s;s=s+16|0;n=r+4|0;f=r;t[r+8>>2]=e;t[n>>2]=i;t[f>>2]=t[(t[n>>2]|0)+12>>2];while(1){if(!(t[f>>2]|0))break;if((t[(t[f>>2]|0)+12>>2]|0)!=0?(t[t[(t[f>>2]|0)+12>>2]>>2]|0)==17:0){n=(t[f>>2]|0)+12|0;if(!(t[(t[(t[f>>2]|0)+12>>2]|0)+12>>2]|0)){t[n>>2]=0;t[f>>2]=t[(t[f>>2]|0)+8>>2];continue}else{t[(t[f>>2]|0)+12>>2]=t[(t[n>>2]|0)+12>>2];t[f>>2]=t[(t[f>>2]|0)+8>>2];continue}}t[f>>2]=t[(t[f>>2]|0)+8>>2]}s=r;return}function zw(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0;r=s;s=s+16|0;n=r+8|0;f=r+4|0;u=r;t[f>>2]=e;t[u>>2]=i;if((t[(t[u>>2]|0)+56>>2]|0)!=0?(t[(t[u>>2]|0)+36>>2]&1|0)==0:0){i=(t[u>>2]|0)+36|0;t[i>>2]=t[i>>2]|1;if((kv(t[f>>2]|0,t[u>>2]|0,(t[u>>2]|0)+40|0,t[(t[u>>2]|0)+56>>2]|0,0)|0)==-1){t[n>>2]=-1;a=t[n>>2]|0;s=r;return a|0}else{t[n>>2]=0;a=t[n>>2]|0;s=r;return a|0}}t[n>>2]=0;a=t[n>>2]|0;s=r;return a|0}function jw(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0;r=s;s=s+16|0;n=r+8|0;f=r+4|0;u=r;t[f>>2]=e;t[u>>2]=i;if((t[t[u>>2]>>2]|0)!=4){t[n>>2]=0;a=t[n>>2]|0;s=r;return a|0}if((t[t[u>>2]>>2]|0)!=1?(t[(t[u>>2]|0)+48>>2]&536870912|0)==0:0){i=(t[u>>2]|0)+48|0;t[i>>2]=t[i>>2]|536870912;i=t[u>>2]|0;do if(t[(t[u>>2]|0)+48>>2]&64){if(!(t[i+28>>2]|0)){rh(t[f>>2]|0,153152,153192);t[n>>2]=-1;a=t[n>>2]|0;s=r;return a|0}}else{e=t[u>>2]|0;if(t[i+48>>2]&128){if(t[e+92>>2]|0)break;rh(t[f>>2]|0,153152,153232);t[n>>2]=-1;a=t[n>>2]|0;s=r;return a|0}if(!(t[e+64>>2]|0)){rh(t[f>>2]|0,153152,153272);t[n>>2]=-1;a=t[n>>2]|0;s=r;return a|0}if(((t[t[(t[u>>2]|0)+64>>2]>>2]|0)!=1?(t[(t[(t[u>>2]|0)+64>>2]|0)+48>>2]&536870912|0)==0:0)?(jw(t[f>>2]|0,t[(t[u>>2]|0)+64>>2]|0)|0)==-1:0){t[n>>2]=-1;a=t[n>>2]|0;s=r;return a|0}e=t[u>>2]|0;if(t[(t[(t[u>>2]|0)+64>>2]|0)+48>>2]&256){o=e+48|0;t[o>>2]=t[o>>2]|256;break}o=t[u>>2]|0;if(t[(t[e+64>>2]|0)+48>>2]&64){e=o+48|0;t[e>>2]=t[e>>2]|64;t[(t[u>>2]|0)+28>>2]=t[(t[(t[u>>2]|0)+64>>2]|0)+28>>2];break}if(t[(t[o+64>>2]|0)+48>>2]&128){o=(t[u>>2]|0)+48|0;t[o>>2]=t[o>>2]|128}}while(0);t[n>>2]=0;a=t[n>>2]|0;s=r;return a|0}t[n>>2]=0;a=t[n>>2]|0;s=r;return a|0}function Vw(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0;r=s;s=s+16|0;n=r+8|0;f=r+4|0;u=r;t[f>>2]=e;t[u>>2]=i;if(t[(t[u>>2]|0)+48>>2]&128){t[n>>2]=hv(t[f>>2]|0,t[u>>2]|0,t[(t[u>>2]|0)+92>>2]|0)|0;a=t[n>>2]|0;s=r;return a|0}else{t[n>>2]=0;a=t[n>>2]|0;s=r;return a|0}return 0}function qw(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0;r=s;s=s+32|0;n=r+16|0;f=r+12|0;u=r+8|0;a=r+4|0;o=r;t[f>>2]=e;t[u>>2]=i;t[o>>2]=t[(t[f>>2]|0)+20>>2];if((t[t[u>>2]>>2]|0)!=4){t[n>>2]=-1;c=t[n>>2]|0;s=r;return c|0}if((t[t[u>>2]>>2]|0)!=1?(t[(t[u>>2]|0)+48>>2]&4194304|0)==0:0){i=(t[u>>2]|0)+48|0;t[i>>2]=t[i>>2]|4194304;t[(t[u>>2]|0)+52>>2]=4;e:do if(t[(t[u>>2]|0)+64>>2]|0){if((t[t[(t[u>>2]|0)+64>>2]>>2]|0)!=1?(t[(t[(t[u>>2]|0)+64>>2]|0)+48>>2]&4194304|0)==0:0)wv(t[(t[u>>2]|0)+64>>2]|0,t[f>>2]|0)|0;if((t[(t[u>>2]|0)+92>>2]|0)!=0?(dv(t[f>>2]|0,t[u>>2]|0)|0)==-1:0){t[n>>2]=-1;c=t[n>>2]|0;s=r;return c|0}t[a>>2]=vv(t[f>>2]|0,t[u>>2]|0)|0;if((t[a>>2]|0)!=-1){do if(!(t[a>>2]|0)){t[a>>2]=mv(t[f>>2]|0,t[u>>2]|0)|0;if((t[a>>2]|0)==-1)break e;if(!(t[a>>2]|0)){t[a>>2]=_v(t[u>>2]|0,t[f>>2]|0)|0;if((t[a>>2]|0)==-1)break e;if(!(t[a>>2]|0)){if(!((t[(t[u>>2]|0)+96>>2]|0)==0?(t[(t[(t[u>>2]|0)+64>>2]|0)+96>>2]|0)==0:0)){t[a>>2]=pv(t[f>>2]|0,t[u>>2]|0)|0;if((t[a>>2]|0)==-1)break e;if(t[a>>2]|0)break}t[a>>2]=Ev(t[u>>2]|0)|0;if((t[a>>2]|0)==-1)break e;if(!(t[a>>2]|0))Sv(t[u>>2]|0)}}}while(0);if((t[o>>2]|0)!=(t[(t[f>>2]|0)+20>>2]|0)){t[n>>2]=t[(t[f>>2]|0)+16>>2];c=t[n>>2]|0;s=r;return c|0}else{t[n>>2]=0;c=t[n>>2]|0;s=r;return c|0}}}else rh(t[f>>2]|0,147168,147208);while(0);t[n>>2]=-1;c=t[n>>2]|0;s=r;return c|0}t[n>>2]=0;c=t[n>>2]|0;s=r;return c|0}function Yw(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0;r=s;s=s+16|0;n=r+12|0;f=r+8|0;u=r+4|0;a=r;t[f>>2]=e;t[u>>2]=i;if(!(t[(t[u>>2]|0)+48>>2]|0)){t[n>>2]=0;o=t[n>>2]|0;s=r;return o|0}if(t[(t[u>>2]|0)+44>>2]|0){i=(gv(t[(t[u>>2]|0)+48>>2]|0,23)|0)!=0;e=t[f>>2]|0;c=t[u>>2]|0;if(i){th(e,3090,0,c,159552,0,0);t[n>>2]=t[(t[f>>2]|0)+16>>2];o=t[n>>2]|0;s=r;return o|0}t[a>>2]=nh(e,t[c+52>>2]|0,t[(t[u>>2]|0)+48>>2]|0,t[(t[u>>2]|0)+44>>2]|0,(t[u>>2]|0)+68|0,1,1,0)|0;if(t[a>>2]|0){c=t[f>>2]|0;if((t[a>>2]|0)<0){rh(c,159840,141832);t[n>>2]=-1;o=t[n>>2]|0;s=r;return o|0}else{th(c,3079,0,t[u>>2]|0,159680,0,0);t[n>>2]=t[(t[f>>2]|0)+16>>2];o=t[n>>2]|0;s=r;return o|0}}}t[n>>2]=0;o=t[n>>2]|0;s=r;return o|0}function Gw(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0;r=s;s=s+16|0;n=r+12|0;f=r+8|0;u=r+4|0;a=r;t[f>>2]=e;t[u>>2]=i;if((t[f>>2]|0)==0|(t[u>>2]|0)==0){t[n>>2]=-1;o=t[n>>2]|0;s=r;return o|0}if(((t[(t[u>>2]|0)+28>>2]|0)!=0?(t[(t[u>>2]|0)+12>>2]|0)!=0:0)?(t[t[(t[u>>2]|0)+12>>2]>>2]|0)==15:0){if(((t[(t[(t[u>>2]|0)+12>>2]|0)+44>>2]|0)!=0?(t[(t[(t[u>>2]|0)+12>>2]|0)+60>>2]&512|0)!=0:0)?(t[(t[u>>2]|0)+16>>2]&1|0)==0:0){sv(t[f>>2]|0,3078,t[u>>2]|0,0,159424,0);t[n>>2]=t[(t[f>>2]|0)+16>>2];o=t[n>>2]|0;s=r;return o|0}if((t[(t[u>>2]|0)+32>>2]|0)!=0?(t[(t[(t[u>>2]|0)+12>>2]|0)+48>>2]|0)!=0:0){i=(gv(t[(t[(t[u>>2]|0)+12>>2]|0)+48>>2]|0,23)|0)!=0;e=t[f>>2]|0;c=t[u>>2]|0;if(i){th(e,3089,0,c,159552,0,0);t[n>>2]=t[(t[f>>2]|0)+16>>2];o=t[n>>2]|0;s=r;return o|0}t[a>>2]=nh(e,t[c+20>>2]|0,t[(t[(t[u>>2]|0)+12>>2]|0)+48>>2]|0,t[(t[u>>2]|0)+28>>2]|0,(t[u>>2]|0)+32|0,1,1,0)|0;if(t[a>>2]|0){c=t[f>>2]|0;if((t[a>>2]|0)<0){rh(c,159640,141832);t[n>>2]=-1;o=t[n>>2]|0;s=r;return o|0}else{th(c,3089,0,t[u>>2]|0,159680,0,0);t[n>>2]=t[(t[f>>2]|0)+16>>2];o=t[n>>2]|0;s=r;return o|0}}}if((t[(t[(t[u>>2]|0)+12>>2]|0)+68>>2]|0)!=0?(t[(t[(t[u>>2]|0)+12>>2]|0)+60>>2]&1|0)==0:0){if(!(Od(t[(t[u>>2]|0)+32>>2]|0,t[(t[(t[u>>2]|0)+12>>2]|0)+68>>2]|0)|0))sv(t[f>>2]|0,3078,t[u>>2]|0,0,159728,t[(t[(t[u>>2]|0)+12>>2]|0)+44>>2]|0);t[n>>2]=t[(t[f>>2]|0)+16>>2];o=t[n>>2]|0;s=r;return o|0}t[n>>2]=0;o=t[n>>2]|0;s=r;return o|0}t[n>>2]=0;o=t[n>>2]|0;s=r;return o|0}function Ww(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0;r=s;s=s+48|0;n=r+40|0;f=r+36|0;u=r+32|0;a=r+28|0;o=r+24|0;c=r+20|0;l=r+16|0;b=r+12|0;k=r+8|0;h=r+4|0;w=r;t[f>>2]=e;t[u>>2]=i;e:do if((t[(t[u>>2]|0)+56>>2]|0)!=0?(t[(t[(t[u>>2]|0)+56>>2]|0)+4>>2]|0)>1:0){t[a>>2]=t[(t[u>>2]|0)+56>>2];t[k>>2]=0;t[l>>2]=(t[(t[a>>2]|0)+4>>2]|0)-1;i:while(1){if((t[l>>2]|0)<0)break e;t[o>>2]=t[(t[t[a>>2]>>2]|0)+(t[l>>2]<<2)>>2];r:do if((t[l>>2]|0)>0){t[b>>2]=(t[l>>2]|0)-1;while(1){if((t[b>>2]|0)<0){d=15;break r}t[c>>2]=t[(t[t[a>>2]>>2]|0)+(t[b>>2]<<2)>>2];if((t[(t[(t[o>>2]|0)+12>>2]|0)+8>>2]|0)==(t[(t[(t[c>>2]|0)+12>>2]|0)+8>>2]|0)?(t[(t[(t[o>>2]|0)+12>>2]|0)+56>>2]|0)==(t[(t[(t[c>>2]|0)+12>>2]|0)+56>>2]|0):0)break;t[b>>2]=(t[b>>2]|0)+-1}t[h>>2]=0;i=t[f>>2]|0;e=t[(t[u>>2]|0)+32>>2]|0;v=t[u>>2]|0;th(i,3087,e,v,152424,Nd(h,t[o>>2]|0)|0,0);if(t[h>>2]|0){pAi[t[135736>>2]&511](t[h>>2]|0);t[h>>2]=0}if((yv(t[a>>2]|0,t[l>>2]|0)|0)==-1){d=13;break i}}else d=15;while(0);if(((d|0)==15?(d=0,(t[(t[(t[o>>2]|0)+12>>2]|0)+48>>2]|0)!=0):0)?(gv(t[(t[(t[o>>2]|0)+12>>2]|0)+48>>2]|0,23)|0)!=0:0){if(t[k>>2]|0){t[w>>2]=0;v=t[f>>2]|0;e=t[(t[u>>2]|0)+32>>2]|0;i=t[u>>2]|0;th(v,3087,e,i,152440,Nd(w,t[o>>2]|0)|0,0);if(t[w>>2]|0){pAi[t[135736>>2]&511](t[w>>2]|0);t[w>>2]=0}if((yv(t[a>>2]|0,t[l>>2]|0)|0)==-1){d=21;break}}t[k>>2]=1}t[l>>2]=(t[l>>2]|0)+-1}if((d|0)==13){t[n>>2]=-1;m=t[n>>2]|0;s=r;return m|0}else if((d|0)==21){t[n>>2]=-1;m=t[n>>2]|0;s=r;return m|0}}while(0);t[n>>2]=0;m=t[n>>2]|0;s=r;return m|0}function Kw(e){e=e|0;var i=0,r=0,n=0,f=0,u=0,a=0,o=0,c=0;i=s;s=s+32|0;r=i+16|0;n=i+12|0;f=i+8|0;u=i+4|0;a=i;t[n>>2]=e;t[f>>2]=0;t[u>>2]=t[(t[(t[n>>2]|0)+28>>2]|0)+28>>2];if(!(t[u>>2]|0)){t[r>>2]=0;o=t[r>>2]|0;s=i;return o|0}while(1){e=t[u>>2]|0;if(!(t[(t[u>>2]|0)+12>>2]|0))t[u>>2]=t[e>>2];else{t[a>>2]=t[e+4>>2];e=t[t[a>>2]>>2]|0;if((e|0)==16){t[f>>2]=Fv(t[n>>2]|0,1,t[a>>2]|0,t[(t[u>>2]|0)+12>>2]|0,t[(t[a>>2]|0)+56>>2]|0,t[(t[(t[u>>2]|0)+12>>2]|0)+56>>2]|0,t[(t[a>>2]|0)+40>>2]|0,t[(t[(t[u>>2]|0)+12>>2]|0)+40>>2]|0)|0;if((t[f>>2]|0)==-1){c=8;break}}else if((e|0)==5|(e|0)==4)t[(t[(t[u>>2]|0)+12>>2]|0)+8>>2]=0;t[u>>2]=t[t[u>>2]>>2]}if(!(t[u>>2]|0)){c=11;break}}if((c|0)==8){t[r>>2]=-1;o=t[r>>2]|0;s=i;return o|0}else if((c|0)==11){t[r>>2]=0;o=t[r>>2]|0;s=i;return o|0}return 0}function Xw(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0;r=s;s=s+48|0;n=r+40|0;f=r+36|0;u=r+32|0;a=r+28|0;o=r+24|0;c=r+20|0;l=r+16|0;b=r+12|0;k=r+8|0;h=r+4|0;w=r;t[f>>2]=e;t[u>>2]=i;t[a>>2]=0;t[o>>2]=t[(t[f>>2]|0)+20>>2];t[c>>2]=t[(t[u>>2]|0)+64>>2];if((t[t[u>>2]>>2]|0)!=1?(t[(t[u>>2]|0)+48>>2]&4194304|0)==0:0){i=(t[u>>2]|0)+48|0;t[i>>2]=t[i>>2]|4194304;e:do if(t[c>>2]|0){if((t[t[c>>2]>>2]|0)!=1?(t[(t[c>>2]|0)+48>>2]&4194304|0)==0:0)wv(t[c>>2]|0,t[f>>2]|0)|0;if(t[(t[c>>2]|0)+48>>2]&8388608){t[n>>2]=0;d=t[n>>2]|0;s=r;return d|0}t[a>>2]=Ov(t[f>>2]|0,t[u>>2]|0)|0;if((t[a>>2]|0)!=-1){i:do if(!(t[a>>2]|0)){r:do if((t[(t[u>>2]|0)+52>>2]|0)==4){if(!((t[t[c>>2]>>2]|0)!=5?(t[(t[c>>2]|0)+88>>2]|0)!=45:0))v=16;if(((v|0)==16?(t[(t[c>>2]|0)+104>>2]|0)!=0:0)?(t[(t[u>>2]|0)+48>>2]&4|0)!=0:0){if(t[(t[u>>2]|0)+104>>2]|0){t[l>>2]=t[(t[u>>2]|0)+104>>2];t[(t[u>>2]|0)+104>>2]=0}else t[l>>2]=t[(t[c>>2]|0)+104>>2];t[b>>2]=Av(t[f>>2]|0,t[(t[f>>2]|0)+36>>2]|0,4,0,t[(t[u>>2]|0)+112>>2]|0,t[(t[u>>2]|0)+36>>2]|0,0)|0;if(!(t[b>>2]|0))break e;t[t[b>>2]>>2]=4;t[(t[b>>2]|0)+64>>2]=t[l>>2];t[(t[b>>2]|0)+68>>2]=t[(t[u>>2]|0)+68>>2];t[(t[u>>2]|0)+68>>2]=0;t[(t[b>>2]|0)+96>>2]=t[(t[u>>2]|0)+96>>2];t[(t[u>>2]|0)+96>>2]=0;t[(t[u>>2]|0)+104>>2]=t[b>>2];do if((t[t[l>>2]>>2]|0)!=1){if(t[(t[l>>2]|0)+48>>2]&4194304)break;wv(t[l>>2]|0,t[f>>2]|0)|0}while(0);t[a>>2]=jw(t[f>>2]|0,t[b>>2]|0)|0;if((t[a>>2]|0)==-1)break e;if(t[a>>2]|0)break i;t[a>>2]=qw(t[f>>2]|0,t[b>>2]|0)|0;if((t[a>>2]|0)==-1)break e;if(t[a>>2]|0)break i;else break}if(!((t[t[c>>2]>>2]|0)!=5?(t[(t[c>>2]|0)+88>>2]|0)!=45:0))v=31;if(((v|0)==31?(t[(t[c>>2]|0)+52>>2]|0)==3:0)?(t[(t[u>>2]|0)+48>>2]&4|0)!=0:0){if((t[(t[u>>2]|0)+104>>2]|0)!=0?(t[(t[(t[u>>2]|0)+104>>2]|0)+64>>2]|0)!=0:0)break;sv(t[f>>2]|0,3069,t[u>>2]|0,0,149808,t[(t[u>>2]|0)+8>>2]|0);break e}if(!((t[t[c>>2]>>2]|0)!=5?(t[(t[c>>2]|0)+88>>2]|0)!=45:0))v=38;if((v|0)==38?(t[(t[u>>2]|0)+48>>2]&2|0)!=0:0)if(!(t[(t[c>>2]|0)+104>>2]|0)){sv(t[f>>2]|0,3069,t[u>>2]|0,0,149976,t[(t[u>>2]|0)+8>>2]|0);break e}else{t[(t[u>>2]|0)+104>>2]=t[(t[c>>2]|0)+104>>2];break}if((t[t[c>>2]>>2]|0)!=4){if((t[t[c>>2]>>2]|0)==1?(t[(t[c>>2]|0)+88>>2]|0)!=45:0)v=45}else v=45;if((v|0)==45?(t[(t[u>>2]|0)+48>>2]&2|0)!=0:0){t[(t[u>>2]|0)+104>>2]=t[c>>2];break}sv(t[f>>2]|0,3069,t[u>>2]|0,0,150112,t[(t[u>>2]|0)+8>>2]|0);break e}else{t[k>>2]=0;t[h>>2]=t[(t[u>>2]|0)+28>>2];n:do if(!(t[h>>2]|0))v=55;else{do if((t[t[h>>2]>>2]|0)==25){if((t[t[(t[h>>2]|0)+12>>2]>>2]|0)!=8?(t[t[(t[h>>2]|0)+12>>2]>>2]|0)!=6:0){if((t[t[(t[h>>2]|0)+12>>2]>>2]|0)!=7)break;if(t[(t[h>>2]|0)+16>>2]|0)break}if(!(t[(t[(t[h>>2]|0)+12>>2]|0)+12>>2]|0)){v=55;break n}}while(0);t[(t[u>>2]|0)+52>>2]=2}while(0);do if((v|0)==55){if(!(t[(t[u>>2]|0)+48>>2]&1)){t[(t[u>>2]|0)+52>>2]=1;break}if(!((t[h>>2]|0)!=0?(t[t[(t[h>>2]|0)+12>>2]>>2]|0)==6:0)){t[h>>2]=Mv(t[f>>2]|0,t[(t[u>>2]|0)+36>>2]|0,1,1)|0;if(!(t[h>>2]|0))break e;i=Rv(t[f>>2]|0,t[(t[f>>2]|0)+36>>2]|0,6,t[(t[u>>2]|0)+36>>2]|0)|0;t[(t[h>>2]|0)+12>>2]=i;if(!(t[(t[h>>2]|0)+12>>2]|0))break e;t[(t[u>>2]|0)+28>>2]=t[h>>2]}t[k>>2]=1;t[(t[u>>2]|0)+52>>2]=2}while(0);i=t[(t[u>>2]|0)+52>>2]|0;if(t[(t[u>>2]|0)+48>>2]&4){if((i|0)==1)break;if(!(t[(t[u>>2]|0)+48>>2]&1))break;t[(t[u>>2]|0)+52>>2]=3;break}e=t[(t[c>>2]|0)+52>>2]|0;if((i|0)==1){t[(t[u>>2]|0)+52>>2]=e;t[(t[u>>2]|0)+28>>2]=t[(t[c>>2]|0)+28>>2];t[(t[u>>2]|0)+104>>2]=t[(t[c>>2]|0)+104>>2];break}i=(t[(t[u>>2]|0)+48>>2]&1|0)!=0;if((e|0)==1){if(!i)break;t[(t[u>>2]|0)+52>>2]=3;break}if(i)t[(t[u>>2]|0)+52>>2]=3;do if((t[(t[u>>2]|0)+28>>2]|0)!=0?(t[(t[(t[u>>2]|0)+28>>2]|0)+12>>2]|0)!=0:0){if((t[t[(t[(t[u>>2]|0)+28>>2]|0)+12>>2]>>2]|0)!=8)break;i=t[f>>2]|0;th(i,3091,lw(t[u>>2]|0)|0,0,150216,0,0);break r}while(0);do if(t[(t[c>>2]|0)+28>>2]|0){if(!(t[(t[(t[c>>2]|0)+28>>2]|0)+12>>2]|0))break;if((t[t[(t[(t[c>>2]|0)+28>>2]|0)+12>>2]>>2]|0)!=8)break;i=t[f>>2]|0;th(i,3091,lw(t[u>>2]|0)|0,0,150480,0,0);break r}while(0);if(t[k>>2]|0){t[(t[(t[h>>2]|0)+12>>2]|0)+12>>2]=t[(t[c>>2]|0)+28>>2];break}t[w>>2]=t[(t[u>>2]|0)+28>>2];t[h>>2]=Mv(t[f>>2]|0,t[(t[u>>2]|0)+36>>2]|0,1,1)|0;if(!(t[h>>2]|0))break e;i=Rv(t[f>>2]|0,t[(t[f>>2]|0)+36>>2]|0,6,t[(t[u>>2]|0)+36>>2]|0)|0;t[(t[h>>2]|0)+12>>2]=i;if(!(t[(t[h>>2]|0)+12>>2]|0))break e;t[(t[u>>2]|0)+28>>2]=t[h>>2];i=Mv(t[f>>2]|0,t[(t[u>>2]|0)+36>>2]|0,t[(t[(t[c>>2]|0)+28>>2]|0)+16>>2]|0,t[(t[(t[c>>2]|0)+28>>2]|0)+20>>2]|0)|0;t[(t[(t[h>>2]|0)+12>>2]|0)+12>>2]=i;if(!(t[(t[(t[h>>2]|0)+12>>2]|0)+12>>2]|0))break e;t[h>>2]=t[(t[(t[h>>2]|0)+12>>2]|0)+12>>2];t[(t[h>>2]|0)+12>>2]=t[(t[(t[c>>2]|0)+28>>2]|0)+12>>2];t[(t[h>>2]|0)+8>>2]=t[w>>2]}while(0);t[a>>2]=Nv(t[f>>2]|0,t[u>>2]|0)|0;if((t[a>>2]|0)==-1)break e;if(!(t[a>>2]|0)){t[a>>2]=Tv(t[f>>2]|0,t[u>>2]|0)|0;if((t[a>>2]|0)==-1)break e;if(!(t[a>>2]|0))if((t[o>>2]|0)!=(t[(t[f>>2]|0)+20>>2]|0)){t[n>>2]=t[(t[f>>2]|0)+16>>2];d=t[n>>2]|0;s=r;return d|0}else{t[n>>2]=0;d=t[n>>2]|0;s=r;return d|0}}}while(0);i=(t[u>>2]|0)+48|0;t[i>>2]=t[i>>2]|8388608;t[n>>2]=t[(t[f>>2]|0)+16>>2];d=t[n>>2]|0;s=r;return d|0}}else rh(t[f>>2]|0,149776,147208);while(0);f=(t[u>>2]|0)+48|0;t[f>>2]=t[f>>2]|8388608;t[n>>2]=-1;d=t[n>>2]|0;s=r;return d|0}t[n>>2]=0;d=t[n>>2]|0;s=r;return d|0}function Zw(e,i){e=e|0;i=i|0;var r=0,n=0,f=0;r=s;s=s+16|0;n=r+4|0;f=r;t[n>>2]=e;t[f>>2]=i;if(!(t[n>>2]|0)){s=r;return}if(t[(t[n>>2]|0)+48>>2]&262144){s=r;return}i=(t[n>>2]|0)+48|0;t[i>>2]=t[i>>2]|262144;if(Lv(t[f>>2]|0,t[n>>2]|0)|0){s=r;return}Dv(t[f>>2]|0,t[n>>2]|0);s=r;return}function Jw(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0;r=s;s=s+16|0;n=r;f=r+8|0;u=r+4|0;t[f>>2]=e;t[u>>2]=i;if((t[t[f>>2]>>2]|0)!=5){s=r;return}if(t[(t[f>>2]|0)+108>>2]|0){s=r;return}if((t[(t[f>>2]|0)+52>>2]|0)!=2?(t[(t[f>>2]|0)+52>>2]|0)!=3:0){s=r;return}t[(t[u>>2]|0)+64>>2]=0;i=rb()|0;t[(t[u>>2]|0)+64>>2]=i;if(!(t[(t[u>>2]|0)+64>>2]|0)){i=t[33976]|0;e=t[33980]|0;t[n>>2]=t[(t[f>>2]|0)+8>>2];yAi[i&511](e,157984,n);s=r;return}n=ub(t[(t[u>>2]|0)+64>>2]|0)|0;t[(t[u>>2]|0)+76>>2]=n;Cv(t[u>>2]|0,t[(t[f>>2]|0)+28>>2]|0)|0;ab(t[(t[u>>2]|0)+64>>2]|0,t[(t[u>>2]|0)+76>>2]|0)|0;n=_b(t[(t[u>>2]|0)+64>>2]|0)|0;t[(t[f>>2]|0)+108>>2]=n;if(t[(t[f>>2]|0)+108>>2]|0){if((ib(t[(t[f>>2]|0)+108>>2]|0)|0)!=1)sv(t[u>>2]|0,3070,t[f>>2]|0,t[(t[f>>2]|0)+36>>2]|0,158072,0)}else sv(t[u>>2]|0,3069,t[f>>2]|0,t[(t[f>>2]|0)+36>>2]|0,158032,0);t[(t[u>>2]|0)+76>>2]=0;nb(t[(t[u>>2]|0)+64>>2]|0);t[(t[u>>2]|0)+64>>2]=0;s=r;return}function Qw(e){e=e|0;var i=0,r=0,n=0,f=0,u=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0;i=s;s=s+32|0;r=i+28|0;n=i+24|0;f=i+20|0;u=i+16|0;o=i+12|0;c=i+8|0;l=i+4|0;b=i;t[n>>2]=e;t[u>>2]=0;t[o>>2]=0;e=t[n>>2]|0;if(t[(t[n>>2]|0)+84>>2]|0)t[l>>2]=t[e+84>>2];else t[l>>2]=eF(t[e+24>>2]|0)|0;e=t[n>>2]|0;if(!(t[l>>2]|0)){th(e,1,0,0,141128,0,0);t[r>>2]=1;k=t[r>>2]|0;
	s=i;return k|0}t[e+96>>2]=-1;t[(t[n>>2]|0)+84>>2]=t[l>>2];t[c>>2]=t[l>>2];e:while(1){if(!(t[c>>2]|0)){h=48;break}if((t[(t[n>>2]|0)+176>>2]|0)!=-1?(t[(t[n>>2]|0)+96>>2]|0)>=(t[(t[n>>2]|0)+176>>2]|0):0)h=45;else h=10;do if((h|0)==10){h=0;if((t[(t[c>>2]|0)+4>>2]|0)==1){e=(t[n>>2]|0)+96|0;t[e>>2]=(t[e>>2]|0)+1;if(($w(t[n>>2]|0)|0)==-1)break e;t[o>>2]=t[(t[n>>2]|0)+108>>2];t[(t[o>>2]|0)+4>>2]=t[c>>2];t[(t[o>>2]|0)+8>>2]=a[(t[c>>2]|0)+56>>1];t[(t[o>>2]|0)+12>>2]=t[(t[c>>2]|0)+8>>2];if(t[(t[c>>2]|0)+36>>2]|0)t[(t[o>>2]|0)+16>>2]=t[(t[(t[c>>2]|0)+36>>2]|0)+8>>2];e=(t[o>>2]|0)+32|0;t[e>>2]=t[e>>2]|32;t[(t[n>>2]|0)+168>>2]=0;if(t[(t[c>>2]|0)+44>>2]|0){t[f>>2]=t[(t[c>>2]|0)+44>>2];do{if(t[(t[f>>2]|0)+36>>2]|0)t[b>>2]=t[(t[(t[f>>2]|0)+36>>2]|0)+8>>2];else t[b>>2]=0;e=t[n>>2]|0;w=t[f>>2]|0;d=t[(t[o>>2]|0)+8>>2]|0;v=t[(t[f>>2]|0)+8>>2]|0;m=t[b>>2]|0;t[u>>2]=ed(e,w,d,v,m,0,sy(t[(t[f>>2]|0)+32>>2]|0,t[(t[f>>2]|0)+12>>2]|0,1)|0,1)|0;if((t[u>>2]|0)==-1){h=20;break e}t[f>>2]=t[(t[f>>2]|0)+24>>2]}while((t[f>>2]|0)!=0)}t[u>>2]=id(t[n>>2]|0)|0;if(t[u>>2]|0)if((t[u>>2]|0)==-1){h=24;break e}else break;if((t[(t[n>>2]|0)+176>>2]|0)!=-1?(t[(t[n>>2]|0)+96>>2]|0)>=(t[(t[n>>2]|0)+176>>2]|0):0)break}else{if((t[(t[c>>2]|0)+4>>2]|0)!=3?(t[(t[c>>2]|0)+4>>2]|0)!=4:0){if((t[(t[c>>2]|0)+4>>2]|0)==6){h=36;break e}if((t[(t[c>>2]|0)+4>>2]|0)==5){h=36;break e}else break}if((t[o>>2]|0)!=0?(t[(t[o>>2]|0)+32>>2]&32|0)!=0:0){m=(t[o>>2]|0)+32|0;t[m>>2]=t[m>>2]^32}t[u>>2]=nd(t[n>>2]|0,t[(t[c>>2]|0)+4>>2]|0,t[(t[c>>2]|0)+40>>2]|0,-1,1,0)|0;if((t[u>>2]|0)<0){h=33;break e}}if(t[(t[c>>2]|0)+12>>2]|0){t[c>>2]=t[(t[c>>2]|0)+12>>2];continue e}}while(0);while(1){if((h|0)==45){h=0;_=t[c>>2]|0;if(t[(t[c>>2]|0)+24>>2]|0)break;t[c>>2]=t[_+20>>2]}if((t[(t[c>>2]|0)+4>>2]|0)!=1){h=45;continue}p=t[n>>2]|0;if((t[c>>2]|0)!=(t[(t[(t[n>>2]|0)+108>>2]|0)+4>>2]|0)){h=41;break e}t[u>>2]=rd(p)|0;if((t[u>>2]|0)!=0&(t[u>>2]|0)<0){h=43;break e}if((t[c>>2]|0)==(t[l>>2]|0)){h=48;break e}else h=45}t[c>>2]=t[_+24>>2]}if((h|0)==20)rh(t[n>>2]|0,155912,144696);else if((h|0)==24)rh(t[n>>2]|0,155912,144744);else if((h|0)==33)rh(t[n>>2]|0,155936,141336);else if((h|0)==36)rh(t[n>>2]|0,155936,155960);else if((h|0)==41)rh(p,155936,156168);else if((h|0)==43)rh(t[n>>2]|0,155936,141688);else if((h|0)==48){t[r>>2]=t[u>>2];k=t[r>>2]|0;s=i;return k|0}t[r>>2]=-1;k=t[r>>2]|0;s=i;return k|0}function $w(e){e=e|0;var i=0,r=0,n=0,f=0;i=s;s=s+16|0;r=i+4|0;n=i;t[n>>2]=e;e=Pv(t[n>>2]|0)|0;t[(t[n>>2]|0)+108>>2]=e;e=t[n>>2]|0;if(!(t[(t[n>>2]|0)+108>>2]|0)){rh(e,155592,155624);t[r>>2]=-1;f=t[r>>2]|0;s=i;return f|0}else{t[e+168>>2]=0;t[r>>2]=0;f=t[r>>2]|0;s=i;return f|0}return 0}function ed(e,i,r,n,f,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;u=u|0;a=a|0;o=o|0;var c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0;c=s;s=s+48|0;l=c+36|0;b=c+32|0;k=c+28|0;h=c+24|0;w=c+20|0;d=c+16|0;v=c+12|0;m=c+8|0;_=c+4|0;p=c;t[b>>2]=e;t[k>>2]=i;t[h>>2]=r;t[w>>2]=n;t[d>>2]=f;t[v>>2]=u;t[m>>2]=a;t[_>>2]=o;t[p>>2]=Bv(t[b>>2]|0)|0;if(!(t[p>>2]|0)){rh(t[b>>2]|0,155408,145304);t[l>>2]=-1;E=t[l>>2]|0;s=c;return E|0}t[(t[p>>2]|0)+4>>2]=t[k>>2];t[(t[p>>2]|0)+8>>2]=t[h>>2];t[(t[p>>2]|0)+44>>2]=1;t[(t[p>>2]|0)+12>>2]=t[w>>2];t[(t[p>>2]|0)+16>>2]=t[d>>2];if(t[v>>2]|0){v=(t[p>>2]|0)+32|0;t[v>>2]=t[v>>2]|1}do if(t[d>>2]|0){if(Xl(t[w>>2]|0,155432)|0){if(!(Xl(t[(t[p>>2]|0)+16>>2]|0,t[38860]|0)|0))break;t[(t[p>>2]|0)+48>>2]=2;break}if(Xl(t[w>>2]|0,155448)|0){if(!(Xl(t[(t[p>>2]|0)+16>>2]|0,t[38860]|0)|0))break;t[(t[p>>2]|0)+48>>2]=1;break}if(Xl(t[w>>2]|0,155456)|0){if(!(Xl(t[(t[p>>2]|0)+16>>2]|0,t[38860]|0)|0))break;t[(t[p>>2]|0)+48>>2]=3;break}v=(Xl(t[w>>2]|0,155472)|0)!=0;h=t[(t[p>>2]|0)+16>>2]|0;if(v){if(!(Xl(h,t[38860]|0)|0))break;t[(t[p>>2]|0)+48>>2]=4;break}else{if(!(Xl(h,t[38876]|0)|0))break;t[(t[p>>2]|0)+48>>2]=5;break}}while(0);t[(t[p>>2]|0)+20>>2]=t[m>>2];if(t[_>>2]|0){_=(t[p>>2]|0)+32|0;t[_>>2]=t[_>>2]|2}if(t[(t[p>>2]|0)+48>>2]|0)t[(t[p>>2]|0)+44>>2]=17;t[l>>2]=0;E=t[l>>2]|0;s=c;return E|0}function id(e){e=e|0;var i=0,r=0,n=0,f=0,u=0,a=0,o=0,c=0;i=s;s=s+16|0;r=i+12|0;n=i+8|0;f=i+4|0;u=i;t[n>>2]=e;t[f>>2]=0;if((t[(t[n>>2]|0)+176>>2]|0)!=-1?(t[(t[n>>2]|0)+96>>2]|0)>=(t[(t[n>>2]|0)+176>>2]|0):0)rh(t[n>>2]|0,144776,144800);else a=4;e:do if((a|0)==4){do if(t[(t[n>>2]|0)+92>>2]|0){t[f>>2]=Iv(t[n>>2]|0)|0;if(!(t[f>>2]|0)){aO(t[(t[(t[n>>2]|0)+20>>2]|0)+48>>2]|0,357,t[n>>2]|0);break}if((t[f>>2]|0)==-1)break e;t[(t[n>>2]|0)+176>>2]=0;t[r>>2]=t[f>>2];o=t[r>>2]|0;s=i;return o|0}while(0);e=t[n>>2]|0;do if((t[(t[n>>2]|0)+96>>2]|0)>0){t[f>>2]=Hv(e)|0;if(t[f>>2]|0){if((t[f>>2]|0)>=0)break;rh(t[n>>2]|0,144776,144816);break e}if((t[(t[n>>2]|0)+96>>2]|0)!=(t[(t[n>>2]|0)+176>>2]|0))if((t[(t[(t[n>>2]|0)+108>>2]|0)+44>>2]|0)==0?(t[(t[(t[n>>2]|0)+108>>2]|0)+28>>2]|0)==0:0){rh(t[n>>2]|0,144776,144864);break e}else a=19}else{c=nv(t[e+20>>2]|0,t[(t[(t[n>>2]|0)+108>>2]|0)+12>>2]|0,t[(t[(t[n>>2]|0)+108>>2]|0)+16>>2]|0)|0;t[(t[(t[n>>2]|0)+108>>2]|0)+44>>2]=c;if(!(t[(t[(t[n>>2]|0)+108>>2]|0)+44>>2]|0)){t[f>>2]=1845;th(t[n>>2]|0,t[f>>2]|0,0,0,144944,0,0)}else a=19}while(0);i:do if((a|0)==19){do if(t[(t[(t[n>>2]|0)+108>>2]|0)+44>>2]|0){if((t[t[(t[(t[n>>2]|0)+108>>2]|0)+44>>2]>>2]|0)==2){t[f>>2]=xv(t[n>>2]|0,u)|0;if(t[f>>2]|0){if((t[f>>2]|0)>=0)break i;rh(t[n>>2]|0,144776,145016);break e}e=t[n>>2]|0;if(t[u>>2]|0){t[(t[n>>2]|0)+176>>2]=t[e+96>>2];break i}if((t[t[(t[e+108>>2]|0)+44>>2]>>2]|0)!=14){t[(t[(t[n>>2]|0)+108>>2]|0)+44>>2]=0;break}}t[f>>2]=Uv(t[n>>2]|0)|0;if(t[f>>2]|0){if((t[f>>2]|0)>=0)break i;rh(t[n>>2]|0,144776,145056);break e}}while(0);e=t[(t[n>>2]|0)+108>>2]|0;if(!(t[(t[(t[n>>2]|0)+108>>2]|0)+28>>2]|0)){c=e+32|0;t[c>>2]=t[c>>2]|1024;t[f>>2]=1875;th(t[n>>2]|0,t[f>>2]|0,0,0,145096,0,0);break}c=t[n>>2]|0;if(t[(t[e+28>>2]|0)+48>>2]&1048576){e=(t[c+108>>2]|0)+32|0;t[e>>2]=t[e>>2]|1024;t[f>>2]=1876;th(t[n>>2]|0,t[f>>2]|0,0,0,145128,0,0);break}if((t[c+116>>2]|0)!=0?(t[f>>2]=zv(t[n>>2]|0,1)|0,t[(t[(t[n>>2]|0)+108>>2]|0)+80>>2]=1,(t[f>>2]|0)==-1):0){rh(t[n>>2]|0,144776,145160);break e}if((t[t[(t[(t[n>>2]|0)+108>>2]|0)+28>>2]>>2]|0)!=5?(t[(t[(t[(t[n>>2]|0)+108>>2]|0)+28>>2]|0)+88>>2]|0)!=45:0){if(t[(t[n>>2]|0)+168>>2]|0)t[f>>2]=Vv(t[n>>2]|0)|0}else a=40;do if((a|0)==40){if((t[(t[n>>2]|0)+168>>2]|0)==0?(t[(t[(t[(t[n>>2]|0)+108>>2]|0)+28>>2]|0)+116>>2]|0)==0:0)break;t[f>>2]=jv(t[n>>2]|0)|0}while(0);if(t[(t[n>>2]|0)+168>>2]|0)eh(t[n>>2]|0);if((t[f>>2]|0)==-1){rh(t[n>>2]|0,144776,145200);break e}else{t[f>>2]=0;break}}while(0);if(t[f>>2]|0)t[(t[n>>2]|0)+176>>2]=t[(t[n>>2]|0)+96>>2];t[r>>2]=t[f>>2];o=t[r>>2]|0;s=i;return o|0}while(0);t[r>>2]=-1;o=t[r>>2]|0;s=i;return o|0}function rd(e){e=e|0;var i=0,r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0;i=s;s=s+80|0;r=i+76|0;n=i+72|0;f=i+68|0;u=i+64|0;a=i+24|0;o=i+20|0;c=i+16|0;l=i+12|0;b=i+8|0;k=i+4|0;h=i;t[n>>2]=e;t[f>>2]=0;t[u>>2]=t[(t[n>>2]|0)+108>>2];if(t[(t[n>>2]|0)+168>>2]|0)eh(t[n>>2]|0);e:do if(!(t[(t[u>>2]|0)+32>>2]&512))if((t[(t[u>>2]|0)+28>>2]|0)!=0?(t[(t[u>>2]|0)+32>>2]&1024|0)==0:0){if((t[(t[(t[u>>2]|0)+28>>2]|0)+52>>2]|0)!=3?(t[(t[(t[u>>2]|0)+28>>2]|0)+52>>2]|0)!=2:0)w=21;else w=9;i:do if((w|0)==9?(t[(t[(t[u>>2]|0)+28>>2]|0)+88>>2]|0)!=45:0)if(!(t[(t[u>>2]|0)+32>>2]&256)){t[c>>2]=10;if((t[(t[u>>2]|0)+60>>2]|0)==0?(e=Ws(t[(t[(t[u>>2]|0)+28>>2]|0)+108>>2]|0,358,t[n>>2]|0)|0,t[(t[u>>2]|0)+60>>2]=e,(t[(t[u>>2]|0)+60>>2]|0)==0):0){rh(t[n>>2]|0,141728,141760);break e}if(t[(t[u>>2]|0)+32>>2]&4){t[f>>2]=0;w=21;break}Js(t[(t[u>>2]|0)+60>>2]|0,c,l,a,o)|0;t[f>>2]=Xs(t[(t[u>>2]|0)+60>>2]|0,0,0)|0;do if((t[f>>2]|0)>=0){if((t[f>>2]|0)==0?(t[(t[u>>2]|0)+32>>2]&4|0)==0:0)break;t[f>>2]=0;w=21;break i}while(0);t[f>>2]=1;e=(t[u>>2]|0)+32|0;t[e>>2]=t[e>>2]|256;Yv(t[n>>2]|0,1871,0,0,141800,t[c>>2]|0,t[l>>2]|0,a);w=21}else w=21;while(0);if((w|0)==21?(t[(t[(t[u>>2]|0)+28>>2]|0)+52>>2]|0)==2:0){w=81;break}if(t[(t[n>>2]|0)+72>>2]|0){MD(t[(t[n>>2]|0)+72>>2]|0);t[(t[n>>2]|0)+72>>2]=0}e=t[u>>2]|0;if(!(t[(t[u>>2]|0)+44>>2]|0)){do if((t[t[e+28>>2]>>2]|0)==4)w=28;else{if((t[t[(t[u>>2]|0)+28>>2]>>2]|0)==1?(t[(t[(t[u>>2]|0)+28>>2]|0)+88>>2]|0)!=45:0){w=28;break}if((t[(t[(t[u>>2]|0)+28>>2]|0)+52>>2]|0)!=4?(t[(t[(t[u>>2]|0)+28>>2]|0)+52>>2]|0)!=6:0)break;t[f>>2]=Gv(t[n>>2]|0,t[u>>2]|0,t[(t[(t[u>>2]|0)+28>>2]|0)+104>>2]|0,t[(t[u>>2]|0)+20>>2]|0)|0}while(0);if((w|0)==28)t[f>>2]=Gv(t[n>>2]|0,t[u>>2]|0,t[(t[u>>2]|0)+28>>2]|0,t[(t[u>>2]|0)+20>>2]|0)|0;if((t[f>>2]|0)>=0){w=81;break}rh(t[n>>2]|0,141728,141832);break}if(((t[(t[e+44>>2]|0)+76>>2]|0)!=0?(t[(t[u>>2]|0)+32>>2]&32|0)!=0:0)?(t[(t[u>>2]|0)+32>>2]&4|0)==0:0){if(t[(t[u>>2]|0)+32>>2]&8){t[f>>2]=Wv(t[n>>2]|0,t[(t[(t[u>>2]|0)+44>>2]|0)+76>>2]|0,(t[u>>2]|0)+24|0)|0;if(t[f>>2]|0){if((t[f>>2]|0)>=0){w=81;break}rh(t[n>>2]|0,141728,141872);break}}else{do if((t[t[(t[u>>2]|0)+28>>2]>>2]|0)==4)w=44;else{if((t[t[(t[u>>2]|0)+28>>2]>>2]|0)==1?(t[(t[(t[u>>2]|0)+28>>2]|0)+88>>2]|0)!=45:0){w=44;break}if((t[(t[(t[u>>2]|0)+28>>2]|0)+52>>2]|0)!=4?(t[(t[(t[u>>2]|0)+28>>2]|0)+52>>2]|0)!=6:0)break;t[f>>2]=Gv(t[n>>2]|0,t[u>>2]|0,t[(t[(t[u>>2]|0)+28>>2]|0)+104>>2]|0,t[(t[(t[u>>2]|0)+44>>2]|0)+76>>2]|0)|0}while(0);if((w|0)==44)t[f>>2]=Gv(t[n>>2]|0,t[u>>2]|0,t[(t[u>>2]|0)+28>>2]|0,t[(t[(t[u>>2]|0)+44>>2]|0)+76>>2]|0)|0;if(t[f>>2]|0){if((t[f>>2]|0)>=0){w=81;break}rh(t[n>>2]|0,141728,141832);break}}if(!(t[(t[n>>2]|0)+80>>2]&1)){w=81;break}if(!(t[(t[u>>2]|0)+4>>2]|0)){w=81;break}t[k>>2]=fw(t[(t[u>>2]|0)+28>>2]|0,t[(t[(t[u>>2]|0)+44>>2]|0)+76>>2]|0)|0;if(t[k>>2]|0){t[b>>2]=yy(t[k>>2]|0)|0;pAi[t[135736>>2]&511](t[k>>2]|0)}else t[b>>2]=yy(t[(t[(t[u>>2]|0)+44>>2]|0)+76>>2]|0)|0;if(!(t[b>>2]|0)){rh(t[n>>2]|0,141728,141912);break}else{Hy(t[(t[u>>2]|0)+4>>2]|0,t[b>>2]|0)|0;w=81;break}}if(!(t[(t[u>>2]|0)+32>>2]&4)){do if((t[t[(t[u>>2]|0)+28>>2]>>2]|0)==4)w=63;else{if((t[t[(t[u>>2]|0)+28>>2]>>2]|0)==1?(t[(t[(t[u>>2]|0)+28>>2]|0)+88>>2]|0)!=45:0){w=63;break}if((t[(t[(t[u>>2]|0)+28>>2]|0)+52>>2]|0)!=4?(t[(t[(t[u>>2]|0)+28>>2]|0)+52>>2]|0)!=6:0)break;t[f>>2]=Gv(t[n>>2]|0,t[u>>2]|0,t[(t[(t[u>>2]|0)+28>>2]|0)+104>>2]|0,t[(t[u>>2]|0)+20>>2]|0)|0}while(0);if((w|0)==63)t[f>>2]=Gv(t[n>>2]|0,t[u>>2]|0,t[(t[u>>2]|0)+28>>2]|0,t[(t[u>>2]|0)+20>>2]|0)|0;if(t[f>>2]|0){if((t[f>>2]|0)>=0){w=81;break}rh(t[n>>2]|0,141728,141832);break}if((t[(t[(t[u>>2]|0)+44>>2]|0)+76>>2]|0)!=0?(t[(t[(t[u>>2]|0)+44>>2]|0)+48>>2]&8|0)!=0:0){if(t[(t[u>>2]|0)+32>>2]&128){t[f>>2]=1856;th(t[n>>2]|0,t[f>>2]|0,0,0,141936,0,0);w=81;break}e=t[u>>2]|0;if((t[(t[(t[u>>2]|0)+28>>2]|0)+52>>2]|0)==3){if(Xl(t[e+20>>2]|0,t[(t[(t[u>>2]|0)+44>>2]|0)+76>>2]|0)|0){w=81;break}t[f>>2]=1857;th(t[n>>2]|0,t[f>>2]|0,0,0,142024,t[(t[u>>2]|0)+20>>2]|0,t[(t[(t[u>>2]|0)+44>>2]|0)+76>>2]|0);w=81;break}if((t[(t[e+28>>2]|0)+52>>2]|0)!=4?(t[(t[(t[u>>2]|0)+28>>2]|0)+52>>2]|0)!=6:0){w=81;break}if(!(Xl(t[(t[u>>2]|0)+20>>2]|0,t[(t[(t[u>>2]|0)+44>>2]|0)+76>>2]|0)|0)){t[f>>2]=1858;th(t[n>>2]|0,t[f>>2]|0,0,0,142096,t[(t[u>>2]|0)+20>>2]|0,t[(t[(t[u>>2]|0)+44>>2]|0)+76>>2]|0);w=81}else w=81}else w=81}else w=81}else w=81;else{t[(t[n>>2]|0)+176>>2]=(t[(t[n>>2]|0)+96>>2]|0)-1;w=81}while(0);e:do if((w|0)==81){if((t[(t[n>>2]|0)+96>>2]|0)<0){t[r>>2]=0;d=t[r>>2]|0;s=i;return d|0}if((t[(t[n>>2]|0)+96>>2]|0)==(t[(t[n>>2]|0)+176>>2]|0))t[(t[n>>2]|0)+176>>2]=-1;if((t[(t[u>>2]|0)+80>>2]|0)!=0?(Kv(t[n>>2]|0,t[(t[n>>2]|0)+96>>2]|0)|0)==-1:0)break;do if(t[(t[u>>2]|0)+56>>2]|0){if((t[(t[n>>2]|0)+184>>2]|0)==0?(t[(t[n>>2]|0)+188>>2]|0)==0:0)break;if((Xv(t[n>>2]|0,t[u>>2]|0)|0)==-1)break e}while(0);if((t[(t[(t[n>>2]|0)+108>>2]|0)+76>>2]|0)!=0?(fT(t[n>>2]|0)|0)==-1:0)break;do if((t[(t[u>>2]|0)+52>>2]|0)!=0?(t[(t[n>>2]|0)+96>>2]|0)>0:0){if((t[(t[n>>2]|0)+184>>2]|0)==0?(t[(t[n>>2]|0)+188>>2]|0)==0:0)break;if((tT(t[n>>2]|0)|0)==-1)break e}while(0);ih(t[n>>2]|0,t[u>>2]|0);b=t[n>>2]|0;if(!(t[(t[n>>2]|0)+96>>2]|0)){k=b+96|0;t[k>>2]=(t[k>>2]|0)+-1;t[(t[n>>2]|0)+108>>2]=0;t[r>>2]=0;d=t[r>>2]|0;s=i;return d|0}if(t[b+112>>2]|0){t[h>>2]=t[(t[n>>2]|0)+112>>2];do{if((t[(t[h>>2]|0)+8>>2]|0)==(t[(t[n>>2]|0)+96>>2]|0))t[(t[h>>2]|0)+8>>2]=-1;t[h>>2]=t[t[h>>2]>>2]}while((t[h>>2]|0)!=0)}b=(t[n>>2]|0)+96|0;t[b>>2]=(t[b>>2]|0)+-1;t[(t[n>>2]|0)+108>>2]=t[(t[(t[n>>2]|0)+100>>2]|0)+(t[(t[n>>2]|0)+96>>2]<<2)>>2];t[r>>2]=t[f>>2];d=t[r>>2]|0;s=i;return d|0}while(0);t[(t[n>>2]|0)+52>>2]=-1;t[r>>2]=-1;d=t[r>>2]|0;s=i;return d|0}function nd(e,i,r,n,f,a){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;a=a|0;var o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0;o=s;s=s+32|0;c=o+24|0;l=o+20|0;b=o+16|0;k=o+12|0;h=o+8|0;w=o+4|0;d=o;t[l>>2]=e;t[b>>2]=i;t[k>>2]=r;t[h>>2]=n;t[w>>2]=f;t[d>>2]=a;if(t[d>>2]|0)t[t[d>>2]>>2]=0;a=t[l>>2]|0;if(t[(t[(t[l>>2]|0)+108>>2]|0)+32>>2]&4){th(a,1848,0,0,141368,0,0);t[c>>2]=t[(t[l>>2]|0)+52>>2];v=t[c>>2]|0;s=o;return v|0}f=t[l>>2]|0;if((t[(t[(t[a+108>>2]|0)+28>>2]|0)+52>>2]|0)==1){th(f,1841,0,0,141456,0,0);t[c>>2]=t[(t[l>>2]|0)+52>>2];v=t[c>>2]|0;s=o;return v|0}if((t[(t[(t[f+108>>2]|0)+28>>2]|0)+52>>2]|0)==2){if((t[b>>2]|0)==3?(Dd(t[k>>2]|0,t[h>>2]|0)|0)!=0:0){t[c>>2]=0;v=t[c>>2]|0;s=o;return v|0}th(t[l>>2]|0,1843,0,0,141528,0,0);t[c>>2]=t[(t[l>>2]|0)+52>>2];v=t[c>>2]|0;s=o;return v|0}if((t[k>>2]|0)!=0?(u[t[k>>2]>>0]|0|0)!=0:0){do if((t[(t[(t[(t[l>>2]|0)+108>>2]|0)+28>>2]|0)+52>>2]|0)==3){if((t[(t[(t[l>>2]|0)+108>>2]|0)+44>>2]|0)!=0?(t[(t[(t[(t[l>>2]|0)+108>>2]|0)+44>>2]|0)+76>>2]|0)!=0:0)break;t[c>>2]=0;v=t[c>>2]|0;s=o;return v|0}while(0);do if(!(t[(t[(t[l>>2]|0)+108>>2]|0)+20>>2]|0)){b=t[w>>2]|0;if((b|0)==1){t[(t[(t[l>>2]|0)+108>>2]|0)+20>>2]=t[k>>2];break}else if((b|0)==2){t[(t[(t[l>>2]|0)+108>>2]|0)+20>>2]=t[k>>2];if(t[d>>2]|0)t[t[d>>2]>>2]=1;f=(t[(t[l>>2]|0)+108>>2]|0)+32|0;t[f>>2]=t[f>>2]|2;break}else if((b|0)==3){b=t[k>>2]|0;if((t[h>>2]|0)!=-1){f=ql(b,t[h>>2]|0)|0;t[(t[(t[l>>2]|0)+108>>2]|0)+20>>2]=f}else{f=Yl(b)|0;t[(t[(t[l>>2]|0)+108>>2]|0)+20>>2]=f}f=(t[(t[l>>2]|0)+108>>2]|0)+32|0;t[f>>2]=t[f>>2]|2;break}else break}else{if((t[h>>2]|0)<0)t[h>>2]=rs(t[k>>2]|0)|0;f=t[(t[(t[l>>2]|0)+108>>2]|0)+20>>2]|0;b=t[k>>2]|0;a=t[h>>2]|0;if(t[(t[(t[l>>2]|0)+108>>2]|0)+32>>2]&2){n=fs(f,b,a)|0;t[(t[(t[l>>2]|0)+108>>2]|0)+20>>2]=n;break}else{n=ts(f,b,a)|0;t[(t[(t[l>>2]|0)+108>>2]|0)+20>>2]=n;n=(t[(t[l>>2]|0)+108>>2]|0)+32|0;t[n>>2]=t[n>>2]|2;break}}while(0);t[c>>2]=0;v=t[c>>2]|0;s=o;return v|0}t[c>>2]=0;v=t[c>>2]|0;s=o;return v|0}function fd(e){e=e|0;var i=0,r=0,n=0,f=0;i=s;s=s+16|0;r=i+4|0;n=i;t[n>>2]=e;do if(!(t[(t[n>>2]|0)+88>>2]|0)){if(t[(t[n>>2]|0)+20>>2]|0){e=uT(140432,t[(t[(t[n>>2]|0)+20>>2]|0)+60>>2]|0)|0;t[(t[n>>2]|0)+88>>2]=e}else{e=Mk(140432)|0;t[(t[n>>2]|0)+88>>2]=e}e=t[n>>2]|0;if(t[(t[n>>2]|0)+88>>2]|0){Dk(t[e+88>>2]|0,t[(t[n>>2]|0)+8>>2]|0,t[(t[n>>2]|0)+12>>2]|0,t[(t[n>>2]|0)+4>>2]|0);Pk(t[(t[n>>2]|0)+88>>2]|0,t[(t[n>>2]|0)+16>>2]|0,t[(t[n>>2]|0)+4>>2]|0);break}rh(e,141232,141264);t[r>>2]=-1;f=t[r>>2]|0;s=i;return f|0}while(0);t[r>>2]=0;f=t[r>>2]|0;s=i;return f|0}function td(e,i){e=e|0;i=i|0;var r=0,n=0,f=0;r=s;s=s+16|0;n=r+4|0;f=r;t[n>>2]=e;t[f>>2]=i;if(!(t[(t[(t[n>>2]|0)+52>>2]|0)+76>>2]|0)){s=r;return}aO(t[(t[(t[n>>2]|0)+52>>2]|0)+76>>2]|0,359,t[f>>2]|0);s=r;return}function ud(e){e=e|0;var i=0,r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0;i=s;s=s+48|0;r=i+32|0;n=i+28|0;f=i+24|0;u=i+20|0;a=i+16|0;o=i+12|0;c=i+8|0;l=i+4|0;b=i;t[r>>2]=e;if(!(t[r>>2]|0)){s=i;return}t[(t[r>>2]|0)+152>>2]=0;t[(t[r>>2]|0)+84>>2]=0;t[(t[r>>2]|0)+24>>2]=0;t[(t[r>>2]|0)+160>>2]=0;t[(t[r>>2]|0)+184>>2]=0;if(t[(t[r>>2]|0)+72>>2]|0){MD(t[(t[r>>2]|0)+72>>2]|0);t[(t[r>>2]|0)+72>>2]=0}if(t[(t[r>>2]|0)+112>>2]|0){t[n>>2]=t[(t[r>>2]|0)+112>>2];do{t[f>>2]=t[t[n>>2]>>2];pAi[t[135736>>2]&511](t[n>>2]|0);t[n>>2]=t[f>>2]}while((t[n>>2]|0)!=0);t[(t[r>>2]|0)+112>>2]=0}if(t[(t[r>>2]|0)+124>>2]|0){t[u>>2]=t[(t[r>>2]|0)+124>>2];while(1){if(!(t[u>>2]|0))break;t[a>>2]=t[u>>2];t[u>>2]=t[(t[u>>2]|0)+12>>2];oT(t[a>>2]|0)}t[(t[r>>2]|0)+124>>2]=0}if(t[(t[r>>2]|0)+128>>2]|0){t[o>>2]=0;while(1){if((t[o>>2]|0)>=(t[(t[r>>2]|0)+132>>2]|0))break;t[c>>2]=t[(t[(t[r>>2]|0)+128>>2]|0)+(t[o>>2]<<2)>>2];pAi[t[135736>>2]&511](t[(t[c>>2]|0)+4>>2]|0);pAi[t[135736>>2]&511](t[c>>2]|0);t[o>>2]=(t[o>>2]|0)+1}pAi[t[135736>>2]&511](t[(t[r>>2]|0)+128>>2]|0);t[(t[r>>2]|0)+128>>2]=0;t[(t[r>>2]|0)+132>>2]=0;t[(t[r>>2]|0)+136>>2]=0}if(t[(t[r>>2]|0)+116>>2]|0){$k(t[(t[r>>2]|0)+116>>2]|0);t[(t[r>>2]|0)+116>>2]=0}if(t[(t[r>>2]|0)+168>>2]|0)eh(t[r>>2]|0);e:do if(t[(t[r>>2]|0)+100>>2]|0){t[l>>2]=0;while(1){if((t[l>>2]|0)>=(t[(t[r>>2]|0)+104>>2]|0))break e;t[b>>2]=t[(t[(t[r>>2]|0)+100>>2]|0)+(t[l>>2]<<2)>>2];if(!(t[b>>2]|0))break e;ih(t[r>>2]|0,t[b>>2]|0);t[l>>2]=(t[l>>2]|0)+1}}while(0);cT(t[(t[r>>2]|0)+180>>2]|0);bz(t[(t[r>>2]|0)+156>>2]|0);l=lz()|0;t[(t[r>>2]|0)+156>>2]=l;if(!(t[(t[r>>2]|0)+48>>2]|0)){s=i;return}pAi[t[135736>>2]&511](t[(t[r>>2]|0)+48>>2]|0);t[(t[r>>2]|0)+48>>2]=0;s=i;return}function ad(e){e=e|0;var i=0,r=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if(!(t[r>>2]|0)){s=i;return}if(t[(t[r>>2]|0)+32>>2]|0)Yk(t[(t[r>>2]|0)+32>>2]|0);if(t[(t[r>>2]|0)+68>>2]|0)MD(t[(t[r>>2]|0)+68>>2]|0);pAi[t[135736>>2]&511](t[r>>2]|0);s=i;return}function od(e){e=e|0;var i=0,r=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if(!(t[r>>2]|0)){s=i;return}if(t[(t[r>>2]|0)+4>>2]|0)Yk(t[(t[r>>2]|0)+4>>2]|0);if(t[(t[r>>2]|0)+32>>2]|0)MD(t[(t[r>>2]|0)+32>>2]|0);pAi[t[135736>>2]&511](t[r>>2]|0);s=i;return}function cd(e){e=e|0;var i=0,r=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if(!(t[r>>2]|0)){s=i;return}pAi[t[135736>>2]&511](t[r>>2]|0);s=i;return}function ld(e){e=e|0;var i=0,r=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if(!(t[r>>2]|0)){s=i;return}if(t[(t[r>>2]|0)+24>>2]|0)Yk(t[(t[r>>2]|0)+24>>2]|0);if(t[(t[r>>2]|0)+84>>2]|0)fb(t[(t[r>>2]|0)+84>>2]|0);if(t[(t[r>>2]|0)+96>>2]|0)MD(t[(t[r>>2]|0)+96>>2]|0);pAi[t[135736>>2]&511](t[r>>2]|0);s=i;return}function sd(e){e=e|0;var i=0,r=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if(t[(t[r>>2]|0)+4>>2]|0)Yk(t[(t[r>>2]|0)+4>>2]|0);pAi[t[135736>>2]&511](t[r>>2]|0);s=i;return}function bd(e){e=e|0;var i=0,r=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if(!(t[r>>2]|0)){s=i;return}if(t[(t[r>>2]|0)+24>>2]|0)Yk(t[(t[r>>2]|0)+24>>2]|0);if(t[(t[r>>2]|0)+56>>2]|0)Wk(t[(t[r>>2]|0)+56>>2]|0);pAi[t[135736>>2]&511](t[r>>2]|0);s=i;return}function kd(e){e=e|0;var i=0,r=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if(t[(t[r>>2]|0)+4>>2]|0)Yk(t[(t[r>>2]|0)+4>>2]|0);pAi[t[135736>>2]&511](t[r>>2]|0);s=i;return}function hd(e){e=e|0;var i=0,r=0,n=0,f=0;i=s;s=s+16|0;r=i+8|0;n=i+4|0;f=i;t[r>>2]=e;if(!(t[r>>2]|0)){s=i;return}if(t[(t[r>>2]|0)+4>>2]|0)Yk(t[(t[r>>2]|0)+4>>2]|0);if(t[(t[r>>2]|0)+24>>2]|0){if(t[(t[(t[r>>2]|0)+24>>2]|0)+16>>2]|0)vj(t[(t[(t[r>>2]|0)+24>>2]|0)+16>>2]|0);pAi[t[135736>>2]&511](t[(t[r>>2]|0)+24>>2]|0)}if(t[(t[r>>2]|0)+28>>2]|0){t[n>>2]=t[(t[r>>2]|0)+28>>2];do{t[f>>2]=t[n>>2];t[n>>2]=t[t[n>>2]>>2];if(t[(t[f>>2]|0)+16>>2]|0)vj(t[(t[f>>2]|0)+16>>2]|0);pAi[t[135736>>2]&511](t[f>>2]|0)}while((t[n>>2]|0)!=0)}pAi[t[135736>>2]&511](t[r>>2]|0);s=i;return}function wd(e){e=e|0;var i=0,r=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if(!(t[r>>2]|0)){s=i;return}pAi[t[135736>>2]&511](t[r>>2]|0);s=i;return}function dd(e){e=e|0;var i=0,r=0;i=s;s=s+16|0;r=i;t[r>>2]=e;pAi[t[135736>>2]&511](t[r>>2]|0);s=i;return}function vd(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i+4|0;n=i;t[n>>2]=e;e=t[n>>2]|0;do if((t[t[n>>2]>>2]|0)==1){if((t[e>>2]|0)!=5?(t[(t[n>>2]|0)+88>>2]|0)!=45:0){t[r>>2]=143688;break}t[r>>2]=143664}else t[r>>2]=lT(t[e>>2]|0)|0;while(0);s=i;return t[r>>2]|0}function md(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0;n=s;s=s+16|0;f=n+8|0;u=n+4|0;a=n;t[f>>2]=e;t[u>>2]=i;t[a>>2]=r;dp(16,3069,t[f>>2]|0,t[u>>2]|0,t[a>>2]|0);s=n;return}function _d(e){e=e|0;var i=0,r=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if(t[(t[r>>2]|0)+8>>2]|0)pAi[t[135736>>2]&511](t[(t[r>>2]|0)+8>>2]|0);if(t[(t[r>>2]|0)+20>>2]|0)Wk(t[(t[r>>2]|0)+20>>2]|0);pAi[t[135736>>2]&511](t[r>>2]|0);s=i;return}function pd(e,i,r,n,f,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;u=u|0;var a=0,o=0,c=0,l=0,b=0,k=0,h=0;a=s;s=s+32|0;o=a+20|0;c=a+16|0;l=a+12|0;b=a+8|0;k=a+4|0;h=a;t[o>>2]=e;t[c>>2]=i;t[l>>2]=r;t[b>>2]=n;t[k>>2]=f;t[h>>2]=u;kw(t[o>>2]|0,t[c>>2]|0,t[l>>2]|0,t[b>>2]|0,t[k>>2]|0,t[h>>2]|0,0,0);s=a;return}function Ed(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i+4|0;n=i;t[n>>2]=e;e=t[n>>2]|0;do if((t[t[n>>2]>>2]|0)!=1){if(t[e+48>>2]&64){t[r>>2]=3;break}if(t[(t[n>>2]|0)+48>>2]&128){t[r>>2]=0;break}if(!(t[(t[n>>2]|0)+48>>2]&256)){t[r>>2]=-1;break}if(t[(t[n>>2]|0)+48>>2]&16777216){t[r>>2]=1;break}if(t[(t[n>>2]|0)+48>>2]&33554432){t[r>>2]=2;break}else{t[r>>2]=3;break}}else{if((t[e+88>>2]|0)!=1?(t[(t[n>>2]|0)+88>>2]|0)!=46:0)if((t[(t[n>>2]|0)+88>>2]|0)==2){t[r>>2]=2;break}else{t[r>>2]=3;break}t[r>>2]=1}while(0);s=i;return t[r>>2]|0}function Sd(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0;r=s;s=s+48|0;n=r+32|0;f=r+28|0;u=r+24|0;a=r+20|0;o=r+16|0;c=r+12|0;l=r+8|0;b=r+4|0;k=r;t[f>>2]=e;t[u>>2]=i;i=t[f>>2]|0;if(t[(t[f>>2]|0)+36>>2]|0){t[a>>2]=t[i+96>>2];e:while(1){if((t[a>>2]|0)<0){h=14;break}i:do if(t[(t[(t[(t[f>>2]|0)+100>>2]|0)+(t[a>>2]<<2)>>2]|0)+68>>2]|0){t[c>>2]=t[(t[(t[f>>2]|0)+100>>2]|0)+(t[a>>2]<<2)>>2];t[o>>2]=0;while(1){if((t[o>>2]|0)>=(t[(t[c>>2]|0)+68>>2]<<1|0))break i;if((t[u>>2]|0)==0?(t[(t[(t[c>>2]|0)+64>>2]|0)+(t[o>>2]<<2)>>2]|0)==0:0){h=11;break e}if((t[u>>2]|0)!=0?(Xl(t[u>>2]|0,t[(t[(t[c>>2]|0)+64>>2]|0)+(t[o>>2]<<2)>>2]|0)|0)!=0:0){h=11;break e}t[o>>2]=(t[o>>2]|0)+2}}while(0);t[a>>2]=(t[a>>2]|0)+-1}if((h|0)==11){t[n>>2]=t[(t[(t[c>>2]|0)+64>>2]|0)+((t[o>>2]|0)+1<<2)>>2];w=t[n>>2]|0;s=r;return w|0}else if((h|0)==14){t[n>>2]=0;w=t[n>>2]|0;s=r;return w|0}}else{h=t[f>>2]|0;if(t[i+160>>2]|0){t[l>>2]=PI(t[h+160>>2]|0,t[u>>2]|0)|0;if(t[l>>2]|0){t[b>>2]=kz(t[(t[f>>2]|0)+156>>2]|0,t[l>>2]|0,-1)|0;pAi[t[135736>>2]&511](t[l>>2]|0);t[n>>2]=t[b>>2];w=t[n>>2]|0;s=r;return w|0}else{t[n>>2]=0;w=t[n>>2]|0;s=r;return w|0}}if((t[(t[h+108>>2]|0)+4>>2]|0)!=0?(t[(t[(t[(t[f>>2]|0)+108>>2]|0)+4>>2]|0)+32>>2]|0)!=0:0){t[k>>2]=wF(t[(t[(t[(t[f>>2]|0)+108>>2]|0)+4>>2]|0)+32>>2]|0,t[(t[(t[f>>2]|0)+108>>2]|0)+4>>2]|0,t[u>>2]|0)|0;if(t[k>>2]|0){t[n>>2]=t[(t[k>>2]|0)+8>>2];w=t[n>>2]|0;s=r;return w|0}else{t[n>>2]=0;w=t[n>>2]|0;s=r;return w|0}}rh(t[f>>2]|0,154192,154224);t[n>>2]=0;w=t[n>>2]|0;s=r;return w|0}return 0}function gd(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0;n=s;s=s+32|0;f=n+20|0;u=n+16|0;a=n+12|0;o=n+8|0;c=n+4|0;l=n;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;t[c>>2]=0;if((t[a>>2]|0)==0|(t[u>>2]|0)==0){t[f>>2]=0;b=t[f>>2]|0;s=n;return b|0}do if(t[u>>2]|0){if((Xl(t[o>>2]|0,t[(t[u>>2]|0)+4>>2]|0)|0)!=0?(t[c>>2]=rO(t[(t[u>>2]|0)+44>>2]|0,t[a>>2]|0)|0,(t[c>>2]|0)!=0):0)break;if((bO(t[(t[u>>2]|0)+48>>2]|0)|0)>1){r=t[(t[u>>2]|0)+48>>2]|0;if(!(t[o>>2]|0))t[l>>2]=rO(r,145792)|0;else t[l>>2]=rO(r,t[o>>2]|0)|0;if(t[l>>2]|0)t[c>>2]=rO(t[(t[(t[l>>2]|0)+52>>2]|0)+44>>2]|0,t[a>>2]|0)|0}}while(0);t[f>>2]=t[c>>2];b=t[f>>2]|0;s=n;return b|0}function yd(e){e=e|0;var i=0,r=0,n=0,f=0,u=0;i=s;s=s+16|0;r=i+4|0;n=i;t[n>>2]=e;while(1){if(!(t[n>>2]|0)){f=7;break}if((t[(t[n>>2]|0)+88>>2]|0)==46){f=5;break}if(t[(t[n>>2]|0)+48>>2]&16384){f=5;break}t[n>>2]=t[(t[n>>2]|0)+64>>2]}if((f|0)==5){t[r>>2]=t[n>>2];u=t[r>>2]|0;s=i;return u|0}else if((f|0)==7){t[r>>2]=0;u=t[r>>2]|0;s=i;return u|0}return 0}function Fd(e,i,r,n,f,u,a,o,c,l){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;u=u|0;a=a|0;o=o|0;c=c|0;l=l|0;var b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0,S=0,g=0,y=0,F=0,O=0,A=0,M=0,R=0,N=0,T=0;b=s;s=s+112|0;k=b;h=b+56|0;w=b+52|0;d=b+48|0;v=b+44|0;m=b+40|0;_=b+36|0;p=b+32|0;E=b+28|0;S=b+24|0;g=b+20|0;y=b+16|0;F=b+12|0;O=b+8|0;A=b+4|0;M=b+85|0;R=b+60|0;t[h>>2]=e;t[w>>2]=i;t[d>>2]=r;t[v>>2]=n;t[m>>2]=f;t[_>>2]=u;t[p>>2]=a;t[E>>2]=o;t[S>>2]=c;t[g>>2]=l;t[y>>2]=0;t[F>>2]=0;t[A>>2]=Ad(t[h>>2]|0,t[d>>2]|0)|0;bw(F,t[h>>2]|0,t[d>>2]|0)|0;if((t[w>>2]|0)==1840)t[O>>2]=1007;else t[O>>2]=t[t[p>>2]>>2];t[F>>2]=us(t[F>>2]|0,142560)|0;t[F>>2]=us(t[F>>2]|0,148120)|0;l=t[F>>2]|0;t[F>>2]=us(l,fh(t[O>>2]|0)|0)|0;t[F>>2]=us(t[F>>2]|0,156768)|0;do if(!(t[E>>2]|0)){if((t[O>>2]|0)==1009|(t[O>>2]|0)==1011|(t[O>>2]|0)==1010){l=t[F>>2]|0;if((t[A>>2]|0)==2)t[F>>2]=us(l,156776)|0;else t[F>>2]=us(l,156816)|0;t[k>>2]=HD(t[p>>2]|0)|0;SY(M,24,156856,k)|0;t[k>>2]=t[m>>2];SY(R,24,156856,k)|0;do if((t[O>>2]|0)!=1009){if((t[O>>2]|0)==1010){t[F>>2]=us(t[F>>2]|0,156912)|0;break}if((t[O>>2]|0)==1011)t[F>>2]=us(t[F>>2]|0,156968)|0}else t[F>>2]=us(t[F>>2]|0,156864)|0;while(0);l=t[h>>2]|0;c=t[w>>2]|0;o=t[d>>2]|0;a=t[F>>2]|0;if((t[A>>2]|0)==2){sT(l,c,o,a,t[v>>2]|0,R,M);break}else{pd(l,c,o,a,R,M);break}}if((t[O>>2]|0)==1007){t[F>>2]=us(t[F>>2]|0,157024)|0;a=t[h>>2]|0;o=t[w>>2]|0;c=t[d>>2]|0;l=t[F>>2]|0;u=t[v>>2]|0;pd(a,o,c,l,u,bT(t[h>>2]|0,y,t[_>>2]|0)|0);break}if((t[O>>2]|0)==1006){t[F>>2]=us(t[F>>2]|0,157080)|0;pd(t[h>>2]|0,t[w>>2]|0,t[d>>2]|0,t[F>>2]|0,t[v>>2]|0,t[(t[p>>2]|0)+8>>2]|0);break}if((t[O>>2]|0)==1e3){t[F>>2]=us(t[F>>2]|0,157136)|0;pd(t[h>>2]|0,t[w>>2]|0,t[d>>2]|0,t[F>>2]|0,t[v>>2]|0,t[(t[p>>2]|0)+8>>2]|0);break}if((t[O>>2]|0)==1002){t[F>>2]=us(t[F>>2]|0,157200)|0;pd(t[h>>2]|0,t[w>>2]|0,t[d>>2]|0,t[F>>2]|0,t[v>>2]|0,t[(t[p>>2]|0)+8>>2]|0);break}if((t[O>>2]|0)==1001){t[F>>2]=us(t[F>>2]|0,157272)|0;pd(t[h>>2]|0,t[w>>2]|0,t[d>>2]|0,t[F>>2]|0,t[v>>2]|0,t[(t[p>>2]|0)+8>>2]|0);break}if((t[O>>2]|0)==1003){t[F>>2]=us(t[F>>2]|0,157320)|0;pd(t[h>>2]|0,t[w>>2]|0,t[d>>2]|0,t[F>>2]|0,t[v>>2]|0,t[(t[p>>2]|0)+8>>2]|0);break}if((t[O>>2]|0)==1004){t[F>>2]=us(t[F>>2]|0,157360)|0;pd(t[h>>2]|0,t[w>>2]|0,t[d>>2]|0,t[F>>2]|0,t[v>>2]|0,t[(t[p>>2]|0)+8>>2]|0);break}if((t[O>>2]|0)==1005){t[F>>2]=us(t[F>>2]|0,157424)|0;pd(t[h>>2]|0,t[w>>2]|0,t[d>>2]|0,t[F>>2]|0,t[v>>2]|0,t[(t[p>>2]|0)+8>>2]|0);break}u=t[F>>2]|0;if((t[A>>2]|0)==2){t[F>>2]=us(u,157496)|0;pd(t[h>>2]|0,t[w>>2]|0,t[d>>2]|0,t[F>>2]|0,t[v>>2]|0,0);break}else{t[F>>2]=us(u,157536)|0;pd(t[h>>2]|0,t[w>>2]|0,t[d>>2]|0,t[F>>2]|0,0,0);break}}else{t[F>>2]=us(t[F>>2]|0,t[E>>2]|0)|0;t[F>>2]=us(t[F>>2]|0,142704)|0;pd(t[h>>2]|0,t[w>>2]|0,t[d>>2]|0,t[F>>2]|0,t[S>>2]|0,t[g>>2]|0)}while(0);if(!(t[y>>2]|0)){N=t[33934]|0;T=t[F>>2]|0;pAi[N&511](T);s=b;return}pAi[t[135736>>2]&511](t[y>>2]|0);t[y>>2]=0;N=t[33934]|0;T=t[F>>2]|0;pAi[N&511](T);s=b;return}function Od(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0;r=s;s=s+32|0;n=r+28|0;f=r+24|0;u=r+20|0;a=r+16|0;o=r+12|0;c=r+8|0;l=r+4|0;b=r;t[f>>2]=e;t[u>>2]=i;e:while(1){if(!(t[f>>2]|0)){k=20;break}t[a>>2]=ED(qD(t[f>>2]|0)|0)|0;t[o>>2]=ED(qD(t[u>>2]|0)|0)|0;t[c>>2]=yd(t[a>>2]|0)|0;t[l>>2]=yd(t[o>>2]|0)|0;if((t[c>>2]|0)!=(t[l>>2]|0)){k=4;break}do if((t[(t[c>>2]|0)+88>>2]|0)!=1){if((t[t[c>>2]>>2]|0)==1?(t[(t[c>>2]|0)+88>>2]|0)==46:0){k=8;break}t[b>>2]=ID(t[f>>2]|0,1,t[u>>2]|0,1)|0;if((t[b>>2]|0)==-2){k=11;break e}if(t[b>>2]|0){k=13;break e}}else k=8;while(0);if((k|0)==8?(k=0,i=yD(t[f>>2]|0)|0,(Xl(i,yD(t[u>>2]|0)|0)|0)==0):0){k=9;break}t[f>>2]=gD(t[f>>2]|0)|0;i=(t[f>>2]|0)!=0;h=gD(t[u>>2]|0)|0;if(!i){k=17;break}t[u>>2]=h;if(!(t[u>>2]|0)){k=16;break}}do if((k|0)==4)t[n>>2]=0;else if((k|0)==9)t[n>>2]=0;else if((k|0)==11)t[n>>2]=-1;else if((k|0)==13)t[n>>2]=0;else if((k|0)==16)t[n>>2]=0;else if((k|0)==17)if(h){t[n>>2]=0;break}else{t[n>>2]=1;break}else if((k|0)==20)t[n>>2]=0;while(0);s=r;return t[n>>2]|0}function Ad(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0;r=s;s=s+16|0;n=r+8|0;f=r+4|0;u=r;t[f>>2]=e;t[u>>2]=i;if(t[u>>2]|0){t[n>>2]=t[(t[u>>2]|0)+4>>2];a=t[n>>2]|0;s=r;return a|0}if((t[t[f>>2]>>2]|0)==2?(t[(t[f>>2]|0)+108>>2]|0)!=0:0){t[n>>2]=t[t[(t[f>>2]|0)+108>>2]>>2];a=t[n>>2]|0;s=r;return a|0}t[n>>2]=-1;a=t[n>>2]|0;s=r;return a|0}function Md(e){e=e|0;var i=0,r=0,n=0,f=0;i=s;s=s+16|0;r=i+4|0;n=i;t[n>>2]=e;switch(t[t[n>>2]>>2]|0){case 15:{if(t[(t[n>>2]|0)+60>>2]&1)t[r>>2]=1;else f=10;break}case 17:{t[r>>2]=1;break}case 4:case 5:{if(t[(t[n>>2]|0)+48>>2]&8)t[r>>2]=1;else f=10;break}case 14:{if(t[(t[n>>2]|0)+48>>2]&2)t[r>>2]=1;else f=10;break}default:t[r>>2]=1}if((f|0)==10)t[r>>2]=0;s=i;return t[r>>2]|0}function Rd(e,i){e=e|0;i=i|0;var r=0,n=0,f=0;r=s;s=s+16|0;n=r+4|0;f=r;t[n>>2]=e;t[f>>2]=i;i=t[n>>2]|0;n=kT(t[f>>2]|0)|0;e=uh(i,n,hT(t[f>>2]|0)|0)|0;s=r;return e|0}function Nd(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0;r=s;s=s+16|0;n=r+8|0;f=r+4|0;u=r;t[n>>2]=e;t[f>>2]=i;t[u>>2]=0;i=t[t[n>>2]>>2]|0;e=us(i,vd(t[f>>2]|0)|0)|0;t[t[n>>2]>>2]=e;e=us(t[t[n>>2]>>2]|0,143656)|0;t[t[n>>2]>>2]=e;e=t[t[n>>2]>>2]|0;i=us(e,Rd(u,t[f>>2]|0)|0)|0;t[t[n>>2]>>2]=i;i=us(t[t[n>>2]>>2]|0,142568)|0;t[t[n>>2]>>2]=i;if(!(t[u>>2]|0)){a=t[n>>2]|0;o=t[a>>2]|0;s=r;return o|0}pAi[t[135736>>2]&511](t[u>>2]|0);t[u>>2]=0;a=t[n>>2]|0;o=t[a>>2]|0;s=r;return o|0}function Td(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i+4|0;n=i;t[n>>2]=e;e=t[n>>2]|0;if((e|0)==1)t[r>>2]=148168;else if((e|0)==2)t[r>>2]=148176;else if((e|0)==3)t[r>>2]=148184;else t[r>>2]=148192;s=i;return t[r>>2]|0}function Ld(e,i,r,n,f,u,a,o,c,l){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;u=u|0;a=a|0;o=o|0;c=c|0;l=l|0;var b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0,S=0,g=0,y=0,F=0,O=0,A=0,M=0,R=0,N=0,T=0,L=0,D=0,C=0,P=0,B=0;b=s;s=s+96|0;k=b;h=b+88|0;w=b+84|0;d=b+80|0;v=b+76|0;m=b+72|0;_=b+68|0;p=b+64|0;E=b+60|0;S=b+56|0;g=b+52|0;y=b+48|0;F=b+44|0;O=b+40|0;A=b+36|0;M=b+32|0;R=b+28|0;N=b+24|0;T=b+20|0;L=b+16|0;t[h>>2]=e;t[w>>2]=i;t[d>>2]=r;t[v>>2]=n;t[m>>2]=f;t[_>>2]=u;t[p>>2]=a;t[E>>2]=o;t[S>>2]=c;t[g>>2]=l;t[y>>2]=0;t[F>>2]=0;t[O>>2]=0;if(!(t[h>>2]|0)){s=b;return}l=t[h>>2]|0;if((t[t[h>>2]>>2]|0)!=2){if((t[l>>2]|0)!=1){c=t[33976]|0;o=t[33980]|0;t[k>>2]=140328;t[k+4>>2]=2125;yAi[c&511](o,140296,k);s=b;return}t[L>>2]=t[h>>2];o=t[L>>2]|0;if((t[w>>2]|0)!=1){c=o+20|0;t[c>>2]=(t[c>>2]|0)+1;t[(t[L>>2]|0)+16>>2]=t[d>>2];t[F>>2]=t[(t[L>>2]|0)+8>>2]}else t[F>>2]=t[o+12>>2];t[y>>2]=t[(t[L>>2]|0)+24>>2];t[O>>2]=t[(t[L>>2]|0)+4>>2];L=t[y>>2]|0;o=t[F>>2]|0;c=t[O>>2]|0;a=t[h>>2]|0;u=t[v>>2]|0;f=t[d>>2]|0;n=t[w>>2]|0;r=t[p>>2]|0;i=t[E>>2]|0;e=t[S>>2]|0;D=t[_>>2]|0;C=t[E>>2]|0;P=t[S>>2]|0;B=t[g>>2]|0;t[k>>2]=t[p>>2];t[k+4>>2]=C;t[k+8>>2]=P;t[k+12>>2]=B;cp(L,o,c,a,u,16,f,n,0,0,r,i,e,0,0,D,k);s=b;return}t[A>>2]=l;t[M>>2]=0;t[R>>2]=0;l=t[A>>2]|0;if((t[w>>2]|0)!=1){D=l+56|0;t[D>>2]=(t[D>>2]|0)+1;t[(t[A>>2]|0)+52>>2]=t[d>>2];t[F>>2]=t[(t[A>>2]|0)+8>>2]}else t[F>>2]=t[l+12>>2];t[y>>2]=t[(t[A>>2]|0)+16>>2];t[O>>2]=t[(t[A>>2]|0)+4>>2];do if(!(t[m>>2]|0)){if(((t[v>>2]|0)==0?(t[(t[A>>2]|0)+96>>2]|0)>=0:0)?(t[(t[A>>2]|0)+108>>2]|0)!=0:0)t[v>>2]=t[(t[(t[A>>2]|0)+108>>2]|0)+4>>2];if(((t[v>>2]|0)==0?(t[(t[A>>2]|0)+40>>2]|0)!=0:0)?(t[(t[(t[A>>2]|0)+40>>2]|0)+36>>2]|0)!=0:0){t[M>>2]=t[(t[(t[(t[A>>2]|0)+40>>2]|0)+36>>2]|0)+4>>2];t[m>>2]=t[(t[(t[(t[A>>2]|0)+40>>2]|0)+36>>2]|0)+28>>2];t[R>>2]=t[(t[(t[(t[A>>2]|0)+40>>2]|0)+36>>2]|0)+32>>2]}}else{t[v>>2]=0;l=t[A>>2]|0;if(t[(t[A>>2]|0)+24>>2]|0){t[M>>2]=t[(t[l+24>>2]|0)+72>>2];break}if((t[l+40>>2]|0)!=0?(t[(t[(t[A>>2]|0)+40>>2]|0)+36>>2]|0)!=0:0)t[M>>2]=t[(t[(t[(t[A>>2]|0)+40>>2]|0)+36>>2]|0)+4>>2]}while(0);if((t[(t[A>>2]|0)+196>>2]|0)!=0?(t[M>>2]|0)==0|(t[m>>2]|0)==0:0){dAi[t[(t[A>>2]|0)+196>>2]&511](t[(t[A>>2]|0)+200>>2]|0,T,N)|0;if(!(t[M>>2]|0))t[M>>2]=t[T>>2];if(!(t[m>>2]|0))t[m>>2]=t[N>>2]}if((t[M>>2]|0)==0?(t[(t[A>>2]|0)+48>>2]|0)!=0:0)t[M>>2]=t[(t[A>>2]|0)+48>>2];A=t[y>>2]|0;y=t[F>>2]|0;F=t[O>>2]|0;O=t[h>>2]|0;h=t[v>>2]|0;v=t[d>>2]|0;d=t[w>>2]|0;w=t[M>>2]|0;M=t[m>>2]|0;m=t[p>>2]|0;N=t[E>>2]|0;T=t[S>>2]|0;l=t[R>>2]|0;R=t[_>>2]|0;_=t[E>>2]|0;E=t[S>>2]|0;S=t[g>>2]|0;t[k>>2]=t[p>>2];t[k+4>>2]=_;t[k+8>>2]=E;t[k+12>>2]=S;cp(A,y,F,O,h,17,v,d,w,M,m,N,T,0,l,R,k);s=b;return}function Dd(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,a=0,o=0;r=s;s=s+16|0;n=r+8|0;f=r+4|0;a=r;t[f>>2]=e;t[a>>2]=i;if(!(t[f>>2]|0)){t[n>>2]=1;o=t[n>>2]|0;s=r;return o|0}e:do if((t[a>>2]|0)<0){i:while(1){if(!(u[t[f>>2]>>0]|0))break e;do if((u[t[f>>2]>>0]|0|0)!=32){if(9<=(u[t[f>>2]>>0]|0|0)?(u[t[f>>2]>>0]|0|0)<=10:0)break;if((u[t[f>>2]>>0]|0|0)!=13)break i}while(0);t[f>>2]=(t[f>>2]|0)+1}t[n>>2]=0;o=t[n>>2]|0;s=r;return o|0}else{i:while(1){if(!((t[a>>2]|0)!=0?(u[t[f>>2]>>0]|0|0)!=0:0))break e;do if((u[t[f>>2]>>0]|0|0)!=32){if(9<=(u[t[f>>2]>>0]|0|0)?(u[t[f>>2]>>0]|0|0)<=10:0)break;if((u[t[f>>2]>>0]|0|0)!=13)break i}while(0);t[f>>2]=(t[f>>2]|0)+1;t[a>>2]=(t[a>>2]|0)+-1}t[n>>2]=0;o=t[n>>2]|0;s=r;return o|0}while(0);t[n>>2]=1;o=t[n>>2]|0;s=r;return o|0}function Cd(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0;r=s;s=s+16|0;n=r+8|0;f=r+4|0;u=r;t[f>>2]=e;t[u>>2]=i;do if(t[t[f>>2]>>2]|0){if((t[(t[f>>2]|0)+8>>2]|0)<=(t[(t[f>>2]|0)+4>>2]|0)?(i=(t[f>>2]|0)+8|0,t[i>>2]=t[i>>2]<<1,i=MAi[t[135760>>2]&511](t[t[f>>2]>>2]|0,t[(t[f>>2]|0)+8>>2]<<2)|0,t[t[f>>2]>>2]=i,(t[t[f>>2]>>2]|0)==0):0){Qh(0,142376,0);t[(t[f>>2]|0)+8>>2]=0;t[n>>2]=-1;a=t[n>>2]|0;s=r;return a|0}}else{i=gAi[t[135744>>2]&511](80)|0;t[t[f>>2]>>2]=i;if(t[t[f>>2]>>2]|0){t[(t[f>>2]|0)+8>>2]=20;break}Qh(0,142344,0);
	t[n>>2]=-1;a=t[n>>2]|0;s=r;return a|0}while(0);i=t[u>>2]|0;u=(t[f>>2]|0)+4|0;e=t[u>>2]|0;t[u>>2]=e+1;t[(t[t[f>>2]>>2]|0)+(e<<2)>>2]=i;t[n>>2]=0;a=t[n>>2]|0;s=r;return a|0}function Pd(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,l=0;n=s;s=s+32|0;f=n+16|0;u=n+12|0;a=n+8|0;o=n+4|0;c=n;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;t[c>>2]=Bd(t[a>>2]|0,t[o>>2]|0)|0;if(!(t[c>>2]|0)){t[f>>2]=0;l=t[f>>2]|0;s=n;return l|0}else{t[f>>2]=wT(t[u>>2]|0,t[c>>2]|0)|0;l=t[f>>2]|0;s=n;return l|0}return 0}function Bd(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0;r=s;s=s+16|0;n=r+12|0;f=r+8|0;u=r+4|0;a=r;t[f>>2]=e;t[u>>2]=i;if((t[f>>2]|0)==0|(t[u>>2]|0)==0){t[n>>2]=0;o=t[n>>2]|0;s=r;return o|0}t[a>>2]=t[(t[f>>2]|0)+44>>2];while(1){if(!(t[a>>2]|0)){c=9;break}if((t[(t[a>>2]|0)+36>>2]|0)==0?(Xl(t[(t[a>>2]|0)+8>>2]|0,t[u>>2]|0)|0)!=0:0){c=7;break}t[a>>2]=t[(t[a>>2]|0)+24>>2]}if((c|0)==7){t[n>>2]=t[a>>2];o=t[n>>2]|0;s=r;return o|0}else if((c|0)==9){t[n>>2]=0;o=t[n>>2]|0;s=r;return o|0}return 0}function Id(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;var u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0;u=s;s=s+32|0;a=u+24|0;o=u+20|0;c=u+16|0;l=u+12|0;b=u+8|0;k=u+4|0;h=u;t[o>>2]=e;t[c>>2]=i;t[l>>2]=r;t[b>>2]=n;t[k>>2]=f;if((t[o>>2]|0)==0|(t[b>>2]|0)==0|(t[l>>2]|0)==0){t[a>>2]=-1;w=t[a>>2]|0;s=u;return w|0}t[h>>2]=Hd(t[o>>2]|0,t[l>>2]|0)|0;if(t[k>>2]|0)t[t[k>>2]>>2]=t[h>>2];t[a>>2]=dT(t[o>>2]|0,t[c>>2]|0,t[l>>2]|0,t[h>>2]|0,t[b>>2]|0)|0;w=t[a>>2]|0;s=u;return w|0}function Hd(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0;r=s;s=s+16|0;n=r+12|0;f=r+8|0;u=r+4|0;a=r;t[n>>2]=e;t[f>>2]=i;t[u>>2]=sF(t[f>>2]|0)|0;if(!(t[u>>2]|0))t[u>>2]=Yl(142672)|0;t[a>>2]=kz(t[(t[n>>2]|0)+80>>2]|0,t[u>>2]|0,-1)|0;pAi[t[135736>>2]&511](t[u>>2]|0);s=r;return t[a>>2]|0}function xd(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0;n=s;s=s+16|0;f=n+12|0;u=n+8|0;a=n+4|0;o=n;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;if(Xl(t[u>>2]|0,163536)|0){if(!(t[t[a>>2]>>2]&t[o>>2])){r=t[a>>2]|0;t[r>>2]=t[r>>2]|t[o>>2]}}else if(!(Xl(t[u>>2]|0,163552)|0)){t[f>>2]=1;c=t[f>>2]|0;s=n;return c|0}t[f>>2]=0;c=t[f>>2]|0;s=n;return c|0}function Ud(e,i,r,n,f,u,a,o,c,l){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;u=u|0;a=a|0;o=o|0;c=c|0;l=l|0;var b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0,S=0,g=0;b=s;s=s+48|0;k=b+44|0;h=b+40|0;w=b+32|0;d=b+28|0;v=b+24|0;m=b+20|0;_=b+16|0;p=b+12|0;E=b+8|0;S=b+4|0;g=b;t[k>>2]=e;t[h>>2]=i;t[b+36>>2]=r;t[w>>2]=n;t[d>>2]=f;t[v>>2]=u;t[m>>2]=a;t[_>>2]=o;t[p>>2]=c;t[E>>2]=l;t[S>>2]=0;bw(S,t[k>>2]|0,t[w>>2]|0)|0;do if(!(t[_>>2]|0)){l=(t[(t[w>>2]|0)+4>>2]|0)==2;c=t[S>>2]|0;do if(t[d>>2]|0){if(l)t[S>>2]=us(c,154256)|0;else t[S>>2]=us(c,154288)|0;o=(Md(t[d>>2]|0)|0)!=0;a=t[S>>2]|0;if(o)t[S>>2]=us(a,154352)|0;else t[S>>2]=us(a,154336)|0;do if(!(t[(t[d>>2]|0)+48>>2]&256)){if(t[(t[d>>2]|0)+48>>2]&64){t[S>>2]=us(t[S>>2]|0,147936)|0;break}if(t[(t[d>>2]|0)+48>>2]&128)t[S>>2]=us(t[S>>2]|0,147952)|0}else t[S>>2]=us(t[S>>2]|0,147920)|0;while(0);if(Md(t[d>>2]|0)|0){t[g>>2]=0;t[S>>2]=us(t[S>>2]|0,143656)|0;a=t[S>>2]|0;if(t[(t[d>>2]|0)+88>>2]|0){t[S>>2]=us(a,154360)|0;t[S>>2]=us(t[S>>2]|0,t[(t[d>>2]|0)+8>>2]|0)|0}else t[S>>2]=us(a,uh(g,t[(t[d>>2]|0)+112>>2]|0,t[(t[d>>2]|0)+8>>2]|0)|0)|0;t[S>>2]=us(t[S>>2]|0,161528)|0;if(t[g>>2]|0){pAi[t[135736>>2]&511](t[g>>2]|0);t[g>>2]=0}}}else if(l){t[S>>2]=us(c,161536)|0;break}else{t[S>>2]=us(c,161568)|0;break}while(0);c=t[S>>2]|0;if(t[v>>2]|0){t[S>>2]=us(c,161608)|0;t[S>>2]=us(t[S>>2]|0,t[v>>2]|0)|0;t[S>>2]=us(t[S>>2]|0,161624)|0}else t[S>>2]=us(c,140352)|0;c=t[k>>2]|0;l=t[w>>2]|0;a=t[h>>2]|0;o=t[S>>2]|0;if((t[(t[w>>2]|0)+4>>2]|0)==2){pw(c,l,a,o,t[m>>2]|0,0);break}else{pw(c,l,a,o,0,0);break}}else{t[S>>2]=us(t[S>>2]|0,t[_>>2]|0)|0;t[S>>2]=us(t[S>>2]|0,142704)|0;vT(t[k>>2]|0,t[w>>2]|0,t[h>>2]|0,0,0,0,t[S>>2]|0,t[p>>2]|0,t[E>>2]|0,0,0,0)}while(0);if(!(t[S>>2]|0)){s=b;return}pAi[t[135736>>2]&511](t[S>>2]|0);t[S>>2]=0;s=b;return}function zd(e,i,r,n,f,a,o,c){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;a=a|0;o=o|0;c=c|0;var l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0,S=0,g=0,y=0,F=0,O=0,A=0,M=0,R=0;l=s;s=s+64|0;b=l+48|0;k=l+44|0;h=l+40|0;w=l+36|0;d=l+32|0;v=l+28|0;m=l+24|0;_=l+20|0;p=l+16|0;E=l+12|0;S=l+8|0;g=l+4|0;y=l;t[k>>2]=e;t[h>>2]=i;t[w>>2]=r;t[d>>2]=n;t[v>>2]=f;t[m>>2]=a;t[_>>2]=o;t[p>>2]=c;t[E>>2]=0;if((t[h>>2]|0)==0|(t[k>>2]|0)==0){t[b>>2]=-1;F=t[b>>2]|0;s=l;return F|0}if(!(u[t[k>>2]>>0]|0)){t[b>>2]=0;F=t[b>>2]|0;s=l;return F|0}e:do if(Xl(t[k>>2]|0,165432)|0){if((t[w>>2]|0)!=-1){c=t[h>>2]|0;t[c>>2]=t[c>>2]|t[w>>2];break}if((t[d>>2]|0)!=-1){c=t[h>>2]|0;t[c>>2]=t[c>>2]|t[d>>2]}if((t[v>>2]|0)!=-1){c=t[h>>2]|0;t[c>>2]=t[c>>2]|t[v>>2]}if((t[m>>2]|0)!=-1){c=t[h>>2]|0;t[c>>2]=t[c>>2]|t[m>>2]}if((t[_>>2]|0)!=-1){c=t[h>>2]|0;t[c>>2]=t[c>>2]|t[_>>2]}if((t[p>>2]|0)!=-1){c=t[h>>2]|0;t[c>>2]=t[c>>2]|t[p>>2]}}else{t[g>>2]=t[k>>2];while(1){do if((u[t[g>>2]>>0]|0|0)==32)O=1;else{if(9<=(u[t[g>>2]>>0]|0|0)?(u[t[g>>2]>>0]|0|0)<=10:0){O=1;break}O=(u[t[g>>2]>>0]|0|0)==13}while(0);c=t[g>>2]|0;if(O){t[g>>2]=c+1;continue}t[S>>2]=c;while(1){if(u[t[S>>2]>>0]|0){do if((u[t[S>>2]>>0]|0|0)==32)A=1;else{if(9<=(u[t[S>>2]>>0]|0|0)?(u[t[S>>2]>>0]|0|0)<=10:0){A=1;break}A=(u[t[S>>2]>>0]|0|0)==13}while(0);M=A^1}else M=0;R=t[S>>2]|0;if(!M)break;t[S>>2]=R+1}if((R|0)==(t[g>>2]|0))break e;t[y>>2]=ql(t[g>>2]|0,(t[S>>2]|0)-(t[g>>2]|0)|0)|0;do if(Xl(t[y>>2]|0,165440)|0){if((t[d>>2]|0)==-1){t[E>>2]=1;break}if(!(t[t[h>>2]>>2]&t[d>>2])){c=t[h>>2]|0;t[c>>2]=t[c>>2]|t[d>>2]}}else{if(Xl(t[y>>2]|0,165456)|0){if((t[v>>2]|0)==-1){t[E>>2]=1;break}if(t[t[h>>2]>>2]&t[v>>2])break;c=t[h>>2]|0;t[c>>2]=t[c>>2]|t[v>>2];break}if(Xl(t[y>>2]|0,165472)|0){if((t[m>>2]|0)==-1){t[E>>2]=1;break}if(t[t[h>>2]>>2]&t[m>>2])break;c=t[h>>2]|0;t[c>>2]=t[c>>2]|t[m>>2];break}if(Xl(t[y>>2]|0,165488)|0){if((t[_>>2]|0)==-1){t[E>>2]=1;break}if(t[t[h>>2]>>2]&t[_>>2])break;c=t[h>>2]|0;t[c>>2]=t[c>>2]|t[_>>2];break}if(!(Xl(t[y>>2]|0,165496)|0)){t[E>>2]=1;break}if((t[p>>2]|0)==-1){t[E>>2]=1;break}if(!(t[t[h>>2]>>2]&t[p>>2])){c=t[h>>2]|0;t[c>>2]=t[c>>2]|t[p>>2]}}while(0);if(t[y>>2]|0)pAi[t[135736>>2]&511](t[y>>2]|0);t[g>>2]=t[S>>2];if(t[E>>2]|0)break e;if(!(u[t[g>>2]>>0]|0))break}}while(0);t[b>>2]=t[E>>2];F=t[b>>2]|0;s=l;return F|0}function jd(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0;n=s;s=s+32|0;f=n+28|0;u=n+24|0;a=n+20|0;o=n+16|0;c=n+12|0;l=n+8|0;b=n+4|0;k=n;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;t[l>>2]=0;t[k>>2]=0;if((t[u>>2]|0)==0|(t[a>>2]|0)==0){t[f>>2]=0;h=t[f>>2]|0;s=n;return h|0}if(t[o>>2]|0)t[c>>2]=mT(t[u>>2]|0,t[a>>2]|0)|0;else t[c>>2]=0;t[b>>2]=t[(t[a>>2]|0)+44>>2];while(1){if(!(t[b>>2]|0))break;if((t[(t[b>>2]|0)+36>>2]|0)==0?(Xl(t[(t[b>>2]|0)+8>>2]|0,161384)|0)==0:0)w=12;else w=10;if(((w|0)==10?(w=0,(t[(t[b>>2]|0)+36>>2]|0)!=0):0)?(Xl(t[(t[(t[b>>2]|0)+36>>2]|0)+8>>2]|0,t[38526]|0)|0)!=0:0)w=12;if((w|0)==12){w=0;_T(t[u>>2]|0,3035,0,t[b>>2]|0)}t[b>>2]=t[(t[b>>2]|0)+24>>2]}Pd(t[u>>2]|0,t[a>>2]|0,161384)|0;t[l>>2]=t[(t[a>>2]|0)+12>>2];while(1){if(!(t[l>>2]|0))break;if((((t[l>>2]|0)!=0?(t[(t[l>>2]|0)+36>>2]|0)!=0:0)?(Xl(t[(t[l>>2]|0)+8>>2]|0,168752)|0)!=0:0)?(Xl(t[(t[(t[l>>2]|0)+36>>2]|0)+8>>2]|0,t[38526]|0)|0)!=0:0){t[b>>2]=t[(t[l>>2]|0)+44>>2];while(1){if(!(t[b>>2]|0))break;if((t[(t[b>>2]|0)+36>>2]|0)==0?(Xl(t[(t[b>>2]|0)+8>>2]|0,168760)|0)==0:0)w=26;else w=24;if(((w|0)==24?(w=0,(t[(t[b>>2]|0)+36>>2]|0)!=0):0)?(Xl(t[(t[(t[b>>2]|0)+36>>2]|0)+8>>2]|0,t[38526]|0)|0)!=0:0)w=26;if((w|0)==26){w=0;_T(t[u>>2]|0,3035,0,t[b>>2]|0)}t[b>>2]=t[(t[b>>2]|0)+24>>2]}o=t[u>>2]|0;r=t[l>>2]|0;pT(o,0,r,168760,ED(29)|0,0)|0;t[l>>2]=t[(t[l>>2]|0)+24>>2];continue}if((((t[l>>2]|0)!=0?(t[(t[l>>2]|0)+36>>2]|0)!=0:0)?(Xl(t[(t[l>>2]|0)+8>>2]|0,168768)|0)!=0:0)?(Xl(t[(t[(t[l>>2]|0)+36>>2]|0)+8>>2]|0,t[38526]|0)|0)!=0:0){t[b>>2]=t[(t[l>>2]|0)+44>>2];while(1){if(!(t[b>>2]|0))break;r=t[b>>2]|0;do if(!(t[(t[b>>2]|0)+36>>2]|0)){if(!(Xl(t[r+8>>2]|0,168760)|0))_T(t[u>>2]|0,3035,0,t[b>>2]|0)}else{if(!(Xl(t[(t[r+36>>2]|0)+8>>2]|0,t[38526]|0)|0)){if(!(Xl(t[(t[b>>2]|0)+8>>2]|0,168784)|0))break;if(Xl(t[(t[(t[b>>2]|0)+36>>2]|0)+8>>2]|0,168792)|0)break}_T(t[u>>2]|0,3035,0,t[b>>2]|0)}while(0);t[b>>2]=t[(t[b>>2]|0)+24>>2]}t[b>>2]=ET(t[l>>2]|0,168792,168784)|0;if(t[b>>2]|0){r=t[u>>2]|0;o=t[b>>2]|0;Id(r,0,o,ED(17)|0,0)|0}t[l>>2]=t[(t[l>>2]|0)+24>>2];continue}if(!(t[k>>2]|0))$d(t[u>>2]|0,3033,0,t[a>>2]|0,t[l>>2]|0,0,168832);t[k>>2]=1;t[l>>2]=t[(t[l>>2]|0)+24>>2]}t[f>>2]=t[c>>2];h=t[f>>2]|0;s=n;return h|0}function Vd(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0;n=s;s=s+48|0;f=n+40|0;u=n+36|0;a=n+32|0;o=n+28|0;c=n+24|0;l=n+20|0;b=n+16|0;k=n+12|0;h=n+8|0;w=n+4|0;d=n;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;t[l>>2]=0;t[b>>2]=0;t[w>>2]=0;t[d>>2]=0;if((t[u>>2]|0)==0|(t[a>>2]|0)==0|(t[o>>2]|0)==0){t[f>>2]=-1;v=t[f>>2]|0;s=n;return v|0}t[h>>2]=t[(t[o>>2]|0)+44>>2];while(1){if(!(t[h>>2]|0))break;r=t[h>>2]|0;if(!(t[(t[h>>2]|0)+36>>2]|0)){if(((Xl(t[r+8>>2]|0,161384)|0)==0?(Xl(t[(t[h>>2]|0)+8>>2]|0,162304)|0)==0:0)?(Xl(t[(t[h>>2]|0)+8>>2]|0,155456)|0)==0:0)_T(t[u>>2]|0,3035,0,t[h>>2]|0)}else if(Xl(t[(t[r+36>>2]|0)+8>>2]|0,t[38526]|0)|0)_T(t[u>>2]|0,3035,0,t[h>>2]|0);t[h>>2]=t[(t[h>>2]|0)+24>>2]}h=t[u>>2]|0;r=t[o>>2]|0;i=(pT(h,0,r,162304,ED(29)|0,l)|0)!=0;r=t[u>>2]|0;h=t[o>>2]|0;e=ED(29)|0;if(i){Ud(r,3037,0,h,e,0,t[l>>2]|0,0,0,0);t[f>>2]=t[(t[u>>2]|0)+16>>2];v=t[f>>2]|0;s=n;return v|0}if(pT(r,0,h,155456,e,b)|0){e=t[u>>2]|0;h=t[o>>2]|0;r=ED(29)|0;Ud(e,3037,0,h,r,0,t[b>>2]|0,0,0,0);t[f>>2]=t[(t[u>>2]|0)+16>>2];v=t[f>>2]|0;s=n;return v|0}t[c>>2]=t[(t[o>>2]|0)+12>>2];if((((t[c>>2]|0)!=0?(t[(t[c>>2]|0)+36>>2]|0)!=0:0)?(Xl(t[(t[c>>2]|0)+8>>2]|0,160992)|0)!=0:0)?(Xl(t[(t[(t[c>>2]|0)+36>>2]|0)+8>>2]|0,t[38526]|0)|0)!=0:0)t[c>>2]=t[(t[c>>2]|0)+24>>2];if(t[c>>2]|0)$d(t[u>>2]|0,3033,0,t[o>>2]|0,t[c>>2]|0,0,161392);t[k>>2]=t[(t[(t[(t[u>>2]|0)+28>>2]|0)+16>>2]|0)+12>>2];c=t[k>>2]|0;if(t[l>>2]|0){if(Xl(c,t[l>>2]|0)|0){sv(t[u>>2]|0,3064,0,t[o>>2]|0,168408,t[k>>2]|0);t[f>>2]=t[(t[u>>2]|0)+16>>2];v=t[f>>2]|0;s=n;return v|0}}else if(!c){sv(t[u>>2]|0,3065,0,t[o>>2]|0,168512,0);t[f>>2]=t[(t[u>>2]|0)+16>>2];v=t[f>>2]|0;s=n;return v|0}if(t[b>>2]|0)t[b>>2]=ST(t[(t[u>>2]|0)+80>>2]|0,t[b>>2]|0,t[o>>2]|0)|0;t[w>>2]=lh(t[u>>2]|0,1,t[b>>2]|0,0,0,0,t[o>>2]|0,t[k>>2]|0,t[l>>2]|0,d)|0;if(t[w>>2]|0){t[f>>2]=t[w>>2];v=t[f>>2]|0;s=n;return v|0}if((t[d>>2]|0)==0&(t[b>>2]|0)!=0)mw(t[u>>2]|0,3084,t[o>>2]|0,0,168608,t[b>>2]|0,0,0);if(((t[d>>2]|0)!=0?(t[(t[d>>2]|0)+20>>2]|0)!=0:0)?(t[(t[d>>2]|0)+32>>2]|0)==0:0)t[w>>2]=gT(t[u>>2]|0,t[a>>2]|0,t[d>>2]|0)|0;t[f>>2]=t[w>>2];v=t[f>>2]|0;s=n;return v|0}function qd(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,l=0;n=s;s=s+32|0;f=n+16|0;u=n+12|0;a=n+8|0;o=n+4|0;c=n;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;t[c>>2]=yT(t[u>>2]|0,t[a>>2]|0,t[o>>2]|0,2)|0;if(t[c>>2]|0){t[f>>2]=t[c>>2];l=t[f>>2]|0;s=n;return l|0}else{t[f>>2]=0;l=t[f>>2]|0;s=n;return l|0}return 0}function Yd(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,l=0;n=s;s=s+32|0;f=n+16|0;u=n+12|0;a=n+8|0;o=n+4|0;c=n;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;t[c>>2]=yT(t[u>>2]|0,t[a>>2]|0,t[o>>2]|0,3)|0;if(t[c>>2]|0){t[f>>2]=t[c>>2];l=t[f>>2]|0;s=n;return l|0}else{t[f>>2]=0;l=t[f>>2]|0;s=n;return l|0}return 0}function Gd(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0,S=0;f=s;s=s+64|0;u=f+52|0;a=f+48|0;o=f+44|0;c=f+40|0;l=f+36|0;b=f+32|0;k=f+28|0;h=f+24|0;w=f+20|0;d=f+16|0;v=f+12|0;m=f+8|0;_=f+4|0;p=f;t[a>>2]=e;t[o>>2]=i;t[c>>2]=r;t[l>>2]=n;t[h>>2]=0;t[w>>2]=0;t[m>>2]=0;t[_>>2]=0;t[p>>2]=0;if((t[a>>2]|0)==0|(t[o>>2]|0)==0|(t[c>>2]|0)==0){t[u>>2]=0;E=t[u>>2]|0;s=f;return E|0}t[k>>2]=t[(t[a>>2]|0)+84>>2];if(t[l>>2]|0){t[d>>2]=Bd(t[c>>2]|0,161352)|0;n=t[a>>2]|0;if(!(t[d>>2]|0)){FT(n,3036,0,t[c>>2]|0,161352,0);t[u>>2]=0;E=t[u>>2]|0;s=f;return E|0}r=t[d>>2]|0;if(Id(n,0,r,ED(22)|0,w)|0){t[u>>2]=0;E=t[u>>2]|0;s=f;return E|0}}r=t[a>>2]|0;n=t[o>>2]|0;do if(!(t[l>>2]|0)){t[b>>2]=Av(r,n,5,0,t[(t[a>>2]|0)+112>>2]|0,t[c>>2]|0,0)|0;if(t[b>>2]|0){t[w>>2]=t[(t[b>>2]|0)+8>>2];t[(t[b>>2]|0)+36>>2]=t[c>>2];t[t[b>>2]>>2]=5;break}t[u>>2]=0;E=t[u>>2]|0;s=f;return E|0}else{t[b>>2]=Av(r,n,5,t[w>>2]|0,t[(t[a>>2]|0)+112>>2]|0,t[c>>2]|0,1)|0;if(t[b>>2]|0){t[(t[b>>2]|0)+36>>2]=t[c>>2];t[t[b>>2]>>2]=5;i=(t[b>>2]|0)+48|0;t[i>>2]=t[i>>2]|8;break}t[u>>2]=0;E=t[u>>2]|0;s=f;return E|0}while(0);t[(t[b>>2]|0)+112>>2]=t[(t[a>>2]|0)+112>>2];t[d>>2]=t[(t[c>>2]|0)+44>>2];while(1){if(!(t[d>>2]|0))break;w=t[d>>2]|0;do if(!(t[(t[d>>2]|0)+36>>2]|0)){if(Xl(t[w+8>>2]|0,161384)|0){Pd(t[a>>2]|0,t[c>>2]|0,161384)|0;break}if(Xl(t[(t[d>>2]|0)+8>>2]|0,167064)|0){if(!(OT(t[a>>2]|0,0,t[d>>2]|0)|0))break;n=(t[b>>2]|0)+48|0;t[n>>2]=t[n>>2]|1;break}if(!(t[l>>2]|0)){_T(t[a>>2]|0,3035,0,t[d>>2]|0);break}if(!(Xl(t[(t[d>>2]|0)+8>>2]|0,161352)|0)){if(Xl(t[(t[d>>2]|0)+8>>2]|0,164512)|0){if(!(OT(t[a>>2]|0,0,t[d>>2]|0)|0))break;n=(t[b>>2]|0)+48|0;t[n>>2]=t[n>>2]|1048576;break}if(Xl(t[(t[d>>2]|0)+8>>2]|0,164504)|0){t[v>>2]=Hd(t[a>>2]|0,t[d>>2]|0)|0;if(zd(t[v>>2]|0,(t[b>>2]|0)+48|0,-1,512,1024,-1,-1,-1)|0){Ud(t[a>>2]|0,3037,0,t[d>>2]|0,0,164528,t[v>>2]|0,0,0,0);break}else{t[m>>2]=1;break}}n=(Xl(t[(t[d>>2]|0)+8>>2]|0,164480)|0)!=0;r=t[a>>2]|0;i=t[d>>2]|0;if(!n){_T(r,3035,0,i);break}t[v>>2]=Hd(r,i)|0;if(zd(t[v>>2]|0,(t[b>>2]|0)+48|0,-1,262144,524288,-1,-1,-1)|0){Ud(t[a>>2]|0,3037,0,t[d>>2]|0,0,167072,t[v>>2]|0,0,0,0);break}else{t[_>>2]=1;break}}}else if(Xl(t[(t[w+36>>2]|0)+8>>2]|0,t[38526]|0)|0)_T(t[a>>2]|0,3035,0,t[d>>2]|0);while(0);t[d>>2]=t[(t[d>>2]|0)+24>>2]}if(!(t[_>>2]|0)){if(t[(t[o>>2]|0)+24>>2]&128){_=(t[b>>2]|0)+48|0;t[_>>2]=t[_>>2]|524288}if(t[(t[o>>2]|0)+24>>2]&64){_=(t[b>>2]|0)+48|0;t[_>>2]=t[_>>2]|262144}}if(!(t[m>>2]|0)){if(t[(t[o>>2]|0)+24>>2]&8){m=(t[b>>2]|0)+48|0;t[m>>2]=t[m>>2]|1024}if(t[(t[o>>2]|0)+24>>2]&4){m=(t[b>>2]|0)+48|0;t[m>>2]=t[m>>2]|512}}t[h>>2]=t[(t[c>>2]|0)+12>>2];if((((t[h>>2]|0)!=0?(t[(t[h>>2]|0)+36>>2]|0)!=0:0)?(Xl(t[(t[h>>2]|0)+8>>2]|0,160992)|0)!=0:0)?(Xl(t[(t[(t[h>>2]|0)+36>>2]|0)+8>>2]|0,t[38526]|0)|0)!=0:0){m=jd(t[a>>2]|0,t[h>>2]|0,1)|0;t[(t[b>>2]|0)+24>>2]=m;t[h>>2]=t[(t[h>>2]|0)+24>>2]}t[(t[a>>2]|0)+84>>2]=t[b>>2];if((((t[h>>2]|0)!=0?(t[(t[h>>2]|0)+36>>2]|0)!=0:0)?(Xl(t[(t[h>>2]|0)+8>>2]|0,167120)|0)!=0:0)?(Xl(t[(t[(t[h>>2]|0)+36>>2]|0)+8>>2]|0,t[38526]|0)|0)!=0:0){if(t[(t[b>>2]|0)+48>>2]&1){m=(t[b>>2]|0)+48|0;t[m>>2]=t[m>>2]^1}AT(t[a>>2]|0,t[o>>2]|0,t[h>>2]|0,p)|0;t[h>>2]=t[(t[h>>2]|0)+24>>2]}else S=63;do if((S|0)==63){if((((t[h>>2]|0)!=0?(t[(t[h>>2]|0)+36>>2]|0)!=0:0)?(Xl(t[(t[h>>2]|0)+8>>2]|0,167136)|0)!=0:0)?(Xl(t[(t[(t[h>>2]|0)+36>>2]|0)+8>>2]|0,t[38526]|0)|0)!=0:0){t[(t[b>>2]|0)+52>>2]=1;MT(t[a>>2]|0,t[o>>2]|0,t[h>>2]|0,p)|0;t[h>>2]=t[(t[h>>2]|0)+24>>2];break}m=ED(45)|0;t[(t[b>>2]|0)+64>>2]=m;m=(t[b>>2]|0)+48|0;t[m>>2]=t[m>>2]|4;if((((t[h>>2]|0)!=0?(t[(t[h>>2]|0)+36>>2]|0)!=0:0)?(Xl(t[(t[h>>2]|0)+8>>2]|0,161648)|0)!=0:0)?(Xl(t[(t[(t[h>>2]|0)+36>>2]|0)+8>>2]|0,t[38526]|0)|0)!=0:0){m=RT(t[a>>2]|0,t[o>>2]|0,t[h>>2]|0,8,1)|0;t[(t[b>>2]|0)+28>>2]=m;t[h>>2]=t[(t[h>>2]|0)+24>>2]}else S=73;do if((S|0)==73){if((((t[h>>2]|0)!=0?(t[(t[h>>2]|0)+36>>2]|0)!=0:0)?(Xl(t[(t[h>>2]|0)+8>>2]|0,161656)|0)!=0:0)?(Xl(t[(t[(t[h>>2]|0)+36>>2]|0)+8>>2]|0,t[38526]|0)|0)!=0:0){m=RT(t[a>>2]|0,t[o>>2]|0,t[h>>2]|0,7,1)|0;t[(t[b>>2]|0)+28>>2]=m;t[h>>2]=t[(t[h>>2]|0)+24>>2];break}if((((t[h>>2]|0)!=0?(t[(t[h>>2]|0)+36>>2]|0)!=0:0)?(Xl(t[(t[h>>2]|0)+8>>2]|0,161664)|0)!=0:0)?(Xl(t[(t[(t[h>>2]|0)+36>>2]|0)+8>>2]|0,t[38526]|0)|0)!=0:0){m=RT(t[a>>2]|0,t[o>>2]|0,t[h>>2]|0,6,1)|0;t[(t[b>>2]|0)+28>>2]=m;t[h>>2]=t[(t[h>>2]|0)+24>>2];break}if((((t[h>>2]|0)!=0?(t[(t[h>>2]|0)+36>>2]|0)!=0:0)?(Xl(t[(t[h>>2]|0)+8>>2]|0,161080)|0)!=0:0)?(Xl(t[(t[(t[h>>2]|0)+36>>2]|0)+8>>2]|0,t[38526]|0)|0)!=0:0){m=NT(t[a>>2]|0,t[o>>2]|0,t[h>>2]|0)|0;t[(t[b>>2]|0)+28>>2]=m;t[h>>2]=t[(t[h>>2]|0)+24>>2]}}while(0);if((TT(t[a>>2]|0,t[o>>2]|0,h,(t[b>>2]|0)+116|0,12,0)|0)==-1){t[u>>2]=0;E=t[u>>2]|0;s=f;return E|0}if((((t[h>>2]|0)!=0?(t[(t[h>>2]|0)+36>>2]|0)!=0:0)?(Xl(t[(t[h>>2]|0)+8>>2]|0,163328)|0)!=0:0)?(Xl(t[(t[(t[h>>2]|0)+36>>2]|0)+8>>2]|0,t[38526]|0)|0)!=0:0){m=LT(t[a>>2]|0,t[o>>2]|0,t[h>>2]|0)|0;t[(t[b>>2]|0)+84>>2]=m;t[h>>2]=t[(t[h>>2]|0)+24>>2]}}while(0);if(t[h>>2]|0)$d(t[a>>2]|0,3033,0,t[c>>2]|0,t[h>>2]|0,0,167152);if((t[l>>2]|0)!=0?!((t[p>>2]|0)!=0?1:(t[(t[a>>2]|0)+100>>2]|0)==0):0)sv(t[a>>2]|0,3081,0,t[c>>2]|0,167288,0);t[(t[a>>2]|0)+84>>2]=t[k>>2];t[u>>2]=t[b>>2];E=t[u>>2]|0;s=f;return E|0}function Wd(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0;f=s;s=s+48|0;u=f+44|0;a=f+40|0;o=f+36|0;c=f+32|0;l=f+28|0;b=f+24|0;k=f+20|0;h=f+16|0;w=f+12|0;d=f+8|0;v=f+4|0;m=f;t[a>>2]=e;t[o>>2]=i;t[c>>2]=r;t[l>>2]=n;t[h>>2]=0;t[w>>2]=0;t[v>>2]=0;if((t[a>>2]|0)==0|(t[o>>2]|0)==0|(t[c>>2]|0)==0){t[u>>2]=0;_=t[u>>2]|0;s=f;return _|0}if(t[l>>2]|0){t[d>>2]=Bd(t[c>>2]|0,161352)|0;n=t[a>>2]|0;if(!(t[d>>2]|0)){FT(n,3036,0,t[c>>2]|0,161352,0);t[u>>2]=0;_=t[u>>2]|0;s=f;return _|0}r=t[d>>2]|0;if(Id(n,0,r,ED(22)|0,w)|0){t[u>>2]=0;_=t[u>>2]|0;s=f;return _|0}if(t[(t[a>>2]|0)+96>>2]|0){if(t[(t[a>>2]|0)+100>>2]|0){sv(t[a>>2]|0,3081,0,t[c>>2]|0,165552,0);t[u>>2]=0;_=t[u>>2]|0;s=f;return _|0}t[m>>2]=RD(t[w>>2]|0,t[38526]|0)|0;if(t[m>>2]|0){t[u>>2]=t[m>>2];_=t[u>>2]|0;s=f;return _|0}}}m=t[a>>2]|0;r=t[o>>2]|0;e:do if(t[l>>2]|0){t[b>>2]=Av(m,r,4,t[w>>2]|0,t[(t[a>>2]|0)+112>>2]|0,t[c>>2]|0,1)|0;if(!(t[b>>2]|0)){t[u>>2]=0;_=t[u>>2]|0;s=f;return _|0}t[t[b>>2]>>2]=4;t[(t[b>>2]|0)+52>>2]=4;n=(t[b>>2]|0)+48|0;t[n>>2]=t[n>>2]|8;t[d>>2]=t[(t[c>>2]|0)+44>>2];while(1){if(!(t[d>>2]|0))break;n=t[d>>2]|0;if(!(t[(t[d>>2]|0)+36>>2]|0)){if(((Xl(t[n+8>>2]|0,161384)|0)==0?(Xl(t[(t[d>>2]|0)+8>>2]|0,161352)|0)==0:0)?(Xl(t[(t[d>>2]|0)+8>>2]|0,164504)|0)==0:0)_T(t[a>>2]|0,3035,0,t[d>>2]|0)}else if(Xl(t[(t[n+36>>2]|0)+8>>2]|0,t[38526]|0)|0)_T(t[a>>2]|0,3035,0,t[d>>2]|0);t[d>>2]=t[(t[d>>2]|0)+24>>2]}t[d>>2]=Bd(t[c>>2]|0,164504)|0;if(t[d>>2]|0){t[w>>2]=Sw(t[a>>2]|0,t[c>>2]|0,164504)|0;if(!(zd(t[w>>2]|0,(t[b>>2]|0)+48|0,-1,-1,1024,-1,2048,4096)|0))break;Ud(t[a>>2]|0,3037,t[b>>2]|0,t[d>>2]|0,0,165608,t[w>>2]|0,0,0,0);break}if(t[(t[o>>2]|0)+24>>2]&8){n=(t[b>>2]|0)+48|0;t[n>>2]=t[n>>2]|1024}if(t[(t[o>>2]|0)+24>>2]&16){n=(t[b>>2]|0)+48|0;t[n>>2]=t[n>>2]|2048}if(t[(t[o>>2]|0)+24>>2]&32){n=(t[b>>2]|0)+48|0;t[n>>2]=t[n>>2]|4096}}else{t[b>>2]=Av(m,r,4,0,t[(t[a>>2]|0)+112>>2]|0,t[c>>2]|0,0)|0;if(!(t[b>>2]|0)){t[u>>2]=0;_=t[u>>2]|0;s=f;return _|0}t[t[b>>2]>>2]=4;t[(t[b>>2]|0)+52>>2]=4;t[d>>2]=t[(t[c>>2]|0)+44>>2];while(1){if(!(t[d>>2]|0))break e;n=t[d>>2]|0;if(!(t[(t[d>>2]|0)+36>>2]|0)){if(!(Xl(t[n+8>>2]|0,161384)|0))_T(t[a>>2]|0,3035,0,t[d>>2]|0)}else if(Xl(t[(t[n+36>>2]|0)+8>>2]|0,t[38526]|0)|0)_T(t[a>>2]|0,3035,0,t[d>>2]|0);t[d>>2]=t[(t[d>>2]|0)+24>>2]}}while(0);t[(t[b>>2]|0)+112>>2]=t[(t[a>>2]|0)+112>>2];Pd(t[a>>2]|0,t[c>>2]|0,161384)|0;t[k>>2]=t[(t[a>>2]|0)+84>>2];t[(t[a>>2]|0)+84>>2]=t[b>>2];t[h>>2]=t[(t[c>>2]|0)+12>>2];if((((t[h>>2]|0)!=0?(t[(t[h>>2]|0)+36>>2]|0)!=0:0)?(Xl(t[(t[h>>2]|0)+8>>2]|0,160992)|0)!=0:0)?(Xl(t[(t[(t[h>>2]|0)+36>>2]|0)+8>>2]|0,t[38526]|0)|0)!=0:0){d=jd(t[a>>2]|0,t[h>>2]|0,1)|0;t[(t[b>>2]|0)+24>>2]=d;t[h>>2]=t[(t[h>>2]|0)+24>>2]}do if(t[h>>2]|0){if((((t[h>>2]|0)!=0?(t[(t[h>>2]|0)+36>>2]|0)!=0:0)?(Xl(t[(t[h>>2]|0)+8>>2]|0,165456)|0)!=0:0)?(Xl(t[(t[(t[h>>2]|0)+36>>2]|0)+8>>2]|0,t[38526]|0)|0)!=0:0){DT(t[a>>2]|0,t[o>>2]|0,t[h>>2]|0,4)|0;t[v>>2]=1;t[h>>2]=t[(t[h>>2]|0)+24>>2];break}if((((t[h>>2]|0)!=0?(t[(t[h>>2]|0)+36>>2]|0)!=0:0)?(Xl(t[(t[h>>2]|0)+8>>2]|0,165488)|0)!=0:0)?(Xl(t[(t[(t[h>>2]|0)+36>>2]|0)+8>>2]|0,t[38526]|0)|0)!=0:0){CT(t[a>>2]|0,t[o>>2]|0,t[h>>2]|0)|0;t[h>>2]=t[(t[h>>2]|0)+24>>2];break}if((((t[h>>2]|0)!=0?(t[(t[h>>2]|0)+36>>2]|0)!=0:0)?(Xl(t[(t[h>>2]|0)+8>>2]|0,165496)|0)!=0:0)?(Xl(t[(t[(t[h>>2]|0)+36>>2]|0)+8>>2]|0,t[38526]|0)|0)!=0:0){PT(t[a>>2]|0,t[o>>2]|0,t[h>>2]|0)|0;t[h>>2]=t[(t[h>>2]|0)+24>>2]}}else $d(t[a>>2]|0,3034,0,t[c>>2]|0,t[h>>2]|0,0,165656);while(0);if(t[h>>2]|0)$d(t[a>>2]|0,3033,0,t[c>>2]|0,t[h>>2]|0,0,165656);if((t[l>>2]|0)!=0?!((t[v>>2]|0)!=0?1:(t[(t[a>>2]|0)+100>>2]|0)==0):0)sv(t[a>>2]|0,3081,0,t[c>>2]|0,165704,0);t[(t[a>>2]|0)+84>>2]=t[k>>2];t[u>>2]=t[b>>2];_=t[u>>2]|0;s=f;return _|0}function Kd(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;var u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0,S=0,g=0,y=0,F=0,O=0,A=0,M=0,R=0,N=0,T=0,L=0,D=0,C=0,P=0,B=0;u=s;s=s+112|0;a=u+96|0;o=u+92|0;c=u+88|0;l=u+84|0;b=u+80|0;k=u+76|0;h=u+72|0;w=u+68|0;d=u+64|0;v=u+60|0;m=u+56|0;_=u+52|0;p=u+48|0;E=u+44|0;S=u+40|0;g=u+36|0;y=u+32|0;F=u+28|0;O=u+24|0;A=u+20|0;M=u+16|0;R=u+12|0;N=u+8|0;T=u+4|0;L=u;t[o>>2]=e;t[c>>2]=i;t[l>>2]=r;t[b>>2]=n;t[k>>2]=f;t[h>>2]=0;t[w>>2]=0;t[d>>2]=0;t[v>>2]=0;t[S>>2]=0;t[g>>2]=0;if((t[o>>2]|0)==0|(t[c>>2]|0)==0|(t[l>>2]|0)==0){t[a>>2]=0;D=t[a>>2]|0;s=u;return D|0}if(t[b>>2]|0)t[t[b>>2]>>2]=0;t[_>>2]=Bd(t[l>>2]|0,161352)|0;t[m>>2]=Bd(t[l>>2]|0,160064)|0;if((t[k>>2]|0)!=0|(t[m>>2]|0)==0){if(!(t[_>>2]|0)){FT(t[o>>2]|0,3036,0,t[l>>2]|0,161352,0);t[a>>2]=0;D=t[a>>2]|0;s=u;return D|0}}else t[S>>2]=1;Pd(t[o>>2]|0,t[l>>2]|0,161384)|0;t[v>>2]=t[(t[l>>2]|0)+12>>2];if((((t[v>>2]|0)!=0?(t[(t[v>>2]|0)+36>>2]|0)!=0:0)?(Xl(t[(t[v>>2]|0)+8>>2]|0,160992)|0)!=0:0)?(Xl(t[(t[(t[v>>2]|0)+36>>2]|0)+8>>2]|0,t[38526]|0)|0)!=0:0){t[d>>2]=jd(t[o>>2]|0,t[v>>2]|0,1)|0;t[v>>2]=t[(t[v>>2]|0)+24>>2]}if(!(t[k>>2]|0)){t[p>>2]=BT(t[o>>2]|0,t[l>>2]|0,0,-1,1,161744)|0;t[E>>2]=IT(t[o>>2]|0,t[l>>2]|0,0,1073741824,1,161768)|0;HT(t[o>>2]|0,0,t[l>>2]|0,t[p>>2]|0,t[E>>2]|0)|0;t[w>>2]=Mv(t[o>>2]|0,t[l>>2]|0,t[p>>2]|0,t[E>>2]|0)|0;if(t[w>>2]|0)if(t[S>>2]|0){t[y>>2]=0;t[F>>2]=0;t[O>>2]=0;if(t[b>>2]|0)t[t[b>>2]>>2]=1;xT(t[o>>2]|0,t[c>>2]|0,0,t[m>>2]|0,y,F)|0;UT(t[o>>2]|0,t[c>>2]|0,t[l>>2]|0,t[m>>2]|0,t[y>>2]|0)|0;if(t[_>>2]|0)zT(t[o>>2]|0,3039,0,t[_>>2]|0,160064,161352);t[m>>2]=t[(t[l>>2]|0)+44>>2];while(1){if(!(t[m>>2]|0))break;b=t[m>>2]|0;if(t[(t[m>>2]|0)+36>>2]|0){if(Xl(t[(t[b+36>>2]|0)+8>>2]|0,t[38526]|0)|0)_T(t[o>>2]|0,3035,0,t[m>>2]|0);t[m>>2]=t[(t[m>>2]|0)+24>>2];continue}if(((((Xl(t[b+8>>2]|0,160064)|0)==0?(Xl(t[(t[m>>2]|0)+8>>2]|0,161352)|0)==0:0)?(Xl(t[(t[m>>2]|0)+8>>2]|0,161384)|0)==0:0)?(Xl(t[(t[m>>2]|0)+8>>2]|0,161808)|0)==0:0)?(Xl(t[(t[m>>2]|0)+8>>2]|0,161824)|0)==0:0){C=30;break}t[m>>2]=t[(t[m>>2]|0)+24>>2]}if((C|0)==30)jT(t[o>>2]|0,3040,0,0,t[m>>2]|0,164392);if(t[v>>2]|0)$d(t[o>>2]|0,3033,0,t[l>>2]|0,t[v>>2]|0,0,161392);if(!((t[p>>2]|0)==0&(t[E>>2]|0)==0)?(t[O>>2]=VT(t[o>>2]|0,14,t[F>>2]|0,t[y>>2]|0)|0,(t[O>>2]|0)!=0):0){t[(t[w>>2]|0)+12>>2]=t[O>>2];t[(t[w>>2]|0)+4>>2]=t[d>>2];qT((t[(t[o>>2]|0)+28>>2]|0)+20|0,10,t[w>>2]|0)|0;t[a>>2]=t[w>>2];D=t[a>>2]|0;s=u;return D|0}}else C=39}else C=39;if((C|0)==39?(t[A>>2]=0,t[T>>2]=0,t[L>>2]=0,O=t[o>>2]|0,y=t[_>>2]|0,(Id(O,0,y,ED(22)|0,R)|0)==0):0){do if(!(t[k>>2]|0)){t[m>>2]=Bd(t[l>>2]|0,163528)|0;if(!(t[m>>2]|0)){if(!(t[(t[c>>2]|0)+24>>2]&1))break;t[A>>2]=t[(t[o>>2]|0)+112>>2];break}t[N>>2]=Hd(t[o>>2]|0,t[m>>2]|0)|0;if(Xl(t[N>>2]|0,163536)|0){t[A>>2]=t[(t[o>>2]|0)+112>>2];break}if(!(Xl(t[N>>2]|0,163552)|0))Ud(t[o>>2]|0,3037,0,t[m>>2]|0,0,163568,t[N>>2]|0,0,0,0)}else t[A>>2]=t[(t[o>>2]|0)+112>>2];while(0);t[h>>2]=YT(t[o>>2]|0,t[R>>2]|0,t[A>>2]|0,t[l>>2]|0,t[k>>2]|0)|0;if(t[h>>2]|0){t[m>>2]=t[(t[l>>2]|0)+44>>2];while(1){if(!(t[m>>2]|0))break;A=t[m>>2]|0;do if(!(t[(t[m>>2]|0)+36>>2]|0)){if(((((((Xl(t[A+8>>2]|0,161352)|0)==0?(Xl(t[(t[m>>2]|0)+8>>2]|0,155448)|0)==0:0)?(Xl(t[(t[m>>2]|0)+8>>2]|0,161384)|0)==0:0)?(Xl(t[(t[m>>2]|0)+8>>2]|0,159128)|0)==0:0)?(Xl(t[(t[m>>2]|0)+8>>2]|0,159120)|0)==0:0)?(Xl(t[(t[m>>2]|0)+8>>2]|0,164480)|0)==0:0)?(Xl(t[(t[m>>2]|0)+8>>2]|0,164488)|0)==0:0){R=t[(t[m>>2]|0)+8>>2]|0;if(!(t[k>>2]|0)){if(Xl(R,161808)|0)break;if(Xl(t[(t[m>>2]|0)+8>>2]|0,161824)|0)break;if(Xl(t[(t[m>>2]|0)+8>>2]|0,163528)|0)break;_T(t[o>>2]|0,3035,0,t[m>>2]|0);break}else{if(Xl(R,164504)|0)break;if(Xl(t[(t[m>>2]|0)+8>>2]|0,164512)|0)break;if(Xl(t[(t[m>>2]|0)+8>>2]|0,160544)|0)break;_T(t[o>>2]|0,3035,0,t[m>>2]|0);break}}}else if(Xl(t[(t[A+36>>2]|0)+8>>2]|0,t[38526]|0)|0)_T(t[o>>2]|0,3035,0,t[m>>2]|0);while(0);t[m>>2]=t[(t[m>>2]|0)+24>>2]}do if(t[k>>2]|0){A=(t[h>>2]|0)+48|0;t[A>>2]=t[A>>2]|2;A=(t[h>>2]|0)+48|0;t[A>>2]=t[A>>2]|32;GT(t[o>>2]|0,t[c>>2]|0,0,t[l>>2]|0,160544,(t[h>>2]|0)+68|0,(t[h>>2]|0)+64|0)|0;if(WT(t[o>>2]|0,t[l>>2]|0,164512,0)|0){A=(t[h>>2]|0)+48|0;t[A>>2]=t[A>>2]|16}t[m>>2]=Bd(t[l>>2]|0,164504)|0;if(t[m>>2]|0){t[N>>2]=Hd(t[o>>2]|0,t[m>>2]|0)|0;if(!(zd(t[N>>2]|0,(t[h>>2]|0)+48|0,-1,32768,65536,-1,-1,-1)|0))break;Ud(t[o>>2]|0,3037,0,t[m>>2]|0,0,164528,t[N>>2]|0,0,0,0);break}if(t[(t[c>>2]|0)+24>>2]&4){A=(t[h>>2]|0)+48|0;t[A>>2]=t[A>>2]|32768}if(t[(t[c>>2]|0)+24>>2]&8){A=(t[h>>2]|0)+48|0;t[A>>2]=t[A>>2]|65536}}while(0);t[m>>2]=Bd(t[l>>2]|0,164480)|0;if(!(t[m>>2]|0)){if(t[(t[c>>2]|0)+24>>2]&128){A=(t[h>>2]|0)+48|0;t[A>>2]=t[A>>2]|4096}if(t[(t[c>>2]|0)+24>>2]&64){A=(t[h>>2]|0)+48|0;t[A>>2]=t[A>>2]|2048}if(t[(t[c>>2]|0)+24>>2]&256){A=(t[h>>2]|0)+48|0;t[A>>2]=t[A>>2]|8192}}else{t[N>>2]=Hd(t[o>>2]|0,t[m>>2]|0)|0;if(zd(t[N>>2]|0,(t[h>>2]|0)+48|0,-1,2048,4096,8192,-1,-1)|0)Ud(t[o>>2]|0,3037,0,t[m>>2]|0,0,164576,t[N>>2]|0,0,0,0)}if(WT(t[o>>2]|0,t[l>>2]|0,164488,0)|0){N=(t[h>>2]|0)+48|0;t[N>>2]=t[N>>2]|1}t[m>>2]=Bd(t[l>>2]|0,155448)|0;if(t[m>>2]|0){xT(t[o>>2]|0,t[c>>2]|0,0,t[m>>2]|0,(t[h>>2]|0)+60|0,(t[h>>2]|0)+56|0)|0;UT(t[o>>2]|0,t[c>>2]|0,t[l>>2]|0,t[m>>2]|0,t[(t[h>>2]|0)+60>>2]|0)|0}N=Sw(t[o>>2]|0,t[l>>2]|0,159128)|0;t[(t[h>>2]|0)+76>>2]=N;t[m>>2]=Bd(t[l>>2]|0,159120)|0;do if(t[m>>2]|0){t[M>>2]=Hd(t[o>>2]|0,t[m>>2]|0)|0;if(t[(t[h>>2]|0)+76>>2]|0){zT(t[o>>2]|0,3038,0,t[m>>2]|0,159128,159120);break}else{N=(t[h>>2]|0)+48|0;t[N>>2]=t[N>>2]|8;t[(t[h>>2]|0)+76>>2]=t[M>>2];break}}while(0);if((((t[v>>2]|0)!=0?(t[(t[v>>2]|0)+36>>2]|0)!=0:0)?(Xl(t[(t[v>>2]|0)+8>>2]|0,161008)|0)!=0:0)?(Xl(t[(t[(t[v>>2]|0)+36>>2]|0)+8>>2]|0,t[38526]|0)|0)!=0:0){M=t[o>>2]|0;if(t[(t[h>>2]|0)+56>>2]|0)$d(M,3041,0,t[l>>2]|0,t[v>>2]|0,164640,0);else{m=Gd(M,t[c>>2]|0,t[v>>2]|0,0)|0;t[(t[h>>2]|0)+28>>2]=m}t[v>>2]=t[(t[v>>2]|0)+24>>2]}else C=107;if(((((C|0)==107?(t[v>>2]|0)!=0:0)?(t[(t[v>>2]|0)+36>>2]|0)!=0:0)?(Xl(t[(t[v>>2]|0)+8>>2]|0,161024)|0)!=0:0)?(Xl(t[(t[(t[v>>2]|0)+36>>2]|0)+8>>2]|0,t[38526]|0)|0)!=0:0){m=t[o>>2]|0;if(t[(t[h>>2]|0)+56>>2]|0)$d(m,3041,0,t[l>>2]|0,t[v>>2]|0,164128,0);else{M=Wd(m,t[c>>2]|0,t[v>>2]|0,0)|0;t[(t[h>>2]|0)+28>>2]=M}t[v>>2]=t[(t[v>>2]|0)+24>>2]}while(1){if((((t[v>>2]|0)!=0?(t[(t[v>>2]|0)+36>>2]|0)!=0:0)?(Xl(t[(t[v>>2]|0)+8>>2]|0,164712)|0)!=0:0)?(Xl(t[(t[(t[v>>2]|0)+36>>2]|0)+8>>2]|0,t[38526]|0)|0)!=0:0)P=1;else C=119;e:do if((C|0)==119){C=0;do if(t[v>>2]|0){if(!(t[(t[v>>2]|0)+36>>2]|0))break;if(!(Xl(t[(t[v>>2]|0)+8>>2]|0,164720)|0))break;if(Xl(t[(t[(t[v>>2]|0)+36>>2]|0)+8>>2]|0,t[38526]|0)|0){P=1;break e}}while(0);if(t[v>>2]|0){if(!(t[(t[v>>2]|0)+36>>2]|0)){P=0;break}if(!(Xl(t[(t[v>>2]|0)+8>>2]|0,164728)|0)){P=0;break}P=(Xl(t[(t[(t[v>>2]|0)+36>>2]|0)+8>>2]|0,t[38526]|0)|0)!=0}else P=0}while(0);B=(t[v>>2]|0)!=0;if(!P)break;do if(B){if(!(t[(t[v>>2]|0)+36>>2]|0)){C=133;break}if(!(Xl(t[(t[v>>2]|0)+8>>2]|0,164712)|0)){C=133;break}if(!(Xl(t[(t[(t[v>>2]|0)+36>>2]|0)+8>>2]|0,t[38526]|0)|0)){C=133;break}t[T>>2]=KT(t[o>>2]|0,t[c>>2]|0,t[v>>2]|0,22,t[(t[h>>2]|0)+52>>2]|0)|0}else C=133;while(0);e:do if((C|0)==133){C=0;do if(t[v>>2]|0){if(!(t[(t[v>>2]|0)+36>>2]|0))break;if(!(Xl(t[(t[v>>2]|0)+8>>2]|0,164720)|0))break;if(!(Xl(t[(t[(t[v>>2]|0)+36>>2]|0)+8>>2]|0,t[38526]|0)|0))break;t[T>>2]=KT(t[o>>2]|0,t[c>>2]|0,t[v>>2]|0,23,t[(t[h>>2]|0)+52>>2]|0)|0;break e}while(0);if(!(t[v>>2]|0))break;if(!(t[(t[v>>2]|0)+36>>2]|0))break;if(!(Xl(t[(t[v>>2]|0)+8>>2]|0,164728)|0))break;if(!(Xl(t[(t[(t[v>>2]|0)+36>>2]|0)+8>>2]|0,t[38526]|0)|0))break;t[T>>2]=KT(t[o>>2]|0,t[c>>2]|0,t[v>>2]|0,24,t[(t[h>>2]|0)+52>>2]|0)|0}while(0);M=t[T>>2]|0;if(t[L>>2]|0)t[(t[L>>2]|0)+8>>2]=M;else t[(t[h>>2]|0)+100>>2]=M;t[L>>2]=t[T>>2];t[v>>2]=t[(t[v>>2]|0)+24>>2]}if(B)$d(t[o>>2]|0,3033,0,t[l>>2]|0,t[v>>2]|0,0,164736);t[(t[h>>2]|0)+24>>2]=t[d>>2];if(t[g>>2]|0){pAi[t[135736>>2]&511](t[g>>2]|0);t[g>>2]=0}v=t[h>>2]|0;if(t[k>>2]|0){t[a>>2]=v;D=t[a>>2]|0;s=u;return D|0}else{t[(t[w>>2]|0)+12>>2]=v;t[a>>2]=t[w>>2];D=t[a>>2]|0;s=u;return D|0}}}if(t[g>>2]|0){pAi[t[135736>>2]&511](t[g>>2]|0);t[g>>2]=0}if(t[d>>2]|0){if(t[w>>2]|0)t[(t[w>>2]|0)+4>>2]=0;if(t[h>>2]|0)t[(t[h>>2]|0)+24>>2]=0;Yk(t[d>>2]|0)}t[a>>2]=0;D=t[a>>2]|0;s=u;return D|0}function Xd(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0;n=s;s=s+32|0;f=n+28|0;u=n+24|0;a=n+20|0;o=n+16|0;c=n+12|0;l=n+8|0;b=n+4|0;k=n;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;t[b>>2]=0;if((t[u>>2]|0)==0|(t[a>>2]|0)==0|(t[o>>2]|0)==0){t[f>>2]=0;h=t[f>>2]|0;s=n;return h|0}t[k>>2]=Bd(t[o>>2]|0,161352)|0;r=t[u>>2]|0;if(!(t[k>>2]|0)){FT(r,3036,0,t[o>>2]|0,161352,0);t[f>>2]=0;h=t[f>>2]|0;s=n;return h|0}i=t[k>>2]|0;if(Id(r,0,i,ED(22)|0,c)|0){t[f>>2]=0;h=t[f>>2]|0;s=n;return h|0}i=(Xl(t[c>>2]|0,163840)|0)!=0;r=t[u>>2]|0;if(i){i=t[k>>2]|0;Ud(r,3056,0,i,ED(22)|0,0,0,163848,0,0);t[f>>2]=0;h=t[f>>2]|0;s=n;return h|0}if(Xl(t[r+112>>2]|0,t[38860]|0)|0)th(t[u>>2]|0,3057,t[o>>2]|0,0,163792,t[38860]|0,0);t[l>>2]=XT(t[u>>2]|0,t[a>>2]|0,t[c>>2]|0,t[(t[u>>2]|0)+112>>2]|0,t[o>>2]|0,1)|0;if(!(t[l>>2]|0)){t[f>>2]=0;h=t[f>>2]|0;s=n;return h|0}c=(t[l>>2]|0)+60|0;t[c>>2]=t[c>>2]|1;t[k>>2]=t[(t[o>>2]|0)+44>>2];while(1){if(!(t[k>>2]|0))break;c=t[k>>2]|0;if(!(t[(t[k>>2]|0)+36>>2]|0)){if(((((Xl(t[c+8>>2]|0,161384)|0)==0?(Xl(t[(t[k>>2]|0)+8>>2]|0,159128)|0)==0:0)?(Xl(t[(t[k>>2]|0)+8>>2]|0,159120)|0)==0:0)?(Xl(t[(t[k>>2]|0)+8>>2]|0,161352)|0)==0:0)?(Xl(t[(t[k>>2]|0)+8>>2]|0,155448)|0)==0:0)_T(t[u>>2]|0,3035,0,t[k>>2]|0)}else if(Xl(t[(t[c+36>>2]|0)+8>>2]|0,t[38526]|0)|0)_T(t[u>>2]|0,3035,0,t[k>>2]|0);t[k>>2]=t[(t[k>>2]|0)+24>>2]}GT(t[u>>2]|0,t[a>>2]|0,0,t[o>>2]|0,155448,(t[l>>2]|0)+28|0,(t[l>>2]|0)+24|0)|0;Pd(t[u>>2]|0,t[o>>2]|0,161384)|0;c=Sw(t[u>>2]|0,t[o>>2]|0,159120)|0;t[(t[l>>2]|0)+44>>2]=c;if(t[(t[l>>2]|0)+44>>2]|0){c=(t[l>>2]|0)+60|0;t[c>>2]=t[c>>2]|512}t[k>>2]=Bd(t[o>>2]|0,159128)|0;do if(t[k>>2]|0){c=t[u>>2]|0;if(t[(t[l>>2]|0)+60>>2]&512){zT(c,3051,t[l>>2]|0,t[k>>2]|0,159128,159120);break}else{r=Hd(c,t[k>>2]|0)|0;t[(t[l>>2]|0)+44>>2]=r;break}}while(0);t[b>>2]=t[(t[o>>2]|0)+12>>2];if((((t[b>>2]|0)!=0?(t[(t[b>>2]|0)+36>>2]|0)!=0:0)?(Xl(t[(t[b>>2]|0)+8>>2]|0,160992)|0)!=0:0)?(Xl(t[(t[(t[b>>2]|0)+36>>2]|0)+8>>2]|0,t[38526]|0)|0)!=0:0){k=jd(t[u>>2]|0,t[b>>2]|0,1)|0;t[(t[l>>2]|0)+32>>2]=k;t[b>>2]=t[(t[b>>2]|0)+24>>2]}if((((t[b>>2]|0)!=0?(t[(t[b>>2]|0)+36>>2]|0)!=0:0)?(Xl(t[(t[b>>2]|0)+8>>2]|0,161024)|0)!=0:0)?(Xl(t[(t[(t[b>>2]|0)+36>>2]|0)+8>>2]|0,t[38526]|0)|0)!=0:0){k=t[u>>2]|0;if(t[(t[l>>2]|0)+24>>2]|0)$d(k,3055,0,t[o>>2]|0,t[b>>2]|0,164128,0);else{r=Wd(k,t[a>>2]|0,t[b>>2]|0,0)|0;t[(t[l>>2]|0)+48>>2]=r}t[b>>2]=t[(t[b>>2]|0)+24>>2]}if(t[b>>2]|0)$d(t[u>>2]|0,3033,0,t[o>>2]|0,t[b>>2]|0,0,164200);t[f>>2]=t[l>>2];h=t[f>>2]|0;s=n;return h|0}function Zd(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0;n=s;s=s+48|0;f=n+32|0;u=n+28|0;a=n+24|0;o=n+20|0;c=n+16|0;l=n+12|0;b=n+8|0;k=n+4|0;h=n;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;t[b>>2]=0;t[h>>2]=0;if((t[u>>2]|0)==0|(t[a>>2]|0)==0|(t[o>>2]|0)==0){t[f>>2]=0;w=t[f>>2]|0;s=n;return w|0}t[k>>2]=Bd(t[o>>2]|0,161352)|0;r=t[u>>2]|0;if(!(t[k>>2]|0)){FT(r,3036,0,t[o>>2]|0,161352,0);t[f>>2]=0;w=t[f>>2]|0;s=n;return w|0}i=t[k>>2]|0;if(Id(r,0,i,ED(22)|0,c)|0){t[f>>2]=0;w=t[f>>2]|0;s=n;return w|0}t[l>>2]=ZT(t[u>>2]|0,t[a>>2]|0,t[c>>2]|0,t[(t[u>>2]|0)+112>>2]|0,t[o>>2]|0)|0;if(!(t[l>>2]|0)){t[f>>2]=0;w=t[f>>2]|0;s=n;return w|0}t[k>>2]=t[(t[o>>2]|0)+44>>2];while(1){if(!(t[k>>2]|0))break;c=t[k>>2]|0;if(!(t[(t[k>>2]|0)+36>>2]|0)){if((Xl(t[c+8>>2]|0,161352)|0)==0?(Xl(t[(t[k>>2]|0)+8>>2]|0,161384)|0)==0:0)_T(t[u>>2]|0,3035,0,t[k>>2]|0)}else if(Xl(t[(t[c+36>>2]|0)+8>>2]|0,t[38526]|0)|0)_T(t[u>>2]|0,3035,0,t[k>>2]|0);t[k>>2]=t[(t[k>>2]|0)+24>>2]}Pd(t[u>>2]|0,t[o>>2]|0,161384)|0;t[b>>2]=t[(t[o>>2]|0)+12>>2];if((((t[b>>2]|0)!=0?(t[(t[b>>2]|0)+36>>2]|0)!=0:0)?(Xl(t[(t[b>>2]|0)+8>>2]|0,160992)|0)!=0:0)?(Xl(t[(t[(t[b>>2]|0)+36>>2]|0)+8>>2]|0,t[38526]|0)|0)!=0:0){k=jd(t[u>>2]|0,t[b>>2]|0,1)|0;t[(t[l>>2]|0)+24>>2]=k;t[b>>2]=t[(t[b>>2]|0)+24>>2]}if((TT(t[u>>2]|0,t[a>>2]|0,b,(t[l>>2]|0)+56|0,16,h)|0)==-1){t[f>>2]=0;w=t[f>>2]|0;s=n;return w|0}if(t[h>>2]|0){h=(t[l>>2]|0)+36|0;t[h>>2]=t[h>>2]|16}if((((t[b>>2]|0)!=0?(t[(t[b>>2]|0)+36>>2]|0)!=0:0)?(Xl(t[(t[b>>2]|0)+8>>2]|0,163328)|0)!=0:0)?(Xl(t[(t[(t[b>>2]|0)+36>>2]|0)+8>>2]|0,t[38526]|0)|0)!=0:0){h=LT(t[u>>2]|0,t[a>>2]|0,t[b>>2]|0)|0;t[(t[l>>2]|0)+40>>2]=h;t[b>>2]=t[(t[b>>2]|0)+24>>2];
	}if(t[b>>2]|0)$d(t[u>>2]|0,3033,0,t[o>>2]|0,t[b>>2]|0,0,163344);t[f>>2]=t[l>>2];w=t[f>>2]|0;s=n;return w|0}function Jd(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0;n=s;s=s+32|0;f=n+28|0;u=n+24|0;a=n+20|0;o=n+16|0;c=n+12|0;l=n+8|0;b=n+4|0;k=n;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;t[l>>2]=0;if((t[u>>2]|0)==0|(t[a>>2]|0)==0|(t[o>>2]|0)==0){t[f>>2]=0;h=t[f>>2]|0;s=n;return h|0}t[b>>2]=Bd(t[o>>2]|0,161352)|0;r=t[u>>2]|0;if(!(t[b>>2]|0)){FT(r,3036,0,t[o>>2]|0,161352,0);t[f>>2]=0;h=t[f>>2]|0;s=n;return h|0}i=t[b>>2]|0;if(Id(r,0,i,ED(22)|0,k)|0){t[f>>2]=0;h=t[f>>2]|0;s=n;return h|0}t[c>>2]=JT(t[u>>2]|0,t[a>>2]|0,t[k>>2]|0,t[(t[u>>2]|0)+112>>2]|0,t[o>>2]|0)|0;if(!(t[c>>2]|0)){t[f>>2]=0;h=t[f>>2]|0;s=n;return h|0}t[b>>2]=t[(t[o>>2]|0)+44>>2];while(1){if(!(t[b>>2]|0))break;k=t[b>>2]|0;if(!(t[(t[b>>2]|0)+36>>2]|0)){if((Xl(t[k+8>>2]|0,161352)|0)==0?(Xl(t[(t[b>>2]|0)+8>>2]|0,161384)|0)==0:0)_T(t[u>>2]|0,3035,0,t[b>>2]|0)}else if(Xl(t[(t[k+36>>2]|0)+8>>2]|0,t[38526]|0)|0)_T(t[u>>2]|0,3035,0,t[b>>2]|0);t[b>>2]=t[(t[b>>2]|0)+24>>2]}Pd(t[u>>2]|0,t[o>>2]|0,161384)|0;t[l>>2]=t[(t[o>>2]|0)+12>>2];if((((t[l>>2]|0)!=0?(t[(t[l>>2]|0)+36>>2]|0)!=0:0)?(Xl(t[(t[l>>2]|0)+8>>2]|0,160992)|0)!=0:0)?(Xl(t[(t[(t[l>>2]|0)+36>>2]|0)+8>>2]|0,t[38526]|0)|0)!=0:0){b=jd(t[u>>2]|0,t[l>>2]|0,1)|0;t[(t[c>>2]|0)+4>>2]=b;t[l>>2]=t[(t[l>>2]|0)+24>>2]}if((((t[l>>2]|0)!=0?(t[(t[l>>2]|0)+36>>2]|0)!=0:0)?(Xl(t[(t[l>>2]|0)+8>>2]|0,161648)|0)!=0:0)?(Xl(t[(t[(t[l>>2]|0)+36>>2]|0)+8>>2]|0,t[38526]|0)|0)!=0:0){b=RT(t[u>>2]|0,t[a>>2]|0,t[l>>2]|0,8,0)|0;t[(t[c>>2]|0)+12>>2]=b;t[l>>2]=t[(t[l>>2]|0)+24>>2]}else w=28;do if((w|0)==28){if((((t[l>>2]|0)!=0?(t[(t[l>>2]|0)+36>>2]|0)!=0:0)?(Xl(t[(t[l>>2]|0)+8>>2]|0,161656)|0)!=0:0)?(Xl(t[(t[(t[l>>2]|0)+36>>2]|0)+8>>2]|0,t[38526]|0)|0)!=0:0){b=RT(t[u>>2]|0,t[a>>2]|0,t[l>>2]|0,7,0)|0;t[(t[c>>2]|0)+12>>2]=b;t[l>>2]=t[(t[l>>2]|0)+24>>2];break}if((((t[l>>2]|0)!=0?(t[(t[l>>2]|0)+36>>2]|0)!=0:0)?(Xl(t[(t[l>>2]|0)+8>>2]|0,161664)|0)!=0:0)?(Xl(t[(t[(t[l>>2]|0)+36>>2]|0)+8>>2]|0,t[38526]|0)|0)!=0:0){b=RT(t[u>>2]|0,t[a>>2]|0,t[l>>2]|0,6,0)|0;t[(t[c>>2]|0)+12>>2]=b;t[l>>2]=t[(t[l>>2]|0)+24>>2]}}while(0);if(t[l>>2]|0)$d(t[u>>2]|0,3033,0,t[o>>2]|0,t[l>>2]|0,0,161680);t[f>>2]=t[c>>2];h=t[f>>2]|0;s=n;return h|0}function Qd(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0;n=s;s=s+32|0;f=n+24|0;u=n+20|0;a=n+16|0;o=n+12|0;c=n+8|0;l=n+4|0;b=n;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;t[b>>2]=0;if((t[u>>2]|0)==0|(t[a>>2]|0)==0|(t[o>>2]|0)==0){t[f>>2]=0;k=t[f>>2]|0;s=n;return k|0}t[c>>2]=Sw(t[u>>2]|0,t[o>>2]|0,161352)|0;r=t[u>>2]|0;if(!(t[c>>2]|0)){QT(r,t[o>>2]|0,t[b>>2]|0,1723,161360,0,0);t[f>>2]=0;k=t[f>>2]|0;s=n;return k|0}t[l>>2]=$T(r,t[a>>2]|0,t[c>>2]|0,t[(t[u>>2]|0)+112>>2]|0,t[o>>2]|0)|0;if(!(t[l>>2]|0)){t[f>>2]=0;k=t[f>>2]|0;s=n;return k|0}Pd(t[u>>2]|0,t[o>>2]|0,161384)|0;t[b>>2]=t[(t[o>>2]|0)+12>>2];if((((t[b>>2]|0)!=0?(t[(t[b>>2]|0)+36>>2]|0)!=0:0)?(Xl(t[(t[b>>2]|0)+8>>2]|0,160992)|0)!=0:0)?(Xl(t[(t[(t[b>>2]|0)+36>>2]|0)+8>>2]|0,t[38526]|0)|0)!=0:0){c=jd(t[u>>2]|0,t[b>>2]|0,1)|0;t[(t[l>>2]|0)+8>>2]=c;t[b>>2]=t[(t[b>>2]|0)+24>>2]}if(t[b>>2]|0)$d(t[u>>2]|0,3033,0,t[o>>2]|0,t[b>>2]|0,0,161392);t[f>>2]=t[l>>2];k=t[f>>2]|0;s=n;return k|0}function $d(e,i,r,n,f,u,a){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;u=u|0;a=a|0;var o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0;o=s;s=s+32|0;c=o+28|0;l=o+24|0;b=o+20|0;k=o+16|0;h=o+12|0;w=o+8|0;d=o+4|0;v=o;t[c>>2]=e;t[l>>2]=i;t[b>>2]=r;t[k>>2]=n;t[h>>2]=f;t[w>>2]=u;t[d>>2]=a;t[v>>2]=0;sw(v,0,t[b>>2]|0,t[k>>2]|0)|0;do if(!(t[w>>2]|0)){b=t[c>>2]|0;a=t[k>>2]|0;u=t[h>>2]|0;f=t[l>>2]|0;n=t[v>>2]|0;if(t[d>>2]|0){QT(b,a,u,f,161272,n,t[d>>2]|0);break}else{QT(b,a,u,f,161320,n,0);break}}else QT(t[c>>2]|0,t[k>>2]|0,t[h>>2]|0,t[l>>2]|0,161256,t[v>>2]|0,t[w>>2]|0);while(0);if(!(t[v>>2]|0)){s=o;return}pAi[t[135736>>2]&511](t[v>>2]|0);t[v>>2]=0;s=o;return}function ev(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0;f=s;s=s+32|0;u=f+28|0;a=f+24|0;o=f+20|0;c=f+16|0;l=f+12|0;b=f+8|0;k=f+4|0;h=f;t[a>>2]=e;t[o>>2]=i;t[c>>2]=r;t[l>>2]=n;if((t[a>>2]|0)==0|(t[c>>2]|0)==0){t[u>>2]=0;w=t[u>>2]|0;s=f;return w|0}e:do if((t[(t[a>>2]|0)+44>>2]|0)!=0?(t[(t[(t[a>>2]|0)+44>>2]|0)+4>>2]|0)!=0:0){t[k>>2]=0;i:while(1){if((t[k>>2]|0)>=(t[(t[(t[a>>2]|0)+44>>2]|0)+4>>2]|0))break e;t[b>>2]=t[(t[t[(t[a>>2]|0)+44>>2]>>2]|0)+(t[k>>2]<<2)>>2];do if((t[t[b>>2]>>2]|0)==(t[o>>2]|0)){n=t[o>>2]|0;if((n|0)==4|(n|0)==5){if((t[(t[b>>2]|0)+8>>2]|0)!=(t[c>>2]|0))break;if((t[(t[b>>2]|0)+112>>2]|0)==(t[l>>2]|0)){d=11;break i}else break}else if((n|0)==16){if((t[(t[b>>2]|0)+8>>2]|0)!=(t[c>>2]|0))break;if((t[(t[b>>2]|0)+52>>2]|0)==(t[l>>2]|0)){d=17;break i}else break}else if((n|0)==17){if((t[(t[b>>2]|0)+16>>2]|0)!=(t[c>>2]|0))break;if((t[(t[b>>2]|0)+20>>2]|0)==(t[l>>2]|0)){d=14;break i}else break}else{d=18;break i}}while(0);t[k>>2]=(t[k>>2]|0)+1}if((d|0)==11){t[u>>2]=t[b>>2];w=t[u>>2]|0;s=f;return w|0}else if((d|0)==14){t[u>>2]=t[b>>2];w=t[u>>2]|0;s=f;return w|0}else if((d|0)==17){t[u>>2]=t[b>>2];w=t[u>>2]|0;s=f;return w|0}else if((d|0)==18){t[u>>2]=0;w=t[u>>2]|0;s=f;return w|0}}while(0);do if(t[(t[a>>2]|0)+24>>2]|0){t[h>>2]=t[(t[a>>2]|0)+24>>2];k=(t[a>>2]|0)+4|0;t[k>>2]=t[k>>2]|1;while(1){if(((t[(t[h>>2]|0)+12>>2]|0)!=0?(t[(t[(t[h>>2]|0)+12>>2]|0)+4>>2]&1|0)==0:0)?(t[b>>2]=ev(t[(t[h>>2]|0)+12>>2]|0,t[o>>2]|0,t[c>>2]|0,t[l>>2]|0)|0,(t[b>>2]|0)!=0):0)break;t[h>>2]=t[t[h>>2]>>2];if(!(t[h>>2]|0)){d=27;break}}if((d|0)==27){k=(t[a>>2]|0)+4|0;t[k>>2]=t[k>>2]^1;break}t[u>>2]=t[b>>2];w=t[u>>2]|0;s=f;return w|0}while(0);t[u>>2]=0;w=t[u>>2]|0;s=f;return w|0}function iv(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0;n=s;s=s+32|0;f=n+20|0;u=n+16|0;a=n+12|0;o=n+8|0;c=n+4|0;l=n;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;t[c>>2]=0;if(!(t[a>>2]|0)){t[f>>2]=0;b=t[f>>2]|0;s=n;return b|0}if((t[o>>2]|0)!=0?(Xl(t[o>>2]|0,t[38526]|0)|0)!=0:0){t[c>>2]=RD(t[a>>2]|0,t[o>>2]|0)|0;if((t[c>>2]|0)==0&(t[u>>2]|0)!=0)k=7}else k=6;if((k|0)==6?(t[u>>2]|0)!=0:0)k=7;do if((k|0)==7){if((Xl(t[o>>2]|0,t[(t[u>>2]|0)+4>>2]|0)|0)!=0?(t[c>>2]=rO(t[(t[u>>2]|0)+28>>2]|0,t[a>>2]|0)|0,(t[c>>2]|0)!=0):0)break;if((bO(t[(t[u>>2]|0)+48>>2]|0)|0)>1){r=t[(t[u>>2]|0)+48>>2]|0;if(!(t[o>>2]|0))t[l>>2]=rO(r,145792)|0;else t[l>>2]=rO(r,t[o>>2]|0)|0;if(t[l>>2]|0)t[c>>2]=rO(t[(t[(t[l>>2]|0)+52>>2]|0)+28>>2]|0,t[a>>2]|0)|0}}while(0);t[f>>2]=t[c>>2];b=t[f>>2]|0;s=n;return b|0}function rv(e,i,r,n,f,u,a,o,c){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;u=u|0;a=a|0;o=o|0;c=c|0;var l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0,S=0;l=s;s=s+48|0;b=l+40|0;k=l+36|0;h=l+32|0;w=l+28|0;d=l+24|0;v=l+20|0;m=l+16|0;_=l+12|0;p=l+8|0;E=l+4|0;S=l;t[b>>2]=e;t[k>>2]=i;t[h>>2]=r;t[w>>2]=n;t[d>>2]=f;t[v>>2]=u;t[m>>2]=a;t[_>>2]=o;t[p>>2]=c;t[E>>2]=0;t[S>>2]=0;sw(E,0,t[h>>2]|0,t[w>>2]|0)|0;if(!(t[p>>2]|0))t[p>>2]=lT(t[_>>2]|0)|0;_=t[b>>2]|0;b=t[w>>2]|0;w=t[k>>2]|0;k=t[E>>2]|0;h=t[d>>2]|0;d=uh(S,t[m>>2]|0,t[v>>2]|0)|0;vT(_,b,w,0,0,0,160072,k,h,d,t[p>>2]|0,0);if(t[E>>2]|0){pAi[t[135736>>2]&511](t[E>>2]|0);t[E>>2]=0}if(!(t[S>>2]|0)){s=l;return}pAi[t[135736>>2]&511](t[S>>2]|0);t[S>>2]=0;s=l;return}function nv(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0;n=s;s=s+32|0;f=n+20|0;u=n+16|0;a=n+12|0;o=n+8|0;c=n+4|0;l=n;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;t[c>>2]=0;if((t[a>>2]|0)==0|(t[u>>2]|0)==0){t[f>>2]=0;b=t[f>>2]|0;s=n;return b|0}do if(t[u>>2]|0){if((Xl(t[o>>2]|0,t[(t[u>>2]|0)+4>>2]|0)|0)!=0?(t[c>>2]=rO(t[(t[u>>2]|0)+40>>2]|0,t[a>>2]|0)|0,(t[c>>2]|0)!=0):0)break;if((bO(t[(t[u>>2]|0)+48>>2]|0)|0)>1){r=t[(t[u>>2]|0)+48>>2]|0;if(!(t[o>>2]|0))t[l>>2]=rO(r,145792)|0;else t[l>>2]=rO(r,t[o>>2]|0)|0;if(t[l>>2]|0)t[c>>2]=rO(t[(t[(t[l>>2]|0)+52>>2]|0)+40>>2]|0,t[a>>2]|0)|0}}while(0);t[f>>2]=t[c>>2];b=t[f>>2]|0;s=n;return b|0}function fv(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0;r=s;s=s+48|0;n=r+32|0;f=r+28|0;u=r+24|0;a=r+20|0;o=r+16|0;c=r+12|0;l=r+8|0;b=r+4|0;k=r;t[f>>2]=e;t[u>>2]=i;t[a>>2]=t[(t[u>>2]|0)+92>>2];t[o>>2]=0;e:while(1){if(!(t[a>>2]|0))break;t[b>>2]=t[(t[(t[a>>2]|0)+4>>2]|0)+12>>2];t[k>>2]=t[(t[(t[a>>2]|0)+4>>2]|0)+16>>2];t[l>>2]=iv(t[(t[f>>2]|0)+36>>2]|0,t[b>>2]|0,t[k>>2]|0)|0;do if(t[l>>2]|0){if((t[t[l>>2]>>2]|0)!=4){if((t[t[l>>2]>>2]|0)!=1)break;if((t[(t[l>>2]|0)+88>>2]|0)==45)break}t[(t[a>>2]|0)+4>>2]=t[l>>2];t[o>>2]=t[a>>2];t[a>>2]=t[t[a>>2]>>2];continue e}while(0);rv(t[f>>2]|0,3004,t[u>>2]|0,t[(t[u>>2]|0)+36>>2]|0,160512,t[b>>2]|0,t[k>>2]|0,4,0);i=t[t[a>>2]>>2]|0;if(!(t[o>>2]|0))t[(t[u>>2]|0)+92>>2]=i;else t[t[o>>2]>>2]=i;t[c>>2]=t[a>>2];t[a>>2]=t[t[a>>2]>>2];pAi[t[135736>>2]&511](t[c>>2]|0)}t[l>>2]=t[(t[u>>2]|0)+28>>2];while(1){if(!(t[l>>2]|0)){h=20;break}t[a>>2]=gAi[t[135744>>2]&511](8)|0;if(!(t[a>>2]|0)){h=15;break}t[(t[a>>2]|0)+4>>2]=t[l>>2];t[t[a>>2]>>2]=0;c=t[a>>2]|0;if(!(t[o>>2]|0))t[(t[u>>2]|0)+92>>2]=c;else t[t[o>>2]>>2]=c;t[o>>2]=t[a>>2];t[l>>2]=t[(t[l>>2]|0)+4>>2]}if((h|0)==15){Qh(t[f>>2]|0,149752,0);t[n>>2]=-1;w=t[n>>2]|0;s=r;return w|0}else if((h|0)==20){t[n>>2]=0;w=t[n>>2]|0;s=r;return w|0}return 0}function tv(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0;f=s;s=s+32|0;u=f;a=f+24|0;o=f+20|0;c=f+16|0;l=f+12|0;b=f+8|0;t[o>>2]=e;t[c>>2]=i;t[l>>2]=r;t[b>>2]=n;n=t[c>>2]|0;if((n|0)==17){t[a>>2]=eL(t[o>>2]|0,t[l>>2]|0,t[b>>2]|0)|0;k=t[a>>2]|0;s=f;return k|0}else if((n|0)==14){t[a>>2]=nv(t[o>>2]|0,t[l>>2]|0,t[b>>2]|0)|0;k=t[a>>2]|0;s=f;return k|0}else{b=t[33976]|0;l=t[33980]|0;t[u>>2]=140328;t[u+4>>2]=4984;yAi[b&511](l,140296,u);t[a>>2]=0;k=t[a>>2]|0;s=f;return k|0}return 0}function uv(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0;n=s;s=s+32|0;f=n+20|0;u=n+16|0;a=n+12|0;o=n+8|0;c=n+4|0;l=n;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;t[c>>2]=0;if((t[a>>2]|0)==0|(t[u>>2]|0)==0){t[f>>2]=0;b=t[f>>2]|0;s=n;return b|0}do if(t[u>>2]|0){if((Xl(t[o>>2]|0,t[(t[u>>2]|0)+4>>2]|0)|0)!=0?(t[c>>2]=rO(t[(t[u>>2]|0)+32>>2]|0,t[a>>2]|0)|0,(t[c>>2]|0)!=0):0)break;if((bO(t[(t[u>>2]|0)+48>>2]|0)|0)>1){r=t[(t[u>>2]|0)+48>>2]|0;if(!(t[o>>2]|0))t[l>>2]=rO(r,145792)|0;else t[l>>2]=rO(r,t[o>>2]|0)|0;if(t[l>>2]|0)t[c>>2]=rO(t[(t[(t[l>>2]|0)+52>>2]|0)+32>>2]|0,t[a>>2]|0)|0}}while(0);t[f>>2]=t[c>>2];b=t[f>>2]|0;s=n;return b|0}function av(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0;n=s;s=s+32|0;f=n+20|0;u=n+16|0;a=n+12|0;o=n+8|0;c=n+4|0;l=n;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;t[c>>2]=0;if((t[a>>2]|0)==0|(t[u>>2]|0)==0){t[f>>2]=0;b=t[f>>2]|0;s=n;return b|0}do if(t[u>>2]|0){if((Xl(t[o>>2]|0,t[(t[u>>2]|0)+4>>2]|0)|0)!=0?(t[c>>2]=rO(t[(t[u>>2]|0)+36>>2]|0,t[a>>2]|0)|0,(t[c>>2]|0)!=0):0)break;if((bO(t[(t[u>>2]|0)+48>>2]|0)|0)>1){r=t[(t[u>>2]|0)+48>>2]|0;if(!(t[o>>2]|0))t[l>>2]=rO(r,145792)|0;else t[l>>2]=rO(r,t[o>>2]|0)|0;if(t[l>>2]|0)t[c>>2]=rO(t[(t[(t[l>>2]|0)+52>>2]|0)+36>>2]|0,t[a>>2]|0)|0}}while(0);t[f>>2]=t[c>>2];b=t[f>>2]|0;s=n;return b|0}function ov(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0;n=s;s=s+32|0;f=n+20|0;u=n+16|0;a=n+12|0;o=n+8|0;c=n+4|0;l=n;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;t[c>>2]=0;if((t[a>>2]|0)==0|(t[u>>2]|0)==0){t[f>>2]=0;b=t[f>>2]|0;s=n;return b|0}do if(t[u>>2]|0){if((Xl(t[o>>2]|0,t[(t[u>>2]|0)+4>>2]|0)|0)!=0?(t[c>>2]=rO(t[(t[u>>2]|0)+76>>2]|0,t[a>>2]|0)|0,(t[c>>2]|0)!=0):0)break;if((bO(t[(t[u>>2]|0)+48>>2]|0)|0)>1){r=t[(t[u>>2]|0)+48>>2]|0;if(!(t[o>>2]|0))t[l>>2]=rO(r,145792)|0;else t[l>>2]=rO(r,t[o>>2]|0)|0;if(t[l>>2]|0)t[c>>2]=rO(t[(t[(t[l>>2]|0)+52>>2]|0)+76>>2]|0,t[a>>2]|0)|0}}while(0);t[f>>2]=t[c>>2];b=t[f>>2]|0;s=n;return b|0}function cv(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,l=0;n=s;s=s+32|0;f=n+16|0;u=n+12|0;a=n+8|0;o=n+4|0;c=n;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;if((t[o>>2]|0)!=0?(t[t[o>>2]>>2]|0)!=1:0){if((t[a>>2]|0)==(t[o>>2]|0)){r=t[u>>2]|0;i=t[a>>2]|0;sv(r,3009,i,lw(t[a>>2]|0)|0,160032,0);t[f>>2]=3009;l=t[f>>2]|0;s=n;return l|0}if(t[(t[o>>2]|0)+48>>2]&65536){t[f>>2]=0;l=t[f>>2]|0;s=n;return l|0}else{i=(t[o>>2]|0)+48|0;t[i>>2]=t[i>>2]|65536;t[c>>2]=cv(t[u>>2]|0,t[a>>2]|0,t[(t[o>>2]|0)+64>>2]|0)|0;a=(t[o>>2]|0)+48|0;t[a>>2]=t[a>>2]^65536;t[f>>2]=t[c>>2];l=t[f>>2]|0;s=n;return l|0}}t[f>>2]=0;l=t[f>>2]|0;s=n;return l|0}function lv(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0;r=s;s=s+32|0;n=r+20|0;f=r+16|0;u=r+12|0;a=r+8|0;o=r+4|0;c=r;t[f>>2]=e;t[u>>2]=i;t[a>>2]=0;e:while(1){if(!(t[u>>2]|0)){l=14;break}t[o>>2]=t[(t[u>>2]|0)+12>>2];do if(t[o>>2]|0){i=t[t[o>>2]>>2]|0;if((i|0)==8|(i|0)==7|(i|0)==6){t[a>>2]=lv(t[f>>2]|0,t[(t[o>>2]|0)+12>>2]|0)|0;if(t[a>>2]|0){l=12;break e}else break}else if((i|0)!=17)break;t[c>>2]=t[o>>2];if((t[c>>2]|0)==(t[f>>2]|0)){l=6;break e}if(((t[(t[c>>2]|0)+28>>2]&1|0)==0?(t[(t[c>>2]|0)+12>>2]|0)!=0:0)?(i=(t[c>>2]|0)+28|0,t[i>>2]=t[i>>2]|1,t[a>>2]=lv(t[f>>2]|0,t[(t[(t[c>>2]|0)+12>>2]|0)+12>>2]|0)|0,i=(t[c>>2]|0)+28|0,t[i>>2]=t[i>>2]^1,(t[a>>2]|0)!=0):0){l=10;break e}}while(0);t[u>>2]=t[(t[u>>2]|0)+8>>2]}if((l|0)==6){t[n>>2]=t[u>>2];b=t[n>>2]|0;s=r;return b|0}else if((l|0)==10){t[n>>2]=t[a>>2];b=t[n>>2]|0;s=r;return b|0}else if((l|0)==12){t[n>>2]=t[a>>2];b=t[n>>2]|0;s=r;return b|0}else if((l|0)==14){t[n>>2]=0;b=t[n>>2]|0;s=r;return b|0}return 0}function sv(e,i,r,n,f,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;u=u|0;var a=0,o=0,c=0,l=0,b=0,k=0,h=0;a=s;s=s+32|0;o=a+20|0;c=a+16|0;l=a+12|0;b=a+8|0;k=a+4|0;h=a;t[o>>2]=e;t[c>>2]=i;t[l>>2]=r;t[b>>2]=n;t[k>>2]=f;t[h>>2]=u;iL(t[o>>2]|0,t[c>>2]|0,t[l>>2]|0,t[b>>2]|0,t[k>>2]|0,t[h>>2]|0,0,0);s=a;return}function bv(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0;r=s;s=s+32|0;n=r+24|0;f=r+20|0;u=r+16|0;a=r+12|0;o=r+8|0;c=r+4|0;l=r;t[f>>2]=e;t[u>>2]=i;t[l>>2]=0;while(1){if((t[l>>2]|0)>=(t[(t[u>>2]|0)+4>>2]|0)){b=14;break}t[o>>2]=t[(t[t[u>>2]>>2]|0)+(t[l>>2]<<2)>>2];if(((t[t[o>>2]>>2]|0)==2e3?(t[(t[o>>2]|0)+8>>2]|0)==16:0)?(t[(t[o>>2]|0)+4>>2]|0)!=0:0){t[a>>2]=t[(t[o>>2]|0)+4>>2];if((t[a>>2]|0)==(t[f>>2]|0)){b=7;break}if((((t[(t[a>>2]|0)+36>>2]&4|0)==0?(t[(t[a>>2]|0)+56>>2]|0)!=0:0)?(t[(t[a>>2]|0)+36>>2]&16|0)!=0:0)?(i=(t[a>>2]|0)+36|0,t[i>>2]=t[i>>2]|4,t[c>>2]=bv(t[f>>2]|0,t[(t[a>>2]|0)+56>>2]|0)|0,i=(t[a>>2]|0)+36|0,t[i>>2]=t[i>>2]^4,(t[c>>2]|0)!=0):0){b=12;break}}t[l>>2]=(t[l>>2]|0)+1}if((b|0)==7){t[n>>2]=t[o>>2];k=t[n>>2]|0;s=r;return k|0}else if((b|0)==12){t[n>>2]=t[c>>2];k=t[n>>2]|0;s=r;return k|0}else if((b|0)==14){t[n>>2]=0;k=t[n>>2]|0;s=r;return k|0}return 0}function kv(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;var u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0,S=0,g=0,y=0;u=s;s=s+64|0;a=u+56|0;o=u+52|0;c=u+48|0;l=u+44|0;b=u+40|0;k=u+36|0;h=u+32|0;w=u+28|0;d=u+24|0;v=u+20|0;m=u+16|0;_=u+12|0;p=u+8|0;E=u+4|0;S=u;t[o>>2]=e;t[c>>2]=i;t[l>>2]=r;t[b>>2]=n;t[k>>2]=f;t[_>>2]=(t[t[l>>2]>>2]|0)==0?0:1;if(t[k>>2]|0)t[(t[k>>2]|0)+4>>2]=0;t[v>>2]=0;e:while(1){if((t[v>>2]|0)>=(t[(t[b>>2]|0)+4>>2]|0)){g=41;break}t[w>>2]=t[(t[t[b>>2]>>2]|0)+(t[v>>2]<<2)>>2];i:do if((t[t[w>>2]>>2]|0)!=2001){if((t[t[w>>2]>>2]|0)==2e3?(t[(t[w>>2]|0)+8>>2]|0)==16:0){if(!(t[(t[w>>2]|0)+4>>2]|0)){g=14;break e}t[h>>2]=t[(t[w>>2]|0)+4>>2];if((t[(t[h>>2]|0)+36>>2]&1|0)==0?(zw(t[o>>2]|0,t[h>>2]|0)|0)==-1:0){g=17;break e}do if(t[(t[h>>2]|0)+40>>2]|0){if(!(t[t[l>>2]>>2]|0)){t[t[l>>2]>>2]=t[(t[h>>2]|0)+40>>2];break}if(!(t[_>>2]|0)){f=t[o>>2]|0;n=t[(t[o>>2]|0)+36>>2]|0;t[p>>2]=nL(f,n,21,lw(t[c>>2]|0)|0)|0;if(!(t[p>>2]|0)){g=23;break e}if((fL(t[o>>2]|0,t[p>>2]|0,t[t[l>>2]>>2]|0)|0)==-1){g=25;break e}t[(t[p>>2]|0)+24>>2]=t[(t[t[l>>2]>>2]|0)+24>>2];t[t[l>>2]>>2]=t[p>>2];t[_>>2]=1}if((tL(t[o>>2]|0,t[t[l>>2]>>2]|0,t[(t[h>>2]|0)+40>>2]|0)|0)==-1){g=28;break e}}while(0);t[d>>2]=t[(t[h>>2]|0)+56>>2];if((t[d>>2]|0)!=0?(t[(t[d>>2]|0)+4>>2]|0)!=0:0){t[(t[t[b>>2]>>2]|0)+(t[v>>2]<<2)>>2]=t[t[t[d>>2]>>2]>>2];if((t[(t[d>>2]|0)+4>>2]|0)==1)break;t[m>>2]=1;while(1){if((t[m>>2]|0)>=(t[(t[d>>2]|0)+4>>2]|0))break i;t[v>>2]=(t[v>>2]|0)+1;if((uL(t[b>>2]|0,t[(t[t[d>>2]>>2]|0)+(t[m>>2]<<2)>>2]|0,t[v>>2]|0)|0)==-1){g=38;break e}t[m>>2]=(t[m>>2]|0)+1}}if((yv(t[b>>2]|0,t[v>>2]|0)|0)==-1){g=32;break e}t[v>>2]=(t[v>>2]|0)+-1}}else{if(!(t[k>>2]|0)){g=7;break e}if((yv(t[b>>2]|0,t[v>>2]|0)|0)==-1){g=9;break e}t[v>>2]=(t[v>>2]|0)+-1;rL(t[k>>2]|0,2,t[w>>2]|0)|0}while(0);t[v>>2]=(t[v>>2]|0)+1}switch(g|0){case 7:{rh(t[o>>2]|0,152800,152840);t[a>>2]=-1;y=t[a>>2]|0;s=u;return y|0}case 9:{t[a>>2]=-1;y=t[a>>2]|0;s=u;return y|0}case 14:{t[a>>2]=-1;y=t[a>>2]|0;s=u;return y|0}case 17:{t[a>>2]=-1;y=t[a>>2]|0;s=u;return y|0}case 23:{t[a>>2]=-1;y=t[a>>2]|0;s=u;return y|0}case 25:{t[a>>2]=-1;y=t[a>>2]|0;s=u;return y|0}case 28:{t[a>>2]=-1;y=t[a>>2]|0;s=u;return y|0}case 32:{t[a>>2]=-1;y=t[a>>2]|0;s=u;return y|0}case 38:{t[a>>2]=-1;y=t[a>>2]|0;s=u;return y|0}case 41:{e:do if(((t[k>>2]|0)!=0?(t[(t[k>>2]|0)+4>>2]|0)!=0:0)?(t[(t[b>>2]|0)+4>>2]|0)!=0:0){t[v>>2]=(t[(t[k>>2]|0)+4>>2]|0)-1;while(1){if((t[v>>2]|0)<0)break e;t[E>>2]=t[(t[t[k>>2]>>2]|0)+(t[v>>2]<<2)>>2];t[m>>2]=0;while(1){if((t[m>>2]|0)>=(t[(t[b>>2]|0)+4>>2]|0))break;t[w>>2]=t[(t[t[b>>2]>>2]|0)+(t[m>>2]<<2)>>2];if((t[(t[E>>2]|0)+8>>2]|0)==(t[(t[(t[w>>2]|0)+12>>2]|0)+8>>2]|0)?(t[(t[E>>2]|0)+12>>2]|0)==(t[(t[(t[w>>2]|0)+12>>2]|0)+56>>2]|0):0){g=50;break}t[m>>2]=(t[m>>2]|0)+1}if((g|0)==50){g=0;t[S>>2]=0;d=t[o>>2]|0;h=t[(t[E>>2]|0)+4>>2]|0;mw(d,3086,h,0,152880,uh(S,t[(t[E>>2]|0)+12>>2]|0,t[(t[E>>2]|0)+8>>2]|0)|0,0,0);if(t[S>>2]|0){pAi[t[135736>>2]&511](t[S>>2]|0);t[S>>2]=0}if((yv(t[k>>2]|0,t[v>>2]|0)|0)==-1)break}t[v>>2]=(t[v>>2]|0)+-1}t[a>>2]=-1;y=t[a>>2]|0;s=u;return y|0}while(0);t[a>>2]=0;y=t[a>>2]|0;s=u;return y|0}}return 0}function hv(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0;n=s;s=s+32|0;f=n+24|0;u=n+20|0;a=n+16|0;o=n+12|0;c=n+8|0;l=n+4|0;b=n;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;t[c>>2]=t[o>>2];e:while(1){if(!(t[c>>2]|0)){k=14;break}t[l>>2]=t[(t[c>>2]|0)+4>>2];while(1){if(!(t[l>>2]|0))break;if((t[t[l>>2]>>2]|0)==1)break;if((t[l>>2]|0)==(t[a>>2]|0)){k=7;break e}if(((t[(t[l>>2]|0)+48>>2]&128|0)!=0?(t[(t[l>>2]|0)+48>>2]&65536|0)==0:0)?(o=(t[l>>2]|0)+48|0,t[o>>2]=t[o>>2]|65536,o=t[u>>2]|0,r=t[a>>2]|0,t[b>>2]=hv(o,r,cw(t[l>>2]|0)|0)|0,r=(t[l>>2]|0)+48|0,t[r>>2]=t[r>>2]^65536,(t[b>>2]|0)!=0):0){k=11;break e}t[l>>2]=t[(t[l>>2]|0)+64>>2]}t[c>>2]=t[t[c>>2]>>2]}if((k|0)==7){sv(t[u>>2]|0,3003,t[a>>2]|0,0,159872,0);t[f>>2]=3003;h=t[f>>2]|0;s=n;return h|0}else if((k|0)==11){t[f>>2]=t[b>>2];h=t[f>>2]|0;s=n;return h|0}else if((k|0)==14){t[f>>2]=0;h=t[f>>2]|0;s=n;return h|0}return 0}function wv(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0;r=s;s=s+16|0;n=r+8|0;f=r+4|0;u=r;t[f>>2]=e;t[u>>2]=i;do if(!(t[f>>2]|0))t[n>>2]=0;else{if((t[t[u>>2]>>2]|0)!=1){rh(t[u>>2]|0,147104,147128);t[n>>2]=-1;break}if((t[t[f>>2]>>2]|0)!=1?(t[(t[f>>2]|0)+48>>2]&4194304|0)==0:0){if((t[t[f>>2]>>2]|0)==5){t[n>>2]=Xw(t[u>>2]|0,t[f>>2]|0)|0;break}if((t[t[f>>2]>>2]|0)==4){t[n>>2]=qw(t[u>>2]|0,t[f>>2]|0)|0;break}else{t[n>>2]=0;break}}t[n>>2]=0}while(0);s=r;return t[n>>2]|0}function dv(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0;r=s;s=s+32|0;n=r+28|0;f=r+24|0;u=r+20|0;a=r+16|0;o=r+12|0;c=r+8|0;l=r+4|0;b=r;t[f>>2]=e;t[u>>2]=i;t[a>>2]=t[(t[u>>2]|0)+92>>2];e:while(1){if(!(t[a>>2]|0)){k=15;break}if((t[t[(t[a>>2]|0)+4>>2]>>2]|0)!=1?(t[(t[(t[a>>2]|0)+4>>2]|0)+48>>2]&4194304|0)==0:0)wv(t[(t[a>>2]|0)+4>>2]|0,t[f>>2]|0)|0;i:do if(((t[(t[(t[a>>2]|0)+4>>2]|0)+48>>2]&128|0)!=0?(t[l>>2]=cw(t[(t[a>>2]|0)+4>>2]|0)|0,(t[l>>2]|0)!=0):0)?(t[(t[a>>2]|0)+4>>2]=t[(t[l>>2]|0)+4>>2],(t[t[l>>2]>>2]|0)!=0):0){t[o>>2]=t[t[a>>2]>>2];t[l>>2]=t[t[l>>2]>>2];t[c>>2]=t[a>>2];while(1){if(!(t[l>>2]|0))break i;t[b>>2]=gAi[t[135744>>2]&511](8)|0;if(!(t[b>>2]|0)){k=12;break e}t[(t[b>>2]|0)+4>>2]=t[(t[l>>2]|0)+4>>2];t[t[c>>2]>>2]=t[b>>2];t[c>>2]=t[b>>2];t[t[b>>2]>>2]=t[o>>2];t[l>>2]=t[t[l>>2]>>2]}}while(0);t[a>>2]=t[t[a>>2]>>2]}if((k|0)==12){Qh(t[f>>2]|0,149752,0);t[n>>2]=-1;h=t[n>>2]|0;s=r;return h|0}else if((k|0)==15){t[n>>2]=0;h=t[n>>2]|0;s=r;return h|0}return 0}function vv(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0;r=s;s=s+32|0;n=r+16|0;f=r+12|0;u=r+8|0;a=r+4|0;o=r;t[f>>2]=e;t[u>>2]=i;t[a>>2]=t[(t[u>>2]|0)+64>>2];t[o>>2]=0;if(!(t[a>>2]|0)){sv(t[f>>2]|0,3008,t[u>>2]|0,0,149560,0);t[n>>2]=3008;c=t[n>>2]|0;s=r;return c|0}do if((t[t[a>>2]>>2]|0)!=4){if((t[t[a>>2]>>2]|0)==1?(t[(t[a>>2]|0)+88>>2]|0)!=45:0)break;i=t[f>>2]|0;e=t[u>>2]|0;sv(i,3008,e,0,149584,Rd(o,t[a>>2]|0)|0);if(t[o>>2]|0){pAi[t[135736>>2]&511](t[o>>2]|0);t[o>>2]=0}t[n>>2]=3008;c=t[n>>2]|0;s=r;return c|0}while(0);if(!((t[(t[u>>2]|0)+48>>2]&64|0)==0?(t[(t[u>>2]|0)+48>>2]&128|0)==0:0))l=11;do if((l|0)==11?(t[(t[u>>2]|0)+48>>2]&4|0)==0:0){if((t[t[a>>2]>>2]|0)==1?(t[(t[a>>2]|0)+88>>2]|0)==46:0)break;if((t[t[a>>2]>>2]|0)!=4){e=t[f>>2]|0;i=t[u>>2]|0;sv(e,3008,i,0,149624,Rd(o,t[a>>2]|0)|0);if(t[o>>2]|0){pAi[t[135736>>2]&511](t[o>>2]|0);t[o>>2]=0}t[n>>2]=3008;c=t[n>>2]|0;s=r;return c|0}}while(0);if(((t[(t[u>>2]|0)+48>>2]&256|0)==0?(t[(t[u>>2]|0)+48>>2]&128|0)==0:0)?(t[(t[u>>2]|0)+48>>2]&64|0)==0:0){sv(t[f>>2]|0,3008,t[u>>2]|0,0,149728,0);t[n>>2]=3008;c=t[n>>2]|0;s=r;return c|0}if(!(aL(t[a>>2]|0,1024)|0)){t[n>>2]=0;c=t[n>>2]|0;s=r;return c|0}l=t[f>>2]|0;f=t[u>>2]|0;sv(l,3010,f,0,149224,Rd(o,t[a>>2]|0)|0);if(t[o>>2]|0){pAi[t[135736>>2]&511](t[o>>2]|0);t[o>>2]=0}t[n>>2]=3010;c=t[n>>2]|0;s=r;return c|0}function mv(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0,S=0,g=0,y=0,F=0,O=0,A=0,M=0,R=0,N=0,T=0;r=s;s=s+96|0;n=r+80|0;f=r+76|0;u=r+72|0;a=r+68|0;o=r+64|0;c=r+60|0;l=r+56|0;b=r+52|0;k=r+48|0;h=r+44|0;w=r+40|0;d=r+36|0;v=r+32|0;m=r+28|0;_=r+24|0;p=r+20|0;E=r+16|0;S=r+12|0;g=r+8|0;y=r+4|0;F=r;t[f>>2]=e;t[u>>2]=i;t[a>>2]=0;if((t[t[u>>2]>>2]|0)!=4){rh(t[f>>2]|0,148320,148352);t[n>>2]=-1;O=t[n>>2]|0;s=r;return O|0}i=t[u>>2]|0;e:do if(t[(t[u>>2]|0)+48>>2]&256){if(!(t[(t[i+64>>2]|0)+48>>2]&256)){e=t[f>>2]|0;A=t[u>>2]|0;sv(e,3011,A,0,148400,Rd(a,t[(t[u>>2]|0)+64>>2]|0)|0);if(t[a>>2]|0){pAi[t[135736>>2]&511](t[a>>2]|0);t[a>>2]=0}t[n>>2]=3011;O=t[n>>2]|0;s=r;return O|0}if(aL(t[(t[u>>2]|0)+64>>2]|0,1024)|0){A=t[f>>2]|0;e=t[u>>2]|0;sv(A,3012,e,0,148448,Rd(a,t[(t[u>>2]|0)+64>>2]|0)|0);if(t[a>>2]|0){pAi[t[135736>>2]&511](t[a>>2]|0);t[a>>2]=0}t[n>>2]=3012;O=t[n>>2]|0;s=r;return O|0}if(t[(t[u>>2]|0)+68>>2]|0){t[l>>2]=1;t[o>>2]=yd(t[u>>2]|0)|0;if(!(t[o>>2]|0)){rh(t[f>>2]|0,148320,148512);t[n>>2]=-1;O=t[n>>2]|0;s=r;return O|0}t[c>>2]=t[(t[u>>2]|0)+68>>2];do{if(!(pD(t[o>>2]|0,t[t[c>>2]>>2]|0)|0)){t[l>>2]=0;oL(t[f>>2]|0,3013,t[u>>2]|0,t[o>>2]|0,t[c>>2]|0)}t[c>>2]=t[(t[c>>2]|0)+4>>2]}while((t[c>>2]|0)!=0);if(!(t[l>>2]|0)){t[n>>2]=3013;O=t[n>>2]|0;s=r;return O|0}}}else{if(!(t[i+48>>2]&64)){if(!(t[(t[u>>2]|0)+48>>2]&128))break;t[p>>2]=t[(t[u>>2]|0)+92>>2];while(1){if(!(t[p>>2]|0))break;if((t[t[(t[p>>2]|0)+4>>2]>>2]|0)!=1?(t[(t[(t[p>>2]|0)+4>>2]|0)+48>>2]&4194304|0)==0:0)wv(t[(t[p>>2]|0)+4>>2]|0,t[f>>2]|0)|0;if((t[(t[(t[p>>2]|0)+4>>2]|0)+48>>2]&256|0)==0?(t[(t[(t[p>>2]|0)+4>>2]|0)+48>>2]&64|0)==0:0){M=91;break}t[p>>2]=t[t[p>>2]>>2]}if((M|0)==91){e=t[f>>2]|0;A=t[u>>2]|0;sv(e,3023,A,0,149040,Rd(a,t[(t[p>>2]|0)+4>>2]|0)|0);if(t[a>>2]|0){pAi[t[135736>>2]&511](t[a>>2]|0);t[a>>2]=0}t[n>>2]=3023;O=t[n>>2]|0;s=r;return O|0}A=t[u>>2]|0;if((t[(t[(t[u>>2]|0)+64>>2]|0)+88>>2]|0)==46){t[p>>2]=t[A+92>>2];while(1){if(!(t[p>>2]|0)){M=103;break}if(aL(t[(t[p>>2]|0)+4>>2]|0,4096)|0)break;t[p>>2]=t[t[p>>2]>>2]}if((M|0)==103){if(!(t[(t[u>>2]|0)+96>>2]|0))break;sv(t[f>>2]|0,3025,t[u>>2]|0,0,149160,0);t[n>>2]=3025;O=t[n>>2]|0;s=r;return O|0}e=t[f>>2]|0;R=t[u>>2]|0;sv(e,3024,R,0,149104,Rd(a,t[(t[p>>2]|0)+4>>2]|0)|0);if(t[a>>2]|0){pAi[t[135736>>2]&511](t[a>>2]|0);t[a>>2]=0}t[n>>2]=3024;O=t[n>>2]|0;s=r;return O|0}if(!(t[(t[A+64>>2]|0)+48>>2]&128)){R=t[f>>2]|0;e=t[u>>2]|0;sv(R,3027,e,0,149184,Rd(a,t[(t[u>>2]|0)+64>>2]|0)|0);if(t[a>>2]|0){pAi[t[135736>>2]&511](t[a>>2]|0);t[a>>2]=0}t[n>>2]=3027;O=t[n>>2]|0;s=r;return O|0}if(aL(t[(t[u>>2]|0)+64>>2]|0,1024)|0){e=t[f>>2]|0;R=t[u>>2]|0;sv(e,3026,R,0,149224,Rd(a,t[(t[u>>2]|0)+64>>2]|0)|0);if(t[a>>2]|0){pAi[t[135736>>2]&511](t[a>>2]|0);t[a>>2]=0}t[n>>2]=3026;O=t[n>>2]|0;s=r;return O|0}i:do if(t[(t[u>>2]|0)+92>>2]|0){t[p>>2]=t[(t[u>>2]|0)+92>>2];t[E>>2]=cw(t[(t[u>>2]|0)+64>>2]|0)|0;if((t[p>>2]|0)==0&(t[E>>2]|0)!=0)rh(t[f>>2]|0,148320,149296);while(1){if(!(t[p>>2]|0))break i;if(t[E>>2]|0){if((t[(t[p>>2]|0)+4>>2]|0)!=(t[(t[E>>2]|0)+4>>2]|0)?(lL(t[f>>2]|0,t[(t[p>>2]|0)+4>>2]|0,t[(t[E>>2]|0)+4>>2]|0,0)|0)!=0:0)break}else rh(t[f>>2]|0,148320,149296);t[p>>2]=t[t[p>>2]>>2];if(!(t[E>>2]|0))continue;t[E>>2]=t[t[E>>2]>>2]}t[S>>2]=0;t[g>>2]=0;R=t[f>>2]|0;e=t[u>>2]|0;N=Rd(a,t[(t[p>>2]|0)+4>>2]|0)|0;T=Rd(S,t[(t[E>>2]|0)+4>>2]|0)|0;iL(R,3028,e,0,149344,N,T,Rd(g,t[(t[u>>2]|0)+64>>2]|0)|0);if(t[a>>2]|0){pAi[t[135736>>2]&511](t[a>>2]|0);t[a>>2]=0}if(t[S>>2]|0){pAi[t[135736>>2]&511](t[S>>2]|0);t[S>>2]=0}if(t[g>>2]|0){pAi[t[135736>>2]&511](t[g>>2]|0);t[g>>2]=0}t[n>>2]=3028;O=t[n>>2]|0;s=r;return O|0}while(0);if(!(t[(t[u>>2]|0)+68>>2]|0))break;t[F>>2]=1;t[y>>2]=t[(t[u>>2]|0)+68>>2];do{if((t[t[y>>2]>>2]|0)!=1006?(t[t[y>>2]>>2]|0)!=1007:0){cL(t[f>>2]|0,3029,t[u>>2]|0,t[y>>2]|0);t[F>>2]=0}t[y>>2]=t[(t[y>>2]|0)+4>>2]}while((t[y>>2]|0)!=0);if(t[F>>2]|0)break;t[n>>2]=3029;O=t[n>>2]|0;s=r;return O|0}t[b>>2]=0;t[b>>2]=t[(t[u>>2]|0)+28>>2];do if(t[b>>2]|0){if((t[t[b>>2]>>2]|0)!=4){if((t[t[b>>2]>>2]|0)!=1)break;if((t[(t[b>>2]|0)+88>>2]|0)==45)break}if((t[t[b>>2]>>2]|0)!=1?(t[(t[b>>2]|0)+48>>2]&4194304|0)==0:0)wv(t[b>>2]|0,t[f>>2]|0)|0;if((t[(t[b>>2]|0)+48>>2]&256|0)==0?(t[(t[b>>2]|0)+48>>2]&128|0)==0:0){A=t[f>>2]|0;T=t[u>>2]|0;sv(A,3015,T,0,148584,Rd(a,t[b>>2]|0)|0);if(t[a>>2]|0){pAi[t[135736>>2]&511](t[a>>2]|0);t[a>>2]=0}t[n>>2]=3015;O=t[n>>2]|0;s=r;return O|0}i:do if(t[(t[b>>2]|0)+48>>2]&128){t[k>>2]=t[(t[b>>2]|0)+92>>2];while(1){if(!(t[k>>2]|0))break i;if(!(t[(t[(t[k>>2]|0)+4>>2]|0)+48>>2]&256))break;t[k>>2]=t[t[k>>2]>>2]}T=t[f>>2]|0;A=t[u>>2]|0;sv(T,3015,A,0,148648,Rd(a,t[(t[k>>2]|0)+4>>2]|0)|0);if(t[a>>2]|0){pAi[t[135736>>2]&511](t[a>>2]|0);t[a>>2]=0}t[n>>2]=3015;O=t[n>>2]|0;s=r;return O|0}while(0);if((t[t[(t[u>>2]|0)+64>>2]>>2]|0)==1?(t[(t[(t[u>>2]|0)+64>>2]|0)+88>>2]|0)==46:0){if(aL(t[b>>2]|0,2048)|0){A=t[f>>2]|0;T=t[u>>2]|0;sv(A,3016,T,0,148736,Rd(a,t[b>>2]|0)|0);if(t[a>>2]|0){pAi[t[135736>>2]&511](t[a>>2]|0);t[a>>2]=0}t[n>>2]=3016;O=t[n>>2]|0;s=r;return O|0}if(!(t[(t[u>>2]|0)+68>>2]|0))break e;t[h>>2]=t[(t[u>>2]|0)+68>>2];while(1){if((t[t[h>>2]>>2]|0)!=1008)break;t[h>>2]=t[(t[h>>2]|0)+4>>2];if(!(t[h>>2]|0))break e}cL(t[f>>2]|0,3017,t[u>>2]|0,t[h>>2]|0);t[n>>2]=3017;O=t[n>>2]|0;s=r;return O|0}if(!(t[(t[(t[u>>2]|0)+64>>2]|0)+48>>2]&64)){T=t[f>>2]|0;A=t[u>>2]|0;sv(T,3018,A,0,148792,Rd(a,t[(t[u>>2]|0)+64>>2]|0)|0);if(t[a>>2]|0){pAi[t[135736>>2]&511](t[a>>2]|0);t[a>>2]=0}t[n>>2]=3018;O=t[n>>2]|0;s=r;return O|0}if(aL(t[(t[u>>2]|0)+64>>2]|0,1024)|0){A=t[f>>2]|0;T=t[u>>2]|0;sv(A,3019,T,0,148832,Rd(a,t[(t[u>>2]|0)+64>>2]|0)|0);if(t[a>>2]|0){pAi[t[135736>>2]&511](t[a>>2]|0);t[a>>2]=0}t[n>>2]=3019;O=t[n>>2]|0;s=r;return O|0}t[w>>2]=t[(t[(t[u>>2]|0)+64>>2]|0)+28>>2];do if(t[w>>2]|0){if((t[t[w>>2]>>2]|0)!=4){if((t[t[w>>2]>>2]|0)!=1)break;if((t[(t[w>>2]|0)+88>>2]|0)==45)break}if((t[b>>2]|0)!=(t[w>>2]|0)?(lL(t[f>>2]|0,t[b>>2]|0,t[w>>2]|0,0)|0)!=0:0){t[d>>2]=0;t[v>>2]=0;T=t[f>>2]|0;A=t[u>>2]|0;N=Rd(a,t[b>>2]|0)|0;e=Rd(d,t[w>>2]|0)|0;iL(T,3020,A,0,148952,N,e,Rd(v,t[(t[u>>2]|0)+64>>2]|0)|0);if(t[a>>2]|0){pAi[t[135736>>2]&511](t[a>>2]|0);t[a>>2]=0}if(t[d>>2]|0){pAi[t[135736>>2]&511](t[d>>2]|0);t[d>>2]=0}if(t[v>>2]|0){pAi[t[135736>>2]&511](t[v>>2]|0);t[v>>2]=0}t[n>>2]=3020;O=t[n>>2]|0;s=r;return O|0}if(!(t[(t[u>>2]|0)+68>>2]|0))break e;t[_>>2]=1;t[m>>2]=t[(t[u>>2]|0)+68>>2];do{if(((t[t[m>>2]>>2]|0)+-1006|0)>>>0>=6){cL(t[f>>2]|0,3021,t[u>>2]|0,t[m>>2]|0);t[_>>2]=0}t[m>>2]=t[(t[m>>2]|0)+4>>2]}while((t[m>>2]|0)!=0);if(t[_>>2]|0)break e;t[n>>2]=3021;O=t[n>>2]|0;s=r;return O|0}while(0);rh(t[f>>2]|0,148320,148904);t[n>>2]=-1;O=t[n>>2]|0;s=r;return O|0}while(0);rh(t[f>>2]|0,148320,148544);t[n>>2]=-1;O=t[n>>2]|0;s=r;return O|0}while(0);t[n>>2]=0;O=t[n>>2]|0;s=r;return O|0}function _v(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0;r=s;s=s+32|0;n=r+24|0;f=r+20|0;u=r+16|0;a=r+12|0;o=r+8|0;c=r+4|0;l=r;t[f>>2]=e;t[u>>2]=i;t[o>>2]=t[(t[u>>2]|0)+20>>2];t[c>>2]=t[(t[f>>2]|0)+8>>2];do if(t[(t[f>>2]|0)+68>>2]|0){t[l>>2]=t[(t[f>>2]|0)+68>>2];if((t[(t[u>>2]|0)+92>>2]|0)==0?(sL(t[u>>2]|0)|0)==-1:0){t[n>>2]=-1;b=t[n>>2]|0;s=r;return b|0}t[(t[(t[u>>2]|0)+92>>2]|0)+20>>2]=t[(t[u>>2]|0)+36>>2];while(1){if(!(t[l>>2]|0)){k=9;break}t[a>>2]=Tk(t[l>>2]|0,t[f>>2]|0,t[u>>2]|0,t[c>>2]|0)|0;if((t[a>>2]|0)==-1)break;t[l>>2]=t[(t[l>>2]|0)+4>>2]}if((k|0)==9){t[(t[(t[u>>2]|0)+92>>2]|0)+20>>2]=0;break}t[n>>2]=-1;b=t[n>>2]|0;s=r;return b|0}while(0);if((t[o>>2]|0)!=(t[(t[u>>2]|0)+20>>2]|0)){t[n>>2]=t[(t[u>>2]|0)+16>>2];b=t[n>>2]|0;s=r;return b|0}else{t[n>>2]=0;b=t[n>>2]|0;s=r;return b|0}return 0}function pv(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0,S=0,g=0,y=0,F=0,O=0,A=0,M=0,R=0,N=0,T=0,L=0,D=0,C=0,P=0,B=0;r=s;s=s+112|0;n=r+108|0;f=r+104|0;u=r+100|0;a=r+96|0;o=r+92|0;c=r+88|0;l=r+84|0;b=r+80|0;k=r+76|0;h=r+72|0;w=r+68|0;d=r+64|0;v=r+60|0;m=r+56|0;_=r+52|0;p=r+48|0;E=r+44|0;S=r+40|0;g=r+36|0;y=r+32|0;F=r+28|0;O=r+24|0;A=r+20|0;M=r+16|0;R=r+12|0;N=r+8|0;T=r+4|0;L=r;t[f>>2]=e;t[u>>2]=i;t[a>>2]=t[(t[u>>2]|0)+64>>2];t[l>>2]=0;t[h>>2]=0;t[w>>2]=0;t[d>>2]=0;t[v>>2]=0;t[m>>2]=0;t[_>>2]=0;t[p>>2]=0;t[E>>2]=0;t[S>>2]=0;t[g>>2]=0;t[y>>2]=0;t[F>>2]=0;t[O>>2]=0;t[A>>2]=0;t[M>>2]=0;t[R>>2]=0;t[N>>2]=0;t[T>>2]=0;if((t[(t[u>>2]|0)+96>>2]|0)==0?(t[(t[a>>2]|0)+96>>2]|0)==0:0){t[n>>2]=0;D=t[n>>2]|0;s=r;return D|0}t[l>>2]=t[(t[u>>2]|0)+96>>2];e:do if(t[l>>2]|0)while(1){if(!(t[t[l>>2]>>2]|0))break e;t[l>>2]=t[t[l>>2]>>2]}while(0);t[c>>2]=t[(t[u>>2]|0)+96>>2];while(1){if(!(t[c>>2]|0))break;t[b>>2]=t[(t[c>>2]|0)+4>>2];switch(t[t[b>>2]>>2]|0){case 1011:{t[m>>2]=t[b>>2];break}case 1005:{t[d>>2]=t[b>>2];break}case 1009:{t[h>>2]=t[b>>2];break}case 1003:{t[S>>2]=t[b>>2];break}case 1004:{t[w>>2]=t[b>>2];break}case 1001:{t[E>>2]=t[b>>2];break}case 1002:{t[p>>2]=t[b>>2];break}case 1e3:{t[_>>2]=t[b>>2];break}case 1010:{t[v>>2]=t[b>>2];break}default:{}}t[c>>2]=t[t[c>>2]>>2]}t[c>>2]=t[(t[a>>2]|0)+96>>2];while(1){if(!(t[c>>2]|0))break;t[b>>2]=t[(t[c>>2]|0)+4>>2];switch(t[t[b>>2]>>2]|0){case 1002:{t[R>>2]=t[b>>2];break}case 1001:{t[N>>2]=t[b>>2];break}case 1005:{t[F>>2]=t[b>>2];break}case 1004:{t[y>>2]=t[b>>2];break}case 1e3:{t[M>>2]=t[b>>2];break}case 1003:{t[T>>2]=t[b>>2];break}case 1011:{t[A>>2]=t[b>>2];break}case 1010:{t[O>>2]=t[b>>2];break}case 1009:{t[g>>2]=t[b>>2];break}default:{}}t[c>>2]=t[t[c>>2]>>2]}if((t[h>>2]|0)!=0?(t[m>>2]|0)!=0|(t[v>>2]|0)!=0:0)sv(t[f>>2]|0,1717,t[h>>2]|0,t[(t[h>>2]|0)+20>>2]|0,147232,0);if((t[p>>2]|0)!=0&(t[S>>2]|0)!=0){i=t[f>>2]|0;e=t[p>>2]|0;C=t[(t[p>>2]|0)+20>>2]|0;P=fh(t[t[p>>2]>>2]|0)|0;iL(i,1717,e,C,147352,P,fh(t[t[S>>2]>>2]|0)|0,0)}if((t[_>>2]|0)!=0&(t[E>>2]|0)!=0){P=t[f>>2]|0;C=t[_>>2]|0;e=t[(t[_>>2]|0)+20>>2]|0;i=fh(t[t[_>>2]>>2]|0)|0;iL(P,1717,C,e,147352,i,fh(t[t[E>>2]>>2]|0)|0,0)}if((t[h>>2]|0)!=0&(t[g>>2]|0)!=0){t[L>>2]=BD(t[(t[h>>2]|0)+32>>2]|0,t[(t[g>>2]|0)+32>>2]|0)|0;if((t[L>>2]|0)!=-2){if(t[L>>2]|0)bL(t[f>>2]|0,t[h>>2]|0,t[g>>2]|0,0,0,1);if((t[L>>2]|0)!=0?(t[(t[g>>2]|0)+24>>2]|0)!=0:0){sv(t[f>>2]|0,1717,t[h>>2]|0,t[(t[h>>2]|0)+20>>2]|0,147440,0);B=47}else B=47}}else B=47;e:do if((B|0)==47){if((t[m>>2]|0)!=0&(t[A>>2]|0)!=0){t[L>>2]=BD(t[(t[m>>2]|0)+32>>2]|0,t[(t[A>>2]|0)+32>>2]|0)|0;if((t[L>>2]|0)==-2)break;if((t[L>>2]|0)==-1)bL(t[f>>2]|0,t[m>>2]|0,t[A>>2]|0,1,1,1);if((t[L>>2]|0)!=0?(t[(t[A>>2]|0)+24>>2]|0)!=0:0)sv(t[f>>2]|0,1717,t[m>>2]|0,t[(t[m>>2]|0)+20>>2]|0,147440,0)}if((t[v>>2]|0)!=0&(t[O>>2]|0)!=0){t[L>>2]=BD(t[(t[v>>2]|0)+32>>2]|0,t[(t[O>>2]|0)+32>>2]|0)|0;if((t[L>>2]|0)==-2)break;if((t[L>>2]|0)==1)bL(t[f>>2]|0,t[v>>2]|0,t[O>>2]|0,-1,1,1);if((t[L>>2]|0)!=0?(t[(t[O>>2]|0)+24>>2]|0)!=0:0)sv(t[f>>2]|0,1717,t[v>>2]|0,t[(t[v>>2]|0)+20>>2]|0,147440,0)}if(!(t[h>>2]|0))t[h>>2]=t[g>>2];if(t[h>>2]|0){if(!(t[m>>2]|0))t[m>>2]=t[A>>2];if(t[m>>2]|0){t[L>>2]=BD(t[(t[h>>2]|0)+32>>2]|0,t[(t[m>>2]|0)+32>>2]|0)|0;if((t[L>>2]|0)==-2)break;if((t[L>>2]|0)==-1)bL(t[f>>2]|0,t[h>>2]|0,t[m>>2]|0,1,1,0)}if(!(t[v>>2]|0))t[v>>2]=t[O>>2];if(t[v>>2]|0){t[L>>2]=BD(t[(t[h>>2]|0)+32>>2]|0,t[(t[v>>2]|0)+32>>2]|0)|0;if((t[L>>2]|0)==-2)break;if((t[L>>2]|0)==1)bL(t[f>>2]|0,t[h>>2]|0,t[v>>2]|0,-1,1,0)}}if(t[p>>2]|0){if(t[_>>2]|0){t[L>>2]=BD(t[(t[p>>2]|0)+32>>2]|0,t[(t[_>>2]|0)+32>>2]|0)|0;if((t[L>>2]|0)==-2)break;if((t[L>>2]|0)==-1)bL(t[f>>2]|0,t[p>>2]|0,t[_>>2]|0,1,1,0);
	}if(t[R>>2]|0){t[L>>2]=BD(t[(t[p>>2]|0)+32>>2]|0,t[(t[R>>2]|0)+32>>2]|0)|0;if((t[L>>2]|0)==-2)break;if((t[L>>2]|0)==1)bL(t[f>>2]|0,t[p>>2]|0,t[R>>2]|0,-1,1,1);if((t[L>>2]|0)!=0?(t[(t[R>>2]|0)+24>>2]|0)!=0:0)sv(t[f>>2]|0,1717,t[p>>2]|0,t[(t[p>>2]|0)+20>>2]|0,147440,0)}if(t[T>>2]|0){t[L>>2]=BD(t[(t[p>>2]|0)+32>>2]|0,t[(t[T>>2]|0)+32>>2]|0)|0;if((t[L>>2]|0)==-2)break;if((t[L>>2]|0)!=-1)bL(t[f>>2]|0,t[p>>2]|0,t[T>>2]|0,-1,0,1)}if(t[M>>2]|0){t[L>>2]=BD(t[(t[p>>2]|0)+32>>2]|0,t[(t[M>>2]|0)+32>>2]|0)|0;if((t[L>>2]|0)==-2)break;if((t[L>>2]|0)==-1)bL(t[f>>2]|0,t[p>>2]|0,t[M>>2]|0,1,1,1)}if(t[N>>2]|0){t[L>>2]=BD(t[(t[p>>2]|0)+32>>2]|0,t[(t[N>>2]|0)+32>>2]|0)|0;if((t[L>>2]|0)==-2)break;if((t[L>>2]|0)!=1)bL(t[f>>2]|0,t[p>>2]|0,t[N>>2]|0,1,0,1)}}do if(t[S>>2]|0){if(t[E>>2]|0){t[L>>2]=BD(t[(t[S>>2]|0)+32>>2]|0,t[(t[E>>2]|0)+32>>2]|0)|0;if((t[L>>2]|0)==-2)break e;if((t[L>>2]|0)==-1)bL(t[f>>2]|0,t[S>>2]|0,t[E>>2]|0,1,1,0)}do if(t[T>>2]|0){t[L>>2]=BD(t[(t[S>>2]|0)+32>>2]|0,t[(t[T>>2]|0)+32>>2]|0)|0;if((t[L>>2]|0)==-2)break e;if((t[L>>2]|0)==1)bL(t[f>>2]|0,t[S>>2]|0,t[T>>2]|0,-1,1,1);if(t[L>>2]|0){if(!(t[(t[T>>2]|0)+24>>2]|0))break;sv(t[f>>2]|0,1717,t[S>>2]|0,t[(t[S>>2]|0)+20>>2]|0,147440,0)}}while(0);if(t[R>>2]|0){t[L>>2]=BD(t[(t[S>>2]|0)+32>>2]|0,t[(t[R>>2]|0)+32>>2]|0)|0;if((t[L>>2]|0)==-2)break e;if((t[L>>2]|0)==1)bL(t[f>>2]|0,t[S>>2]|0,t[R>>2]|0,-1,1,1)}do if(t[M>>2]|0){t[L>>2]=BD(t[(t[S>>2]|0)+32>>2]|0,t[(t[M>>2]|0)+32>>2]|0)|0;if((t[L>>2]|0)==-2)break e;if((t[L>>2]|0)==1)break;bL(t[f>>2]|0,t[S>>2]|0,t[M>>2]|0,1,0,1)}while(0);if(t[N>>2]|0){t[L>>2]=BD(t[(t[S>>2]|0)+32>>2]|0,t[(t[N>>2]|0)+32>>2]|0)|0;if((t[L>>2]|0)==-2)break e;if((t[L>>2]|0)==1)break;bL(t[f>>2]|0,t[S>>2]|0,t[N>>2]|0,1,0,1)}}while(0);do if(t[E>>2]|0){if(t[p>>2]|0){t[L>>2]=BD(t[(t[E>>2]|0)+32>>2]|0,t[(t[p>>2]|0)+32>>2]|0)|0;if((t[L>>2]|0)==-2)break e;if((t[L>>2]|0)!=-1)bL(t[f>>2]|0,t[E>>2]|0,t[p>>2]|0,-1,0,0)}do if(t[N>>2]|0){t[L>>2]=BD(t[(t[E>>2]|0)+32>>2]|0,t[(t[N>>2]|0)+32>>2]|0)|0;if((t[L>>2]|0)==-2)break e;if((t[L>>2]|0)==-1)bL(t[f>>2]|0,t[E>>2]|0,t[N>>2]|0,1,1,1);if(!(t[L>>2]|0))break;if(!(t[(t[N>>2]|0)+24>>2]|0))break;sv(t[f>>2]|0,1717,t[E>>2]|0,t[(t[E>>2]|0)+20>>2]|0,147440,0)}while(0);do if(t[R>>2]|0){t[L>>2]=BD(t[(t[E>>2]|0)+32>>2]|0,t[(t[R>>2]|0)+32>>2]|0)|0;if((t[L>>2]|0)==-2)break e;if((t[L>>2]|0)!=1)break;bL(t[f>>2]|0,t[E>>2]|0,t[R>>2]|0,-1,1,1)}while(0);do if(t[M>>2]|0){t[L>>2]=BD(t[(t[E>>2]|0)+32>>2]|0,t[(t[M>>2]|0)+32>>2]|0)|0;if((t[L>>2]|0)==-2)break e;if((t[L>>2]|0)!=-1)break;bL(t[f>>2]|0,t[E>>2]|0,t[M>>2]|0,1,1,1)}while(0);if(t[T>>2]|0){t[L>>2]=BD(t[(t[E>>2]|0)+32>>2]|0,t[(t[T>>2]|0)+32>>2]|0)|0;if((t[L>>2]|0)==-2)break e;if((t[L>>2]|0)==-1)break;bL(t[f>>2]|0,t[E>>2]|0,t[T>>2]|0,-1,0,1)}}while(0);do if(t[_>>2]|0){if(t[S>>2]|0){t[L>>2]=BD(t[(t[_>>2]|0)+32>>2]|0,t[(t[S>>2]|0)+32>>2]|0)|0;if((t[L>>2]|0)==-2)break e;if((t[L>>2]|0)!=-1)bL(t[f>>2]|0,t[_>>2]|0,t[S>>2]|0,-1,0,0)}do if(t[M>>2]|0){t[L>>2]=BD(t[(t[_>>2]|0)+32>>2]|0,t[(t[M>>2]|0)+32>>2]|0)|0;if((t[L>>2]|0)==-2)break e;if((t[L>>2]|0)==-1)bL(t[f>>2]|0,t[_>>2]|0,t[M>>2]|0,1,1,1);if(!(t[L>>2]|0))break;if(!(t[(t[M>>2]|0)+24>>2]|0))break;sv(t[f>>2]|0,1717,t[_>>2]|0,t[(t[_>>2]|0)+20>>2]|0,147440,0)}while(0);do if(t[R>>2]|0){t[L>>2]=BD(t[(t[_>>2]|0)+32>>2]|0,t[(t[R>>2]|0)+32>>2]|0)|0;if((t[L>>2]|0)==-2)break e;if((t[L>>2]|0)!=1)break;bL(t[f>>2]|0,t[_>>2]|0,t[R>>2]|0,-1,1,1)}while(0);do if(t[N>>2]|0){t[L>>2]=BD(t[(t[_>>2]|0)+32>>2]|0,t[(t[N>>2]|0)+32>>2]|0)|0;if((t[L>>2]|0)==-2)break e;if((t[L>>2]|0)==1)break;bL(t[f>>2]|0,t[_>>2]|0,t[N>>2]|0,1,0,1)}while(0);if(!(t[T>>2]|0))break;t[L>>2]=BD(t[(t[_>>2]|0)+32>>2]|0,t[(t[T>>2]|0)+32>>2]|0)|0;if((t[L>>2]|0)==-2)break e;if((t[L>>2]|0)==-1)break;bL(t[f>>2]|0,t[_>>2]|0,t[T>>2]|0,-1,0,1)}while(0);do if((t[w>>2]|0)!=0&(t[y>>2]|0)!=0){t[L>>2]=BD(t[(t[w>>2]|0)+32>>2]|0,t[(t[y>>2]|0)+32>>2]|0)|0;if((t[L>>2]|0)==-2)break e;if((t[L>>2]|0)==1)bL(t[f>>2]|0,t[w>>2]|0,t[y>>2]|0,-1,1,1);if(t[L>>2]|0){if(!(t[(t[y>>2]|0)+24>>2]|0))break;sv(t[f>>2]|0,1717,t[w>>2]|0,t[(t[w>>2]|0)+20>>2]|0,147440,0)}}while(0);do if((t[d>>2]|0)!=0&(t[F>>2]|0)!=0){t[L>>2]=BD(t[(t[d>>2]|0)+32>>2]|0,t[(t[F>>2]|0)+32>>2]|0)|0;if((t[L>>2]|0)==-2)break e;if((t[L>>2]|0)==1)bL(t[f>>2]|0,t[d>>2]|0,t[F>>2]|0,-1,1,1);if(!(t[L>>2]|0))break;if(!(t[(t[F>>2]|0)+24>>2]|0))break;sv(t[f>>2]|0,1717,t[d>>2]|0,t[(t[d>>2]|0)+20>>2]|0,147440,0)}while(0);if(!(t[w>>2]|0))t[w>>2]=t[y>>2];if(!(t[d>>2]|0))t[d>>2]=t[F>>2];do if((t[w>>2]|0)!=0&(t[d>>2]|0)!=0){t[L>>2]=BD(t[(t[d>>2]|0)+32>>2]|0,t[(t[w>>2]|0)+32>>2]|0)|0;if((t[L>>2]|0)==-2)break e;if((t[L>>2]|0)!=1)break;bL(t[f>>2]|0,t[d>>2]|0,t[w>>2]|0,-1,1,0)}while(0);t[c>>2]=t[(t[a>>2]|0)+96>>2];i:while(1){if(!(t[c>>2]|0)){B=216;break}t[k>>2]=t[(t[c>>2]|0)+4>>2];do if((t[t[k>>2]>>2]|0)!=1006){if((t[t[k>>2]>>2]|0)==1007)break;t[o>>2]=t[(t[u>>2]|0)+96>>2];while(1){if(!(t[o>>2]|0))break;t[b>>2]=t[(t[o>>2]|0)+4>>2];if((t[t[b>>2]>>2]|0)==(t[t[k>>2]>>2]|0)){B=201;break}t[o>>2]=t[t[o>>2]>>2]}do if((B|0)==201){B=0;if((t[t[b>>2]>>2]|0)!=1008)break;if((t[(t[b>>2]|0)+28>>2]|0)<(t[(t[k>>2]|0)+28>>2]|0))sv(t[f>>2]|0,1717,t[b>>2]|0,t[(t[b>>2]|0)+20>>2]|0,147512,0);if(!(t[(t[k>>2]|0)+24>>2]|0))break;if((t[(t[b>>2]|0)+28>>2]|0)==(t[(t[k>>2]|0)+28>>2]|0))break;sv(t[f>>2]|0,1717,t[b>>2]|0,t[(t[b>>2]|0)+20>>2]|0,147440,0)}while(0);if(t[o>>2]|0)break;t[o>>2]=gAi[t[135744>>2]&511](8)|0;if(!(t[o>>2]|0)){B=210;break i}t[(t[o>>2]|0)+4>>2]=t[(t[c>>2]|0)+4>>2];t[t[o>>2]>>2]=0;i=t[o>>2]|0;if(!(t[l>>2]|0))t[(t[u>>2]|0)+96>>2]=i;else t[t[l>>2]>>2]=i;t[l>>2]=t[o>>2]}while(0);t[c>>2]=t[t[c>>2]>>2]}if((B|0)==210){Qh(t[f>>2]|0,147616,0);t[n>>2]=-1;D=t[n>>2]|0;s=r;return D|0}else if((B|0)==216){t[n>>2]=0;D=t[n>>2]|0;s=r;return D|0}}while(0);rh(t[f>>2]|0,147656,147696);t[n>>2]=-1;D=t[n>>2]|0;s=r;return D|0}function Ev(e){e=e|0;var i=0,r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0;i=s;s=s+16|0;r=i+12|0;n=i+8|0;f=i+4|0;u=i;t[n>>2]=e;e=(t[n>>2]|0)+48|0;a=t[e>>2]|0;if(t[(t[n>>2]|0)+48>>2]&64){t[e>>2]=a|67108864;t[r>>2]=0;o=t[r>>2]|0;s=i;return o|0}if(a&128){t[r>>2]=0;o=t[r>>2]|0;s=i;return o|0}e:do if(t[(t[n>>2]|0)+96>>2]|0){t[f>>2]=t[(t[n>>2]|0)+96>>2];while(1){if(!(t[f>>2]|0))break e;c=t[f>>2]|0;if((t[t[(t[f>>2]|0)+4>>2]>>2]|0)==1008)break;t[f>>2]=t[c>>2]}a=t[(t[c+4>>2]|0)+28>>2]|0;if((a|0)==2){e=(t[n>>2]|0)+48|0;t[e>>2]=t[e>>2]|33554432}else if((a|0)==1){e=(t[n>>2]|0)+48|0;t[e>>2]=t[e>>2]|16777216}else if((a|0)==3){a=(t[n>>2]|0)+48|0;t[a>>2]=t[a>>2]|67108864}else{t[r>>2]=-1;o=t[r>>2]|0;s=i;return o|0}t[r>>2]=0;o=t[r>>2]|0;s=i;return o|0}while(0);t[u>>2]=t[(t[n>>2]|0)+64>>2];while(1){if(!(t[u>>2]|0))break;if((t[(t[u>>2]|0)+88>>2]|0)==45)break;l=t[u>>2]|0;if((t[t[u>>2]>>2]|0)==1){b=20;break}t[u>>2]=t[l+64>>2]}do if((b|0)==20){if((t[l+88>>2]|0)==2){c=(t[n>>2]|0)+48|0;t[c>>2]=t[c>>2]|33554432;break}if((t[(t[u>>2]|0)+88>>2]|0)!=1?(t[(t[u>>2]|0)+88>>2]|0)!=46:0){c=(t[n>>2]|0)+48|0;t[c>>2]=t[c>>2]|67108864;break}c=(t[n>>2]|0)+48|0;t[c>>2]=t[c>>2]|16777216}while(0);t[r>>2]=0;o=t[r>>2]|0;s=i;return o|0}function Sv(e){e=e|0;var i=0,r=0,n=0,f=0,u=0,a=0,o=0;i=s;s=s+32|0;r=i+20|0;n=i+16|0;f=i+12|0;u=i+8|0;a=i+4|0;o=i;t[r>>2]=e;t[n>>2]=0;t[f>>2]=0;t[u>>2]=0;t[n>>2]=(t[(t[(t[r>>2]|0)+64>>2]|0)+48>>2]&134217728|0)!=0?1:0;if(t[n>>2]|0){t[f>>2]=(t[(t[(t[r>>2]|0)+64>>2]|0)+48>>2]&2097152|0)!=0?1:0;t[u>>2]=(t[(t[(t[r>>2]|0)+64>>2]|0)+48>>2]&268435456|0)!=0?1:0}e:do if(t[(t[r>>2]|0)+68>>2]|0){t[a>>2]=t[(t[r>>2]|0)+68>>2];while(1){if(!(t[a>>2]|0))break e;e=t[t[a>>2]>>2]|0;if((e|0)==1007){t[f>>2]=1;t[u>>2]=1;t[n>>2]=1}else if((e|0)==1006){t[u>>2]=1;t[n>>2]=1}else if((e|0)!=1008)t[n>>2]=1;t[a>>2]=t[(t[a>>2]|0)+4>>2]}}while(0);if(t[u>>2]|0){u=(t[r>>2]|0)+48|0;t[u>>2]=t[u>>2]|268435456}if(t[f>>2]|0){u=(t[r>>2]|0)+48|0;t[u>>2]=t[u>>2]|2097152}if(t[n>>2]|0){u=(t[r>>2]|0)+48|0;t[u>>2]=t[u>>2]|134217728}if((t[n>>2]|0)==0|(t[f>>2]|0)!=0){s=i;return}if(!(t[(t[r>>2]|0)+48>>2]&256)){s=i;return}t[o>>2]=yd(t[r>>2]|0)|0;if((t[(t[o>>2]|0)+88>>2]|0)==46){s=i;return}if((t[(t[o>>2]|0)+88>>2]|0)==1){s=i;return}o=(t[r>>2]|0)+48|0;t[o>>2]=t[o>>2]|2097152;s=i;return}function gv(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0;r=s;s=s+16|0;n=r+8|0;f=r+4|0;u=r;t[f>>2]=e;t[u>>2]=i;do if(!(t[f>>2]|0))t[n>>2]=0;else{if((t[t[f>>2]>>2]|0)!=5?(t[(t[f>>2]|0)+88>>2]|0)!=45:0){i=t[f>>2]|0;if((t[t[f>>2]>>2]|0)!=1){t[n>>2]=gv(t[i+28>>2]|0,t[u>>2]|0)|0;break}if((t[i+88>>2]|0)==(t[u>>2]|0)){t[n>>2]=1;break}if((t[(t[f>>2]|0)+88>>2]|0)!=46?(t[(t[f>>2]|0)+88>>2]|0)!=45:0){t[n>>2]=gv(t[(t[f>>2]|0)+28>>2]|0,t[u>>2]|0)|0;break}t[n>>2]=0;break}t[n>>2]=0}while(0);s=r;return t[n>>2]|0}function yv(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0;r=s;s=s+16|0;n=r+12|0;f=r+8|0;u=r+4|0;a=r;t[f>>2]=e;t[u>>2]=i;if((t[t[f>>2]>>2]|0)!=0?(t[u>>2]|0)<(t[(t[f>>2]|0)+4>>2]|0):0){do if((t[(t[f>>2]|0)+4>>2]|0)==1){pAi[t[135736>>2]&511](t[t[f>>2]>>2]|0);t[t[f>>2]>>2]=0;t[(t[f>>2]|0)+4>>2]=0;t[(t[f>>2]|0)+8>>2]=0}else{if(((t[(t[f>>2]|0)+4>>2]|0)-1|0)==(t[u>>2]|0)){i=(t[f>>2]|0)+4|0;t[i>>2]=(t[i>>2]|0)+-1;break}t[a>>2]=t[u>>2];while(1){if((t[a>>2]|0)>=((t[(t[f>>2]|0)+4>>2]|0)-1|0))break;t[(t[t[f>>2]>>2]|0)+(t[a>>2]<<2)>>2]=t[(t[t[f>>2]>>2]|0)+((t[a>>2]|0)+1<<2)>>2];t[a>>2]=(t[a>>2]|0)+1}i=(t[f>>2]|0)+4|0;t[i>>2]=(t[i>>2]|0)+-1}while(0);t[n>>2]=0;o=t[n>>2]|0;s=r;return o|0}kL(152576);t[n>>2]=-1;o=t[n>>2]|0;s=r;return o|0}function Fv(e,i,r,n,f,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;u=u|0;a=a|0;o=o|0;var c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0,S=0,g=0,y=0,F=0,O=0,A=0,M=0,R=0,N=0,T=0,L=0,D=0,C=0,P=0,B=0,I=0,H=0,x=0;c=s;s=s+112|0;l=c+108|0;b=c+104|0;k=c+100|0;h=c+96|0;w=c+92|0;d=c+88|0;v=c+84|0;m=c+80|0;_=c+76|0;p=c+72|0;E=c+68|0;S=c+64|0;g=c+60|0;y=c+56|0;F=c+52|0;O=c+48|0;A=c+44|0;M=c+40|0;R=c+36|0;N=c+32|0;T=c+28|0;L=c+24|0;D=c+20|0;C=c+16|0;P=c+12|0;B=c+8|0;I=c+4|0;H=c;t[b>>2]=e;t[k>>2]=i;t[h>>2]=r;t[w>>2]=n;t[d>>2]=f;t[v>>2]=u;t[m>>2]=a;t[_>>2]=o;t[p>>2]=0;e:do if(t[d>>2]|0){t[S>>2]=0;while(1){if((t[S>>2]|0)>=(t[(t[d>>2]|0)+4>>2]|0))break e;t[p>>2]=t[(t[t[d>>2]>>2]|0)+(t[S>>2]<<2)>>2];t[y>>2]=0;i:do if(t[v>>2]|0){t[g>>2]=0;while(1){if((t[g>>2]|0)>=(t[(t[v>>2]|0)+4>>2]|0))break i;t[E>>2]=t[(t[t[v>>2]>>2]|0)+(t[g>>2]<<2)>>2];if((t[(t[(t[p>>2]|0)+12>>2]|0)+8>>2]|0)==(t[(t[(t[E>>2]|0)+12>>2]|0)+8>>2]|0)?(t[(t[(t[p>>2]|0)+12>>2]|0)+56>>2]|0)==(t[(t[(t[E>>2]|0)+12>>2]|0)+56>>2]|0):0)break;t[g>>2]=(t[g>>2]|0)+1}t[y>>2]=1;if((t[(t[p>>2]|0)+24>>2]|0)==2?(t[(t[E>>2]|0)+24>>2]|0)==1:0){t[A>>2]=0;o=t[b>>2]|0;a=lw(t[h>>2]|0)|0;u=t[h>>2]|0;f=t[p>>2]|0;n=(t[k>>2]|0)==0?151424:151432;hL(o,1788,a,u,f,151312,n,Nd(A,t[w>>2]|0)|0,0,0);if(!(t[A>>2]|0))break;pAi[t[135736>>2]&511](t[A>>2]|0);t[A>>2]=0;break}if(!(lL(t[b>>2]|0,t[(t[(t[p>>2]|0)+12>>2]|0)+48>>2]|0,t[(t[(t[E>>2]|0)+12>>2]|0)+48>>2]|0,0)|0)){wL(t[E>>2]|0,O,F,0)|0;if(!((t[F>>2]|0)!=0&(t[O>>2]|0)==1))break;t[T>>2]=0;wL(t[E>>2]|0,O,T,0)|0;if((t[O>>2]|0)!=0?(t[T>>2]|0)==(t[F>>2]|0):0)break;t[L>>2]=0;n=t[b>>2]|0;f=lw(t[h>>2]|0)|0;u=t[h>>2]|0;a=t[p>>2]|0;o=(t[k>>2]|0)==0?151424:151432;hL(n,3077,f,u,a,151576,o,Nd(L,t[w>>2]|0)|0,0,0);if(!(t[L>>2]|0))break;pAi[t[135736>>2]&511](t[L>>2]|0);t[L>>2]=0;break}t[M>>2]=0;t[R>>2]=0;t[N>>2]=0;o=t[b>>2]|0;a=lw(t[h>>2]|0)|0;u=t[h>>2]|0;f=t[p>>2]|0;n=Nd(M,t[(t[(t[p>>2]|0)+12>>2]|0)+48>>2]|0)|0;r=Nd(R,t[(t[(t[E>>2]|0)+12>>2]|0)+48>>2]|0)|0;i=(t[k>>2]|0)==0?151424:151432;hL(o,1789,a,u,f,151448,n,r,i,Nd(N,t[w>>2]|0)|0);if(t[M>>2]|0){pAi[t[135736>>2]&511](t[M>>2]|0);t[M>>2]=0}if(t[R>>2]|0){pAi[t[135736>>2]&511](t[R>>2]|0);t[R>>2]=0}if(t[N>>2]|0){pAi[t[135736>>2]&511](t[N>>2]|0);t[N>>2]=0}}while(0);do if(!(t[y>>2]|0)){if((t[_>>2]|0)!=0?(dL(t[_>>2]|0,t[(t[(t[p>>2]|0)+12>>2]|0)+56>>2]|0)|0)==0:0)break;t[D>>2]=0;i=t[b>>2]|0;r=lw(t[h>>2]|0)|0;n=t[h>>2]|0;f=t[p>>2]|0;u=(t[k>>2]|0)==0?151424:151432;hL(i,1790,r,n,f,151680,u,Nd(D,t[w>>2]|0)|0,0,0);if(t[D>>2]|0){pAi[t[135736>>2]&511](t[D>>2]|0);t[D>>2]=0}}while(0);t[S>>2]=(t[S>>2]|0)+1}}while(0);e:do if(t[v>>2]|0){t[g>>2]=0;while(1){if((t[g>>2]|0)>=(t[(t[v>>2]|0)+4>>2]|0))break e;t[E>>2]=t[(t[t[v>>2]>>2]|0)+(t[g>>2]<<2)>>2];if((t[(t[E>>2]|0)+24>>2]|0)==1){t[y>>2]=0;i:do if(t[d>>2]|0){t[S>>2]=0;while(1){if((t[S>>2]|0)>=(t[(t[d>>2]|0)+4>>2]|0))break i;t[p>>2]=t[(t[t[d>>2]>>2]|0)+(t[S>>2]<<2)>>2];if((t[(t[(t[p>>2]|0)+12>>2]|0)+8>>2]|0)==(t[(t[(t[E>>2]|0)+12>>2]|0)+8>>2]|0)?(t[(t[(t[p>>2]|0)+12>>2]|0)+56>>2]|0)==(t[(t[(t[E>>2]|0)+12>>2]|0)+56>>2]|0):0)break;t[S>>2]=(t[S>>2]|0)+1}t[y>>2]=1}while(0);if(!(t[y>>2]|0)){t[C>>2]=0;t[P>>2]=0;D=t[b>>2]|0;N=t[h>>2]|0;R=Nd(C,t[E>>2]|0)|0;M=(t[k>>2]|0)==0?151424:151432;ah(D,1791,0,N,151760,R,M,Nd(P,t[w>>2]|0)|0,0);if(t[C>>2]|0){pAi[t[135736>>2]&511](t[C>>2]|0);t[C>>2]=0}if(t[P>>2]|0){pAi[t[135736>>2]&511](t[P>>2]|0);t[P>>2]=0}}}t[g>>2]=(t[g>>2]|0)+1}}while(0);do if(t[m>>2]|0){if(!(t[_>>2]|0)){t[B>>2]=0;g=t[b>>2]|0;P=t[h>>2]|0;C=vd(t[h>>2]|0)|0;E=(t[k>>2]|0)==0?151424:151432;y=vd(t[w>>2]|0)|0;ah(g,1797,0,P,151832,C,E,y,Rd(B,t[w>>2]|0)|0);if(t[B>>2]|0){pAi[t[135736>>2]&511](t[B>>2]|0);t[B>>2]=0}t[l>>2]=t[(t[b>>2]|0)+16>>2];x=t[l>>2]|0;s=c;return x|0}if((t[(t[_>>2]|0)+28>>2]|0)==0?(vL(t[m>>2]|0,t[_>>2]|0)|0)!=0:0){t[I>>2]=0;y=t[b>>2]|0;E=t[h>>2]|0;C=(t[k>>2]|0)==0?151424:151432;P=vd(t[w>>2]|0)|0;ah(y,1798,0,E,151904,C,P,Rd(I,t[w>>2]|0)|0,0);if(t[I>>2]|0){pAi[t[135736>>2]&511](t[I>>2]|0);t[I>>2]=0}t[l>>2]=t[(t[b>>2]|0)+16>>2];x=t[l>>2]|0;s=c;return x|0}if((t[t[w>>2]>>2]|0)==1?(t[(t[w>>2]|0)+88>>2]|0)==45:0)break;if((t[(t[m>>2]|0)+24>>2]|0)<(t[(t[_>>2]|0)+24>>2]|0)){t[H>>2]=0;P=t[b>>2]|0;C=t[w>>2]|0;E=(t[k>>2]|0)==0?151424:151432;y=vd(t[w>>2]|0)|0;ah(P,1799,0,C,151984,E,y,Rd(H,t[w>>2]|0)|0,0);if(t[H>>2]|0){pAi[t[135736>>2]&511](t[H>>2]|0);t[H>>2]=0}t[l>>2]=t[(t[b>>2]|0)+16>>2];x=t[l>>2]|0;s=c;return x|0}}while(0);t[l>>2]=0;x=t[l>>2]|0;s=c;return x|0}function Ov(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0;r=s;s=s+48|0;n=r+32|0;f=r+28|0;u=r+24|0;a=r+20|0;o=r+16|0;c=r+12|0;l=r+8|0;b=r+4|0;k=r;t[f>>2]=e;t[u>>2]=i;t[o>>2]=0;t[a>>2]=t[(t[u>>2]|0)+64>>2];if((t[(t[u>>2]|0)+52>>2]|0)!=4?(t[(t[u>>2]|0)+52>>2]|0)!=6:0){if((t[t[a>>2]>>2]|0)!=5?(t[(t[a>>2]|0)+88>>2]|0)!=45:0){t[c>>2]=0;i=t[f>>2]|0;e=t[u>>2]|0;h=t[(t[u>>2]|0)+36>>2]|0;sv(i,3076,e,h,153352,uh(c,t[(t[a>>2]|0)+112>>2]|0,t[(t[a>>2]|0)+8>>2]|0)|0);if(t[c>>2]|0){pAi[t[135736>>2]&511](t[c>>2]|0);t[c>>2]=0}t[n>>2]=3076;w=t[n>>2]|0;s=r;return w|0}}else{do if((t[t[a>>2]>>2]|0)!=4){if((t[t[a>>2]>>2]|0)==1?(t[(t[a>>2]|0)+88>>2]|0)!=45:0){d=11;break}if((t[(t[a>>2]|0)+52>>2]|0)!=4?(t[(t[a>>2]|0)+52>>2]|0)!=6:0){if((t[(t[a>>2]|0)+52>>2]|0)==3?(t[(t[u>>2]|0)+48>>2]&4|0)!=0:0){if(!(mL(t[(t[a>>2]|0)+28>>2]|0)|0)){t[o>>2]=3076;break}if(t[(t[u>>2]|0)+104>>2]|0)break;t[b>>2]=0;c=t[f>>2]|0;h=t[u>>2]|0;sv(c,3076,h,0,153664,uh(b,t[(t[a>>2]|0)+112>>2]|0,t[(t[a>>2]|0)+8>>2]|0)|0);if(t[b>>2]|0){pAi[t[135736>>2]&511](t[b>>2]|0);t[b>>2]=0}t[n>>2]=3076;w=t[n>>2]|0;s=r;return w|0}t[o>>2]=3076;break}if(!(t[(t[a>>2]|0)+104>>2]|0)){sv(t[f>>2]|0,3069,t[u>>2]|0,0,153584,t[(t[u>>2]|0)+8>>2]|0);t[n>>2]=-1;w=t[n>>2]|0;s=r;return w|0}}else d=11;while(0);if((d|0)==11?(t[(t[u>>2]|0)+48>>2]&2|0)==0:0){t[l>>2]=0;d=t[f>>2]|0;b=t[u>>2]|0;sv(d,3076,b,0,153464,uh(l,t[(t[a>>2]|0)+112>>2]|0,t[(t[a>>2]|0)+8>>2]|0)|0);if(t[l>>2]|0){pAi[t[135736>>2]&511](t[l>>2]|0);t[l>>2]=0}t[n>>2]=3076;w=t[n>>2]|0;s=r;return w|0}if((t[o>>2]|0)>0){t[k>>2]=0;l=(t[(t[u>>2]|0)+48>>2]&4|0)!=0;b=t[f>>2]|0;f=t[u>>2]|0;u=uh(k,t[(t[a>>2]|0)+112>>2]|0,t[(t[a>>2]|0)+8>>2]|0)|0;if(l)sv(b,3076,f,0,153800,u);else sv(b,3076,f,0,153984,u);if(t[k>>2]|0){pAi[t[135736>>2]&511](t[k>>2]|0);t[k>>2]=0}}}t[n>>2]=t[o>>2];w=t[n>>2]|0;s=r;return w|0}function Av(e,i,r,n,f,u,a){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;u=u|0;a=a|0;var o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0;o=s;s=s+48|0;c=o+32|0;l=o+28|0;b=o+24|0;k=o+20|0;h=o+16|0;w=o+12|0;d=o+8|0;v=o+4|0;m=o;t[l>>2]=e;t[b>>2]=i;t[k>>2]=r;t[h>>2]=n;t[w>>2]=f;t[d>>2]=u;t[v>>2]=a;t[m>>2]=0;if((t[l>>2]|0)==0|(t[b>>2]|0)==0){t[c>>2]=0;_=t[c>>2]|0;s=o;return _|0}t[m>>2]=gAi[t[135744>>2]&511](120)|0;if(!(t[m>>2]|0)){Qh(t[l>>2]|0,153304,0);t[c>>2]=0;_=t[c>>2]|0;s=o;return _|0}b=(t[m>>2]|0)+0|0;a=b+120|0;do{t[b>>2]=0;b=b+4|0}while((b|0)<(a|0));t[t[m>>2]>>2]=t[k>>2];t[(t[m>>2]|0)+8>>2]=t[h>>2];t[(t[m>>2]|0)+112>>2]=t[w>>2];t[(t[m>>2]|0)+36>>2]=t[d>>2];d=t[l>>2]|0;if(t[v>>2]|0){do if(t[d+100>>2]|0){v=_L(t[l>>2]|0,t[(t[l>>2]|0)+116>>2]|0,t[m>>2]|0,t[h>>2]|0,t[w>>2]|0)|0;t[(t[l>>2]|0)+120>>2]=v;if(t[(t[l>>2]|0)+120>>2]|0){t[(t[l>>2]|0)+124>>2]=0;break}pAi[t[135736>>2]&511](t[m>>2]|0);t[c>>2]=0;_=t[c>>2]|0;s=o;return _|0}while(0);qT((t[(t[(t[l>>2]|0)+28>>2]|0)+16>>2]|0)+44|0,5,t[m>>2]|0)|0}else qT((t[(t[d+28>>2]|0)+16>>2]|0)+48|0,10,t[m>>2]|0)|0;qT((t[(t[l>>2]|0)+28>>2]|0)+20|0,10,t[m>>2]|0)|0;t[c>>2]=t[m>>2];_=t[c>>2]|0;s=o;return _|0}function Mv(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0;f=s;s=s+32|0;u=f+20|0;a=f+16|0;o=f+12|0;c=f+8|0;l=f+4|0;b=f;t[a>>2]=e;t[o>>2]=i;t[c>>2]=r;t[l>>2]=n;t[b>>2]=0;if(!(t[a>>2]|0)){t[u>>2]=0;k=t[u>>2]|0;s=f;return k|0}t[b>>2]=gAi[t[135744>>2]&511](28)|0;if(!(t[b>>2]|0)){Qh(t[a>>2]|0,153120,0);t[u>>2]=0;k=t[u>>2]|0;s=f;return k|0}else{t[t[b>>2]>>2]=25;t[(t[b>>2]|0)+4>>2]=0;t[(t[b>>2]|0)+24>>2]=t[o>>2];t[(t[b>>2]|0)+16>>2]=t[c>>2];t[(t[b>>2]|0)+20>>2]=t[l>>2];t[(t[b>>2]|0)+8>>2]=0;t[(t[b>>2]|0)+12>>2]=0;qT((t[(t[(t[a>>2]|0)+28>>2]|0)+16>>2]|0)+48|0,10,t[b>>2]|0)|0;t[u>>2]=t[b>>2];k=t[u>>2]|0;s=f;return k|0}return 0}function Rv(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0;f=s;s=s+32|0;u=f+20|0;a=f+16|0;o=f+12|0;c=f+8|0;l=f+4|0;b=f;t[a>>2]=e;t[o>>2]=i;t[c>>2]=r;t[l>>2]=n;t[b>>2]=0;if((t[a>>2]|0)==0|(t[o>>2]|0)==0){t[u>>2]=0;k=t[u>>2]|0;s=f;return k|0}t[b>>2]=gAi[t[135744>>2]&511](20)|0;if(!(t[b>>2]|0)){Qh(t[a>>2]|0,153080,0);t[u>>2]=0;k=t[u>>2]|0;s=f;return k|0}o=t[b>>2]|0;t[o+0>>2]=0;t[o+4>>2]=0;t[o+8>>2]=0;t[o+12>>2]=0;t[o+16>>2]=0;t[t[b>>2]>>2]=t[c>>2];t[(t[b>>2]|0)+16>>2]=t[l>>2];qT((t[(t[(t[a>>2]|0)+28>>2]|0)+16>>2]|0)+48|0,10,t[b>>2]|0)|0;if((t[c>>2]|0)==6|(t[c>>2]|0)==7)qT((t[(t[a>>2]|0)+28>>2]|0)+20|0,10,t[b>>2]|0)|0;t[u>>2]=t[b>>2];k=t[u>>2]|0;s=f;return k|0}function Nv(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0;r=s;s=s+64|0;n=r+48|0;f=r+44|0;u=r+40|0;a=r+36|0;o=r+32|0;c=r+28|0;l=r+24|0;b=r+20|0;k=r+16|0;h=r+12|0;w=r+8|0;d=r+4|0;v=r;t[f>>2]=e;t[u>>2]=i;t[a>>2]=0;t[b>>2]=0;if(!(t[(t[u>>2]|0)+64>>2]|0)){rh(t[f>>2]|0,152632,152664);t[n>>2]=-1;m=t[n>>2]|0;s=r;return m|0}t[a>>2]=t[(t[u>>2]|0)+64>>2];if(((t[t[a>>2]>>2]|0)!=1?(t[(t[a>>2]|0)+48>>2]&4194304|0)==0:0)?(wv(t[a>>2]|0,t[f>>2]|0)|0)==-1:0){t[n>>2]=-1;m=t[n>>2]|0;s=r;return m|0}t[c>>2]=t[(t[u>>2]|0)+116>>2];t[l>>2]=t[(t[a>>2]|0)+116>>2];do if(t[c>>2]|0){i=t[f>>2]|0;e=t[u>>2]|0;_=(t[u>>2]|0)+84|0;p=t[c>>2]|0;if(!(t[(t[u>>2]|0)+48>>2]&4)){if((kv(i,e,_,p,0)|0)!=-1)break;rh(t[f>>2]|0,152632,152680);break}if((kv(i,e,_,p,t[(t[f>>2]|0)+128>>2]|0)|0)==-1)rh(t[f>>2]|0,152632,152680);if(t[(t[(t[f>>2]|0)+128>>2]|0)+4>>2]|0)t[b>>2]=t[(t[f>>2]|0)+128>>2]}while(0);e:do if(t[l>>2]|0){if(!(t[(t[u>>2]|0)+48>>2]&4)){t[k>>2]=0;while(1){if((t[k>>2]|0)>=(t[(t[l>>2]|0)+4>>2]|0)){E=45;break e}t[o>>2]=t[(t[t[l>>2]>>2]|0)+(t[k>>2]<<2)>>2];if(!(t[c>>2]|0)){p=hh()|0;t[(t[u>>2]|0)+116>>2]=p;if(!(t[(t[u>>2]|0)+116>>2]|0))break e;t[c>>2]=t[(t[u>>2]|0)+116>>2]}rL(t[c>>2]|0,t[(t[l>>2]|0)+4>>2]|0,t[o>>2]|0)|0;t[k>>2]=(t[k>>2]|0)+1}}if(t[c>>2]|0)t[d>>2]=t[(t[c>>2]|0)+4>>2];else t[d>>2]=0;t[k>>2]=0;while(1){if((t[k>>2]|0)>=(t[(t[l>>2]|0)+4>>2]|0)){E=45;break e}t[o>>2]=t[(t[t[l>>2]>>2]|0)+(t[k>>2]<<2)>>2];i:do if(t[b>>2]|0){t[h>>2]=0;while(1){if((t[h>>2]|0)>=(t[(t[b>>2]|0)+4>>2]|0)){E=28;break i}t[w>>2]=t[(t[t[b>>2]>>2]|0)+(t[h>>2]<<2)>>2];if((t[(t[(t[o>>2]|0)+12>>2]|0)+8>>2]|0)==(t[(t[w>>2]|0)+8>>2]|0)?(t[(t[(t[o>>2]|0)+12>>2]|0)+56>>2]|0)==(t[(t[w>>2]|0)+12>>2]|0):0)break i;t[h>>2]=(t[h>>2]|0)+1}}else E=28;while(0);i:do if((E|0)==28){E=0;r:do if(t[d>>2]|0){t[h>>2]=0;while(1){if((t[h>>2]|0)>=(t[d>>2]|0))break r;t[v>>2]=t[(t[t[c>>2]>>2]|0)+(t[h>>2]<<2)>>2];if((t[(t[(t[o>>2]|0)+12>>2]|0)+8>>2]|0)==(t[(t[(t[v>>2]|0)+12>>2]|0)+8>>2]|0)?(t[(t[(t[o>>2]|0)+12>>2]|0)+56>>2]|0)==(t[(t[(t[v>>2]|0)+12>>2]|0)+56>>2]|0):0)break i;t[h>>2]=(t[h>>2]|0)+1}}while(0);if(!(t[c>>2]|0)){p=hh()|0;t[(t[u>>2]|0)+116>>2]=p;if(!(t[(t[u>>2]|0)+116>>2]|0))break e;t[c>>2]=t[(t[u>>2]|0)+116>>2]}rL(t[c>>2]|0,2,t[o>>2]|0)|0}while(0);t[k>>2]=(t[k>>2]|0)+1}}else E=45;while(0);e:do if((E|0)==45){if((t[c>>2]|0)!=0?(t[(t[c>>2]|0)+4>>2]|0)==0:0){Wk(t[c>>2]|0);t[(t[u>>2]|0)+116>>2]=0}do if((t[(t[u>>2]|0)+48>>2]&2|0)!=0?(t[(t[a>>2]|0)+84>>2]|0)!=0:0)if(t[(t[u>>2]|0)+84>>2]|0)if((pL(t[f>>2]|0,t[(t[u>>2]|0)+84>>2]|0,t[(t[a>>2]|0)+84>>2]|0)|0)==-1)break e;else break;else{t[(t[u>>2]|0)+84>>2]=t[(t[a>>2]|0)+84>>2];break}while(0);t[n>>2]=0;m=t[n>>2]|0;s=r;return m|0}while(0);t[n>>2]=-1;m=t[n>>2]|0;s=r;return m|0}function Tv(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0;r=s;s=s+16|0;n=r+12|0;f=r+8|0;u=r+4|0;a=r;t[f>>2]=e;t[u>>2]=i;t[a>>2]=EL(t[f>>2]|0,t[u>>2]|0)|0;if(t[a>>2]|0){t[n>>2]=t[a>>2];o=t[n>>2]|0;s=r;return o|0}i=t[f>>2]|0;f=t[u>>2]|0;if(t[(t[u>>2]|0)+48>>2]&2)t[a>>2]=SL(i,f)|0;else t[a>>2]=gL(i,f)|0;t[n>>2]=t[a>>2];o=t[n>>2]|0;s=r;return o|0}function Lv(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0,S=0;r=s;s=s+64|0;n=r+56|0;f=r+52|0;u=r+48|0;a=r+44|0;o=r+40|0;c=r+36|0;l=r+32|0;b=r+28|0;k=r+24|0;h=r+20|0;w=r+16|0;d=r+12|0;v=r+8|0;m=r+4|0;_=r;t[f>>2]=e;t[u>>2]=i;t[a>>2]=0;t[o>>2]=t[(t[u>>2]|0)+28>>2];if(t[(t[u>>2]|0)+80>>2]|0){t[c>>2]=t[(t[u>>2]|0)+80>>2];Zw(t[c>>2]|0,t[f>>2]|0);if(!(t[(t[u>>2]|0)+48>>2]&2)){sv(t[f>>2]|0,3046,t[u>>2]|0,0,158528,0);t[a>>2]=3046}i=t[c>>2]|0;do if((t[c>>2]|0)!=(t[u>>2]|0))if(t[i+80>>2]|0){t[l>>2]=yL(t[c>>2]|0,t[c>>2]|0)|0;break}else{t[l>>2]=0;break}else t[l>>2]=i;while(0);if(t[l>>2]|0){t[b>>2]=0;t[k>>2]=0;i=t[f>>2]|0;e=t[l>>2]|0;p=Rd(b,t[l>>2]|0)|0;iL(i,3049,e,0,158608,p,Rd(k,t[c>>2]|0)|0,0);if(t[b>>2]|0){pAi[t[135736>>2]&511](t[b>>2]|0);t[b>>2]=0}if(t[k>>2]|0){pAi[t[135736>>2]&511](t[k>>2]|0);t[k>>2]=0}t[a>>2]=3049}if((t[o>>2]|0)!=(t[(t[(t[u>>2]|0)+80>>2]|0)+28>>2]|0)){t[h>>2]=0;if(t[(t[c>>2]|0)+48>>2]&32768)t[h>>2]=t[h>>2]|2;if(t[(t[c>>2]|0)+48>>2]&65536)t[h>>2]=t[h>>2]|1;if(FL(t[f>>2]|0,t[o>>2]|0,t[(t[c>>2]|0)+28>>2]|0,t[h>>2]|0)|0){t[w>>2]=0;t[d>>2]=0;t[v>>2]=0;t[a>>2]=3047;h=t[f>>2]|0;k=t[u>>2]|0;b=Rd(w,t[o>>2]|0)|0;p=Rd(d,t[c>>2]|0)|0;iL(h,3047,k,0,158704,b,p,Rd(v,t[(t[c>>2]|0)+28>>2]|0)|0);if(t[w>>2]|0){pAi[t[135736>>2]&511](t[w>>2]|0);t[w>>2]=0}if(t[d>>2]|0){pAi[t[135736>>2]&511](t[d>>2]|0);t[d>>2]=0}if(t[v>>2]|0){pAi[t[135736>>2]&511](t[v>>2]|0);t[v>>2]=0}}}}do if(t[(t[u>>2]|0)+76>>2]|0){if((t[t[o>>2]>>2]|0)!=4)if((t[t[o>>2]>>2]|0)==1?(t[(t[o>>2]|0)+88>>2]|0)!=45:0)E=31;else E=32;else E=31;if((E|0)==31?(gv(t[o>>2]|0,23)|0)==0:0)E=32;if((E|0)==32){if((t[t[o>>2]>>2]|0)!=5?(t[(t[o>>2]|0)+88>>2]|0)!=45:0){E=38;break}if((t[(t[o>>2]|0)+52>>2]|0)!=4?(t[(t[o>>2]|0)+52>>2]|0)!=6:0){E=38;break}if(!(gv(t[(t[o>>2]|0)+104>>2]|0,23)|0)){E=38;break}}t[a>>2]=3048;sv(t[f>>2]|0,3048,t[u>>2]|0,0,158848,0)}else E=38;while(0);if((E|0)==38?(t[(t[u>>2]|0)+76>>2]|0)!=0:0){t[_>>2]=0;if(!(t[o>>2]|0)){pw(t[f>>2]|0,t[(t[u>>2]|0)+36>>2]|0,3069,159008,0,0);t[n>>2]=-1;S=t[n>>2]|0;s=r;return S|0}do if(t[(t[u>>2]|0)+36>>2]|0){E=t[(t[u>>2]|0)+36>>2]|0;if(t[(t[u>>2]|0)+48>>2]&8){t[_>>2]=dF(E,159120)|0;break}else{t[_>>2]=dF(E,159128)|0;break}}while(0);t[m>>2]=OL(t[f>>2]|0,t[_>>2]|0,t[o>>2]|0,t[(t[u>>2]|0)+76>>2]|0,(t[u>>2]|0)+96|0)|0;if(t[m>>2]|0)if((t[m>>2]|0)<0){rh(t[f>>2]|0,159136,159168);t[n>>2]=-1;S=t[n>>2]|0;s=r;return S|0}else{t[n>>2]=t[m>>2];S=t[n>>2]|0;s=r;return S|0}}t[n>>2]=t[a>>2];S=t[n>>2]|0;s=r;return S|0}function Dv(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0;r=s;s=s+32|0;n=r+24|0;f=r+20|0;u=r+16|0;a=r+12|0;o=r+8|0;c=r+4|0;l=r;t[n>>2]=e;t[f>>2]=i;if(!(t[(t[f>>2]|0)+80>>2]|0)){s=r;return}if(t[(t[f>>2]|0)+48>>2]&16){s=r;return}t[u>>2]=t[(t[f>>2]|0)+80>>2];while(1){if(!(t[u>>2]|0))break;t[c>>2]=0;t[l>>2]=0;do if(!(t[(t[u>>2]|0)+48>>2]&8192)){t[a>>2]=t[(t[u>>2]|0)+28>>2];t[o>>2]=t[(t[f>>2]|0)+28>>2];if((t[a>>2]|0)!=(t[o>>2]|0)){if(t[(t[u>>2]|0)+48>>2]&4096)t[c>>2]=t[c>>2]|524288;if(t[(t[u>>2]|0)+48>>2]&2048)t[c>>2]=t[c>>2]|262144;while(1){if(!(t[o>>2]|0))break;if((t[o>>2]|0)==(t[a>>2]|0))break;if((t[(t[o>>2]|0)+48>>2]&2|0)!=0?(t[l>>2]&524288|0)==0:0)t[l>>2]=t[l>>2]|262144;if((t[(t[o>>2]|0)+48>>2]&4|0)!=0?(t[l>>2]&524288|0)==0:0)t[l>>2]=t[l>>2]|524288;t[o>>2]=t[(t[o>>2]|0)+64>>2]}t[o>>2]=t[(t[(t[f>>2]|0)+28>>2]|0)+64>>2];while(1){if(!(t[o>>2]|0))break;if((t[t[o>>2]>>2]|0)!=5?(t[(t[o>>2]|0)+88>>2]|0)!=45:0)break;if((t[(t[o>>2]|0)+48>>2]&262144|0)!=0?(t[c>>2]&262144|0)==0:0)t[c>>2]=t[c>>2]|262144;if((t[(t[o>>2]|0)+48>>2]&524288|0)!=0?(t[c>>2]&524288|0)==0:0)t[c>>2]=t[c>>2]|524288;if((t[o>>2]|0)==(t[a>>2]|0))break;t[o>>2]=t[(t[o>>2]|0)+64>>2]}if(t[c>>2]|0){if((t[c>>2]&262144|0)!=0?(t[l>>2]&262144|0)!=0:0)break;if((t[c>>2]&524288|0)!=0?(t[l>>2]&524288|0)!=0:0)break}}AL(t[n>>2]|0,t[u>>2]|0,t[f>>2]|0)|0;if(!(t[(t[u>>2]|0)+48>>2]&131072)){i=(t[u>>2]|0)+48|0;t[i>>2]=t[i>>2]|131072}}while(0);t[u>>2]=t[(t[u>>2]|0)+80>>2]}s=r;return}function Cv(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0,S=0,g=0,y=0,F=0,O=0,A=0,M=0,R=0,N=0,T=0,L=0,D=0,C=0,P=0,B=0,I=0,H=0,x=0,U=0,z=0,j=0,V=0,q=0,Y=0,G=0,W=0,K=0;r=s;s=s+128|0;n=r+124|0;f=r+120|0;u=r+116|0;a=r+112|0;o=r+108|0;c=r+104|0;l=r+100|0;b=r+96|0;k=r+92|0;h=r+88|0;w=r+84|0;d=r+80|0;v=r+76|0;m=r+72|0;_=r+68|0;p=r+64|0;E=r+60|0;S=r+56|0;g=r+52|0;y=r+48|0;F=r+44|0;O=r+40|0;A=r+36|0;M=r+32|0;R=r+28|0;N=r+24|0;T=r+20|0;L=r+16|0;D=r+12|0;C=r+8|0;P=r+4|0;B=r;t[f>>2]=e;t[u>>2]=i;t[a>>2]=0;if(!(t[u>>2]|0)){rh(t[f>>2]|0,158112,158144);t[n>>2]=1;I=t[n>>2]|0;s=r;return I|0}if(!(t[(t[u>>2]|0)+12>>2]|0)){t[n>>2]=1;I=t[n>>2]|0;s=r;return I|0}e:do switch(t[t[(t[u>>2]|0)+12>>2]>>2]|0){case 8:{t[a>>2]=1;t[C>>2]=t[(t[(t[u>>2]|0)+12>>2]|0)+12>>2];if(t[C>>2]|0){t[a>>2]=0;t[L>>2]=t[(t[f>>2]|0)+76>>2];t[D>>2]=kb(t[(t[f>>2]|0)+64>>2]|0)|0;hb(t[(t[f>>2]|0)+64>>2]|0,t[(t[f>>2]|0)+76>>2]|0,t[D>>2]|0)|0;t[(t[f>>2]|0)+76>>2]=t[D>>2];while(1){if(!(t[C>>2]|0)){H=103;break}t[(t[f>>2]|0)+76>>2]=t[D>>2];t[P>>2]=t[(t[C>>2]|0)+12>>2];if(!(t[P>>2]|0)){H=93;break}do if(!(t[(t[P>>2]|0)+48>>2]&131072)){if((t[(t[C>>2]|0)+16>>2]|0)==1?(t[(t[C>>2]|0)+20>>2]|0)==1:0){bb(t[(t[f>>2]|0)+64>>2]|0,t[(t[f>>2]|0)+76>>2]|0,t[(t[f>>2]|0)+76>>2]|0,t[(t[P>>2]|0)+8>>2]|0,t[(t[P>>2]|0)+52>>2]|0,1,1,t[P>>2]|0)|0;break}if((t[(t[C>>2]|0)+16>>2]|0)==0?(t[(t[C>>2]|0)+20>>2]|0)==1:0)sb(t[(t[f>>2]|0)+64>>2]|0,t[(t[f>>2]|0)+76>>2]|0,t[(t[f>>2]|0)+76>>2]|0,t[(t[P>>2]|0)+8>>2]|0,t[(t[P>>2]|0)+52>>2]|0,0,1,t[P>>2]|0)|0}else{t[B>>2]=db(t[(t[f>>2]|0)+64>>2]|0,t[(t[C>>2]|0)+16>>2]|0,t[(t[C>>2]|0)+20>>2]|0)|0;RL(t[f>>2]|0,t[C>>2]|0,t[B>>2]|0,t[(t[f>>2]|0)+76>>2]|0)|0}while(0);t[C>>2]=t[(t[C>>2]|0)+8>>2]}if((H|0)==93){rh(t[f>>2]|0,158112,158168);t[n>>2]=t[a>>2];I=t[n>>2]|0;s=r;return I|0}else if((H|0)==103){i=wb(t[(t[f>>2]|0)+64>>2]|0,t[(t[f>>2]|0)+76>>2]|0,0,0)|0;t[(t[f>>2]|0)+76>>2]=i;if(t[(t[u>>2]|0)+16>>2]|0)break e;hb(t[(t[f>>2]|0)+64>>2]|0,t[L>>2]|0,t[(t[f>>2]|0)+76>>2]|0)|0;t[a>>2]=1;break e}}break}case 2:{t[b>>2]=t[(t[u>>2]|0)+12>>2];t[c>>2]=t[(t[f>>2]|0)+76>>2];t[l>>2]=kb(t[(t[f>>2]|0)+64>>2]|0)|0;do if((t[(t[u>>2]|0)+20>>2]|0)==1){if((t[(t[b>>2]|0)+28>>2]|0)==1){i=cb(t[(t[f>>2]|0)+64>>2]|0,t[c>>2]|0,0,140432,140432,t[b>>2]|0)|0;t[(t[f>>2]|0)+76>>2]=i;hb(t[(t[f>>2]|0)+64>>2]|0,t[(t[f>>2]|0)+76>>2]|0,t[l>>2]|0)|0;i=cb(t[(t[f>>2]|0)+64>>2]|0,t[c>>2]|0,0,140432,0,t[b>>2]|0)|0;t[(t[f>>2]|0)+76>>2]=i;hb(t[(t[f>>2]|0)+64>>2]|0,t[(t[f>>2]|0)+76>>2]|0,t[l>>2]|0)|0;break}i=t[b>>2]|0;if(t[(t[b>>2]|0)+32>>2]|0){t[k>>2]=t[i+32>>2];do{t[(t[f>>2]|0)+76>>2]=t[c>>2];e=cb(t[(t[f>>2]|0)+64>>2]|0,t[(t[f>>2]|0)+76>>2]|0,0,140432,t[(t[k>>2]|0)+4>>2]|0,t[b>>2]|0)|0;t[(t[f>>2]|0)+76>>2]=e;hb(t[(t[f>>2]|0)+64>>2]|0,t[(t[f>>2]|0)+76>>2]|0,t[l>>2]|0)|0;t[k>>2]=t[t[k>>2]>>2]}while((t[k>>2]|0)!=0)}else{if(!(t[i+36>>2]|0))break;e=lb(t[(t[f>>2]|0)+64>>2]|0,t[c>>2]|0,t[l>>2]|0,140432,t[(t[(t[b>>2]|0)+36>>2]|0)+4>>2]|0,t[b>>2]|0)|0;t[(t[f>>2]|0)+76>>2]=e;break}}else{if((t[(t[u>>2]|0)+20>>2]|0)==1073741824)x=1073741824;else x=(t[(t[u>>2]|0)+20>>2]|0)-1|0;t[d>>2]=x;if((t[(t[u>>2]|0)+16>>2]|0)<1)U=0;else U=(t[(t[u>>2]|0)+16>>2]|0)-1|0;t[v>>2]=U;t[h>>2]=db(t[(t[f>>2]|0)+64>>2]|0,t[v>>2]|0,t[d>>2]|0)|0;t[w>>2]=kb(t[(t[f>>2]|0)+64>>2]|0)|0;do if((t[(t[b>>2]|0)+28>>2]|0)!=1){e=t[b>>2]|0;if(t[(t[b>>2]|0)+32>>2]|0){t[k>>2]=t[e+32>>2];do{z=cb(t[(t[f>>2]|0)+64>>2]|0,t[c>>2]|0,0,140432,t[(t[k>>2]|0)+4>>2]|0,t[b>>2]|0)|0;t[(t[f>>2]|0)+76>>2]=z;hb(t[(t[f>>2]|0)+64>>2]|0,t[(t[f>>2]|0)+76>>2]|0,t[w>>2]|0)|0;t[k>>2]=t[t[k>>2]>>2]}while((t[k>>2]|0)!=0)}else{if(!(t[e+36>>2]|0))break;z=lb(t[(t[f>>2]|0)+64>>2]|0,t[c>>2]|0,t[w>>2]|0,140432,t[(t[(t[b>>2]|0)+36>>2]|0)+4>>2]|0,t[b>>2]|0)|0;t[(t[f>>2]|0)+76>>2]=z;break}}else{z=cb(t[(t[f>>2]|0)+64>>2]|0,t[c>>2]|0,0,140432,140432,t[b>>2]|0)|0;t[(t[f>>2]|0)+76>>2]=z;hb(t[(t[f>>2]|0)+64>>2]|0,t[(t[f>>2]|0)+76>>2]|0,t[w>>2]|0)|0;z=cb(t[(t[f>>2]|0)+64>>2]|0,t[c>>2]|0,0,140432,0,t[b>>2]|0)|0;t[(t[f>>2]|0)+76>>2]=z;hb(t[(t[f>>2]|0)+64>>2]|0,t[(t[f>>2]|0)+76>>2]|0,t[w>>2]|0)|0}while(0);vb(t[(t[f>>2]|0)+64>>2]|0,t[w>>2]|0,t[c>>2]|0,t[h>>2]|0)|0;mb(t[(t[f>>2]|0)+64>>2]|0,t[w>>2]|0,t[l>>2]|0,t[h>>2]|0)|0}while(0);if(!(t[(t[u>>2]|0)+16>>2]|0)){hb(t[(t[f>>2]|0)+64>>2]|0,t[c>>2]|0,t[l>>2]|0)|0;t[a>>2]=1}t[(t[f>>2]|0)+76>>2]=t[l>>2];break}case 14:{t[a>>2]=ML(t[f>>2]|0,t[u>>2]|0)|0;break}case 17:{t[a>>2]=1;break}case 7:{t[a>>2]=0;t[F>>2]=t[(t[f>>2]|0)+76>>2];t[O>>2]=kb(t[(t[f>>2]|0)+64>>2]|0)|0;i=t[u>>2]|0;i:do if((t[(t[u>>2]|0)+20>>2]|0)!=1){if((t[i+20>>2]|0)==1073741824)j=1073741824;else j=(t[(t[u>>2]|0)+20>>2]|0)-1|0;t[N>>2]=j;if((t[(t[u>>2]|0)+16>>2]|0)<1)V=0;else V=(t[(t[u>>2]|0)+16>>2]|0)-1|0;t[T>>2]=V;t[A>>2]=db(t[(t[f>>2]|0)+64>>2]|0,t[T>>2]|0,t[N>>2]|0)|0;t[M>>2]=kb(t[(t[f>>2]|0)+64>>2]|0)|0;t[R>>2]=kb(t[(t[f>>2]|0)+64>>2]|0)|0;t[y>>2]=t[(t[(t[u>>2]|0)+12>>2]|0)+12>>2];while(1){if(!(t[y>>2]|0))break;t[(t[f>>2]|0)+76>>2]=t[R>>2];t[o>>2]=Cv(t[f>>2]|0,t[y>>2]|0)|0;if((t[o>>2]|0)==1)t[a>>2]=1;hb(t[(t[f>>2]|0)+64>>2]|0,t[(t[f>>2]|0)+76>>2]|0,t[M>>2]|0)|0;t[y>>2]=t[(t[y>>2]|0)+8>>2]}hb(t[(t[f>>2]|0)+64>>2]|0,t[F>>2]|0,t[R>>2]|0)|0;vb(t[(t[f>>2]|0)+64>>2]|0,t[M>>2]|0,t[R>>2]|0,t[A>>2]|0)|0;mb(t[(t[f>>2]|0)+64>>2]|0,t[M>>2]|0,t[O>>2]|0,t[A>>2]|0)|0;if((t[a>>2]|0)==1)hb(t[(t[f>>2]|0)+64>>2]|0,t[R>>2]|0,t[O>>2]|0)|0}else{t[y>>2]=t[(t[i+12>>2]|0)+12>>2];while(1){if(!(t[y>>2]|0))break i;t[(t[f>>2]|0)+76>>2]=t[F>>2];t[o>>2]=Cv(t[f>>2]|0,t[y>>2]|0)|0;if((t[o>>2]|0)==1)t[a>>2]=1;hb(t[(t[f>>2]|0)+64>>2]|0,t[(t[f>>2]|0)+76>>2]|0,t[O>>2]|0)|0;t[y>>2]=t[(t[y>>2]|0)+8>>2]}}while(0);if(!(t[(t[u>>2]|0)+16>>2]|0)){hb(t[(t[f>>2]|0)+64>>2]|0,t[F>>2]|0,t[O>>2]|0)|0;t[a>>2]=1}t[(t[f>>2]|0)+76>>2]=t[O>>2];break}case 6:{t[a>>2]=1;if((t[(t[u>>2]|0)+16>>2]|0)==1?(t[(t[u>>2]|0)+20>>2]|0)==1:0){t[m>>2]=t[(t[(t[u>>2]|0)+12>>2]|0)+12>>2];while(1){if(!(t[m>>2]|0))break e;t[o>>2]=Cv(t[f>>2]|0,t[m>>2]|0)|0;if((t[o>>2]|0)!=1)t[a>>2]=0;t[m>>2]=t[(t[m>>2]|0)+8>>2]}}t[_>>2]=t[(t[f>>2]|0)+76>>2];i=t[u>>2]|0;if((t[(t[u>>2]|0)+20>>2]|0)>=1073741824){z=(t[i+16>>2]|0)>1;q=hb(t[(t[f>>2]|0)+64>>2]|0,t[_>>2]|0,0)|0;t[(t[f>>2]|0)+76>>2]=q;t[_>>2]=t[(t[f>>2]|0)+76>>2];if(z){t[E>>2]=db(t[(t[f>>2]|0)+64>>2]|0,(t[(t[u>>2]|0)+16>>2]|0)-1|0,1073741824)|0;t[m>>2]=t[(t[(t[u>>2]|0)+12>>2]|0)+12>>2];while(1){Y=t[f>>2]|0;if(!(t[m>>2]|0))break;t[o>>2]=Cv(Y,t[m>>2]|0)|0;if((t[o>>2]|0)!=1)t[a>>2]=0;t[m>>2]=t[(t[m>>2]|0)+8>>2]}t[p>>2]=t[Y+76>>2];vb(t[(t[f>>2]|0)+64>>2]|0,t[p>>2]|0,t[_>>2]|0,t[E>>2]|0)|0;z=mb(t[(t[f>>2]|0)+64>>2]|0,t[p>>2]|0,0,t[E>>2]|0)|0;t[(t[f>>2]|0)+76>>2]=z;if((t[a>>2]|0)!=1)break e;hb(t[(t[f>>2]|0)+64>>2]|0,t[_>>2]|0,t[(t[f>>2]|0)+76>>2]|0)|0;break e}else{t[m>>2]=t[(t[(t[u>>2]|0)+12>>2]|0)+12>>2];while(1){G=t[f>>2]|0;if(!(t[m>>2]|0))break;t[o>>2]=Cv(G,t[m>>2]|0)|0;if((t[o>>2]|0)!=1)t[a>>2]=0;t[m>>2]=t[(t[m>>2]|0)+8>>2]}hb(t[G+64>>2]|0,t[(t[f>>2]|0)+76>>2]|0,t[_>>2]|0)|0;z=hb(t[(t[f>>2]|0)+64>>2]|0,t[(t[f>>2]|0)+76>>2]|0,0)|0;t[(t[f>>2]|0)+76>>2]=z;if(t[(t[u>>2]|0)+16>>2]|0)break e;hb(t[(t[f>>2]|0)+64>>2]|0,t[_>>2]|0,t[(t[f>>2]|0)+76>>2]|0)|0;t[a>>2]=1;break e}}if((t[i+20>>2]|0)<=1?(t[(t[u>>2]|0)+16>>2]|0)<=1:0){t[m>>2]=t[(t[(t[u>>2]|0)+12>>2]|0)+12>>2];while(1){W=t[f>>2]|0;if(!(t[m>>2]|0))break;
	t[o>>2]=Cv(W,t[m>>2]|0)|0;if((t[o>>2]|0)!=1)t[a>>2]=0;t[m>>2]=t[(t[m>>2]|0)+8>>2]}i=hb(t[W+64>>2]|0,t[(t[f>>2]|0)+76>>2]|0,0)|0;t[(t[f>>2]|0)+76>>2]=i;if(t[(t[u>>2]|0)+16>>2]|0)break e;hb(t[(t[f>>2]|0)+64>>2]|0,t[_>>2]|0,t[(t[f>>2]|0)+76>>2]|0)|0;t[a>>2]=1;break e}i=hb(t[(t[f>>2]|0)+64>>2]|0,t[_>>2]|0,0)|0;t[(t[f>>2]|0)+76>>2]=i;t[_>>2]=t[(t[f>>2]|0)+76>>2];t[g>>2]=db(t[(t[f>>2]|0)+64>>2]|0,(t[(t[u>>2]|0)+16>>2]|0)-1|0,(t[(t[u>>2]|0)+20>>2]|0)-1|0)|0;t[m>>2]=t[(t[(t[u>>2]|0)+12>>2]|0)+12>>2];while(1){K=t[f>>2]|0;if(!(t[m>>2]|0))break;t[o>>2]=Cv(K,t[m>>2]|0)|0;if((t[o>>2]|0)!=1)t[a>>2]=0;t[m>>2]=t[(t[m>>2]|0)+8>>2]}t[S>>2]=t[K+76>>2];vb(t[(t[f>>2]|0)+64>>2]|0,t[S>>2]|0,t[_>>2]|0,t[g>>2]|0)|0;i=mb(t[(t[f>>2]|0)+64>>2]|0,t[S>>2]|0,0,t[g>>2]|0)|0;t[(t[f>>2]|0)+76>>2]=i;if((t[a>>2]|0)==1?1:(t[(t[u>>2]|0)+16>>2]|0)==0){hb(t[(t[f>>2]|0)+64>>2]|0,t[_>>2]|0,t[(t[f>>2]|0)+76>>2]|0)|0;t[a>>2]=1}break}default:{i=t[f>>2]|0;nw(i,158112,158200,vd(t[(t[u>>2]|0)+12>>2]|0)|0,0);t[n>>2]=t[a>>2];I=t[n>>2]|0;s=r;return I|0}}while(0);t[n>>2]=t[a>>2];I=t[n>>2]|0;s=r;return I|0}function Pv(e){e=e|0;var i=0,r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0;i=s;s=s+16|0;r=i+12|0;n=i+8|0;f=i+4|0;u=i;t[n>>2]=e;t[f>>2]=0;e=t[n>>2]|0;if((t[(t[n>>2]|0)+96>>2]|0)>(t[(t[n>>2]|0)+104>>2]|0)){rh(e,155664,155696);t[r>>2]=0;a=t[r>>2]|0;s=i;return a|0}e:do if(t[e+100>>2]|0){o=t[n>>2]|0;if((t[(t[n>>2]|0)+104>>2]|0)>(t[(t[n>>2]|0)+96>>2]|0)){t[f>>2]=t[(t[(t[n>>2]|0)+100>>2]|0)+(t[o+96>>2]<<2)>>2];break}t[u>>2]=t[o+104>>2];o=(t[n>>2]|0)+104|0;t[o>>2]=t[o>>2]<<1;o=MAi[t[135760>>2]&511](t[(t[n>>2]|0)+100>>2]|0,t[(t[n>>2]|0)+104>>2]<<2)|0;t[(t[n>>2]|0)+100>>2]=o;if(!(t[(t[n>>2]|0)+100>>2]|0)){kh(t[n>>2]|0,155768,0);t[r>>2]=0;a=t[r>>2]|0;s=i;return a|0}else while(1){if((t[u>>2]|0)>=(t[(t[n>>2]|0)+104>>2]|0))break e;t[(t[(t[n>>2]|0)+100>>2]|0)+(t[u>>2]<<2)>>2]=0;t[u>>2]=(t[u>>2]|0)+1}}else{o=gAi[t[135744>>2]&511](40)|0;t[(t[n>>2]|0)+100>>2]=o;o=t[n>>2]|0;if(t[(t[n>>2]|0)+100>>2]|0){c=(t[o+100>>2]|0)+0|0;l=c+40|0;do{t[c>>2]=0;c=c+4|0}while((c|0)<(l|0));t[(t[n>>2]|0)+104>>2]=10;break}kh(o,155728,0);t[r>>2]=0;a=t[r>>2]|0;s=i;return a|0}while(0);do if(t[f>>2]|0){if(t[(t[f>>2]|0)+12>>2]|0){rh(t[n>>2]|0,155664,155840);t[r>>2]=0;a=t[r>>2]|0;s=i;return a|0}}else{t[f>>2]=gAi[t[135744>>2]&511](84)|0;if(t[f>>2]|0){t[(t[(t[n>>2]|0)+100>>2]|0)+(t[(t[n>>2]|0)+96>>2]<<2)>>2]=t[f>>2];break}kh(t[n>>2]|0,155808,0);t[r>>2]=0;a=t[r>>2]|0;s=i;return a|0}while(0);c=(t[f>>2]|0)+0|0;l=c+84|0;do{t[c>>2]=0;c=c+4|0}while((c|0)<(l|0));t[t[f>>2]>>2]=1;t[(t[f>>2]|0)+48>>2]=t[(t[n>>2]|0)+96>>2];t[r>>2]=t[f>>2];a=t[r>>2]|0;s=i;return a|0}function Bv(e){e=e|0;var i=0,r=0,n=0,f=0,u=0,a=0,o=0;i=s;s=s+16|0;r=i+8|0;n=i+4|0;f=i;t[n>>2]=e;do if(!(t[(t[n>>2]|0)+164>>2]|0)){e=gAi[t[135744>>2]&511](4)|0;t[(t[n>>2]|0)+164>>2]=e;t[(t[n>>2]|0)+172>>2]=1;if(!(t[(t[n>>2]|0)+164>>2]|0)){kh(t[n>>2]|0,145800,0);t[r>>2]=0;u=t[r>>2]|0;s=i;return u|0}}else{e=t[n>>2]|0;if((t[(t[n>>2]|0)+172>>2]|0)<=(t[(t[n>>2]|0)+168>>2]|0)){a=e+172|0;t[a>>2]=(t[a>>2]|0)+1;a=MAi[t[135760>>2]&511](t[(t[n>>2]|0)+164>>2]|0,t[(t[n>>2]|0)+172>>2]<<2)|0;t[(t[n>>2]|0)+164>>2]=a;if(t[(t[n>>2]|0)+164>>2]|0)break;kh(t[n>>2]|0,145832,0);t[r>>2]=0;u=t[r>>2]|0;s=i;return u|0}a=e+168|0;e=t[a>>2]|0;t[a>>2]=e+1;t[f>>2]=t[(t[(t[n>>2]|0)+164>>2]|0)+(e<<2)>>2];if(t[(t[f>>2]|0)+12>>2]|0){rh(t[n>>2]|0,145872,145904);t[r>>2]=0;u=t[r>>2]|0;s=i;return u|0}else{t[t[f>>2]>>2]=2;t[r>>2]=t[f>>2];u=t[r>>2]|0;s=i;return u|0}}while(0);t[f>>2]=gAi[t[135744>>2]&511](60)|0;if(!(t[f>>2]|0)){kh(t[n>>2]|0,145928,0);t[r>>2]=0;u=t[r>>2]|0;s=i;return u|0}else{e=(t[f>>2]|0)+0|0;a=e+60|0;do{t[e>>2]=0;e=e+4|0}while((e|0)<(a|0));t[t[f>>2]>>2]=2;e=t[f>>2]|0;a=(t[n>>2]|0)+168|0;o=t[a>>2]|0;t[a>>2]=o+1;t[(t[(t[n>>2]|0)+164>>2]|0)+(o<<2)>>2]=e;t[r>>2]=t[f>>2];u=t[r>>2]|0;s=i;return u|0}return 0}function Iv(e){e=e|0;var i=0,r=0,n=0,f=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0,S=0,g=0,y=0,F=0;i=s;s=s+48|0;r=i+32|0;n=i+28|0;f=i+24|0;a=i+20|0;o=i+16|0;c=i+12|0;l=i+8|0;b=i+4|0;k=i;t[n>>2]=e;t[o>>2]=0;t[l>>2]=0;t[b>>2]=0;t[k>>2]=NL(t[n>>2]|0,3)|0;if(!(t[k>>2]|0))t[k>>2]=NL(t[n>>2]|0,4)|0;if(!(t[k>>2]|0)){t[r>>2]=0;h=t[r>>2]|0;s=i;return h|0}t[f>>2]=t[(t[k>>2]|0)+20>>2];do{if((t[(t[k>>2]|0)+48>>2]|0)==3){while(1){do if((u[t[f>>2]>>0]|0|0)==32)w=1;else{if(9<=(u[t[f>>2]>>0]|0|0)?(u[t[f>>2]>>0]|0|0)<=10:0){w=1;break}w=(u[t[f>>2]>>0]|0|0)==13}while(0);d=t[f>>2]|0;if(!w)break;t[f>>2]=d+1}t[a>>2]=d;while(1){if(u[t[a>>2]>>0]|0){do if((u[t[a>>2]>>0]|0|0)==32)v=1;else{if(9<=(u[t[a>>2]>>0]|0|0)?(u[t[a>>2]>>0]|0|0)<=10:0){v=1;break}v=(u[t[a>>2]>>0]|0|0)==13}while(0);m=v^1}else m=0;_=t[a>>2]|0;if(!m)break;t[a>>2]=_+1}if((_|0)==(t[f>>2]|0))break;t[l>>2]=(t[l>>2]|0)+1;t[o>>2]=kz(t[(t[(t[n>>2]|0)+20>>2]|0)+60>>2]|0,t[f>>2]|0,(t[a>>2]|0)-(t[f>>2]|0)|0)|0;t[f>>2]=t[a>>2]}while(1){do if((u[t[f>>2]>>0]|0|0)==32)p=1;else{if(9<=(u[t[f>>2]>>0]|0|0)?(u[t[f>>2]>>0]|0|0)<=10:0){p=1;break}p=(u[t[f>>2]>>0]|0|0)==13}while(0);E=t[f>>2]|0;if(!p)break;t[f>>2]=E+1}t[a>>2]=E;while(1){if(u[t[a>>2]>>0]|0){do if((u[t[a>>2]>>0]|0|0)==32)S=1;else{if(9<=(u[t[a>>2]>>0]|0|0)?(u[t[a>>2]>>0]|0|0)<=10:0){S=1;break}S=(u[t[a>>2]>>0]|0|0)==13}while(0);g=S^1}else g=0;y=t[a>>2]|0;if(!g)break;t[a>>2]=y+1}if((y|0)==(t[f>>2]|0)){F=40;break}t[l>>2]=(t[l>>2]|0)+1;t[c>>2]=kz(t[(t[(t[n>>2]|0)+20>>2]|0)+60>>2]|0,t[f>>2]|0,(t[a>>2]|0)-(t[f>>2]|0)|0)|0;t[f>>2]=t[a>>2];t[b>>2]=TL(t[n>>2]|0,t[(t[n>>2]|0)+20>>2]|0,t[(t[k>>2]|0)+4>>2]|0,t[o>>2]|0,t[c>>2]|0)|0;if((t[b>>2]|0)==-1){F=43;break}}while((u[t[f>>2]>>0]|0|0)!=0);if((F|0)==40){if((t[(t[k>>2]|0)+48>>2]|0)==3)mw(t[n>>2]|0,1879,t[(t[k>>2]|0)+4>>2]|0,0,155136,0,0,0)}else if((F|0)==43){rh(t[n>>2]|0,155224,155248);t[r>>2]=-1;h=t[r>>2]|0;s=i;return h|0}t[r>>2]=t[b>>2];h=t[r>>2]|0;s=i;return h|0}function Hv(e){e=e|0;var i=0,r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0;i=s;s=s+96|0;r=i+80|0;n=i+76|0;f=i+72|0;u=i+68|0;a=i+64|0;o=i+60|0;c=i+56|0;l=i+16|0;b=i+8|0;k=i+4|0;h=i;t[n>>2]=e;t[a>>2]=0;e=t[n>>2]|0;if((t[(t[n>>2]|0)+96>>2]|0)<=0){rh(e,154576,154608);t[r>>2]=-1;w=t[r>>2]|0;s=i;return w|0}t[f>>2]=t[(t[(t[n>>2]|0)+100>>2]|0)+((t[e+96>>2]|0)-1<<2)>>2];if(t[(t[f>>2]|0)+32>>2]&32){e=(t[f>>2]|0)+32|0;t[e>>2]=t[e>>2]^32}e:do if(t[(t[f>>2]|0)+32>>2]&4){t[(t[n>>2]|0)+108>>2]=t[(t[(t[n>>2]|0)+100>>2]|0)+((t[(t[n>>2]|0)+96>>2]|0)-1<<2)>>2];t[a>>2]=1848;th(t[n>>2]|0,t[a>>2]|0,0,0,154648,0,0);t[(t[n>>2]|0)+108>>2]=t[(t[(t[n>>2]|0)+100>>2]|0)+(t[(t[n>>2]|0)+96>>2]<<2)>>2]}else{t[u>>2]=t[(t[f>>2]|0)+28>>2];if((t[(t[u>>2]|0)+88>>2]|0)==45){e=nv(t[(t[n>>2]|0)+20>>2]|0,t[(t[(t[n>>2]|0)+108>>2]|0)+12>>2]|0,t[(t[(t[n>>2]|0)+108>>2]|0)+16>>2]|0)|0;t[(t[(t[n>>2]|0)+108>>2]|0)+44>>2]=e;do if(!(t[(t[(t[n>>2]|0)+108>>2]|0)+44>>2]|0)){t[o>>2]=NL(t[n>>2]|0,1)|0;if(!(t[o>>2]|0)){e=ED(45)|0;t[(t[(t[n>>2]|0)+108>>2]|0)+28>>2]=e;break}t[a>>2]=LL(t[n>>2]|0,t[o>>2]|0,(t[(t[n>>2]|0)+108>>2]|0)+28|0,0)|0;if(t[a>>2]|0)if((t[a>>2]|0)==-1){rh(t[n>>2]|0,154576,154504);t[r>>2]=-1;w=t[r>>2]|0;s=i;return w|0}else{t[r>>2]=t[a>>2];w=t[r>>2]|0;s=i;return w|0}}while(0);t[r>>2]=0;w=t[r>>2]|0;s=i;return w|0}i:do switch(t[(t[u>>2]|0)+52>>2]|0){case 2:case 3:{t[k>>2]=10;if(!(t[(t[u>>2]|0)+108>>2]|0)){rh(t[n>>2]|0,154576,154808);t[r>>2]=-1;w=t[r>>2]|0;s=i;return w|0}if(t[(t[f>>2]|0)+32>>2]&256){rh(t[n>>2]|0,154576,154856);t[r>>2]=-1;w=t[r>>2]|0;s=i;return w|0}t[c>>2]=t[(t[f>>2]|0)+60>>2];do if(!(t[c>>2]|0)){t[c>>2]=Ws(t[(t[u>>2]|0)+108>>2]|0,358,t[n>>2]|0)|0;if(t[c>>2]|0){t[(t[f>>2]|0)+60>>2]=t[c>>2];break}rh(t[n>>2]|0,154576,141760);t[r>>2]=-1;w=t[r>>2]|0;s=i;return w|0}while(0);t[a>>2]=Zs(t[c>>2]|0,t[(t[(t[n>>2]|0)+108>>2]|0)+12>>2]|0,t[(t[(t[n>>2]|0)+108>>2]|0)+16>>2]|0,t[(t[n>>2]|0)+108>>2]|0)|0;if((t[(t[n>>2]|0)+52>>2]|0)==1818){rh(t[n>>2]|0,154576,154912);t[r>>2]=-1;w=t[r>>2]|0;s=i;return w|0}if((t[a>>2]|0)<0){Qs(t[c>>2]|0,0,k,h,l,b)|0;Yv(t[n>>2]|0,1871,0,0,154944,t[k>>2]|0,t[h>>2]|0,l);t[a>>2]=t[(t[n>>2]|0)+52>>2];break e}else{t[a>>2]=0;break i}break}case 1:{t[(t[n>>2]|0)+108>>2]=t[(t[(t[n>>2]|0)+100>>2]|0)+((t[(t[n>>2]|0)+96>>2]|0)-1<<2)>>2];t[a>>2]=1841;th(t[n>>2]|0,t[a>>2]|0,0,0,154736,0,0);t[(t[n>>2]|0)+108>>2]=t[(t[(t[n>>2]|0)+100>>2]|0)+(t[(t[n>>2]|0)+96>>2]<<2)>>2];break e;break}case 6:case 4:{t[(t[n>>2]|0)+108>>2]=t[(t[(t[n>>2]|0)+100>>2]|0)+((t[(t[n>>2]|0)+96>>2]|0)-1<<2)>>2];if((t[t[u>>2]>>2]|0)!=5?(t[(t[u>>2]|0)+88>>2]|0)!=45:0){t[a>>2]=1828;th(t[n>>2]|0,t[a>>2]|0,0,0,155064,0,0)}else{t[a>>2]=1842;th(t[n>>2]|0,t[a>>2]|0,0,0,154976,0,0)}t[(t[n>>2]|0)+108>>2]=t[(t[(t[n>>2]|0)+100>>2]|0)+(t[(t[n>>2]|0)+96>>2]<<2)>>2];t[a>>2]=t[(t[n>>2]|0)+52>>2];break e;break}default:{}}while(0);t[r>>2]=t[a>>2];w=t[r>>2]|0;s=i;return w|0}while(0);t[(t[n>>2]|0)+176>>2]=t[(t[n>>2]|0)+96>>2];u=(t[(t[n>>2]|0)+108>>2]|0)+32|0;t[u>>2]=t[u>>2]|512;u=(t[f>>2]|0)+32|0;t[u>>2]=t[u>>2]|256;t[r>>2]=t[a>>2];w=t[r>>2]|0;s=i;return w|0}function xv(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0;r=s;s=s+32|0;n=r+20|0;f=r+16|0;u=r+12|0;a=r+8|0;o=r+4|0;c=r;t[f>>2]=e;t[u>>2]=i;t[a>>2]=t[(t[(t[f>>2]|0)+108>>2]|0)+44>>2];if(!((t[u>>2]|0)==0|(t[a>>2]|0)==0)?(t[t[a>>2]>>2]|0)==2:0){t[t[u>>2]>>2]=0;if((t[(t[a>>2]|0)+24>>2]|0)==1){t[t[u>>2]>>2]=1;t[n>>2]=0;l=t[n>>2]|0;s=r;return l|0}t[o>>2]=0;t[o>>2]=nv(t[(t[f>>2]|0)+20>>2]|0,t[(t[(t[f>>2]|0)+108>>2]|0)+12>>2]|0,t[(t[(t[f>>2]|0)+108>>2]|0)+16>>2]|0)|0;if(t[o>>2]|0){t[(t[(t[f>>2]|0)+108>>2]|0)+44>>2]=t[o>>2];t[n>>2]=0;l=t[n>>2]|0;s=r;return l|0}o=t[f>>2]|0;if((t[(t[a>>2]|0)+24>>2]|0)==3){th(o,1845,0,0,154416,0,0);t[n>>2]=t[(t[f>>2]|0)+52>>2];l=t[n>>2]|0;s=r;return l|0}if((t[o+168>>2]|0)!=0?(t[c>>2]=NL(t[f>>2]|0,1)|0,(t[c>>2]|0)!=0):0)if((LL(t[f>>2]|0,t[c>>2]|0,(t[(t[f>>2]|0)+108>>2]|0)+28|0,0)|0)==-1){rh(t[f>>2]|0,154368,154504);t[n>>2]=-1;l=t[n>>2]|0;s=r;return l|0}else{t[n>>2]=0;l=t[n>>2]|0;s=r;return l|0}c=ED(45)|0;t[(t[(t[f>>2]|0)+108>>2]|0)+28>>2]=c;t[n>>2]=0;l=t[n>>2]|0;s=r;return l|0}rh(t[f>>2]|0,154368,154400);t[n>>2]=-1;l=t[n>>2]|0;s=r;return l|0}function Uv(e){e=e|0;var i=0,r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0;i=s;s=s+32|0;r=i+24|0;n=i+20|0;f=i+16|0;u=i+12|0;a=i+8|0;o=i+4|0;c=i;t[n>>2]=e;t[f>>2]=t[(t[(t[n>>2]|0)+108>>2]|0)+44>>2];if(!(t[f>>2]|0)){th(t[n>>2]|0,1845,0,0,146200,0,0);t[r>>2]=t[(t[n>>2]|0)+52>>2];l=t[r>>2]|0;s=i;return l|0}t[u>>2]=t[(t[f>>2]|0)+28>>2];if(t[(t[f>>2]|0)+48>>2]&16){th(t[n>>2]|0,1846,0,0,146240,0,0);t[r>>2]=t[(t[n>>2]|0)+52>>2];l=t[r>>2]|0;s=i;return l|0}e=t[n>>2]|0;if(!(t[u>>2]|0)){th(e,1875,0,0,145096,0,0);t[r>>2]=1875;l=t[r>>2]|0;s=i;return l|0}do if(t[e+168>>2]|0){t[o>>2]=NL(t[n>>2]|0,2)|0;do if(t[o>>2]|0){t[(t[n>>2]|0)+108>>2]=t[o>>2];b=t[n>>2]|0;k=ED(15)|0;t[a>>2]=nh(b,0,k,t[(t[o>>2]|0)+20>>2]|0,(t[o>>2]|0)+24|0,1,0,0)|0;t[(t[n>>2]|0)+108>>2]=t[(t[(t[n>>2]|0)+100>>2]|0)+(t[(t[n>>2]|0)+96>>2]<<2)>>2];if((t[a>>2]|0)<0){rh(t[n>>2]|0,146280,146312);t[r>>2]=-1;l=t[r>>2]|0;s=i;return l|0}if(!(t[a>>2]|0)){if(!(t[(t[f>>2]|0)+48>>2]&1)){th(t[n>>2]|0,1847,0,0,146392,0,0);break}if(FD(t[(t[o>>2]|0)+24>>2]|0)|0){if((t[(t[f>>2]|0)+48>>2]&8|0)!=0?(t[(t[f>>2]|0)+76>>2]|0)!=0:0){th(t[n>>2]|0,1849,0,0,146424,0,0);break}k=(t[(t[n>>2]|0)+108>>2]|0)+32|0;t[k>>2]=t[k>>2]|4}}}while(0);t[o>>2]=NL(t[n>>2]|0,1)|0;if(t[o>>2]|0){t[c>>2]=0;t[a>>2]=LL(t[n>>2]|0,t[o>>2]|0,c,t[f>>2]|0)|0;if((t[a>>2]|0)!=0&(t[a>>2]|0)==-1){rh(t[n>>2]|0,146280,146512);t[r>>2]=-1;l=t[r>>2]|0;s=i;return l|0}else{if(!(t[c>>2]|0))break;k=(t[(t[n>>2]|0)+108>>2]|0)+32|0;t[k>>2]=t[k>>2]|8;t[u>>2]=t[c>>2];break}}}while(0);if((t[(t[f>>2]|0)+100>>2]|0)!=0?(DL(t[n>>2]|0,t[f>>2]|0)|0)==-1:0){t[r>>2]=-1;l=t[r>>2]|0;s=i;return l|0}if(!(t[u>>2]|0)){th(t[n>>2]|0,1875,0,0,145096,0,0);t[r>>2]=1875;l=t[r>>2]|0;s=i;return l|0}else{t[(t[(t[n>>2]|0)+108>>2]|0)+28>>2]=t[u>>2];t[r>>2]=0;l=t[r>>2]|0;s=i;return l|0}return 0}function zv(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0;r=s;s=s+48|0;n=r+36|0;f=r+32|0;u=r+28|0;a=r+24|0;o=r+20|0;c=r+16|0;l=r+12|0;b=r+8|0;k=r+4|0;h=r;t[f>>2]=e;t[u>>2]=i;t[o>>2]=0;t[b>>2]=0;t[k>>2]=t[(t[f>>2]|0)+96>>2];if(!(t[(t[f>>2]|0)+116>>2]|0)){t[n>>2]=0;w=t[n>>2]|0;s=r;return w|0}if((t[u>>2]|0)==2)t[k>>2]=(t[k>>2]|0)+1;t[c>>2]=t[(t[f>>2]|0)+116>>2];t[a>>2]=t[c>>2];e:while(1){if((t[a>>2]|0)==(t[o>>2]|0)){d=34;break}i=t[(t[a>>2]|0)+32>>2]|0;e=t[(t[(t[f>>2]|0)+108>>2]|0)+12>>2]|0;v=t[(t[(t[f>>2]|0)+108>>2]|0)+16>>2]|0;if((t[u>>2]|0)==1)t[l>>2]=pj(i,e,v)|0;else t[l>>2]=Sj(i,e,v)|0;if((t[l>>2]|0)==-1){d=11;break}i:do if(t[l>>2]|0){if(t[(t[a>>2]|0)+12>>2]|0){if((t[(t[a>>2]|0)+20>>2]|0)<=(t[(t[a>>2]|0)+16>>2]|0)?(v=(t[a>>2]|0)+20|0,t[v>>2]=t[v>>2]<<1,v=MAi[t[135760>>2]&511](t[(t[a>>2]|0)+12>>2]|0,t[(t[a>>2]|0)+20>>2]<<2)|0,t[(t[a>>2]|0)+12>>2]=v,(t[(t[a>>2]|0)+12>>2]|0)==0):0){d=19;break e}}else{v=gAi[t[135744>>2]&511](20)|0;t[(t[a>>2]|0)+12>>2]=v;if(!(t[(t[a>>2]|0)+12>>2]|0)){d=15;break e}t[(t[a>>2]|0)+20>>2]=5}v=t[k>>2]|0;e=(t[a>>2]|0)+16|0;i=t[e>>2]|0;t[e>>2]=i+1;t[(t[(t[a>>2]|0)+12>>2]|0)+(i<<2)>>2]=v;v=t[a>>2]|0;if((t[t[a>>2]>>2]|0)==1){t[h>>2]=t[(t[(t[(t[v+24>>2]|0)+16>>2]|0)+4>>2]|0)+28>>2];while(1){if(!(t[h>>2]|0))break i;if((CL(t[f>>2]|0,t[(t[a>>2]|0)+24>>2]|0,t[h>>2]|0,2)|0)==-1){d=24;break e}t[h>>2]=t[t[h>>2]>>2]}}if((t[v>>2]|0)==2){if((t[b>>2]|0)==0?(t[(t[(t[f>>2]|0)+108>>2]|0)+32>>2]&16|0)==0:0){i=(t[(t[f>>2]|0)+108>>2]|0)+32|0;t[i>>2]=t[i>>2]|16}t[b>>2]=(t[b>>2]|0)+1}}while(0);if(!(t[(t[a>>2]|0)+4>>2]|0)){t[o>>2]=t[c>>2];t[a>>2]=t[(t[f>>2]|0)+116>>2];continue}else{t[a>>2]=t[(t[a>>2]|0)+4>>2];continue}}if((d|0)==11){rh(t[f>>2]|0,145960,145984);t[n>>2]=-1;w=t[n>>2]|0;s=r;return w|0}else if((d|0)==15){kh(0,146008,0);t[n>>2]=-1;w=t[n>>2]|0;s=r;return w|0}else if((d|0)==19){kh(0,146048,0);t[n>>2]=-1;w=t[n>>2]|0;s=r;return w|0}else if((d|0)==24){t[n>>2]=-1;w=t[n>>2]|0;s=r;return w|0}else if((d|0)==34){t[n>>2]=t[b>>2];w=t[n>>2]|0;s=r;return w|0}return 0}function jv(e){e=e|0;var i=0,r=0,n=0,f=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0,S=0,g=0,y=0,F=0,O=0,A=0,M=0,R=0,N=0,T=0,L=0;i=s;s=s+128|0;r=i;n=i+100|0;f=i+96|0;a=i+92|0;o=i+88|0;c=i+84|0;l=i+80|0;b=i+76|0;k=i+72|0;h=i+68|0;w=i+64|0;d=i+60|0;v=i+56|0;m=i+52|0;_=i+48|0;p=i+44|0;E=i+40|0;S=i+36|0;g=i+32|0;y=i+28|0;F=i+24|0;O=i+20|0;A=i+16|0;M=i+104|0;R=i+12|0;N=i+8|0;t[f>>2]=e;t[a>>2]=t[(t[(t[f>>2]|0)+108>>2]|0)+28>>2];t[c>>2]=0;t[l>>2]=0;t[_>>2]=0;t[E>>2]=0;t[g>>2]=0;t[o>>2]=t[(t[a>>2]|0)+116>>2];t[v>>2]=t[(t[f>>2]|0)+168>>2];if(t[o>>2]|0)t[m>>2]=t[(t[o>>2]|0)+4>>2];else t[m>>2]=0;t[h>>2]=0;e:while(1){if((t[h>>2]|0)>=(t[m>>2]|0)){T=26;break}t[d>>2]=0;t[c>>2]=t[(t[t[o>>2]>>2]|0)+(t[h>>2]<<2)>>2];t[l>>2]=t[(t[c>>2]|0)+12>>2];t[w>>2]=0;while(1){if((t[w>>2]|0)>=(t[v>>2]|0))break;t[b>>2]=t[(t[(t[f>>2]|0)+164>>2]|0)+(t[w>>2]<<2)>>2];if((((t[(t[b>>2]|0)+48>>2]|0)==0?(u[t[(t[b>>2]|0)+12>>2]>>0]|0|0)==(u[t[(t[l>>2]|0)+8>>2]>>0]|0|0):0)?(Xl(t[(t[b>>2]|0)+12>>2]|0,t[(t[l>>2]|0)+8>>2]|0)|0)!=0:0)?(Xl(t[(t[b>>2]|0)+16>>2]|0,t[(t[l>>2]|0)+56>>2]|0)|0)!=0:0){T=12;break}t[w>>2]=(t[w>>2]|0)+1}if((T|0)==12){T=0;t[d>>2]=1;t[(t[b>>2]|0)+44>>2]=2;t[(t[b>>2]|0)+40>>2]=t[c>>2];t[(t[b>>2]|0)+36>>2]=t[l>>2];t[(t[b>>2]|0)+28>>2]=t[(t[l>>2]|0)+48>>2]}do if(!(t[d>>2]|0)){if((t[(t[c>>2]|0)+24>>2]|0)==1){t[k>>2]=Bv(t[f>>2]|0)|0;if(!(t[k>>2]|0)){T=17;break e}t[(t[k>>2]|0)+44>>2]=4;t[(t[k>>2]|0)+40>>2]=t[c>>2];t[(t[k>>2]|0)+36>>2]=t[l>>2];break}if((t[(t[c>>2]|0)+24>>2]|0)==2){if((t[(t[c>>2]|0)+28>>2]|0)==0?(t[(t[l>>2]|0)+44>>2]|0)==0:0)break;t[k>>2]=Bv(t[f>>2]|0)|0;if(!(t[k>>2]|0)){T=23;break e}t[(t[k>>2]|0)+44>>2]=8;t[(t[k>>2]|0)+40>>2]=t[c>>2];t[(t[k>>2]|0)+36>>2]=t[l>>2];t[(t[k>>2]|0)+28>>2]=t[(t[l>>2]|0)+48>>2];t[(t[k>>2]|0)+12>>2]=t[(t[l>>2]|0)+8>>2];t[(t[k>>2]|0)+16>>2]=t[(t[l>>2]|0)+56>>2]}}while(0);t[h>>2]=(t[h>>2]|0)+1}if((T|0)==17){rh(t[f>>2]|0,145272,145304);t[n>>2]=-1;L=t[n>>2]|0;s=i;return L|0}else if((T|0)==23){rh(t[f>>2]|0,145272,145304);t[n>>2]=-1;L=t[n>>2]|0;s=i;return L|0}else if((T|0)==26){if(!(t[(t[f>>2]|0)+168>>2]|0)){t[n>>2]=0;L=t[n>>2]|0;s=i;return L|0}e:do if(t[(t[a>>2]|0)+84>>2]|0){t[h>>2]=0;while(1){if((t[h>>2]|0)>=(t[v>>2]|0))break e;t[b>>2]=t[(t[(t[f>>2]|0)+164>>2]|0)+(t[h>>2]<<2)>>2];i:do if((t[(t[b>>2]|0)+44>>2]|0)==1?(dL(t[(t[a>>2]|0)+84>>2]|0,t[(t[b>>2]|0)+16>>2]|0)|0)==0:0){if((t[(t[(t[a>>2]|0)+84>>2]|0)+24>>2]|0)==1){t[(t[b>>2]|0)+44>>2]=13;break}l=uv(t[(t[f>>2]|0)+20>>2]|0,t[(t[b>>2]|0)+12>>2]|0,t[(t[b>>2]|0)+16>>2]|0)|0;t[(t[b>>2]|0)+36>>2]=l;if(!(t[(t[b>>2]|0)+36>>2]|0)){l=(t[b>>2]|0)+44|0;if((t[(t[(t[a>>2]|0)+84>>2]|0)+24>>2]|0)==2){t[l>>2]=14;break}else{t[l>>2]=10;break}}t[(t[b>>2]|0)+44>>2]=2;t[(t[b>>2]|0)+28>>2]=t[(t[(t[b>>2]|0)+36>>2]|0)+48>>2];if(gv(t[(t[b>>2]|0)+28>>2]|0,23)|0){if(t[E>>2]|0){t[(t[b>>2]|0)+44>>2]=15;l=t[33976]|0;k=t[33980]|0;t[r>>2]=140328;t[r+4>>2]=25406;yAi[l&511](k,140296,r);break}t[E>>2]=(t[E>>2]|0)+1;if(t[o>>2]|0){t[w>>2]=0;while(1){if((t[w>>2]|0)>=(t[(t[o>>2]|0)+4>>2]|0))break i;if(gv(t[(t[(t[(t[t[o>>2]>>2]|0)+(t[w>>2]<<2)>>2]|0)+12>>2]|0)+48>>2]|0,23)|0)break;t[w>>2]=(t[w>>2]|0)+1}t[(t[b>>2]|0)+44>>2]=16;k=t[33976]|0;l=t[33980]|0;t[r>>2]=140328;t[r+4>>2]=25424;yAi[k&511](l,140296,r)}}}while(0);t[h>>2]=(t[h>>2]|0)+1}}while(0);if(!(t[(t[f>>2]|0)+168>>2]|0)){t[n>>2]=0;L=t[n>>2]|0;s=i;return L|0}if((((t[(t[f>>2]|0)+80>>2]&1|0)!=0?(t[y>>2]=t[(t[(t[f>>2]|0)+100>>2]|0)+(t[(t[f>>2]|0)+96>>2]<<2)>>2],(t[y>>2]|0)!=0):0)?(t[(t[y>>2]|0)+4>>2]|0)!=0:0)?(t[(t[(t[y>>2]|0)+4>>2]|0)+32>>2]|0)!=0:0)t[g>>2]=t[(t[y>>2]|0)+4>>2];t[h>>2]=0;e:while(1){if((t[h>>2]|0)>=(t[(t[f>>2]|0)+168>>2]|0)){T=124;break}t[b>>2]=t[(t[(t[f>>2]|0)+164>>2]|0)+(t[h>>2]<<2)>>2];if(!((t[(t[b>>2]|0)+44>>2]|0)!=2?(t[(t[b>>2]|0)+44>>2]|0)!=8:0))T=60;do if((T|0)==60){T=0;y=t[b>>2]|0;if(!(t[(t[b>>2]|0)+28>>2]|0)){t[y+44>>2]=6;break}t[(t[f>>2]|0)+108>>2]=y;t[S>>2]=0;t[_>>2]=0;if((t[(t[f>>2]|0)+116>>2]|0)!=0?(t[_>>2]=zv(t[f>>2]|0,2)|0,(t[_>>2]|0)==-1):0){T=64;break e}i:do if((t[(t[b>>2]|0)+44>>2]|0)==8){if((t[_>>2]|0)!=0|(t[g>>2]|0)!=0){y=t[b>>2]|0;if(t[(t[(t[b>>2]|0)+40>>2]|0)+28>>2]|0){t[(t[b>>2]|0)+20>>2]=t[(t[y+40>>2]|0)+28>>2];t[(t[b>>2]|0)+24>>2]=t[(t[(t[b>>2]|0)+40>>2]|0)+32>>2]}else{t[(t[b>>2]|0)+20>>2]=t[(t[y+36>>2]|0)+44>>2];t[(t[b>>2]|0)+24>>2]=t[(t[(t[b>>2]|0)+36>>2]|0)+68>>2]}if(!(t[(t[b>>2]|0)+24>>2]|0)){T=71;break e}y=PD(t[(t[b>>2]|0)+24>>2]|0)|0;t[(t[b>>2]|0)+24>>2]=y;if(!(t[(t[b>>2]|0)+24>>2]|0)){T=73;break e}}if(t[g>>2]|0){t[O>>2]=t[(t[b>>2]|0)+20>>2];t[F>>2]=fw(t[(t[b>>2]|0)+28>>2]|0,t[(t[b>>2]|0)+20>>2]|0)|0;if(t[F>>2]|0)t[O>>2]=t[F>>2];y=t[g>>2]|0;if(!(t[(t[b>>2]|0)+16>>2]|0)){if(!(by(y,t[(t[b>>2]|0)+12>>2]|0,t[O>>2]|0)|0)){T=79;break e}}else{t[A>>2]=rF(t[y+32>>2]|0,t[g>>2]|0,t[(t[b>>2]|0)+16>>2]|0)|0;if(!(t[A>>2]|0)){t[R>>2]=0;do{y=t[R>>2]|0;t[R>>2]=y+1;t[r>>2]=y;SY(M,12,145464,r)|0;t[A>>2]=wF(t[(t[g>>2]|0)+32>>2]|0,t[g>>2]|0,M)|0;if((t[R>>2]|0)>1e3){T=84;break e}}while((t[A>>2]|0)!=0);t[A>>2]=Wg(t[(t[f>>2]|0)+84>>2]|0,t[(t[b>>2]|0)+16>>2]|0,M)|0}ky(t[g>>2]|0,t[A>>2]|0,t[(t[b>>2]|0)+12>>2]|0,t[O>>2]|0)|0}if(t[F>>2]|0)pAi[t[135736>>2]&511](t[F>>2]|0)}}else{if(t[(t[f>>2]|0)+72>>2]|0){MD(t[(t[f>>2]|0)+72>>2]|0);t[(t[f>>2]|0)+72>>2]=0}do if(t[(t[(t[b>>2]|0)+36>>2]|0)+60>>2]&512)T=96;else{if((t[(t[b>>2]|0)+40>>2]|0)!=0?(t[(t[(t[b>>2]|0)+40>>2]|0)+16>>2]&512|0)!=0:0){T=96;break}t[S>>2]=0}while(0);if((T|0)==96){T=0;t[S>>2]=1}if((t[_>>2]|0)!=0|(t[S>>2]|0)!=0){y=(t[b>>2]|0)+32|0;t[y>>2]=t[y>>2]|16;t[p>>2]=nh(t[f>>2]|0,t[(t[b>>2]|0)+4>>2]|0,t[(t[b>>2]|0)+28>>2]|0,t[(t[b>>2]|0)+20>>2]|0,(t[b>>2]|0)+24|0,1,1,0)|0}else t[p>>2]=nh(t[f>>2]|0,t[(t[b>>2]|0)+4>>2]|0,t[(t[b>>2]|0)+28>>2]|0,t[(t[b>>2]|0)+20>>2]|0,0,1,0,0)|0;if(t[p>>2]|0){if((t[p>>2]|0)==-1){T=103;break e}t[(t[b>>2]|0)+44>>2]=5;break}if(t[S>>2]|0){if(!(t[(t[b>>2]|0)+24>>2]|0)){y=t[33976]|0;w=t[33980]|0;t[r>>2]=140328;t[r+4>>2]=25678;yAi[y&511](w,140296,r);break}do if(t[(t[b>>2]|0)+40>>2]|0){if(!(t[(t[(t[b>>2]|0)+40>>2]|0)+28>>2]|0))break;if(!(t[(t[(t[b>>2]|0)+40>>2]|0)+32>>2]|0)){w=t[33976]|0;y=t[33980]|0;t[r>>2]=140328;t[r+4>>2]=25685;yAi[w&511](y,140296,r);break i}t[(t[b>>2]|0)+52>>2]=t[(t[(t[b>>2]|0)+40>>2]|0)+28>>2];if(Od(t[(t[b>>2]|0)+24>>2]|0,t[(t[(t[b>>2]|0)+40>>2]|0)+32>>2]|0)|0)break i;t[(t[b>>2]|0)+44>>2]=7;break i}while(0);if(!(t[(t[(t[b>>2]|0)+36>>2]|0)+68>>2]|0)){y=t[33976]|0;w=t[33980]|0;t[r>>2]=140328;t[r+4>>2]=25700;yAi[y&511](w,140296,r);break}t[(t[b>>2]|0)+52>>2]=t[(t[(t[b>>2]|0)+36>>2]|0)+44>>2];if(Od(t[(t[b>>2]|0)+24>>2]|0,t[(t[(t[b>>2]|0)+36>>2]|0)+68>>2]|0)|0)break;t[(t[b>>2]|0)+44>>2]=7}}while(0);w=t[f>>2]|0;if(t[_>>2]|0)if((Kv(w,(t[(t[f>>2]|0)+96>>2]|0)+1|0)|0)==-1){T=120;break e}else break;if(t[w+116>>2]|0)PL(t[f>>2]|0)|0}while(0);t[h>>2]=(t[h>>2]|0)+1}if((T|0)==64)rh(t[f>>2]|0,145272,145160);else if((T|0)==71)rh(t[f>>2]|0,145272,145344);else if((T|0)==73)rh(t[f>>2]|0,145272,145408);else if((T|0)==79){rh(t[f>>2]|0,145272,145440);if(t[F>>2]|0)pAi[t[135736>>2]&511](t[F>>2]|0)}else if((T|0)==84){rh(t[f>>2]|0,145272,145472);if(t[F>>2]|0)pAi[t[135736>>2]&511](t[F>>2]|0)}else if((T|0)==103)rh(t[f>>2]|0,145272,145536);else if((T|0)==120)rh(t[f>>2]|0,145272,145160);else if((T|0)==124){t[h>>2]=0;while(1){if((t[h>>2]|0)>=(t[(t[f>>2]|0)+168>>2]|0))break;t[b>>2]=t[(t[(t[f>>2]|0)+164>>2]|0)+(t[h>>2]<<2)>>2];e:do if((((t[(t[b>>2]|0)+44>>2]|0)!=17?(t[(t[b>>2]|0)+44>>2]|0)!=2:0)?(t[(t[b>>2]|0)+44>>2]|0)!=13:0)?(t[(t[b>>2]|0)+44>>2]|0)!=14:0){t[(t[f>>2]|0)+108>>2]=t[b>>2];switch(t[(t[b>>2]|0)+44>>2]|0){case 6:{th(t[f>>2]|0,1862,0,0,145096,0,0);break e;break}case 4:{t[N>>2]=0;t[(t[f>>2]|0)+108>>2]=t[(t[(t[f>>2]|0)+100>>2]|0)+(t[(t[f>>2]|0)+96>>2]<<2)>>2];th(t[f>>2]|0,1868,0,0,145592,uh(N,t[(t[(t[b>>2]|0)+36>>2]|0)+56>>2]|0,t[(t[(t[b>>2]|0)+36>>2]|0)+8>>2]|0)|0,0);if(!(t[N>>2]|0))break e;pAi[t[135736>>2]&511](t[N>>2]|0);t[N>>2]=0;break e;break}case 7:{th(t[f>>2]|0,1874,0,0,145640,t[(t[b>>2]|0)+20>>2]|0,t[(t[b>>2]|0)+52>>2]|0);break e;break}case 10:{th(t[f>>2]|0,1878,0,0,145704,0,0);break e;break}case 1:{if(t[(t[b>>2]|0)+48>>2]|0)break e;T=t[f>>2]|0;F=t[b>>2]|0;if(!(t[(t[a>>2]|0)+84>>2]|0)){BL(T,1866,F,0);break e}else{BL(T,1867,F,0);break e}break}default:break e}}while(0);t[h>>2]=(t[h>>2]|0)+1}t[(t[f>>2]|0)+108>>2]=t[(t[(t[f>>2]|0)+100>>2]|0)+(t[(t[f>>2]|0)+96>>2]<<2)>>2];t[n>>2]=0;L=t[n>>2]|0;s=i;return L|0}t[(t[f>>2]|0)+108>>2]=t[(t[(t[f>>2]|0)+100>>2]|0)+(t[(t[f>>2]|0)+96>>2]<<2)>>2];t[n>>2]=-1;L=t[n>>2]|0;s=i;return L|0}return 0}function Vv(e){e=e|0;var i=0,r=0,n=0,f=0,u=0,a=0,o=0;i=s;s=s+32|0;r=i+16|0;n=i+12|0;f=i+8|0;u=i+4|0;a=i;t[n>>2]=e;t[u>>2]=0;if(!(t[(t[n>>2]|0)+168>>2]|0)){t[r>>2]=0;o=t[r>>2]|0;s=i;return o|0}t[a>>2]=0;while(1){if((t[a>>2]|0)>=(t[(t[n>>2]|0)+168>>2]|0))break;t[f>>2]=t[(t[(t[n>>2]|0)+164>>2]|0)+(t[a>>2]<<2)>>2];if(!(t[(t[f>>2]|0)+48>>2]|0)){t[(t[n>>2]|0)+108>>2]=t[f>>2];BL(t[n>>2]|0,1827,t[f>>2]|0,0);t[u>>2]=1827}t[a>>2]=(t[a>>2]|0)+1}t[(t[n>>2]|0)+108>>2]=t[(t[(t[n>>2]|0)+100>>2]|0)+(t[(t[n>>2]|0)+96>>2]<<2)>>2];t[r>>2]=t[u>>2];o=t[r>>2]|0;s=i;return o|0}function qv(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,u=0,a=0;f=s;s=s+16|0;u=f+4|0;a=f;t[f+12>>2]=e;t[f+8>>2]=i;t[u>>2]=r;t[a>>2]=n;t[(t[a>>2]|0)+44>>2]=t[u>>2];s=f;return}function Yv(e,i,r,n,f,a,o,c){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;a=a|0;o=o|0;c=c|0;var l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0,S=0,g=0,y=0,F=0,O=0,A=0,M=0,R=0,N=0,T=0;l=s;s=s+64|0;b=l+56|0;k=l+52|0;h=l+48|0;w=l+40|0;d=l+36|0;v=l+32|0;m=l+28|0;_=l+24|0;p=l+20|0;E=l+16|0;S=l+12|0;g=l+8|0;y=l+4|0;F=l;t[b>>2]=e;t[k>>2]=i;t[h>>2]=r;t[l+44>>2]=n;t[w>>2]=f;t[d>>2]=a;t[v>>2]=o;t[m>>2]=c;t[_>>2]=0;t[p>>2]=0;bw(p,t[b>>2]|0,t[h>>2]|0)|0;t[p>>2]=us(t[p>>2]|0,t[w>>2]|0)|0;t[p>>2]=us(t[p>>2]|0,144352)|0;if(((t[d>>2]|0)+(t[v>>2]|0)|0)<=0){t[p>>2]=us(t[p>>2]|0,140352)|0;O=t[b>>2]|0;A=t[k>>2]|0;M=t[h>>2]|0;R=t[p>>2]|0;pd(O,A,M,R,0,0);N=t[33934]|0;T=t[p>>2]|0;pAi[N&511](T);s=l;return}if(((t[d>>2]|0)+(t[v>>2]|0)|0)>1)t[_>>2]=Yl(144360)|0;else t[_>>2]=Yl(144384)|0;t[S>>2]=0;t[F>>2]=0;while(1){if((t[F>>2]|0)>=((t[d>>2]|0)+(t[v>>2]|0)|0))break;t[g>>2]=t[(t[m>>2]|0)+(t[F>>2]<<2)>>2];do if(t[g>>2]|0){if((((u[t[g>>2]>>0]|0|0)==110?(u[(t[g>>2]|0)+1>>0]|0|0)==111:0)?(u[(t[g>>2]|0)+2>>0]|0|0)==116:0)?(u[(t[g>>2]|0)+3>>0]|0|0)==32:0){t[g>>2]=(t[g>>2]|0)+4;t[_>>2]=us(t[_>>2]|0,144400)|0}t[E>>2]=0;t[y>>2]=t[g>>2];if((u[t[y>>2]>>0]|0|0)==42){t[E>>2]=Yl(140432)|0;t[y>>2]=(t[y>>2]|0)+1}else{while(1){if(!(u[t[y>>2]>>0]|0))break;if((u[t[y>>2]>>0]|0|0)==124)break;t[y>>2]=(t[y>>2]|0)+1}t[E>>2]=fs(t[E>>2]|0,t[g>>2]|0,(t[y>>2]|0)-(t[g>>2]|0)|0)|0}if(u[t[y>>2]>>0]|0){t[y>>2]=(t[y>>2]|0)+1;if(((t[v>>2]|0)!=0?(u[t[y>>2]>>0]|0|0)==42:0)?(u[t[E>>2]>>0]|0|0)==42:0){if(!(t[E>>2]|0))break;pAi[t[135736>>2]&511](t[E>>2]|0);t[E>>2]=0;break}t[g>>2]=t[y>>2];if((u[t[y>>2]>>0]|0|0)==42)t[S>>2]=Yl(144408)|0;else{while(1){if(!(u[t[y>>2]>>0]|0))break;t[y>>2]=(t[y>>2]|0)+1}if((t[F>>2]|0)>=(t[d>>2]|0))t[S>>2]=Yl(144416)|0;else t[S>>2]=Yl(144432)|0;t[S>>2]=fs(t[S>>2]|0,t[g>>2]|0,(t[y>>2]|0)-(t[g>>2]|0)|0)|0;t[S>>2]=us(t[S>>2]|0,144440)|0}t[_>>2]=us(t[_>>2]|0,t[S>>2]|0)|0;if(t[S>>2]|0){pAi[t[135736>>2]&511](t[S>>2]|0);t[S>>2]=0}}t[_>>2]=us(t[_>>2]|0,t[E>>2]|0)|0;if(t[E>>2]|0){pAi[t[135736>>2]&511](t[E>>2]|0);t[E>>2]=0}if((t[F>>2]|0)<((t[d>>2]|0)+(t[v>>2]|0)-1|0))t[_>>2]=us(t[_>>2]|0,144448)|0}while(0);t[F>>2]=(t[F>>2]|0)+1}t[_>>2]=us(t[_>>2]|0,144456)|0;t[p>>2]=us(t[p>>2]|0,t[_>>2]|0)|0;if(!(t[_>>2]|0)){O=t[b>>2]|0;A=t[k>>2]|0;M=t[h>>2]|0;R=t[p>>2]|0;pd(O,A,M,R,0,0);N=t[33934]|0;T=t[p>>2]|0;pAi[N&511](T);s=l;return}pAi[t[135736>>2]&511](t[_>>2]|0);t[_>>2]=0;O=t[b>>2]|0;A=t[k>>2]|0;M=t[h>>2]|0;R=t[p>>2]|0;pd(O,A,M,R,0,0);N=t[33934]|0;T=t[p>>2]|0;pAi[N&511](T);s=l;return}function Gv(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,u=0,a=0,o=0,c=0,l=0,b=0;f=s;s=s+32|0;u=f+16|0;a=f+12|0;o=f+8|0;c=f+4|0;l=f;t[a>>2]=e;t[o>>2]=i;t[c>>2]=r;t[l>>2]=n;n=t[a>>2]|0;a=t[c>>2]|0;c=t[l>>2]|0;if(t[(t[o>>2]|0)+32>>2]&16){t[u>>2]=nh(n,0,a,c,(t[o>>2]|0)+24|0,1,1,0)|0;b=t[u>>2]|0;s=f;return b|0}else{t[u>>2]=nh(n,0,a,c,0,1,0,0)|0;b=t[u>>2]|0;s=f;return b|0}return 0}function Wv(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0;n=s;s=s+32|0;f=n+20|0;u=n+16|0;a=n+12|0;o=n+8|0;c=n+4|0;l=n;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;t[c>>2]=0;t[l>>2]=t[(t[u>>2]|0)+108>>2];if(!((t[t[(t[l>>2]|0)+28>>2]>>2]|0)!=5?(t[(t[(t[l>>2]|0)+28>>2]|0)+88>>2]|0)!=45:0))b=3;do if(((b|0)==3?(t[(t[(t[l>>2]|0)+28>>2]|0)+52>>2]|0)!=4:0)?(t[(t[(t[l>>2]|0)+28>>2]|0)+52>>2]|0)!=6:0){if((t[(t[(t[l>>2]|0)+28>>2]|0)+52>>2]|0)==3?(mL(t[(t[(t[l>>2]|0)+28>>2]|0)+28>>2]|0)|0)!=0:0)break;t[c>>2]=3059;th(t[u>>2]|0,t[c>>2]|0,0,0,144160,0,0);t[f>>2]=t[c>>2];k=t[f>>2]|0;s=n;return k|0}while(0);do if((t[t[(t[l>>2]|0)+28>>2]>>2]|0)==4)b=11;else{if((t[t[(t[l>>2]|0)+28>>2]>>2]|0)==1?(t[(t[(t[l>>2]|0)+28>>2]|0)+88>>2]|0)!=45:0){b=11;break}if((t[(t[(t[l>>2]|0)+28>>2]|0)+52>>2]|0)!=4?(t[(t[(t[l>>2]|0)+28>>2]|0)+52>>2]|0)!=6:0)break;t[c>>2]=nh(t[u>>2]|0,0,t[(t[(t[l>>2]|0)+28>>2]|0)+104>>2]|0,t[a>>2]|0,t[o>>2]|0,1,1,0)|0}while(0);if((b|0)==11)t[c>>2]=nh(t[u>>2]|0,0,t[(t[l>>2]|0)+28>>2]|0,t[a>>2]|0,t[o>>2]|0,1,1,0)|0;if((t[c>>2]|0)<0)rh(t[u>>2]|0,144320,141832);t[f>>2]=t[c>>2];k=t[f>>2]|0;s=n;return k|0}function Kv(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0,S=0,g=0,y=0,F=0,O=0,A=0,M=0,R=0,N=0,T=0,L=0,D=0,C=0,P=0,B=0,I=0,H=0,x=0;r=s;s=s+128|0;n=r+124|0;f=r+120|0;u=r+116|0;a=r+112|0;o=r+108|0;c=r+104|0;l=r+100|0;b=r+96|0;k=r+92|0;h=r+88|0;w=r+84|0;d=r+80|0;v=r+76|0;m=r+72|0;_=r+68|0;p=r+64|0;E=r+60|0;S=r+56|0;g=r+52|0;y=r+48|0;F=r+44|0;O=r+40|0;A=r+36|0;M=r+32|0;R=r+28|0;N=r+24|0;T=r+20|0;L=r+16|0;D=r+12|0;C=r+8|0;P=r+4|0;B=r;t[f>>2]=e;t[u>>2]=i;t[b>>2]=0;t[k>>2]=t[(t[(t[f>>2]|0)+108>>2]|0)+28>>2];t[h>>2]=0;if(!(t[(t[f>>2]|0)+116>>2]|0)){t[n>>2]=0;I=t[n>>2]|0;s=r;return I|0}t[a>>2]=t[(t[f>>2]|0)+116>>2];e:while(1){if(!(t[a>>2]|0)){H=103;break}t[c>>2]=gj(t[(t[a>>2]|0)+32>>2]|0)|0;if((t[c>>2]|0)==-1){H=6;break}do if(t[(t[a>>2]|0)+16>>2]|0){t[l>>2]=t[(t[(t[a>>2]|0)+12>>2]|0)+((t[(t[a>>2]|0)+16>>2]|0)-1<<2)>>2];i=t[a>>2]|0;if((t[l>>2]|0)!=(t[u>>2]|0)){t[a>>2]=t[i+4>>2];continue e}if((t[i>>2]|0)!=2){if((t[t[a>>2]>>2]|0)==1){t[S>>2]=0;t[y>>2]=t[(t[a>>2]|0)+24>>2];t[F>>2]=t[(t[(t[y>>2]|0)+16>>2]|0)+4>>2];t[N>>2]=t[(t[F>>2]|0)+32>>2];t[A>>2]=(t[u>>2]|0)-(t[(t[y>>2]|0)+4>>2]|0);do if((t[(t[y>>2]|0)+24>>2]|0)!=0?(t[(t[y>>2]|0)+28>>2]|0)>(t[A>>2]|0):0){t[S>>2]=(t[(t[y>>2]|0)+24>>2]|0)+(t[A>>2]<<2);if(!(t[t[S>>2]>>2]|0))if((t[t[F>>2]>>2]|0)==23){H=91;break}else break;t[M>>2]=0;while(1){if((t[M>>2]|0)>=(t[N>>2]|0))break;if(!(t[(t[t[S>>2]>>2]|0)+(t[M>>2]<<2)>>2]|0)){H=61;break}t[M>>2]=(t[M>>2]|0)+1}if((H|0)==61){H=0;if((t[t[F>>2]>>2]|0)==23){H=91;break}else break}t[O>>2]=xL(t[f>>2]|0,t[y>>2]|0)|0;if((t[t[F>>2]>>2]|0)!=24?(t[(t[O>>2]|0)+4>>2]|0)!=0:0){t[M>>2]=0;t[c>>2]=0;do{t[D>>2]=t[(t[(t[t[O>>2]>>2]|0)+(t[M>>2]<<2)>>2]|0)+4>>2];t[R>>2]=0;while(1){if((t[R>>2]|0)>=(t[N>>2]|0))break;t[T>>2]=t[(t[t[S>>2]>>2]|0)+(t[R>>2]<<2)>>2];t[L>>2]=t[(t[D>>2]|0)+(t[R>>2]<<2)>>2];t[c>>2]=Od(t[(t[T>>2]|0)+4>>2]|0,t[(t[L>>2]|0)+4>>2]|0)|0;if((t[c>>2]|0)==-1){H=69;break e}if(!(t[c>>2]|0))break;t[R>>2]=(t[R>>2]|0)+1}if((t[c>>2]|0)==1)break;t[M>>2]=(t[M>>2]|0)+1}while((t[M>>2]|0)<(t[(t[O>>2]|0)+4>>2]|0));if((t[M>>2]|0)!=(t[(t[O>>2]|0)+4>>2]|0)){t[C>>2]=0;t[P>>2]=0;i=t[f>>2]|0;e=t[F>>2]|0;x=UL(t[f>>2]|0,C,t[t[S>>2]>>2]|0,t[N>>2]|0)|0;th(i,1877,0,e,143312,x,IL(P,t[F>>2]|0)|0);if(t[C>>2]|0){pAi[t[135736>>2]&511](t[C>>2]|0);t[C>>2]=0}if(!(t[P>>2]|0))break;pAi[t[135736>>2]&511](t[P>>2]|0);t[P>>2]=0;break}}t[g>>2]=gAi[t[135744>>2]&511](16)|0;if(!(t[g>>2]|0)){H=80;break e}x=t[g>>2]|0;t[x+0>>2]=0;t[x+4>>2]=0;t[x+8>>2]=0;t[x+12>>2]=0;x=t[f>>2]|0;if((t[t[F>>2]>>2]|0)==24){e=jL(x,t[(t[(t[f>>2]|0)+108>>2]|0)+12>>2]|0,t[(t[(t[f>>2]|0)+108>>2]|0)+16>>2]|0)|0;t[(t[g>>2]|0)+12>>2]=e;if((t[(t[g>>2]|0)+12>>2]|0)==-1){H=86;break e}}else{if((zL(x,t[g>>2]|0)|0)==-1){H=83;break e}t[(t[g>>2]|0)+12>>2]=-1}t[t[g>>2]>>2]=t[(t[f>>2]|0)+60>>2];t[(t[g>>2]|0)+8>>2]=t[(t[(t[f>>2]|0)+108>>2]|0)+8>>2];t[(t[g>>2]|0)+4>>2]=t[t[S>>2]>>2];t[t[S>>2]>>2]=0;if((Cd(t[O>>2]|0,t[g>>2]|0)|0)==-1){H=88;break e}}else H=55;while(0);if((H|0)==55?(H=0,(t[t[F>>2]>>2]|0)==23):0)H=91;if((H|0)==91?(H=0,t[B>>2]=0,x=t[f>>2]|0,e=t[F>>2]|0,th(x,1877,0,e,143384,IL(B,t[F>>2]|0)|0,0),(t[B>>2]|0)!=0):0){pAi[t[135736>>2]&511](t[B>>2]|0);t[B>>2]=0}if((t[S>>2]|0)!=0?(t[t[S>>2]>>2]|0)!=0:0){pAi[t[135736>>2]&511](t[t[S>>2]>>2]|0);t[t[S>>2]>>2]=0}}}else{if((t[t[k>>2]>>2]|0)!=5?(t[(t[k>>2]|0)+88>>2]|0)!=45:0)t[h>>2]=t[k>>2];else H=13;do if((H|0)==13){H=0;if((t[(t[k>>2]|0)+52>>2]|0)!=4?(t[(t[k>>2]|0)+52>>2]|0)!=6:0){t[h>>2]=0;break}t[h>>2]=t[(t[k>>2]|0)+104>>2];if(!(t[h>>2]|0)){H=16;break e}}while(0);if(!(t[h>>2]|0)){t[w>>2]=0;e=t[f>>2]|0;x=t[(t[(t[(t[a>>2]|0)+24>>2]|0)+16>>2]|0)+4>>2]|0;i=t[(t[(t[a>>2]|0)+28>>2]|0)+12>>2]|0;th(e,1877,0,x,142904,i,IL(w,t[(t[(t[(t[a>>2]|0)+24>>2]|0)+16>>2]|0)+4>>2]|0)|0);if(t[w>>2]|0){pAi[t[135736>>2]&511](t[w>>2]|0);t[w>>2]=0}i=(t[a>>2]|0)+16|0;t[i>>2]=(t[i>>2]|0)+-1;break}if((t[b>>2]|0)==0?(t[(t[(t[f>>2]|0)+108>>2]|0)+24>>2]|0)==0:0){th(t[f>>2]|0,1877,0,t[(t[(t[(t[a>>2]|0)+24>>2]|0)+16>>2]|0)+4>>2]|0,142984,0,0);i=(t[a>>2]|0)+16|0;t[i>>2]=(t[i>>2]|0)+-1;break}t[d>>2]=t[(t[a>>2]|0)+24>>2];t[m>>2]=(t[(t[a>>2]|0)+8>>2]|0)-(t[(t[d>>2]|0)+4>>2]|0);t[_>>2]=t[(t[(t[a>>2]|0)+28>>2]|0)+8>>2];i=t[m>>2]|0;i:do if(t[(t[d>>2]|0)+24>>2]|0){if((i|0)>=(t[(t[d>>2]|0)+28>>2]|0)){t[p>>2]=t[(t[d>>2]|0)+28>>2];x=(t[d>>2]|0)+28|0;t[x>>2]=t[x>>2]<<1;x=MAi[t[135760>>2]&511](t[(t[d>>2]|0)+24>>2]|0,t[(t[d>>2]|0)+28>>2]<<2)|0;t[(t[d>>2]|0)+24>>2]=x;if(!(t[(t[d>>2]|0)+24>>2]|0)){H=35;break e}while(1){if((t[p>>2]|0)>=(t[(t[d>>2]|0)+28>>2]|0))break i;t[(t[(t[d>>2]|0)+24>>2]|0)+(t[p>>2]<<2)>>2]=0;t[p>>2]=(t[p>>2]|0)+1}}}else{if((i|0)>9)t[(t[d>>2]|0)+28>>2]=t[m>>2]<<1;else t[(t[d>>2]|0)+28>>2]=10;x=gAi[t[135744>>2]&511](t[(t[d>>2]|0)+28>>2]<<2)|0;t[(t[d>>2]|0)+24>>2]=x;if(!(t[(t[d>>2]|0)+24>>2]|0)){H=31;break e}VY(t[(t[d>>2]|0)+24>>2]|0,0,t[(t[d>>2]|0)+28>>2]<<2|0)|0}while(0);t[v>>2]=t[(t[(t[d>>2]|0)+24>>2]|0)+(t[m>>2]<<2)>>2];if(t[v>>2]|0){if(t[(t[v>>2]|0)+(t[_>>2]<<2)>>2]|0){t[E>>2]=0;i=t[f>>2]|0;x=t[(t[(t[d>>2]|0)+16>>2]|0)+4>>2]|0;e=t[(t[(t[a>>2]|0)+28>>2]|0)+12>>2]|0;th(i,1877,0,x,143168,e,IL(E,t[(t[(t[d>>2]|0)+16>>2]|0)+4>>2]|0)|0);if(t[E>>2]|0){pAi[t[135736>>2]&511](t[E>>2]|0);t[E>>2]=0}e=(t[a>>2]|0)+16|0;t[e>>2]=(t[e>>2]|0)+-1;break}}else{t[v>>2]=gAi[t[135744>>2]&511](t[(t[(t[(t[d>>2]|0)+16>>2]|0)+4>>2]|0)+32>>2]<<2)|0;if(!(t[v>>2]|0)){H=44;break e}VY(t[v>>2]|0,0,t[(t[(t[(t[d>>2]|0)+16>>2]|0)+4>>2]|0)+32>>2]<<2|0)|0;
	t[(t[(t[d>>2]|0)+24>>2]|0)+(t[m>>2]<<2)>>2]=t[v>>2]}if(!(t[b>>2]|0)){t[b>>2]=gAi[t[135744>>2]&511](8)|0;if(!(t[b>>2]|0)){H=48;break e}t[t[b>>2]>>2]=t[h>>2];t[(t[b>>2]|0)+4>>2]=t[(t[(t[f>>2]|0)+108>>2]|0)+24>>2];t[(t[(t[f>>2]|0)+108>>2]|0)+24>>2]=0;if((HL(t[f>>2]|0,t[b>>2]|0)|0)==-1){H=50;break e}}t[(t[v>>2]|0)+(t[_>>2]<<2)>>2]=t[b>>2]}e=(t[a>>2]|0)+16|0;t[e>>2]=(t[e>>2]|0)+-1}while(0);if((t[(t[a>>2]|0)+16>>2]|0)==0?(t[(t[a>>2]|0)+8>>2]|0)==(t[u>>2]|0):0){if((t[(t[f>>2]|0)+116>>2]|0)!=(t[a>>2]|0))rh(t[f>>2]|0,142760,143424);t[o>>2]=t[(t[a>>2]|0)+4>>2];t[(t[f>>2]|0)+116>>2]=t[(t[a>>2]|0)+4>>2];t[(t[a>>2]|0)+4>>2]=t[(t[f>>2]|0)+120>>2];t[(t[f>>2]|0)+120>>2]=t[a>>2];t[a>>2]=t[o>>2];continue}t[a>>2]=t[(t[a>>2]|0)+4>>2]}switch(H|0){case 6:{rh(t[f>>2]|0,142760,142792);t[n>>2]=-1;I=t[n>>2]|0;s=r;return I|0}case 16:{rh(t[f>>2]|0,142760,142816);t[n>>2]=-1;I=t[n>>2]|0;s=r;return I|0}case 31:{kh(0,143088,0);t[n>>2]=-1;I=t[n>>2]|0;s=r;return I|0}case 35:{kh(0,143128,0);t[n>>2]=-1;I=t[n>>2]|0;s=r;return I|0}case 44:{kh(0,143256,0);t[n>>2]=-1;I=t[n>>2]|0;s=r;return I|0}case 48:{kh(0,143288,0);pAi[t[135736>>2]&511](t[v>>2]|0);t[(t[(t[d>>2]|0)+24>>2]|0)+(t[m>>2]<<2)>>2]=0;t[n>>2]=-1;I=t[n>>2]|0;s=r;return I|0}case 50:{Qk(t[b>>2]|0);t[n>>2]=-1;I=t[n>>2]|0;s=r;return I|0}case 69:{t[n>>2]=-1;I=t[n>>2]|0;s=r;return I|0}case 80:{kh(0,143344,0);pAi[t[135736>>2]&511](t[t[S>>2]>>2]|0);t[t[S>>2]>>2]=0;t[n>>2]=-1;I=t[n>>2]|0;s=r;return I|0}case 83:{pAi[t[135736>>2]&511](t[g>>2]|0);pAi[t[135736>>2]&511](t[t[S>>2]>>2]|0);t[t[S>>2]>>2]=0;t[n>>2]=-1;I=t[n>>2]|0;s=r;return I|0}case 86:{pAi[t[135736>>2]&511](t[g>>2]|0);pAi[t[135736>>2]&511](t[t[S>>2]>>2]|0);t[t[S>>2]>>2]=0;t[n>>2]=-1;I=t[n>>2]|0;s=r;return I|0}case 88:{if((t[t[F>>2]>>2]|0)==24){pAi[t[135736>>2]&511](t[(t[g>>2]|0)+4>>2]|0);pAi[t[135736>>2]&511](t[g>>2]|0)}t[n>>2]=-1;I=t[n>>2]|0;s=r;return I|0}case 103:{t[n>>2]=0;I=t[n>>2]|0;s=r;return I|0}}return 0}function Xv(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0,S=0,g=0;r=s;s=s+80|0;n=r+64|0;f=r+60|0;u=r+56|0;a=r+52|0;o=r+48|0;c=r+44|0;l=r+40|0;b=r+36|0;k=r+32|0;h=r+28|0;w=r+24|0;d=r+20|0;v=r+16|0;m=r+12|0;_=r+8|0;p=r+4|0;E=r;t[f>>2]=e;t[u>>2]=i;t[E>>2]=t[(t[u>>2]|0)+56>>2];e:while(1){if(!(t[E>>2]|0)){S=51;break}if(((t[t[(t[(t[E>>2]|0)+16>>2]|0)+4>>2]>>2]|0)!=24?(t[(t[E>>2]|0)+32>>2]|0)!=0:0)?(t[(t[(t[E>>2]|0)+32>>2]|0)+4>>2]|0)!=0:0){do if(!(t[(t[f>>2]|0)+188>>2]|0)){if((t[(t[(t[E>>2]|0)+16>>2]|0)+8>>2]|0)!=-1?(t[(t[(t[E>>2]|0)+16>>2]|0)+8>>2]|0)<=(t[(t[f>>2]|0)+96>>2]|0):0)break;t[E>>2]=t[(t[E>>2]|0)+8>>2];continue e}while(0);t[a>>2]=VL(t[f>>2]|0,t[E>>2]|0)|0;if((t[(t[a>>2]|0)+20>>2]|0)!=0?(t[(t[(t[a>>2]|0)+20>>2]|0)+4>>2]|0)!=0:0){t[p>>2]=t[t[(t[a>>2]|0)+20>>2]>>2];t[w>>2]=t[(t[(t[a>>2]|0)+20>>2]|0)+4>>2]}else{t[p>>2]=0;t[w>>2]=0}if(t[(t[a>>2]|0)+8>>2]|0)t[d>>2]=t[(t[a>>2]|0)+12>>2];else t[d>>2]=0;u=t[(t[E>>2]|0)+32>>2]|0;if((t[d>>2]|0)==0&(t[w>>2]|0)==0){t[(t[a>>2]|0)+8>>2]=t[u>>2];t[(t[a>>2]|0)+16>>2]=t[(t[(t[E>>2]|0)+32>>2]|0)+8>>2];t[(t[a>>2]|0)+12>>2]=t[(t[(t[E>>2]|0)+32>>2]|0)+4>>2];t[t[(t[E>>2]|0)+32>>2]>>2]=0;t[(t[(t[E>>2]|0)+32>>2]|0)+8>>2]=0;t[(t[(t[E>>2]|0)+32>>2]|0)+4>>2]=0}else{t[k>>2]=t[u+4>>2];t[_>>2]=t[t[(t[E>>2]|0)+32>>2]>>2];t[h>>2]=t[(t[(t[(t[E>>2]|0)+16>>2]|0)+4>>2]|0)+32>>2];t[c>>2]=0;do{t[v>>2]=t[(t[(t[_>>2]|0)+(t[c>>2]<<2)>>2]|0)+4>>2];i:do if(t[w>>2]|0){t[l>>2]=0;while(1){if((t[h>>2]|0)==1){t[o>>2]=Od(t[(t[t[v>>2]>>2]|0)+4>>2]|0,t[(t[t[(t[(t[p>>2]|0)+(t[l>>2]<<2)>>2]|0)+4>>2]>>2]|0)+4>>2]|0)|0;if((t[o>>2]|0)==-1){S=52;break e}if((t[o>>2]|0)==1)break i}else{t[o>>2]=0;t[m>>2]=t[(t[(t[p>>2]|0)+(t[l>>2]<<2)>>2]|0)+4>>2];t[b>>2]=0;while(1){if((t[b>>2]|0)>=(t[h>>2]|0))break;t[o>>2]=Od(t[(t[(t[v>>2]|0)+(t[b>>2]<<2)>>2]|0)+4>>2]|0,t[(t[(t[m>>2]|0)+(t[b>>2]<<2)>>2]|0)+4>>2]|0)|0;if((t[o>>2]|0)==-1){S=52;break e}if(!(t[o>>2]|0))break;t[b>>2]=(t[b>>2]|0)+1}if((t[o>>2]|0)==1)break i}t[l>>2]=(t[l>>2]|0)+1;if((t[l>>2]|0)>=(t[w>>2]|0)){S=33;break}}}else S=33;while(0);i:do if((S|0)==33){S=0;r:do if(t[d>>2]|0){t[l>>2]=0;n:while(1){f:do if((t[h>>2]|0)==1){t[o>>2]=Od(t[(t[t[v>>2]>>2]|0)+4>>2]|0,t[(t[t[(t[(t[(t[a>>2]|0)+8>>2]|0)+(t[l>>2]<<2)>>2]|0)+4>>2]>>2]|0)+4>>2]|0)|0;if((t[o>>2]|0)==-1){S=52;break e}if(t[o>>2]|0)break n}else{t[o>>2]=0;t[m>>2]=t[(t[(t[(t[a>>2]|0)+8>>2]|0)+(t[l>>2]<<2)>>2]|0)+4>>2];t[b>>2]=0;while(1){if((t[b>>2]|0)>=(t[h>>2]|0))break n;t[o>>2]=Od(t[(t[(t[v>>2]|0)+(t[b>>2]<<2)>>2]|0)+4>>2]|0,t[(t[(t[m>>2]|0)+(t[b>>2]<<2)>>2]|0)+4>>2]|0)|0;if((t[o>>2]|0)==-1){S=52;break e}if(!(t[o>>2]|0))break f;t[b>>2]=(t[b>>2]|0)+1}}while(0);t[l>>2]=(t[l>>2]|0)+1;if((t[l>>2]|0)>=(t[d>>2]|0))break r}if((t[(t[a>>2]|0)+20>>2]|0)==0?(u=hh()|0,t[(t[a>>2]|0)+20>>2]=u,(t[(t[a>>2]|0)+20>>2]|0)==0):0){S=52;break e}if((Cd(t[(t[a>>2]|0)+20>>2]|0,t[(t[(t[a>>2]|0)+8>>2]|0)+(t[l>>2]<<2)>>2]|0)|0)==-1){S=52;break e}t[(t[(t[a>>2]|0)+8>>2]|0)+(t[l>>2]<<2)>>2]=t[(t[(t[a>>2]|0)+8>>2]|0)+((t[(t[a>>2]|0)+12>>2]|0)-1<<2)>>2];u=(t[a>>2]|0)+12|0;t[u>>2]=(t[u>>2]|0)+-1;break i}while(0);if((qL(t[a>>2]|0,t[(t[_>>2]|0)+(t[c>>2]<<2)>>2]|0)|0)==-1){S=52;break e}}while(0);t[c>>2]=(t[c>>2]|0)+1}while((t[c>>2]|0)<(t[k>>2]|0))}t[E>>2]=t[(t[E>>2]|0)+8>>2];continue}t[E>>2]=t[(t[E>>2]|0)+8>>2]}if((S|0)==51){t[n>>2]=0;g=t[n>>2]|0;s=r;return g|0}else if((S|0)==52){t[n>>2]=-1;g=t[n>>2]|0;s=r;return g|0}return 0}function Zv(e){e=e|0;var i=0;i=s;s=s+e|0;s=s+15&-16;return i|0}function Jv(){return s|0}function Qv(e){e=e|0;s=e}function $v(e,i){e=e|0;i=i|0;if(!p){p=e;E=i}}function em(e){e=e|0;n[k>>0]=n[e>>0];n[k+1>>0]=n[e+1>>0];n[k+2>>0]=n[e+2>>0];n[k+3>>0]=n[e+3>>0]}function im(e){e=e|0;n[k>>0]=n[e>>0];n[k+1>>0]=n[e+1>>0];n[k+2>>0]=n[e+2>>0];n[k+3>>0]=n[e+3>>0];n[k+4>>0]=n[e+4>>0];n[k+5>>0]=n[e+5>>0];n[k+6>>0]=n[e+6>>0];n[k+7>>0]=n[e+7>>0]}function rm(e){e=e|0;P=e}function nm(){return P|0}function fm(e,i){e=e|0;i=i|0;var r=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,m=0,_=0,p=0,E=0,S=0;r=s;s=s+64|0;f=r;u=r+52|0;a=r+48|0;o=r+44|0;c=r+40|0;l=r+36|0;b=r+32|0;k=r+28|0;h=r+24|0;w=r+20|0;d=r+16|0;m=r+12|0;_=r+8|0;p=r+4|0;t[u>>2]=0;t[a>>2]=e;t[o>>2]=i;t[b>>2]=0;t[k>>2]=0;if((t[a>>2]|0)<=1){tm(t[t[o>>2]>>2]|0);t[u>>2]=1;E=t[u>>2]|0;s=r;return E|0}Ep(20902);t[c>>2]=1;e:while(1){if((t[c>>2]|0)>=(t[a>>2]|0))break;if(!(MY(t[(t[o>>2]|0)+(t[c>>2]<<2)>>2]|0,144)|0))break;i:do if((n[t[(t[o>>2]|0)+(t[c>>2]<<2)>>2]>>0]|0)==45){if((MY(t[(t[o>>2]|0)+(t[c>>2]<<2)>>2]|0,152)|0)!=0?(MY(t[(t[o>>2]|0)+(t[c>>2]<<2)>>2]|0,160)|0)!=0:0){if((MY(t[(t[o>>2]|0)+(t[c>>2]<<2)>>2]|0,176)|0)!=0?(MY(t[(t[o>>2]|0)+(t[c>>2]<<2)>>2]|0,184)|0)!=0:0){if((MY(t[(t[o>>2]|0)+(t[c>>2]<<2)>>2]|0,208)|0)!=0?(MY(t[(t[o>>2]|0)+(t[c>>2]<<2)>>2]|0,216)|0)!=0:0){if((MY(t[(t[o>>2]|0)+(t[c>>2]<<2)>>2]|0,232)|0)!=0?(MY(t[(t[o>>2]|0)+(t[c>>2]<<2)>>2]|0,248)|0)!=0:0){do if(MY(t[(t[o>>2]|0)+(t[c>>2]<<2)>>2]|0,280)|0){if(!(MY(t[(t[o>>2]|0)+(t[c>>2]<<2)>>2]|0,288)|0))break;do if(MY(t[(t[o>>2]|0)+(t[c>>2]<<2)>>2]|0,296)|0){if(!(MY(t[(t[o>>2]|0)+(t[c>>2]<<2)>>2]|0,304)|0))break;do if(MY(t[(t[o>>2]|0)+(t[c>>2]<<2)>>2]|0,320)|0){if(!(MY(t[(t[o>>2]|0)+(t[c>>2]<<2)>>2]|0,328)|0))break;do if(MY(t[(t[o>>2]|0)+(t[c>>2]<<2)>>2]|0,344)|0){if(!(MY(t[(t[o>>2]|0)+(t[c>>2]<<2)>>2]|0,360)|0))break;do if(MY(t[(t[o>>2]|0)+(t[c>>2]<<2)>>2]|0,376)|0){if(!(MY(t[(t[o>>2]|0)+(t[c>>2]<<2)>>2]|0,392)|0))break;do if(MY(t[(t[o>>2]|0)+(t[c>>2]<<2)>>2]|0,408)|0){if(!(MY(t[(t[o>>2]|0)+(t[c>>2]<<2)>>2]|0,416)|0))break;do if(MY(t[(t[o>>2]|0)+(t[c>>2]<<2)>>2]|0,432)|0){if(!(MY(t[(t[o>>2]|0)+(t[c>>2]<<2)>>2]|0,448)|0))break;do if(MY(t[(t[o>>2]|0)+(t[c>>2]<<2)>>2]|0,464)|0){if(!(MY(t[(t[o>>2]|0)+(t[c>>2]<<2)>>2]|0,472)|0))break;do if(MY(t[(t[o>>2]|0)+(t[c>>2]<<2)>>2]|0,480)|0){if(!(MY(t[(t[o>>2]|0)+(t[c>>2]<<2)>>2]|0,488)|0))break;if(!(MY(t[(t[o>>2]|0)+(t[c>>2]<<2)>>2]|0,496)|0))break;do if(MY(t[(t[o>>2]|0)+(t[c>>2]<<2)>>2]|0,520)|0){if(!(MY(t[(t[o>>2]|0)+(t[c>>2]<<2)>>2]|0,536)|0))break;do if(MY(t[(t[o>>2]|0)+(t[c>>2]<<2)>>2]|0,560)|0){if(!(MY(t[(t[o>>2]|0)+(t[c>>2]<<2)>>2]|0,568)|0))break;do if(MY(t[(t[o>>2]|0)+(t[c>>2]<<2)>>2]|0,592)|0){if(!(MY(t[(t[o>>2]|0)+(t[c>>2]<<2)>>2]|0,600)|0))break;do if(MY(t[(t[o>>2]|0)+(t[c>>2]<<2)>>2]|0,616)|0){if(!(MY(t[(t[o>>2]|0)+(t[c>>2]<<2)>>2]|0,624)|0))break;do if(MY(t[(t[o>>2]|0)+(t[c>>2]<<2)>>2]|0,648)|0){if(!(MY(t[(t[o>>2]|0)+(t[c>>2]<<2)>>2]|0,664)|0))break;do if(MY(t[(t[o>>2]|0)+(t[c>>2]<<2)>>2]|0,688)|0){if(!(MY(t[(t[o>>2]|0)+(t[c>>2]<<2)>>2]|0,704)|0))break;do if(MY(t[(t[o>>2]|0)+(t[c>>2]<<2)>>2]|0,728)|0){if(!(MY(t[(t[o>>2]|0)+(t[c>>2]<<2)>>2]|0,744)|0))break;do if(MY(t[(t[o>>2]|0)+(t[c>>2]<<2)>>2]|0,768)|0){if(!(MY(t[(t[o>>2]|0)+(t[c>>2]<<2)>>2]|0,776)|0))break;do if(MY(t[(t[o>>2]|0)+(t[c>>2]<<2)>>2]|0,792)|0){if(!(MY(t[(t[o>>2]|0)+(t[c>>2]<<2)>>2]|0,808)|0))break;do if(MY(t[(t[o>>2]|0)+(t[c>>2]<<2)>>2]|0,832)|0){if(!(MY(t[(t[o>>2]|0)+(t[c>>2]<<2)>>2]|0,848)|0))break;do if(MY(t[(t[o>>2]|0)+(t[c>>2]<<2)>>2]|0,872)|0){if(!(MY(t[(t[o>>2]|0)+(t[c>>2]<<2)>>2]|0,888)|0))break;do if(MY(t[(t[o>>2]|0)+(t[c>>2]<<2)>>2]|0,912)|0){if(!(MY(t[(t[o>>2]|0)+(t[c>>2]<<2)>>2]|0,928)|0))break;do if(MY(t[(t[o>>2]|0)+(t[c>>2]<<2)>>2]|0,952)|0){if(!(MY(t[(t[o>>2]|0)+(t[c>>2]<<2)>>2]|0,960)|0))break;do if(MY(t[(t[o>>2]|0)+(t[c>>2]<<2)>>2]|0,984)|0){if(!(MY(t[(t[o>>2]|0)+(t[c>>2]<<2)>>2]|0,992)|0))break;do if(MY(t[(t[o>>2]|0)+(t[c>>2]<<2)>>2]|0,1016)|0){if(!(MY(t[(t[o>>2]|0)+(t[c>>2]<<2)>>2]|0,1024)|0))break;do if(MY(t[(t[o>>2]|0)+(t[c>>2]<<2)>>2]|0,1040)|0){if(!(MY(t[(t[o>>2]|0)+(t[c>>2]<<2)>>2]|0,1048)|0))break;do if(MY(t[(t[o>>2]|0)+(t[c>>2]<<2)>>2]|0,1072)|0){if(!(MY(t[(t[o>>2]|0)+(t[c>>2]<<2)>>2]|0,1080)|0))break;do if(MY(t[(t[o>>2]|0)+(t[c>>2]<<2)>>2]|0,1096)|0){if(!(MY(t[(t[o>>2]|0)+(t[c>>2]<<2)>>2]|0,1112)|0))break;do if(MY(t[(t[o>>2]|0)+(t[c>>2]<<2)>>2]|0,1136)|0){if(!(MY(t[(t[o>>2]|0)+(t[c>>2]<<2)>>2]|0,1144)|0))break;do if(MY(t[(t[o>>2]|0)+(t[c>>2]<<2)>>2]|0,1168)|0){if(!(MY(t[(t[o>>2]|0)+(t[c>>2]<<2)>>2]|0,1176)|0))break;do if(MY(t[(t[o>>2]|0)+(t[c>>2]<<2)>>2]|0,1200)|0){if(!(MY(t[(t[o>>2]|0)+(t[c>>2]<<2)>>2]|0,1216)|0))break;do if(MY(t[(t[o>>2]|0)+(t[c>>2]<<2)>>2]|0,1240)|0){if(!(MY(t[(t[o>>2]|0)+(t[c>>2]<<2)>>2]|0,1256)|0))break;do if(MY(t[(t[o>>2]|0)+(t[c>>2]<<2)>>2]|0,1280)|0){if(!(MY(t[(t[o>>2]|0)+(t[c>>2]<<2)>>2]|0,1304)|0))break;do if(MY(t[(t[o>>2]|0)+(t[c>>2]<<2)>>2]|0,1328)|0){if(!(MY(t[(t[o>>2]|0)+(t[c>>2]<<2)>>2]|0,1344)|0))break;do if(MY(t[(t[o>>2]|0)+(t[c>>2]<<2)>>2]|0,1360)|0){if(!(MY(t[(t[o>>2]|0)+(t[c>>2]<<2)>>2]|0,1376)|0))break;do if(MY(t[(t[o>>2]|0)+(t[c>>2]<<2)>>2]|0,1392)|0){if(!(MY(t[(t[o>>2]|0)+(t[c>>2]<<2)>>2]|0,1408)|0))break;do if(MY(t[(t[o>>2]|0)+(t[c>>2]<<2)>>2]|0,1432)|0){if(!(MY(t[(t[o>>2]|0)+(t[c>>2]<<2)>>2]|0,1440)|0))break;do if(MY(t[(t[o>>2]|0)+(t[c>>2]<<2)>>2]|0,1456)|0){if(!(MY(t[(t[o>>2]|0)+(t[c>>2]<<2)>>2]|0,1464)|0))break;do if(MY(t[(t[o>>2]|0)+(t[c>>2]<<2)>>2]|0,1488)|0){if(!(MY(t[(t[o>>2]|0)+(t[c>>2]<<2)>>2]|0,1504)|0))break;do if(MY(t[(t[o>>2]|0)+(t[c>>2]<<2)>>2]|0,1528)|0){if(!(MY(t[(t[o>>2]|0)+(t[c>>2]<<2)>>2]|0,1544)|0))break;do if(MY(t[(t[o>>2]|0)+(t[c>>2]<<2)>>2]|0,1568)|0){if(!(MY(t[(t[o>>2]|0)+(t[c>>2]<<2)>>2]|0,1584)|0))break;do if(MY(t[(t[o>>2]|0)+(t[c>>2]<<2)>>2]|0,1608)|0){if(!(MY(t[(t[o>>2]|0)+(t[c>>2]<<2)>>2]|0,1616)|0))break;do if(MY(t[(t[o>>2]|0)+(t[c>>2]<<2)>>2]|0,1656)|0){if(!(MY(t[(t[o>>2]|0)+(t[c>>2]<<2)>>2]|0,1672)|0))break;do if(MY(t[(t[o>>2]|0)+(t[c>>2]<<2)>>2]|0,1696)|0){if(!(MY(t[(t[o>>2]|0)+(t[c>>2]<<2)>>2]|0,1704)|0))break;do if(MY(t[(t[o>>2]|0)+(t[c>>2]<<2)>>2]|0,1736)|0){if(!(MY(t[(t[o>>2]|0)+(t[c>>2]<<2)>>2]|0,1744)|0))break;do if(MY(t[(t[o>>2]|0)+(t[c>>2]<<2)>>2]|0,1768)|0){if(!(MY(t[(t[o>>2]|0)+(t[c>>2]<<2)>>2]|0,1776)|0))break;do if(MY(t[(t[o>>2]|0)+(t[c>>2]<<2)>>2]|0,1792)|0){if(!(MY(t[(t[o>>2]|0)+(t[c>>2]<<2)>>2]|0,1800)|0))break;do if(MY(t[(t[o>>2]|0)+(t[c>>2]<<2)>>2]|0,1824)|0){if(!(MY(t[(t[o>>2]|0)+(t[c>>2]<<2)>>2]|0,1832)|0))break;do if(MY(t[(t[o>>2]|0)+(t[c>>2]<<2)>>2]|0,1856)|0){if(!(MY(t[(t[o>>2]|0)+(t[c>>2]<<2)>>2]|0,1864)|0))break;do if(MY(t[(t[o>>2]|0)+(t[c>>2]<<2)>>2]|0,1880)|0){if(!(MY(t[(t[o>>2]|0)+(t[c>>2]<<2)>>2]|0,1888)|0))break;do if(MY(t[(t[o>>2]|0)+(t[c>>2]<<2)>>2]|0,1904)|0){if(!(MY(t[(t[o>>2]|0)+(t[c>>2]<<2)>>2]|0,1920)|0))break;do if(MY(t[(t[o>>2]|0)+(t[c>>2]<<2)>>2]|0,1944)|0){if(!(MY(t[(t[o>>2]|0)+(t[c>>2]<<2)>>2]|0,1960)|0))break;do if(MY(t[(t[o>>2]|0)+(t[c>>2]<<2)>>2]|0,1984)|0){if(!(MY(t[(t[o>>2]|0)+(t[c>>2]<<2)>>2]|0,1992)|0))break;do if(MY(t[(t[o>>2]|0)+(t[c>>2]<<2)>>2]|0,2016)|0){if(!(MY(t[(t[o>>2]|0)+(t[c>>2]<<2)>>2]|0,2032)|0))break;do if(MY(t[(t[o>>2]|0)+(t[c>>2]<<2)>>2]|0,2056)|0){if(!(MY(t[(t[o>>2]|0)+(t[c>>2]<<2)>>2]|0,2064)|0))break;do if(MY(t[(t[o>>2]|0)+(t[c>>2]<<2)>>2]|0,2072)|0){if(!(MY(t[(t[o>>2]|0)+(t[c>>2]<<2)>>2]|0,2088)|0))break;do if(MY(t[(t[o>>2]|0)+(t[c>>2]<<2)>>2]|0,2104)|0){if(!(MY(t[(t[o>>2]|0)+(t[c>>2]<<2)>>2]|0,2120)|0))break;do if(MY(t[(t[o>>2]|0)+(t[c>>2]<<2)>>2]|0,2144)|0){if(!(MY(t[(t[o>>2]|0)+(t[c>>2]<<2)>>2]|0,2152)|0))break;do if(MY(t[(t[o>>2]|0)+(t[c>>2]<<2)>>2]|0,2160)|0){if(!(MY(t[(t[o>>2]|0)+(t[c>>2]<<2)>>2]|0,2176)|0))break;do if(MY(t[(t[o>>2]|0)+(t[c>>2]<<2)>>2]|0,2200)|0){if(!(MY(t[(t[o>>2]|0)+(t[c>>2]<<2)>>2]|0,2208)|0))break;if((MY(t[(t[o>>2]|0)+(t[c>>2]<<2)>>2]|0,2224)|0)!=0?(MY(t[(t[o>>2]|0)+(t[c>>2]<<2)>>2]|0,2240)|0)!=0:0){S=206;break e}t[564]=(t[564]|0)+1;t[68]=t[68]|131072;break i}while(0);t[c>>2]=(t[c>>2]|0)+1;t[50]=(t[50]|0)+1;t[554]=t[(t[o>>2]|0)+(t[c>>2]<<2)>>2];break i}while(0);t[c>>2]=(t[c>>2]|0)+1;t[548]=t[(t[o>>2]|0)+(t[c>>2]<<2)>>2];break i}while(0);t[c>>2]=(t[c>>2]|0)+1;sm(t[(t[o>>2]|0)+(t[c>>2]<<2)>>2]|0);break i}while(0);t[534]=(t[534]|0)+1;break i}while(0);t[68]=t[68]&-65537;break i}while(0);t[68]=t[68]|2048;fA(199);break i}while(0);t[c>>2]=(t[c>>2]|0)+1;t[512]=t[(t[o>>2]|0)+(t[c>>2]<<2)>>2];t[78]=(t[78]|0)+1;break i}while(0);t[c>>2]=(t[c>>2]|0)+1;t[502]=t[(t[o>>2]|0)+(t[c>>2]<<2)>>2];t[78]=(t[78]|0)+1;break i}while(0);t[c>>2]=(t[c>>2]|0)+1;t[494]=t[(t[o>>2]|0)+(t[c>>2]<<2)>>2];t[78]=(t[78]|0)+1;t[68]=t[68]|2;break i}while(0);t[484]=(t[484]|0)+1;break i}while(0);t[474]=(t[474]|0)+1;break i}while(0);t[468]=(t[468]|0)+1;t[68]=t[68]|512;break i}while(0);t[462]=(t[462]|0)+1;t[50]=(t[50]|0)+1;break i}while(0);t[454]=(t[454]|0)+1;break i}while(0);t[c>>2]=(t[c>>2]|0)+1;if(!(t[(t[o>>2]|0)+(t[c>>2]<<2)>>2]|0))break i;t[440]=FY(t[(t[o>>2]|0)+(t[c>>2]<<2)>>2]|0)|0;if((t[440]|0)!=1)break i;t[422]=(t[422]|0)+1;Wp(0)|0;break i}while(0);t[422]=(t[422]|0)+1;t[440]=1;Wp(0)|0;break i}while(0);t[c>>2]=(t[c>>2]|0)+1;i=t[(t[o>>2]|0)+(t[c>>2]<<2)>>2]|0;t[f>>2]=1728;if((jq(i,1720,f)|0)==1){PA(195,196,197,198)|0;break i}else{t[432]=0;break i}}while(0);t[422]=(t[422]|0)+1;Wp(0)|0;t[68]=t[68]|256;break i}while(0);t[c>>2]=(t[c>>2]|0)+1;t[408]=t[(t[o>>2]|0)+(t[c>>2]<<2)>>2];P_(1640,1648)|0;break i}while(0);t[400]=(t[400]|0)+1;break i}while(0);t[390]=(t[390]|0)+1;break i}while(0);t[380]=(t[380]|0)+1;t[68]=t[68]|14;break i}while(0);t[370]=(t[370]|0)+1;t[68]=t[68]|14;break i}while(0);t[362]=(t[362]|0)+1;t[68]=t[68]|14;break i}while(0);t[356]=(t[356]|0)+1;t[33952]=1;break i}while(0);t[33956]=1;qp(1)|0;t[68]=t[68]|128;break i}while(0);t[33956]=0;qp(0)|0;t[68]=t[68]|64;break i}while(0);t[308]=(t[308]|0)+1;t[68]=t[68]|1024;t[68]=t[68]|262144;break i}while(0);t[308]=(t[308]|0)+1;t[68]=t[68]|1024;t[68]=t[68]|32768;break i}while(0);t[308]=(t[308]|0)+1;t[68]=t[68]|1024;break i}while(0);t[298]=(t[298]|0)+1;break i}while(0);t[290]=(t[290]|0)+1;break i}while(0);t[272]=(t[272]|0)+1;t[282]=10;break i}while(0);t[272]=(t[272]|0)+1;break i}while(0);if(t[266]|0){t[266]=(t[266]|0)*10;break i}else{t[266]=100;break i}}while(0);t[258]=(t[258]|0)+1;break i}while(0);t[252]=(t[252]|0)+1;break i}while(0);t[244]=(t[244]|0)+1;break i}while(0);t[236]=(t[236]|0)+1;break i}while(0);t[c>>2]=(t[c>>2]|0)+1;t[226]=t[(t[o>>2]|0)+(t[c>>2]<<2)>>2];t[180]=(t[180]|0)+1;t[68]=t[68]|4;break i}while(0);t[c>>2]=(t[c>>2]|0)+1;t[216]=t[(t[o>>2]|0)+(t[c>>2]<<2)>>2];t[180]=(t[180]|0)+1;t[68]=t[68]|4;break i}while(0);t[206]=(t[206]|0)+1;t[180]=(t[180]|0)+1;t[68]=t[68]|4;break i}while(0);t[196]=(t[196]|0)+1;t[68]=t[68]|16;break i}while(0);t[180]=(t[180]|0)+1;t[190]=(t[190]|0)+1;t[68]=t[68]|8;break i}while(0);t[180]=(t[180]|0)+1;t[68]=t[68]|4;break i}while(0);t[170]=(t[170]|0)+1;t[68]=t[68]|4;break i}while(0);t[160]=(t[160]|0)+1;break i}while(0);t[152]=(t[152]|0)+1;break i}while(0);t[146]=(t[146]|0)+1;break i}while(0);t[138]=(t[138]|0)+1;break i}while(0);t[c>>2]=(t[c>>2]|0)+1;t[128]=t[(t[o>>2]|0)+(t[c>>2]<<2)>>2];break i}while(0);t[50]=(t[50]|0)+1;break i}while(0);um(t[t[o>>2]>>2]|0);t[k>>2]=1;break i}while(0);t[68]=t[68]|4096;break i}while(0);t[68]=t[68]|16384;break i}while(0);t[68]=t[68]|8192;break i}while(0);t[84]=(t[84]|0)+1;t[68]=t[68]|2097152;break i}while(0);t[78]=(t[78]|0)+1;t[68]=t[68]|2;break i}while(0);t[68]=t[68]|524288;break}t[66]=(t[66]|0)+1;t[68]=t[68]|1;break}t[56]=(t[56]|0)+1;break}t[48]=(t[48]|0)+1;t[50]=1;break}t[42]=(t[42]|0)+1}while(0);t[c>>2]=(t[c>>2]|0)+1}if((S|0)==206){i=t[v>>2]|0;t[f>>2]=t[(t[o>>2]|0)+(t[c>>2]<<2)>>2];xe(i|0,2264,f|0)|0;tm(t[t[o>>2]>>2]|0);t[u>>2]=1;E=t[u>>2]|0;s=r;return E|0}do if((t[400]|0)==0&(t[390]|0)!=0){t[w>>2]=ti(2288)|0;if(t[w>>2]|0){ac(t[w>>2]|0);break}else{xe(t[v>>2]|0,2312,f|0)|0;break}}while(0);if(t[468]|0)ej(1)|0;else ej(2)|0;if(t[484]|0){Gc(200)|0;Wc(201)|0}t[h>>2]=ti(2352)|0;if(t[h>>2]|0)t[33988]=t[h>>2];t[592]=tA()|0;fA(202);Yp(1)|0;if(t[180]|0)t[33958]=t[33958]|2;if(t[190]|0)t[33958]=t[33958]|4;if(t[78]|0)Gp(1)|0;if(t[196]|0)t[33954]=1;if(!((t[138]|0)==0|(t[146]|0)!=0)){yAi[t[135904>>2]&511](t[33980]|0,2376,f);yAi[t[135904>>2]&511](t[33980]|0,2440,f);h=t[33976]|0;w=t[33980]|0;t[f>>2]=t[t[o>>2]>>2];yAi[h&511](w,2488,f);w=t[33976]|0;h=t[33980]|0;t[f>>2]=t[t[o>>2]>>2];yAi[w&511](h,2536,f)}if((t[512]|0)!=0&(t[474]|0)==0&(t[454]|0)==0){t[33958]=t[33958]|1;t[68]=t[68]|4;if(t[252]|0)wm();t[d>>2]=XV(t[512]|0)|0;t[650]=JV(t[d>>2]|0)|0;if(!(t[650]|0)){h=t[33976]|0;w=t[33980]|0;t[f>>2]=t[512];yAi[h&511](w,2608,f);t[662]=5;t[512]=0}ZV(t[d>>2]|0);if(t[252]|0)dm(2656,f)}if((t[494]|0)!=0&(t[474]|0)==0&(t[454]|0)==0){t[33958]=t[33958]|1;t[68]=t[68]|4;if(t[252]|0)wm();t[m>>2]=IH(t[494]|0)|0;UH(t[m>>2]|0,203,203,t[v>>2]|0);t[670]=xH(t[m>>2]|0)|0;if(!(t[670]|0)){d=t[33976]|0;w=t[33980]|0;t[f>>2]=t[494];yAi[d&511](w,2688,f);t[662]=5;t[494]=0}HH(t[m>>2]|0);if(t[252]|0)dm(2656,f)}else if((t[502]|0)!=0&(t[454]|0)==0){if(t[252]|0)wm();t[_>>2]=Mk(t[502]|0)|0;Dk(t[_>>2]|0,203,203,t[v>>2]|0);t[682]=Lk(t[_>>2]|0)|0;if(!(t[682]|0)){m=t[33976]|0;w=t[33980]|0;t[f>>2]=t[502];yAi[m&511](w,2736,f);t[662]=5;t[502]=0}Rk(t[_>>2]|0);if(t[252]|0)dm(2656,f)}if((t[548]|0)!=0&(t[462]|0)==0?(t[694]=Fj(t[548]|0,0,0,0)|0,(t[694]|0)==0):0){_=t[33976]|0;w=t[33980]|0;t[f>>2]=t[548];yAi[_&511](w,2784,f);t[662]=7;t[548]=0}t[c>>2]=1;while(1){if((t[c>>2]|0)>=(t[a>>2]|0))break;e:do if((MY(t[(t[o>>2]|0)+(t[c>>2]<<2)>>2]|0,1608)|0)!=0?(MY(t[(t[o>>2]|0)+(t[c>>2]<<2)>>2]|0,1616)|0)!=0:0){do if(MY(t[(t[o>>2]|0)+(t[c>>2]<<2)>>2]|0,480)|0){if(!(MY(t[(t[o>>2]|0)+(t[c>>2]<<2)>>2]|0,488)|0))break;if(!(MY(t[(t[o>>2]|0)+(t[c>>2]<<2)>>2]|0,496)|0))break;do if(MY(t[(t[o>>2]|0)+(t[c>>2]<<2)>>2]|0,832)|0){if(!(MY(t[(t[o>>2]|0)+(t[c>>2]<<2)>>2]|0,848)|0))break;do if(MY(t[(t[o>>2]|0)+(t[c>>2]<<2)>>2]|0,2144)|0){if(!(MY(t[(t[o>>2]|0)+(t[c>>2]<<2)>>2]|0,2152)|0))break;do if(MY(t[(t[o>>2]|0)+(t[c>>2]<<2)>>2]|0,872)|0){if(!(MY(t[(t[o>>2]|0)+(t[c>>2]<<2)>>2]|0,888)|0))break;do if(MY(t[(t[o>>2]|0)+(t[c>>2]<<2)>>2]|0,1944)|0){if(!(MY(t[(t[o>>2]|0)+(t[c>>2]<<2)>>2]|0,1960)|0))break;do if(MY(t[(t[o>>2]|0)+(t[c>>2]<<2)>>2]|0,1696)|0){if(!(MY(t[(t[o>>2]|0)+(t[c>>2]<<2)>>2]|0,1704)|0))break;do if(MY(t[(t[o>>2]|0)+(t[c>>2]<<2)>>2]|0,1768)|0){if(!(MY(t[(t[o>>2]|0)+(t[c>>2]<<2)>>2]|0,1776)|0))break;do if(MY(t[(t[o>>2]|0)+(t[c>>2]<<2)>>2]|0,1984)|0){if(!(MY(t[(t[o>>2]|0)+(t[c>>2]<<2)>>2]|0,1992)|0))break;do if(MY(t[(t[o>>2]|0)+(t[c>>2]<<2)>>2]|0,2016)|0){if(!(MY(t[(t[o>>2]|0)+(t[c>>2]<<2)>>2]|0,2032)|0))break;do if(MY(t[(t[o>>2]|0)+(t[c>>2]<<2)>>2]|0,2160)|0){if(!(MY(t[(t[o>>2]|0)+(t[c>>2]<<2)>>2]|0,2176)|0))break;do if(MY(t[(t[o>>2]|0)+(t[c>>2]<<2)>>2]|0,2200)|0){if(!(MY(t[(t[o>>2]|0)+(t[c>>2]<<2)>>2]|0,2208)|0))break;if((t[252]|0)!=0&(t[266]|0)!=0)wm();if((n[t[(t[o>>2]|0)+(t[c>>2]<<2)>>2]>>0]|0)==45?(MY(t[(t[o>>2]|0)+(t[c>>2]<<2)>>2]|0,144)|0)!=0:0)break e;do if(t[266]|0){t[p>>2]=0;t[l>>2]=0;while(1){if((t[l>>2]|0)>=(t[266]|0))break;do if(t[454]|0)vm(t[(t[o>>2]|0)+(t[c>>2]<<2)>>2]|0);else{if(t[474]|0){mm(t[(t[o>>2]|0)+(t[c>>2]<<2)>>2]|0);break}if(!(t[p>>2]|0))t[p>>2]=zp()|0;_m(t[(t[o>>2]|0)+(t[c>>2]<<2)>>2]|0,t[p>>2]|0)}while(0);t[l>>2]=(t[l>>2]|0)+1}if(!(t[p>>2]|0))break;Up(t[p>>2]|0)}else{t[704]=0;do if(!(t[454]|0)){w=t[(t[o>>2]|0)+(t[c>>2]<<2)>>2]|0;if(t[474]|0){mm(w);break}else{_m(w,0);break}}else vm(t[(t[o>>2]|0)+(t[c>>2]<<2)>>2]|0);while(0);if(!((t[484]|0)!=0&(t[704]|0)!=0))break;w=t[v>>2]|0;t[f>>2]=t[704];xe(w|0,2824,f|0)|0;t[662]=8}while(0);t[b>>2]=(t[b>>2]|0)+1;if(!((t[252]|0)!=0&(t[266]|0)!=0))break e;t[f>>2]=t[266];dm(2856,f);break e}while(0);t[c>>2]=(t[c>>2]|0)+1;break e}while(0);t[c>>2]=(t[c>>2]|0)+1;break e}while(0);t[c>>2]=(t[c>>2]|0)+1;break e}while(0);t[c>>2]=(t[c>>2]|0)+1;break e}while(0);t[c>>2]=(t[c>>2]|0)+1;break e}while(0);t[c>>2]=(t[c>>2]|0)+1;break e}while(0);t[c>>2]=(t[c>>2]|0)+1;break e}while(0);t[c>>2]=(t[c>>2]|0)+1;break e}while(0);t[c>>2]=(t[c>>2]|0)+1;break e}while(0);t[c>>2]=(t[c>>2]|0)+1;break e}while(0);t[c>>2]=(t[c>>2]|0)+1}else S=257;while(0);if((S|0)==257){S=0;t[c>>2]=(t[c>>2]|0)+1}t[c>>2]=(t[c>>2]|0)+1}if(t[258]|0)_m(0,0);if(!((t[138]|0)==0|(t[146]|0)!=0))yAi[t[135904>>2]&511](t[33980]|0,2872,f);if((((t[b>>2]|0)!=0|(t[258]|0)!=0)^1)&(t[k>>2]|0)==0)tm(t[t[o>>2]>>2]|0);if(t[650]|0)KV(t[650]|0);if(t[670]|0)CH(t[670]|0);if(t[682]|0)Ak(t[682]|0);BH();if(t[694]|0)vj(t[694]|0);dS();FA();t[u>>2]=t[662];E=t[u>>2]|0;s=r;return E|0}function tm(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i;n=i+4|0;t[n>>2]=e;t[r>>2]=t[n>>2];Je(56872,r|0)|0;Je(56912,r|0)|0;Je(56976,r|0)|0;Je(57040,r|0)|0;Je(57096,r|0)|0;Je(57136,r|0)|0;Je(57200,r|0)|0;Je(57264,r|0)|0;Je(57328,r|0)|0;Je(57384,r|0)|0;Je(57440,r|0)|0;Je(57504,r|0)|0;Je(57552,r|0)|0;Je(57608,r|0)|0;Je(57672,r|0)|0;Je(57736,r|0)|0;Je(57792,r|0)|0;Je(57832,r|0)|0;Je(57880,r|0)|0;Je(57952,r|0)|0;Je(58016,r|0)|0;Je(58088,r|0)|0;Je(58160,r|0)|0;Je(58192,r|0)|0;Je(58248,r|0)|0;Je(58304,r|0)|0;Je(58352,r|0)|0;Je(58384,r|0)|0;Je(58448,r|0)|0;Je(58496,r|0)|0;Je(58544,r|0)|0;Je(58616,r|0)|0;Je(58648,r|0)|0;Je(58712,r|0)|0;Je(58776,r|0)|0;Je(58824,r|0)|0;Je(58880,r|0)|0;Je(58928,r|0)|0;Je(58984,r|0)|0;Je(59040,r|0)|0;Je(59096,r|0)|0;Je(59144,r|0)|0;Je(59208,r|0)|0;Je(59280,r|0)|0;Je(59344,r|0)|0;Je(59408,r|0)|0;Je(59480,r|0)|0;Je(59536,r|0)|0;Je(59576,r|0)|0;Je(59640,r|0)|0;t[r>>2]=59736;Je(59696,r|0)|0;Je(59760,r|0)|0;Je(59800,r|0)|0;Je(59848,r|0)|0;Je(59888,r|0)|0;Je(59952,r|0)|0;Je(60008,r|0)|0;Je(60048,r|0)|0;Je(60120,r|0)|0;Je(60192,r|0)|0;Je(60256,r|0)|0;Je(60312,r|0)|0;Je(60368,r|0)|0;Je(60432,r|0)|0;Je(60496,r|0)|0;Je(60560,r|0)|0;Je(60616,r|0)|0;Je(60680,r|0)|0;Je(60744,r|0)|0;Je(60808,r|0)|0;Je(60856,r|0)|0;s=i;return}function um(e){e=e|0;var i=0,r=0,n=0,f=0,u=0;i=s;s=s+16|0;r=i;n=i+8|0;t[n>>2]=e;e=t[v>>2]|0;f=t[33946]|0;t[r>>2]=t[n>>2];t[r+4>>2]=f;xe(e|0,56440,r|0)|0;xe(t[v>>2]|0,56472,r|0)|0;if(Qp(1)|0)xe(t[v>>2]|0,56496,r|0)|0;if(Qp(2)|0)xe(t[v>>2]|0,56512,r|0)|0;if(Qp(3)|0)xe(t[v>>2]|0,56520,r|0)|0;if(Qp(4)|0)xe(t[v>>2]|0,56528,r|0)|0;if(Qp(5)|0)xe(t[v>>2]|0,56536,r|0)|0;if(Qp(6)|0)xe(t[v>>2]|0,56544,r|0)|0;if(Qp(7)|0)xe(t[v>>2]|0,56560,r|0)|0;if(Qp(8)|0)xe(t[v>>2]|0,56568,r|0)|0;if(Qp(9)|0)xe(t[v>>2]|0,56576,r|0)|0;if(Qp(10)|0)xe(t[v>>2]|0,56584,r|0)|0;if(Qp(11)|0)xe(t[v>>2]|0,56592,r|0)|0;if(Qp(12)|0)xe(t[v>>2]|0,56608,r|0)|0;if(Qp(13)|0)xe(t[v>>2]|0,56616,r|0)|0;if(Qp(14)|0)xe(t[v>>2]|0,56624,r|0)|0;if(Qp(15)|0)xe(t[v>>2]|0,56632,r|0)|0;if(Qp(16)|0)xe(t[v>>2]|0,56648,r|0)|0;if(Qp(17)|0)xe(t[v>>2]|0,56656,r|0)|0;if(Qp(18)|0)xe(t[v>>2]|0,56672,r|0)|0;if(Qp(19)|0)xe(t[v>>2]|0,56688,r|0)|0;if(Qp(20)|0)xe(t[v>>2]|0,56696,r|0)|0;if(Qp(21)|0)xe(t[v>>2]|0,56712,r|0)|0;if(Qp(22)|0)xe(t[v>>2]|0,56728,r|0)|0;if(Qp(23)|0)xe(t[v>>2]|0,56744,r|0)|0;if(Qp(24)|0)xe(t[v>>2]|0,56760,r|0)|0;if(Qp(25)|0)xe(t[v>>2]|0,56768,r|0)|0;if(Qp(26)|0)xe(t[v>>2]|0,56784,r|0)|0;if(Qp(27)|0)xe(t[v>>2]|0,56800,r|0)|0;if(Qp(28)|0)xe(t[v>>2]|0,56816,r|0)|0;if(Qp(29)|0)xe(t[v>>2]|0,56824,r|0)|0;if(Qp(30)|0)xe(t[v>>2]|0,56840,r|0)|0;if(Qp(31)|0)xe(t[v>>2]|0,56856,r|0)|0;if(!(Qp(33)|0)){u=t[v>>2]|0;xe(u|0,3760,r|0)|0;s=i;return}xe(t[v>>2]|0,56864,r|0)|0;u=t[v>>2]|0;xe(u|0,3760,r|0)|0;s=i;return}function am(e){e=e|0;var i=0,r=0;i=s;s=s+16|0;r=i;t[r>>2]=e;RA(t[r>>2]|0);s=i;return}function om(e){e=e|0;var i=0,r=0,n=0,f=0,u=0;i=s;s=s+16|0;r=i+8|0;n=i+4|0;f=i;t[n>>2]=e;t[f>>2]=OA(t[n>>2]|0)|0;if((t[f>>2]|0)!=0?(n=LA()|0,(n|0)>(t[432]|0)):0){a_();RA(t[f>>2]|0);t[r>>2]=0;u=t[r>>2]|0;s=i;return u|0}t[r>>2]=t[f>>2];u=t[r>>2]|0;s=i;return u|0}function cm(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0;r=s;s=s+16|0;n=r+12|0;f=r+8|0;u=r+4|0;a=r;t[f>>2]=e;t[u>>2]=i;t[a>>2]=MA(t[f>>2]|0,t[u>>2]|0)|0;if((t[a>>2]|0)!=0?(u=LA()|0,(u|0)>(t[432]|0)):0){a_();RA(t[a>>2]|0);t[n>>2]=0;o=t[n>>2]|0;s=r;return o|0}t[n>>2]=t[a>>2];o=t[n>>2]|0;s=r;return o|0}function lm(e){e=e|0;var i=0,r=0,n=0,f=0,u=0;i=s;s=s+16|0;r=i+8|0;n=i+4|0;f=i;t[n>>2]=e;t[f>>2]=TA(t[n>>2]|0)|0;if((t[f>>2]|0)!=0?(n=LA()|0,(n|0)>(t[432]|0)):0){a_();pAi[t[135736>>2]&511](t[f>>2]|0);t[r>>2]=0;u=t[r>>2]|0;s=i;return u|0}t[r>>2]=t[f>>2];u=t[r>>2]|0;s=i;return u|0}function sm(e){e=e|0;var i=0,r=0,n=0,f=0,a=0,o=0,c=0,l=0,b=0;i=s;s=s+16|0;r=i;n=i+8|0;f=i+4|0;t[n>>2]=e;if(!(t[n>>2]|0)){s=i;return}while(1){if(!(u[t[n>>2]>>0]|0)){a=20;break}if((t[13962]|0)>=64)break;t[f>>2]=t[n>>2];while(1){if((u[t[f>>2]>>0]|0|0)==32)o=1;else o=(u[t[f>>2]>>0]|0|0)==58;c=t[f>>2]|0;if(!o)break;t[f>>2]=c+1}t[n>>2]=c;while(1){if((u[t[f>>2]>>0]|0|0)!=0?(u[t[f>>2]>>0]|0|0)!=32:0)l=(u[t[f>>2]>>0]|0|0)!=58;else l=0;b=t[f>>2]|0;if(!l)break;t[f>>2]=b+1}if((b|0)==(t[n>>2]|0))continue;e=ql(t[n>>2]|0,(t[f>>2]|0)-(t[n>>2]|0)|0)|0;t[55888+(t[13962]<<2)>>2]=e;if(t[55888+(t[13962]<<2)>>2]|0)t[13962]=(t[13962]|0)+1;t[n>>2]=t[f>>2]}if((a|0)==20){s=i;return}xe(t[v>>2]|0,56360,r|0)|0;s=i;return}function bm(e){e=e|0;var i=0,r=0;i=s;s=s+16|0;r=i+4|0;t[r>>2]=e;e=Xq(4)|0;t[t[r>>2]>>2]=e;if(!(t[t[r>>2]>>2]|0)){xe(t[v>>2]|0,56312,i|0)|0;_i(9)}else{t[t[t[r>>2]>>2]>>2]=-2123209900;t[704]=(t[704]|0)+1;s=i;return}}function km(e){e=e|0;var i=0,r=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if(!(t[t[r>>2]>>2]|0))De(56200,56224,3119,56248);if((t[t[t[r>>2]>>2]>>2]|0)==-2123209900){Zq(t[t[r>>2]>>2]|0);t[704]=(t[704]|0)+-1;s=i;return}else De(56264,56224,3120,56248)}function hm(e,i,r){e=e|0;i=i|0;r=r|0;var f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,m=0,_=0,p=0,E=0;f=s;s=s+64|0;u=f;a=f+48|0;o=f+44|0;c=f+40|0;l=f+36|0;b=f+32|0;k=f+28|0;h=f+24|0;w=f+20|0;d=f+16|0;m=f+12|0;_=f+8|0;t[o>>2]=e;t[c>>2]=i;t[l>>2]=r;t[k>>2]=0;t[h>>2]=0;t[d>>2]=t[o>>2];t[m>>2]=t[o>>2];e:do if((t[13962]|0)>0&(t[m>>2]|0)!=0)while(1){if(!(n[t[m>>2]>>0]|0))break e;if((n[t[m>>2]>>0]|0)==47)t[d>>2]=(t[m>>2]|0)+1;t[m>>2]=(t[m>>2]|0)+1}while(0);if((t[l>>2]|0)!=0?(t[t[l>>2]>>2]|0)!=0:0){t[k>>2]=t[(t[t[l>>2]>>2]|0)+84>>2];t[h>>2]=t[(t[t[l>>2]>>2]|0)+88>>2];t[(t[t[l>>2]>>2]|0)+84>>2]=0;t[(t[t[l>>2]>>2]|0)+88>>2]=0}if((t[592]|0)!=0?(t[b>>2]=dAi[t[2368>>2]&511](t[o>>2]|0,t[c>>2]|0,t[l>>2]|0)|0,(t[b>>2]|0)!=0):0){if(t[k>>2]|0)t[(t[t[l>>2]>>2]|0)+84>>2]=t[k>>2];if(t[h>>2]|0)t[(t[t[l>>2]>>2]|0)+88>>2]=t[h>>2];if(t[534]|0){m=t[v>>2]|0;r=(t[c>>2]|0)!=0?t[c>>2]|0:55152;t[u>>2]=(t[o>>2]|0)!=0?t[o>>2]|0:55152;t[u+4>>2]=r;xe(m|0,55856,u|0)|0}t[a>>2]=t[b>>2];p=t[a>>2]|0;s=f;return p|0}t[w>>2]=0;while(1){if((t[w>>2]|0)>=(t[13962]|0))break;t[_>>2]=Yl(t[55888+(t[w>>2]<<2)>>2]|0)|0;t[_>>2]=us(t[_>>2]|0,56152)|0;t[_>>2]=us(t[_>>2]|0,t[d>>2]|0)|0;if(t[_>>2]|0){t[b>>2]=dAi[t[2368>>2]&511](t[_>>2]|0,t[c>>2]|0,t[l>>2]|0)|0;if(t[b>>2]|0){E=22;break}pAi[t[135736>>2]&511](t[_>>2]|0)}t[w>>2]=(t[w>>2]|0)+1}if((E|0)==22){if(t[k>>2]|0)t[(t[t[l>>2]>>2]|0)+84>>2]=t[k>>2];if(t[h>>2]|0)t[(t[t[l>>2]>>2]|0)+88>>2]=t[h>>2];if(t[534]|0){E=t[v>>2]|0;w=(t[c>>2]|0)!=0?t[c>>2]|0:55152;t[u>>2]=t[_>>2];t[u+4>>2]=w;xe(E|0,55856,u|0)|0}pAi[t[135736>>2]&511](t[_>>2]|0);t[a>>2]=t[b>>2];p=t[a>>2]|0;s=f;return p|0}if(t[h>>2]|0)t[(t[t[l>>2]>>2]|0)+88>>2]=t[h>>2];do if(t[k>>2]|0){t[(t[t[l>>2]>>2]|0)+84>>2]=t[k>>2];if(t[o>>2]|0){h=t[k>>2]|0;b=t[l>>2]|0;t[u>>2]=t[o>>2];yAi[h&511](b,56160,u);break}if(t[c>>2]|0){b=t[k>>2]|0;h=t[l>>2]|0;t[u>>2]=t[c>>2];yAi[b&511](h,56160,u)}}while(0);t[a>>2]=0;p=t[a>>2]|0;s=f;return p|0}function wm(){var e=0;e=s;wi(55824,0)|0;s=e;return}function dm(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0;r=s;s=s+32|0;n=r;f=r+28|0;u=r+24|0;a=r+8|0;t[f>>2]=e;wi(55816,0)|0;t[u>>2]=(t[13954]|0)-(t[13956]|0);t[u>>2]=(t[u>>2]|0)*1e3;t[u>>2]=(t[u>>2]|0)+(((t[13955]|0)-(t[13957]|0)|0)/1e3|0);t[a>>2]=i;Te(t[v>>2]|0,t[f>>2]|0,a|0)|0;a=t[v>>2]|0;t[n>>2]=t[u>>2];xe(a|0,55832,n|0)|0;s=r;return}function vm(e){e=e|0;var i=0,r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0;i=s;s=s+112|0;r=i;n=i+100|0;f=i+96|0;u=i+92|0;a=i+88|0;o=i+12|0;c=i+8|0;l=i+4|0;t[n>>2]=e;t[a>>2]=-1;t[c>>2]=0;t[l>>2]=0;e=t[n>>2]|0;do if(t[290]|0){if((ri(e|0,o|0)|0)<0){s=i;return}b=Ue(t[n>>2]|0,0,r|0)|0;t[a>>2]=b;if((b|0)<0){s=i;return}t[c>>2]=vi(0,t[o+36>>2]|0,1,1,t[a>>2]|0,0)|0;if((t[c>>2]|0)!=(-1|0)){t[f>>2]=JI(t[c>>2]|0,t[o+36>>2]|0,t[n>>2]|0,0,t[68]|0)|0;break}Ge(t[a>>2]|0)|0;b=t[v>>2]|0;t[r>>2]=t[n>>2];xe(b|0,2920,r|0)|0;t[662]=4;s=i;return}else t[f>>2]=QI(e,0,t[68]|0)|0;while(0);if((t[548]|0)!=0?(t[694]=Fj(t[548]|0,0,0,0)|0,(t[694]|0)==0):0){e=t[33976]|0;b=t[33980]|0;t[r>>2]=t[548];yAi[e&511](b,2784,r);t[662]=7;t[548]=0}if(((t[694]|0)!=0?(t[898]=Aj(t[694]|0)|0,(t[898]|0)!=0):0)?(t[u>>2]=pj(t[898]|0,0,0)|0,(t[u>>2]|0)<0):0){xe(t[v>>2]|0,3600,r|0)|0;_j(t[898]|0);t[898]=0}if(t[f>>2]|0){if(!(t[196]|0)){if(t[180]|0)qI(t[f>>2]|0,1,1)|0}else qI(t[f>>2]|0,3,1)|0;if(t[494]|0){if(!((t[252]|0)==0|(t[266]|0)!=0))wm();t[u>>2]=WI(t[f>>2]|0,t[494]|0)|0;if((t[u>>2]|0)<0){b=t[33976]|0;e=t[33980]|0;t[r>>2]=t[494];yAi[b&511](e,2688,r);t[662]=5;t[494]=0}if(!((t[252]|0)==0|(t[266]|0)!=0))dm(2656,r)}if(t[502]|0){if(!((t[252]|0)==0|(t[266]|0)!=0))wm();t[u>>2]=GI(t[f>>2]|0,t[502]|0)|0;if((t[u>>2]|0)<0){e=t[33976]|0;b=t[33980]|0;t[r>>2]=t[502];yAi[e&511](b,55704,r);t[662]=5;t[502]=0}if(!((t[252]|0)==0|(t[266]|0)!=0))dm(2656,r)}if(!((t[252]|0)==0|(t[266]|0)!=0))wm();t[u>>2]=RI(t[f>>2]|0)|0;while(1){if((t[u>>2]|0)!=1)break;if((t[42]|0)!=0|(t[694]|0)!=0)Rm(t[f>>2]|0);t[u>>2]=RI(t[f>>2]|0)|0}do if(!((t[252]|0)==0|(t[266]|0)!=0)){if(t[494]|0){dm(55744,r);break}if(t[196]|0){dm(55744,r);break}else{dm(2952,r);break}}while(0);if((t[196]|0)!=0?(KI(t[f>>2]|0)|0)!=1:0){b=t[33976]|0;e=t[33980]|0;t[r>>2]=t[n>>2];yAi[b&511](e,3448,r);t[662]=3}do if((t[494]|0)!=0|(t[502]|0)!=0){e=(KI(t[f>>2]|0)|0)!=1;b=t[v>>2]|0;k=t[n>>2]|0;if(e){t[r>>2]=k;xe(b|0,3512,r|0)|0;t[662]=3;break}else{t[r>>2]=k;xe(b|0,3496,r|0)|0;break}}while(0);CI(t[f>>2]|0);if(t[u>>2]|0){u=t[v>>2]|0;t[r>>2]=t[n>>2];xe(u|0,55768,r|0)|0;t[662]=1}}else{u=t[v>>2]|0;t[r>>2]=t[n>>2];xe(u|0,55792,r|0)|0;t[662]=1}if(t[898]|0){_j(t[898]|0);t[898]=0}if(!(t[290]|0)){s=i;return}IO(t[l>>2]|0);Ke(t[c>>2]|0,t[o+36>>2]|0)|0;Ge(t[a>>2]|0)|0;s=i;return}function mm(e){e=e|0;var i=0,r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0;i=s;s=s+48|0;r=i;n=i+36|0;f=i+32|0;u=i+28|0;a=i+24|0;o=i+20|0;c=i+16|0;l=i+12|0;b=i+8|0;k=i+4|0;t[n>>2]=e;t[u>>2]=54320;t[a>>2]=0;t[c>>2]=0;t[l>>2]=0;t[13584]=0;do if(!(t[50]|0))if(t[468]|0){t[f>>2]=t[34];break}else{t[f>>2]=t[13588];break}else t[f>>2]=t[13586];while(0);t[a>>2]=zO(t[n>>2]|0,0)|0;do if(t[a>>2]|0){if(!(t[682]|0)){t[c>>2]=zp()|0;if(!(t[c>>2]|0)){IO(t[a>>2]|0);break}t[l>>2]=t[t[c>>2]>>2];t[t[c>>2]>>2]=t[f>>2];t[(t[c>>2]|0)+4>>2]=t[u>>2];t[o>>2]=Pp(t[c>>2]|0,t[a>>2]|0,0)|0;if(!(t[o>>2]|0)){IO(t[a>>2]|0);break}eE(t[c>>2]|0,t[o>>2]|0)|0;iS(t[c>>2]|0)|0;if(!(t[(t[c>>2]|0)+8>>2]|0))break;xe(t[v>>2]|0,54360,r|0)|0;fy(t[(t[c>>2]|0)+8>>2]|0);t[(t[c>>2]|0)+8>>2]=0;break}t[k>>2]=Ik(t[682]|0)|0;Ck(t[k>>2]|0,203,203,t[v>>2]|0);Hk(t[k>>2]|0,t[n>>2]|0);t[b>>2]=qk(t[k>>2]|0,t[a>>2]|0,0,t[f>>2]|0,t[u>>2]|0)|0;do if(!(t[266]|0)){if(!(t[b>>2]|0)){e=t[v>>2]|0;t[r>>2]=t[n>>2];xe(e|0,3496,r|0)|0;break;
	}e=t[v>>2]|0;h=t[n>>2]|0;if((t[b>>2]|0)>0){t[r>>2]=h;xe(e|0,3512,r|0)|0;t[662]=3;break}else{t[r>>2]=h;xe(e|0,3536,r|0)|0;t[662]=3;break}}while(0);Nk(t[k>>2]|0)}while(0);if(!(t[c>>2]|0)){s=i;return}t[t[c>>2]>>2]=t[l>>2];Up(t[c>>2]|0);s=i;return}function _m(e,i){e=e|0;i=i|0;var r=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,p=0,E=0,S=0,g=0,y=0,F=0,O=0,A=0,M=0,R=0,N=0,T=0,L=0,D=0,C=0,P=0,B=0,I=0,H=0,x=0,U=0,z=0,j=0,V=0,q=0,Y=0,G=0,W=0,K=0,X=0,Z=0,J=0,Q=0,$=0,ee=0,ie=0,re=0,ne=0,fe=0,te=0,ue=0,ae=0,oe=0,ce=0,le=0,se=0,be=0;r=s;s=s+6512|0;f=r;u=r+1376|0;a=r+1372|0;o=r+1368|0;c=r+1364|0;l=r+1360|0;b=r+1356|0;k=r+1352|0;h=r+2408|0;w=r+1348|0;d=r+1344|0;p=r+1268|0;E=r+1264|0;S=r+1260|0;g=r+1256|0;y=r+1252|0;F=r+1248|0;O=r+1384|0;A=r+1244|0;M=r+1240|0;R=r+1236|0;N=r+1232|0;T=r+1156|0;L=r+1152|0;D=r+1148|0;C=r+1144|0;P=r+120|0;B=r+112|0;I=r+108|0;H=r+104|0;x=r+100|0;U=r+96|0;z=r+92|0;j=r+88|0;V=r+84|0;q=r+80|0;Y=r+76|0;G=r+72|0;W=r+68|0;K=r+64|0;X=r+60|0;Z=r+56|0;J=r+52|0;Q=r+48|0;$=r+44|0;ee=r+40|0;ie=r+36|0;re=r+32|0;ne=r+28|0;fe=r+24|0;te=r+20|0;ue=r+16|0;ae=r+12|0;oe=r+8|0;t[u>>2]=e;t[a>>2]=i;t[o>>2]=0;if(!((t[252]|0)==0|(t[266]|0)!=0))wm();do if(!(t[u>>2]|0)){if(t[258]|0){t[o>>2]=ny(2888)|0;t[l>>2]=Sy(t[o>>2]|0,0,2896,0)|0;Cy(t[l>>2]|0,2904);iF(t[o>>2]|0,t[l>>2]|0)|0}}else{if((t[152]|0)!=0&(t[272]|0)!=0){t[b>>2]=mi(t[u>>2]|0,2912)|0;if(!(t[b>>2]|0))break;t[k>>2]=Re(h|0,1,4,t[b>>2]|0)|0;if((t[k>>2]|0)>0){t[w>>2]=ON(0,0,h,t[k>>2]|0,t[u>>2]|0,0)|0;mS(t[w>>2]|0,t[68]|0)|0;while(1){i=Re(h|0,1,t[282]|0,t[b>>2]|0)|0;t[k>>2]=i;ce=t[w>>2]|0;if((i|0)<=0)break;FN(ce,h,t[k>>2]|0,0)|0}FN(ce,h,0,1)|0;t[o>>2]=t[(t[w>>2]|0)+8>>2];SN(t[w>>2]|0)}Qe(t[b>>2]|0)|0;break}if((t[152]|0)!=0&(t[290]|0)!=0){if((ri(t[u>>2]|0,p|0)|0)<0){s=r;return}i=Ue(t[u>>2]|0,0,f|0)|0;t[d>>2]=i;if((i|0)<0){s=r;return}t[E>>2]=vi(0,t[p+36>>2]|0,1,1,t[d>>2]|0,0)|0;if((t[E>>2]|0)!=(-1|0)){t[o>>2]=LN(t[E>>2]|0,t[p+36>>2]|0,t[u>>2]|0,0,t[68]|0)|0;Ke(t[E>>2]|0,t[p+36>>2]|0)|0;Ge(t[d>>2]|0)|0;break}Ge(t[d>>2]|0)|0;i=t[v>>2]|0;t[f>>2]=t[u>>2];xe(i|0,2920,f|0)|0;t[662]=4;s=r;return}if(t[152]|0){t[o>>2]=TN(t[u>>2]|0,0,t[68]|0)|0;break}if(t[272]|0){if((n[t[u>>2]>>0]|0)==45?(n[(t[u>>2]|0)+1>>0]|0)==0:0)t[S>>2]=t[m>>2];else t[S>>2]=mi(t[u>>2]|0,2912)|0;if(!(t[S>>2]|0))break;t[F>>2]=1024;t[y>>2]=Re(O|0,1,4,t[S>>2]|0)|0;if((t[y>>2]|0)>0){t[A>>2]=fS(0,0,O,t[y>>2]|0,t[u>>2]|0)|0;mS(t[A>>2]|0,t[68]|0)|0;while(1){i=Re(O|0,1,t[F>>2]|0,t[S>>2]|0)|0;t[y>>2]=i;le=t[A>>2]|0;if((i|0)<=0)break;nS(le,O,t[y>>2]|0,0)|0}nS(le,O,0,1)|0;t[o>>2]=t[(t[A>>2]|0)+8>>2];t[g>>2]=t[(t[A>>2]|0)+12>>2];Up(t[A>>2]|0);if(!(t[g>>2]|0)){fy(t[o>>2]|0);t[o>>2]=0}}if((t[S>>2]|0)==(t[m>>2]|0))break;Qe(t[S>>2]|0)|0;break}if(t[298]|0){if((n[t[u>>2]>>0]|0)==45?(n[(t[u>>2]|0)+1>>0]|0)==0:0){t[o>>2]=ES(0,0,0,t[68]|0)|0;break}t[M>>2]=mi(t[u>>2]|0,2912)|0;if(!(t[M>>2]|0)){t[o>>2]=0;break}if(!(t[a>>2]|0)){t[o>>2]=SS(204,205,t[M>>2]|0,t[u>>2]|0,0,t[68]|0)|0;break}else{t[o>>2]=FS(t[a>>2]|0,204,205,t[M>>2]|0,t[u>>2]|0,0,t[68]|0)|0;break}}if(t[138]|0){if(!(t[a>>2]|0))t[R>>2]=zp()|0;else t[R>>2]=t[a>>2];if(!(t[R>>2]|0)){t[o>>2]=0;break}t[(t[t[R>>2]>>2]|0)+88>>2]=206;t[(t[t[R>>2]>>2]|0)+84>>2]=207;t[(t[R>>2]|0)+112>>2]=208;t[(t[R>>2]|0)+116>>2]=209;t[o>>2]=gS(t[R>>2]|0,t[u>>2]|0,0,t[68]|0)|0;if(t[a>>2]|0)break;Up(t[R>>2]|0);break}if(t[290]|0){if((ri(t[u>>2]|0,T|0)|0)<0){s=r;return}i=Ue(t[u>>2]|0,0,f|0)|0;t[N>>2]=i;if((i|0)<0){s=r;return}t[L>>2]=vi(0,t[T+36>>2]|0,1,1,t[N>>2]|0,0)|0;if((t[L>>2]|0)==(-1|0)){Ge(t[N>>2]|0)|0;i=t[v>>2]|0;t[f>>2]=t[u>>2];xe(i|0,2920,f|0)|0;t[662]=4;s=r;return}if(!(t[a>>2]|0))t[o>>2]=pS(t[L>>2]|0,t[T+36>>2]|0,t[u>>2]|0,0,t[68]|0)|0;else t[o>>2]=yS(t[a>>2]|0,t[L>>2]|0,t[T+36>>2]|0,t[u>>2]|0,0,t[68]|0)|0;Ke(t[L>>2]|0,t[T+36>>2]|0)|0;Ge(t[N>>2]|0)|0;break}if(!(t[196]|0)){if(t[a>>2]|0){t[o>>2]=gS(t[a>>2]|0,t[u>>2]|0,0,t[68]|0)|0;break}i=t[u>>2]|0;if(t[468]|0){t[o>>2]=wS(i)|0;break}else{t[o>>2]=_S(i,0,t[68]|0)|0;break}}t[D>>2]=0;if(!(t[a>>2]|0))t[D>>2]=zp()|0;else t[D>>2]=t[a>>2];if(!(t[D>>2]|0)){t[o>>2]=0;break}t[o>>2]=gS(t[D>>2]|0,t[u>>2]|0,0,t[68]|0)|0;if(!(t[(t[D>>2]|0)+100>>2]|0))t[662]=4;if(!(t[a>>2]|0))Up(t[D>>2]|0)}while(0);if(!(t[o>>2]|0)){t[662]=1;s=r;return}if(!((t[252]|0)==0|(t[266]|0)!=0))dm(2952,f);if((t[236]|0)!=0?(t[C>>2]=Qg(t[o>>2]|0)|0,(t[C>>2]|0)!=0):0){iy(t[C>>2]|0);ey(t[C>>2]|0)}if(t[308]|0){if(!((t[252]|0)==0|(t[266]|0)!=0))wm();if((Oo(t[o>>2]|0,t[68]|0)|0)<0)t[662]=1;if(!((t[252]|0)==0|(t[266]|0)!=0))dm(2960,f)}if(t[554]|0)Om(t[o>>2]|0,t[554]|0);if(t[48]|0){On(t[o>>2]|0)|0;Ar(t[o>>2]|0,t[u>>2]|0,210,t[_>>2]|0)}if(t[56]|0){t[c>>2]=t[o>>2];if(t[252]|0)wm();t[o>>2]=Jy(t[o>>2]|0,1)|0;if(t[252]|0)dm(2984,f);if(t[252]|0)wm();fy(t[c>>2]|0);if(t[252]|0)dm(2992,f)}e:do if((t[244]|0)==0|(t[152]|0)!=0){if(t[462]|0)Mm(t[o>>2]|0)}else if(t[(t[o>>2]|0)+12>>2]|0){t[H>>2]=t[(t[o>>2]|0)+12>>2];while(1){if(t[H>>2]|0)se=(t[(t[H>>2]|0)+16>>2]|0)==0;else se=0;be=t[H>>2]|0;if(!se)break;t[H>>2]=t[be+24>>2]}if(be){t[B>>2]=pR(t[(t[H>>2]|0)+16>>2]|0,0,P,256)|0;if((t[B>>2]|0)<0){xe(t[v>>2]|0,3016,f|0)|0;break}c=t[v>>2]|0;if(!(t[B>>2]|0)){xe(c|0,3056,f|0)|0;break}t[f>>2]=t[B>>2];xe(c|0,3096,f|0)|0;t[I>>2]=0;while(1){if((t[I>>2]|0)>=(t[B>>2]|0))break e;c=t[v>>2]|0;t[f>>2]=t[P+(t[I>>2]<<2)>>2];xe(c|0,3144,f|0)|0;t[I>>2]=(t[I>>2]|0)+1}}}while(0);do if(!(t[50]|0)){if(t[42]|0){if(!(t[128]|0))t[Q>>2]=t[_>>2];else t[Q>>2]=mi(t[128]|0,3160)|0;if(!(t[Q>>2]|0)){I=t[v>>2]|0;t[f>>2]=t[128];xe(I|0,3168,f|0)|0;t[662]=6;break}hr(t[Q>>2]|0,t[o>>2]|0);if(!(t[128]|0))break;Qe(t[Q>>2]|0)|0;break}if(!((t[252]|0)==0|(t[266]|0)!=0))wm();do if(!((t[152]|0)==0|(t[160]|0)!=0)){do if(t[788]|0)rr((t[128]|0)!=0?t[128]|0:144,t[o>>2]|0)|0;else{I=(t[440]|0)==1;P=t[128]|0;if(t[408]|0){B=(P|0)!=0?t[128]|0:144;H=t[o>>2]|0;be=t[408]|0;if(I){nr(B,H,be,1)|0;break}else{nr(B,H,be,0)|0;break}}if(I){nr((P|0)!=0?t[128]|0:144,t[o>>2]|0,0,1)|0;break}if(!P)t[U>>2]=t[_>>2];else t[U>>2]=mi(t[128]|0,3160)|0;if(!(t[U>>2]|0)){P=t[v>>2]|0;t[f>>2]=t[128];xe(P|0,3168,f|0)|0;t[662]=6;break}if((ir(t[U>>2]|0,t[o>>2]|0)|0)<0)t[662]=6;if(!(t[128]|0))break;Qe(t[U>>2]|0)|0}while(0);if(!((t[252]|0)==0|(t[266]|0)!=0))dm(3192,f)}else{if(t[362]|0){t[z>>2]=0;t[j>>2]=ol(t[o>>2]|0,0,0,0,1,z)|0;if((t[j>>2]|0)<0){xe(t[v>>2]|0,3224,f|0)|0;t[662]=6;break}if(($e(1,t[z>>2]|0,t[j>>2]|0)|0)==-1)xe(t[v>>2]|0,3200,f|0)|0;pAi[t[135736>>2]&511](t[z>>2]|0);break}if(t[370]|0){t[V>>2]=0;t[q>>2]=ol(t[o>>2]|0,0,2,0,1,V)|0;if((t[q>>2]|0)<0){xe(t[v>>2]|0,3224,f|0)|0;t[662]=6;break}if(($e(1,t[V>>2]|0,t[q>>2]|0)|0)==-1)xe(t[v>>2]|0,3200,f|0)|0;pAi[t[135736>>2]&511](t[V>>2]|0);break}if(t[380]|0){t[Y>>2]=0;t[G>>2]=ol(t[o>>2]|0,0,1,0,1,Y)|0;if((t[G>>2]|0)<0){xe(t[v>>2]|0,3224,f|0)|0;t[662]=6;break}if(($e(1,t[Y>>2]|0,t[G>>2]|0)|0)==-1)xe(t[v>>2]|0,3200,f|0)|0;pAi[t[135736>>2]&511](t[Y>>2]|0);break}if(t[290]|0){P=(t[440]|0)==1;I=t[o>>2]|0;do if(t[408]|0){be=t[408]|0;if(P){kV(I,W,K,be,1);break}else{dV(I,W,K,be);break}}else if(P){wV(I,W,K,1);break}else{hV(I,W,K);break}while(0);if(!(t[W>>2]|0)){xe(t[v>>2]|0,3248,f|0)|0;t[662]=6;break}if(($e(1,t[W>>2]|0,t[K>>2]|0)|0)==-1)xe(t[v>>2]|0,3200,f|0)|0;pAi[t[135736>>2]&511](t[W>>2]|0);break}if(t[788]|0){SV((t[128]|0)!=0?t[128]|0:144,t[o>>2]|0)|0;break}if(!(t[816]|0)){t[J>>2]=0;do if((t[440]|0)==1)t[J>>2]=t[J>>2]|1;else{if((t[440]|0)!=2)break;t[J>>2]=t[J>>2]|128}while(0);if(t[160]|0)t[J>>2]=t[J>>2]|32;if(!(t[128]|0))t[Z>>2]=fV(1,t[408]|0,t[J>>2]|0)|0;else t[Z>>2]=tV(t[128]|0,t[408]|0,t[J>>2]|0)|0;if(!(t[Z>>2]|0)){t[662]=6;break}if((uV(t[Z>>2]|0,t[o>>2]|0)|0)<0){I=t[v>>2]|0;t[f>>2]=(t[128]|0)!=0?t[128]|0:144;xe(I|0,3272,f|0)|0;t[662]=6}cV(t[Z>>2]|0)|0;break}I=(t[440]|0)==1;P=t[128]|0;if(t[408]|0){be=(P|0)!=0?t[128]|0:144;H=t[o>>2]|0;B=t[408]|0;if(I)t[x>>2]=_V(be,H,B,1)|0;else t[x>>2]=pV(be,H,B)|0;if((t[x>>2]|0)>=0)break;B=t[v>>2]|0;t[f>>2]=(t[128]|0)!=0?t[128]|0:144;xe(B|0,3272,f|0)|0;t[662]=6;break}if(I){t[x>>2]=EV((P|0)!=0?t[128]|0:144,t[o>>2]|0,1)|0;if((t[x>>2]|0)>=0)break;I=t[v>>2]|0;t[f>>2]=(t[128]|0)!=0?t[128]|0:144;xe(I|0,3272,f|0)|0;t[662]=6;break}if(!P)t[X>>2]=t[_>>2];else t[X>>2]=mi(t[128]|0,3160)|0;if(!(t[X>>2]|0)){P=t[v>>2]|0;t[f>>2]=t[128];xe(P|0,3168,f|0)|0;t[662]=6;break}if((mV(t[X>>2]|0,t[o>>2]|0)|0)<0)t[662]=6;if(!(t[128]|0))break;Qe(t[X>>2]|0)|0}while(0);if(!((t[252]|0)==0|(t[266]|0)!=0))dm(3192,f)}while(0);do if(!((t[216]|0)!=0|(t[226]|0)!=0)){if(t[206]|0){X=_M()|0;t[ie>>2]=X;if(!X){yAi[t[135904>>2]&511](t[33980]|0,3336,f);_i(-1)}if(!((t[252]|0)==0|(t[266]|0)!=0))wm();t[t[ie>>2]>>2]=t[v>>2];t[(t[ie>>2]|0)+4>>2]=203;t[(t[ie>>2]|0)+8>>2]=203;if(!(mR(t[ie>>2]|0,t[o>>2]|0)|0)){X=t[33976]|0;x=t[33980]|0;t[f>>2]=t[u>>2];yAi[X&511](x,3448,f);t[662]=3}if(!((t[252]|0)==0|(t[266]|0)!=0))dm(3480,f);pM(t[ie>>2]|0)}}else{if(!((t[252]|0)==0|(t[266]|0)!=0))wm();if(t[216]|0)t[$>>2]=aS(0,t[216]|0)|0;else t[$>>2]=aS(t[226]|0,0)|0;if(!((t[252]|0)==0|(t[266]|0)!=0))dm(3296,f);if(!(t[$>>2]|0)){x=t[33976]|0;X=t[33980]|0;if(t[216]|0){t[f>>2]=t[216];yAi[x&511](X,3312,f)}else{t[f>>2]=t[226];yAi[x&511](X,3312,f)}t[662]=2;break}X=_M()|0;t[ee>>2]=X;if(!X){yAi[t[135904>>2]&511](t[33980]|0,3336,f);_i(-1)}t[t[ee>>2]>>2]=t[v>>2];t[(t[ee>>2]|0)+4>>2]=203;t[(t[ee>>2]|0)+8>>2]=203;if(!((t[252]|0)==0|(t[266]|0)!=0))wm();if(!(dR(t[ee>>2]|0,t[o>>2]|0,t[$>>2]|0)|0)){X=t[33976]|0;x=t[33980]|0;Z=t[u>>2]|0;if(t[216]|0){J=t[216]|0;t[f>>2]=Z;t[f+4>>2]=J;yAi[X&511](x,3376,f)}else{J=t[226]|0;t[f>>2]=Z;t[f+4>>2]=J;yAi[X&511](x,3376,f)}t[662]=3}if(!((t[252]|0)==0|(t[266]|0)!=0))dm(3424,f);pM(t[ee>>2]|0);ey(t[$>>2]|0)}while(0);if(t[650]|0){if(!((t[252]|0)==0|(t[266]|0)!=0))wm();if(t[42]|0)t[fe>>2]=4;else t[fe>>2]=2;if(t[50]|0)t[fe>>2]=t[fe>>2]|1;t[re>>2]=QV(t[650]|0,t[fe>>2]|0)|0;t[ne>>2]=eq(t[re>>2]|0,t[o>>2]|0)|0;do if(t[ne>>2]|0){fe=t[v>>2]|0;$=t[u>>2]|0;if((t[ne>>2]|0)>0){t[f>>2]=$;xe(fe|0,3512,f|0)|0;t[662]=3;break}else{t[f>>2]=$;xe(fe|0,3536,f|0)|0;t[662]=3;break}}else{fe=t[v>>2]|0;t[f>>2]=t[u>>2];xe(fe|0,3496,f|0)|0}while(0);$V(t[re>>2]|0);if(!((t[252]|0)==0|(t[266]|0)!=0))dm(3480,f)}if(t[670]|0){if(!((t[252]|0)==0|(t[266]|0)!=0))wm();t[te>>2]=YH(t[670]|0)|0;WH(t[te>>2]|0,203,203,t[v>>2]|0);t[ue>>2]=XH(t[te>>2]|0,t[o>>2]|0)|0;do if(t[ue>>2]|0){re=t[v>>2]|0;ne=t[u>>2]|0;if((t[ue>>2]|0)>0){t[f>>2]=ne;xe(re|0,3512,f|0)|0;t[662]=3;break}else{t[f>>2]=ne;xe(re|0,3536,f|0)|0;t[662]=3;break}}else{re=t[v>>2]|0;t[f>>2]=t[u>>2];xe(re|0,3496,f|0)|0}while(0);GH(t[te>>2]|0);if(!((t[252]|0)==0|(t[266]|0)!=0))dm(3480,f)}else if(t[682]|0){if(!((t[252]|0)==0|(t[266]|0)!=0))wm();t[ae>>2]=Ik(t[682]|0)|0;Ck(t[ae>>2]|0,203,203,t[v>>2]|0);t[oe>>2]=Uk(t[ae>>2]|0,t[o>>2]|0)|0;do if(t[oe>>2]|0){te=t[v>>2]|0;ue=t[u>>2]|0;if((t[oe>>2]|0)>0){t[f>>2]=ue;xe(te|0,3512,f|0)|0;t[662]=3;break}else{t[f>>2]=ue;xe(te|0,3536,f|0)|0;t[662]=3;break}}else{te=t[v>>2]|0;t[f>>2]=t[u>>2];xe(te|0,3496,f|0)|0}while(0);Nk(t[ae>>2]|0);if(!((t[252]|0)==0|(t[266]|0)!=0))dm(3480,f)}if(!((t[356]|0)==0|(t[152]|0)!=0))sr(t[v>>2]|0,t[o>>2]|0);if(!((t[252]|0)==0|(t[266]|0)!=0))wm();fy(t[o>>2]|0);if((t[252]|0)==0|(t[266]|0)!=0){s=r;return}dm(3584,f);s=r;return}function pm(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0;n=s;s=s+16|0;f=n+8|0;u=n+4|0;a=n;t[f>>2]=e;t[u>>2]=i;t[a>>2]=r;r=Re(t[u>>2]|0,1,t[a>>2]|0,t[f>>2]|0)|0;s=n;return r|0}function Em(e){e=e|0;var i=0,r=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if((t[r>>2]|0)==(t[m>>2]|0)){s=i;return}Qe(t[r>>2]|0)|0;s=i;return}function Sm(e,i,r){e=e|0;i=i|0;r=r|0;var f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0;f=s;s=s+48|0;u=f;a=f+36|0;o=f+32|0;c=f+28|0;l=f+24|0;b=f+8|0;k=f+4|0;t[a>>2]=e;t[o>>2]=i;t[c>>2]=t[a>>2];n[4136]=0;t[l>>2]=t[(t[c>>2]|0)+36>>2];if(((t[l>>2]|0)!=0?(t[(t[l>>2]|0)+4>>2]|0)==0:0)?(t[(t[c>>2]|0)+40>>2]|0)>1:0)t[l>>2]=t[(t[(t[c>>2]|0)+48>>2]|0)+((t[(t[c>>2]|0)+40>>2]|0)-2<<2)>>2];Tm(t[l>>2]|0);yAi[t[135904>>2]&511](t[33980]|0,54304,u);t[b>>2]=r;t[k>>2]=HY(4136)|0;yY(4136+(t[k>>2]|0)|0,5e4-(t[k>>2]|0)|0,t[o>>2]|0,b)|0;Lm();yAi[t[135904>>2]&511](t[33980]|0,54168,u);Dm(t[l>>2]|0);Lm();s=f;return}function gm(e,i,r){e=e|0;i=i|0;r=r|0;var f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0;f=s;s=s+48|0;u=f;a=f+36|0;o=f+32|0;c=f+28|0;l=f+24|0;b=f+8|0;k=f+4|0;t[a>>2]=e;t[o>>2]=i;t[c>>2]=t[a>>2];n[4136]=0;t[l>>2]=t[(t[c>>2]|0)+36>>2];if(((t[l>>2]|0)!=0?(t[(t[l>>2]|0)+4>>2]|0)==0:0)?(t[(t[c>>2]|0)+40>>2]|0)>1:0)t[l>>2]=t[(t[(t[c>>2]|0)+48>>2]|0)+((t[(t[c>>2]|0)+40>>2]|0)-2<<2)>>2];Tm(t[l>>2]|0);yAi[t[135904>>2]&511](t[33980]|0,54280,u);t[b>>2]=r;t[k>>2]=HY(4136)|0;yY(4136+(t[k>>2]|0)|0,5e4-(t[k>>2]|0)|0,t[o>>2]|0,b)|0;Lm();yAi[t[135904>>2]&511](t[33980]|0,54168,u);Dm(t[l>>2]|0);Lm();s=f;return}function ym(e,i,r){e=e|0;i=i|0;r=r|0;var f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0;f=s;s=s+48|0;u=f;a=f+36|0;o=f+32|0;c=f+28|0;l=f+24|0;b=f+8|0;k=f+4|0;t[a>>2]=e;t[o>>2]=i;t[c>>2]=t[a>>2];n[4136]=0;t[l>>2]=t[(t[c>>2]|0)+36>>2];if((t[(t[l>>2]|0)+4>>2]|0)==0?(t[(t[c>>2]|0)+40>>2]|0)>1:0)t[l>>2]=t[(t[(t[c>>2]|0)+48>>2]|0)+((t[(t[c>>2]|0)+40>>2]|0)-2<<2)>>2];Tm(t[l>>2]|0);yAi[t[135904>>2]&511](t[33980]|0,54256,u);t[k>>2]=HY(4136)|0;t[b>>2]=r;yY(4136+(t[k>>2]|0)|0,5e4-(t[k>>2]|0)|0,t[o>>2]|0,b)|0;Lm();yAi[t[135904>>2]&511](t[33980]|0,54168,u);Dm(t[l>>2]|0);Lm();t[662]=3;s=f;return}function Fm(e,i,r){e=e|0;i=i|0;r=r|0;var f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0;f=s;s=s+48|0;u=f;a=f+36|0;o=f+32|0;c=f+28|0;l=f+24|0;b=f+8|0;k=f+4|0;t[a>>2]=e;t[o>>2]=i;t[c>>2]=t[a>>2];n[4136]=0;t[l>>2]=t[(t[c>>2]|0)+36>>2];if((t[(t[l>>2]|0)+4>>2]|0)==0?(t[(t[c>>2]|0)+40>>2]|0)>1:0)t[l>>2]=t[(t[(t[c>>2]|0)+48>>2]|0)+((t[(t[c>>2]|0)+40>>2]|0)-2<<2)>>2];Tm(t[l>>2]|0);yAi[t[135904>>2]&511](t[33980]|0,54136,u);t[b>>2]=r;t[k>>2]=HY(4136)|0;yY(4136+(t[k>>2]|0)|0,5e4-(t[k>>2]|0)|0,t[o>>2]|0,b)|0;Lm();yAi[t[135904>>2]&511](t[33980]|0,54168,u);Dm(t[l>>2]|0);Lm();s=f;return}function Om(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0;r=s;s=s+32|0;n=r;f=r+16|0;u=r+12|0;a=r+8|0;o=r+4|0;t[f>>2]=e;t[u>>2]=i;t[a>>2]=wf(t[f>>2]|0)|0;if(!(t[a>>2]|0)){xe(t[v>>2]|0,3912,n|0)|0;t[662]=9;s=r;return}t[(t[a>>2]|0)+4>>2]=t[f>>2];t[o>>2]=Et(t[u>>2]|0,t[a>>2]|0)|0;vf(t[a>>2]|0);if(!(t[o>>2]|0)){xe(t[v>>2]|0,3944,n|0)|0;t[662]=10;s=r;return}else{Nm(t[o>>2]|0);_n(t[o>>2]|0);s=r;return}}function Am(e){e=e|0;var i=0,r=0,f=0,u=0,a=0,o=0,c=0,l=0;i=s;s=s+528|0;r=i;f=i+16|0;u=i+12|0;a=i+20|0;o=i+8|0;c=i+4|0;t[u>>2]=e;if(t[u>>2]|0){e=t[_>>2]|0;t[r>>2]=t[u>>2];xe(e|0,3904,r|0)|0}if(!(di(a|0,500,t[m>>2]|0)|0)){t[f>>2]=0;l=t[f>>2]|0;s=i;return l|0}n[a+500>>0]=0;t[c>>2]=HY(a|0)|0;t[o>>2]=Xq((t[c>>2]|0)+1|0)|0;if(t[o>>2]|0)YY(t[o>>2]|0,a|0,(t[c>>2]|0)+1|0)|0;t[f>>2]=t[o>>2];l=t[f>>2]|0;s=i;return l|0}function Mm(e){e=e|0;var i=0,r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0;i=s;s=s+128|0;r=i;n=i+116|0;f=i+112|0;u=i+108|0;a=i+104|0;o=i+16|0;c=i+8|0;l=i+4|0;t[n>>2]=e;t[a>>2]=eF(t[n>>2]|0)|0;t[l>>2]=t[(t[a>>2]|0)+48>>2];t[c>>2]=0;while(1){if(!((t[l>>2]|0)!=0&(t[c>>2]|0)<20))break;a=t[(t[l>>2]|0)+8>>2]|0;e=t[c>>2]|0;t[c>>2]=e+1;t[o+(e<<2)>>2]=a;a=t[(t[l>>2]|0)+12>>2]|0;e=t[c>>2]|0;t[c>>2]=e+1;t[o+(e<<2)>>2]=a;t[l>>2]=t[t[l>>2]>>2]}l=t[c>>2]|0;t[c>>2]=l+1;t[o+(l<<2)>>2]=0;t[o+(t[c>>2]<<2)>>2]=0;if((t[548]|0)!=0?(t[694]=Fj(t[548]|0,t[(t[n>>2]|0)+80>>2]|0,0,o)|0,(t[694]|0)==0):0){o=t[33976]|0;c=t[33980]|0;t[r>>2]=t[548];yAi[o&511](c,2784,r);t[662]=7;t[548]=0}if(((t[694]|0)!=0?(t[898]=Aj(t[694]|0)|0,(t[898]|0)!=0):0)?(t[u>>2]=pj(t[898]|0,0,0)|0,(t[u>>2]|0)<0):0){xe(t[v>>2]|0,3600,r|0)|0;_j(t[898]|0);t[898]=0}t[f>>2]=ZI(t[n>>2]|0)|0;if(t[f>>2]|0){if(!((t[252]|0)==0|(t[266]|0)!=0))wm();t[u>>2]=RI(t[f>>2]|0)|0;while(1){if((t[u>>2]|0)!=1)break;if((t[42]|0)!=0|(t[694]|0)!=0)Rm(t[f>>2]|0);t[u>>2]=RI(t[f>>2]|0)|0}if(!((t[252]|0)==0|(t[266]|0)!=0))dm(3632,r);CI(t[f>>2]|0);if(t[u>>2]|0){xe(t[v>>2]|0,3656,r|0)|0;t[662]=1}}else{xe(t[v>>2]|0,3688,r|0)|0;t[662]=1}if(!(t[898]|0)){s=i;return}_j(t[898]|0);t[898]=0;s=i;return}function Rm(e){e=e|0;var i=0,r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0;i=s;s=s+64|0;r=i;n=i+48|0;f=i+44|0;u=i+40|0;a=i+36|0;o=i+32|0;c=i+28|0;l=i+24|0;b=i+20|0;t[n>>2]=e;t[a>>2]=BI(t[n>>2]|0)|0;t[o>>2]=II(t[n>>2]|0)|0;do if(t[42]|0){e=xI(t[n>>2]|0)|0;t[f>>2]=e;t[f>>2]=(t[f>>2]|0)==0?3736:e;t[u>>2]=VI(t[n>>2]|0)|0;e=zI(t[n>>2]|0)|0;k=t[a>>2]|0;h=t[f>>2]|0;w=t[o>>2]|0;d=jI(t[n>>2]|0)|0;t[r>>2]=e;t[r+4>>2]=k;t[r+8>>2]=h;t[r+12>>2]=w;t[r+16>>2]=d;Je(3744,r|0)|0;if(!(t[u>>2]|0)){Je(3760,r|0)|0;break}else{t[r>>2]=t[u>>2];Je(3768,r|0)|0;break}}while(0);if(!(t[694]|0)){s=i;return}t[c>>2]=0;t[l>>2]=-1;if((t[a>>2]|0)==1?(u=t[694]|0,t[l>>2]=Oj(u,YI(t[n>>2]|0)|0)|0,(t[l>>2]|0)!=0):0){t[c>>2]=$y(YI(t[n>>2]|0)|0)|0;u=t[548]|0;t[r>>2]=t[c>>2];t[r+4>>2]=u;Je(3776,r|0)|0}do if(t[898]|0){do if((t[a>>2]|0)==1){u=t[898]|0;f=HI(t[n>>2]|0)|0;t[b>>2]=pj(u,f,UI(t[n>>2]|0)|0)|0;if((t[b>>2]|0)<0){xe(t[v>>2]|0,3600,r|0)|0;_j(t[898]|0);t[898]=0;break}if((t[b>>2]|0)!=(t[l>>2]|0)){if(!(t[c>>2]|0))t[c>>2]=$y(YI(t[n>>2]|0)|0)|0;xe(t[v>>2]|0,3808,r|0)|0;f=t[v>>2]|0;u=t[548]|0;if(t[c>>2]|0){d=t[c>>2]|0;t[r>>2]=u;t[r+4>>2]=d;xe(f|0,3856,r|0)|0;break}else{d=xI(t[n>>2]|0)|0;t[r>>2]=u;t[r+4>>2]=d;xe(f|0,3856,r|0)|0;break}}}while(0);if((t[a>>2]|0)!=15?!((t[a>>2]|0)==1&(t[o>>2]|0)!=0):0)break;t[b>>2]=gj(t[898]|0)|0;if((t[b>>2]|0)<0){xe(t[v>>2]|0,3880,r|0)|0;_j(t[898]|0);t[898]=0}}while(0);if(!(t[c>>2]|0)){s=i;return}pAi[t[135736>>2]&511](t[c>>2]|0);s=i;return}function Nm(e){e=e|0;var i=0,r=0,n=0,f=0,u=0,a=0;i=s;s=s+32|0;r=i;n=i+20|0;f=i+16|0;u=i+12|0;a=i+8|0;t[n>>2]=e;switch(t[t[n>>2]>>2]|0){case 4:{t[r>>2]=t[(t[n>>2]|0)+24>>2];Je(3904,r|0)|0;s=i;return}case 3:{e=wn(+l[(t[n>>2]|0)+16>>3])|0;if((e|0)==-1){Je(4032,r|0)|0;s=i;return}else if((e|0)!=1)if(hn(+l[(t[n>>2]|0)+16>>3])|0){Je(4048,r|0)|0;s=i;return}else{l[k>>3]=+l[(t[n>>2]|0)+16>>3];t[r>>2]=t[k>>2];t[r+4>>2]=t[k+4>>2];Je(4056,r|0)|0;s=i;return}else{Je(4016,r|0)|0;s=i;return}break}case 1:{if((t[(t[n>>2]|0)+4>>2]|0)!=0?(t[t[(t[n>>2]|0)+4>>2]>>2]|0)>0:0){t[a>>2]=fV(1,0,0)|0;if(!(t[a>>2]|0)){xe(t[v>>2]|0,3912,r|0)|0;t[662]=9;s=i;return}t[f>>2]=0;while(1){if((t[f>>2]|0)>=(t[t[(t[n>>2]|0)+4>>2]>>2]|0))break;t[u>>2]=t[(t[(t[(t[n>>2]|0)+4>>2]|0)+8>>2]|0)+(t[f>>2]<<2)>>2];aV(t[a>>2]|0,t[u>>2]|0)|0;t[f>>2]=(t[f>>2]|0)+1}cV(t[a>>2]|0)|0;s=i;return}xe(t[v>>2]|0,3976,r|0)|0;t[662]=10;s=i;return}case 2:{if(t[(t[n>>2]|0)+8>>2]|0){Je(4e3,r|0)|0;s=i;return}else{Je(4008,r|0)|0;s=i;return}break}case 0:{xe(t[v>>2]|0,4064,r|0)|0;t[662]=10;s=i;return}default:{xe(t[v>>2]|0,4096,r|0)|0;t[662]=10;s=i;return}}}function Tm(e){e=e|0;var i=0,r=0,n=0,f=0,u=0,a=0;i=s;s=s+16|0;r=i;n=i+12|0;f=i+8|0;t[n>>2]=e;yAi[t[135904>>2]&511](t[33980]|0,54216,r);t[f>>2]=HY(4136)|0;if(!(t[n>>2]|0)){Lm();s=i;return}e=4136+(t[f>>2]|0)|0;u=5e4-(t[f>>2]|0)|0;f=t[n>>2]|0;if(t[(t[n>>2]|0)+4>>2]|0){a=t[(t[n>>2]|0)+28>>2]|0;t[r>>2]=t[f+4>>2];t[r+4>>2]=a;SY(e,u,54224,r)|0;Lm();s=i;return}else{t[r>>2]=t[f+28>>2];SY(e,u,54232,r)|0;Lm();s=i;return}}function Lm(){var e=0,i=0,r=0,f=0,u=0;e=s;s=s+16|0;i=e;r=e+4|0;t[r>>2]=d_(0,4136)|0;if(!(t[r>>2]|0)){n[4136]=0;s=e;return}f=t[33976]|0;u=t[33980]|0;t[i>>2]=t[r>>2];yAi[f&511](u,3904,i);pAi[t[135736>>2]&511](t[r>>2]|0);n[4136]=0;s=e;return}function Dm(e){e=e|0;var i=0,r=0,n=0,f=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0;i=s;s=s+32|0;r=i;n=i+20|0;f=i+16|0;a=i+12|0;o=i+8|0;c=i+4|0;t[n>>2]=e;if(!(t[n>>2]|0)){s=i;return}yAi[t[135904>>2]&511](t[33980]|0,54176,r);t[f>>2]=t[(t[n>>2]|0)+16>>2];t[a>>2]=t[(t[n>>2]|0)+12>>2];while(1){if((t[f>>2]|0)>>>0<=(t[a>>2]|0)>>>0)break;if((u[t[f>>2]>>0]|0|0)!=10?(u[t[f>>2]>>0]|0|0)!=13:0)break;t[f>>2]=(t[f>>2]|0)+-1}t[c>>2]=0;while(1){e=t[c>>2]|0;t[c>>2]=e+1;if(((e|0)<80?(t[f>>2]|0)>>>0>(t[a>>2]|0)>>>0:0)?(u[t[f>>2]>>0]|0|0)!=10:0)l=(u[t[f>>2]>>0]|0|0)!=13;else l=0;b=t[f>>2]|0;if(!l)break;t[f>>2]=b+-1}if(!((u[b>>0]|0|0)!=10?(u[t[f>>2]>>0]|0|0)!=13:0))t[f>>2]=(t[f>>2]|0)+1;t[a>>2]=t[f>>2];t[c>>2]=0;while(1){if(((u[t[f>>2]>>0]|0|0)!=0?(u[t[f>>2]>>0]|0|0)!=10:0)?(u[t[f>>2]>>0]|0|0)!=13:0)k=(t[c>>2]|0)<79;else k=0;t[o>>2]=HY(4136)|0;h=4136+(t[o>>2]|0)|0;w=5e4-(t[o>>2]|0)|0;if(!k)break;b=t[f>>2]|0;t[f>>2]=b+1;t[r>>2]=u[b>>0];SY(h,w,54184,r)|0;t[c>>2]=(t[c>>2]|0)+1}SY(h,w,3760,r)|0;t[f>>2]=t[(t[n>>2]|0)+16>>2];while(1){if((u[t[f>>2]>>0]|0|0)!=10?(u[t[f>>2]>>0]|0|0)!=13:0)break;t[f>>2]=(t[f>>2]|0)+-1}t[c>>2]=0;while(1){if((t[f>>2]|0)!=(t[a>>2]|0)){n=t[c>>2]|0;t[c>>2]=n+1;d=(n|0)<80}else d=0;t[o>>2]=HY(4136)|0;v=4136+(t[o>>2]|0)|0;m=5e4-(t[o>>2]|0)|0;if(!d)break;SY(v,m,54192,r)|0;t[a>>2]=(t[a>>2]|0)+1}SY(v,m,54200,r)|0;Lm();yAi[t[135904>>2]&511](t[33980]|0,54208,r);s=i;return}function Cm(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,u=0,a=0,o=0,c=0;f=s;s=s+32|0;u=f;a=f+12|0;o=f+8|0;c=f+4|0;t[f+16>>2]=e;t[a>>2]=i;t[o>>2]=r;t[c>>2]=n;t[13584]=(t[13584]|0)+1;if(t[50]|0){s=f;return}n=t[_>>2]|0;t[u>>2]=t[a>>2];xe(n|0,55552,u|0)|0;n=t[_>>2]|0;if(!(t[o>>2]|0))xe(n|0,54736,u|0)|0;else{t[u>>2]=t[o>>2];xe(n|0,54744,u|0)|0}n=t[_>>2]|0;if(!(t[c>>2]|0)){xe(n|0,54752,u|0)|0;s=f;return}else{t[u>>2]=t[c>>2];xe(n|0,54760,u|0)|0;s=f;return}}function Pm(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i+8|0;t[i+4>>2]=e;t[13584]=(t[13584]|0)+1;if(t[50]|0){t[r>>2]=0;n=t[r>>2]|0;s=i;return n|0}else{xe(t[_>>2]|0,55528,i|0)|0;t[r>>2]=0;n=t[r>>2]|0;s=i;return n|0}return 0}function Bm(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i+8|0;t[i+4>>2]=e;t[13584]=(t[13584]|0)+1;if(t[50]|0){t[r>>2]=0;n=t[r>>2]|0;s=i;return n|0}else{xe(t[_>>2]|0,55496,i|0)|0;t[r>>2]=0;n=t[r>>2]|0;s=i;return n|0}return 0}function Im(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i+8|0;t[i+4>>2]=e;t[13584]=(t[13584]|0)+1;if(t[50]|0){t[r>>2]=0;n=t[r>>2]|0;s=i;return n|0}else{xe(t[_>>2]|0,55464,i|0)|0;t[r>>2]=0;n=t[r>>2]|0;s=i;return n|0}return 0}function Hm(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0;n=s;s=s+32|0;f=n;u=n+16|0;a=n+8|0;o=n+4|0;t[n+12>>2]=e;t[a>>2]=i;t[o>>2]=r;t[13584]=(t[13584]|0)+1;if(t[50]|0){t[u>>2]=0;c=t[u>>2]|0;s=n;return c|0}xe(t[_>>2]|0,55424,f|0)|0;r=t[_>>2]|0;if(t[a>>2]|0){t[f>>2]=t[a>>2];xe(r|0,3904,f|0)|0}else xe(r|0,54192,f|0)|0;r=t[_>>2]|0;if(t[o>>2]|0){t[f>>2]=t[o>>2];xe(r|0,55448,f|0)|0}else xe(r|0,55456,f|0)|0;t[u>>2]=0;c=t[u>>2]|0;s=n;return c|0}function xm(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0;r=s;s=s+16|0;n=r;f=r+12|0;u=r+4|0;t[r+8>>2]=e;t[u>>2]=i;t[13584]=(t[13584]|0)+1;if(t[50]|0){t[f>>2]=0;a=t[f>>2]|0;s=r;return a|0}else{i=t[_>>2]|0;t[n>>2]=t[u>>2];xe(i|0,55400,n|0)|0;t[f>>2]=0;a=t[f>>2]|0;s=r;return a|0}return 0}function Um(e,i,r,n,f,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;u=u|0;var a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0;a=s;s=s+48|0;o=a;c=a+40|0;l=a+36|0;b=a+32|0;k=a+28|0;h=a+24|0;w=a+20|0;t[a+44>>2]=e;t[c>>2]=i;t[l>>2]=r;t[b>>2]=n;t[k>>2]=f;t[h>>2]=u;t[w>>2]=55152;if(!(t[b>>2]|0))t[b>>2]=t[w>>2];if(!(t[k>>2]|0))t[k>>2]=t[w>>2];if(!(t[h>>2]|0))t[h>>2]=t[w>>2];t[13584]=(t[13584]|0)+1;if(t[50]|0){s=a;return}w=t[_>>2]|0;u=t[l>>2]|0;l=t[b>>2]|0;b=t[k>>2]|0;k=t[h>>2]|0;t[o>>2]=t[c>>2];t[o+4>>2]=u;t[o+8>>2]=l;t[o+12>>2]=b;t[o+16>>2]=k;xe(w|0,55360,o|0)|0;s=a;return}function zm(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,u=0,a=0,o=0,c=0;f=s;s=s+32|0;u=f;a=f+20|0;o=f+16|0;c=f+12|0;t[f+24>>2]=e;t[a>>2]=i;t[o>>2]=r;t[c>>2]=n;t[13584]=(t[13584]|0)+1;if(t[50]|0){s=f;return}n=t[_>>2]|0;r=t[o>>2]|0;o=t[c>>2]|0;t[u>>2]=t[a>>2];t[u+4>>2]=r;t[u+8>>2]=o;xe(n|0,55328,u|0)|0;s=f;return}function jm(e,i,r,n,f,u,a){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;u=u|0;a=a|0;var o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0;o=s;s=s+48|0;c=o;l=o+40|0;b=o+36|0;k=o+32|0;h=o+28|0;w=o+24|0;d=o+20|0;t[o+44>>2]=e;t[l>>2]=i;t[b>>2]=r;t[k>>2]=n;t[h>>2]=f;t[w>>2]=u;t[d>>2]=a;t[13584]=(t[13584]|0)+1;if(t[50]|0){s=o;return}a=t[_>>2]|0;u=t[l>>2]|0;l=t[b>>2]|0;b=t[k>>2]|0;k=t[h>>2]|0;if(!(t[w>>2]|0)){t[c>>2]=u;t[c+4>>2]=l;t[c+8>>2]=b;t[c+12>>2]=k;xe(a|0,55232,c|0)|0}else{h=t[w>>2]|0;t[c>>2]=u;t[c+4>>2]=l;t[c+8>>2]=b;t[c+12>>2]=k;t[c+16>>2]=h;xe(a|0,55280,c|0)|0}NM(t[d>>2]|0);s=o;return}function Vm(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,u=0,a=0,o=0;f=s;s=s+32|0;u=f;a=f+16|0;o=f+12|0;t[f+20>>2]=e;t[a>>2]=i;t[o>>2]=r;t[f+8>>2]=n;t[13584]=(t[13584]|0)+1;if(t[50]|0){s=f;return}n=t[_>>2]|0;r=t[o>>2]|0;t[u>>2]=t[a>>2];t[u+4>>2]=r;xe(n|0,55200,u|0)|0;s=f;return}function qm(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;var u=0,a=0,o=0,c=0,l=0,b=0,k=0;u=s;s=s+48|0;a=u;o=u+32|0;c=u+28|0;l=u+24|0;b=u+20|0;k=u+16|0;t[u+36>>2]=e;t[o>>2]=i;t[c>>2]=r;t[l>>2]=n;t[b>>2]=f;t[k>>2]=55152;if(!(t[c>>2]|0))t[c>>2]=t[k>>2];if(!(t[l>>2]|0))t[l>>2]=t[k>>2];if(!(t[b>>2]|0))t[b>>2]=t[k>>2];t[13584]=(t[13584]|0)+1;if(t[50]|0){s=u;return}k=t[_>>2]|0;f=t[c>>2]|0;c=t[l>>2]|0;l=t[b>>2]|0;t[a>>2]=t[o>>2];t[a+4>>2]=f;t[a+8>>2]=c;t[a+12>>2]=l;xe(k|0,55160,a|0)|0;s=u;return}function Ym(e,i){e=e|0;i=i|0;var r=0;r=s;s=s+16|0;t[r+8>>2]=e;t[r+4>>2]=i;t[13584]=(t[13584]|0)+1;if(t[50]|0){s=r;return}xe(t[_>>2]|0,55120,r|0)|0;s=r;return}function Gm(e){e=e|0;var i=0;i=s;s=s+16|0;t[i+4>>2]=e;t[13584]=(t[13584]|0)+1;if(t[50]|0){s=i;return}xe(t[_>>2]|0,55096,i|0)|0;s=i;return}function Wm(e){e=e|0;var i=0;i=s;s=s+16|0;t[i+4>>2]=e;t[13584]=(t[13584]|0)+1;if(t[50]|0){s=i;return}xe(t[_>>2]|0,55072,i|0)|0;s=i;return}function Km(e,i){e=e|0;i=i|0;var r=0,n=0,f=0;r=s;s=s+16|0;n=r;f=r+4|0;t[r+8>>2]=e;t[f>>2]=i;t[13584]=(t[13584]|0)+1;if(t[50]|0){s=r;return}i=t[_>>2]|0;t[n>>2]=t[f>>2];xe(i|0,55048,n|0)|0;s=r;return}function Xm(e,i,r){e=e|0;i=i|0;r=r|0;var f=0,u=0,a=0,o=0,c=0,l=0,b=0;f=s;s=s+64|0;u=f;a=f+16|0;o=f+12|0;c=f+24|0;l=f+8|0;t[f+20>>2]=e;t[a>>2]=i;t[o>>2]=r;t[13584]=(t[13584]|0)+1;if(t[50]|0){s=f;return}t[l>>2]=0;while(1){b=t[l>>2]|0;if(!((t[l>>2]|0)<30?(t[l>>2]|0)<(t[o>>2]|0):0))break;n[c+(t[l>>2]|0)>>0]=n[(t[a>>2]|0)+b>>0]|0;t[l>>2]=(t[l>>2]|0)+1}n[c+b>>0]=0;b=t[_>>2]|0;l=t[o>>2]|0;t[u>>2]=c;t[u+4>>2]=l;xe(b|0,55024,u|0)|0;s=f;return}function Zm(e,i,r){e=e|0;i=i|0;r=r|0;var f=0,u=0,a=0,o=0,c=0,l=0,b=0;f=s;s=s+64|0;u=f;a=f+16|0;o=f+12|0;c=f+24|0;l=f+8|0;t[f+20>>2]=e;t[a>>2]=i;t[o>>2]=r;t[13584]=(t[13584]|0)+1;if(t[50]|0){s=f;return}t[l>>2]=0;while(1){b=t[l>>2]|0;if(!((t[l>>2]|0)<30?(t[l>>2]|0)<(t[o>>2]|0):0))break;n[c+(t[l>>2]|0)>>0]=n[(t[a>>2]|0)+b>>0]|0;t[l>>2]=(t[l>>2]|0)+1}n[c+b>>0]=0;b=t[_>>2]|0;l=t[o>>2]|0;t[u>>2]=c;t[u+4>>2]=l;xe(b|0,54984,u|0)|0;s=f;return}function Jm(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0;n=s;s=s+32|0;f=n;u=n+12|0;a=n+8|0;t[n+16>>2]=e;t[u>>2]=i;t[a>>2]=r;t[13584]=(t[13584]|0)+1;if(t[50]|0){s=n;return}r=t[_>>2]|0;i=t[u>>2]|0;if(t[a>>2]|0){u=t[a>>2]|0;t[f>>2]=i;t[f+4>>2]=u;xe(r|0,54904,f|0)|0;s=n;return}else{t[f>>2]=i;xe(r|0,54944,f|0)|0;s=n;return}}function Qm(e,i){e=e|0;i=i|0;var r=0,n=0,f=0;r=s;s=s+16|0;n=r;f=r+4|0;t[r+8>>2]=e;t[f>>2]=i;t[13584]=(t[13584]|0)+1;if(t[50]|0){s=r;return}i=t[_>>2]|0;t[n>>2]=t[f>>2];xe(i|0,54880,n|0)|0;s=r;return}function $m(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0;n=s;s=s+32|0;f=n+24|0;u=n+8|0;t[n+28>>2]=e;t[f>>2]=i;t[13584]=(t[13584]|0)+1;if(t[50]|0){s=n;return}t[u>>2]=r;xe(t[_>>2]|0,54864,n|0)|0;Te(t[_>>2]|0,t[f>>2]|0,u|0)|0;s=n;return}function e_(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0;n=s;s=s+32|0;f=n+24|0;u=n+8|0;t[n+28>>2]=e;t[f>>2]=i;t[13584]=(t[13584]|0)+1;if(t[50]|0){s=n;return}t[u>>2]=r;xe(t[_>>2]|0,54848,n|0)|0;Te(t[_>>2]|0,t[f>>2]|0,u|0)|0;s=n;return}function i_(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0;n=s;s=s+32|0;f=n+24|0;u=n+8|0;t[n+28>>2]=e;t[f>>2]=i;t[13584]=(t[13584]|0)+1;if(t[50]|0){s=n;return}t[u>>2]=r;xe(t[_>>2]|0,54824,n|0)|0;Te(t[_>>2]|0,t[f>>2]|0,u|0)|0;s=n;return}function r_(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0;r=s;s=s+16|0;n=r;f=r+12|0;u=r+4|0;t[r+8>>2]=e;t[u>>2]=i;t[13584]=(t[13584]|0)+1;if(t[50]|0){t[f>>2]=0;a=t[f>>2]|0;s=r;return a|0}else{i=t[_>>2]|0;t[n>>2]=t[u>>2];xe(i|0,54792,n|0)|0;t[f>>2]=0;a=t[f>>2]|0;s=r;return a|0}return 0}function n_(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0;n=s;s=s+32|0;f=n;u=n+12|0;a=n+8|0;t[n+16>>2]=e;t[u>>2]=i;t[a>>2]=r;t[13584]=(t[13584]|0)+1;if(t[50]|0){s=n;return}r=t[_>>2]|0;i=t[a>>2]|0;t[f>>2]=t[u>>2];t[f+4>>2]=i;xe(r|0,54768,f|0)|0;s=n;return}function f_(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,u=0,a=0,o=0,c=0;f=s;s=s+32|0;u=f;a=f+12|0;o=f+8|0;c=f+4|0;t[f+16>>2]=e;t[a>>2]=i;t[o>>2]=r;t[c>>2]=n;t[13584]=(t[13584]|0)+1;if(t[50]|0){s=f;return}n=t[_>>2]|0;t[u>>2]=t[a>>2];xe(n|0,54712,u|0)|0;n=t[_>>2]|0;if(!(t[o>>2]|0))xe(n|0,54736,u|0)|0;else{t[u>>2]=t[o>>2];xe(n|0,54744,u|0)|0}n=t[_>>2]|0;if(!(t[c>>2]|0)){xe(n|0,54752,u|0)|0;s=f;return}else{t[u>>2]=t[c>>2];xe(n|0,54760,u|0)|0;s=f;return}}function t_(e,i,r,n,f,u,a,o,c){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;u=u|0;a=a|0;o=o|0;c=c|0;var l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,p=0,E=0,S=0;l=s;s=s+48|0;b=l;k=l+40|0;h=l+36|0;w=l+32|0;d=l+28|0;v=l+24|0;m=l+20|0;p=l+16|0;E=l+12|0;S=l+8|0;t[l+44>>2]=e;t[k>>2]=i;t[h>>2]=r;t[w>>2]=n;t[d>>2]=f;t[v>>2]=u;t[m>>2]=a;t[p>>2]=o;t[E>>2]=c;t[13584]=(t[13584]|0)+1;if(t[50]|0){s=l;return}c=t[_>>2]|0;t[b>>2]=t[k>>2];xe(c|0,54584,b|0)|0;c=t[_>>2]|0;if(!(t[h>>2]|0))xe(c|0,54536,b|0)|0;else{t[b>>2]=t[h>>2];xe(c|0,54544,b|0)|0}c=t[_>>2]|0;if(!(t[w>>2]|0))xe(c|0,54536,b|0)|0;else{t[b>>2]=t[w>>2];xe(c|0,54608,b|0)|0}c=t[_>>2]|0;t[b>>2]=t[d>>2];xe(c|0,54616,b|0)|0;e:do if(t[v>>2]|0){t[S>>2]=0;while(1){if((t[S>>2]|0)>=(t[d>>2]<<1|0))break e;xe(t[_>>2]|0,54624,b|0)|0;if(t[(t[v>>2]|0)+(t[S>>2]<<2)>>2]|0){c=t[_>>2]|0;t[b>>2]=t[(t[v>>2]|0)+(t[S>>2]<<2)>>2];xe(c|0,54632,b|0)|0}t[S>>2]=(t[S>>2]|0)+1;c=t[_>>2]|0;t[b>>2]=t[(t[v>>2]|0)+(t[S>>2]<<2)>>2];xe(c|0,54640,b|0)|0;t[S>>2]=(t[S>>2]|0)+1}}while(0);v=t[_>>2]|0;d=t[p>>2]|0;t[b>>2]=t[m>>2];t[b+4>>2]=d;xe(v|0,54648,b|0)|0;e:do if(t[E>>2]|0){t[S>>2]=0;while(1){if((t[S>>2]|0)>=((t[m>>2]|0)*5|0))break e;v=t[_>>2]|0;d=t[S>>2]|0;if(t[(t[E>>2]|0)+((t[S>>2]|0)+1<<2)>>2]|0){p=t[(t[E>>2]|0)+(t[S>>2]<<2)>>2]|0;t[b>>2]=t[(t[E>>2]|0)+(d+1<<2)>>2];t[b+4>>2]=p;xe(v|0,54664,b|0)|0}else{t[b>>2]=t[(t[E>>2]|0)+(d<<2)>>2];xe(v|0,54680,b|0)|0}v=t[_>>2]|0;d=(t[(t[E>>2]|0)+((t[S>>2]|0)+4<<2)>>2]|0)-(t[(t[E>>2]|0)+((t[S>>2]|0)+3<<2)>>2]|0)|0;t[b>>2]=t[(t[E>>2]|0)+((t[S>>2]|0)+3<<2)>>2];t[b+4>>2]=d;xe(v|0,54688,b|0)|0;t[S>>2]=(t[S>>2]|0)+5}}while(0);xe(t[_>>2]|0,54704,b|0)|0;s=l;return}function u_(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,u=0,a=0,o=0,c=0;f=s;s=s+32|0;u=f;a=f+12|0;o=f+8|0;c=f+4|0;t[f+16>>2]=e;t[a>>2]=i;t[o>>2]=r;t[c>>2]=n;t[13584]=(t[13584]|0)+1;if(t[50]|0){s=f;return}n=t[_>>2]|0;t[u>>2]=t[a>>2];xe(n|0,54512,u|0)|0;n=t[_>>2]|0;if(!(t[o>>2]|0))xe(n|0,54536,u|0)|0;else{t[u>>2]=t[o>>2];xe(n|0,54544,u|0)|0}n=t[_>>2]|0;if(!(t[c>>2]|0)){xe(n|0,54552,u|0)|0;s=f;return}else{t[u>>2]=t[c>>2];xe(n|0,54568,u|0)|0;s=f;return}}function a_(){var e=0,i=0,r=0;e=s;s=s+16|0;i=e;r=t[v>>2]|0;t[i>>2]=t[432];xe(r|0,56400,i|0)|0;t[662]=9;s=e;return}function o_(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0;n=s;s=s+32|0;f=n;u=n+12|0;a=n+8|0;o=n+4|0;t[n+16>>2]=e;t[u>>2]=i;t[a>>2]=r;t[13584]=(t[13584]|0)+1;if(t[50]|0){s=n;return}r=t[_>>2]|0;t[f>>2]=t[u>>2];xe(r|0,60952,f|0)|0;e:do if(t[a>>2]|0){t[o>>2]=0;while(1){if(!(t[(t[a>>2]|0)+(t[o>>2]<<2)>>2]|0))break e;r=t[_>>2]|0;u=t[o>>2]|0;t[o>>2]=u+1;t[f>>2]=t[(t[a>>2]|0)+(u<<2)>>2];xe(r|0,54680,f|0)|0;if(t[(t[a>>2]|0)+(t[o>>2]<<2)>>2]|0){r=t[_>>2]|0;t[f>>2]=t[(t[a>>2]|0)+(t[o>>2]<<2)>>2];xe(r|0,60976,f|0)|0}t[o>>2]=(t[o>>2]|0)+1}}while(0);xe(t[_>>2]|0,54704,f|0)|0;s=n;return}function c_(e,i){e=e|0;i=i|0;var r=0,n=0,f=0;r=s;s=s+16|0;n=r;f=r+4|0;t[r+8>>2]=e;t[f>>2]=i;t[13584]=(t[13584]|0)+1;if(t[50]|0){s=r;return}i=t[_>>2]|0;t[n>>2]=t[f>>2];xe(i|0,60928,n|0)|0;s=r;return}function l_(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i+4|0;n=i;t[n>>2]=e;do if(!(t[n>>2]|0))t[r>>2]=0;else{e=u[t[n>>2]>>0]|0;if((e|0)==103){if(Xl(t[n>>2]|0,61072)|0){t[r>>2]=61080;break}}else if((e|0)==97){if(Xl(t[n>>2]|0,61160)|0){t[r>>2]=61168;break}if(Xl(t[n>>2]|0,61248)|0){t[r>>2]=61256;break}}else if((e|0)==108){if(Xl(t[n>>2]|0,60984)|0){t[r>>2]=60992;break}}else if((e|0)==113?(Xl(t[n>>2]|0,61336)|0)!=0:0){t[r>>2]=61344;break}t[r>>2]=0}while(0);s=i;return t[r>>2]|0}function s_(e,i,r,n,f,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;u=u|0;var a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0;a=s;s=s+48|0;o=a+32|0;c=a+28|0;l=a+24|0;b=a+20|0;k=a+16|0;h=a+12|0;w=a+8|0;d=a+4|0;v=a;t[c>>2]=e;t[l>>2]=i;t[b>>2]=r;t[k>>2]=n;t[h>>2]=f;t[w>>2]=u;if(!(t[c>>2]|0)){p_(521,61424);t[o>>2]=0;m=t[o>>2]|0;s=a;return m|0}if(!(t[(t[c>>2]|0)+48>>2]|0)){p_(522,61464);t[o>>2]=0;m=t[o>>2]|0;s=a;return m|0}t[v>>2]=t[(t[c>>2]|0)+48>>2];t[d>>2]=E_(t[v>>2]|0,t[l>>2]|0,t[b>>2]|0,t[k>>2]|0,t[h>>2]|0,t[w>>2]|0)|0;if(!(t[d>>2]|0)){t[o>>2]=0;m=t[o>>2]|0;s=a;return m|0}t[(t[d>>2]|0)+20>>2]=t[v>>2];t[(t[d>>2]|0)+32>>2]=t[(t[v>>2]|0)+32>>2];w=t[d>>2]|0;h=(t[v>>2]|0)+16|0;if(!(t[(t[v>>2]|0)+16>>2]|0)){
	t[h>>2]=w;t[(t[v>>2]|0)+12>>2]=w}else{t[(t[h>>2]|0)+24>>2]=w;t[(t[d>>2]|0)+28>>2]=t[(t[v>>2]|0)+16>>2];t[(t[v>>2]|0)+16>>2]=t[d>>2]}t[o>>2]=t[d>>2];m=t[o>>2]|0;s=a;return m|0}function b_(e,i,r,n,f,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;u=u|0;var a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0;a=s;s=s+48|0;o=a+32|0;c=a+28|0;l=a+24|0;b=a+20|0;k=a+16|0;h=a+12|0;w=a+8|0;d=a+4|0;v=a;t[c>>2]=e;t[l>>2]=i;t[b>>2]=r;t[k>>2]=n;t[h>>2]=f;t[w>>2]=u;if(!(t[c>>2]|0)){p_(521,61520);t[o>>2]=0;m=t[o>>2]|0;s=a;return m|0}if(!(t[(t[c>>2]|0)+44>>2]|0)){p_(522,61560);t[o>>2]=0;m=t[o>>2]|0;s=a;return m|0}t[v>>2]=t[(t[c>>2]|0)+44>>2];t[d>>2]=E_(t[v>>2]|0,t[l>>2]|0,t[b>>2]|0,t[k>>2]|0,t[h>>2]|0,t[w>>2]|0)|0;if(!(t[d>>2]|0)){t[o>>2]=0;m=t[o>>2]|0;s=a;return m|0}t[(t[d>>2]|0)+20>>2]=t[v>>2];t[(t[d>>2]|0)+32>>2]=t[(t[v>>2]|0)+32>>2];w=t[d>>2]|0;h=(t[v>>2]|0)+16|0;if(!(t[(t[v>>2]|0)+16>>2]|0)){t[h>>2]=w;t[(t[v>>2]|0)+12>>2]=w}else{t[(t[h>>2]|0)+24>>2]=w;t[(t[d>>2]|0)+28>>2]=t[(t[v>>2]|0)+16>>2];t[(t[v>>2]|0)+16>>2]=t[d>>2]}t[o>>2]=t[d>>2];m=t[o>>2]|0;s=a;return m|0}function k_(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0;r=s;s=s+32|0;n=r+16|0;f=r+12|0;u=r+8|0;a=r+4|0;o=r;t[f>>2]=e;t[u>>2]=i;if(!(t[f>>2]|0)){t[n>>2]=0;c=t[n>>2]|0;s=r;return c|0}if(((t[(t[f>>2]|0)+44>>2]|0)!=0?(t[(t[(t[f>>2]|0)+44>>2]|0)+60>>2]|0)!=0:0)?(t[a>>2]=t[(t[(t[f>>2]|0)+44>>2]|0)+60>>2],t[o>>2]=g_(t[a>>2]|0,t[u>>2]|0)|0,(t[o>>2]|0)!=0):0){t[n>>2]=t[o>>2];c=t[n>>2]|0;s=r;return c|0}if((t[(t[f>>2]|0)+48>>2]|0)!=0?(t[(t[(t[f>>2]|0)+48>>2]|0)+60>>2]|0)!=0:0){t[a>>2]=t[(t[(t[f>>2]|0)+48>>2]|0)+60>>2];t[n>>2]=g_(t[a>>2]|0,t[u>>2]|0)|0;c=t[n>>2]|0;s=r;return c|0}t[n>>2]=0;c=t[n>>2]|0;s=r;return c|0}function h_(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0;r=s;s=s+32|0;n=r+16|0;f=r+12|0;u=r+8|0;a=r+4|0;o=r;t[f>>2]=e;t[u>>2]=i;if(t[f>>2]|0){if(((t[(t[f>>2]|0)+44>>2]|0)!=0?(t[(t[(t[f>>2]|0)+44>>2]|0)+48>>2]|0)!=0:0)?(t[o>>2]=t[(t[(t[f>>2]|0)+44>>2]|0)+48>>2],t[a>>2]=g_(t[o>>2]|0,t[u>>2]|0)|0,(t[a>>2]|0)!=0):0){t[n>>2]=t[a>>2];c=t[n>>2]|0;s=r;return c|0}if((((t[(t[f>>2]|0)+40>>2]|0)!=1?(t[(t[f>>2]|0)+48>>2]|0)!=0:0)?(t[(t[(t[f>>2]|0)+48>>2]|0)+48>>2]|0)!=0:0)?(t[o>>2]=t[(t[(t[f>>2]|0)+48>>2]|0)+48>>2],t[a>>2]=g_(t[o>>2]|0,t[u>>2]|0)|0,(t[a>>2]|0)!=0):0){t[n>>2]=t[a>>2];c=t[n>>2]|0;s=r;return c|0}}t[n>>2]=l_(t[u>>2]|0)|0;c=t[n>>2]|0;s=r;return c|0}function w_(e,i){e=e|0;i=i|0;var r=0,n=0,f=0;r=s;s=s+16|0;n=r+4|0;f=r;t[n>>2]=e;t[f>>2]=i;i=y_(t[n>>2]|0,t[f>>2]|0,1)|0;s=r;return i|0}function d_(e,i){e=e|0;i=i|0;var r=0,n=0,f=0;r=s;s=s+16|0;n=r+4|0;f=r;t[n>>2]=e;t[f>>2]=i;i=y_(t[n>>2]|0,t[f>>2]|0,0)|0;s=r;return i|0}function v_(e){e=e|0;var i=0,r=0;i=s;s=s+16|0;r=i;t[r>>2]=e;XF(t[r>>2]|0,211);s=i;return}function m_(e){e=e|0;var i=0,r=0;i=s;s=s+16|0;r=i;t[r>>2]=e;e=sO(t[r>>2]|0,212)|0;s=i;return e|0}function __(e,i){e=e|0;i=i|0;var r=0,n=0,f=0;r=s;s=s+16|0;n=r+4|0;f=r;t[n>>2]=e;t[f>>2]=i;if((t[n>>2]|0)==0|(t[f>>2]|0)==0){s=r;return}switch(t[(t[f>>2]|0)+48>>2]|0){case 2:{NF(t[n>>2]|0,61616);RF(t[n>>2]|0,t[(t[f>>2]|0)+8>>2]|0);i=t[n>>2]|0;if(t[(t[f>>2]|0)+52>>2]|0){NF(i,61648);TF(t[n>>2]|0,t[(t[f>>2]|0)+52>>2]|0);NF(t[n>>2]|0,61632);TF(t[n>>2]|0,t[(t[f>>2]|0)+56>>2]|0)}else{NF(i,61664);TF(t[n>>2]|0,t[(t[f>>2]|0)+56>>2]|0)}NF(t[n>>2]|0,61640);s=r;return}case 1:{NF(t[n>>2]|0,61616);RF(t[n>>2]|0,t[(t[f>>2]|0)+8>>2]|0);NF(t[n>>2]|0,61632);i=t[n>>2]|0;e=t[f>>2]|0;if(t[(t[f>>2]|0)+36>>2]|0)TF(i,t[e+36>>2]|0);else M_(i,t[e+40>>2]|0);NF(t[n>>2]|0,61640);s=r;return}case 5:{NF(t[n>>2]|0,61688);RF(t[n>>2]|0,t[(t[f>>2]|0)+8>>2]|0);e=t[n>>2]|0;if(t[(t[f>>2]|0)+52>>2]|0){NF(e,61648);TF(t[n>>2]|0,t[(t[f>>2]|0)+52>>2]|0);NF(t[n>>2]|0,61632);TF(t[n>>2]|0,t[(t[f>>2]|0)+56>>2]|0)}else{NF(e,61664);TF(t[n>>2]|0,t[(t[f>>2]|0)+56>>2]|0)}NF(t[n>>2]|0,61640);s=r;return}case 3:{NF(t[n>>2]|0,61616);RF(t[n>>2]|0,t[(t[f>>2]|0)+8>>2]|0);e=t[n>>2]|0;if(t[(t[f>>2]|0)+52>>2]|0){NF(e,61648);TF(t[n>>2]|0,t[(t[f>>2]|0)+52>>2]|0);NF(t[n>>2]|0,61632);TF(t[n>>2]|0,t[(t[f>>2]|0)+56>>2]|0)}else{NF(e,61664);TF(t[n>>2]|0,t[(t[f>>2]|0)+56>>2]|0)}do if(t[(t[f>>2]|0)+40>>2]|0){NF(t[n>>2]|0,61680);e=t[n>>2]|0;i=t[f>>2]|0;if(t[(t[f>>2]|0)+36>>2]|0){RF(e,t[i+36>>2]|0);break}else{RF(e,t[i+40>>2]|0);break}}while(0);NF(t[n>>2]|0,61640);s=r;return}case 4:{NF(t[n>>2]|0,61688);RF(t[n>>2]|0,t[(t[f>>2]|0)+8>>2]|0);NF(t[n>>2]|0,61632);i=t[n>>2]|0;e=t[f>>2]|0;if(!(t[(t[f>>2]|0)+36>>2]|0))M_(i,t[e+40>>2]|0);else TF(i,t[e+36>>2]|0);NF(t[n>>2]|0,61640);s=r;return}default:{p_(535,61704);s=r;return}}}function p_(e,i){e=e|0;i=i|0;var r=0,n=0,f=0;r=s;s=s+16|0;n=r+4|0;f=r;t[n>>2]=e;t[f>>2]=i;dp(2,t[n>>2]|0,0,t[f>>2]|0,0);s=r;return}function E_(e,i,r,n,f,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;u=u|0;var a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0;a=s;s=s+48|0;o=a+36|0;c=a+32|0;l=a+28|0;b=a+24|0;k=a+20|0;h=a+16|0;w=a+12|0;d=a+8|0;v=a+4|0;m=a;t[c>>2]=e;t[l>>2]=i;t[b>>2]=r;t[k>>2]=n;t[h>>2]=f;t[w>>2]=u;t[d>>2]=0;t[v>>2]=0;if(!(t[l>>2]|0)){t[o>>2]=0;_=t[o>>2]|0;s=a;return _|0}if(!(t[c>>2]|0)){t[o>>2]=0;_=t[o>>2]|0;s=a;return _|0}if(t[(t[c>>2]|0)+32>>2]|0)t[d>>2]=t[(t[(t[c>>2]|0)+32>>2]|0)+80>>2];switch(t[b>>2]|0){case 6:{t[o>>2]=0;_=t[o>>2]|0;s=a;return _|0}case 3:case 2:case 1:{if(!(t[(t[c>>2]|0)+48>>2]|0)){u=KF(0,t[d>>2]|0)|0;t[(t[c>>2]|0)+48>>2]=u}t[v>>2]=t[(t[c>>2]|0)+48>>2];break}case 5:case 4:{if(!(t[(t[c>>2]|0)+60>>2]|0)){u=KF(0,t[d>>2]|0)|0;t[(t[c>>2]|0)+60>>2]=u}t[v>>2]=t[(t[c>>2]|0)+60>>2];break}default:{}}if(!(t[v>>2]|0)){t[o>>2]=0;_=t[o>>2]|0;s=a;return _|0}t[m>>2]=S_(t[d>>2]|0,t[l>>2]|0,t[b>>2]|0,t[k>>2]|0,t[h>>2]|0,t[w>>2]|0)|0;if(!(t[m>>2]|0)){t[o>>2]=0;_=t[o>>2]|0;s=a;return _|0}t[(t[m>>2]|0)+32>>2]=t[(t[c>>2]|0)+32>>2];c=(ZF(t[v>>2]|0,t[l>>2]|0,t[m>>2]|0)|0)!=0;l=t[m>>2]|0;if(c){R_(l);t[o>>2]=0;_=t[o>>2]|0;s=a;return _|0}else{t[o>>2]=l;_=t[o>>2]|0;s=a;return _|0}return 0}function S_(e,i,r,n,f,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;u=u|0;var a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0;a=s;s=s+32|0;o=a+28|0;c=a+24|0;l=a+20|0;b=a+16|0;k=a+12|0;h=a+8|0;w=a+4|0;d=a;t[c>>2]=e;t[l>>2]=i;t[b>>2]=r;t[k>>2]=n;t[h>>2]=f;t[w>>2]=u;t[d>>2]=gAi[t[135744>>2]&511](76)|0;if(!(t[d>>2]|0)){F_(62016);t[o>>2]=0;v=t[o>>2]|0;s=a;return v|0}u=(t[d>>2]|0)+0|0;f=u+76|0;do{t[u>>2]=0;u=u+4|0}while((u|0)<(f|0));t[(t[d>>2]|0)+4>>2]=17;t[(t[d>>2]|0)+72>>2]=0;t[(t[d>>2]|0)+48>>2]=t[b>>2];if(!(t[c>>2]|0)){b=Yl(t[l>>2]|0)|0;t[(t[d>>2]|0)+8>>2]=b;if(t[k>>2]|0){b=Yl(t[k>>2]|0)|0;t[(t[d>>2]|0)+52>>2]=b}if(t[h>>2]|0){b=Yl(t[h>>2]|0)|0;t[(t[d>>2]|0)+56>>2]=b}}else{b=kz(t[c>>2]|0,t[l>>2]|0,-1)|0;t[(t[d>>2]|0)+8>>2]=b;if(t[k>>2]|0){b=kz(t[c>>2]|0,t[k>>2]|0,-1)|0;t[(t[d>>2]|0)+52>>2]=b}if(t[h>>2]|0){b=kz(t[c>>2]|0,t[h>>2]|0,-1)|0;t[(t[d>>2]|0)+56>>2]=b}}do if(t[w>>2]|0){b=rs(t[w>>2]|0)|0;t[(t[d>>2]|0)+44>>2]=b;if((t[c>>2]|0)!=0?(t[(t[d>>2]|0)+44>>2]|0)<5:0){b=kz(t[c>>2]|0,t[w>>2]|0,t[(t[d>>2]|0)+44>>2]|0)|0;t[(t[d>>2]|0)+40>>2]=b;break}b=ql(t[w>>2]|0,t[(t[d>>2]|0)+44>>2]|0)|0;t[(t[d>>2]|0)+40>>2]=b}else{t[(t[d>>2]|0)+44>>2]=0;t[(t[d>>2]|0)+40>>2]=0}while(0);t[(t[d>>2]|0)+64>>2]=0;t[(t[d>>2]|0)+36>>2]=0;t[(t[d>>2]|0)+68>>2]=0;t[o>>2]=t[d>>2];v=t[o>>2]|0;s=a;return v|0}function g_(e,i){e=e|0;i=i|0;var r=0,n=0,f=0;r=s;s=s+16|0;n=r+4|0;f=r;t[n>>2]=e;t[f>>2]=i;i=rO(t[n>>2]|0,t[f>>2]|0)|0;s=r;return i|0}function y_(e,i,r){e=e|0;i=i|0;r=r|0;var f=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0,S=0,g=0,y=0,F=0,O=0,A=0,M=0,R=0,N=0,T=0,L=0,D=0,C=0;f=s;s=s+112|0;a=f;o=f+84|0;c=f+80|0;l=f+76|0;b=f+72|0;k=f+68|0;h=f+64|0;w=f+60|0;d=f+56|0;v=f+52|0;m=f+48|0;_=f+44|0;p=f+40|0;E=f+36|0;S=f+32|0;g=f+28|0;y=f+24|0;F=f+20|0;O=f+99|0;A=f+16|0;M=f+12|0;R=f+8|0;N=f+88|0;T=f+4|0;t[c>>2]=e;t[l>>2]=i;t[b>>2]=r;t[k>>2]=t[l>>2];t[h>>2]=0;t[w>>2]=0;t[d>>2]=0;t[v>>2]=0;if(!(t[l>>2]|0)){t[o>>2]=0;L=t[o>>2]|0;s=f;return L|0}if(t[c>>2]|0)t[v>>2]=(t[(t[c>>2]|0)+4>>2]|0)==13&1;t[d>>2]=1e3;t[h>>2]=gAi[t[135744>>2]&511](t[d>>2]|0)|0;if(!(t[h>>2]|0)){F_(61816);t[o>>2]=0;L=t[o>>2]|0;s=f;return L|0}t[w>>2]=t[h>>2];e:while(1){D=t[w>>2]|0;if(!(u[t[k>>2]>>0]|0)){C=87;break}t[m>>2]=D-(t[h>>2]|0);if(((t[m>>2]|0)+100|0)>>>0>(t[d>>2]|0)>>>0){t[p>>2]=t[d>>2]<<1;if((t[p>>2]|0)>>>0<(t[d>>2]|0)>>>0){C=88;break}t[_>>2]=MAi[t[135760>>2]&511](t[h>>2]|0,t[p>>2]|0)|0;if(!(t[_>>2]|0)){C=88;break}t[h>>2]=t[_>>2];t[d>>2]=t[p>>2];t[w>>2]=(t[h>>2]|0)+(t[m>>2]|0)}i:do if((u[t[k>>2]>>0]|0)==60){if(((((t[v>>2]|0)!=0&(t[b>>2]|0)!=0?(u[(t[k>>2]|0)+1>>0]|0)==33:0)?(u[(t[k>>2]|0)+2>>0]|0)==45:0)?(u[(t[k>>2]|0)+3>>0]|0)==45:0)?(l=is(t[k>>2]|0,61856)|0,t[E>>2]=l,(l|0)!=0):0){while(1){l=(t[k>>2]|0)!=(t[E>>2]|0);r=t[k>>2]|0;t[k>>2]=r+1;i=n[r>>0]|0;r=t[w>>2]|0;t[w>>2]=r+1;n[r>>0]=i;if(!l)break;t[m>>2]=(t[w>>2]|0)-(t[h>>2]|0);if(((t[m>>2]|0)+100|0)>>>0<=(t[d>>2]|0)>>>0)continue;t[g>>2]=t[d>>2]<<1;if((t[g>>2]|0)>>>0<(t[d>>2]|0)>>>0){C=88;break e}t[S>>2]=MAi[t[135760>>2]&511](t[h>>2]|0,t[g>>2]|0)|0;if(!(t[S>>2]|0)){C=88;break e}t[h>>2]=t[S>>2];t[d>>2]=t[g>>2];t[w>>2]=(t[h>>2]|0)+(t[m>>2]|0)}l=t[k>>2]|0;t[k>>2]=l+1;i=n[l>>0]|0;l=t[w>>2]|0;t[w>>2]=l+1;n[l>>0]=i;i=t[k>>2]|0;t[k>>2]=i+1;l=n[i>>0]|0;i=t[w>>2]|0;t[w>>2]=i+1;n[i>>0]=l;continue e}l=t[w>>2]|0;t[w>>2]=l+1;n[l>>0]=38;l=t[w>>2]|0;t[w>>2]=l+1;n[l>>0]=108;l=t[w>>2]|0;t[w>>2]=l+1;n[l>>0]=116;l=t[w>>2]|0;t[w>>2]=l+1;n[l>>0]=59}else{if((u[t[k>>2]>>0]|0)==62){l=t[w>>2]|0;t[w>>2]=l+1;n[l>>0]=38;l=t[w>>2]|0;t[w>>2]=l+1;n[l>>0]=103;l=t[w>>2]|0;t[w>>2]=l+1;n[l>>0]=116;l=t[w>>2]|0;t[w>>2]=l+1;n[l>>0]=59;break}if((u[t[k>>2]>>0]|0)==38){if(((t[v>>2]|0)!=0&(t[b>>2]|0)!=0?(u[(t[k>>2]|0)+1>>0]|0)==123:0)?(Yq(t[k>>2]|0,125)|0)!=0:0)while(1){l=(u[t[k>>2]>>0]|0)!=125;i=t[k>>2]|0;t[k>>2]=i+1;r=n[i>>0]|0;i=t[w>>2]|0;t[w>>2]=i+1;n[i>>0]=r;if(!l)continue e;t[m>>2]=(t[w>>2]|0)-(t[h>>2]|0);if(((t[m>>2]|0)+100|0)>>>0<=(t[d>>2]|0)>>>0)continue;t[F>>2]=t[d>>2]<<1;if((t[F>>2]|0)>>>0<(t[d>>2]|0)>>>0){C=88;break e}t[y>>2]=MAi[t[135760>>2]&511](t[h>>2]|0,t[F>>2]|0)|0;if(!(t[y>>2]|0)){C=88;break e}t[h>>2]=t[y>>2];t[d>>2]=t[F>>2];t[w>>2]=(t[h>>2]|0)+(t[m>>2]|0)}l=t[w>>2]|0;t[w>>2]=l+1;n[l>>0]=38;l=t[w>>2]|0;t[w>>2]=l+1;n[l>>0]=97;l=t[w>>2]|0;t[w>>2]=l+1;n[l>>0]=109;l=t[w>>2]|0;t[w>>2]=l+1;n[l>>0]=112;l=t[w>>2]|0;t[w>>2]=l+1;n[l>>0]=59;break}if(!((u[t[k>>2]>>0]|0)>=32?(u[t[k>>2]>>0]|0)<128:0))C=40;do if(((C|0)==40?(C=0,(u[t[k>>2]>>0]|0)!=10):0)?(u[t[k>>2]>>0]|0)!=9:0){if((t[v>>2]|0)!=0?(u[t[k>>2]>>0]|0)==13:0)break;if((u[t[k>>2]>>0]|0)<128){if(!(9<=(u[t[k>>2]>>0]|0)?(u[t[k>>2]>>0]|0)<=10:0))C=81;if(((C|0)==81?(C=0,(u[t[k>>2]>>0]|0)!=13):0)?32>(u[t[k>>2]>>0]|0):0)break i;t[a>>2]=u[t[k>>2]>>0];SY(N,11,61920,a)|0;n[N+10>>0]=0;t[T>>2]=N;while(1){if(!(n[t[T>>2]>>0]|0))break i;l=t[T>>2]|0;t[T>>2]=l+1;r=n[l>>0]|0;l=t[w>>2]|0;t[w>>2]=l+1;n[l>>0]=r}}if(t[c>>2]|0){if((t[v>>2]|0)!=0?1:(t[(t[c>>2]|0)+60>>2]|0)!=0)C=49}else if(t[v>>2]|0)C=49;if((C|0)==49){C=0;r=n[t[k>>2]>>0]|0;l=t[w>>2]|0;t[w>>2]=l+1;n[l>>0]=r;break i}t[M>>2]=0;t[R>>2]=1;if((u[t[k>>2]>>0]|0)<192){p_(5032,61864);if(t[c>>2]|0){r=Yl(61904)|0;t[(t[c>>2]|0)+60>>2]=r}t[a>>2]=u[t[k>>2]>>0];SY(O,11,61920,a)|0;n[O+10>>0]=0;t[A>>2]=O;while(1){if(!(n[t[A>>2]>>0]|0))break;r=t[A>>2]|0;t[A>>2]=r+1;l=n[r>>0]|0;r=t[w>>2]|0;t[w>>2]=r+1;n[r>>0]=l}t[k>>2]=(t[k>>2]|0)+1;continue e}l=t[k>>2]|0;do if((u[t[k>>2]>>0]|0)<224){t[M>>2]=u[l>>0]&31;t[M>>2]=t[M>>2]<<6;t[M>>2]=t[M>>2]|u[(t[k>>2]|0)+1>>0]&63;t[R>>2]=2}else{r=t[k>>2]|0;if((u[l>>0]|0)<240){t[M>>2]=u[r>>0]&15;t[M>>2]=t[M>>2]<<6;t[M>>2]=t[M>>2]|u[(t[k>>2]|0)+1>>0]&63;t[M>>2]=t[M>>2]<<6;t[M>>2]=t[M>>2]|u[(t[k>>2]|0)+2>>0]&63;t[R>>2]=3;break}if((u[r>>0]|0)>=248)break;t[M>>2]=u[t[k>>2]>>0]&7;t[M>>2]=t[M>>2]<<6;t[M>>2]=t[M>>2]|u[(t[k>>2]|0)+1>>0]&63;t[M>>2]=t[M>>2]<<6;t[M>>2]=t[M>>2]|u[(t[k>>2]|0)+2>>0]&63;t[M>>2]=t[M>>2]<<6;t[M>>2]=t[M>>2]|u[(t[k>>2]|0)+3>>0]&63;t[R>>2]=4}while(0);r:do if((t[R>>2]|0)!=1){l=t[M>>2]|0;do if((t[M>>2]|0)<256){if(!(9<=(l|0)&(t[M>>2]|0)<=10|(t[M>>2]|0)==13|32<=(t[M>>2]|0)))break r}else{if(256<=(l|0)&(t[M>>2]|0)<=55295)break;if(57344<=(t[M>>2]|0)&(t[M>>2]|0)<=65533)break;if(!(65536<=(t[M>>2]|0)&(t[M>>2]|0)<=1114111))break r}while(0);t[a>>2]=t[M>>2];SY(O,11,61968,a)|0;n[O+10>>0]=0;t[A>>2]=O;while(1){if(!(n[t[A>>2]>>0]|0))break;l=t[A>>2]|0;t[A>>2]=l+1;r=n[l>>0]|0;l=t[w>>2]|0;t[w>>2]=l+1;n[l>>0]=r}t[k>>2]=(t[k>>2]|0)+(t[R>>2]|0);continue e}while(0);p_(9,61928);if(t[c>>2]|0){r=Yl(61904)|0;t[(t[c>>2]|0)+60>>2]=r}t[a>>2]=u[t[k>>2]>>0];SY(O,11,61920,a)|0;n[O+10>>0]=0;t[A>>2]=O;while(1){if(!(n[t[A>>2]>>0]|0))break;r=t[A>>2]|0;t[A>>2]=r+1;l=n[r>>0]|0;r=t[w>>2]|0;t[w>>2]=r+1;n[r>>0]=l}t[k>>2]=(t[k>>2]|0)+1;continue e}while(0);l=n[t[k>>2]>>0]|0;r=t[w>>2]|0;t[w>>2]=r+1;n[r>>0]=l}while(0);t[k>>2]=(t[k>>2]|0)+1}if((C|0)==87){n[D>>0]=0;t[o>>2]=t[h>>2];L=t[o>>2]|0;s=f;return L|0}else if((C|0)==88){F_(61976);pAi[t[135736>>2]&511](t[h>>2]|0);t[o>>2]=0;L=t[o>>2]|0;s=f;return L|0}return 0}function F_(e){e=e|0;var i=0,r=0;i=s;s=s+16|0;r=i;t[r>>2]=e;dp(2,2,0,0,t[r>>2]|0);s=i;return}function O_(e,i){e=e|0;i=i|0;var r=0,n=0;r=s;s=s+16|0;n=r+4|0;t[n>>2]=e;t[r>>2]=i;if(!(t[n>>2]|0)){s=r;return}R_(t[n>>2]|0);s=r;return}function A_(e){e=e|0;var i=0,r=0,n=0,f=0,u=0,a=0;i=s;s=s+16|0;r=i+8|0;n=i+4|0;f=i;t[n>>2]=e;t[f>>2]=gAi[t[135744>>2]&511](76)|0;if(!(t[f>>2]|0)){F_(61784);t[r>>2]=0;u=t[r>>2]|0;s=i;return u|0}e=(t[f>>2]|0)+0|0;a=e+76|0;do{t[e>>2]=0;e=e+4|0}while((e|0)<(a|0));t[(t[f>>2]|0)+4>>2]=17;t[(t[f>>2]|0)+48>>2]=t[(t[n>>2]|0)+48>>2];if(t[(t[n>>2]|0)+8>>2]|0){e=Yl(t[(t[n>>2]|0)+8>>2]|0)|0;t[(t[f>>2]|0)+8>>2]=e}if(t[(t[n>>2]|0)+52>>2]|0){e=Yl(t[(t[n>>2]|0)+52>>2]|0)|0;t[(t[f>>2]|0)+52>>2]=e}if(t[(t[n>>2]|0)+56>>2]|0){e=Yl(t[(t[n>>2]|0)+56>>2]|0)|0;t[(t[f>>2]|0)+56>>2]=e}if(t[(t[n>>2]|0)+40>>2]|0){e=Yl(t[(t[n>>2]|0)+40>>2]|0)|0;t[(t[f>>2]|0)+40>>2]=e}if(t[(t[n>>2]|0)+36>>2]|0){e=Yl(t[(t[n>>2]|0)+36>>2]|0)|0;t[(t[f>>2]|0)+36>>2]=e}if(t[(t[n>>2]|0)+64>>2]|0){e=Yl(t[(t[n>>2]|0)+64>>2]|0)|0;t[(t[f>>2]|0)+64>>2]=e}t[r>>2]=t[f>>2];u=t[r>>2]|0;s=i;return u|0}function M_(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,a=0,o=0;r=s;s=s+16|0;n=r+12|0;f=r+8|0;a=r+4|0;o=r;t[n>>2]=e;t[f>>2]=i;if((t[(t[n>>2]|0)+12>>2]|0)==2){s=r;return}i=(es(t[f>>2]|0,37)|0)!=0;e=t[n>>2]|0;if(!i){TF(e,t[f>>2]|0);s=r;return}MF(e,61760)|0;e=t[f>>2]|0;t[o>>2]=e;t[a>>2]=e;while(1){if(!(u[t[o>>2]>>0]|0))break;if((u[t[o>>2]>>0]|0|0)==34){if((t[a>>2]|0)!=(t[o>>2]|0))OF(t[n>>2]|0,t[a>>2]|0,(t[o>>2]|0)-(t[a>>2]|0)|0)|0;OF(t[n>>2]|0,61768,6)|0;t[o>>2]=(t[o>>2]|0)+1;t[a>>2]=t[o>>2];continue}if((u[t[o>>2]>>0]|0|0)!=37){t[o>>2]=(t[o>>2]|0)+1;continue}if((t[a>>2]|0)!=(t[o>>2]|0))OF(t[n>>2]|0,t[a>>2]|0,(t[o>>2]|0)-(t[a>>2]|0)|0)|0;OF(t[n>>2]|0,61776,6)|0;t[o>>2]=(t[o>>2]|0)+1;t[a>>2]=t[o>>2]}if((t[a>>2]|0)!=(t[o>>2]|0))OF(t[n>>2]|0,t[a>>2]|0,(t[o>>2]|0)-(t[a>>2]|0)|0)|0;MF(t[n>>2]|0,61760)|0;s=r;return}function R_(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i+4|0;n=i;t[r>>2]=e;t[n>>2]=0;if(!(t[r>>2]|0)){s=i;return}if(t[(t[r>>2]|0)+32>>2]|0)t[n>>2]=t[(t[(t[r>>2]|0)+32>>2]|0)+80>>2];if(((t[(t[r>>2]|0)+12>>2]|0)!=0?(t[(t[r>>2]|0)+68>>2]|0)==1:0)?(t[r>>2]|0)==(t[(t[(t[r>>2]|0)+12>>2]|0)+20>>2]|0):0)ty(t[(t[r>>2]|0)+12>>2]|0);e=(t[(t[r>>2]|0)+8>>2]|0)!=0;if(t[n>>2]|0){if(e?(wz(t[n>>2]|0,t[(t[r>>2]|0)+8>>2]|0)|0)==0:0)pAi[t[135736>>2]&511](t[(t[r>>2]|0)+8>>2]|0);if((t[(t[r>>2]|0)+52>>2]|0)!=0?(wz(t[n>>2]|0,t[(t[r>>2]|0)+52>>2]|0)|0)==0:0)pAi[t[135736>>2]&511](t[(t[r>>2]|0)+52>>2]|0);if((t[(t[r>>2]|0)+56>>2]|0)!=0?(wz(t[n>>2]|0,t[(t[r>>2]|0)+56>>2]|0)|0)==0:0)pAi[t[135736>>2]&511](t[(t[r>>2]|0)+56>>2]|0);if((t[(t[r>>2]|0)+64>>2]|0)!=0?(wz(t[n>>2]|0,t[(t[r>>2]|0)+64>>2]|0)|0)==0:0)pAi[t[135736>>2]&511](t[(t[r>>2]|0)+64>>2]|0);if((t[(t[r>>2]|0)+40>>2]|0)!=0?(wz(t[n>>2]|0,t[(t[r>>2]|0)+40>>2]|0)|0)==0:0)pAi[t[135736>>2]&511](t[(t[r>>2]|0)+40>>2]|0);if((t[(t[r>>2]|0)+36>>2]|0)!=0?(wz(t[n>>2]|0,t[(t[r>>2]|0)+36>>2]|0)|0)==0:0)pAi[t[135736>>2]&511](t[(t[r>>2]|0)+36>>2]|0)}else{if(e)pAi[t[135736>>2]&511](t[(t[r>>2]|0)+8>>2]|0);if(t[(t[r>>2]|0)+52>>2]|0)pAi[t[135736>>2]&511](t[(t[r>>2]|0)+52>>2]|0);if(t[(t[r>>2]|0)+56>>2]|0)pAi[t[135736>>2]&511](t[(t[r>>2]|0)+56>>2]|0);if(t[(t[r>>2]|0)+64>>2]|0)pAi[t[135736>>2]&511](t[(t[r>>2]|0)+64>>2]|0);if(t[(t[r>>2]|0)+40>>2]|0)pAi[t[135736>>2]&511](t[(t[r>>2]|0)+40>>2]|0);if(t[(t[r>>2]|0)+36>>2]|0)pAi[t[135736>>2]&511](t[(t[r>>2]|0)+36>>2]|0)}pAi[t[135736>>2]&511](t[r>>2]|0);s=i;return}function N_(e,i,r,f){e=e|0;i=i|0;r=r|0;f=f|0;var a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0;a=s;s=s+48|0;o=a+36|0;c=a+32|0;l=a+28|0;b=a+24|0;k=a+20|0;h=a+16|0;w=a+12|0;d=a+8|0;v=a+4|0;m=a;t[c>>2]=e;t[l>>2]=i;t[b>>2]=r;t[k>>2]=f;t[h>>2]=t[c>>2];t[w>>2]=t[b>>2];if((t[c>>2]|0)==0|(t[b>>2]|0)==0|(t[l>>2]|0)==0|(t[k>>2]|0)==0){t[o>>2]=-1;_=t[o>>2]|0;s=a;return _|0}t[d>>2]=(t[c>>2]|0)+(t[t[l>>2]>>2]|0);t[v>>2]=(t[b>>2]|0)+(t[t[k>>2]>>2]|0);t[m>>2]=t[v>>2];e:while(1){if((t[b>>2]|0)>>>0<(t[v>>2]|0)>>>0)p=(t[c>>2]|0)>>>0<((t[d>>2]|0)+-1|0)>>>0;else p=0;E=t[b>>2]|0;if(!p)break;if((u[E>>0]|0|0)>=128){f=((u[t[b>>2]>>0]|0)>>6&31|192)&255;r=t[c>>2]|0;t[c>>2]=r+1;n[r>>0]=f;f=((u[t[b>>2]>>0]|0)&63|128)&255;r=t[c>>2]|0;t[c>>2]=r+1;n[r>>0]=f;t[b>>2]=(t[b>>2]|0)+1}if(((t[m>>2]|0)-(t[b>>2]|0)|0)>((t[d>>2]|0)-(t[c>>2]|0)|0))t[m>>2]=(t[b>>2]|0)+((t[d>>2]|0)-(t[c>>2]|0));while(1){if((t[b>>2]|0)>>>0>=(t[m>>2]|0)>>>0)continue e;if((u[t[b>>2]>>0]|0|0)>=128)continue e;f=t[b>>2]|0;t[b>>2]=f+1;r=n[f>>0]|0;f=t[c>>2]|0;t[c>>2]=f+1;n[f>>0]=r}}if((E>>>0<(t[v>>2]|0)>>>0?(t[c>>2]|0)>>>0<(t[d>>2]|0)>>>0:0)?(u[t[b>>2]>>0]|0|0)<128:0){d=t[b>>2]|0;t[b>>2]=d+1;v=n[d>>0]|0;d=t[c>>2]|0;t[c>>2]=d+1;n[d>>0]=v}t[t[l>>2]>>2]=(t[c>>2]|0)-(t[h>>2]|0);t[t[k>>2]>>2]=(t[b>>2]|0)-(t[w>>2]|0);t[o>>2]=t[t[l>>2]>>2];_=t[o>>2]|0;s=a;return _|0}function T_(e,i,r,f){e=e|0;i=i|0;r=r|0;f=f|0;var a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0,S=0,g=0,y=0;a=s;s=s+64|0;o=a+48|0;c=a+44|0;l=a+40|0;b=a+36|0;k=a+32|0;h=a+28|0;w=a+24|0;d=a+20|0;v=a+16|0;m=a+12|0;_=a+8|0;p=a+4|0;E=a;t[c>>2]=e;t[l>>2]=i;t[b>>2]=r;t[k>>2]=f;t[h>>2]=t[b>>2];t[d>>2]=t[c>>2];t[v>>2]=t[b>>2];if((t[c>>2]|0)==0|(t[l>>2]|0)==0|(t[k>>2]|0)==0){t[o>>2]=-1;S=t[o>>2]|0;s=a;return S|0}if(!(t[b>>2]|0)){t[t[l>>2]>>2]=0;t[t[k>>2]>>2]=0;t[o>>2]=0;S=t[o>>2]|0;s=a;return S|0}t[m>>2]=(t[b>>2]|0)+(t[t[k>>2]>>2]|0);t[w>>2]=(t[c>>2]|0)+(t[t[l>>2]>>2]|0);e:while(1){if((t[b>>2]|0)>>>0>=(t[m>>2]|0)>>>0){g=28;break}f=t[b>>2]|0;t[b>>2]=f+1;t[p>>2]=u[f>>0];f=t[p>>2]|0;do if((t[p>>2]|0)>>>0<128){t[_>>2]=f;t[E>>2]=0}else{if(f>>>0<192){g=10;break e}r=t[p>>2]|0;if((t[p>>2]|0)>>>0<224){t[_>>2]=r&31;t[E>>2]=1;break}i=t[p>>2]|0;if(r>>>0<240){t[_>>2]=i&15;t[E>>2]=2;break}if(i>>>0>=248){g=17;break e}t[_>>2]=t[p>>2]&7;t[E>>2]=3}while(0);if(((t[m>>2]|0)-(t[b>>2]|0)|0)<(t[E>>2]|0)){g=28;break}while(1){if(!(t[E>>2]|0))break;if((t[b>>2]|0)>>>0>=(t[m>>2]|0)>>>0)break;f=t[b>>2]|0;t[b>>2]=f+1;i=u[f>>0]|0;t[p>>2]=i;if((i&192|0)!=128){g=22;break e}t[_>>2]=t[_>>2]<<6;t[_>>2]=t[_>>2]|t[p>>2]&63;t[E>>2]=(t[E>>2]|0)+-1}y=t[c>>2]|0;if((t[_>>2]|0)>>>0>255){g=27;break}if(y>>>0>=(t[w>>2]|0)>>>0){g=28;break}i=t[_>>2]&255;f=t[c>>2]|0;t[c>>2]=f+1;n[f>>0]=i;t[h>>2]=t[b>>2]}if((g|0)==10){t[t[l>>2]>>2]=(t[c>>2]|0)-(t[d>>2]|0);t[t[k>>2]>>2]=(t[h>>2]|0)-(t[v>>2]|0);t[o>>2]=-2;S=t[o>>2]|0;s=a;return S|0}else if((g|0)==17){t[t[l>>2]>>2]=(t[c>>2]|0)-(t[d>>2]|0);t[t[k>>2]>>2]=(t[h>>2]|0)-(t[v>>2]|0);t[o>>2]=-2;S=t[o>>2]|0;s=a;return S|0}else if((g|0)==22){t[t[l>>2]>>2]=(t[c>>2]|0)-(t[d>>2]|0);t[t[k>>2]>>2]=(t[h>>2]|0)-(t[v>>2]|0);t[o>>2]=-2;S=t[o>>2]|0;s=a;return S|0}else if((g|0)==27){t[t[l>>2]>>2]=y-(t[d>>2]|0);t[t[k>>2]>>2]=(t[h>>2]|0)-(t[v>>2]|0);t[o>>2]=-2;S=t[o>>2]|0;s=a;return S|0}else if((g|0)==28){t[t[l>>2]>>2]=(t[c>>2]|0)-(t[d>>2]|0);t[t[k>>2]>>2]=(t[h>>2]|0)-(t[v>>2]|0);t[o>>2]=t[t[l>>2]>>2];S=t[o>>2]|0;s=a;return S|0}return 0}function L_(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,a=0,o=0;r=s;s=s+16|0;n=r+8|0;f=r+4|0;a=r;t[f>>2]=e;t[a>>2]=i;if(!(t[f>>2]|0)){t[n>>2]=0;o=t[n>>2]|0;s=r;return o|0}if((t[a>>2]|0)>=4){if((((u[t[f>>2]>>0]|0|0)==0?(u[(t[f>>2]|0)+1>>0]|0|0)==0:0)?(u[(t[f>>2]|0)+2>>0]|0|0)==0:0)?(u[(t[f>>2]|0)+3>>0]|0|0)==60:0){t[n>>2]=5;o=t[n>>2]|0;s=r;return o|0}if((((u[t[f>>2]>>0]|0|0)==60?(u[(t[f>>2]|0)+1>>0]|0|0)==0:0)?(u[(t[f>>2]|0)+2>>0]|0|0)==0:0)?(u[(t[f>>2]|0)+3>>0]|0|0)==0:0){t[n>>2]=4;o=t[n>>2]|0;s=r;return o|0}if((((u[t[f>>2]>>0]|0|0)==0?(u[(t[f>>2]|0)+1>>0]|0|0)==0:0)?(u[(t[f>>2]|0)+2>>0]|0|0)==60:0)?(u[(t[f>>2]|0)+3>>0]|0|0)==0:0){t[n>>2]=7;o=t[n>>2]|0;s=r;return o|0}if((((u[t[f>>2]>>0]|0|0)==0?(u[(t[f>>2]|0)+1>>0]|0|0)==60:0)?(u[(t[f>>2]|0)+2>>0]|0|0)==0:0)?(u[(t[f>>2]|0)+3>>0]|0|0)==0:0){t[n>>2]=8;o=t[n>>2]|0;s=r;return o|0}if((((u[t[f>>2]>>0]|0|0)==76?(u[(t[f>>2]|0)+1>>0]|0|0)==111:0)?(u[(t[f>>2]|0)+2>>0]|0|0)==167:0)?(u[(t[f>>2]|0)+3>>0]|0|0)==148:0){t[n>>2]=6;o=t[n>>2]|0;s=r;return o|0}if((((u[t[f>>2]>>0]|0|0)==60?(u[(t[f>>2]|0)+1>>0]|0|0)==63:0)?(u[(t[f>>2]|0)+2>>0]|0|0)==120:0)?(u[(t[f>>2]|0)+3>>0]|0|0)==109:0){t[n>>2]=1;o=t[n>>2]|0;s=r;return o|0}if((((u[t[f>>2]>>0]|0|0)==60?(u[(t[f>>2]|0)+1>>0]|0|0)==0:0)?(u[(t[f>>2]|0)+2>>0]|0|0)==63:0)?(u[(t[f>>2]|0)+3>>0]|0|0)==0:0){t[n>>2]=2;o=t[n>>2]|0;s=r;return o|0}if((((u[t[f>>2]>>0]|0|0)==0?(u[(t[f>>2]|0)+1>>0]|0|0)==60:0)?(u[(t[f>>2]|0)+2>>0]|0|0)==0:0)?(u[(t[f>>2]|0)+3>>0]|0|0)==63:0){t[n>>2]=3;o=t[n>>2]|0;s=r;return o|0}}if((((t[a>>2]|0)>=3?(u[t[f>>2]>>0]|0|0)==239:0)?(u[(t[f>>2]|0)+1>>0]|0|0)==187:0)?(u[(t[f>>2]|0)+2>>0]|0|0)==191:0){t[n>>2]=1;o=t[n>>2]|0;s=r;return o|0}if((t[a>>2]|0)>=2){if((u[t[f>>2]>>0]|0|0)==254?(u[(t[f>>2]|0)+1>>0]|0|0)==255:0){t[n>>2]=3;o=t[n>>2]|0;s=r;return o|0}if((u[t[f>>2]>>0]|0|0)==255?(u[(t[f>>2]|0)+1>>0]|0|0)==254:0){t[n>>2]=2;o=t[n>>2]|0;s=r;return o|0}}t[n>>2]=0;o=t[n>>2]|0;s=r;return o|0}function D_(){var e=0,i=0;e=s;s=s+16|0;i=e;if(!(t[15520]|0)){s=e;return}t[i>>2]=0;while(1){if((t[i>>2]|0)>=(t[15522]|0))break;if(t[(t[15520]|0)+(t[i>>2]<<3)>>2]|0)pAi[t[135736>>2]&511](t[(t[15520]|0)+(t[i>>2]<<3)>>2]|0);if(t[(t[15520]|0)+(t[i>>2]<<3)+4>>2]|0)pAi[t[135736>>2]&511](t[(t[15520]|0)+(t[i>>2]<<3)+4>>2]|0);t[i>>2]=(t[i>>2]|0)+1}t[15522]=0;t[15524]=0;pAi[t[135736>>2]&511](t[15520]|0);t[15520]=0;s=e;return}function C_(e){e=e|0;var i=0,r=0,f=0,u=0,a=0,o=0,c=0,l=0;i=s;s=s+112|0;r=i+8|0;f=i+4|0;u=i;a=i+12|0;t[f>>2]=e;if(!(t[f>>2]|0)){t[r>>2]=0;o=t[r>>2]|0;s=i;return o|0}if(!(t[15520]|0)){t[r>>2]=0;o=t[r>>2]|0;s=i;return o|0}t[u>>2]=0;while(1){if((t[u>>2]|0)>=99)break;e=(Pq(n[(t[f>>2]|0)+(t[u>>2]|0)>>0]|0)|0)&255;n[a+(t[u>>2]|0)>>0]=e;if(!(n[a+(t[u>>2]|0)>>0]|0))break;t[u>>2]=(t[u>>2]|0)+1}n[a+(t[u>>2]|0)>>0]=0;t[u>>2]=0;while(1){if((t[u>>2]|0)>=(t[15522]|0)){c=14;break}f=(MY(t[(t[15520]|0)+(t[u>>2]<<3)+4>>2]|0,a)|0)!=0;l=t[u>>2]|0;if(!f){c=12;break}t[u>>2]=l+1}if((c|0)==12){t[r>>2]=t[(t[15520]|0)+(l<<3)>>2];o=t[r>>2]|0;s=i;return o|0}else if((c|0)==14){t[r>>2]=0;o=t[r>>2]|0;s=i;return o|0}return 0}function P_(e,i){e=e|0;i=i|0;var r=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0;r=s;s=s+128|0;f=r+12|0;u=r+8|0;a=r+4|0;o=r;c=r+16|0;t[u>>2]=e;t[a>>2]=i;if((t[u>>2]|0)==0|(t[a>>2]|0)==0){t[f>>2]=-1;l=t[f>>2]|0;s=r;return l|0}t[o>>2]=0;while(1){if((t[o>>2]|0)>=99)break;i=(Pq(n[(t[a>>2]|0)+(t[o>>2]|0)>>0]|0)|0)&255;n[c+(t[o>>2]|0)>>0]=i;if(!(n[c+(t[o>>2]|0)>>0]|0))break;t[o>>2]=(t[o>>2]|0)+1}n[c+(t[o>>2]|0)>>0]=0;if(!(t[15520]|0)){t[15522]=0;t[15524]=20;t[15520]=gAi[t[135744>>2]&511](t[15524]<<3)|0;if(!(t[15520]|0)){t[f>>2]=-1;l=t[f>>2]|0;s=r;return l|0}}else if((t[15522]|0)>=(t[15524]|0)){t[15524]=t[15524]<<1;t[15520]=MAi[t[135760>>2]&511](t[15520]|0,t[15524]<<3)|0}t[o>>2]=0;while(1){if((t[o>>2]|0)>=(t[15522]|0)){b=17;break}if(!(MY(t[(t[15520]|0)+(t[o>>2]<<3)+4>>2]|0,c)|0)){b=15;break}t[o>>2]=(t[o>>2]|0)+1}if((b|0)==15){pAi[t[135736>>2]&511](t[(t[15520]|0)+(t[o>>2]<<3)>>2]|0);a=gAi[t[135768>>2]&511](t[u>>2]|0)|0;t[(t[15520]|0)+(t[o>>2]<<3)>>2]=a;t[f>>2]=0;l=t[f>>2]|0;s=r;return l|0}else if((b|0)==17){b=gAi[t[135768>>2]&511](t[u>>2]|0)|0;t[(t[15520]|0)+(t[15522]<<3)>>2]=b;b=gAi[t[135768>>2]&511](c)|0;t[(t[15520]|0)+(t[15522]<<3)+4>>2]=b;t[15522]=(t[15522]|0)+1;t[f>>2]=0;l=t[f>>2]|0;s=r;return l|0}return 0}function B_(e){e=e|0;var i=0,r=0,f=0,u=0,a=0,o=0;i=s;s=s+528|0;r=i+12|0;f=i+8|0;u=i+4|0;a=i+16|0;o=i;t[f>>2]=e;do if(t[f>>2]|0){t[u>>2]=C_(t[f>>2]|0)|0;if(t[u>>2]|0)t[f>>2]=t[u>>2];t[o>>2]=0;while(1){if((t[o>>2]|0)>=499)break;e=(Pq(n[(t[f>>2]|0)+(t[o>>2]|0)>>0]|0)|0)&255;n[a+(t[o>>2]|0)>>0]=e;if(!(n[a+(t[o>>2]|0)>>0]|0))break;t[o>>2]=(t[o>>2]|0)+1}n[a+(t[o>>2]|0)>>0]=0;if(!(MY(a,62104)|0)){t[r>>2]=0;break}if(!(MY(a,62112)|0)){t[r>>2]=1;break}if(!(MY(a,62120)|0)){t[r>>2]=1;break}if(!(MY(a,62128)|0)){t[r>>2]=2;break}if(!(MY(a,62136)|0)){t[r>>2]=2;break}if(!(MY(a,62144)|0)){t[r>>2]=9;break}if(!(MY(a,62160)|0)){t[r>>2]=9;break}if(!(MY(a,62168)|0)){t[r>>2]=9;break}if(!(MY(a,62176)|0)){t[r>>2]=4;break}if(!(MY(a,62192)|0)){t[r>>2]=4;break}if(!(MY(a,62200)|0)){t[r>>2]=4;break}if(!(MY(a,62208)|0)){t[r>>2]=10;break}if(!(MY(a,62224)|0)){t[r>>2]=10;break}if(!(MY(a,62240)|0)){t[r>>2]=10;break}if(!(MY(a,62256)|0)){t[r>>2]=11;break}if(!(MY(a,62272)|0)){t[r>>2]=11;break}if(!(MY(a,62288)|0)){t[r>>2]=11;break}if(!(MY(a,62304)|0)){t[r>>2]=12;break}if(!(MY(a,62320)|0)){t[r>>2]=13;break}if(!(MY(a,62336)|0)){t[r>>2]=14;break}if(!(MY(a,62352)|0)){t[r>>2]=15;break}if(!(MY(a,62368)|0)){t[r>>2]=16;break}if(!(MY(a,62384)|0)){t[r>>2]=17;break}if(!(MY(a,62400)|0)){t[r>>2]=18;break}if(!(MY(a,62416)|0)){t[r>>2]=19;break}if(!(MY(a,62432)|0)){t[r>>2]=20;break}if(MY(a,62448)|0){t[r>>2]=-1;break}else{t[r>>2]=21;break}}else t[r>>2]=0;while(0);s=i;return t[r>>2]|0}function I_(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i+4|0;n=i;t[n>>2]=e;do switch(t[n>>2]|0){case 4:{t[r>>2]=62176;break}case 10:{t[r>>2]=62208;break}case 20:{t[r>>2]=62464;break}case 3:{t[r>>2]=62128;break}case 15:{t[r>>2]=62352;break}case 12:{t[r>>2]=62304;break}case 6:{t[r>>2]=62456;break}case 21:{t[r>>2]=62448;break}case 13:{t[r>>2]=62320;break}case 19:{t[r>>2]=62416;break}case 7:{t[r>>2]=62176;break}case 5:{t[r>>2]=62176;break}case 1:{t[r>>2]=62112;break}case 9:{t[r>>2]=62144;break}case 11:{t[r>>2]=62256;break}case 8:{t[r>>2]=62176;break}case 17:{t[r>>2]=62384;break}case 14:{t[r>>2]=62336;break}case 18:{t[r>>2]=62400;break}case-1:{t[r>>2]=0;break}case 16:{t[r>>2]=62368;break}case 22:{t[r>>2]=0;break}case 0:{t[r>>2]=0;break}case 2:{t[r>>2]=62128;break}default:t[r>>2]=0}while(0);s=i;return t[r>>2]|0}function H_(e,i,r){e=e|0;i=i|0;r=r|0;var f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0;f=s;s=s+544|0;u=f+28|0;a=f+24|0;o=f+20|0;c=f+16|0;l=f+12|0;b=f+8|0;k=f+32|0;h=f+4|0;w=f;t[a>>2]=e;t[o>>2]=i;t[c>>2]=r;t[w>>2]=0;t[b>>2]=C_(t[a>>2]|0)|0;if(t[b>>2]|0)t[a>>2]=t[b>>2];if(!(t[a>>2]|0)){K_(6e3,62480,0);t[u>>2]=0;d=t[u>>2]|0;s=f;return d|0}t[h>>2]=0;while(1){if((t[h>>2]|0)>=499)break;b=(Pq(n[(t[a>>2]|0)+(t[h>>2]|0)>>0]|0)|0)&255;n[k+(t[h>>2]|0)>>0]=b;if(!(n[k+(t[h>>2]|0)>>0]|0))break;t[h>>2]=(t[h>>2]|0)+1}n[k+(t[h>>2]|0)>>0]=0;t[w>>2]=gAi[t[135768>>2]&511](k)|0;if(!(t[w>>2]|0)){X_(62520);t[u>>2]=0;d=t[u>>2]|0;s=f;return d|0}t[l>>2]=gAi[t[135744>>2]&511](20)|0;if(!(t[l>>2]|0)){pAi[t[135736>>2]&511](t[w>>2]|0);X_(62520);t[u>>2]=0;d=t[u>>2]|0;s=f;return d|0}else{k=t[l>>2]|0;t[k+0>>2]=0;t[k+4>>2]=0;t[k+8>>2]=0;t[k+12>>2]=0;t[k+16>>2]=0;t[(t[l>>2]|0)+4>>2]=t[o>>2];t[(t[l>>2]|0)+8>>2]=t[c>>2];t[t[l>>2]>>2]=t[w>>2];t[(t[l>>2]|0)+12>>2]=0;t[(t[l>>2]|0)+16>>2]=0;x_(t[l>>2]|0);t[u>>2]=t[l>>2];d=t[u>>2]|0;s=f;return d|0}return 0}function x_(e){e=e|0;var i=0,r=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if(!(t[15642]|0))U_();if((t[r>>2]|0)==0|(t[15642]|0)==0){K_(6001,62768,0);s=i;return}if((t[15688]|0)>=50){K_(6002,62816,62888);s=i;return}else{e=t[r>>2]|0;r=t[15688]|0;t[15688]=r+1;t[(t[15642]|0)+(r<<2)>>2]=e;s=i;return}}function U_(){var e=0,i=0,r=0;e=s;s=s+16|0;i=e+4|0;r=e;f[i>>1]=4660;t[r>>2]=i;if(t[15642]|0){s=e;return}t[15642]=gAi[t[135744>>2]&511](200)|0;do if((u[t[r>>2]>>0]|0|0)!=18)if((u[t[r>>2]>>0]|0|0)==52){t[15644]=1;break}else{K_(1,62584,0);break}else t[15644]=0;while(0);if(!(t[15642]|0)){X_(62624);s=e;return}else{H_(62112,213,213)|0;t[15672]=H_(62672,214,215)|0;t[15678]=H_(62696,216,217)|0;H_(62128,214,218)|0;H_(62208,219,220)|0;H_(62720,221,222)|0;H_(62728,221,222)|0;H_(62744,0,223)|0;s=e;return}}function z_(){var e=0;e=s;D_();if(!(t[15642]|0)){s=e;return}while(1){if((t[15688]|0)<=0)break;t[15688]=(t[15688]|0)+-1;if(!(t[(t[15642]|0)+(t[15688]<<2)>>2]|0))continue;if(t[t[(t[15642]|0)+(t[15688]<<2)>>2]>>2]|0)pAi[t[135736>>2]&511](t[t[(t[15642]|0)+(t[15688]<<2)>>2]>>2]|0);pAi[t[135736>>2]&511](t[(t[15642]|0)+(t[15688]<<2)>>2]|0)}pAi[t[135736>>2]&511](t[15642]|0);t[15642]=0;t[15688]=0;t[15690]=0;s=e;return}function j_(e){e=e|0;var i=0,r=0,n=0,f=0,u=0;i=s;s=s+16|0;r=i+8|0;n=i+4|0;f=i;t[n>>2]=e;if(!(t[15642]|0))U_();e:do switch(t[n>>2]|0){case 6:{t[f>>2]=V_(62456)|0;if(t[f>>2]|0){t[r>>2]=t[f>>2];break e}t[f>>2]=V_(62912)|0;if(t[f>>2]|0){t[r>>2]=t[f>>2];break e}t[f>>2]=V_(62920)|0;if(t[f>>2]|0){t[r>>2]=t[f>>2];break e}t[f>>2]=V_(62936)|0;if(t[f>>2]|0)t[r>>2]=t[f>>2];else u=63;break}case 2:{t[r>>2]=t[15672];break}case 9:{t[f>>2]=V_(62144)|0;if(t[f>>2]|0){t[r>>2]=t[f>>2];break e}t[f>>2]=V_(62160)|0;if(t[f>>2]|0){t[r>>2]=t[f>>2];break e}t[f>>2]=V_(62168)|0;if(t[f>>2]|0)t[r>>2]=t[f>>2];else u=63;break}case 18:{t[f>>2]=V_(62400)|0;if(t[f>>2]|0)t[r>>2]=t[f>>2];else u=63;break}case 3:{t[r>>2]=t[15678];break}case 10:{t[f>>2]=V_(62208)|0;if(t[f>>2]|0)t[r>>2]=t[f>>2];else u=63;break}case-1:{t[r>>2]=0;break}case 12:{t[f>>2]=V_(62304)|0;if(t[f>>2]|0)t[r>>2]=t[f>>2];else u=63;break}case 5:{t[f>>2]=V_(62176)|0;if(t[f>>2]|0){t[r>>2]=t[f>>2];break e}t[f>>2]=V_(62192)|0;if(t[f>>2]|0){t[r>>2]=t[f>>2];break e}t[f>>2]=V_(62200)|0;if(t[f>>2]|0)t[r>>2]=t[f>>2];else u=63;break}case 14:{t[f>>2]=V_(62336)|0;if(t[f>>2]|0)t[r>>2]=t[f>>2];else u=63;break}case 19:{t[f>>2]=V_(62416)|0;if(t[f>>2]|0)t[r>>2]=t[f>>2];else u=63;break}case 20:{t[f>>2]=V_(62944)|0;if(t[f>>2]|0){t[r>>2]=t[f>>2];break e}t[f>>2]=V_(62432)|0;if(t[f>>2]|0){t[r>>2]=t[f>>2];break e}t[f>>2]=V_(62960)|0;if(t[f>>2]|0)t[r>>2]=t[f>>2];else u=63;break}case 11:{t[f>>2]=V_(62256)|0;if(t[f>>2]|0)t[r>>2]=t[f>>2];else u=63;break}case 0:{t[r>>2]=0;break}case 17:{t[f>>2]=V_(62384)|0;if(t[f>>2]|0)t[r>>2]=t[f>>2];else u=63;break}case 15:{t[f>>2]=V_(62352)|0;if(t[f>>2]|0)t[r>>2]=t[f>>2];else u=63;break}case 16:{t[f>>2]=V_(62368)|0;if(t[f>>2]|0)t[r>>2]=t[f>>2];else u=63;break}case 13:{t[f>>2]=V_(62320)|0;if(t[f>>2]|0)t[r>>2]=t[f>>2];else u=63;break}case 21:{t[f>>2]=V_(62448)|0;if(t[f>>2]|0)t[r>>2]=t[f>>2];else u=63;break}case 1:{t[r>>2]=0;break}case 4:{t[f>>2]=V_(62176)|0;if(t[f>>2]|0){t[r>>2]=t[f>>2];break e}t[f>>2]=V_(62192)|0;if(t[f>>2]|0){t[r>>2]=t[f>>2];break e}t[f>>2]=V_(62200)|0;if(t[f>>2]|0)t[r>>2]=t[f>>2];else u=63;break}default:u=63}while(0);if((u|0)==63)t[r>>2]=0;s=i;return t[r>>2]|0}function V_(e){e=e|0;var i=0,r=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0;i=s;s=s+144|0;r=i+36|0;f=i+32|0;u=i+28|0;a=i+24|0;o=i+20|0;c=i+16|0;l=i+12|0;b=i+8|0;k=i+40|0;h=i+4|0;w=i;t[f>>2]=e;if(!(t[15642]|0))U_();if(!(t[f>>2]|0)){t[r>>2]=t[15690];d=t[r>>2]|0;s=i;return d|0}if(!(n[t[f>>2]>>0]|0)){t[r>>2]=t[15690];d=t[r>>2]|0;s=i;return d|0}t[a>>2]=t[f>>2];t[u>>2]=C_(t[f>>2]|0)|0;if(t[u>>2]|0)t[f>>2]=t[u>>2];t[h>>2]=0;while(1){if((t[h>>2]|0)>=99)break;u=(Pq(n[(t[f>>2]|0)+(t[h>>2]|0)>>0]|0)|0)&255;n[k+(t[h>>2]|0)>>0]=u;if(!(n[k+(t[h>>2]|0)>>0]|0))break;t[h>>2]=(t[h>>2]|0)+1}n[k+(t[h>>2]|0)>>0]=0;e:do if(t[15642]|0){t[h>>2]=0;while(1){if((t[h>>2]|0)>=(t[15688]|0))break e;u=(MY(k,t[t[(t[15642]|0)+(t[h>>2]<<2)>>2]>>2]|0)|0)!=0;v=t[h>>2]|0;if(!u)break;t[h>>2]=v+1}t[r>>2]=t[(t[15642]|0)+(v<<2)>>2];d=t[r>>2]|0;s=i;return d|0}while(0);t[l>>2]=Bq(62112,t[f>>2]|0)|0;t[b>>2]=Bq(t[f>>2]|0,62112)|0;if((t[l>>2]|0)==(-1|0))t[l>>2]=Bq(62112,k)|0;if((t[b>>2]|0)==(-1|0))t[b>>2]=Bq(k,62112)|0;if((t[l>>2]|0)!=(-1|0)&(t[b>>2]|0)!=(-1|0)){t[c>>2]=gAi[t[135744>>2]&511](20)|0;if(!(t[c>>2]|0)){t[r>>2]=0;d=t[r>>2]|0;s=i;return d|0}else{k=t[c>>2]|0;t[k+0>>2]=0;t[k+4>>2]=0;t[k+8>>2]=0;t[k+12>>2]=0;t[k+16>>2]=0;k=gAi[t[135768>>2]&511](t[f>>2]|0)|0;t[t[c>>2]>>2]=k;t[(t[c>>2]|0)+4>>2]=0;t[(t[c>>2]|0)+8>>2]=0;t[(t[c>>2]|0)+12>>2]=t[l>>2];t[(t[c>>2]|0)+16>>2]=t[b>>2];t[r>>2]=t[c>>2];d=t[r>>2]|0;s=i;return d|0}}if((t[l>>2]|0)!=(-1|0)|(t[b>>2]|0)!=(-1|0))K_(1,62976,t[f>>2]|0);t[o>>2]=B_(t[a>>2]|0)|0;if(((t[o>>2]|0)!=-1?(t[w>>2]=I_(t[o>>2]|0)|0,(t[w>>2]|0)!=0):0)?(MY(t[f>>2]|0,t[w>>2]|0)|0)!=0:0){t[r>>2]=V_(t[w>>2]|0)|0;d=t[r>>2]|0;s=i;return d|0}t[r>>2]=0;d=t[r>>2]|0;s=i;return d|0}function q_(e,i){e=e|0;i=i|0;var r=0,f=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0;
	r=s;s=s+112|0;f=r;a=r+56|0;o=r+52|0;c=r+48|0;l=r+44|0;b=r+40|0;k=r+36|0;h=r+32|0;w=r+28|0;d=r+24|0;v=r+20|0;m=r+60|0;_=r+16|0;t[o>>2]=e;t[c>>2]=i;t[l>>2]=-2;if((((t[o>>2]|0)!=0?(t[(t[o>>2]|0)+12>>2]|0)!=0:0)?(t[(t[o>>2]|0)+16>>2]|0)!=0:0)?(t[(t[o>>2]|0)+20>>2]|0)!=0:0){t[v>>2]=t[(t[o>>2]|0)+16>>2];t[d>>2]=t[(t[o>>2]|0)+20>>2];t[k>>2]=Ts(t[d>>2]|0)|0;if(!(t[k>>2]|0)){t[a>>2]=0;p=t[a>>2]|0;s=r;return p|0}t[b>>2]=(Ls(t[v>>2]|0)|0)-1;i=t[k>>2]|0;if((t[c>>2]|0)>=0){if(i>>>0>(t[c>>2]|0)>>>0)t[k>>2]=t[c>>2]}else if(i>>>0>180)t[k>>2]=180;if(t[k>>2]<<1>>>0>=(t[b>>2]|0)>>>0){Fs(t[v>>2]|0,t[k>>2]<<1)|0;t[b>>2]=(Ls(t[v>>2]|0)|0)-1}if((t[b>>2]|0)>>>0>360)t[b>>2]=360;t[h>>2]=t[k>>2];t[w>>2]=t[b>>2];b=t[(t[o>>2]|0)+12>>2]|0;if(!(t[(t[(t[o>>2]|0)+12>>2]|0)+4>>2]|0)){if((t[b+12>>2]|0)!=0?(k=t[(t[(t[o>>2]|0)+12>>2]|0)+12>>2]|0,o=As(t[v>>2]|0)|0,t[l>>2]=fp(k,o,w,Os(t[d>>2]|0)|0,h)|0,ys(t[d>>2]|0,t[h>>2]|0)|0,Ms(t[v>>2]|0,t[w>>2]|0)|0,(t[l>>2]|0)==-1):0)t[l>>2]=-3}else{o=t[b+4>>2]|0;b=As(t[v>>2]|0)|0;k=Os(t[d>>2]|0)|0;t[l>>2]=OAi[o&511](b,w,k,h)|0;ys(t[d>>2]|0,t[h>>2]|0)|0;Ms(t[v>>2]|0,t[w>>2]|0)|0}if((t[l>>2]|0)==-2){t[_>>2]=Os(t[d>>2]|0)|0;d=u[(t[_>>2]|0)+1>>0]|0;w=u[(t[_>>2]|0)+2>>0]|0;v=u[(t[_>>2]|0)+3>>0]|0;t[f>>2]=u[t[_>>2]>>0];t[f+4>>2]=d;t[f+8>>2]=w;t[f+12>>2]=v;SY(m,49,63016,f)|0;n[m+49>>0]=0;K_(6003,63048,m)}if((t[l>>2]|0)==-3)t[l>>2]=0;if((t[l>>2]|0)==-1)t[l>>2]=0;t[a>>2]=t[l>>2];p=t[a>>2]|0;s=r;return p|0}t[a>>2]=-1;p=t[a>>2]|0;s=r;return p|0}function Y_(e,i){e=e|0;i=i|0;var r=0,f=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0;r=s;s=s+112|0;f=r;a=r+56|0;o=r+52|0;c=r+48|0;l=r+44|0;b=r+40|0;k=r+36|0;h=r+32|0;w=r+28|0;d=r+24|0;v=r+20|0;m=r+60|0;_=r+16|0;t[o>>2]=e;t[c>>2]=i;t[l>>2]=-2;if((((t[o>>2]|0)!=0?(t[(t[o>>2]|0)+12>>2]|0)!=0:0)?(t[(t[o>>2]|0)+16>>2]|0)!=0:0)?(t[(t[o>>2]|0)+20>>2]|0)!=0:0){t[v>>2]=t[(t[o>>2]|0)+16>>2];t[d>>2]=t[(t[o>>2]|0)+20>>2];t[k>>2]=Ts(t[d>>2]|0)|0;if(!(t[k>>2]|0)){t[a>>2]=0;p=t[a>>2]|0;s=r;return p|0}if((t[k>>2]|0)>>>0>65536&(t[c>>2]|0)==0)t[k>>2]=65536;t[b>>2]=Ls(t[v>>2]|0)|0;if((t[b>>2]|0)>>>0>0)t[b>>2]=(t[b>>2]|0)+-1;if(t[k>>2]<<1>>>0>=(t[b>>2]|0)>>>0?(Fs(t[v>>2]|0,t[k>>2]<<1)|0,t[b>>2]=Ls(t[v>>2]|0)|0,(t[b>>2]|0)>>>0>0):0)t[b>>2]=(t[b>>2]|0)+-1;if((t[b>>2]|0)>>>0>131072&(t[c>>2]|0)==0)t[b>>2]=131072;t[h>>2]=t[k>>2];t[w>>2]=t[b>>2];b=t[(t[o>>2]|0)+12>>2]|0;if(!(t[(t[(t[o>>2]|0)+12>>2]|0)+4>>2]|0)){if((t[b+12>>2]|0)!=0?(k=t[(t[(t[o>>2]|0)+12>>2]|0)+12>>2]|0,o=As(t[v>>2]|0)|0,t[l>>2]=fp(k,o,w,Os(t[d>>2]|0)|0,h)|0,ys(t[d>>2]|0,t[h>>2]|0)|0,Ms(t[v>>2]|0,t[w>>2]|0)|0,(t[l>>2]|0)==-1):0)t[l>>2]=-3}else{o=t[b+4>>2]|0;b=As(t[v>>2]|0)|0;k=Os(t[d>>2]|0)|0;t[l>>2]=OAi[o&511](b,w,k,h)|0;ys(t[d>>2]|0,t[h>>2]|0)|0;Ms(t[v>>2]|0,t[w>>2]|0)|0}if((t[l>>2]|0)==-2){t[_>>2]=Os(t[d>>2]|0)|0;d=u[(t[_>>2]|0)+1>>0]|0;v=u[(t[_>>2]|0)+2>>0]|0;h=u[(t[_>>2]|0)+3>>0]|0;t[f>>2]=u[t[_>>2]>>0];t[f+4>>2]=d;t[f+8>>2]=v;t[f+12>>2]=h;SY(m,49,63016,f)|0;n[m+49>>0]=0;K_(6003,63048,m)}if((t[l>>2]|0)==-3)t[l>>2]=0;t[a>>2]=(t[w>>2]|0)!=0?t[w>>2]|0:t[l>>2]|0;p=t[a>>2]|0;s=r;return p|0}t[a>>2]=-1;p=t[a>>2]|0;s=r;return p|0}function G_(e,i){e=e|0;i=i|0;var r=0,f=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0,S=0,g=0,y=0,F=0,O=0,A=0,M=0;r=s;s=s+160|0;f=r;a=r+72|0;o=r+68|0;c=r+64|0;l=r+60|0;b=r+56|0;k=r+52|0;h=r+48|0;w=r+44|0;d=r+40|0;v=r+36|0;m=r+32|0;_=r+28|0;p=r+24|0;E=r+20|0;S=r+16|0;g=r+128|0;y=r+76|0;t[o>>2]=e;t[c>>2]=i;t[l>>2]=-2;t[k>>2]=0;t[_>>2]=0;if((((t[o>>2]|0)!=0?(t[(t[o>>2]|0)+12>>2]|0)!=0:0)?(t[(t[o>>2]|0)+16>>2]|0)!=0:0)?(t[(t[o>>2]|0)+20>>2]|0)!=0:0){t[m>>2]=t[(t[o>>2]|0)+20>>2];t[v>>2]=t[(t[o>>2]|0)+16>>2];e:while(1){t[b>>2]=Ls(t[m>>2]|0)|0;if((t[b>>2]|0)>>>0>0)t[b>>2]=(t[b>>2]|0)+-1;if(t[c>>2]|0){F=10;break}t[h>>2]=Ts(t[v>>2]|0)|0;if(!(t[h>>2]|0)){F=17;break}if((t[h>>2]|0)>>>0>65536)t[h>>2]=65536;if(t[h>>2]<<2>>>0>=(t[b>>2]|0)>>>0){Fs(t[m>>2]|0,t[h>>2]<<2)|0;t[b>>2]=(Ls(t[m>>2]|0)|0)-1}if((t[b>>2]|0)>>>0>262144)t[b>>2]=262144;t[w>>2]=t[h>>2];t[d>>2]=t[b>>2];i=t[(t[o>>2]|0)+12>>2]|0;do if(t[(t[(t[o>>2]|0)+12>>2]|0)+8>>2]|0){e=t[i+8>>2]|0;O=As(t[m>>2]|0)|0;A=Os(t[v>>2]|0)|0;t[l>>2]=OAi[e&511](O,d,A,w)|0;if((t[d>>2]|0)>0){ys(t[v>>2]|0,t[w>>2]|0)|0;Ms(t[m>>2]|0,t[d>>2]|0)|0;t[k>>2]=(t[k>>2]|0)+(t[d>>2]|0)}}else{if(!(t[i+16>>2]|0)){F=32;break e}A=t[(t[(t[o>>2]|0)+12>>2]|0)+16>>2]|0;O=As(t[m>>2]|0)|0;t[l>>2]=fp(A,O,d,Os(t[v>>2]|0)|0,w)|0;ys(t[v>>2]|0,t[w>>2]|0)|0;Ms(t[m>>2]|0,t[d>>2]|0)|0;t[k>>2]=(t[k>>2]|0)+(t[d>>2]|0);if((t[l>>2]|0)==-1)if((t[d>>2]|0)>0){t[_>>2]=0;continue e}else{t[l>>2]=-3;break}}while(0);if((t[l>>2]|0)>=0)t[o>>2]=(t[o>>2]|0)+(t[l>>2]<<5);if((t[l>>2]|0)!=-2)break;t[p>>2]=Ts(t[v>>2]|0)|0;t[E>>2]=Os(t[v>>2]|0)|0;t[S>>2]=cs(t[E>>2]|0,p)|0;if((t[_>>2]|0)!=0?(t[d>>2]|0)<(t[_>>2]|0):0){F=38;break}if((t[S>>2]|0)<=0){F=41;break}t[f>>2]=t[S>>2];t[_>>2]=SY(g,20,63152,f)|0;ys(t[v>>2]|0,t[p>>2]|0)|0;Bs(t[v>>2]|0,g,-1)|0}if((F|0)==10){t[w>>2]=0;t[d>>2]=t[b>>2];b=t[(t[o>>2]|0)+12>>2]|0;if(t[(t[(t[o>>2]|0)+12>>2]|0)+8>>2]|0){g=t[b+8>>2]|0;p=As(t[m>>2]|0)|0;t[l>>2]=OAi[g&511](p,d,0,w)|0;if((t[l>>2]|0)>0)Ms(t[m>>2]|0,t[d>>2]|0)|0}else if(t[b+16>>2]|0){b=t[(t[(t[o>>2]|0)+12>>2]|0)+16>>2]|0;t[l>>2]=fp(b,As(t[m>>2]|0)|0,d,0,w)|0;Ms(t[m>>2]|0,t[d>>2]|0)|0}t[a>>2]=0;M=t[a>>2]|0;s=r;return M|0}else if((F|0)==17){t[a>>2]=0;M=t[a>>2]|0;s=r;return M|0}else if((F|0)==32){K_(6004,63104,0);t[a>>2]=-1;M=t[a>>2]|0;s=r;return M|0}else if((F|0)==38){Rs(t[m>>2]|0,t[d>>2]|0)|0;t[k>>2]=(t[k>>2]|0)-(t[d>>2]|0);ys(t[v>>2]|0,(t[_>>2]|0)-(t[d>>2]|0)|0)|0;t[_>>2]=0;t[l>>2]=-1}else if((F|0)==41?(F=u[(t[E>>2]|0)+1>>0]|0,_=u[(t[E>>2]|0)+2>>0]|0,d=u[(t[E>>2]|0)+3>>0]|0,t[f>>2]=u[t[E>>2]>>0],t[f+4>>2]=F,t[f+8>>2]=_,t[f+12>>2]=d,SY(y,49,63016,f)|0,n[y+49>>0]=0,K_(6003,63160,y),(ps(t[v>>2]|0)|0)!=2):0)n[t[E>>2]>>0]=32;t[a>>2]=t[l>>2];M=t[a>>2]|0;s=r;return M|0}t[a>>2]=-1;M=t[a>>2]|0;s=r;return M|0}function W_(e){e=e|0;var i=0,r=0,n=0,f=0,u=0,a=0,o=0,c=0;i=s;s=s+32|0;r=i+20|0;n=i+16|0;f=i+12|0;u=i+8|0;a=i+4|0;o=i;t[n>>2]=e;t[f>>2]=0;t[u>>2]=0;t[o>>2]=0;if(!(t[n>>2]|0)){t[r>>2]=-1;c=t[r>>2]|0;s=i;return c|0}if(!(t[t[n>>2]>>2]|0)){t[r>>2]=-1;c=t[r>>2]|0;s=i;return c|0}e:do if(t[15642]|0){t[a>>2]=0;while(1){if((t[a>>2]|0)>=(t[15688]|0))break e;if((t[n>>2]|0)==(t[(t[15642]|0)+(t[a>>2]<<2)>>2]|0))break;t[a>>2]=(t[a>>2]|0)+1}t[o>>2]=1}while(0);do if(!(t[o>>2]|0)){if((t[(t[n>>2]|0)+16>>2]|0)==0?(t[(t[n>>2]|0)+12>>2]|0)==0:0)break;t[u>>2]=1;if(t[(t[n>>2]|0)+16>>2]|0){if(Iq(t[(t[n>>2]|0)+16>>2]|0)|0)t[f>>2]=-1;t[(t[n>>2]|0)+16>>2]=0}if(t[(t[n>>2]|0)+12>>2]|0){if(Iq(t[(t[n>>2]|0)+12>>2]|0)|0)t[f>>2]=-1;t[(t[n>>2]|0)+12>>2]=0}}while(0);if(t[u>>2]|0){if(t[t[n>>2]>>2]|0)pAi[t[135736>>2]&511](t[t[n>>2]>>2]|0);t[t[n>>2]>>2]=0;pAi[t[135736>>2]&511](t[n>>2]|0)}t[r>>2]=t[f>>2];c=t[r>>2]|0;s=i;return c|0}function K_(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0;n=s;s=s+16|0;f=n;u=n+12|0;a=n+8|0;o=n+4|0;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;r=t[u>>2]|0;u=t[o>>2]|0;i=t[a>>2]|0;t[f>>2]=t[o>>2];cp(0,0,0,0,0,27,r,3,0,0,u,0,0,0,0,i,f);s=n;return}function X_(e){e=e|0;var i=0,r=0;i=s;s=s+16|0;r=i;t[r>>2]=e;dp(27,2,0,0,t[r>>2]|0);s=i;return}function Z_(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0;f=s;s=s+32|0;u=f+20|0;a=f+16|0;o=f+12|0;c=f+8|0;l=f+4|0;b=f;t[a>>2]=e;t[o>>2]=i;t[c>>2]=r;t[l>>2]=n;if((t[a>>2]|0)==0|(t[c>>2]|0)==0|(t[o>>2]|0)==0|(t[l>>2]|0)==0){t[u>>2]=-1;k=t[u>>2]|0;s=f;return k|0}if((t[t[o>>2]>>2]|0)>(t[t[l>>2]>>2]|0))t[b>>2]=t[t[l>>2]>>2];else t[b>>2]=t[t[o>>2]>>2];if((t[b>>2]|0)<0){t[u>>2]=-1;k=t[u>>2]|0;s=f;return k|0}else{YY(t[a>>2]|0,t[c>>2]|0,t[b>>2]|0)|0;t[t[o>>2]>>2]=t[b>>2];t[t[l>>2]>>2]=t[b>>2];t[u>>2]=t[t[o>>2]>>2];k=t[u>>2]|0;s=f;return k|0}return 0}function J_(e,i,r,f){e=e|0;i=i|0;r=r|0;f=f|0;var o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0,S=0,g=0,y=0,F=0,O=0;o=s;s=s+64|0;c=o+56|0;l=o+52|0;b=o+48|0;k=o+44|0;h=o+40|0;w=o+36|0;d=o+32|0;v=o+28|0;m=o+24|0;_=o+20|0;p=o+16|0;E=o+12|0;S=o+8|0;g=o+4|0;y=o;t[l>>2]=e;t[b>>2]=i;t[k>>2]=r;t[h>>2]=f;t[w>>2]=t[l>>2];t[d>>2]=t[k>>2];t[v>>2]=(t[l>>2]|0)+(t[t[b>>2]>>2]|0);t[m>>2]=t[k>>2];if(((t[t[h>>2]>>2]|0)%2|0|0)==1){f=t[h>>2]|0;t[f>>2]=(t[f>>2]|0)+-1}t[S>>2]=(t[t[h>>2]>>2]|0)/2|0;t[_>>2]=(t[m>>2]|0)+(t[S>>2]<<1);while(1){if((t[m>>2]|0)>>>0>=(t[_>>2]|0)>>>0){F=29;break}if(((t[l>>2]|0)-(t[w>>2]|0)+5|0)>=(t[t[b>>2]>>2]|0)){F=29;break}S=t[m>>2]|0;if(t[15644]|0){t[m>>2]=S+2;t[p>>2]=a[S>>1]}else{t[g>>2]=S;S=t[g>>2]|0;t[g>>2]=S+1;t[p>>2]=u[S>>0];t[p>>2]=t[p>>2]|(u[t[g>>2]>>0]|0)<<8;t[m>>2]=(t[m>>2]|0)+2}if((t[p>>2]&64512|0)==55296){if((t[m>>2]|0)>>>0>=(t[_>>2]|0)>>>0){F=29;break}S=t[m>>2]|0;if(t[15644]|0){t[m>>2]=S+2;t[E>>2]=a[S>>1]}else{t[g>>2]=S;S=t[g>>2]|0;t[g>>2]=S+1;t[E>>2]=u[S>>0];t[E>>2]=t[E>>2]|(u[t[g>>2]>>0]|0)<<8;t[m>>2]=(t[m>>2]|0)+2}if((t[E>>2]&64512|0)!=56320){F=16;break}t[p>>2]=t[p>>2]&1023;t[p>>2]=t[p>>2]<<10;t[p>>2]=t[p>>2]|t[E>>2]&1023;t[p>>2]=(t[p>>2]|0)+65536}if((t[l>>2]|0)>>>0>=(t[v>>2]|0)>>>0){F=29;break}S=t[p>>2]|0;do if((t[p>>2]|0)>>>0>=128){f=t[p>>2]|0;if(S>>>0<2048){r=t[l>>2]|0;t[l>>2]=r+1;n[r>>0]=f>>>6&31|192;t[y>>2]=0;break}r=t[p>>2]|0;if(f>>>0<65536){f=t[l>>2]|0;t[l>>2]=f+1;n[f>>0]=r>>>12&15|224;t[y>>2]=6;break}else{f=t[l>>2]|0;t[l>>2]=f+1;n[f>>0]=r>>>18&7|240;t[y>>2]=12;break}}else{r=t[l>>2]|0;t[l>>2]=r+1;n[r>>0]=S;t[y>>2]=-6}while(0);while(1){if((t[y>>2]|0)<0)break;if((t[l>>2]|0)>>>0>=(t[v>>2]|0)>>>0)break;S=((t[p>>2]|0)>>>(t[y>>2]|0)&63|128)&255;r=t[l>>2]|0;t[l>>2]=r+1;n[r>>0]=S;t[y>>2]=(t[y>>2]|0)-6}t[d>>2]=t[m>>2]}if((F|0)==16){t[t[b>>2]>>2]=(t[l>>2]|0)-(t[w>>2]|0);t[t[h>>2]>>2]=(t[d>>2]|0)-(t[k>>2]|0);t[c>>2]=-2;O=t[c>>2]|0;s=o;return O|0}else if((F|0)==29){t[t[b>>2]>>2]=(t[l>>2]|0)-(t[w>>2]|0);t[t[h>>2]>>2]=(t[d>>2]|0)-(t[k>>2]|0);t[c>>2]=t[t[b>>2]>>2];O=t[c>>2]|0;s=o;return O|0}return 0}function Q_(e,i,r,o){e=e|0;i=i|0;r=r|0;o=o|0;var c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0,S=0,g=0,y=0,F=0,O=0,A=0,M=0,R=0;c=s;s=s+64|0;l=c+56|0;b=c+52|0;k=c+48|0;h=c+44|0;w=c+40|0;d=c+36|0;v=c+32|0;m=c+28|0;_=c+24|0;p=c+20|0;E=c+16|0;S=c+12|0;g=c+8|0;y=c+4|0;F=c;O=c+62|0;A=c+60|0;t[b>>2]=e;t[k>>2]=i;t[h>>2]=r;t[w>>2]=o;t[d>>2]=t[b>>2];t[v>>2]=t[h>>2];t[m>>2]=t[h>>2];t[_>>2]=t[d>>2];if((t[d>>2]|0)==0|(t[k>>2]|0)==0|(t[w>>2]|0)==0){t[l>>2]=-1;M=t[l>>2]|0;s=c;return M|0}if(!(t[h>>2]|0)){t[t[k>>2]>>2]=0;t[t[w>>2]>>2]=0;t[l>>2]=0;M=t[l>>2]|0;s=c;return M|0}t[E>>2]=(t[h>>2]|0)+(t[t[w>>2]>>2]|0);t[p>>2]=(t[d>>2]|0)+(((t[t[k>>2]>>2]|0)/2|0)<<1);e:while(1){if((t[h>>2]|0)>>>0>=(t[E>>2]|0)>>>0){R=34;break}b=t[h>>2]|0;t[h>>2]=b+1;t[g>>2]=u[b>>0];b=t[g>>2]|0;do if((t[g>>2]|0)>>>0<128){t[S>>2]=b;t[y>>2]=0}else{if(b>>>0<192){R=10;break e}o=t[g>>2]|0;if((t[g>>2]|0)>>>0<224){t[S>>2]=o&31;t[y>>2]=1;break}r=t[g>>2]|0;if(o>>>0<240){t[S>>2]=r&15;t[y>>2]=2;break}if(r>>>0>=248){R=17;break e}t[S>>2]=t[g>>2]&7;t[y>>2]=3}while(0);if(((t[E>>2]|0)-(t[h>>2]|0)|0)<(t[y>>2]|0)){R=34;break}while(1){if(!(t[y>>2]|0))break;if((t[h>>2]|0)>>>0>=(t[E>>2]|0)>>>0)break;b=t[h>>2]|0;t[h>>2]=b+1;r=u[b>>0]|0;t[g>>2]=r;if((r&192|0)!=128)break;t[S>>2]=t[S>>2]<<6;t[S>>2]=t[S>>2]|t[g>>2]&63;t[y>>2]=(t[y>>2]|0)+-1}do if((t[S>>2]|0)>>>0<65536){if((t[d>>2]|0)>>>0>=(t[p>>2]|0)>>>0){R=34;break e}if(t[15644]|0){r=t[S>>2]&65535;b=t[d>>2]|0;t[d>>2]=b+2;f[b>>1]=r;break}else{t[F>>2]=t[d>>2];n[t[F>>2]>>0]=t[S>>2];n[(t[F>>2]|0)+1>>0]=(t[S>>2]|0)>>>8;t[d>>2]=(t[d>>2]|0)+2;break}}else{if((t[S>>2]|0)>>>0>=1114112){R=34;break e}if(((t[d>>2]|0)+2|0)>>>0>=(t[p>>2]|0)>>>0){R=34;break e}t[S>>2]=(t[S>>2]|0)-65536;r=(55296|(t[S>>2]|0)>>>10)&65535;if(t[15644]|0){b=t[d>>2]|0;t[d>>2]=b+2;f[b>>1]=r;b=(56320|t[S>>2]&1023)&65535;o=t[d>>2]|0;t[d>>2]=o+2;f[o>>1]=b;break}else{f[O>>1]=r;t[F>>2]=t[d>>2];n[t[F>>2]>>0]=f[O>>1];n[(t[F>>2]|0)+1>>0]=(a[O>>1]|0)>>8;t[d>>2]=(t[d>>2]|0)+2;f[A>>1]=56320|t[S>>2]&1023;t[F>>2]=t[d>>2];n[t[F>>2]>>0]=f[A>>1];n[(t[F>>2]|0)+1>>0]=(a[A>>1]|0)>>8;t[d>>2]=(t[d>>2]|0)+2;break}}while(0);t[v>>2]=t[h>>2]}if((R|0)==10){t[t[k>>2]>>2]=(((t[d>>2]|0)-(t[_>>2]|0)|0)/2|0)<<1;t[t[w>>2]>>2]=(t[v>>2]|0)-(t[m>>2]|0);t[l>>2]=-2;M=t[l>>2]|0;s=c;return M|0}else if((R|0)==17){t[t[k>>2]>>2]=(((t[d>>2]|0)-(t[_>>2]|0)|0)/2|0)<<1;t[t[w>>2]>>2]=(t[v>>2]|0)-(t[m>>2]|0);t[l>>2]=-2;M=t[l>>2]|0;s=c;return M|0}else if((R|0)==34){t[t[k>>2]>>2]=(((t[d>>2]|0)-(t[_>>2]|0)|0)/2|0)<<1;t[t[w>>2]>>2]=(t[v>>2]|0)-(t[m>>2]|0);t[l>>2]=t[t[k>>2]>>2];M=t[l>>2]|0;s=c;return M|0}return 0}function $_(e,i,r,f){e=e|0;i=i|0;r=r|0;f=f|0;var o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0,S=0,g=0,y=0,F=0,O=0;o=s;s=s+64|0;c=o+56|0;l=o+52|0;b=o+48|0;k=o+44|0;h=o+40|0;w=o+36|0;d=o+32|0;v=o+28|0;m=o+24|0;_=o+20|0;p=o+16|0;E=o+12|0;S=o+8|0;g=o+4|0;y=o;t[l>>2]=e;t[b>>2]=i;t[k>>2]=r;t[h>>2]=f;t[w>>2]=t[l>>2];t[d>>2]=t[k>>2];t[v>>2]=(t[l>>2]|0)+(t[t[b>>2]>>2]|0);t[m>>2]=t[k>>2];if(((t[t[h>>2]>>2]|0)%2|0|0)==1){f=t[h>>2]|0;t[f>>2]=(t[f>>2]|0)+-1}t[S>>2]=(t[t[h>>2]>>2]|0)/2|0;t[_>>2]=(t[m>>2]|0)+(t[S>>2]<<1);while(1){if((t[m>>2]|0)>>>0>=(t[_>>2]|0)>>>0){F=29;break}S=t[m>>2]|0;if(t[15644]|0){t[g>>2]=S;f=t[g>>2]|0;t[g>>2]=f+1;t[p>>2]=u[f>>0];t[p>>2]=t[p>>2]<<8;t[p>>2]=t[p>>2]|(u[t[g>>2]>>0]|0);t[m>>2]=(t[m>>2]|0)+2}else{t[m>>2]=S+2;t[p>>2]=a[S>>1]}if((t[p>>2]&64512|0)==55296){if((t[m>>2]|0)>>>0>=(t[_>>2]|0)>>>0){F=10;break}S=t[m>>2]|0;if(t[15644]|0){t[g>>2]=S;f=t[g>>2]|0;t[g>>2]=f+1;t[E>>2]=u[f>>0];t[E>>2]=t[E>>2]<<8;t[E>>2]=t[E>>2]|(u[t[g>>2]>>0]|0);t[m>>2]=(t[m>>2]|0)+2}else{t[m>>2]=S+2;t[E>>2]=a[S>>1]}if((t[E>>2]&64512|0)!=56320){F=16;break}t[p>>2]=t[p>>2]&1023;t[p>>2]=t[p>>2]<<10;t[p>>2]=t[p>>2]|t[E>>2]&1023;t[p>>2]=(t[p>>2]|0)+65536}if((t[l>>2]|0)>>>0>=(t[v>>2]|0)>>>0){F=29;break}S=t[p>>2]|0;do if((t[p>>2]|0)>>>0>=128){f=t[p>>2]|0;if(S>>>0<2048){r=t[l>>2]|0;t[l>>2]=r+1;n[r>>0]=f>>>6&31|192;t[y>>2]=0;break}r=t[p>>2]|0;if(f>>>0<65536){f=t[l>>2]|0;t[l>>2]=f+1;n[f>>0]=r>>>12&15|224;t[y>>2]=6;break}else{f=t[l>>2]|0;t[l>>2]=f+1;n[f>>0]=r>>>18&7|240;t[y>>2]=12;break}}else{r=t[l>>2]|0;t[l>>2]=r+1;n[r>>0]=S;t[y>>2]=-6}while(0);while(1){if((t[y>>2]|0)<0)break;if((t[l>>2]|0)>>>0>=(t[v>>2]|0)>>>0)break;S=((t[p>>2]|0)>>>(t[y>>2]|0)&63|128)&255;r=t[l>>2]|0;t[l>>2]=r+1;n[r>>0]=S;t[y>>2]=(t[y>>2]|0)-6}t[d>>2]=t[m>>2]}if((F|0)==10){t[t[b>>2]>>2]=(t[l>>2]|0)-(t[w>>2]|0);t[t[h>>2]>>2]=(t[d>>2]|0)-(t[k>>2]|0);t[c>>2]=-2;O=t[c>>2]|0;s=o;return O|0}else if((F|0)==16){t[t[b>>2]>>2]=(t[l>>2]|0)-(t[w>>2]|0);t[t[h>>2]>>2]=(t[d>>2]|0)-(t[k>>2]|0);t[c>>2]=-2;O=t[c>>2]|0;s=o;return O|0}else if((F|0)==29){t[t[b>>2]>>2]=(t[l>>2]|0)-(t[w>>2]|0);t[t[h>>2]>>2]=(t[d>>2]|0)-(t[k>>2]|0);t[c>>2]=t[t[b>>2]>>2];O=t[c>>2]|0;s=o;return O|0}return 0}function ep(e,i,r,o){e=e|0;i=i|0;r=r|0;o=o|0;var c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0,S=0,g=0,y=0,F=0,O=0,A=0,M=0,R=0;c=s;s=s+64|0;l=c+56|0;b=c+52|0;k=c+48|0;h=c+44|0;w=c+40|0;d=c+36|0;v=c+32|0;m=c+28|0;_=c+24|0;p=c+20|0;E=c+16|0;S=c+12|0;g=c+8|0;y=c+4|0;F=c;O=c+62|0;A=c+60|0;t[b>>2]=e;t[k>>2]=i;t[h>>2]=r;t[w>>2]=o;t[d>>2]=t[b>>2];t[v>>2]=t[h>>2];t[m>>2]=t[h>>2];t[_>>2]=t[d>>2];if((t[b>>2]|0)==0|(t[k>>2]|0)==0|(t[w>>2]|0)==0){t[l>>2]=-1;M=t[l>>2]|0;s=c;return M|0}if(!(t[h>>2]|0)){t[t[k>>2]>>2]=0;t[t[w>>2]>>2]=0;t[l>>2]=0;M=t[l>>2]|0;s=c;return M|0}t[E>>2]=(t[h>>2]|0)+(t[t[w>>2]>>2]|0);t[p>>2]=(t[d>>2]|0)+(((t[t[k>>2]>>2]|0)/2|0)<<1);e:while(1){if((t[h>>2]|0)>>>0>=(t[E>>2]|0)>>>0){R=34;break}b=t[h>>2]|0;t[h>>2]=b+1;t[g>>2]=u[b>>0];b=t[g>>2]|0;do if((t[g>>2]|0)>>>0<128){t[S>>2]=b;t[y>>2]=0}else{if(b>>>0<192){R=10;break e}o=t[g>>2]|0;if((t[g>>2]|0)>>>0<224){t[S>>2]=o&31;t[y>>2]=1;break}r=t[g>>2]|0;if(o>>>0<240){t[S>>2]=r&15;t[y>>2]=2;break}if(r>>>0>=248){R=17;break e}t[S>>2]=t[g>>2]&7;t[y>>2]=3}while(0);if(((t[E>>2]|0)-(t[h>>2]|0)|0)<(t[y>>2]|0)){R=34;break}while(1){if(!(t[y>>2]|0))break;if((t[h>>2]|0)>>>0>=(t[E>>2]|0)>>>0)break;b=t[h>>2]|0;t[h>>2]=b+1;r=u[b>>0]|0;t[g>>2]=r;if((r&192|0)!=128)break;t[S>>2]=t[S>>2]<<6;t[S>>2]=t[S>>2]|t[g>>2]&63;t[y>>2]=(t[y>>2]|0)+-1}do if((t[S>>2]|0)>>>0<65536){if((t[d>>2]|0)>>>0>=(t[p>>2]|0)>>>0){R=34;break e}if(t[15644]|0){t[F>>2]=t[d>>2];n[t[F>>2]>>0]=(t[S>>2]|0)>>>8;n[(t[F>>2]|0)+1>>0]=t[S>>2];t[d>>2]=(t[d>>2]|0)+2;break}else{r=t[S>>2]&65535;b=t[d>>2]|0;t[d>>2]=b+2;f[b>>1]=r;break}}else{if((t[S>>2]|0)>>>0>=1114112){R=34;break e}if(((t[d>>2]|0)+2|0)>>>0>=(t[p>>2]|0)>>>0){R=34;break e}t[S>>2]=(t[S>>2]|0)-65536;r=(55296|(t[S>>2]|0)>>>10)&65535;if(t[15644]|0){f[O>>1]=r;t[F>>2]=t[d>>2];n[t[F>>2]>>0]=(a[O>>1]|0)>>8;n[(t[F>>2]|0)+1>>0]=f[O>>1];t[d>>2]=(t[d>>2]|0)+2;f[A>>1]=56320|t[S>>2]&1023;t[F>>2]=t[d>>2];n[t[F>>2]>>0]=(a[A>>1]|0)>>8;n[(t[F>>2]|0)+1>>0]=f[A>>1];t[d>>2]=(t[d>>2]|0)+2;break}else{b=t[d>>2]|0;t[d>>2]=b+2;f[b>>1]=r;r=(56320|t[S>>2]&1023)&65535;b=t[d>>2]|0;t[d>>2]=b+2;f[b>>1]=r;break}}while(0);t[v>>2]=t[h>>2]}if((R|0)==10){t[t[k>>2]>>2]=((t[d>>2]|0)-(t[_>>2]|0)|0)/2|0;t[t[w>>2]>>2]=(t[v>>2]|0)-(t[m>>2]|0);t[l>>2]=-2;M=t[l>>2]|0;s=c;return M|0}else if((R|0)==17){t[t[k>>2]>>2]=((t[d>>2]|0)-(t[_>>2]|0)|0)/2|0;t[t[w>>2]>>2]=(t[v>>2]|0)-(t[m>>2]|0);t[l>>2]=-2;M=t[l>>2]|0;s=c;return M|0}else if((R|0)==34){t[t[k>>2]>>2]=(((t[d>>2]|0)-(t[_>>2]|0)|0)/2|0)<<1;t[t[w>>2]>>2]=(t[v>>2]|0)-(t[m>>2]|0);t[l>>2]=t[t[k>>2]>>2];M=t[l>>2]|0;s=c;return M|0}return 0}function ip(e,i,r,f){e=e|0;i=i|0;r=r|0;f=f|0;var u=0,a=0,o=0,c=0,l=0,b=0,k=0;u=s;s=s+32|0;a=u+16|0;o=u+12|0;c=u+8|0;l=u+4|0;b=u;t[o>>2]=e;t[c>>2]=i;t[l>>2]=r;t[b>>2]=f;if(t[l>>2]|0){t[a>>2]=Q_(t[o>>2]|0,t[c>>2]|0,t[l>>2]|0,t[b>>2]|0)|0;k=t[a>>2]|0;s=u;return k|0}if((t[t[c>>2]>>2]|0)>=2){n[t[o>>2]>>0]=-1;n[(t[o>>2]|0)+1>>0]=-2;t[t[c>>2]>>2]=2;t[t[b>>2]>>2]=0;t[a>>2]=2;k=t[a>>2]|0;s=u;return k|0}else{t[t[c>>2]>>2]=0;t[t[b>>2]>>2]=0;t[a>>2]=0;k=t[a>>2]|0;s=u;return k|0}return 0}function rp(e,i,r,f){e=e|0;i=i|0;r=r|0;f=f|0;var a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0;a=s;s=s+48|0;o=a+40|0;c=a+36|0;l=a+32|0;b=a+28|0;k=a+24|0;h=a+20|0;w=a+16|0;d=a+12|0;v=a+8|0;m=a+4|0;_=a;t[c>>2]=e;t[l>>2]=i;t[b>>2]=r;t[k>>2]=f;t[h>>2]=t[c>>2];t[w>>2]=t[b>>2];t[d>>2]=t[b>>2];t[v>>2]=(t[c>>2]|0)+(t[t[l>>2]>>2]|0);t[m>>2]=(t[b>>2]|0)+(t[t[k>>2]>>2]|0);while(1){if((t[b>>2]|0)>>>0>=(t[m>>2]|0)>>>0){p=8;break}if(((t[c>>2]|0)-(t[h>>2]|0)+5|0)>=(t[t[l>>2]>>2]|0)){p=8;break}f=t[b>>2]|0;t[b>>2]=f+1;t[_>>2]=u[f>>0];if((t[c>>2]|0)>>>0>=(t[v>>2]|0)>>>0){p=8;break}if((t[_>>2]|0)>>>0>=128){p=7;break}f=t[_>>2]&255;r=t[c>>2]|0;t[c>>2]=r+1;n[r>>0]=f;t[d>>2]=t[b>>2]}if((p|0)==7){t[t[l>>2]>>2]=(t[c>>2]|0)-(t[h>>2]|0);t[t[k>>2]>>2]=(t[d>>2]|0)-(t[w>>2]|0);t[o>>2]=-1;E=t[o>>2]|0;s=a;return E|0}else if((p|0)==8){t[t[l>>2]>>2]=(t[c>>2]|0)-(t[h>>2]|0);t[t[k>>2]>>2]=(t[d>>2]|0)-(t[w>>2]|0);t[o>>2]=t[t[l>>2]>>2];E=t[o>>2]|0;s=a;return E|0}return 0}function np(e,i,r,f){e=e|0;i=i|0;r=r|0;f=f|0;var a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0,S=0,g=0,y=0;a=s;s=s+64|0;o=a+48|0;c=a+44|0;l=a+40|0;b=a+36|0;k=a+32|0;h=a+28|0;w=a+24|0;d=a+20|0;v=a+16|0;m=a+12|0;_=a+8|0;p=a+4|0;E=a;t[c>>2]=e;t[l>>2]=i;t[b>>2]=r;t[k>>2]=f;t[h>>2]=t[b>>2];t[d>>2]=t[c>>2];t[v>>2]=t[b>>2];if((t[c>>2]|0)==0|(t[l>>2]|0)==0|(t[k>>2]|0)==0){t[o>>2]=-1;S=t[o>>2]|0;s=a;return S|0}if(!(t[b>>2]|0)){t[t[l>>2]>>2]=0;t[t[k>>2]>>2]=0;t[o>>2]=0;S=t[o>>2]|0;s=a;return S|0}t[m>>2]=(t[b>>2]|0)+(t[t[k>>2]>>2]|0);t[w>>2]=(t[c>>2]|0)+(t[t[l>>2]>>2]|0);e:while(1){if((t[b>>2]|0)>>>0>=(t[m>>2]|0)>>>0){g=27;break}f=t[b>>2]|0;t[b>>2]=f+1;t[p>>2]=u[f>>0];f=t[p>>2]|0;do if((t[p>>2]|0)>>>0<128){t[_>>2]=f;t[E>>2]=0}else{if(f>>>0<192){g=10;break e}r=t[p>>2]|0;if((t[p>>2]|0)>>>0<224){t[_>>2]=r&31;t[E>>2]=1;break}i=t[p>>2]|0;if(r>>>0<240){t[_>>2]=i&15;t[E>>2]=2;break}if(i>>>0>=248){g=17;break e}t[_>>2]=t[p>>2]&7;t[E>>2]=3}while(0);if(((t[m>>2]|0)-(t[b>>2]|0)|0)<(t[E>>2]|0)){g=27;break}while(1){if(!(t[E>>2]|0))break;if((t[b>>2]|0)>>>0>=(t[m>>2]|0)>>>0)break;f=t[b>>2]|0;t[b>>2]=f+1;i=u[f>>0]|0;t[p>>2]=i;if((i&192|0)!=128)break;t[_>>2]=t[_>>2]<<6;t[_>>2]=t[_>>2]|t[p>>2]&63;t[E>>2]=(t[E>>2]|0)+-1}y=t[c>>2]|0;if((t[_>>2]|0)>>>0>=128){g=26;break}if(y>>>0>=(t[w>>2]|0)>>>0){g=27;break}i=t[_>>2]&255;f=t[c>>2]|0;t[c>>2]=f+1;n[f>>0]=i;t[h>>2]=t[b>>2]}if((g|0)==10){t[t[l>>2]>>2]=(t[c>>2]|0)-(t[d>>2]|0);t[t[k>>2]>>2]=(t[h>>2]|0)-(t[v>>2]|0);t[o>>2]=-2;S=t[o>>2]|0;s=a;return S|0}else if((g|0)==17){t[t[l>>2]>>2]=(t[c>>2]|0)-(t[d>>2]|0);t[t[k>>2]>>2]=(t[h>>2]|0)-(t[v>>2]|0);t[o>>2]=-2;S=t[o>>2]|0;s=a;return S|0}else if((g|0)==26){t[t[l>>2]>>2]=y-(t[d>>2]|0);t[t[k>>2]>>2]=(t[h>>2]|0)-(t[v>>2]|0);t[o>>2]=-2;S=t[o>>2]|0;s=a;return S|0}else if((g|0)==27){t[t[l>>2]>>2]=(t[c>>2]|0)-(t[d>>2]|0);t[t[k>>2]>>2]=(t[h>>2]|0)-(t[v>>2]|0);t[o>>2]=t[t[l>>2]>>2];S=t[o>>2]|0;s=a;return S|0}return 0}function fp(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;var u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0;u=s;s=s+48|0;a=u+40|0;o=u+36|0;c=u+32|0;l=u+28|0;b=u+24|0;k=u+20|0;h=u+16|0;w=u+12|0;d=u+8|0;v=u+4|0;m=u;t[o>>2]=e;t[c>>2]=i;t[l>>2]=r;t[b>>2]=n;t[k>>2]=f;t[d>>2]=t[b>>2];t[v>>2]=t[c>>2];if((t[c>>2]|0)==0|(t[l>>2]|0)==0|(t[k>>2]|0)==0|(t[b>>2]|0)==0){if(t[l>>2]|0)t[t[l>>2]>>2]=0;t[a>>2]=-1;_=t[a>>2]|0;s=u;return _|0}t[h>>2]=t[t[k>>2]>>2];t[w>>2]=t[t[l>>2]>>2];t[m>>2]=Hq(t[o>>2]|0,d,h,v,w)|0;v=t[k>>2]|0;t[v>>2]=(t[v>>2]|0)-(t[h>>2]|0);v=t[l>>2]|0;t[v>>2]=(t[v>>2]|0)-(t[w>>2]|0);if(!((t[h>>2]|0)!=0|(t[m>>2]|0)==-1)){t[a>>2]=0;_=t[a>>2]|0;s=u;return _|0}if((t[(ii()|0)>>2]|0)==84){t[a>>2]=-2;_=t[a>>2]|0;s=u;return _|0}if((t[(ii()|0)>>2]|0)==7){t[a>>2]=-1;_=t[a>>2]|0;s=u;return _|0}else{t[a>>2]=-3;_=t[a>>2]|0;s=u;return _|0}return 0}function tp(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0;n=s;s=s+32|0;f=n+16|0;u=n;t[n+20>>2]=e;t[f>>2]=i;if(!(t[33980]|0))t[33980]=t[v>>2];t[u>>2]=r;Te(t[33980]|0,t[f>>2]|0,u|0)|0;s=n;return}function up(e){e=e|0;var i=0,r=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if(!(t[r>>2]|0)){t[33976]=35;s=i;return}else{t[33976]=t[t[r>>2]>>2];s=i;return}}function ap(e){e=e|0;var i=0,r=0,n=0,f=0,u=0,a=0;i=s;s=s+16|0;r=i;n=i+8|0;t[n>>2]=e;if(!(t[n>>2]|0)){s=i;return}e=t[33976]|0;f=t[33980]|0;u=t[n>>2]|0;if(t[(t[n>>2]|0)+4>>2]|0){a=t[(t[n>>2]|0)+28>>2]|0;t[r>>2]=t[u+4>>2];t[r+4>>2]=a;yAi[e&511](f,63216,r);s=i;return}else{t[r>>2]=t[u+28>>2];yAi[e&511](f,63224,r);s=i;return}}function op(e){e=e|0;var i=0,r=0;i=s;s=s+16|0;r=i;t[r>>2]=e;_p(t[r>>2]|0,t[33976]|0,t[33980]|0);s=i;return}function cp(e,i,r,n,f,u,o,c,l,b,k,h,w,d,v,m,_){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;u=u|0;o=o|0;c=c|0;l=l|0;b=b|0;k=k|0;h=h|0;w=w|0;d=d|0;v=v|0;m=m|0;_=_|0;var p=0,E=0,S=0,g=0,y=0,F=0,O=0,A=0,M=0,R=0,N=0,T=0,L=0,D=0,C=0,P=0,B=0,I=0,H=0,x=0,U=0,z=0,j=0,V=0,q=0,Y=0,G=0,W=0,K=0,X=0,Z=0,J=0,Q=0,$=0;p=s;s=s+144|0;E=p;S=p+132|0;g=p+128|0;y=p+124|0;F=p+120|0;O=p+116|0;A=p+112|0;M=p+108|0;R=p+104|0;N=p+100|0;T=p+96|0;L=p+92|0;D=p+88|0;C=p+84|0;P=p+80|0;B=p+76|0;I=p+72|0;H=p+68|0;x=p+64|0;U=p+60|0;z=p+56|0;j=p+52|0;V=p+48|0;q=p+44|0;Y=p+40|0;G=p+36|0;W=p+32|0;K=p+16|0;X=p+12|0;Z=p+8|0;J=p+4|0;t[S>>2]=e;t[g>>2]=i;t[y>>2]=r;t[F>>2]=n;t[O>>2]=f;t[A>>2]=u;t[M>>2]=o;t[R>>2]=c;t[N>>2]=l;t[T>>2]=b;t[L>>2]=k;t[D>>2]=h;t[C>>2]=w;t[P>>2]=d;t[B>>2]=v;t[I>>2]=m;t[H>>2]=0;t[x>>2]=t[O>>2];t[U>>2]=0;t[z>>2]=0;t[j>>2]=136208;t[V>>2]=0;if(!(t[M>>2]|0)){s=p;return}if((t[33956]|0)==0&(t[R>>2]|0)==1){s=p;return}if(((((t[A>>2]|0)==1|(t[A>>2]|0)==5|(t[A>>2]|0)==4|(t[A>>2]|0)==3|(t[A>>2]|0)==8|(t[A>>2]|0)==23?(t[H>>2]=t[F>>2],(t[S>>2]|0)==0&(t[H>>2]|0)!=0):0)?(t[t[H>>2]>>2]|0)!=0:0)?(t[(t[t[H>>2]>>2]|0)+108>>2]|0)==-554844497:0)?(t[(t[t[H>>2]>>2]|0)+124>>2]|0)!=0:0){t[S>>2]=t[(t[t[H>>2]>>2]|0)+124>>2];t[y>>2]=t[(t[H>>2]|0)+4>>2]}if((t[S>>2]|0)==0?(t[S>>2]=t[33978],(t[S>>2]|0)!=0):0)t[y>>2]=t[33982];e:do if(t[I>>2]|0){t[Y>>2]=-1;t[U>>2]=gAi[t[135744>>2]&511](150)|0;if(t[U>>2]|0){t[q>>2]=150;while(1){if((t[q>>2]|0)>=64e3)break e;t[K>>2]=_;t[G>>2]=yY(t[U>>2]|0,t[q>>2]|0,t[I>>2]|0,K)|0;if((t[G>>2]|0)>-1?(t[G>>2]|0)<(t[q>>2]|0):0){if((t[Y>>2]|0)==(t[G>>2]|0))break e;t[Y>>2]=t[G>>2]}if((t[G>>2]|0)>-1)t[q>>2]=(t[q>>2]|0)+((t[G>>2]|0)+1);else t[q>>2]=(t[q>>2]|0)+100;O=MAi[t[135760>>2]&511](t[U>>2]|0,t[q>>2]|0)|0;t[W>>2]=O;if(!O)break e;t[U>>2]=t[W>>2]}}}else t[U>>2]=Yl(63248)|0;while(0);if(!(t[H>>2]|0)){if((t[x>>2]|0)!=0&(t[N>>2]|0)==0){if((t[(t[x>>2]|0)+32>>2]|0)!=0?(t[(t[(t[x>>2]|0)+32>>2]|0)+72>>2]|0)!=0:0)t[V>>2]=t[x>>2];t[X>>2]=0;while(1){if(!((t[X>>2]|0)<10&(t[x>>2]|0)!=0))break;if((t[(t[x>>2]|0)+4>>2]|0)==1)break;t[x>>2]=t[(t[x>>2]|0)+20>>2];t[X>>2]=(t[X>>2]|0)+1}if(((t[V>>2]|0)==0&(t[x>>2]|0)!=0?(t[(t[x>>2]|0)+32>>2]|0)!=0:0)?(t[(t[(t[x>>2]|0)+32>>2]|0)+72>>2]|0)!=0:0)t[V>>2]=t[x>>2];if((t[x>>2]|0)!=0?(t[(t[x>>2]|0)+4>>2]|0)==1:0)t[T>>2]=a[(t[x>>2]|0)+56>>1];if((t[T>>2]|0)==0|(t[T>>2]|0)==65535)t[T>>2]=Qy(t[x>>2]|0)|0}}else{if(!(t[N>>2]|0)){t[z>>2]=t[(t[H>>2]|0)+36>>2];if(((t[z>>2]|0)!=0?(t[(t[z>>2]|0)+4>>2]|0)==0:0)?(t[(t[H>>2]|0)+40>>2]|0)>1:0)t[z>>2]=t[(t[(t[H>>2]|0)+48>>2]|0)+((t[(t[H>>2]|0)+40>>2]|0)-2<<2)>>2];if(t[z>>2]|0){t[N>>2]=t[(t[z>>2]|0)+4>>2];t[T>>2]=t[(t[z>>2]|0)+28>>2];t[B>>2]=t[(t[z>>2]|0)+32>>2]}}t[j>>2]=(t[H>>2]|0)+384}lp(t[j>>2]|0);t[t[j>>2]>>2]=t[A>>2];t[(t[j>>2]|0)+4>>2]=t[M>>2];t[(t[j>>2]|0)+8>>2]=t[U>>2];t[(t[j>>2]|0)+12>>2]=t[R>>2];if(!(t[N>>2]|0)){if(t[V>>2]|0){t[Z>>2]=t[V>>2];t[J>>2]=0;e:while(1){if(!(t[Z>>2]|0))break;while(1){Q=t[Z>>2]|0;if(!(t[(t[Z>>2]|0)+28>>2]|0)){$=58;break}t[Z>>2]=t[Q+28>>2];if((t[(t[Z>>2]|0)+4>>2]|0)!=19)break;M=(t[J>>2]|0)+-1|0;t[J>>2]=M;if(!((M|0)>=0&(t[Z>>2]|0)!=0))break e}if(($|0)==58){$=0;t[Z>>2]=t[Q+20>>2];continue}if((t[(t[Z>>2]|0)+4>>2]|0)!=20)continue;t[J>>2]=(t[J>>2]|0)+1}do if(t[Z>>2]|0){J=t[Z>>2]|0;if((t[(t[Z>>2]|0)+4>>2]|0)==19){t[J+4>>2]=1;Q=cF(t[Z>>2]|0,63280)|0;t[(t[j>>2]|0)+16>>2]=Q;t[(t[Z>>2]|0)+4>>2]=19;break}else{Q=cF(J,63280)|0;t[(t[j>>2]|0)+16>>2]=Q;break}}else{Q=Yl(t[(t[(t[V>>2]|0)+32>>2]|0)+72>>2]|0)|0;t[(t[j>>2]|0)+16>>2]=Q}while(0);if(((t[x>>2]|0)!=0?(t[(t[j>>2]|0)+16>>2]|0)==0:0)?(t[(t[x>>2]|0)+32>>2]|0)!=0:0){V=Yl(t[(t[(t[x>>2]|0)+32>>2]|0)+72>>2]|0)|0;t[(t[j>>2]|0)+16>>2]=V}}}else{V=Yl(t[N>>2]|0)|0;t[(t[j>>2]|0)+16>>2]=V}t[(t[j>>2]|0)+20>>2]=t[T>>2];if(t[L>>2]|0){T=Yl(t[L>>2]|0)|0;t[(t[j>>2]|0)+24>>2]=T}if(t[D>>2]|0){T=Yl(t[D>>2]|0)|0;t[(t[j>>2]|0)+28>>2]=T}if(t[C>>2]|0){T=Yl(t[C>>2]|0)|0;t[(t[j>>2]|0)+32>>2]=T}t[(t[j>>2]|0)+36>>2]=t[P>>2];t[(t[j>>2]|0)+40>>2]=t[B>>2];t[(t[j>>2]|0)+48>>2]=t[x>>2];t[(t[j>>2]|0)+44>>2]=t[F>>2];if((t[j>>2]|0)!=136208)sp(t[j>>2]|0,136208)|0;if(t[S>>2]|0){EAi[t[S>>2]&511](t[y>>2]|0,t[j>>2]|0);s=p;return}if((t[H>>2]|0)!=0&(t[g>>2]|0)==0&(t[33978]|0)==0?(t[t[H>>2]>>2]|0)!=0:0){S=t[t[H>>2]>>2]|0;if((t[R>>2]|0)==1)t[g>>2]=t[S+84>>2];else t[g>>2]=t[S+88>>2];t[y>>2]=t[(t[H>>2]|0)+4>>2]}else $=87;do if(($|0)==87?(t[g>>2]|0)==0:0){t[g>>2]=t[33976];if(t[H>>2]|0){t[y>>2]=t[H>>2];break}else{t[y>>2]=t[33980];break}}while(0);if(!(t[g>>2]|0)){s=p;return}if((t[g>>2]|0)==57|(t[g>>2]|0)==56|(t[g>>2]|0)==224|(t[g>>2]|0)==225){pp(t[j>>2]|0,t[H>>2]|0,t[U>>2]|0,0,0);s=p;return}if((t[g>>2]|0)==203|(t[g>>2]|0)==35){pp(t[j>>2]|0,t[H>>2]|0,t[U>>2]|0,t[g>>2]|0,t[y>>2]|0);s=p;return}else{H=t[g>>2]|0;g=t[y>>2]|0;t[E>>2]=t[U>>2];yAi[H&511](g,63288,E);s=p;return}}function lp(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if(!(t[r>>2]|0)){s=i;return}if(!(t[(t[r>>2]|0)+4>>2]|0)){s=i;return}if(t[(t[r>>2]|0)+8>>2]|0)pAi[t[135736>>2]&511](t[(t[r>>2]|0)+8>>2]|0);if(t[(t[r>>2]|0)+16>>2]|0)pAi[t[135736>>2]&511](t[(t[r>>2]|0)+16>>2]|0);if(t[(t[r>>2]|0)+24>>2]|0)pAi[t[135736>>2]&511](t[(t[r>>2]|0)+24>>2]|0);if(t[(t[r>>2]|0)+28>>2]|0)pAi[t[135736>>2]&511](t[(t[r>>2]|0)+28>>2]|0);if(t[(t[r>>2]|0)+32>>2]|0)pAi[t[135736>>2]&511](t[(t[r>>2]|0)+32>>2]|0);e=(t[r>>2]|0)+0|0;n=e+52|0;do{t[e>>2]=0;e=e+4|0}while((e|0)<(n|0));t[(t[r>>2]|0)+4>>2]=0;s=i;return}function sp(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0;r=s;s=s+32|0;n=r+28|0;f=r+24|0;u=r+20|0;a=r+16|0;o=r+12|0;c=r+8|0;l=r+4|0;b=r;t[f>>2]=e;t[u>>2]=i;if((t[f>>2]|0)==0|(t[u>>2]|0)==0){t[n>>2]=-1;k=t[n>>2]|0;s=r;return k|0}t[a>>2]=Yl(t[(t[f>>2]|0)+8>>2]|0)|0;t[o>>2]=Yl(t[(t[f>>2]|0)+16>>2]|0)|0;t[c>>2]=Yl(t[(t[f>>2]|0)+24>>2]|0)|0;t[l>>2]=Yl(t[(t[f>>2]|0)+28>>2]|0)|0;t[b>>2]=Yl(t[(t[f>>2]|0)+32>>2]|0)|0;if(t[(t[u>>2]|0)+8>>2]|0)pAi[t[135736>>2]&511](t[(t[u>>2]|0)+8>>2]|0);if(t[(t[u>>2]|0)+16>>2]|0)pAi[t[135736>>2]&511](t[(t[u>>2]|0)+16>>2]|0);if(t[(t[u>>2]|0)+24>>2]|0)pAi[t[135736>>2]&511](t[(t[u>>2]|0)+24>>2]|0);if(t[(t[u>>2]|0)+28>>2]|0)pAi[t[135736>>2]&511](t[(t[u>>2]|0)+28>>2]|0);if(t[(t[u>>2]|0)+32>>2]|0)pAi[t[135736>>2]&511](t[(t[u>>2]|0)+32>>2]|0);t[t[u>>2]>>2]=t[t[f>>2]>>2];t[(t[u>>2]|0)+4>>2]=t[(t[f>>2]|0)+4>>2];t[(t[u>>2]|0)+12>>2]=t[(t[f>>2]|0)+12>>2];t[(t[u>>2]|0)+20>>2]=t[(t[f>>2]|0)+20>>2];t[(t[u>>2]|0)+48>>2]=t[(t[f>>2]|0)+48>>2];t[(t[u>>2]|0)+36>>2]=t[(t[f>>2]|0)+36>>2];t[(t[u>>2]|0)+40>>2]=t[(t[f>>2]|0)+40>>2];t[(t[u>>2]|0)+48>>2]=t[(t[f>>2]|0)+48>>2];t[(t[u>>2]|0)+44>>2]=t[(t[f>>2]|0)+44>>2];t[(t[u>>2]|0)+8>>2]=t[a>>2];t[(t[u>>2]|0)+16>>2]=t[o>>2];t[(t[u>>2]|0)+24>>2]=t[c>>2];t[(t[u>>2]|0)+28>>2]=t[l>>2];t[(t[u>>2]|0)+32>>2]=t[b>>2];t[n>>2]=0;k=t[n>>2]|0;s=r;return k|0}function bp(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0;n=s;s=s+64|0;f=n;u=n+60|0;a=n+56|0;o=n+52|0;c=n+48|0;l=n+44|0;b=n+40|0;k=n+36|0;h=n+32|0;w=n+28|0;d=n+24|0;v=n+8|0;t[u>>2]=e;t[a>>2]=i;t[o>>2]=t[u>>2];t[c>>2]=0;t[l>>2]=0;if(t[o>>2]|0){t[c>>2]=t[(t[o>>2]|0)+36>>2];if(((t[c>>2]|0)!=0?(t[(t[c>>2]|0)+4>>2]|0)==0:0)?(t[(t[o>>2]|0)+40>>2]|0)>1:0){t[l>>2]=t[c>>2];t[c>>2]=t[(t[(t[o>>2]|0)+48>>2]|0)+((t[(t[o>>2]|0)+40>>2]|0)-2<<2)>>2]}ap(t[c>>2]|0)}yAi[t[135904>>2]&511](t[33980]|0,63360,f);t[h>>2]=-1;t[b>>2]=gAi[t[135744>>2]&511](150)|0;e:do if(t[b>>2]|0){t[k>>2]=150;while(1){if((t[k>>2]|0)>=64e3)break e;t[v>>2]=r;t[w>>2]=yY(t[b>>2]|0,t[k>>2]|0,t[a>>2]|0,v)|0;if((t[w>>2]|0)>-1?(t[w>>2]|0)<(t[k>>2]|0):0){if((t[h>>2]|0)==(t[w>>2]|0))break e;t[h>>2]=t[w>>2]}if((t[w>>2]|0)>-1)t[k>>2]=(t[k>>2]|0)+((t[w>>2]|0)+1);else t[k>>2]=(t[k>>2]|0)+100;u=MAi[t[135760>>2]&511](t[b>>2]|0,t[k>>2]|0)|0;t[d>>2]=u;if(!u)break e;t[b>>2]=t[d>>2]}}while(0);d=t[33976]|0;k=t[33980]|0;t[f>>2]=t[b>>2];yAi[d&511](k,63288,f);if(t[b>>2]|0)pAi[t[135736>>2]&511](t[b>>2]|0);if(!(t[o>>2]|0)){s=n;return}op(t[c>>2]|0);if(!(t[l>>2]|0)){s=n;return}ap(t[l>>2]|0);yAi[t[135904>>2]&511](t[33980]|0,63368,f);op(t[l>>2]|0);s=n;return}function kp(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0;n=s;s=s+64|0;f=n;u=n+60|0;a=n+56|0;o=n+52|0;c=n+48|0;l=n+44|0;b=n+40|0;k=n+36|0;h=n+32|0;w=n+28|0;d=n+24|0;v=n+8|0;t[u>>2]=e;t[a>>2]=i;t[o>>2]=t[u>>2];t[c>>2]=0;t[l>>2]=0;if(t[o>>2]|0){t[c>>2]=t[(t[o>>2]|0)+36>>2];if(((t[c>>2]|0)!=0?(t[(t[c>>2]|0)+4>>2]|0)==0:0)?(t[(t[o>>2]|0)+40>>2]|0)>1:0){t[l>>2]=t[c>>2];t[c>>2]=t[(t[(t[o>>2]|0)+48>>2]|0)+((t[(t[o>>2]|0)+40>>2]|0)-2<<2)>>2]}ap(t[c>>2]|0)}yAi[t[135904>>2]&511](t[33980]|0,63376,f);t[h>>2]=-1;t[b>>2]=gAi[t[135744>>2]&511](150)|0;e:do if(t[b>>2]|0){t[k>>2]=150;while(1){if((t[k>>2]|0)>=64e3)break e;t[v>>2]=r;t[w>>2]=yY(t[b>>2]|0,t[k>>2]|0,t[a>>2]|0,v)|0;if((t[w>>2]|0)>-1?(t[w>>2]|0)<(t[k>>2]|0):0){if((t[h>>2]|0)==(t[w>>2]|0))break e;t[h>>2]=t[w>>2]}if((t[w>>2]|0)>-1)t[k>>2]=(t[k>>2]|0)+((t[w>>2]|0)+1);else t[k>>2]=(t[k>>2]|0)+100;u=MAi[t[135760>>2]&511](t[b>>2]|0,t[k>>2]|0)|0;t[d>>2]=u;if(!u)break e;t[b>>2]=t[d>>2]}}while(0);d=t[33976]|0;k=t[33980]|0;t[f>>2]=t[b>>2];yAi[d&511](k,63288,f);if(t[b>>2]|0)pAi[t[135736>>2]&511](t[b>>2]|0);if(!(t[o>>2]|0)){s=n;return}op(t[c>>2]|0);if(!(t[l>>2]|0)){s=n;return}ap(t[l>>2]|0);yAi[t[135904>>2]&511](t[33980]|0,63368,f);op(t[l>>2]|0);s=n;return}function hp(e,i,r){e=e|0;i=i|0;r=r|0;var f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0;f=s;s=s+64|0;u=f;a=f+60|0;o=f+56|0;c=f+52|0;l=f+48|0;b=f+44|0;k=f+40|0;h=f+36|0;w=f+32|0;d=f+28|0;v=f+24|0;m=f+8|0;t[a>>2]=e;t[o>>2]=i;t[c>>2]=t[a>>2];t[l>>2]=0;t[k>>2]=rs(t[o>>2]|0)|0;if((t[k>>2]|0)>1?(n[(t[o>>2]|0)+((t[k>>2]|0)-2)>>0]|0)!=58:0){if(t[c>>2]|0){t[l>>2]=t[(t[c>>2]|0)+36>>2];if((t[(t[l>>2]|0)+4>>2]|0)==0?(t[(t[c>>2]|0)+40>>2]|0)>1:0)t[l>>2]=t[(t[(t[c>>2]|0)+48>>2]|0)+((t[(t[c>>2]|0)+40>>2]|0)-2<<2)>>2];if(!(t[15848]|0))ap(t[l>>2]|0)}yAi[t[135904>>2]&511](t[33980]|0,63400,u);t[15848]=0}else t[15848]=1;t[w>>2]=-1;t[b>>2]=gAi[t[135744>>2]&511](150)|0;e:do if(t[b>>2]|0){t[h>>2]=150;while(1){if((t[h>>2]|0)>=64e3)break e;t[m>>2]=r;t[d>>2]=yY(t[b>>2]|0,t[h>>2]|0,t[o>>2]|0,m)|0;if((t[d>>2]|0)>-1?(t[d>>2]|0)<(t[h>>2]|0):0){if((t[w>>2]|0)==(t[d>>2]|0))break e;t[w>>2]=t[d>>2]}if((t[d>>2]|0)>-1)t[h>>2]=(t[h>>2]|0)+((t[d>>2]|0)+1);else t[h>>2]=(t[h>>2]|0)+100;k=MAi[t[135760>>2]&511](t[b>>2]|0,t[h>>2]|0)|0;t[v>>2]=k;if(!k)break e;t[b>>2]=t[v>>2]}}while(0);v=t[33976]|0;h=t[33980]|0;
	t[u>>2]=t[b>>2];yAi[v&511](h,63288,u);if(t[b>>2]|0)pAi[t[135736>>2]&511](t[b>>2]|0);if(!((t[c>>2]|0)!=0&(t[l>>2]|0)!=0)){s=f;return}op(t[l>>2]|0);s=f;return}function wp(e,i,r){e=e|0;i=i|0;r=r|0;var f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0;f=s;s=s+64|0;u=f;a=f+60|0;o=f+56|0;c=f+52|0;l=f+48|0;b=f+44|0;k=f+40|0;h=f+36|0;w=f+32|0;d=f+28|0;v=f+24|0;m=f+8|0;t[a>>2]=e;t[o>>2]=i;t[c>>2]=t[a>>2];t[l>>2]=0;t[k>>2]=rs(t[o>>2]|0)|0;if((t[c>>2]|0)!=0&(t[k>>2]|0)!=0?(n[(t[o>>2]|0)+((t[k>>2]|0)-1)>>0]|0)!=58:0){t[l>>2]=t[(t[c>>2]|0)+36>>2];if((t[(t[l>>2]|0)+4>>2]|0)==0?(t[(t[c>>2]|0)+40>>2]|0)>1:0)t[l>>2]=t[(t[(t[c>>2]|0)+48>>2]|0)+((t[(t[c>>2]|0)+40>>2]|0)-2<<2)>>2];ap(t[l>>2]|0)}yAi[t[135904>>2]&511](t[33980]|0,63424,u);t[w>>2]=-1;t[b>>2]=gAi[t[135744>>2]&511](150)|0;e:do if(t[b>>2]|0){t[h>>2]=150;while(1){if((t[h>>2]|0)>=64e3)break e;t[m>>2]=r;t[d>>2]=yY(t[b>>2]|0,t[h>>2]|0,t[o>>2]|0,m)|0;if((t[d>>2]|0)>-1?(t[d>>2]|0)<(t[h>>2]|0):0){if((t[w>>2]|0)==(t[d>>2]|0))break e;t[w>>2]=t[d>>2]}if((t[d>>2]|0)>-1)t[h>>2]=(t[h>>2]|0)+((t[d>>2]|0)+1);else t[h>>2]=(t[h>>2]|0)+100;k=MAi[t[135760>>2]&511](t[b>>2]|0,t[h>>2]|0)|0;t[v>>2]=k;if(!k)break e;t[b>>2]=t[v>>2]}}while(0);v=t[33976]|0;h=t[33980]|0;t[u>>2]=t[b>>2];yAi[v&511](h,63288,u);if(t[b>>2]|0)pAi[t[135736>>2]&511](t[b>>2]|0);if(!(t[c>>2]|0)){s=f;return}op(t[l>>2]|0);s=f;return}function dp(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;var u=0,a=0,o=0,c=0,l=0,b=0,k=0;u=s;s=s+32|0;a=u;o=u+20|0;c=u+16|0;l=u+12|0;b=u+8|0;k=u+4|0;t[o>>2]=e;t[c>>2]=i;t[l>>2]=r;t[b>>2]=n;t[k>>2]=f;if((t[c>>2]|0)!=2){f=t[l>>2]|0;n=t[o>>2]|0;r=t[c>>2]|0;c=t[k>>2]|0;i=t[b>>2]|0;t[a>>2]=t[k>>2];cp(0,0,0,0,f,n,r,2,0,0,c,0,0,0,0,i,a);s=u;return}i=t[l>>2]|0;l=t[o>>2]|0;if(t[k>>2]|0){o=t[k>>2]|0;t[a>>2]=t[k>>2];cp(0,0,0,0,i,l,2,3,0,0,o,0,0,0,0,63296,a);s=u;return}else{cp(0,0,0,0,i,l,2,3,0,0,0,0,0,0,0,63328,a);s=u;return}}function vp(){var e=0,i=0;e=s;s=s+16|0;i=e;if(!(t[34053]|0))t[i>>2]=0;else t[i>>2]=136208;s=e;return t[i>>2]|0}function mp(){var e=0;e=s;if(t[34053]|0)lp(136208);s=e;return}function _p(e,i,r){e=e|0;i=i|0;r=r|0;var f=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0;f=s;s=s+128|0;a=f;o=f+32|0;c=f+28|0;l=f+24|0;b=f+20|0;k=f+16|0;h=f+12|0;w=f+8|0;d=f+36|0;v=f+4|0;t[o>>2]=e;t[c>>2]=i;t[l>>2]=r;if(!(t[o>>2]|0)){s=f;return}t[b>>2]=t[(t[o>>2]|0)+16>>2];t[k>>2]=t[(t[o>>2]|0)+12>>2];while(1){if((t[b>>2]|0)>>>0<=(t[k>>2]|0)>>>0)break;if((u[t[b>>2]>>0]|0|0)!=10?(u[t[b>>2]>>0]|0|0)!=13:0)break;t[b>>2]=(t[b>>2]|0)+-1}t[h>>2]=0;while(1){r=t[h>>2]|0;t[h>>2]=r+1;if((r>>>0<80?(t[b>>2]|0)>>>0>(t[k>>2]|0)>>>0:0)?(u[t[b>>2]>>0]|0|0)!=10:0)m=(u[t[b>>2]>>0]|0|0)!=13;else m=0;_=t[b>>2]|0;if(!m)break;t[b>>2]=_+-1}if(!((u[_>>0]|0|0)!=10?(u[t[b>>2]>>0]|0|0)!=13:0))t[b>>2]=(t[b>>2]|0)+1;t[w>>2]=(t[(t[o>>2]|0)+16>>2]|0)-(t[b>>2]|0);t[h>>2]=0;t[v>>2]=d;while(1){if(!(u[t[b>>2]>>0]|0))break;if((u[t[b>>2]>>0]|0|0)==10)break;if(!((t[h>>2]|0)>>>0<80?(u[t[b>>2]>>0]|0|0)!=13:0))break;o=t[b>>2]|0;t[b>>2]=o+1;_=n[o>>0]|0;o=t[v>>2]|0;t[v>>2]=o+1;n[o>>0]=_;t[h>>2]=(t[h>>2]|0)+1}n[t[v>>2]>>0]=0;b=t[c>>2]|0;_=t[l>>2]|0;t[a>>2]=d;yAi[b&511](_,63808,a);t[h>>2]=0;t[v>>2]=d;while(1){if((t[h>>2]|0)>>>0<(t[w>>2]|0)>>>0?(_=t[h>>2]|0,t[h>>2]=_+1,_>>>0<79):0)p=(u[t[v>>2]>>0]|0|0)!=0;else p=0;E=t[v>>2]|0;if(!p)break;if((u[E>>0]|0|0)!=9)n[t[v>>2]>>0]=32;t[v>>2]=(t[v>>2]|0)+1}t[v>>2]=E+1;n[E>>0]=94;n[t[v>>2]>>0]=0;v=t[c>>2]|0;c=t[l>>2]|0;t[a>>2]=d;yAi[v&511](c,63808,a);s=f;return}function pp(e,i,r,f,u){e=e|0;i=i|0;r=r|0;f=f|0;u=u|0;var a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0,S=0,g=0,y=0,F=0,O=0,A=0;a=s;s=s+224|0;o=a;c=a+68|0;l=a+64|0;b=a+60|0;k=a+56|0;h=a+52|0;w=a+48|0;d=a+44|0;v=a+40|0;m=a+36|0;_=a+32|0;p=a+28|0;E=a+24|0;S=a+20|0;g=a+16|0;y=a+12|0;F=a+72|0;O=a+8|0;t[c>>2]=e;t[l>>2]=i;t[b>>2]=r;t[k>>2]=f;t[h>>2]=u;t[w>>2]=0;t[d>>2]=0;t[v>>2]=-1;t[_>>2]=0;t[S>>2]=0;t[g>>2]=0;if(!(t[c>>2]|0)){s=a;return}if(!(t[k>>2]|0)){t[k>>2]=t[33976];t[h>>2]=t[33980]}t[w>>2]=t[(t[c>>2]|0)+16>>2];t[d>>2]=t[(t[c>>2]|0)+20>>2];t[v>>2]=t[(t[c>>2]|0)+4>>2];t[m>>2]=t[t[c>>2]>>2];t[E>>2]=t[(t[c>>2]|0)+12>>2];t[p>>2]=t[(t[c>>2]|0)+48>>2];if(!(t[v>>2]|0)){s=a;return}if((t[p>>2]|0)!=0?(t[(t[p>>2]|0)+4>>2]|0)==1:0)t[_>>2]=t[(t[p>>2]|0)+8>>2];do if(t[l>>2]|0){t[S>>2]=t[(t[l>>2]|0)+36>>2];if(((t[S>>2]|0)!=0?(t[(t[S>>2]|0)+4>>2]|0)==0:0)?(t[(t[l>>2]|0)+40>>2]|0)>1:0){t[g>>2]=t[S>>2];t[S>>2]=t[(t[(t[l>>2]|0)+48>>2]|0)+((t[(t[l>>2]|0)+40>>2]|0)-2<<2)>>2]}if(t[S>>2]|0){if(t[(t[S>>2]|0)+4>>2]|0){p=t[k>>2]|0;v=t[h>>2]|0;u=t[(t[S>>2]|0)+28>>2]|0;t[o>>2]=t[(t[S>>2]|0)+4>>2];t[o+4>>2]=u;yAi[p&511](v,63216,o);break}if((t[d>>2]|0)!=0&(t[m>>2]|0)==1){v=t[k>>2]|0;p=t[h>>2]|0;t[o>>2]=t[(t[S>>2]|0)+28>>2];yAi[v&511](p,63224,o)}}}else{if(t[w>>2]|0){p=t[k>>2]|0;v=t[h>>2]|0;u=t[d>>2]|0;t[o>>2]=t[w>>2];t[o+4>>2]=u;yAi[p&511](v,63216,o);break}if((t[d>>2]|0)!=0?(t[m>>2]|0)==1|(t[m>>2]|0)==17|(t[m>>2]|0)==16|(t[m>>2]|0)==4|(t[m>>2]|0)==18|(t[m>>2]|0)==19:0){v=t[k>>2]|0;p=t[h>>2]|0;t[o>>2]=t[d>>2];yAi[v&511](p,63224,o)}}while(0);if(t[_>>2]|0){w=t[k>>2]|0;p=t[h>>2]|0;t[o>>2]=t[_>>2];yAi[w&511](p,63448,o)}do switch(t[m>>2]|0){case 29:{yAi[t[k>>2]&511](t[h>>2]|0,63736,o);break}case 30:{yAi[t[k>>2]&511](t[h>>2]|0,63760,o);break}case 20:{yAi[t[k>>2]&511](t[h>>2]|0,63672,o);break}case 5:{yAi[t[k>>2]&511](t[h>>2]|0,63504,o);break}case 1:{yAi[t[k>>2]&511](t[h>>2]|0,63464,o);break}case 13:{yAi[t[k>>2]&511](t[h>>2]|0,63464,o);break}case 18:{yAi[t[k>>2]&511](t[h>>2]|0,63624,o);break}case 19:{yAi[t[k>>2]&511](t[h>>2]|0,63648,o);break}case 14:{yAi[t[k>>2]&511](t[h>>2]|0,63568,o);break}case 26:{yAi[t[k>>2]&511](t[h>>2]|0,63576,o);break}case 23:case 4:{yAi[t[k>>2]&511](t[h>>2]|0,63488,o);break}case 3:{yAi[t[k>>2]&511](t[h>>2]|0,63472,o);break}case 17:{yAi[t[k>>2]&511](t[h>>2]|0,63584,o);break}case 16:{yAi[t[k>>2]&511](t[h>>2]|0,63608,o);break}case 21:{yAi[t[k>>2]&511](t[h>>2]|0,63688,o);break}case 22:{yAi[t[k>>2]&511](t[h>>2]|0,63696,o);break}case 27:{yAi[t[k>>2]&511](t[h>>2]|0,63704,o);break}case 28:{yAi[t[k>>2]&511](t[h>>2]|0,63720,o);break}case 6:{yAi[t[k>>2]&511](t[h>>2]|0,63520,o);break}case 7:{yAi[t[k>>2]&511](t[h>>2]|0,63528,o);break}case 8:{yAi[t[k>>2]&511](t[h>>2]|0,63536,o);break}case 11:{yAi[t[k>>2]&511](t[h>>2]|0,63544,o);break}case 12:{yAi[t[k>>2]&511](t[h>>2]|0,63560,o);break}default:{}}while(0);p=t[E>>2]|0;if((p|0)==1)yAi[t[k>>2]&511](t[h>>2]|0,63776,o);else if((p|0)==2)yAi[t[k>>2]&511](t[h>>2]|0,63792,o);else if((p|0)==3)yAi[t[k>>2]&511](t[h>>2]|0,63792,o);else if(!p)yAi[t[k>>2]&511](t[h>>2]|0,63768,o);do if(t[b>>2]|0){t[y>>2]=rs(t[b>>2]|0)|0;if((t[y>>2]|0)>0?(n[(t[b>>2]|0)+((t[y>>2]|0)-1)>>0]|0)!=10:0){p=t[k>>2]|0;E=t[h>>2]|0;t[o>>2]=t[b>>2];yAi[p&511](E,63808,o);break}E=t[k>>2]|0;p=t[h>>2]|0;t[o>>2]=t[b>>2];yAi[E&511](p,63288,o)}else{p=t[k>>2]|0;E=t[h>>2]|0;t[o>>2]=63816;yAi[p&511](E,63808,o)}while(0);if((t[l>>2]|0)!=0?(_p(t[S>>2]|0,t[k>>2]|0,t[h>>2]|0),(t[g>>2]|0)!=0):0){if(!(t[(t[g>>2]|0)+4>>2]|0)){if((t[d>>2]|0)!=0&(t[m>>2]|0)==1){d=t[k>>2]|0;S=t[h>>2]|0;t[o>>2]=t[(t[g>>2]|0)+28>>2];yAi[d&511](S,63856,o)}}else{S=t[k>>2]|0;d=t[h>>2]|0;l=t[(t[g>>2]|0)+28>>2]|0;t[o>>2]=t[(t[g>>2]|0)+4>>2];t[o+4>>2]=l;yAi[S&511](d,63840,o)}_p(t[g>>2]|0,t[k>>2]|0,t[h>>2]|0)}if((t[m>>2]|0)!=12){s=a;return}if(!(t[(t[c>>2]|0)+24>>2]|0)){s=a;return}if((t[(t[c>>2]|0)+36>>2]|0)>=100){s=a;return}m=t[(t[c>>2]|0)+36>>2]|0;if((m|0)>=(rs(t[(t[c>>2]|0)+24>>2]|0)|0)){s=a;return}m=t[k>>2]|0;g=t[h>>2]|0;t[o>>2]=t[(t[c>>2]|0)+24>>2];yAi[m&511](g,63808,o);t[O>>2]=0;while(1){A=t[O>>2]|0;if((t[O>>2]|0)>=(t[(t[c>>2]|0)+36>>2]|0))break;n[F+A>>0]=32;t[O>>2]=(t[O>>2]|0)+1}t[O>>2]=A+1;n[F+A>>0]=94;n[F+(t[O>>2]|0)>>0]=0;O=t[k>>2]|0;k=t[h>>2]|0;t[o>>2]=F;yAi[O&511](k,63808,o);s=a;return}function Ep(e){e=e|0;var i=0,r=0,n=0,f=0,u=0,a=0;i=s;s=s+16|0;r=i;n=i+12|0;f=i+8|0;t[n>>2]=e;t[f>>2]=20902;rS();if(((t[f>>2]|0)/1e4|0|0)!=((t[n>>2]|0)/1e4|0|0)){e=t[33976]|0;u=t[33980]|0;a=(t[f>>2]|0)/1e4|0;t[r>>2]=(t[n>>2]|0)/1e4|0;t[r+4>>2]=a;yAi[e&511](u,63880,r);u=t[v>>2]|0;e=(t[f>>2]|0)/1e4|0;t[r>>2]=(t[n>>2]|0)/1e4|0;t[r+4>>2]=e;xe(u|0,63880,r|0)|0}if(((t[f>>2]|0)/100|0|0)>=((t[n>>2]|0)/100|0|0)){s=i;return}u=t[33976]|0;e=t[33980]|0;a=(t[f>>2]|0)/100|0;t[r>>2]=(t[n>>2]|0)/100|0;t[r+4>>2]=a;yAi[u&511](e,63944,r);s=i;return}function Sp(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0;r=s;s=s+16|0;n=r;f=r+8|0;u=r+4|0;t[f>>2]=e;t[u>>2]=i;if(((t[f>>2]|0)!=0?(t[(t[f>>2]|0)+212>>2]|0)!=0:0)?(t[(t[f>>2]|0)+172>>2]|0)==-1:0){s=r;return}if(t[f>>2]|0){t[(t[f>>2]|0)+84>>2]=2;t[(t[f>>2]|0)+172>>2]=-1;t[(t[f>>2]|0)+212>>2]=1}i=t[f>>2]|0;if(t[u>>2]|0){f=t[u>>2]|0;t[n>>2]=t[u>>2];cp(0,0,0,i,0,1,2,3,0,0,f,0,0,0,0,64008,n);s=r;return}else{cp(0,0,0,i,0,1,2,3,0,0,0,0,0,0,0,64040,n);s=r;return}}function gp(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;var u=0,a=0,o=0,c=0,l=0,b=0,k=0;u=s;s=s+32|0;a=u;o=u+24|0;c=u+20|0;l=u+16|0;b=u+12|0;k=u+8|0;t[o>>2]=e;t[c>>2]=i;t[l>>2]=r;t[b>>2]=n;t[k>>2]=f;if(((t[o>>2]|0)!=0?(t[(t[o>>2]|0)+212>>2]|0)!=0:0)?(t[(t[o>>2]|0)+172>>2]|0)==-1:0){s=u;return}if(t[o>>2]|0)t[(t[o>>2]|0)+84>>2]=t[c>>2];f=t[o>>2]|0;n=t[c>>2]|0;c=t[b>>2]|0;r=t[k>>2]|0;i=t[l>>2]|0;l=t[k>>2]|0;t[a>>2]=t[b>>2];t[a+4>>2]=l;cp(0,0,0,f,0,1,n,3,0,0,c,r,0,0,0,i,a);if(!(t[o>>2]|0)){s=u;return}t[(t[o>>2]|0)+12>>2]=0;if(t[(t[o>>2]|0)+288>>2]|0){s=u;return}t[(t[o>>2]|0)+212>>2]=1;s=u;return}function yp(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0;r=s;s=s+32|0;n=r+20|0;f=r+16|0;u=r+12|0;a=r+8|0;o=r+4|0;c=r;t[f>>2]=e;t[u>>2]=i;if((t[f>>2]|0)==0|(t[u>>2]|0)<0){t[n>>2]=-1;l=t[n>>2]|0;s=r;return l|0}if(!(t[t[f>>2]>>2]|0)){t[n>>2]=-1;l=t[n>>2]|0;s=r;return l|0}if(!(t[(t[f>>2]|0)+12>>2]|0)){t[n>>2]=-1;l=t[n>>2]|0;s=r;return l|0}if(!(t[(t[f>>2]|0)+16>>2]|0)){t[n>>2]=-1;l=t[n>>2]|0;s=r;return l|0}if(!(t[(t[t[f>>2]>>2]|0)+16>>2]|0)){t[n>>2]=-1;l=t[n>>2]|0;s=r;return l|0}t[o>>2]=(t[(t[f>>2]|0)+16>>2]|0)-(t[(t[f>>2]|0)+12>>2]|0);i=Ts(t[(t[t[f>>2]>>2]|0)+16>>2]|0)|0;if(i>>>0>((t[o>>2]|0)+250|0)>>>0){t[n>>2]=0;l=t[n>>2]|0;s=r;return l|0}if(!(t[(t[t[f>>2]>>2]|0)+4>>2]|0)){t[n>>2]=0;l=t[n>>2]|0;s=r;return l|0}t[a>>2]=JO(t[t[f>>2]>>2]|0,t[u>>2]|0)|0;t[c>>2]=Os(t[(t[t[f>>2]>>2]|0)+16>>2]|0)|0;if((t[(t[f>>2]|0)+12>>2]|0)!=(t[c>>2]|0)){t[o>>2]=(t[(t[f>>2]|0)+16>>2]|0)-(t[(t[f>>2]|0)+12>>2]|0);t[(t[f>>2]|0)+12>>2]=t[c>>2];t[(t[f>>2]|0)+16>>2]=(t[c>>2]|0)+(t[o>>2]|0)}o=As(t[(t[t[f>>2]>>2]|0)+16>>2]|0)|0;t[(t[f>>2]|0)+20>>2]=o;t[n>>2]=t[a>>2];l=t[n>>2]|0;s=r;return l|0}function Fp(e){e=e|0;var i=0,r=0,n=0,f=0,u=0,a=0;i=s;s=s+32|0;r=i+16|0;n=i+12|0;f=i+8|0;u=i+4|0;a=i;t[r>>2]=e;if(!(t[r>>2]|0)){s=i;return}if(!(t[t[r>>2]>>2]|0)){s=i;return}if(!(t[(t[r>>2]|0)+12>>2]|0)){s=i;return}if(!(t[(t[r>>2]|0)+16>>2]|0)){s=i;return}if(!(t[(t[t[r>>2]>>2]|0)+16>>2]|0)){s=i;return}e=t[(t[r>>2]|0)+16>>2]|0;t[n>>2]=e-(Os(t[(t[t[r>>2]>>2]|0)+16>>2]|0)|0);if((t[n>>2]|0)>>>0>250){t[f>>2]=ys(t[(t[t[r>>2]>>2]|0)+16>>2]|0,(t[n>>2]|0)-80|0)|0;if((t[f>>2]|0)>>>0>0){n=(t[r>>2]|0)+16|0;t[n>>2]=(t[n>>2]|0)+(0-(t[f>>2]|0));n=(t[r>>2]|0)+36|0;t[n>>2]=(t[n>>2]|0)+(t[f>>2]|0)}f=As(t[(t[t[r>>2]>>2]|0)+16>>2]|0)|0;t[(t[r>>2]|0)+20>>2]=f}if((Ts(t[(t[t[r>>2]>>2]|0)+16>>2]|0)|0)>>>0>250){s=i;return}QO(t[t[r>>2]>>2]|0,500)|0;t[a>>2]=Os(t[(t[t[r>>2]>>2]|0)+16>>2]|0)|0;if((t[(t[r>>2]|0)+12>>2]|0)!=(t[a>>2]|0)){t[u>>2]=(t[(t[r>>2]|0)+16>>2]|0)-(t[(t[r>>2]|0)+12>>2]|0);t[(t[r>>2]|0)+12>>2]=t[a>>2];t[(t[r>>2]|0)+16>>2]=(t[a>>2]|0)+(t[u>>2]|0)}u=As(t[(t[t[r>>2]>>2]|0)+16>>2]|0)|0;t[(t[r>>2]|0)+20>>2]=u;s=i;return}function Op(e){e=e|0;var i=0,r=0,f=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0;i=s;s=s+192|0;r=i;f=i+24|0;a=i+20|0;o=i+178|0;c=i+16|0;l=i+28|0;t[f>>2]=e;if(!(t[f>>2]|0)){s=i;return}if((t[(t[f>>2]|0)+172>>2]|0)==-1){s=i;return}if(!(t[(t[f>>2]|0)+36>>2]|0)){s=i;return}e=u[t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]>>0]|0;do if((t[(t[f>>2]|0)+256>>2]|0)==1){if(((e|0)==0?(yp(t[(t[f>>2]|0)+36>>2]|0,250)|0)<=0:0)?(t[(t[f>>2]|0)+172>>2]|0)!=5:0){aE(t[f>>2]|0)|0;break}b=t[(t[f>>2]|0)+36>>2]|0;if((u[t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==10){k=b+28|0;t[k>>2]=(t[k>>2]|0)+1;t[(t[(t[f>>2]|0)+36>>2]|0)+32>>2]=1}else{k=b+32|0;t[k>>2]=(t[k>>2]|0)+1}t[a>>2]=t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2];n[o>>0]=n[t[a>>2]>>0]|0;e:do if((u[o>>0]|0)&128){do if((u[o>>0]|0|0)!=192){if(!(u[(t[a>>2]|0)+1>>0]|0)){yp(t[(t[f>>2]|0)+36>>2]|0,250)|0;t[a>>2]=t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]}if(((u[(t[a>>2]|0)+1>>0]|0)&192|0)==128){if(((u[o>>0]|0)&224|0)!=224){k=(t[(t[f>>2]|0)+36>>2]|0)+16|0;t[k>>2]=(t[k>>2]|0)+2;break e}if(!(u[(t[a>>2]|0)+2>>0]|0)){yp(t[(t[f>>2]|0)+36>>2]|0,250)|0;t[a>>2]=t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]}if(((u[(t[a>>2]|0)+2>>0]|0)&192|0)==128){if(((u[o>>0]|0)&240|0)==240){if(!(u[(t[a>>2]|0)+3>>0]|0)){yp(t[(t[f>>2]|0)+36>>2]|0,250)|0;t[a>>2]=t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]}if(((u[o>>0]|0)&248|0)!=240)break;if(((u[(t[a>>2]|0)+3>>0]|0)&192|0)!=128)break;k=(t[(t[f>>2]|0)+36>>2]|0)+16|0;t[k>>2]=(t[k>>2]|0)+4;t[c>>2]=((u[t[a>>2]>>0]|0)&7)<<18;t[c>>2]=t[c>>2]|((u[(t[a>>2]|0)+1>>0]|0)&63)<<12;t[c>>2]=t[c>>2]|((u[(t[a>>2]|0)+2>>0]|0)&63)<<6;t[c>>2]=t[c>>2]|(u[(t[a>>2]|0)+3>>0]|0)&63}else{k=(t[(t[f>>2]|0)+36>>2]|0)+16|0;t[k>>2]=(t[k>>2]|0)+3;t[c>>2]=((u[t[a>>2]>>0]|0)&15)<<12;t[c>>2]=t[c>>2]|((u[(t[a>>2]|0)+1>>0]|0)&63)<<6;t[c>>2]=t[c>>2]|(u[(t[a>>2]|0)+2>>0]|0)&63}if(!((t[c>>2]|0)>>>0>55295&(t[c>>2]|0)>>>0<57344)?!((t[c>>2]|0)>>>0>65533&(t[c>>2]|0)>>>0<65536|(t[c>>2]|0)>>>0>=1114112):0)break e;Kp(t[f>>2]|0,9,64072,t[c>>2]|0);break e}}}while(0);if(((t[f>>2]|0)!=0?(t[(t[f>>2]|0)+36>>2]|0)!=0:0)?((t[(t[(t[f>>2]|0)+36>>2]|0)+20>>2]|0)-(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)|0)>=4:0){k=u[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+1>>0]|0;b=u[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+2>>0]|0;h=u[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+3>>0]|0;t[r>>2]=u[t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]>>0];t[r+4>>2]=k;t[r+8>>2]=b;t[r+12>>2]=h;SY(l,149,64152,r)|0;gp(t[f>>2]|0,9,64192,l,0)}else gp(t[f>>2]|0,9,64104,0,0);t[(t[f>>2]|0)+256>>2]=10;h=(t[(t[f>>2]|0)+36>>2]|0)+16|0;t[h>>2]=(t[h>>2]|0)+1;s=i;return}else{h=(t[(t[f>>2]|0)+36>>2]|0)+16|0;t[h>>2]=(t[h>>2]|0)+1}while(0);h=(t[f>>2]|0)+200|0;t[h>>2]=(t[h>>2]|0)+1;if(!(u[t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]>>0]|0))yp(t[(t[f>>2]|0)+36>>2]|0,250)|0}else{h=t[(t[f>>2]|0)+36>>2]|0;if((e|0)==10){b=h+28|0;t[b>>2]=(t[b>>2]|0)+1;t[(t[(t[f>>2]|0)+36>>2]|0)+32>>2]=1}else{b=h+32|0;t[b>>2]=(t[b>>2]|0)+1}b=(t[(t[f>>2]|0)+36>>2]|0)+16|0;t[b>>2]=(t[b>>2]|0)+1;b=(t[f>>2]|0)+200|0;t[b>>2]=(t[b>>2]|0)+1;if(!(u[t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]>>0]|0))yp(t[(t[f>>2]|0)+36>>2]|0,250)|0}while(0);if((u[t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==37?(t[(t[f>>2]|0)+32>>2]|0)==0:0)oE(t[f>>2]|0);if(u[t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]>>0]|0){s=i;return}if((yp(t[(t[f>>2]|0)+36>>2]|0,250)|0)>0){s=i;return}aE(t[f>>2]|0)|0;s=i;return}function Ap(e,i){e=e|0;i=i|0;var r=0,f=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0;r=s;s=s+192|0;f=r;a=r+32|0;o=r+28|0;c=r+24|0;l=r+20|0;b=r+186|0;k=r+16|0;h=r+36|0;t[o>>2]=e;t[c>>2]=i;if(!((t[o>>2]|0)==0|(t[c>>2]|0)==0)?(t[(t[o>>2]|0)+36>>2]|0)!=0:0){if((t[(t[o>>2]|0)+172>>2]|0)==-1){t[a>>2]=0;w=t[a>>2]|0;s=r;return w|0}if((u[t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)>=32?(u[t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)<=127:0){t[t[c>>2]>>2]=1;t[a>>2]=u[t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]>>0];w=t[a>>2]|0;s=r;return w|0}if((t[(t[o>>2]|0)+256>>2]|0)!=1){t[t[c>>2]>>2]=1;i=t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]|0;if((u[t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)!=13){t[a>>2]=u[i>>0];w=t[a>>2]|0;s=r;return w|0}if((u[i+1>>0]|0|0)==10){i=(t[o>>2]|0)+200|0;t[i>>2]=(t[i>>2]|0)+1;i=(t[(t[o>>2]|0)+36>>2]|0)+16|0;t[i>>2]=(t[i>>2]|0)+1}t[a>>2]=10;w=t[a>>2]|0;s=r;return w|0}t[l>>2]=t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2];n[b>>0]=n[t[l>>2]>>0]|0;if(!((u[b>>0]|0)&128)){t[t[c>>2]>>2]=1;if(!(u[t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]>>0]|0))yp(t[(t[o>>2]|0)+36>>2]|0,250)|0;if((u[t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==0?(t[(t[(t[o>>2]|0)+36>>2]|0)+20>>2]|0)>>>0>(t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]|0)>>>0:0)Kp(t[o>>2]|0,9,64248,0);i=t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]|0;if((u[t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)!=13){t[a>>2]=u[i>>0];w=t[a>>2]|0;s=r;return w|0}if((u[i+1>>0]|0|0)==10){i=(t[o>>2]|0)+200|0;t[i>>2]=(t[i>>2]|0)+1;i=(t[(t[o>>2]|0)+36>>2]|0)+16|0;t[i>>2]=(t[i>>2]|0)+1}t[a>>2]=10;w=t[a>>2]|0;s=r;return w|0}e:do if(((u[b>>0]|0)&64|0)!=0?(u[b>>0]|0|0)!=192:0){if(!(u[(t[l>>2]|0)+1>>0]|0)){yp(t[(t[o>>2]|0)+36>>2]|0,250)|0;t[l>>2]=t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]}if(((u[(t[l>>2]|0)+1>>0]|0)&192|0)==128){do if(((u[b>>0]|0)&224|0)==224){if(!(u[(t[l>>2]|0)+2>>0]|0)){yp(t[(t[o>>2]|0)+36>>2]|0,250)|0;t[l>>2]=t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]}if(((u[(t[l>>2]|0)+2>>0]|0)&192|0)!=128)break e;if(((u[b>>0]|0)&240|0)!=240){t[t[c>>2]>>2]=3;t[k>>2]=((u[t[l>>2]>>0]|0)&15)<<12;t[k>>2]=t[k>>2]|((u[(t[l>>2]|0)+1>>0]|0)&63)<<6;t[k>>2]=t[k>>2]|(u[(t[l>>2]|0)+2>>0]|0)&63;if((t[k>>2]|0)>>>0<2048)break e;else break}if(!(u[(t[l>>2]|0)+3>>0]|0)){yp(t[(t[o>>2]|0)+36>>2]|0,250)|0;t[l>>2]=t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]}if(((u[b>>0]|0)&248|0)!=240)break e;if(((u[(t[l>>2]|0)+3>>0]|0)&192|0)!=128)break e;t[t[c>>2]>>2]=4;t[k>>2]=((u[t[l>>2]>>0]|0)&7)<<18;t[k>>2]=t[k>>2]|((u[(t[l>>2]|0)+1>>0]|0)&63)<<12;t[k>>2]=t[k>>2]|((u[(t[l>>2]|0)+2>>0]|0)&63)<<6;t[k>>2]=t[k>>2]|(u[(t[l>>2]|0)+3>>0]|0)&63;if((t[k>>2]|0)>>>0<65536)break e}else{t[t[c>>2]>>2]=2;t[k>>2]=((u[t[l>>2]>>0]|0)&31)<<6;t[k>>2]=t[k>>2]|(u[(t[l>>2]|0)+1>>0]|0)&63;if((t[k>>2]|0)>>>0<128)break e}while(0);i=t[k>>2]|0;if((t[k>>2]|0)>>>0<256){if(!(9<=i>>>0&(t[k>>2]|0)>>>0<=10|(t[k>>2]|0)==13|32<=(t[k>>2]|0)>>>0))d=33}else if((!(256<=i>>>0&(t[k>>2]|0)>>>0<=55295)?!(57344<=(t[k>>2]|0)>>>0&(t[k>>2]|0)>>>0<=65533):0)?!(65536<=(t[k>>2]|0)>>>0&(t[k>>2]|0)>>>0<=1114111):0)d=33;if((d|0)==33)Kp(t[o>>2]|0,9,64072,t[k>>2]|0);t[a>>2]=t[k>>2];w=t[a>>2]|0;s=r;return w|0}}while(0);if(((t[(t[(t[o>>2]|0)+36>>2]|0)+20>>2]|0)-(t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]|0)|0)<4){t[t[c>>2]>>2]=0;t[a>>2]=0;w=t[a>>2]|0;s=r;return w|0}else{k=u[(t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]|0)+1>>0]|0;d=u[(t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]|0)+2>>0]|0;l=u[(t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]|0)+3>>0]|0;t[f>>2]=u[t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]>>0];t[f+4>>2]=k;t[f+8>>2]=d;t[f+12>>2]=l;SY(h,149,64152,f)|0;gp(t[o>>2]|0,9,64192,h,0);t[(t[o>>2]|0)+256>>2]=10;t[t[c>>2]>>2]=1;t[a>>2]=u[t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]>>0];w=t[a>>2]|0;s=r;return w|0}}t[a>>2]=0;w=t[a>>2]|0;s=r;return w|0}function Mp(e,i,r){e=e|0;i=i|0;r=r|0;var f=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0;f=s;s=s+192|0;a=f;o=f+32|0;c=f+28|0;l=f+24|0;b=f+20|0;k=f+186|0;h=f+16|0;w=f+36|0;t[c>>2]=e;t[l>>2]=i;t[b>>2]=r;if((t[b>>2]|0)==0|(t[l>>2]|0)==0){t[o>>2]=0;d=t[o>>2]|0;s=f;return d|0}if((t[c>>2]|0)!=0?(t[(t[c>>2]|0)+256>>2]|0)!=1:0){t[t[b>>2]>>2]=1;t[o>>2]=u[t[l>>2]>>0];d=t[o>>2]|0;s=f;return d|0}n[k>>0]=n[t[l>>2]>>0]|0;if(!((u[k>>0]|0)&128)){t[t[b>>2]>>2]=1;t[o>>2]=u[t[l>>2]>>0];d=t[o>>2]|0;s=f;return d|0}e:do if(((u[(t[l>>2]|0)+1>>0]|0)&192|0)==128){do if(((u[k>>0]|0)&224|0)==224){if(((u[(t[l>>2]|0)+2>>0]|0)&192|0)!=128)break e;if(((u[k>>0]|0)&240|0)!=240){t[t[b>>2]>>2]=3;t[h>>2]=((u[t[l>>2]>>0]|0)&15)<<12;t[h>>2]=t[h>>2]|((u[(t[l>>2]|0)+1>>0]|0)&63)<<6;t[h>>2]=t[h>>2]|(u[(t[l>>2]|0)+2>>0]|0)&63;break}if(((u[k>>0]|0)&248|0)!=240)break e;if(((u[(t[l>>2]|0)+3>>0]|0)&192|0)!=128)break e;t[t[b>>2]>>2]=4;t[h>>2]=((u[t[l>>2]>>0]|0)&7)<<18;t[h>>2]=t[h>>2]|((u[(t[l>>2]|0)+1>>0]|0)&63)<<12;t[h>>2]=t[h>>2]|((u[(t[l>>2]|0)+2>>0]|0)&63)<<6;t[h>>2]=t[h>>2]|(u[(t[l>>2]|0)+3>>0]|0)&63}else{t[t[b>>2]>>2]=2;t[h>>2]=((u[t[l>>2]>>0]|0)&31)<<6;t[h>>2]=t[h>>2]|(u[(t[l>>2]|0)+1>>0]|0)&63}while(0);r=t[h>>2]|0;if((t[h>>2]|0)>>>0<256){if(!(9<=r>>>0&(t[h>>2]|0)>>>0<=10|(t[h>>2]|0)==13|32<=(t[h>>2]|0)>>>0))v=20}else if((!(256<=r>>>0&(t[h>>2]|0)>>>0<=55295)?!(57344<=(t[h>>2]|0)>>>0&(t[h>>2]|0)>>>0<=65533):0)?!(65536<=(t[h>>2]|0)>>>0&(t[h>>2]|0)>>>0<=1114111):0)v=20;if((v|0)==20)Kp(t[c>>2]|0,9,64072,t[h>>2]|0);t[o>>2]=t[h>>2];d=t[o>>2]|0;s=f;return d|0}while(0);if(((t[c>>2]|0)!=0?(t[(t[c>>2]|0)+36>>2]|0)!=0:0)?((t[(t[(t[c>>2]|0)+36>>2]|0)+20>>2]|0)-(t[(t[(t[c>>2]|0)+36>>2]|0)+16>>2]|0)|0)>=4:0){h=u[(t[(t[(t[c>>2]|0)+36>>2]|0)+16>>2]|0)+1>>0]|0;v=u[(t[(t[(t[c>>2]|0)+36>>2]|0)+16>>2]|0)+2>>0]|0;k=u[(t[(t[(t[c>>2]|0)+36>>2]|0)+16>>2]|0)+3>>0]|0;t[a>>2]=u[t[(t[(t[c>>2]|0)+36>>2]|0)+16>>2]>>0];t[a+4>>2]=h;t[a+8>>2]=v;t[a+12>>2]=k;SY(w,149,64152,a)|0;gp(t[c>>2]|0,9,64192,w,0);t[t[b>>2]>>2]=1;t[o>>2]=u[t[l>>2]>>0];d=t[o>>2]|0;s=f;return d|0}t[t[b>>2]>>2]=0;t[o>>2]=0;d=t[o>>2]|0;s=f;return d|0}function Rp(e,i){e=e|0;i=i|0;var r=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0;r=s;s=s+32|0;f=r+16|0;u=r+12|0;a=r+8|0;o=r+4|0;c=r;t[u>>2]=e;t[a>>2]=i;if(!(t[u>>2]|0)){t[f>>2]=0;l=t[f>>2]|0;s=r;return l|0}if((t[a>>2]|0)<128){n[t[u>>2]>>0]=t[a>>2];t[f>>2]=1;l=t[f>>2]|0;s=r;return l|0}t[o>>2]=t[u>>2];i=t[a>>2]|0;do if((t[a>>2]|0)<2048){e=t[u>>2]|0;t[u>>2]=e+1;n[e>>0]=i>>6|192;t[c>>2]=0}else{e=t[a>>2]|0;if((i|0)<65536){b=t[u>>2]|0;t[u>>2]=b+1;n[b>>0]=e>>12|224;t[c>>2]=6;break}b=t[a>>2]|0;if((e|0)<1114112){e=t[u>>2]|0;t[u>>2]=e+1;n[e>>0]=b>>18|240;t[c>>2]=12;break}Kp(0,9,64280,b);t[f>>2]=0;l=t[f>>2]|0;s=r;return l|0}while(0);while(1){if((t[c>>2]|0)<0)break;i=(t[a>>2]>>t[c>>2]&63|128)&255;b=t[u>>2]|0;t[u>>2]=b+1;n[b>>0]=i;t[c>>2]=(t[c>>2]|0)-6}t[f>>2]=(t[u>>2]|0)-(t[o>>2]|0);l=t[f>>2]|0;s=r;return l|0}function Np(e,i,r){e=e|0;i=i|0;r=r|0;var f=0,u=0,a=0,o=0;f=s;s=s+16|0;u=f+12|0;a=f+4|0;o=f;t[f+8>>2]=e;t[a>>2]=i;t[o>>2]=r;do if(t[a>>2]|0)if((t[o>>2]|0)>=128){t[u>>2]=Rp(t[a>>2]|0,t[o>>2]|0)|0;break}else{n[t[a>>2]>>0]=t[o>>2];t[u>>2]=1;break}else t[u>>2]=0;while(0);s=f;return t[u>>2]|0}function Tp(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,a=0,o=0,c=0,l=0;r=s;s=s+32|0;n=r+16|0;f=r+12|0;a=r+8|0;o=r+4|0;c=r;t[f>>2]=e;t[a>>2]=i;t[c>>2]=-1;if(!(t[f>>2]|0)){t[n>>2]=-1;l=t[n>>2]|0;s=r;return l|0}switch(t[a>>2]|0){case 1:{t[(t[f>>2]|0)+256>>2]=1;if((((t[(t[f>>2]|0)+36>>2]|0)!=0?(u[t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==239:0)?(u[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+1>>0]|0|0)==187:0)?(u[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+2>>0]|0|0)==191:0){i=(t[(t[f>>2]|0)+36>>2]|0)+16|0;t[i>>2]=(t[i>>2]|0)+3}t[n>>2]=0;l=t[n>>2]|0;s=r;return l|0}case 21:case 20:case 19:case 22:case 18:case 17:case 16:case 15:case 14:case 13:case 12:case 11:case 10:case 6:{t[c>>2]=45;break}case-1:{gp(t[f>>2]|0,31,64336,0,0);t[n>>2]=-1;l=t[n>>2]|0;s=r;return l|0}case 0:{t[(t[f>>2]|0)+256>>2]=1;t[n>>2]=0;l=t[n>>2]|0;s=r;return l|0}case 9:{t[c>>2]=90;break}case 8:case 7:case 4:case 5:{t[c>>2]=180;break}case 3:case 2:{if(((((t[(t[f>>2]|0)+36>>2]|0)!=0?(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)!=0:0)?(u[t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==239:0)?(u[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+1>>0]|0|0)==187:0)?(u[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+2>>0]|0|0)==191:0){i=(t[(t[f>>2]|0)+36>>2]|0)+16|0;t[i>>2]=(t[i>>2]|0)+3}t[c>>2]=90;break}default:{}}t[o>>2]=j_(t[a>>2]|0)|0;e:do if(!(t[o>>2]|0))do switch(t[a>>2]|0){case 8:{gp(t[f>>2]|0,32,64360,64456,0);break e;break}case 9:{gp(t[f>>2]|0,32,64360,64472,0);break e;break}case 7:{gp(t[f>>2]|0,32,64360,64440,0);break e;break}case 18:case 17:case 16:case 15:case 14:case 13:case 12:case 11:case 10:{if((((t[(t[f>>2]|0)+40>>2]|0)==1?(t[(t[f>>2]|0)+24>>2]|0)==0:0)?(t[(t[f>>2]|0)+36>>2]|0)!=0:0)?(t[(t[(t[f>>2]|0)+36>>2]|0)+44>>2]|0)!=0:0){i=Yl(t[(t[(t[f>>2]|0)+36>>2]|0)+44>>2]|0)|0;t[(t[f>>2]|0)+24>>2]=i}t[(t[f>>2]|0)+256>>2]=t[a>>2];t[n>>2]=0;l=t[n>>2]|0;s=r;return l|0}case 19:{gp(t[f>>2]|0,32,64360,64480,0);break e;break}case 20:{gp(t[f>>2]|0,32,64360,64496,0);break e;break}case 22:{t[(t[f>>2]|0)+256>>2]=1;t[n>>2]=0;l=t[n>>2]|0;s=r;return l|0}case 4:{gp(t[f>>2]|0,32,64360,64392,0);break e;break}case 5:{gp(t[f>>2]|0,32,64360,64416,0);break e;break}case 21:{gp(t[f>>2]|0,32,64360,64512,0);break e;break}case 6:{gp(t[f>>2]|0,32,64360,64432,0);break e;break}default:break e}while(0);while(0);if(!(t[o>>2]|0)){t[n>>2]=-1;l=t[n>>2]|0;s=r;return l|0}else{t[(t[f>>2]|0)+256>>2]=1;t[n>>2]=Xp(t[f>>2]|0,t[o>>2]|0,t[c>>2]|0)|0;l=t[n>>2]|0;s=r;return l|0}return 0}function Lp(e,i){e=e|0;i=i|0;var r=0,n=0,f=0;r=s;s=s+16|0;n=r+4|0;f=r;t[n>>2]=e;t[f>>2]=i;i=Xp(t[n>>2]|0,t[f>>2]|0,-1)|0;s=r;return i|0}function Dp(e){e=e|0;var i=0,r=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if(!(t[r>>2]|0)){s=i;return}if(t[(t[r>>2]|0)+4>>2]|0)pAi[t[135736>>2]&511](t[(t[r>>2]|0)+4>>2]|0);if(t[(t[r>>2]|0)+8>>2]|0)pAi[t[135736>>2]&511](t[(t[r>>2]|0)+8>>2]|0);if(t[(t[r>>2]|0)+44>>2]|0)pAi[t[135736>>2]&511](t[(t[r>>2]|0)+44>>2]|0);if(t[(t[r>>2]|0)+48>>2]|0)pAi[t[135736>>2]&511](t[(t[r>>2]|0)+48>>2]|0);if((t[(t[r>>2]|0)+40>>2]|0)!=0?(t[(t[r>>2]|0)+12>>2]|0)!=0:0)pAi[t[(t[r>>2]|0)+40>>2]&511](t[(t[r>>2]|0)+12>>2]|0);if(t[t[r>>2]>>2]|0)IO(t[t[r>>2]>>2]|0);pAi[t[135736>>2]&511](t[r>>2]|0);s=i;return}function Cp(e){e=e|0;var i=0,r=0,n=0,f=0,u=0,a=0;i=s;s=s+16|0;r=i+8|0;n=i+4|0;f=i;t[n>>2]=e;t[f>>2]=gAi[t[135744>>2]&511](60)|0;if(!(t[f>>2]|0)){Sp(t[n>>2]|0,64520);t[r>>2]=0;u=t[r>>2]|0;s=i;return u|0}e=(t[f>>2]|0)+0|0;a=e+60|0;do{t[e>>2]=0;e=e+4|0}while((e|0)<(a|0));t[(t[f>>2]|0)+28>>2]=1;t[(t[f>>2]|0)+32>>2]=1;t[(t[f>>2]|0)+52>>2]=-1;if(t[n>>2]|0){e=(t[n>>2]|0)+464|0;n=t[e>>2]|0;t[e>>2]=n+1;t[(t[f>>2]|0)+56>>2]=n}t[r>>2]=t[f>>2];u=t[r>>2]|0;s=i;return u|0}function Pp(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,l=0;n=s;s=s+32|0;f=n+20|0;u=n+16|0;a=n+12|0;o=n+8|0;c=n+4|0;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;if(!(t[a>>2]|0)){t[f>>2]=0;l=t[f>>2]|0;s=n;return l|0}if(t[33952]|0)yAi[t[135904>>2]&511](t[33980]|0,64560,n);t[c>>2]=Cp(t[u>>2]|0)|0;if(!(t[c>>2]|0)){t[f>>2]=0;l=t[f>>2]|0;s=n;return l|0}t[(t[c>>2]|0)+4>>2]=0;t[t[c>>2]>>2]=t[a>>2];zs(t[(t[t[c>>2]>>2]|0)+16>>2]|0,t[c>>2]|0)|0;if(t[o>>2]|0)Tp(t[u>>2]|0,t[o>>2]|0)|0;t[f>>2]=t[c>>2];l=t[f>>2]|0;s=n;return l|0}function Bp(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0;r=s;s=s+32|0;n=r;f=r+16|0;u=r+12|0;a=r+8|0;o=r+4|0;t[u>>2]=e;t[a>>2]=i;if(!(t[a>>2]|0)){Jp(t[u>>2]|0,64584,0);t[f>>2]=0;c=t[f>>2]|0;s=r;return c|0}if(t[33952]|0){i=t[33976]|0;e=t[33980]|0;t[n>>2]=t[(t[a>>2]|0)+8>>2];yAi[i&511](e,64624,n)}if(t[(t[a>>2]|0)+40>>2]|0){t[o>>2]=Cp(t[u>>2]|0)|0;if(!(t[o>>2]|0)){t[f>>2]=0;c=t[f>>2]|0;s=r;return c|0}if(t[(t[a>>2]|0)+64>>2]|0){n=Yl(t[(t[a>>2]|0)+64>>2]|0)|0;t[(t[o>>2]|0)+4>>2]=n}t[(t[o>>2]|0)+12>>2]=t[(t[a>>2]|0)+40>>2];t[(t[o>>2]|0)+16>>2]=t[(t[a>>2]|0)+40>>2];t[(t[o>>2]|0)+24>>2]=t[(t[a>>2]|0)+44>>2];t[(t[o>>2]|0)+20>>2]=(t[(t[a>>2]|0)+40>>2]|0)+(t[(t[o>>2]|0)+24>>2]|0);t[f>>2]=t[o>>2];c=t[f>>2]|0;s=r;return c|0}switch(t[(t[a>>2]|0)+48>>2]|0){case 4:{Jp(t[u>>2]|0,64720,t[(t[a>>2]|0)+8>>2]|0);break}case 1:{Jp(t[u>>2]|0,64680,t[(t[a>>2]|0)+8>>2]|0);break}case 6:{Jp(t[u>>2]|0,64768,t[(t[a>>2]|0)+8>>2]|0);break}case 3:{Jp(t[u>>2]|0,64656,t[(t[a>>2]|0)+8>>2]|0);break}case 5:case 2:{t[f>>2]=uA(t[(t[a>>2]|0)+64>>2]|0,t[(t[a>>2]|0)+52>>2]|0,t[u>>2]|0)|0;c=t[f>>2]|0;s=r;return c|0}default:{}}t[f>>2]=0;c=t[f>>2]|0;s=r;return c|0}function Ip(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0;r=s;s=s+32|0;n=r;f=r+28|0;u=r+24|0;a=r+20|0;o=r+16|0;c=r+12|0;l=r+8|0;b=r+4|0;t[u>>2]=e;t[a>>2]=i;t[l>>2]=0;t[b>>2]=0;if(t[33952]|0){i=t[33976]|0;e=t[33980]|0;t[n>>2]=t[a>>2];yAi[i&511](e,64808,n)}if(!(t[u>>2]|0)){t[f>>2]=0;k=t[f>>2]|0;s=r;return k|0}t[o>>2]=zO(t[a>>2]|0,0)|0;if(!(t[o>>2]|0)){n=t[u>>2]|0;if(!(t[a>>2]|0))EO(n,64840,0);else EO(n,64888,t[a>>2]|0);t[f>>2]=0;k=t[f>>2]|0;s=r;return k|0}t[c>>2]=Cp(t[u>>2]|0)|0;if(!(t[c>>2]|0)){t[f>>2]=0;k=t[f>>2]|0;s=r;return k|0}t[t[c>>2]>>2]=t[o>>2];t[c>>2]=nA(t[u>>2]|0,t[c>>2]|0)|0;if(!(t[c>>2]|0)){t[f>>2]=0;k=t[f>>2]|0;s=r;return k|0}if(!(t[(t[c>>2]|0)+4>>2]|0))t[b>>2]=Yl(t[a>>2]|0)|0;else t[b>>2]=Yl(t[(t[c>>2]|0)+4>>2]|0)|0;t[l>>2]=rA(t[b>>2]|0)|0;if(t[(t[c>>2]|0)+4>>2]|0)pAi[t[135736>>2]&511](t[(t[c>>2]|0)+4>>2]|0);a=KA(t[b>>2]|0)|0;t[(t[c>>2]|0)+4>>2]=a;if(t[b>>2]|0)pAi[t[135736>>2]&511](t[b>>2]|0);t[(t[c>>2]|0)+8>>2]=t[l>>2];zs(t[(t[t[c>>2]>>2]|0)+16>>2]|0,t[c>>2]|0)|0;if((t[l>>2]|0)!=0?(t[(t[u>>2]|0)+180>>2]|0)==0:0){b=Yl(t[l>>2]|0)|0;t[(t[u>>2]|0)+180>>2]=b}t[f>>2]=t[c>>2];k=t[f>>2]|0;s=r;return k|0}function Hp(e){e=e|0;var i=0,r=0,n=0,f=0,u=0;i=s;s=s+16|0;r=i+8|0;n=i+4|0;f=i;t[n>>2]=e;if(!(t[n>>2]|0)){Jp(0,64928,0);t[r>>2]=-1;u=t[r>>2]|0;s=i;return u|0}rj();if(!(t[(t[n>>2]|0)+296>>2]|0)){e=lz()|0;t[(t[n>>2]|0)+296>>2]=e}if(!(t[(t[n>>2]|0)+296>>2]|0)){Sp(0,64960);t[r>>2]=-1;u=t[r>>2]|0;s=i;return u|0}dz(t[(t[n>>2]|0)+296>>2]|0,1e7)|0;if(!(t[t[n>>2]>>2]|0)){e=gAi[t[135744>>2]&511](128)|0;t[t[n>>2]>>2]=e}if(!(t[t[n>>2]>>2]|0)){Sp(0,64960);t[r>>2]=-1;u=t[r>>2]|0;s=i;return u|0}ij(t[t[n>>2]>>2]|0,2)|0;t[(t[n>>2]|0)+304>>2]=0;t[(t[n>>2]|0)+300>>2]=0;if(!(t[(t[n>>2]|0)+48>>2]|0)){e=gAi[t[135744>>2]&511](20)|0;t[(t[n>>2]|0)+48>>2]=e;t[(t[n>>2]|0)+44>>2]=5}if(!(t[(t[n>>2]|0)+48>>2]|0)){Sp(0,64960);t[(t[n>>2]|0)+40>>2]=0;t[(t[n>>2]|0)+44>>2]=0;t[(t[n>>2]|0)+36>>2]=0;t[r>>2]=-1;u=t[r>>2]|0;s=i;return u|0}while(1){e=iE(t[n>>2]|0)|0;t[f>>2]=e;if(!e)break;Dp(t[f>>2]|0)}t[(t[n>>2]|0)+40>>2]=0;t[(t[n>>2]|0)+36>>2]=0;t[(t[n>>2]|0)+20>>2]=0;t[(t[n>>2]|0)+24>>2]=0;t[(t[n>>2]|0)+28>>2]=-1;t[(t[n>>2]|0)+88>>2]=0;t[(t[n>>2]|0)+92>>2]=0;t[(t[n>>2]|0)+32>>2]=0;t[(t[n>>2]|0)+96>>2]=0;t[(t[n>>2]|0)+172>>2]=0;t[(t[n>>2]|0)+176>>2]=0;t[(t[n>>2]|0)+180>>2]=0;if(!(t[(t[n>>2]|0)+64>>2]|0)){f=gAi[t[135744>>2]&511](40)|0;t[(t[n>>2]|0)+64>>2]=f;t[(t[n>>2]|0)+60>>2]=10}if(!(t[(t[n>>2]|0)+64>>2]|0)){Sp(0,64960);t[(t[n>>2]|0)+56>>2]=0;t[(t[n>>2]|0)+60>>2]=0;t[(t[n>>2]|0)+52>>2]=0;t[(t[n>>2]|0)+40>>2]=0;t[(t[n>>2]|0)+44>>2]=0;t[(t[n>>2]|0)+36>>2]=0;t[r>>2]=-1;u=t[r>>2]|0;s=i;return u|0}t[(t[n>>2]|0)+56>>2]=0;t[(t[n>>2]|0)+52>>2]=0;if(!(t[(t[n>>2]|0)+196>>2]|0)){f=gAi[t[135744>>2]&511](40)|0;t[(t[n>>2]|0)+196>>2]=f;t[(t[n>>2]|0)+192>>2]=10}if(!(t[(t[n>>2]|0)+196>>2]|0)){Sp(0,64960);t[(t[n>>2]|0)+56>>2]=0;t[(t[n>>2]|0)+60>>2]=0;t[(t[n>>2]|0)+52>>2]=0;t[(t[n>>2]|0)+40>>2]=0;t[(t[n>>2]|0)+44>>2]=0;t[(t[n>>2]|0)+36>>2]=0;t[(t[n>>2]|0)+188>>2]=0;t[(t[n>>2]|0)+192>>2]=0;t[(t[n>>2]|0)+184>>2]=0;t[r>>2]=-1;u=t[r>>2]|0;s=i;return u|0}t[(t[n>>2]|0)+188>>2]=0;t[(t[n>>2]|0)+184>>2]=0;if(!(t[(t[n>>2]|0)+244>>2]|0)){f=gAi[t[135744>>2]&511](40)|0;t[(t[n>>2]|0)+244>>2]=f;t[(t[n>>2]|0)+240>>2]=10}if(!(t[(t[n>>2]|0)+244>>2]|0)){Sp(0,64960);t[(t[n>>2]|0)+56>>2]=0;t[(t[n>>2]|0)+60>>2]=0;t[(t[n>>2]|0)+52>>2]=0;t[(t[n>>2]|0)+40>>2]=0;t[(t[n>>2]|0)+44>>2]=0;t[(t[n>>2]|0)+36>>2]=0;t[(t[n>>2]|0)+188>>2]=0;t[(t[n>>2]|0)+192>>2]=0;t[(t[n>>2]|0)+184>>2]=0;t[(t[n>>2]|0)+236>>2]=0;t[(t[n>>2]|0)+240>>2]=0;t[(t[n>>2]|0)+232>>2]=0;t[r>>2]=-1;u=t[r>>2]|0;s=i;return u|0}t[(t[n>>2]|0)+236>>2]=1;t[(t[n>>2]|0)+240>>2]=10;t[t[(t[n>>2]|0)+244>>2]>>2]=-1;t[(t[n>>2]|0)+232>>2]=t[(t[n>>2]|0)+244>>2];t[(t[n>>2]|0)+4>>2]=t[n>>2];t[(t[n>>2]|0)+8>>2]=0;t[(t[n>>2]|0)+12>>2]=1;t[(t[n>>2]|0)+356>>2]=1;t[(t[n>>2]|0)+100>>2]=1;t[(t[n>>2]|0)+276>>2]=t[33958];if(t[(t[n>>2]|0)+276>>2]|0){f=(t[n>>2]|0)+360|0;t[f>>2]=t[f>>2]|4}t[(t[n>>2]|0)+104>>2]=t[33954];t[(t[n>>2]|0)+268>>2]=t[33960];if(t[(t[n>>2]|0)+268>>2]|0){f=(t[n>>2]|0)+360|0;t[f>>2]=t[f>>2]|128}t[(t[n>>2]|0)+280>>2]=t[33962];t[(t[n>>2]|0)+208>>2]=t[33964];if(!(t[(t[n>>2]|0)+208>>2]|0)){t[(t[t[n>>2]>>2]|0)+72>>2]=65;f=(t[n>>2]|0)+360|0;t[f>>2]=t[f>>2]|256}t[(t[n>>2]|0)+136>>2]=-1412623820;t[(t[n>>2]|0)+108>>2]=t[n>>2];t[(t[n>>2]|0)+112>>2]=224;t[(t[n>>2]|0)+116>>2]=225;if(t[(t[n>>2]|0)+104>>2]|0){f=(t[n>>2]|0)+116|0;if(!(t[33956]|0))t[f>>2]=0;else t[f>>2]=225;t[(t[n>>2]|0)+128>>2]=0;f=(t[n>>2]|0)+360|0;t[f>>2]=t[f>>2]|16}t[(t[n>>2]|0)+16>>2]=t[33966];if(t[(t[n>>2]|0)+16>>2]|0){f=(t[n>>2]|0)+360|0;t[f>>2]=t[f>>2]|2}t[(t[n>>2]|0)+68>>2]=0;t[(t[n>>2]|0)+200>>2]=0;t[(t[n>>2]|0)+204>>2]=0;t[(t[n>>2]|0)+216>>2]=0;t[(t[n>>2]|0)+84>>2]=0;t[(t[n>>2]|0)+248>>2]=0;t[(t[n>>2]|0)+256>>2]=1;t[(t[n>>2]|0)+284>>2]=0;t[(t[n>>2]|0)+440>>2]=0;t[(t[n>>2]|0)+444>>2]=0;t[(t[n>>2]|0)+468>>2]=0;t[(t[n>>2]|0)+464>>2]=1;xp((t[n>>2]|0)+72|0);t[r>>2]=0;u=t[r>>2]|0;s=i;return u|0}function xp(e){e=e|0;var i=0,r=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if(!(t[r>>2]|0)){s=i;return}t[(t[r>>2]|0)+4>>2]=0;t[t[r>>2]>>2]=0;t[(t[r>>2]|0)+8>>2]=0;s=i;return}function Up(e){e=e|0;var i=0,r=0,n=0,f=0,u=0,a=0,o=0;i=s;s=s+32|0;r=i+20|0;n=i+16|0;f=i+12|0;u=i+8|0;a=i+4|0;o=i;t[r>>2]=e;if(!(t[r>>2]|0)){s=i;return}while(1){e=iE(t[r>>2]|0)|0;t[n>>2]=e;if(!e)break;Dp(t[n>>2]|0)}if(t[(t[r>>2]|0)+244>>2]|0)pAi[t[135736>>2]&511](t[(t[r>>2]|0)+244>>2]|0);if(t[(t[r>>2]|0)+196>>2]|0)pAi[t[135736>>2]&511](t[(t[r>>2]|0)+196>>2]|0);if(t[(t[r>>2]|0)+64>>2]|0)pAi[t[135736>>2]&511](t[(t[r>>2]|0)+64>>2]|0);
	if(t[(t[r>>2]|0)+460>>2]|0)pAi[t[135736>>2]&511](t[(t[r>>2]|0)+460>>2]|0);if(t[(t[r>>2]|0)+48>>2]|0)pAi[t[135736>>2]&511](t[(t[r>>2]|0)+48>>2]|0);if(t[(t[r>>2]|0)+20>>2]|0)pAi[t[135736>>2]&511](t[(t[r>>2]|0)+20>>2]|0);if(t[(t[r>>2]|0)+24>>2]|0)pAi[t[135736>>2]&511](t[(t[r>>2]|0)+24>>2]|0);if(t[(t[r>>2]|0)+224>>2]|0)pAi[t[135736>>2]&511](t[(t[r>>2]|0)+224>>2]|0);if(t[(t[r>>2]|0)+228>>2]|0)pAi[t[135736>>2]&511](t[(t[r>>2]|0)+228>>2]|0);if((t[t[r>>2]>>2]|0)!=0?(t[t[r>>2]>>2]|0)!=135968:0)pAi[t[135736>>2]&511](t[t[r>>2]>>2]|0);if(t[(t[r>>2]|0)+180>>2]|0)pAi[t[135736>>2]&511](t[(t[r>>2]|0)+180>>2]|0);if(t[(t[r>>2]|0)+132>>2]|0)pAi[t[135736>>2]&511](t[(t[r>>2]|0)+132>>2]|0);if(t[(t[r>>2]|0)+300>>2]|0)pAi[t[135736>>2]&511](t[(t[r>>2]|0)+300>>2]|0);if(t[(t[r>>2]|0)+296>>2]|0)bz(t[(t[r>>2]|0)+296>>2]|0);if(t[(t[r>>2]|0)+336>>2]|0)pAi[t[135736>>2]&511](t[(t[r>>2]|0)+336>>2]|0);if(t[(t[r>>2]|0)+344>>2]|0)pAi[t[135736>>2]&511](t[(t[r>>2]|0)+344>>2]|0);if(t[(t[r>>2]|0)+340>>2]|0)pAi[t[135736>>2]&511](t[(t[r>>2]|0)+340>>2]|0);if(t[(t[r>>2]|0)+348>>2]|0)XF(t[(t[r>>2]|0)+348>>2]|0,t[33934]|0);if(t[(t[r>>2]|0)+352>>2]|0)XF(t[(t[r>>2]|0)+352>>2]|0,0);e:do if(t[(t[r>>2]|0)+372>>2]|0){t[f>>2]=t[(t[r>>2]|0)+372>>2];while(1){if(!(t[f>>2]|0))break e;t[u>>2]=t[(t[f>>2]|0)+24>>2];pAi[t[135736>>2]&511](t[f>>2]|0);t[f>>2]=t[u>>2]}}while(0);e:do if(t[(t[r>>2]|0)+380>>2]|0){t[a>>2]=t[(t[r>>2]|0)+380>>2];while(1){if(!(t[a>>2]|0))break e;t[o>>2]=t[(t[a>>2]|0)+24>>2];pAi[t[135736>>2]&511](t[a>>2]|0);t[a>>2]=t[o>>2]}}while(0);if(t[(t[r>>2]|0)+392>>2]|0)pAi[t[135736>>2]&511](t[(t[r>>2]|0)+392>>2]|0);if(t[(t[r>>2]|0)+400>>2]|0)pAi[t[135736>>2]&511](t[(t[r>>2]|0)+400>>2]|0);if(t[(t[r>>2]|0)+408>>2]|0)pAi[t[135736>>2]&511](t[(t[r>>2]|0)+408>>2]|0);if(t[(t[r>>2]|0)+412>>2]|0)pAi[t[135736>>2]&511](t[(t[r>>2]|0)+412>>2]|0);if(t[(t[r>>2]|0)+416>>2]|0)pAi[t[135736>>2]&511](t[(t[r>>2]|0)+416>>2]|0);if(t[(t[r>>2]|0)+284>>2]|0)bc(t[(t[r>>2]|0)+284>>2]|0);pAi[t[135736>>2]&511](t[r>>2]|0);s=i;return}function zp(){var e=0,i=0,r=0,n=0,f=0;e=s;s=s+16|0;i=e+4|0;r=e;t[r>>2]=gAi[t[135744>>2]&511](472)|0;do if(t[r>>2]|0){VY(t[r>>2]|0,0,472)|0;n=(Hp(t[r>>2]|0)|0)<0;f=t[r>>2]|0;if(n){Up(f);t[i>>2]=0;break}else{t[i>>2]=f;break}}else{Sp(0,65e3);t[i>>2]=0}while(0);s=e;return t[i>>2]|0}function jp(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0;r=s;s=s+32|0;n=r+24|0;f=r+20|0;u=r+16|0;a=r+12|0;o=r+8|0;c=r+4|0;l=r;t[f>>2]=e;t[u>>2]=i;t[l>>2]=0;if((t[f>>2]|0)==0|(t[u>>2]|0)==0){t[n>>2]=-1;b=t[n>>2]|0;s=r;return b|0}t[o>>2]=1;t[a>>2]=t[(t[f>>2]|0)+4>>2];t[c>>2]=0;while(1){if((t[o>>2]|0)>>>0>(t[a>>2]|0)>>>0)break;if(!((t[l>>2]|0)!=0^1))break;t[c>>2]=(t[o>>2]|0)+((((t[a>>2]|0)-(t[o>>2]|0)|0)>>>0)/2|0);if((t[u>>2]|0)==(t[(t[(t[f>>2]|0)+8>>2]|0)+(((t[c>>2]|0)-1|0)*20|0)>>2]|0)){t[l>>2]=1;continue}i=t[c>>2]|0;if((t[u>>2]|0)>>>0<(t[(t[(t[f>>2]|0)+8>>2]|0)+(((t[c>>2]|0)-1|0)*20|0)>>2]|0)>>>0){t[a>>2]=i-1;continue}else{t[o>>2]=i+1;continue}}if((t[c>>2]|0)!=0?(t[(t[(t[f>>2]|0)+8>>2]|0)+(((t[c>>2]|0)-1|0)*20|0)>>2]|0)>>>0>=(t[u>>2]|0)>>>0:0){t[n>>2]=(t[c>>2]|0)-1;b=t[n>>2]|0;s=r;return b|0}t[n>>2]=t[c>>2];b=t[n>>2]|0;s=r;return b|0}function Vp(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0;r=s;s=s+32|0;n=r+20|0;f=r+16|0;u=r+12|0;a=r+8|0;o=r+4|0;c=r;t[n>>2]=e;t[f>>2]=i;if((t[n>>2]|0)==0|(t[f>>2]|0)==0){s=r;return}t[u>>2]=jp((t[n>>2]|0)+72|0,t[t[f>>2]>>2]|0)|0;if(((t[u>>2]|0)>>>0<(t[(t[n>>2]|0)+76>>2]|0)>>>0?(t[(t[n>>2]|0)+80>>2]|0)!=0:0)?(t[(t[(t[n>>2]|0)+80>>2]|0)+((t[u>>2]|0)*20|0)>>2]|0)==(t[t[f>>2]>>2]|0):0){i=(t[(t[n>>2]|0)+80>>2]|0)+((t[u>>2]|0)*20|0)|0;e=t[f>>2]|0;t[i+0>>2]=t[e+0>>2];t[i+4>>2]=t[e+4>>2];t[i+8>>2]=t[e+8>>2];t[i+12>>2]=t[e+12>>2];t[i+16>>2]=t[e+16>>2];s=r;return}if(!(((t[(t[n>>2]|0)+76>>2]|0)+1|0)>>>0<=(t[(t[n>>2]|0)+72>>2]|0)>>>0?(t[(t[n>>2]|0)+80>>2]|0)!=0:0))l=8;do if((l|0)==8){if(!(t[(t[n>>2]|0)+72>>2]|0))t[(t[n>>2]|0)+72>>2]=2;t[o>>2]=(t[(t[n>>2]|0)+72>>2]<<1)*20;if(!(t[(t[n>>2]|0)+80>>2]|0))t[a>>2]=gAi[t[135744>>2]&511](t[o>>2]|0)|0;else t[a>>2]=MAi[t[135760>>2]&511](t[(t[n>>2]|0)+80>>2]|0,t[o>>2]|0)|0;if(t[a>>2]|0){t[(t[n>>2]|0)+80>>2]=t[a>>2];e=(t[n>>2]|0)+72|0;t[e>>2]=t[e>>2]<<1;break}Sp(t[n>>2]|0,65032);s=r;return}while(0);e:do if((t[u>>2]|0)!=(t[(t[n>>2]|0)+76>>2]|0)){t[c>>2]=t[(t[n>>2]|0)+76>>2];while(1){if((t[c>>2]|0)>>>0<=(t[u>>2]|0)>>>0)break e;a=(t[(t[n>>2]|0)+80>>2]|0)+((t[c>>2]|0)*20|0)|0;o=(t[(t[n>>2]|0)+80>>2]|0)+(((t[c>>2]|0)-1|0)*20|0)|0;t[a+0>>2]=t[o+0>>2];t[a+4>>2]=t[o+4>>2];t[a+8>>2]=t[o+8>>2];t[a+12>>2]=t[o+12>>2];t[a+16>>2]=t[o+16>>2];t[c>>2]=(t[c>>2]|0)+-1}}while(0);c=(t[(t[n>>2]|0)+80>>2]|0)+((t[u>>2]|0)*20|0)|0;u=t[f>>2]|0;t[c+0>>2]=t[u+0>>2];t[c+4>>2]=t[u+4>>2];t[c+8>>2]=t[u+8>>2];t[c+12>>2]=t[u+12>>2];t[c+16>>2]=t[u+16>>2];u=(t[n>>2]|0)+76|0;t[u>>2]=(t[u>>2]|0)+1;s=r;return}function qp(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i+4|0;n=i;t[r>>2]=e;t[n>>2]=t[33960];t[33960]=t[r>>2];s=i;return t[n>>2]|0}function Yp(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i+4|0;n=i;t[r>>2]=e;t[n>>2]=t[33962];t[33962]=t[r>>2];s=i;return t[n>>2]|0}function Gp(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i+4|0;n=i;t[r>>2]=e;t[n>>2]=t[33966];t[33966]=t[r>>2];s=i;return t[n>>2]|0}function Wp(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i+4|0;n=i;t[r>>2]=e;t[n>>2]=t[33964];t[33964]=t[r>>2];if(!(t[r>>2]|0))t[33984]=1;s=i;return t[n>>2]|0}function Kp(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,u=0,a=0,o=0,c=0,l=0;f=s;s=s+32|0;u=f;a=f+16|0;o=f+12|0;c=f+8|0;l=f+4|0;t[a>>2]=e;t[o>>2]=i;t[c>>2]=r;t[l>>2]=n;if(((t[a>>2]|0)!=0?(t[(t[a>>2]|0)+212>>2]|0)!=0:0)?(t[(t[a>>2]|0)+172>>2]|0)==-1:0){s=f;return}if(t[a>>2]|0)t[(t[a>>2]|0)+84>>2]=t[o>>2];n=t[a>>2]|0;r=t[o>>2]|0;o=t[l>>2]|0;i=t[c>>2]|0;t[u>>2]=t[l>>2];cp(0,0,0,n,0,1,r,3,0,0,0,0,0,o,0,i,u);if(!(t[a>>2]|0)){s=f;return}t[(t[a>>2]|0)+12>>2]=0;if(t[(t[a>>2]|0)+288>>2]|0){s=f;return}t[(t[a>>2]|0)+212>>2]=1;s=f;return}function Xp(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,l=0;n=s;s=s+32|0;f=n+16|0;u=n+12|0;a=n+8|0;o=n+4|0;c=n;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;t[c>>2]=0;if(!(t[a>>2]|0)){t[f>>2]=-1;l=t[f>>2]|0;s=n;return l|0}r=t[u>>2]|0;if(t[(t[u>>2]|0)+36>>2]|0){t[c>>2]=Zp(r,t[(t[u>>2]|0)+36>>2]|0,t[a>>2]|0,t[o>>2]|0)|0;t[(t[u>>2]|0)+256>>2]=1;t[f>>2]=t[c>>2];l=t[f>>2]|0;s=n;return l|0}else{Jp(r,65064,0);t[f>>2]=-1;l=t[f>>2]|0;s=n;return l|0}return 0}function Zp(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0;f=s;s=s+32|0;a=f+28|0;o=f+24|0;c=f+20|0;l=f+16|0;b=f+12|0;k=f+8|0;h=f+4|0;w=f;t[o>>2]=e;t[c>>2]=i;t[l>>2]=r;t[b>>2]=n;if(!(t[l>>2]|0)){t[a>>2]=-1;d=t[a>>2]|0;s=f;return d|0}if(!(t[c>>2]|0)){t[a>>2]=-1;d=t[a>>2]|0;s=f;return d|0}n=t[c>>2]|0;if(!(t[t[c>>2]>>2]|0))if(!(t[n+24>>2]|0)){Jp(t[o>>2]|0,65184,0);t[a>>2]=-1;d=t[a>>2]|0;s=f;return d|0}else{t[a>>2]=0;d=t[a>>2]|0;s=f;return d|0}if(t[(t[n>>2]|0)+12>>2]|0)if((t[(t[t[c>>2]>>2]|0)+12>>2]|0)==(t[l>>2]|0)){t[a>>2]=0;d=t[a>>2]|0;s=f;return d|0}else{W_(t[(t[t[c>>2]>>2]|0)+12>>2]|0)|0;t[(t[t[c>>2]>>2]|0)+12>>2]=t[l>>2];t[a>>2]=0;d=t[a>>2]|0;s=f;return d|0}t[(t[t[c>>2]>>2]|0)+12>>2]=t[l>>2];do if(!(Ds(t[(t[t[c>>2]>>2]|0)+16>>2]|0)|0)){do if(t[t[l>>2]>>2]|0){if((MY(t[t[l>>2]>>2]|0,65096)|0)!=0?(MY(t[t[l>>2]>>2]|0,65112)|0)!=0:0)break;if((u[t[(t[c>>2]|0)+16>>2]>>0]|0|0)==255?(u[(t[(t[c>>2]|0)+16>>2]|0)+1>>0]|0|0)==254:0){n=(t[c>>2]|0)+16|0;t[n>>2]=(t[n>>2]|0)+2}}while(0);if((((t[t[l>>2]>>2]|0)!=0?(MY(t[t[l>>2]>>2]|0,65120)|0)==0:0)?(u[t[(t[c>>2]|0)+16>>2]>>0]|0|0)==254:0)?(u[(t[(t[c>>2]|0)+16>>2]|0)+1>>0]|0|0)==255:0){n=(t[c>>2]|0)+16|0;t[n>>2]=(t[n>>2]|0)+2}if(((((t[t[l>>2]>>2]|0)!=0?(MY(t[t[l>>2]>>2]|0,65136)|0)==0:0)?(u[t[(t[c>>2]|0)+16>>2]>>0]|0|0)==239:0)?(u[(t[(t[c>>2]|0)+16>>2]|0)+1>>0]|0|0)==187:0)?(u[(t[(t[c>>2]|0)+16>>2]|0)+2>>0]|0|0)==191:0){n=(t[c>>2]|0)+16|0;t[n>>2]=(t[n>>2]|0)+3}t[h>>2]=(t[(t[c>>2]|0)+16>>2]|0)-(t[(t[c>>2]|0)+12>>2]|0);ys(t[(t[t[c>>2]>>2]|0)+16>>2]|0,t[h>>2]|0)|0;t[(t[t[c>>2]>>2]|0)+20>>2]=t[(t[t[c>>2]>>2]|0)+16>>2];n=ds()|0;t[(t[t[c>>2]>>2]|0)+16>>2]=n;t[(t[t[c>>2]>>2]|0)+32>>2]=t[h>>2];t[w>>2]=Ts(t[(t[t[c>>2]>>2]|0)+20>>2]|0)|0;n=t[t[c>>2]>>2]|0;if(t[(t[o>>2]|0)+32>>2]|0)t[k>>2]=Y_(n,1)|0;else t[k>>2]=q_(n,t[b>>2]|0)|0;if((t[k>>2]|0)>=0){n=t[w>>2]|0;r=n-(Ts(t[(t[t[c>>2]>>2]|0)+20>>2]|0)|0)|0;n=(t[t[c>>2]>>2]|0)+32|0;t[n>>2]=(t[n>>2]|0)+r;zs(t[(t[t[c>>2]>>2]|0)+16>>2]|0,t[c>>2]|0)|0;break}Jp(t[o>>2]|0,65144,0);t[a>>2]=-1;d=t[a>>2]|0;s=f;return d|0}while(0);t[a>>2]=0;d=t[a>>2]|0;s=f;return d|0}function Jp(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0;n=s;s=s+16|0;f=n;u=n+12|0;a=n+8|0;o=n+4|0;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;if(((t[u>>2]|0)!=0?(t[(t[u>>2]|0)+212>>2]|0)!=0:0)?(t[(t[u>>2]|0)+172>>2]|0)==-1:0){s=n;return}if(t[u>>2]|0)t[(t[u>>2]|0)+84>>2]=1;r=t[u>>2]|0;i=t[o>>2]|0;e=t[a>>2]|0;t[f>>2]=t[o>>2];cp(0,0,0,r,0,1,1,3,0,0,i,0,0,0,0,e,f);if(!(t[u>>2]|0)){s=n;return}t[(t[u>>2]|0)+12>>2]=0;if(t[(t[u>>2]|0)+288>>2]|0){s=n;return}t[(t[u>>2]|0)+212>>2]=1;s=n;return}function Qp(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i+4|0;n=i;t[n>>2]=e;do switch(t[n>>2]|0){case 21:{t[r>>2]=1;break}case 18:{t[r>>2]=1;break}case 30:{t[r>>2]=0;break}case 29:{t[r>>2]=0;break}case 33:{t[r>>2]=0;break}case 10:{t[r>>2]=0;break}case 16:{t[r>>2]=1;break}case 14:{t[r>>2]=1;break}case 28:{t[r>>2]=1;break}case 8:{t[r>>2]=1;break}case 15:{t[r>>2]=1;break}case 27:{t[r>>2]=1;break}case 13:{t[r>>2]=1;break}case 20:{t[r>>2]=1;break}case 3:{t[r>>2]=1;break}case 17:{t[r>>2]=1;break}case 4:{t[r>>2]=1;break}case 12:{t[r>>2]=1;break}case 2:{t[r>>2]=1;break}case 11:{t[r>>2]=1;break}case 19:{t[r>>2]=1;break}case 9:{t[r>>2]=0;break}case 24:{t[r>>2]=1;break}case 26:{t[r>>2]=1;break}case 1:{t[r>>2]=0;break}case 22:{t[r>>2]=1;break}case 5:{t[r>>2]=1;break}case 23:{t[r>>2]=1;break}case 32:{t[r>>2]=0;break}case 25:{t[r>>2]=1;break}case 6:{t[r>>2]=1;break}case 31:{t[r>>2]=0;break}case 7:{t[r>>2]=1;break}default:t[r>>2]=0}while(0);s=i;return t[r>>2]|0}function $p(e){e=e|0;var i=0,r=0,n=0,f=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0,S=0;i=s;s=s+16|0;r=i+12|0;n=i+8|0;f=i+4|0;a=i;t[n>>2]=e;t[f>>2]=t[n>>2];if(!(t[f>>2]|0)){t[r>>2]=0;o=t[r>>2]|0;s=i;return o|0}if(!((u[t[f>>2]>>0]|0|0)==105?(u[(t[f>>2]|0)+1>>0]|0|0)==45:0))c=5;do if((c|0)==5){if((u[t[f>>2]>>0]|0|0)==73?(u[(t[f>>2]|0)+1>>0]|0|0)==45:0)break;if((u[t[f>>2]>>0]|0|0)==120?(u[(t[f>>2]|0)+1>>0]|0|0)==45:0)break;if((u[t[f>>2]>>0]|0|0)==88?(u[(t[f>>2]|0)+1>>0]|0|0)==45:0)break;t[a>>2]=t[f>>2];while(1){if((u[t[a>>2]>>0]|0|0)>=65?(u[t[a>>2]>>0]|0|0)<=90:0)l=1;else if((u[t[a>>2]>>0]|0|0)>=97)l=(u[t[a>>2]>>0]|0|0)<=122;else l=0;b=t[a>>2]|0;if(!l)break;t[a>>2]=b+1}n=(t[a>>2]|0)-(t[f>>2]|0)|0;if((b-(t[f>>2]|0)|0)>=4){if((n|0)<=8?(u[t[a>>2]>>0]|0|0)==0:0){t[r>>2]=1;o=t[r>>2]|0;s=i;return o|0}t[r>>2]=0;o=t[r>>2]|0;s=i;return o|0}if((n|0)<2){t[r>>2]=0;o=t[r>>2]|0;s=i;return o|0}if(!(u[t[a>>2]>>0]|0)){t[r>>2]=1;o=t[r>>2]|0;s=i;return o|0}if((u[t[a>>2]>>0]|0|0)!=45){t[r>>2]=0;o=t[r>>2]|0;s=i;return o|0}t[a>>2]=(t[a>>2]|0)+1;t[f>>2]=t[a>>2];if((u[t[a>>2]>>0]|0|0)>=48?(u[t[a>>2]>>0]|0|0)<=57:0)c=103;else c=39;e:do if((c|0)==39){while(1){c=0;if((u[t[a>>2]>>0]|0|0)>=65?(u[t[a>>2]>>0]|0|0)<=90:0)k=1;else if((u[t[a>>2]>>0]|0|0)>=97)k=(u[t[a>>2]>>0]|0|0)<=122;else k=0;h=t[a>>2]|0;if(!k)break;t[a>>2]=h+1;c=39}do if((h-(t[f>>2]|0)|0)!=4){if(((t[a>>2]|0)-(t[f>>2]|0)|0)==2){c=84;break e}if(((t[a>>2]|0)-(t[f>>2]|0)|0)>=5?((t[a>>2]|0)-(t[f>>2]|0)|0)<=8:0)break e;if(((t[a>>2]|0)-(t[f>>2]|0)|0)!=3){t[r>>2]=0;o=t[r>>2]|0;s=i;return o|0}if(!(u[t[a>>2]>>0]|0)){t[r>>2]=1;o=t[r>>2]|0;s=i;return o|0}if((u[t[a>>2]>>0]|0|0)!=45){t[r>>2]=0;o=t[r>>2]|0;s=i;return o|0}t[a>>2]=(t[a>>2]|0)+1;t[f>>2]=t[a>>2];if((u[t[a>>2]>>0]|0|0)>=48?(u[t[a>>2]>>0]|0|0)<=57:0){c=103;break e}while(1){if((u[t[a>>2]>>0]|0|0)>=65?(u[t[a>>2]>>0]|0|0)<=90:0)w=1;else c=59;do if((c|0)==59){c=0;if((u[t[a>>2]>>0]|0|0)<97){w=0;break}w=(u[t[a>>2]>>0]|0|0)<=122}while(0);d=t[a>>2]|0;if(!w)break;t[a>>2]=d+1}if((d-(t[f>>2]|0)|0)==2){c=84;break e}if(((t[a>>2]|0)-(t[f>>2]|0)|0)>=5?((t[a>>2]|0)-(t[f>>2]|0)|0)<=8:0)break e;if(((t[a>>2]|0)-(t[f>>2]|0)|0)==4)break;t[r>>2]=0;o=t[r>>2]|0;s=i;return o|0}while(0);if(!(u[t[a>>2]>>0]|0)){t[r>>2]=1;o=t[r>>2]|0;s=i;return o|0}if((u[t[a>>2]>>0]|0|0)!=45){t[r>>2]=0;o=t[r>>2]|0;s=i;return o|0}t[a>>2]=(t[a>>2]|0)+1;t[f>>2]=t[a>>2];if((u[t[a>>2]>>0]|0|0)>=48?(u[t[a>>2]>>0]|0|0)<=57:0){c=103;break}while(1){if((u[t[a>>2]>>0]|0|0)>=65?(u[t[a>>2]>>0]|0|0)<=90:0)v=1;else if((u[t[a>>2]>>0]|0|0)>=97)v=(u[t[a>>2]>>0]|0|0)<=122;else v=0;m=t[a>>2]|0;if(!v)break;t[a>>2]=m+1}if((m-(t[f>>2]|0)|0)>=5?((t[a>>2]|0)-(t[f>>2]|0)|0)<=8:0)break;if(((t[a>>2]|0)-(t[f>>2]|0)|0)!=2){t[r>>2]=0;o=t[r>>2]|0;s=i;return o|0}else c=84}while(0);do if((c|0)==103){if((((u[(t[a>>2]|0)+1>>0]|0|0)>=48?(u[(t[a>>2]|0)+1>>0]|0|0)<=57:0)?(u[(t[a>>2]|0)+2>>0]|0|0)>=48:0)?(u[(t[a>>2]|0)+2>>0]|0|0)<=57:0){t[a>>2]=(t[a>>2]|0)+3;c=84;break}t[r>>2]=0;o=t[r>>2]|0;s=i;return o|0}while(0);do if((c|0)==84){if(!(u[t[a>>2]>>0]|0)){t[r>>2]=1;o=t[r>>2]|0;s=i;return o|0}if((u[t[a>>2]>>0]|0|0)!=45){t[r>>2]=0;o=t[r>>2]|0;s=i;return o|0}t[a>>2]=(t[a>>2]|0)+1;t[f>>2]=t[a>>2];while(1){if((u[t[a>>2]>>0]|0|0)>=65?(u[t[a>>2]>>0]|0|0)<=90:0)_=1;else if((u[t[a>>2]>>0]|0|0)>=97)_=(u[t[a>>2]>>0]|0|0)<=122;else _=0;p=t[a>>2]|0;if(!_)break;t[a>>2]=p+1}if((p-(t[f>>2]|0)|0)>=5?((t[a>>2]|0)-(t[f>>2]|0)|0)<=8:0)break;t[r>>2]=0;o=t[r>>2]|0;s=i;return o|0}while(0);if(!(u[t[a>>2]>>0]|0)){t[r>>2]=1;o=t[r>>2]|0;s=i;return o|0}if((u[t[a>>2]>>0]|0|0)!=45){t[r>>2]=0;o=t[r>>2]|0;s=i;return o|0}else{t[r>>2]=1;o=t[r>>2]|0;s=i;return o|0}}while(0);t[f>>2]=(t[f>>2]|0)+2;while(1){if((u[t[f>>2]>>0]|0|0)>=65?(u[t[f>>2]>>0]|0|0)<=90:0)E=1;else if((u[t[f>>2]>>0]|0|0)>=97)E=(u[t[f>>2]>>0]|0|0)<=122;else E=0;S=t[f>>2]|0;if(!E)break;t[f>>2]=S+1}t[r>>2]=(u[S>>0]|0|0)==0&1;o=t[r>>2]|0;s=i;return o|0}function eE(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0;r=s;s=s+16|0;n=r+8|0;f=r+4|0;u=r;t[f>>2]=e;t[u>>2]=i;if((t[f>>2]|0)==0|(t[u>>2]|0)==0){t[n>>2]=-1;a=t[n>>2]|0;s=r;return a|0}if((t[(t[f>>2]|0)+40>>2]|0)>=(t[(t[f>>2]|0)+44>>2]|0)?(i=(t[f>>2]|0)+44|0,t[i>>2]=t[i>>2]<<1,i=MAi[t[135760>>2]&511](t[(t[f>>2]|0)+48>>2]|0,t[(t[f>>2]|0)+44>>2]<<2)|0,t[(t[f>>2]|0)+48>>2]=i,(t[(t[f>>2]|0)+48>>2]|0)==0):0){Sp(t[f>>2]|0,0);Dp(t[u>>2]|0);i=(t[f>>2]|0)+44|0;t[i>>2]=(t[i>>2]|0)/2|0;t[u>>2]=0;t[n>>2]=-1;a=t[n>>2]|0;s=r;return a|0}t[(t[(t[f>>2]|0)+48>>2]|0)+(t[(t[f>>2]|0)+40>>2]<<2)>>2]=t[u>>2];t[(t[f>>2]|0)+36>>2]=t[u>>2];u=(t[f>>2]|0)+40|0;f=t[u>>2]|0;t[u>>2]=f+1;t[n>>2]=f;a=t[n>>2]|0;s=r;return a|0}function iE(e){e=e|0;var i=0,r=0,n=0,f=0,u=0;i=s;s=s+16|0;r=i+8|0;n=i+4|0;f=i;t[n>>2]=e;if(!(t[n>>2]|0)){t[r>>2]=0;u=t[r>>2]|0;s=i;return u|0}if((t[(t[n>>2]|0)+40>>2]|0)<=0){t[r>>2]=0;u=t[r>>2]|0;s=i;return u|0}e=(t[n>>2]|0)+40|0;t[e>>2]=(t[e>>2]|0)+-1;e=t[n>>2]|0;if((t[(t[n>>2]|0)+40>>2]|0)>0)t[(t[n>>2]|0)+36>>2]=t[(t[(t[n>>2]|0)+48>>2]|0)+((t[e+40>>2]|0)-1<<2)>>2];else t[e+36>>2]=0;t[f>>2]=t[(t[(t[n>>2]|0)+48>>2]|0)+(t[(t[n>>2]|0)+40>>2]<<2)>>2];t[(t[(t[n>>2]|0)+48>>2]|0)+(t[(t[n>>2]|0)+40>>2]<<2)>>2]=0;t[r>>2]=t[f>>2];u=t[r>>2]|0;s=i;return u|0}function rE(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0;r=s;s=s+16|0;n=r+12|0;f=r+8|0;u=r+4|0;a=r;t[f>>2]=e;t[u>>2]=i;if(!(t[f>>2]|0)){t[n>>2]=0;o=t[n>>2]|0;s=r;return o|0}do if((t[(t[f>>2]|0)+56>>2]|0)>=(t[(t[f>>2]|0)+60>>2]|0)){t[a>>2]=MAi[t[135760>>2]&511](t[(t[f>>2]|0)+64>>2]|0,t[(t[f>>2]|0)+60>>2]<<1<<2)|0;if(t[a>>2]|0){t[(t[f>>2]|0)+64>>2]=t[a>>2];i=(t[f>>2]|0)+60|0;t[i>>2]=t[i>>2]<<1;break}Sp(t[f>>2]|0,0);t[n>>2]=-1;o=t[n>>2]|0;s=r;return o|0}while(0);if((t[(t[f>>2]|0)+56>>2]|0)>>>0>(t[16304]|0)>>>0?(t[(t[f>>2]|0)+360>>2]&524288|0)==0:0){OS(t[f>>2]|0,1,65224,t[16304]|0);t[(t[f>>2]|0)+172>>2]=-1;t[n>>2]=-1;o=t[n>>2]|0;s=r;return o|0}t[(t[(t[f>>2]|0)+64>>2]|0)+(t[(t[f>>2]|0)+56>>2]<<2)>>2]=t[u>>2];t[(t[f>>2]|0)+52>>2]=t[u>>2];u=(t[f>>2]|0)+56|0;f=t[u>>2]|0;t[u>>2]=f+1;t[n>>2]=f;o=t[n>>2]|0;s=r;return o|0}function nE(e){e=e|0;var i=0,r=0,n=0,f=0,u=0;i=s;s=s+16|0;r=i+8|0;n=i+4|0;f=i;t[n>>2]=e;if(!(t[n>>2]|0)){t[r>>2]=0;u=t[r>>2]|0;s=i;return u|0}if((t[(t[n>>2]|0)+56>>2]|0)<=0){t[r>>2]=0;u=t[r>>2]|0;s=i;return u|0}e=(t[n>>2]|0)+56|0;t[e>>2]=(t[e>>2]|0)+-1;e=t[n>>2]|0;if((t[(t[n>>2]|0)+56>>2]|0)>0)t[(t[n>>2]|0)+52>>2]=t[(t[(t[n>>2]|0)+64>>2]|0)+((t[e+56>>2]|0)-1<<2)>>2];else t[e+52>>2]=0;t[f>>2]=t[(t[(t[n>>2]|0)+64>>2]|0)+(t[(t[n>>2]|0)+56>>2]<<2)>>2];t[(t[(t[n>>2]|0)+64>>2]|0)+(t[(t[n>>2]|0)+56>>2]<<2)>>2]=0;t[r>>2]=t[f>>2];u=t[r>>2]|0;s=i;return u|0}function fE(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0;r=s;s=s+16|0;n=r+12|0;f=r+8|0;u=r+4|0;a=r;t[f>>2]=e;t[u>>2]=i;if(!(t[f>>2]|0)){t[n>>2]=-1;o=t[n>>2]|0;s=r;return o|0}do if((t[(t[f>>2]|0)+188>>2]|0)>=(t[(t[f>>2]|0)+192>>2]|0)){t[a>>2]=MAi[t[135760>>2]&511](t[(t[f>>2]|0)+196>>2]|0,t[(t[f>>2]|0)+192>>2]<<1<<2)|0;if(t[a>>2]|0){t[(t[f>>2]|0)+196>>2]=t[a>>2];i=(t[f>>2]|0)+192|0;t[i>>2]=t[i>>2]<<1;break}Sp(t[f>>2]|0,0);t[n>>2]=-1;o=t[n>>2]|0;s=r;return o|0}while(0);t[(t[(t[f>>2]|0)+196>>2]|0)+(t[(t[f>>2]|0)+188>>2]<<2)>>2]=t[u>>2];t[(t[f>>2]|0)+184>>2]=t[u>>2];u=(t[f>>2]|0)+188|0;f=t[u>>2]|0;t[u>>2]=f+1;t[n>>2]=f;o=t[n>>2]|0;s=r;return o|0}function tE(e){e=e|0;var i=0,r=0,n=0,f=0,u=0;i=s;s=s+16|0;r=i+8|0;n=i+4|0;f=i;t[n>>2]=e;if((t[n>>2]|0)!=0?(t[(t[n>>2]|0)+188>>2]|0)>0:0){e=(t[n>>2]|0)+188|0;t[e>>2]=(t[e>>2]|0)+-1;e=t[n>>2]|0;if((t[(t[n>>2]|0)+188>>2]|0)>0)t[(t[n>>2]|0)+184>>2]=t[(t[(t[n>>2]|0)+196>>2]|0)+((t[e+188>>2]|0)-1<<2)>>2];else t[e+184>>2]=0;t[f>>2]=t[(t[(t[n>>2]|0)+196>>2]|0)+(t[(t[n>>2]|0)+188>>2]<<2)>>2];t[(t[(t[n>>2]|0)+196>>2]|0)+(t[(t[n>>2]|0)+188>>2]<<2)>>2]=0;t[r>>2]=t[f>>2];u=t[r>>2]|0;s=i;return u|0}t[r>>2]=0;u=t[r>>2]|0;s=i;return u|0}function uE(e){e=e|0;var i=0,r=0,n=0,f=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0;i=s;s=s+16|0;r=i+12|0;n=i+8|0;f=i+4|0;a=i;t[r>>2]=e;t[n>>2]=0;if((t[(t[r>>2]|0)+40>>2]|0)==1?(t[(t[r>>2]|0)+172>>2]|0)!=3:0){t[f>>2]=t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2];while(1){do if((u[t[f>>2]>>0]|0|0)==32)o=1;else{if(9<=(u[t[f>>2]>>0]|0|0)?(u[t[f>>2]>>0]|0|0)<=10:0){o=1;break}o=(u[t[f>>2]>>0]|0|0)==13}while(0);c=t[f>>2]|0;if(!o)break;e=t[(t[r>>2]|0)+36>>2]|0;if((u[c>>0]|0|0)==10){l=e+28|0;t[l>>2]=(t[l>>2]|0)+1;t[(t[(t[r>>2]|0)+36>>2]|0)+32>>2]=1}else{l=e+32|0;t[l>>2]=(t[l>>2]|0)+1}t[f>>2]=(t[f>>2]|0)+1;t[n>>2]=(t[n>>2]|0)+1;if(u[t[f>>2]>>0]|0)continue;t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]=t[f>>2];yp(t[(t[r>>2]|0)+36>>2]|0,250)|0;t[f>>2]=t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]}t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]=c;b=t[n>>2]|0;s=i;return b|0}do{t[a>>2]=u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0];while(1){if((t[a>>2]|0)!=32?!(9<=(t[a>>2]|0)&(t[a>>2]|0)<=10|(t[a>>2]|0)==13):0)break;Op(t[r>>2]|0);t[a>>2]=u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0];t[n>>2]=(t[n>>2]|0)+1}while(1){if((t[a>>2]|0)==0?(t[(t[r>>2]|0)+40>>2]|0)>1:0)k=(t[(t[r>>2]|0)+172>>2]|0)!=5;else k=0;h=t[r>>2]|0;if(!k)break;aE(h)|0;t[a>>2]=u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]}if((u[t[(t[h+36>>2]|0)+16>>2]>>0]|0|0)==37)oE(t[r>>2]|0);if((t[a>>2]|0)<256){if((t[a>>2]|0)!=32?!(9<=(t[a>>2]|0)&(t[a>>2]|0)<=10):0)w=(t[a>>2]|0)==13;else w=1;d=w&1}else d=0}while((d|0)!=0);b=t[n>>2]|0;s=i;return b|0}function aE(e){e=e|0;var i=0,r=0,f=0,a=0,o=0,c=0;i=s;s=s+16|0;r=i;f=i+8|0;a=i+4|0;t[a>>2]=e;if((t[a>>2]|0)!=0?(t[(t[a>>2]|0)+40>>2]|0)>1:0){if(t[33952]|0){e=t[33976]|0;o=t[33980]|0;t[r>>2]=t[(t[a>>2]|0)+40>>2];yAi[e&511](o,65288,r)}Dp(iE(t[a>>2]|0)|0);if((u[t[(t[(t[a>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==0?(yp(t[(t[a>>2]|0)+36>>2]|0,250)|0)<=0:0){n[f>>0]=aE(t[a>>2]|0)|0;c=n[f>>0]|0;s=i;return c|0}n[f>>0]=n[t[(t[(t[a>>2]|0)+36>>2]|0)+16>>2]>>0]|0;c=n[f>>0]|0;s=i;return c|0}n[f>>0]=0;c=n[f>>0]|0;s=i;return c|0}function oE(e){e=e|0;var i=0,r=0,f=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0;i=s;s=s+32|0;r=i;f=i+20|0;a=i+16|0;o=i+12|0;c=i+8|0;l=i+24|0;b=i+4|0;t[f>>2]=e;t[o>>2]=0;if((u[t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)!=37){s=i;return}switch(t[(t[f>>2]|0)+172>>2]|0){case 14:{AS(t[f>>2]|0,20,0);s=i;return}case 3:{if((t[(t[f>>2]|0)+96>>2]|0)==0?(t[(t[f>>2]|0)+40>>2]|0)==1:0){s=i;return}if((u[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+1>>0]|0|0)==32){s=i;return}if(9<=(u[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+1>>0]|0|0)?(u[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+1>>0]|0|0)<=10:0){s=i;return}if((u[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+1>>0]|0|0)==13){s=i;return}if(!(u[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+1>>0]|0)){s=i;return}break}case 15:case 11:case 16:case 13:case 2:case 12:case 7:case 10:case 9:case 6:case 5:case 8:{s=i;return}case 1:case 0:case 4:{AS(t[f>>2]|0,19,0);s=i;return}case-1:{AS(t[f>>2]|0,18,0);s=i;return}default:{}}Op(t[f>>2]|0);t[a>>2]=sE(t[f>>2]|0)|0;if(t[33952]|0){e=t[33976]|0;k=t[33980]|0;t[r>>2]=t[a>>2];yAi[e&511](k,65408,r)}r=t[f>>2]|0;if(!(t[a>>2]|0)){AS(r,24,0);s=i;return}k=t[f>>2]|0;if((u[t[(t[r+36>>2]|0)+16>>2]>>0]|0|0)!=59){AS(k,25,0);s=i;return}Op(k);if((t[t[f>>2]>>2]|0)!=0?(t[(t[t[f>>2]>>2]|0)+96>>2]|0)!=0:0)t[o>>2]=MAi[t[(t[t[f>>2]>>2]|0)+96>>2]&511](t[(t[f>>2]|0)+4>>2]|0,t[a>>2]|0)|0;if((t[(t[f>>2]|0)+172>>2]|0)==-1){s=i;return}k=t[f>>2]|0;if(!(t[o>>2]|0)){do if((t[k+28>>2]|0)==1)h=26;else{if((t[(t[f>>2]|0)+88>>2]|0)==0?(t[(t[f>>2]|0)+92>>2]|0)==0:0){h=26;break}if((t[(t[f>>2]|0)+104>>2]|0)!=0?(t[(t[f>>2]|0)+112>>2]|0)!=0:0)RS(t[f>>2]|0,27,65432,t[a>>2]|0,0);else NS(t[f>>2]|0,27,65432,t[a>>2]|0,0);t[(t[f>>2]|0)+100>>2]=0}while(0);if((h|0)==26)MS(t[f>>2]|0,26,65432,t[a>>2]|0);TS(t[f>>2]|0,0,0,0)|0;s=i;return}if((t[(t[k+36>>2]|0)+40>>2]|0)!=226){t[c>>2]=DS(t[f>>2]|0,t[o>>2]|0)|0;cE(t[f>>2]|0,t[c>>2]|0)|0;s=i;return}if((t[(t[o>>2]|0)+48>>2]|0)!=4?(t[(t[o>>2]|0)+48>>2]|0)!=5:0){MS(t[f>>2]|0,30,65464,t[a>>2]|0);s=i;return}if(((((((t[(t[o>>2]|0)+48>>2]|0)==5?(t[(t[f>>2]|0)+360>>2]&2|0)==0:0)?(t[(t[f>>2]|0)+360>>2]&16|0)==0:0)?(t[(t[f>>2]|0)+360>>2]&4|0)==0:0)?(t[(t[f>>2]|0)+360>>2]&8|0)==0:0)?(t[(t[f>>2]|0)+16>>2]|0)==0:0)?(t[(t[f>>2]|0)+104>>2]|0)==0:0){s=i;return}t[c>>2]=Bp(t[f>>2]|0,t[o>>2]|0)|0;if((cE(t[f>>2]|0,t[c>>2]|0)|0)<0){s=i;return}if((t[(t[f>>2]|0)+292>>2]|0)==0?((t[(t[(t[f>>2]|0)+36>>2]|0)+20>>2]|0)-(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)|0)<250:0)CS(t[f>>2]|0);if((t[(t[f>>2]|0)+172>>2]|0)==-1){s=i;return}if(((t[(t[(t[f>>2]|0)+36>>2]|0)+20>>2]|0)-(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)|0)>=4?(n[l>>0]=n[t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]>>0]|0,n[l+1>>0]=n[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+1>>0]|0,n[l+2>>0]=n[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+2>>0]|0,n[l+3>>0]=n[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+3>>0]|0,t[b>>2]=L_(l,4)|0,(t[b>>2]|0)!=0):0)Tp(t[f>>2]|0,t[b>>2]|0)|0;if((t[(t[o>>2]|0)+48>>2]|0)!=5){s=i;return}if((u[t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)!=60){s=i;return}if((u[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+1>>0]|0|0)!=63){s=i;return}if((u[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+2>>0]|0|0)!=120){s=i;return}if((u[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+3>>0]|0|0)!=109){s=i;return}if((u[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+4>>0]|0|0)!=108){s=i;return}do if((u[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+5>>0]|0|0)!=32){if(9<=(u[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+5>>0]|0|0)?(u[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+5>>0]|0|0)<=10:0)break;if((u[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+5>>0]|0|0)==13)break;s=i;return}while(0);bE(t[f>>2]|0);s=i;return}function cE(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0;r=s;s=s+32|0;n=r;f=r+20|0;u=r+16|0;a=r+12|0;o=r+8|0;t[u>>2]=e;t[a>>2]=i;if(!(t[a>>2]|0)){t[f>>2]=-1;c=t[f>>2]|0;s=r;return c|0}if(t[33952]|0){if((t[(t[u>>2]|0)+36>>2]|0)!=0?(t[(t[(t[u>>2]|0)+36>>2]|0)+4>>2]|0)!=0:0){i=t[33976]|0;e=t[33980]|0;l=t[(t[(t[u>>2]|0)+36>>2]|0)+28>>2]|0;t[n>>2]=t[(t[(t[u>>2]|0)+36>>2]|0)+4>>2];t[n+4>>2]=l;yAi[i&511](e,65312,n)}e=t[33976]|0;i=t[33980]|0;l=t[(t[a>>2]|0)+16>>2]|0;t[n>>2]=(t[(t[u>>2]|0)+40>>2]|0)+1;t[n+4>>2]=l;yAi[e&511](i,65328,n)}t[o>>2]=eE(t[u>>2]|0,t[a>>2]|0)|0;if((t[(t[u>>2]|0)+172>>2]|0)==-1){t[f>>2]=-1;c=t[f>>2]|0;s=r;return c|0}if((t[(t[u>>2]|0)+292>>2]|0)==0?((t[(t[(t[u>>2]|0)+36>>2]|0)+20>>2]|0)-(t[(t[(t[u>>2]|0)+36>>2]|0)+16>>2]|0)|0)<250:0)CS(t[u>>2]|0);t[f>>2]=t[o>>2];c=t[f>>2]|0;s=r;return c|0}function lE(e){e=e|0;var i=0,r=0,n=0,f=0,a=0,o=0,c=0,l=0;i=s;s=s+32|0;r=i+16|0;n=i+12|0;f=i+8|0;a=i+4|0;o=i;t[n>>2]=e;t[f>>2]=0;t[a>>2]=0;t[o>>2]=0;if(((u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==38?(u[(t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]|0)+1>>0]|0|0)==35:0)?(u[(t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]|0)+2>>0]|0|0)==120:0){e=(t[n>>2]|0)+200|0;t[e>>2]=(t[e>>2]|0)+3;e=(t[(t[n>>2]|0)+36>>2]|0)+16|0;t[e>>2]=(t[e>>2]|0)+3;e=(t[(t[n>>2]|0)+36>>2]|0)+32|0;t[e>>2]=(t[e>>2]|0)+3;if((u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==37)oE(t[n>>2]|0);if((u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==0?(yp(t[(t[n>>2]|0)+36>>2]|0,250)|0)<=0:0)aE(t[n>>2]|0)|0;if((t[(t[n>>2]|0)+292>>2]|0)==0?((t[(t[(t[n>>2]|0)+36>>2]|0)+20>>2]|0)-(t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]|0)|0)<250:0)CS(t[n>>2]|0);e:while(1){if((u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==59)break;e=t[a>>2]|0;t[a>>2]=e+1;if((e|0)>20){t[a>>2]=0;if((t[(t[n>>2]|0)+292>>2]|0)==0?((t[(t[(t[n>>2]|0)+36>>2]|0)+20>>2]|0)-(t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]|0)|0)<250:0)CS(t[n>>2]|0);if((t[(t[n>>2]|0)+172>>2]|0)==-1){c=18;break}}if((u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)>=48?(u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)<=57:0)t[f>>2]=(t[f>>2]<<4)+((u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0)-48);else c=22;do if((c|0)==22){c=0;if((u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)>=97?(t[a>>2]|0)<20?(u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)<=102:0:0){t[f>>2]=(t[f>>2]<<4)+((u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0)-97)+10;break}if((u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)<65){c=28;break e}if(!((t[a>>2]|0)<20?(u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)<=70:0)){c=28;break e}t[f>>2]=(t[f>>2]<<4)+((u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0)-65)+10}while(0);if((t[f>>2]|0)>>>0>1114111)t[o>>2]=t[f>>2];Op(t[n>>2]|0);t[a>>2]=(t[a>>2]|0)+1}if((c|0)==18){t[r>>2]=0;l=t[r>>2]|0;s=i;return l|0}else if((c|0)==28){AS(t[n>>2]|0,6,0);t[f>>2]=0}if((u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==59){e=(t[(t[n>>2]|0)+36>>2]|0)+32|0;t[e>>2]=(t[e>>2]|0)+1;e=(t[n>>2]|0)+200|0;t[e>>2]=(t[e>>2]|0)+1;e=(t[(t[n>>2]|0)+36>>2]|0)+16|0;t[e>>2]=(t[e>>2]|0)+1}}else c=34;do if((c|0)==34){if((u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==38?(u[(t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]|0)+1>>0]|0|0)==35:0){e=(t[n>>2]|0)+200|0;t[e>>2]=(t[e>>2]|0)+2;e=(t[(t[n>>2]|0)+36>>2]|0)+16|0;t[e>>2]=(t[e>>2]|0)+2;e=(t[(t[n>>2]|0)+36>>2]|0)+32|0;t[e>>2]=(t[e>>2]|0)+2;if((u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==37)oE(t[n>>2]|0);if((u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==0?(yp(t[(t[n>>2]|0)+36>>2]|0,250)|0)<=0:0)aE(t[n>>2]|0)|0;if((t[(t[n>>2]|0)+292>>2]|0)==0?((t[(t[(t[n>>2]|0)+36>>2]|0)+20>>2]|0)-(t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]|0)|0)<250:0)CS(t[n>>2]|0);while(1){if((u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==59)break;e=t[a>>2]|0;t[a>>2]=e+1;if((e|0)>20){t[a>>2]=0;if((t[(t[n>>2]|0)+292>>2]|0)==0?((t[(t[(t[n>>2]|0)+36>>2]|0)+20>>2]|0)-(t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]|0)|0)<250:0)CS(t[n>>2]|0);if((t[(t[n>>2]|0)+172>>2]|0)==-1){c=50;break}}if((u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)<48){c=54;break}if((u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)>57){c=54;break}t[f>>2]=((t[f>>2]|0)*10|0)+((u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0)-48);if((t[f>>2]|0)>>>0>1114111)t[o>>2]=t[f>>2];Op(t[n>>2]|0);t[a>>2]=(t[a>>2]|0)+1}if((c|0)==50){t[r>>2]=0;l=t[r>>2]|0;s=i;return l|0}else if((c|0)==54){AS(t[n>>2]|0,7,0);t[f>>2]=0}if((u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)!=59)break;e=(t[(t[n>>2]|0)+36>>2]|0)+32|0;t[e>>2]=(t[e>>2]|0)+1;e=(t[n>>2]|0)+200|0;t[e>>2]=(t[e>>2]|0)+1;e=(t[(t[n>>2]|0)+36>>2]|0)+16|0;t[e>>2]=(t[e>>2]|0)+1;break}AS(t[n>>2]|0,8,0)}while(0);a=t[f>>2]|0;do if((t[f>>2]|0)>>>0<256)if((9<=a>>>0&(t[f>>2]|0)>>>0<=10|(t[f>>2]|0)==13|32<=(t[f>>2]|0)>>>0)&(t[o>>2]|0)==0)c=66;else c=67;else{if(!(256<=a>>>0&(t[f>>2]|0)>>>0<=55295)?!(57344<=(t[f>>2]|0)>>>0&(t[f>>2]|0)>>>0<=65533):0)if(65536<=(t[f>>2]|0)>>>0&(t[f>>2]|0)>>>0<=1114111&(t[o>>2]|0)==0){c=66;break}else{c=67;break}if(!(t[o>>2]|0))c=66;else c=67}while(0);if((c|0)==66){t[r>>2]=t[f>>2];l=t[r>>2]|0;s=i;return l|0}else if((c|0)==67){OS(t[n>>2]|0,9,65360,t[f>>2]|0);t[r>>2]=0;l=t[r>>2]|0;s=i;return l|0}return 0}function sE(e){e=e|0;var i=0,r=0,n=0,f=0,a=0,o=0,c=0,l=0,b=0,k=0;i=s;s=s+32|0;r=i+16|0;n=i+12|0;f=i+8|0;a=i+4|0;o=i;t[n>>2]=e;t[o>>2]=0;if((t[(t[n>>2]|0)+292>>2]|0)==0?((t[(t[(t[n>>2]|0)+36>>2]|0)+20>>2]|0)-(t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]|0)|0)<250:0)CS(t[n>>2]|0);t[f>>2]=t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2];if((u[t[f>>2]>>0]|0|0)>=97?(u[t[f>>2]>>0]|0|0)<=122:0)c=10;else c=6;do if((c|0)==6){if((u[t[f>>2]>>0]|0|0)>=65?(u[t[f>>2]>>0]|0|0)<=90:0){c=10;break}if(!((u[t[f>>2]>>0]|0|0)!=95?(u[t[f>>2]>>0]|0|0)!=58:0))c=10}while(0);if((c|0)==10){t[f>>2]=(t[f>>2]|0)+1;while(1){if((u[t[f>>2]>>0]|0|0)>=97?(u[t[f>>2]>>0]|0|0)<=122:0)l=1;else c=13;do if((c|0)==13){c=0;if((u[t[f>>2]>>0]|0|0)>=65?(u[t[f>>2]>>0]|0|0)<=90:0){l=1;break}if((u[t[f>>2]>>0]|0|0)>=48?(u[t[f>>2]>>0]|0|0)<=57:0){l=1;break}if(((u[t[f>>2]>>0]|0|0)!=95?(u[t[f>>2]>>0]|0|0)!=45:0)?(u[t[f>>2]>>0]|0|0)!=58:0)l=(u[t[f>>2]>>0]|0|0)==46;else l=1}while(0);b=t[f>>2]|0;if(!l)break;t[f>>2]=b+1}if((u[b>>0]|0|0)>0?(u[t[f>>2]>>0]|0|0)<128:0){t[o>>2]=(t[f>>2]|0)-(t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]|0);if((t[o>>2]|0)>5e4?(t[(t[n>>2]|0)+360>>2]&524288|0)==0:0){AS(t[n>>2]|0,110,65688);t[r>>2]=0;k=t[r>>2]|0;s=i;return k|0}t[a>>2]=kz(t[(t[n>>2]|0)+296>>2]|0,t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]|0,t[o>>2]|0)|0;t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]=t[f>>2];f=(t[n>>2]|0)+200|0;t[f>>2]=(t[f>>2]|0)+(t[o>>2]|0);f=(t[(t[n>>2]|0)+36>>2]|0)+32|0;t[f>>2]=(t[f>>2]|0)+(t[o>>2]|0);if(!(t[a>>2]|0))Sp(t[n>>2]|0,0);t[r>>2]=t[a>>2];k=t[r>>2]|0;s=i;return k|0}}t[r>>2]=PS(t[n>>2]|0)|0;k=t[r>>2]|0;s=i;return k|0}function bE(e){e=e|0;var i=0,r=0,n=0,f=0,a=0,o=0;i=s;s=s+16|0;r=i+8|0;n=i+4|0;f=i;t[r>>2]=e;e:do if(((((u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==60?(u[(t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)+1>>0]|0|0)==63:0)?(u[(t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)+2>>0]|0|0)==120:0)?(u[(t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)+3>>0]|0|0)==109:0)?(u[(t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)+4>>0]|0|0)==108:0){do if((u[(t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)+5>>0]|0|0)!=32){if(9<=(u[(t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)+5>>0]|0|0)?(u[(t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)+5>>0]|0|0)<=10:0)break;if((u[(t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)+5>>0]|0|0)!=13)break e}while(0);e=(t[r>>2]|0)+200|0;t[e>>2]=(t[e>>2]|0)+5;e=(t[(t[r>>2]|0)+36>>2]|0)+16|0;t[e>>2]=(t[e>>2]|0)+5;e=(t[(t[r>>2]|0)+36>>2]|0)+32|0;t[e>>2]=(t[e>>2]|0)+5;if((u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==37)oE(t[r>>2]|0);if((u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==0?(yp(t[(t[r>>2]|0)+36>>2]|0,250)|0)<=0:0)aE(t[r>>2]|0)|0;do if((u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)!=32){if(9<=(u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)?(u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)<=10:0)break;if((u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)!=13)BS(t[r>>2]|0,65,68456)}while(0);uE(t[r>>2]|0)|0;t[n>>2]=xE(t[r>>2]|0)|0;do if(t[n>>2]|0){if((u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)!=32){if(9<=(u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)?(u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)<=10:0)break;if((u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)!=13)BS(t[r>>2]|0,65,68496)}}else t[n>>2]=Wl(68488)|0;while(0);t[(t[(t[r>>2]|0)+36>>2]|0)+48>>2]=t[n>>2];t[f>>2]=UE(t[r>>2]|0)|0;if((t[(t[r>>2]|0)+84>>2]|0)==32){s=i;return}if((t[f>>2]|0)==0?(t[(t[r>>2]|0)+84>>2]|0)==0:0)BS(t[r>>2]|0,101,68520);uE(t[r>>2]|0)|0;if((u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==63?(u[(t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)+1>>0]|0|0)==62:0){e=(t[r>>2]|0)+200|0;t[e>>2]=(t[e>>2]|0)+2;e=(t[(t[r>>2]|0)+36>>2]|0)+16|0;t[e>>2]=(t[e>>2]|0)+2;e=(t[(t[r>>2]|0)+36>>2]|0)+32|0;t[e>>2]=(t[e>>2]|0)+2;if((u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==37)oE(t[r>>2]|0);if(u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0){s=i;return}if((yp(t[(t[r>>2]|0)+36>>2]|0,250)|0)>0){s=i;return}aE(t[r>>2]|0)|0;s=i;return}e=(u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==62;AS(t[r>>2]|0,57,0);if(e){Op(t[r>>2]|0);s=i;return}while(1){if(u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0)a=(u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)!=62;else a=0;o=t[r>>2]|0;if(!a)break;e=(t[o+36>>2]|0)+16|0;t[e>>2]=(t[e>>2]|0)+1}Op(o);s=i;return}while(0);AS(t[r>>2]|0,56,0);s=i;return}function kE(e,i,r,f,a,o,c){e=e|0;
	i=i|0;r=r|0;f=f|0;a=a|0;o=o|0;c=c|0;var l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0,S=0,g=0,y=0,F=0,O=0,A=0,M=0,R=0,N=0,T=0,L=0,D=0,C=0,P=0,B=0,I=0,H=0,x=0,U=0,z=0,j=0,V=0,q=0,Y=0,G=0;l=s;s=s+128|0;b=l;k=l+116|0;h=l+112|0;w=l+108|0;d=l+104|0;v=l+100|0;m=l+122|0;_=l+121|0;p=l+120|0;E=l+96|0;S=l+92|0;g=l+88|0;y=l+84|0;F=l+80|0;O=l+76|0;A=l+72|0;M=l+68|0;R=l+64|0;N=l+60|0;T=l+56|0;L=l+52|0;D=l+48|0;C=l+44|0;P=l+40|0;B=l+36|0;I=l+32|0;H=l+28|0;x=l+24|0;U=l+20|0;z=l+16|0;j=l+12|0;V=l+8|0;q=l+4|0;t[h>>2]=e;t[w>>2]=i;t[d>>2]=r;t[v>>2]=f;n[m>>0]=a;n[_>>0]=o;n[p>>0]=c;t[E>>2]=0;t[S>>2]=0;t[g>>2]=0;t[y>>2]=0;t[F>>2]=0;if((t[h>>2]|0)==0|(t[w>>2]|0)==0|(t[d>>2]|0)<0){t[k>>2]=0;Y=t[k>>2]|0;s=l;return Y|0}t[O>>2]=(t[w>>2]|0)+(t[d>>2]|0);if(!((t[(t[h>>2]|0)+248>>2]|0)>40?(t[(t[h>>2]|0)+360>>2]&524288|0)==0:0))G=5;if((G|0)==5?(t[(t[h>>2]|0)+248>>2]|0)<=1024:0){t[S>>2]=300;t[E>>2]=gAi[t[135752>>2]&511](t[S>>2]|0)|0;e:do if(!(t[E>>2]|0))G=88;else{if((t[w>>2]|0)>>>0<(t[O>>2]|0)>>>0)t[M>>2]=Mp(t[h>>2]|0,t[w>>2]|0,R)|0;else t[M>>2]=0;while(1){if(!(t[M>>2]|0))break;if((t[M>>2]|0)==(u[m>>0]|0|0))break;if((t[M>>2]|0)==(u[_>>0]|0|0))break;if((t[M>>2]|0)==0?1:(t[M>>2]|0)==(u[p>>0]|0|0))break;if((t[M>>2]|0)==38?(u[(t[w>>2]|0)+1>>0]|0|0)==35:0){t[N>>2]=IS(t[h>>2]|0,w)|0;if(t[N>>2]|0){d=Rp((t[E>>2]|0)+(t[g>>2]|0)|0,t[N>>2]|0)|0;t[g>>2]=(t[g>>2]|0)+d}if(((t[g>>2]|0)+100|0)>>>0>(t[S>>2]|0)>>>0){t[L>>2]=(t[S>>2]<<1)+100;if((t[L>>2]|0)>>>0<(t[S>>2]|0)>>>0){G=88;break e}t[T>>2]=MAi[t[135760>>2]&511](t[E>>2]|0,t[L>>2]|0)|0;if(!(t[T>>2]|0)){G=88;break e}t[E>>2]=t[T>>2];t[S>>2]=t[L>>2]}}else G=23;i:do if((G|0)==23){G=0;if((t[M>>2]|0)==38?(t[v>>2]&1|0)!=0:0){if(t[33952]|0){d=t[33976]|0;c=t[33980]|0;t[b>>2]=t[w>>2];yAi[d&511](c,65512,b)}t[A>>2]=HS(t[h>>2]|0,w)|0;if((t[(t[h>>2]|0)+388>>2]|0)==89)break e;if((t[(t[h>>2]|0)+388>>2]|0)==1)break e;TS(t[h>>2]|0,0,t[A>>2]|0,0)|0;if(t[A>>2]|0){c=(t[h>>2]|0)+440|0;t[c>>2]=(t[c>>2]|0)+((t[(t[A>>2]|0)+72>>2]|0)/2|0)}do if(t[A>>2]|0){if((t[(t[A>>2]|0)+48>>2]|0)!=6)break;if(!(t[(t[A>>2]|0)+40>>2]|0)){BS(t[h>>2]|0,1,65560);break i}c=Rp((t[E>>2]|0)+(t[g>>2]|0)|0,u[t[(t[A>>2]|0)+40>>2]>>0]|0)|0;t[g>>2]=(t[g>>2]|0)+c;if(((t[g>>2]|0)+100|0)>>>0<=(t[S>>2]|0)>>>0)break i;t[C>>2]=(t[S>>2]<<1)+100;if((t[C>>2]|0)>>>0<(t[S>>2]|0)>>>0){G=88;break e}t[D>>2]=MAi[t[135760>>2]&511](t[E>>2]|0,t[C>>2]|0)|0;if(!(t[D>>2]|0)){G=88;break e}t[E>>2]=t[D>>2];t[S>>2]=t[C>>2];break i}while(0);do if(t[A>>2]|0){if(!(t[(t[A>>2]|0)+40>>2]|0))break;c=(t[h>>2]|0)+248|0;t[c>>2]=(t[c>>2]|0)+1;t[F>>2]=hE(t[h>>2]|0,t[(t[A>>2]|0)+40>>2]|0,t[v>>2]|0,0,0,0)|0;c=(t[h>>2]|0)+248|0;t[c>>2]=(t[c>>2]|0)+-1;if(!(t[F>>2]|0))break i;t[y>>2]=t[F>>2];while(1){if(!(u[t[y>>2]>>0]|0))break;c=t[y>>2]|0;t[y>>2]=c+1;d=n[c>>0]|0;c=t[g>>2]|0;t[g>>2]=c+1;n[(t[E>>2]|0)+c>>0]=d;if(((t[g>>2]|0)+100|0)>>>0<=(t[S>>2]|0)>>>0)continue;if(TS(t[h>>2]|0,t[g>>2]|0,t[A>>2]|0,0)|0)break e;t[B>>2]=(t[S>>2]<<1)+100;if((t[B>>2]|0)>>>0<(t[S>>2]|0)>>>0){G=88;break e}t[P>>2]=MAi[t[135760>>2]&511](t[E>>2]|0,t[B>>2]|0)|0;if(!(t[P>>2]|0)){G=88;break e}t[E>>2]=t[P>>2];t[S>>2]=t[B>>2]}pAi[t[135736>>2]&511](t[F>>2]|0);t[F>>2]=0;break i}while(0);if(!(t[A>>2]|0))break;t[I>>2]=rs(t[(t[A>>2]|0)+8>>2]|0)|0;t[H>>2]=t[(t[A>>2]|0)+8>>2];d=t[g>>2]|0;t[g>>2]=d+1;n[(t[E>>2]|0)+d>>0]=38;if(((t[g>>2]|0)+(t[I>>2]|0)+100|0)>>>0>(t[S>>2]|0)>>>0){t[U>>2]=(t[S>>2]<<1)+(t[I>>2]|0)+100;if((t[U>>2]|0)>>>0<(t[S>>2]|0)>>>0){G=88;break e}t[x>>2]=MAi[t[135760>>2]&511](t[E>>2]|0,t[U>>2]|0)|0;if(!(t[x>>2]|0)){G=88;break e}t[E>>2]=t[x>>2];t[S>>2]=t[U>>2]}while(1){if((t[I>>2]|0)<=0)break;d=t[H>>2]|0;t[H>>2]=d+1;c=n[d>>0]|0;d=t[g>>2]|0;t[g>>2]=d+1;n[(t[E>>2]|0)+d>>0]=c;t[I>>2]=(t[I>>2]|0)+-1}c=t[g>>2]|0;t[g>>2]=c+1;n[(t[E>>2]|0)+c>>0]=59;break}if((t[M>>2]|0)==37?(t[v>>2]&2|0)!=0:0){if(t[33952]|0){c=t[33976]|0;d=t[33980]|0;t[b>>2]=t[w>>2];yAi[c&511](d,65600,b)}t[A>>2]=xS(t[h>>2]|0,w)|0;if((t[(t[h>>2]|0)+388>>2]|0)==89)break e;TS(t[h>>2]|0,0,t[A>>2]|0,0)|0;if(t[A>>2]|0){d=(t[h>>2]|0)+440|0;t[d>>2]=(t[d>>2]|0)+((t[(t[A>>2]|0)+72>>2]|0)/2|0)}if(!(t[A>>2]|0))break;if(!(t[(t[A>>2]|0)+40>>2]|0))US(t[h>>2]|0,t[A>>2]|0)|0;d=(t[h>>2]|0)+248|0;t[d>>2]=(t[d>>2]|0)+1;t[F>>2]=hE(t[h>>2]|0,t[(t[A>>2]|0)+40>>2]|0,t[v>>2]|0,0,0,0)|0;d=(t[h>>2]|0)+248|0;t[d>>2]=(t[d>>2]|0)+-1;if(!(t[F>>2]|0))break;t[y>>2]=t[F>>2];while(1){if(!(u[t[y>>2]>>0]|0))break;d=t[y>>2]|0;t[y>>2]=d+1;c=n[d>>0]|0;d=t[g>>2]|0;t[g>>2]=d+1;n[(t[E>>2]|0)+d>>0]=c;if(((t[g>>2]|0)+100|0)>>>0<=(t[S>>2]|0)>>>0)continue;if(TS(t[h>>2]|0,t[g>>2]|0,t[A>>2]|0,0)|0)break e;t[j>>2]=(t[S>>2]<<1)+100;if((t[j>>2]|0)>>>0<(t[S>>2]|0)>>>0){G=88;break e}t[z>>2]=MAi[t[135760>>2]&511](t[E>>2]|0,t[j>>2]|0)|0;if(!(t[z>>2]|0)){G=88;break e}t[E>>2]=t[z>>2];t[S>>2]=t[j>>2]}pAi[t[135736>>2]&511](t[F>>2]|0);t[F>>2]=0;break}if((t[R>>2]|0)==1){c=t[M>>2]&255;d=t[g>>2]|0;t[g>>2]=d+1;n[(t[E>>2]|0)+d>>0]=c}else{c=Rp((t[E>>2]|0)+(t[g>>2]|0)|0,t[M>>2]|0)|0;t[g>>2]=(t[g>>2]|0)+c}t[w>>2]=(t[w>>2]|0)+(t[R>>2]|0);if(((t[g>>2]|0)+100|0)>>>0>(t[S>>2]|0)>>>0){t[q>>2]=(t[S>>2]<<1)+100;if((t[q>>2]|0)>>>0<(t[S>>2]|0)>>>0){G=88;break e}t[V>>2]=MAi[t[135760>>2]&511](t[E>>2]|0,t[q>>2]|0)|0;if(!(t[V>>2]|0)){G=88;break e}t[E>>2]=t[V>>2];t[S>>2]=t[q>>2]}}while(0);if((t[w>>2]|0)>>>0<(t[O>>2]|0)>>>0){t[M>>2]=Mp(t[h>>2]|0,t[w>>2]|0,R)|0;continue}else{t[M>>2]=0;continue}}n[(t[E>>2]|0)+(t[g>>2]|0)>>0]=0;t[k>>2]=t[E>>2];Y=t[k>>2]|0;s=l;return Y|0}while(0);if((G|0)==88)Sp(t[h>>2]|0,0);if(t[F>>2]|0)pAi[t[135736>>2]&511](t[F>>2]|0);if(t[E>>2]|0)pAi[t[135736>>2]&511](t[E>>2]|0);t[k>>2]=0;Y=t[k>>2]|0;s=l;return Y|0}AS(t[h>>2]|0,89,0);t[k>>2]=0;Y=t[k>>2]|0;s=l;return Y|0}function hE(e,i,r,f,u,a){e=e|0;i=i|0;r=r|0;f=f|0;u=u|0;a=a|0;var o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0;o=s;s=s+32|0;c=o+12|0;l=o+8|0;b=o+4|0;k=o;h=o+18|0;w=o+17|0;d=o+16|0;t[l>>2]=e;t[b>>2]=i;t[k>>2]=r;n[h>>0]=f;n[w>>0]=u;n[d>>0]=a;if((t[l>>2]|0)==0|(t[b>>2]|0)==0){t[c>>2]=0;v=t[c>>2]|0;s=o;return v|0}else{a=t[l>>2]|0;l=t[b>>2]|0;u=rs(t[b>>2]|0)|0;t[c>>2]=kE(a,l,u,t[k>>2]|0,n[h>>0]|0,n[w>>0]|0,n[d>>0]|0)|0;v=t[c>>2]|0;s=o;return v|0}return 0}function wE(e,i,r){e=e|0;i=i|0;r=r|0;var f=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0,S=0,g=0,y=0,F=0,O=0,A=0;f=s;s=s+176|0;a=f+52|0;o=f+48|0;c=f+44|0;l=f+40|0;b=f+56|0;k=f+36|0;h=f+32|0;w=f+28|0;d=f+24|0;v=f+20|0;m=f+16|0;_=f+12|0;p=f+8|0;E=f+4|0;S=f;t[o>>2]=e;t[c>>2]=i;t[l>>2]=r;t[k>>2]=0;t[h>>2]=0;t[w>>2]=100;t[d>>2]=0;t[v>>2]=t[c>>2];if(!(t[l>>2]|0)){t[a>>2]=0;g=t[a>>2]|0;s=f;return g|0}t[t[l>>2]>>2]=0;if(!(t[v>>2]|0)){t[a>>2]=0;g=t[a>>2]|0;s=f;return g|0}if((u[t[v>>2]>>0]|0|0)==58){t[a>>2]=Yl(t[c>>2]|0)|0;g=t[a>>2]|0;s=f;return g|0}r=t[v>>2]|0;t[v>>2]=r+1;t[m>>2]=u[r>>0];while(1){if(!((t[m>>2]|0)!=0&(t[m>>2]|0)!=58))break;if((t[h>>2]|0)>=(t[w>>2]|0))break;r=t[m>>2]&255;i=t[h>>2]|0;t[h>>2]=i+1;n[b+i>>0]=r;r=t[v>>2]|0;t[v>>2]=r+1;t[m>>2]=u[r>>0]}do if((t[h>>2]|0)>=(t[w>>2]|0)){t[w>>2]=t[h>>2]<<1;t[k>>2]=gAi[t[135752>>2]&511](t[w>>2]|0)|0;if(!(t[k>>2]|0)){Sp(t[o>>2]|0,0);t[a>>2]=0;g=t[a>>2]|0;s=f;return g|0}YY(t[k>>2]|0,b|0,t[h>>2]|0)|0;while(1){if(t[m>>2]|0)y=(t[m>>2]|0)!=58;else y=0;F=t[h>>2]|0;if(!y){O=23;break}if((F+10|0)>(t[w>>2]|0)){t[w>>2]=t[w>>2]<<1;t[_>>2]=MAi[t[135760>>2]&511](t[k>>2]|0,t[w>>2]|0)|0;if(!(t[_>>2]|0))break;t[k>>2]=t[_>>2]}r=t[m>>2]&255;i=t[h>>2]|0;t[h>>2]=i+1;n[(t[k>>2]|0)+i>>0]=r;r=t[v>>2]|0;t[v>>2]=r+1;t[m>>2]=u[r>>0]}if((O|0)==23){n[(t[k>>2]|0)+F>>0]=0;break}pAi[t[135736>>2]&511](t[k>>2]|0);Sp(t[o>>2]|0,0);t[a>>2]=0;g=t[a>>2]|0;s=f;return g|0}while(0);if((t[m>>2]|0)==58?(u[t[v>>2]>>0]|0|0)==0:0){if(t[k>>2]|0)pAi[t[135736>>2]&511](t[k>>2]|0);t[t[l>>2]>>2]=0;t[a>>2]=Yl(t[c>>2]|0)|0;g=t[a>>2]|0;s=f;return g|0}if(!(t[k>>2]|0))t[d>>2]=ql(b,t[h>>2]|0)|0;else{t[d>>2]=t[k>>2];t[k>>2]=0;t[w>>2]=100}do if((t[m>>2]|0)==58){t[m>>2]=u[t[v>>2]>>0];t[t[l>>2]>>2]=t[d>>2];if(!(t[m>>2]|0)){t[a>>2]=ql(65640,0)|0;g=t[a>>2]|0;s=f;return g|0}t[h>>2]=0;do if(!((t[m>>2]|0)>=97&(t[m>>2]|0)<=122)?!((t[m>>2]|0)>=65&(t[m>>2]|0)<=90|(t[m>>2]|0)==95|(t[m>>2]|0)==58):0){t[E>>2]=Mp(t[o>>2]|0,t[v>>2]|0,p)|0;F=t[E>>2]|0;if((t[E>>2]|0)<256){if(65<=(F|0)&(t[E>>2]|0)<=90)break;if(97<=(t[E>>2]|0)&(t[E>>2]|0)<=122)break;if(192<=(t[E>>2]|0)&(t[E>>2]|0)<=214)break;if(216<=(t[E>>2]|0)&(t[E>>2]|0)<=246|248<=(t[E>>2]|0))break}else if(dj(F,199744)|0)break;F=t[E>>2]|0;if((t[E>>2]|0)<256){if((F|0)==95)break}else{if(19968<=(F|0)&(t[E>>2]|0)<=40869|(t[E>>2]|0)==12295)break;if(!((12321<=(t[E>>2]|0)&(t[E>>2]|0)<=12329^1)&(t[E>>2]|0)!=95))break}MS(t[o>>2]|0,202,65648,t[c>>2]|0)}while(0);t[v>>2]=(t[v>>2]|0)+1;while(1){if(!(t[m>>2]|0))break;if((t[h>>2]|0)>=(t[w>>2]|0))break;F=t[m>>2]&255;_=t[h>>2]|0;t[h>>2]=_+1;n[b+_>>0]=F;F=t[v>>2]|0;t[v>>2]=F+1;t[m>>2]=u[F>>0]}do if((t[h>>2]|0)>=(t[w>>2]|0)){t[w>>2]=t[h>>2]<<1;t[k>>2]=gAi[t[135752>>2]&511](t[w>>2]|0)|0;if(!(t[k>>2]|0)){Sp(t[o>>2]|0,0);t[a>>2]=0;g=t[a>>2]|0;s=f;return g|0}YY(t[k>>2]|0,b|0,t[h>>2]|0)|0;while(1){A=t[h>>2]|0;if(!(t[m>>2]|0)){O=62;break}if((A+10|0)>(t[w>>2]|0)){t[w>>2]=t[w>>2]<<1;t[S>>2]=MAi[t[135760>>2]&511](t[k>>2]|0,t[w>>2]|0)|0;if(!(t[S>>2]|0))break;t[k>>2]=t[S>>2]}F=t[m>>2]&255;_=t[h>>2]|0;t[h>>2]=_+1;n[(t[k>>2]|0)+_>>0]=F;F=t[v>>2]|0;t[v>>2]=F+1;t[m>>2]=u[F>>0]}if((O|0)==62){n[(t[k>>2]|0)+A>>0]=0;break}Sp(t[o>>2]|0,0);pAi[t[135736>>2]&511](t[k>>2]|0);t[a>>2]=0;g=t[a>>2]|0;s=f;return g|0}while(0);if(!(t[k>>2]|0)){t[d>>2]=ql(b,t[h>>2]|0)|0;break}else{t[d>>2]=t[k>>2];break}}while(0);t[a>>2]=t[d>>2];g=t[a>>2]|0;s=f;return g|0}function dE(e){e=e|0;var i=0,r=0,f=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0;i=s;s=s+144|0;r=i+32|0;f=i+28|0;a=i+36|0;o=i+24|0;c=i+20|0;l=i+16|0;b=i+12|0;k=i+8|0;h=i+4|0;w=i;t[f>>2]=e;t[o>>2]=0;t[b>>2]=0;if((t[(t[f>>2]|0)+292>>2]|0)==0?((t[(t[(t[f>>2]|0)+36>>2]|0)+20>>2]|0)-(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)|0)<250:0)CS(t[f>>2]|0);if((t[(t[f>>2]|0)+172>>2]|0)==-1){t[r>>2]=0;d=t[r>>2]|0;s=i;return d|0}t[l>>2]=Ap(t[f>>2]|0,c)|0;while(1){if(!(zS(t[f>>2]|0,t[l>>2]|0)|0)){v=55;break}e=t[b>>2]|0;t[b>>2]=e+1;if(((e|0)>100?(t[b>>2]=0,(t[(t[f>>2]|0)+292>>2]|0)==0):0)?((t[(t[(t[f>>2]|0)+36>>2]|0)+20>>2]|0)-(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)|0)<250:0)CS(t[f>>2]|0);if((t[c>>2]|0)==1){e=t[l>>2]&255;m=t[o>>2]|0;t[o>>2]=m+1;n[a+m>>0]=e}else{e=Rp(a+(t[o>>2]|0)|0,t[l>>2]|0)|0;t[o>>2]=(t[o>>2]|0)+e}e=t[(t[f>>2]|0)+36>>2]|0;if((u[t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==10){m=e+28|0;t[m>>2]=(t[m>>2]|0)+1;t[(t[(t[f>>2]|0)+36>>2]|0)+32>>2]=1}else{m=e+32|0;t[m>>2]=(t[m>>2]|0)+1}m=(t[(t[f>>2]|0)+36>>2]|0)+16|0;t[m>>2]=(t[m>>2]|0)+(t[c>>2]|0);if((u[t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==37)oE(t[f>>2]|0);t[l>>2]=Ap(t[f>>2]|0,c)|0;if(!(t[l>>2]|0)){t[b>>2]=0;if((t[(t[f>>2]|0)+292>>2]|0)==0?((t[(t[(t[f>>2]|0)+36>>2]|0)+20>>2]|0)-(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)|0)<250:0)CS(t[f>>2]|0);if((t[(t[f>>2]|0)+172>>2]|0)==-1){v=25;break}t[l>>2]=Ap(t[f>>2]|0,c)|0}if((t[o>>2]|0)>=100){v=28;break}}if((v|0)==25){t[r>>2]=0;d=t[r>>2]|0;s=i;return d|0}else if((v|0)==28){t[h>>2]=t[o>>2]<<1;t[k>>2]=gAi[t[135752>>2]&511](t[h>>2]|0)|0;if(!(t[k>>2]|0)){Sp(t[f>>2]|0,0);t[r>>2]=0;d=t[r>>2]|0;s=i;return d|0}YY(t[k>>2]|0,a|0,t[o>>2]|0)|0;while(1){if(!(zS(t[f>>2]|0,t[l>>2]|0)|0)){v=54;break}m=t[b>>2]|0;t[b>>2]=m+1;if((m|0)>100){t[b>>2]=0;if((t[(t[f>>2]|0)+292>>2]|0)==0?((t[(t[(t[f>>2]|0)+36>>2]|0)+20>>2]|0)-(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)|0)<250:0)CS(t[f>>2]|0);if((t[(t[f>>2]|0)+172>>2]|0)==-1){v=37;break}}if(((t[o>>2]|0)+10|0)>(t[h>>2]|0)){if((t[h>>2]|0)>5e4?(t[(t[f>>2]|0)+360>>2]&524288|0)==0:0){v=41;break}t[h>>2]=t[h>>2]<<1;t[w>>2]=MAi[t[135760>>2]&511](t[k>>2]|0,t[h>>2]|0)|0;if(!(t[w>>2]|0)){v=43;break}t[k>>2]=t[w>>2]}if((t[c>>2]|0)==1){m=t[l>>2]&255;e=t[o>>2]|0;t[o>>2]=e+1;n[(t[k>>2]|0)+e>>0]=m}else{m=Rp((t[k>>2]|0)+(t[o>>2]|0)|0,t[l>>2]|0)|0;t[o>>2]=(t[o>>2]|0)+m}m=t[(t[f>>2]|0)+36>>2]|0;if((u[t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==10){e=m+28|0;t[e>>2]=(t[e>>2]|0)+1;t[(t[(t[f>>2]|0)+36>>2]|0)+32>>2]=1}else{e=m+32|0;t[e>>2]=(t[e>>2]|0)+1}e=(t[(t[f>>2]|0)+36>>2]|0)+16|0;t[e>>2]=(t[e>>2]|0)+(t[c>>2]|0);if((u[t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==37)oE(t[f>>2]|0);t[l>>2]=Ap(t[f>>2]|0,c)|0}if((v|0)==37){pAi[t[135736>>2]&511](t[k>>2]|0);t[r>>2]=0;d=t[r>>2]|0;s=i;return d|0}else if((v|0)==41){AS(t[f>>2]|0,110,65696);pAi[t[135736>>2]&511](t[k>>2]|0);t[r>>2]=0;d=t[r>>2]|0;s=i;return d|0}else if((v|0)==43){Sp(t[f>>2]|0,0);pAi[t[135736>>2]&511](t[k>>2]|0);t[r>>2]=0;d=t[r>>2]|0;s=i;return d|0}else if((v|0)==54){n[(t[k>>2]|0)+(t[o>>2]|0)>>0]=0;t[r>>2]=t[k>>2];d=t[r>>2]|0;s=i;return d|0}}else if((v|0)==55){if(!(t[o>>2]|0)){t[r>>2]=0;d=t[r>>2]|0;s=i;return d|0}if((t[o>>2]|0)>5e4?(t[(t[f>>2]|0)+360>>2]&524288|0)==0:0){AS(t[f>>2]|0,110,65696);t[r>>2]=0;d=t[r>>2]|0;s=i;return d|0}t[r>>2]=ql(a,t[o>>2]|0)|0;d=t[r>>2]|0;s=i;return d|0}return 0}function vE(e,i){e=e|0;i=i|0;var r=0,f=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0,S=0,g=0,y=0,F=0,O=0,A=0;r=s;s=s+64|0;f=r+48|0;a=r+44|0;o=r+40|0;c=r+36|0;l=r+32|0;b=r+28|0;k=r+24|0;h=r+20|0;w=r+53|0;d=r+16|0;v=r+12|0;m=r+8|0;_=r+4|0;p=r;E=r+52|0;t[a>>2]=e;t[o>>2]=i;t[c>>2]=0;t[l>>2]=0;t[b>>2]=100;t[d>>2]=0;t[v>>2]=0;do if((u[t[(t[(t[a>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==34)n[w>>0]=34;else{if((u[t[(t[(t[a>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==39){n[w>>0]=39;break}AS(t[a>>2]|0,36,0);t[f>>2]=0;S=t[f>>2]|0;s=r;return S|0}while(0);t[c>>2]=gAi[t[135752>>2]&511](t[b>>2]|0)|0;i=t[a>>2]|0;if(!(t[c>>2]|0)){Sp(i,0);t[f>>2]=0;S=t[f>>2]|0;s=r;return S|0}t[i+172>>2]=11;t[m>>2]=t[(t[a>>2]|0)+36>>2];if((t[(t[a>>2]|0)+292>>2]|0)==0?((t[(t[(t[a>>2]|0)+36>>2]|0)+20>>2]|0)-(t[(t[(t[a>>2]|0)+36>>2]|0)+16>>2]|0)|0)<250:0)CS(t[a>>2]|0);if((t[(t[a>>2]|0)+172>>2]|0)==-1){pAi[t[135736>>2]&511](t[c>>2]|0);t[f>>2]=0;S=t[f>>2]|0;s=r;return S|0}Op(t[a>>2]|0);t[k>>2]=Ap(t[a>>2]|0,h)|0;while(1){i=t[k>>2]|0;if((t[k>>2]|0)<256)if(9<=(i|0)&(t[k>>2]|0)<=10|(t[k>>2]|0)==13|32<=(t[k>>2]|0))g=19;else y=0;else if((!(256<=(i|0)&(t[k>>2]|0)<=55295)?!(57344<=(t[k>>2]|0)&(t[k>>2]|0)<=65533):0)?!(65536<=(t[k>>2]|0)&(t[k>>2]|0)<=1114111):0)y=0;else g=19;do if((g|0)==19){g=0;if((t[k>>2]|0)==(u[w>>0]|0|0)?(t[(t[a>>2]|0)+36>>2]|0)==(t[m>>2]|0):0){y=0;break}y=(t[(t[a>>2]|0)+172>>2]|0)!=-1}while(0);F=t[l>>2]|0;if(!y)break;if((F+5|0)>=(t[b>>2]|0)){t[b>>2]=t[b>>2]<<1;t[_>>2]=MAi[t[135760>>2]&511](t[c>>2]|0,t[b>>2]|0)|0;if(!(t[_>>2]|0)){g=25;break}t[c>>2]=t[_>>2]}if((t[h>>2]|0)==1){i=t[k>>2]&255;e=t[l>>2]|0;t[l>>2]=e+1;n[(t[c>>2]|0)+e>>0]=i}else{i=Rp((t[c>>2]|0)+(t[l>>2]|0)|0,t[k>>2]|0)|0;t[l>>2]=(t[l>>2]|0)+i}i=t[(t[a>>2]|0)+36>>2]|0;if((u[t[(t[(t[a>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==10){e=i+28|0;t[e>>2]=(t[e>>2]|0)+1;t[(t[(t[a>>2]|0)+36>>2]|0)+32>>2]=1}else{e=i+32|0;t[e>>2]=(t[e>>2]|0)+1}e=(t[(t[a>>2]|0)+36>>2]|0)+16|0;t[e>>2]=(t[e>>2]|0)+(t[h>>2]|0);if((u[t[(t[(t[a>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==37)oE(t[a>>2]|0);while(1){if(!(u[t[(t[(t[a>>2]|0)+36>>2]|0)+16>>2]>>0]|0))O=(t[(t[a>>2]|0)+40>>2]|0)>1;else O=0;A=t[a>>2]|0;if(!O)break;aE(A)|0}if((t[A+292>>2]|0)==0?((t[(t[(t[a>>2]|0)+36>>2]|0)+20>>2]|0)-(t[(t[(t[a>>2]|0)+36>>2]|0)+16>>2]|0)|0)<250:0)CS(t[a>>2]|0);t[k>>2]=Ap(t[a>>2]|0,h)|0;if(t[k>>2]|0)continue;if((t[(t[a>>2]|0)+292>>2]|0)==0?((t[(t[(t[a>>2]|0)+36>>2]|0)+20>>2]|0)-(t[(t[(t[a>>2]|0)+36>>2]|0)+16>>2]|0)|0)<250:0)CS(t[a>>2]|0);t[k>>2]=Ap(t[a>>2]|0,h)|0}if((g|0)==25){Sp(t[a>>2]|0,0);pAi[t[135736>>2]&511](t[c>>2]|0);t[f>>2]=0;S=t[f>>2]|0;s=r;return S|0}n[(t[c>>2]|0)+F>>0]=0;if((t[(t[a>>2]|0)+172>>2]|0)==-1){pAi[t[135736>>2]&511](t[c>>2]|0);t[f>>2]=0;S=t[f>>2]|0;s=r;return S|0}t[v>>2]=t[c>>2];while(1){if(!(u[t[v>>2]>>0]|0))break;if((u[t[v>>2]>>0]|0|0)!=37){if((u[t[v>>2]>>0]|0|0)==38?(u[(t[v>>2]|0)+1>>0]|0|0)!=35:0)g=54}else g=54;if((g|0)==54){g=0;n[E>>0]=n[t[v>>2]>>0]|0;t[v>>2]=(t[v>>2]|0)+1;t[p>>2]=jS(t[a>>2]|0,v)|0;if(!((t[p>>2]|0)!=0?(u[t[v>>2]>>0]|0|0)==59:0))OS(t[a>>2]|0,87,65704,u[E>>0]|0);if(((u[E>>0]|0|0)==37?(t[(t[a>>2]|0)+216>>2]|0)==1:0)?(t[(t[a>>2]|0)+40>>2]|0)==1:0)AS(t[a>>2]|0,88,0);if(t[p>>2]|0)pAi[t[135736>>2]&511](t[p>>2]|0);if(!(u[t[v>>2]>>0]|0))break}t[v>>2]=(t[v>>2]|0)+1}v=t[a>>2]|0;do if((t[k>>2]|0)==(u[w>>0]|0|0)){Op(v);t[d>>2]=hE(t[a>>2]|0,t[c>>2]|0,2,0,0,0)|0;if(t[o>>2]|0){t[t[o>>2]>>2]=t[c>>2];break}else{pAi[t[135736>>2]&511](t[c>>2]|0);break}}else{AS(v,37,0);pAi[t[135736>>2]&511](t[c>>2]|0)}while(0);t[f>>2]=t[d>>2];S=t[f>>2]|0;s=r;return S|0}function mE(e){e=e|0;var i=0,r=0,n=0,f=0;i=s;s=s+16|0;r=i+4|0;n=i;t[n>>2]=e;if((t[n>>2]|0)!=0?(t[(t[n>>2]|0)+36>>2]|0)!=0:0){t[r>>2]=VS(t[n>>2]|0,0,0,0)|0;f=t[r>>2]|0;s=i;return f|0}t[r>>2]=0;f=t[r>>2]|0;s=i;return f|0}function _E(e){e=e|0;var i=0,r=0,f=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0;i=s;s=s+48|0;r=i+36|0;f=i+32|0;a=i+28|0;o=i+24|0;c=i+20|0;l=i+16|0;b=i+12|0;k=i+40|0;h=i+8|0;w=i+4|0;d=i;t[f>>2]=e;t[a>>2]=0;t[o>>2]=0;t[c>>2]=100;t[h>>2]=t[(t[f>>2]|0)+172>>2];t[w>>2]=0;if(((t[(t[f>>2]|0)+292>>2]|0)==0?((t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)-(t[(t[(t[f>>2]|0)+36>>2]|0)+12>>2]|0)|0)>500:0)?((t[(t[(t[f>>2]|0)+36>>2]|0)+20>>2]|0)-(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)|0)<500:0)qS(t[f>>2]|0);e=t[f>>2]|0;do if((u[t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==34){Op(e);n[k>>0]=34}else{v=t[f>>2]|0;if((u[t[(t[e+36>>2]|0)+16>>2]>>0]|0|0)==39){Op(v);n[k>>0]=39;break}AS(v,43,0);t[r>>2]=0;m=t[r>>2]|0;s=i;return m|0}while(0);t[a>>2]=gAi[t[135752>>2]&511](t[c>>2]|0)|0;e=t[f>>2]|0;if(!(t[a>>2]|0)){Sp(e,0);t[r>>2]=0;m=t[r>>2]|0;s=i;return m|0}t[e+172>>2]=13;t[l>>2]=Ap(t[f>>2]|0,b)|0;while(1){e=t[l>>2]|0;if((t[l>>2]|0)<256)if(9<=(e|0)&(t[l>>2]|0)<=10|(t[l>>2]|0)==13|32<=(t[l>>2]|0))_=18;else p=0;else if((!(256<=(e|0)&(t[l>>2]|0)<=55295)?!(57344<=(t[l>>2]|0)&(t[l>>2]|0)<=65533):0)?!(65536<=(t[l>>2]|0)&(t[l>>2]|0)<=1114111):0)p=0;else _=18;if((_|0)==18){_=0;p=(t[l>>2]|0)!=(u[k>>0]|0|0)}E=t[o>>2]|0;if(!p){_=50;break}if((E+5|0)>=(t[c>>2]|0)){if((t[c>>2]|0)>5e4?(t[(t[f>>2]|0)+360>>2]&524288|0)==0:0){_=23;break}t[c>>2]=t[c>>2]<<1;t[d>>2]=MAi[t[135760>>2]&511](t[a>>2]|0,t[c>>2]|0)|0;if(!(t[d>>2]|0)){_=25;break}t[a>>2]=t[d>>2]}t[w>>2]=(t[w>>2]|0)+1;if((t[w>>2]|0)>50){if((t[(t[f>>2]|0)+292>>2]|0)==0?((t[(t[(t[f>>2]|0)+36>>2]|0)+20>>2]|0)-(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)|0)<250:0)CS(t[f>>2]|0);t[w>>2]=0;if((t[(t[f>>2]|0)+172>>2]|0)==-1){_=32;break}}if((t[b>>2]|0)==1){e=t[l>>2]&255;v=t[o>>2]|0;t[o>>2]=v+1;n[(t[a>>2]|0)+v>>0]=e}else{e=Rp((t[a>>2]|0)+(t[o>>2]|0)|0,t[l>>2]|0)|0;t[o>>2]=(t[o>>2]|0)+e}e=t[(t[f>>2]|0)+36>>2]|0;if((u[t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==10){v=e+28|0;t[v>>2]=(t[v>>2]|0)+1;t[(t[(t[f>>2]|0)+36>>2]|0)+32>>2]=1}else{v=e+32|0;t[v>>2]=(t[v>>2]|0)+1}v=(t[(t[f>>2]|0)+36>>2]|0)+16|0;t[v>>2]=(t[v>>2]|0)+(t[b>>2]|0);if((u[t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==37)oE(t[f>>2]|0);t[l>>2]=Ap(t[f>>2]|0,b)|0;if(t[l>>2]|0)continue;if((t[(t[f>>2]|0)+292>>2]|0)==0?((t[(t[(t[f>>2]|0)+36>>2]|0)+20>>2]|0)-(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)|0)<250:0)CS(t[f>>2]|0);if(((t[(t[f>>2]|0)+292>>2]|0)==0?((t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)-(t[(t[(t[f>>2]|0)+36>>2]|0)+12>>2]|0)|0)>500:0)?((t[(t[(t[f>>2]|0)+36>>2]|0)+20>>2]|0)-(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)|0)<500:0)qS(t[f>>2]|0);t[l>>2]=Ap(t[f>>2]|0,b)|0}if((_|0)==23){AS(t[f>>2]|0,110,65768);pAi[t[135736>>2]&511](t[a>>2]|0);t[(t[f>>2]|0)+172>>2]=t[h>>2];t[r>>2]=0;m=t[r>>2]|0;s=i;return m|0}else if((_|0)==25){pAi[t[135736>>2]&511](t[a>>2]|0);Sp(t[f>>2]|0,0);t[(t[f>>2]|0)+172>>2]=t[h>>2];t[r>>2]=0;m=t[r>>2]|0;s=i;return m|0}else if((_|0)==32){pAi[t[135736>>2]&511](t[a>>2]|0);t[r>>2]=0;m=t[r>>2]|0;s=i;return m|0}else if((_|0)==50){n[(t[a>>2]|0)+E>>0]=0;t[(t[f>>2]|0)+172>>2]=t[h>>2];h=t[l>>2]|0;if((t[l>>2]|0)<256)if(9<=(h|0)&(t[l>>2]|0)<=10|(t[l>>2]|0)==13|32<=(t[l>>2]|0))_=56;else _=55;else if((!(256<=(h|0)&(t[l>>2]|0)<=55295)?!(57344<=(t[l>>2]|0)&(t[l>>2]|0)<=65533):0)?!(65536<=(t[l>>2]|0)&(t[l>>2]|0)<=1114111):0)_=55;else _=56;if((_|0)==55)AS(t[f>>2]|0,44,0);else if((_|0)==56)Op(t[f>>2]|0);t[r>>2]=t[a>>2];m=t[r>>2]|0;s=i;return m|0}return 0}function pE(e){e=e|0;var i=0,r=0,f=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0;i=s;s=s+48|0;r=i+28|0;f=i+24|0;a=i+20|0;o=i+16|0;c=i+12|0;l=i+33|0;b=i+32|0;k=i+8|0;h=i+4|0;w=i;t[f>>2]=e;t[a>>2]=0;t[o>>2]=0;t[c>>2]=100;t[k>>2]=0;t[h>>2]=t[(t[f>>2]|0)+172>>2];if(((t[(t[f>>2]|0)+292>>2]|0)==0?((t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)-(t[(t[(t[f>>2]|0)+36>>2]|0)+12>>2]|0)|0)>500:0)?((t[(t[(t[f>>2]|0)+36>>2]|0)+20>>2]|0)-(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)|0)<500:0)qS(t[f>>2]|0);e=t[f>>2]|0;do if((u[t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==34){Op(e);n[b>>0]=34}else{d=t[f>>2]|0;if((u[t[(t[e+36>>2]|0)+16>>2]>>0]|0|0)==39){Op(d);n[b>>0]=39;break}AS(d,43,0);t[r>>2]=0;v=t[r>>2]|0;s=i;return v|0}while(0);t[a>>2]=gAi[t[135752>>2]&511](t[c>>2]|0)|0;e=t[f>>2]|0;if(!(t[a>>2]|0)){Sp(e,0);t[r>>2]=0;v=t[r>>2]|0;s=i;return v|0}t[e+172>>2]=16;n[l>>0]=n[t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]>>0]|0;while(1){if(u[198696+(u[l>>0]|0)>>0]|0)m=(u[l>>0]|0|0)!=(u[b>>0]|0|0);else m=0;_=t[o>>2]|0;if(!m){p=38;break}if((_+1|0)>=(t[c>>2]|0)){if((t[c>>2]|0)>5e4?(t[(t[f>>2]|0)+360>>2]&524288|0)==0:0){p=19;break}t[c>>2]=t[c>>2]<<1;t[w>>2]=MAi[t[135760>>2]&511](t[a>>2]|0,t[c>>2]|0)|0;if(!(t[w>>2]|0)){p=21;break}t[a>>2]=t[w>>2]}e=n[l>>0]|0;d=t[o>>2]|0;t[o>>2]=d+1;n[(t[a>>2]|0)+d>>0]=e;t[k>>2]=(t[k>>2]|0)+1;if((t[k>>2]|0)>50){if((t[(t[f>>2]|0)+292>>2]|0)==0?((t[(t[(t[f>>2]|0)+36>>2]|0)+20>>2]|0)-(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)|0)<250:0)CS(t[f>>2]|0);t[k>>2]=0;if((t[(t[f>>2]|0)+172>>2]|0)==-1){p=28;break}}Op(t[f>>2]|0);n[l>>0]=n[t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]>>0]|0;if(u[l>>0]|0)continue;if((t[(t[f>>2]|0)+292>>2]|0)==0?((t[(t[(t[f>>2]|0)+36>>2]|0)+20>>2]|0)-(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)|0)<250:0)CS(t[f>>2]|0);if(((t[(t[f>>2]|0)+292>>2]|0)==0?((t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)-(t[(t[(t[f>>2]|0)+36>>2]|0)+12>>2]|0)|0)>500:0)?((t[(t[(t[f>>2]|0)+36>>2]|0)+20>>2]|0)-(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)|0)<500:0)qS(t[f>>2]|0);n[l>>0]=n[t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]>>0]|0}if((p|0)==19){AS(t[f>>2]|0,110,65784);pAi[t[135736>>2]&511](t[a>>2]|0);t[r>>2]=0;v=t[r>>2]|0;s=i;return v|0}else if((p|0)==21){Sp(t[f>>2]|0,0);pAi[t[135736>>2]&511](t[a>>2]|0);t[r>>2]=0;v=t[r>>2]|0;s=i;return v|0}else if((p|0)==28){pAi[t[135736>>2]&511](t[a>>2]|0);t[r>>2]=0;v=t[r>>2]|0;s=i;return v|0}else if((p|0)==38){n[(t[a>>2]|0)+_>>0]=0;_=t[f>>2]|0;if((u[l>>0]|0|0)!=(u[b>>0]|0|0))AS(_,44,0);else Op(_);t[(t[f>>2]|0)+172>>2]=t[h>>2];t[r>>2]=t[a>>2];v=t[r>>2]|0;s=i;return v|0}return 0}function EE(e,i){e=e|0;i=i|0;var r=0,f=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0;r=s;s=s+48|0;f=r+32|0;a=r+28|0;o=r+24|0;c=r+20|0;l=r+16|0;b=r+12|0;k=r+8|0;h=r+4|0;w=r;t[f>>2]=e;t[a>>2]=i;t[c>>2]=0;t[l>>2]=t[(t[(t[f>>2]|0)+36>>2]|0)+28>>2];t[b>>2]=t[(t[(t[f>>2]|0)+36>>2]|0)+32>>2];if(((t[(t[f>>2]|0)+292>>2]|0)==0?((t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)-(t[(t[(t[f>>2]|0)+36>>2]|0)+12>>2]|0)|0)>500:0)?((t[(t[(t[f>>2]|0)+36>>2]|0)+20>>2]|0)-(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)|0)<500:0)qS(t[f>>2]|0);if((t[(t[f>>2]|0)+292>>2]|0)==0?((t[(t[(t[f>>2]|0)+36>>2]|0)+20>>2]|0)-(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)|0)<250:0)CS(t[f>>2]|0);do if(!(t[a>>2]|0)){t[o>>2]=t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2];e:while(1){i=t[o>>2]|0;if((u[t[o>>2]>>0]|0)==32){t[o>>2]=i+1;e=(t[(t[f>>2]|0)+36>>2]|0)+32|0;t[e>>2]=(t[e>>2]|0)+1;continue}if((u[i>>0]|0)==10)while(1){i=(t[(t[f>>2]|0)+36>>2]|0)+28|0;t[i>>2]=(t[i>>2]|0)+1;t[(t[(t[f>>2]|0)+36>>2]|0)+32>>2]=1;t[o>>2]=(t[o>>2]|0)+1;if((u[t[o>>2]>>0]|0)!=10)continue e}if((u[t[o>>2]>>0]|0)==60){d=15;break}i:while(1){t[k>>2]=t[(t[(t[f>>2]|0)+36>>2]|0)+32>>2];while(1){if(!(n[65800+(u[t[o>>2]>>0]|0)>>0]|0))break;t[o>>2]=(t[o>>2]|0)+1;t[k>>2]=(t[k>>2]|0)+1}t[(t[(t[f>>2]|0)+36>>2]|0)+32>>2]=t[k>>2];if((u[t[o>>2]>>0]|0)==10)while(1){i=(t[(t[f>>2]|0)+36>>2]|0)+28|0;t[i>>2]=(t[i>>2]|0)+1;t[(t[(t[f>>2]|0)+36>>2]|0)+32>>2]=1;t[o>>2]=(t[o>>2]|0)+1;if((u[t[o>>2]>>0]|0)!=10)continue i}v=t[o>>2]|0;if((u[t[o>>2]>>0]|0)!=93)break;if((u[v+1>>0]|0)==93?(u[(t[o>>2]|0)+2>>0]|0)==62:0){d=36;break e}t[o>>2]=(t[o>>2]|0)+1;i=(t[(t[f>>2]|0)+36>>2]|0)+32|0;t[i>>2]=(t[i>>2]|0)+1}t[c>>2]=v-(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0);if((t[c>>2]|0)>0){i:do if((t[t[f>>2]>>2]|0)!=0?(t[(t[t[f>>2]>>2]|0)+72>>2]|0)!=(t[(t[t[f>>2]>>2]|0)+68>>2]|0):0){do if((u[t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]>>0]|0)!=32){if(9<=(u[t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]>>0]|0)?(u[t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]>>0]|0)<=10:0)break;if((u[t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]>>0]|0)!=13){d=53;break i}}while(0);t[w>>2]=t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2];t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]=t[o>>2];i=(YS(t[f>>2]|0,t[w>>2]|0,t[c>>2]|0,0)|0)!=0;e=t[t[f>>2]>>2]|0;if(i){if(t[e+72>>2]|0)yAi[t[(t[t[f>>2]>>2]|0)+72>>2]&511](t[(t[f>>2]|0)+4>>2]|0,t[w>>2]|0,t[c>>2]|0)}else{if(t[e+68>>2]|0)yAi[t[(t[t[f>>2]>>2]|0)+68>>2]&511](t[(t[f>>2]|0)+4>>2]|0,t[w>>2]|0,t[c>>2]|0);if((t[t[(t[f>>2]|0)+232>>2]>>2]|0)==-1)t[t[(t[f>>2]|0)+232>>2]>>2]=-2}t[l>>2]=t[(t[(t[f>>2]|0)+36>>2]|0)+28>>2];t[b>>2]=t[(t[(t[f>>2]|0)+36>>2]|0)+32>>2]}else d=53;while(0);if((d|0)==53?(d=0,(t[t[f>>2]>>2]|0)!=0):0){if(t[(t[t[f>>2]>>2]|0)+68>>2]|0)yAi[t[(t[t[f>>2]>>2]|0)+68>>2]&511](t[(t[f>>2]|0)+4>>2]|0,t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0,t[c>>2]|0);t[l>>2]=t[(t[(t[f>>2]|0)+36>>2]|0)+28>>2];t[b>>2]=t[(t[(t[f>>2]|0)+36>>2]|0)+32>>2]}if((t[(t[f>>2]|0)+172>>2]|0)!=7){d=78;break}}t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]=t[o>>2];do if((u[t[o>>2]>>0]|0)==13){t[o>>2]=(t[o>>2]|0)+1;e=t[o>>2]|0;if((u[t[o>>2]>>0]|0)==10){t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]=e;t[o>>2]=(t[o>>2]|0)+1;i=(t[(t[f>>2]|0)+36>>2]|0)+28|0;t[i>>2]=(t[i>>2]|0)+1;t[(t[(t[f>>2]|0)+36>>2]|0)+32>>2]=1;break}else{t[o>>2]=e+-1;d=62;break}}else d=62;while(0);if((d|0)==62){d=0;if((u[t[o>>2]>>0]|0)==60){d=78;break}if((u[t[o>>2]>>0]|0)==38){d=78;break}if(((t[(t[f>>2]|0)+292>>2]|0)==0?((t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)-(t[(t[(t[f>>2]|0)+36>>2]|0)+12>>2]|0)|0)>500:0)?((t[(t[(t[f>>2]|0)+36>>2]|0)+20>>2]|0)-(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)|0)<500:0)qS(t[f>>2]|0);if((t[(t[f>>2]|0)+292>>2]|0)==0?((t[(t[(t[f>>2]|0)+36>>2]|0)+20>>2]|0)-(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)|0)<250:0)CS(t[f>>2]|0);if((t[(t[f>>2]|0)+172>>2]|0)==-1){d=78;break}t[o>>2]=t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]}if((u[t[o>>2]>>0]|0)>=32?(u[t[o>>2]>>0]|0)<=127:0)continue;if((u[t[o>>2]>>0]|0)!=9){d=76;break}}if((d|0)==15){t[c>>2]=(t[o>>2]|0)-(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0);if((t[c>>2]|0)<=0){s=r;return}t[h>>2]=t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2];t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]=t[o>>2];if((t[t[f>>2]>>2]|0)!=0?(t[(t[t[f>>2]>>2]|0)+72>>2]|0)!=(t[(t[t[f>>2]>>2]|0)+68>>2]|0):0){e=(YS(t[f>>2]|0,t[h>>2]|0,t[c>>2]|0,1)|0)!=0;i=t[t[f>>2]>>2]|0;if(e){if(!(t[i+72>>2]|0)){s=r;return}yAi[t[(t[t[f>>2]>>2]|0)+72>>2]&511](t[(t[f>>2]|0)+4>>2]|0,t[h>>2]|0,t[c>>2]|0);s=r;return}if(t[i+68>>2]|0)yAi[t[(t[t[f>>2]>>2]|0)+68>>2]&511](t[(t[f>>2]|0)+4>>2]|0,t[h>>2]|0,t[c>>2]|0);if((t[t[(t[f>>2]|0)+232>>2]>>2]|0)!=-1){s=r;return}t[t[(t[f>>2]|0)+232>>2]>>2]=-2;s=r;return}if(!(t[t[f>>2]>>2]|0)){s=r;return}if(!(t[(t[t[f>>2]>>2]|0)+68>>2]|0)){s=r;return}yAi[t[(t[t[f>>2]>>2]|0)+68>>2]&511](t[(t[f>>2]|0)+4>>2]|0,t[h>>2]|0,t[c>>2]|0);s=r;return}else if((d|0)==36){AS(t[f>>2]|0,62,0);t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]=t[o>>2];s=r;return}else if((d|0)==76){t[c>>2]=0;break}else if((d|0)==78){s=r;return}}while(0);t[(t[(t[f>>2]|0)+36>>2]|0)+28>>2]=t[l>>2];t[(t[(t[f>>2]|0)+36>>2]|0)+32>>2]=t[b>>2];GS(t[f>>2]|0,t[a>>2]|0);s=r;return}function SE(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0;n=s;s=s+32|0;f=n+20|0;a=n+16|0;o=n+12|0;c=n+8|0;l=n+4|0;b=n;t[a>>2]=e;t[o>>2]=i;t[c>>2]=r;t[l>>2]=0;if(((t[(t[a>>2]|0)+292>>2]|0)==0?((t[(t[(t[a>>2]|0)+36>>2]|0)+16>>2]|0)-(t[(t[(t[a>>2]|0)+36>>2]|0)+12>>2]|0)|0)>500:0)?((t[(t[(t[a>>2]|0)+36>>2]|0)+20>>2]|0)-(t[(t[(t[a>>2]|0)+36>>2]|0)+16>>2]|0)|0)<500:0)qS(t[a>>2]|0);t[t[o>>2]>>2]=0;if((((((u[t[(t[(t[a>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==83?(u[(t[(t[(t[a>>2]|0)+36>>2]|0)+16>>2]|0)+1>>0]|0|0)==89:0)?(u[(t[(t[(t[a>>2]|0)+36>>2]|0)+16>>2]|0)+2>>0]|0|0)==83:0)?(u[(t[(t[(t[a>>2]|0)+36>>2]|0)+16>>2]|0)+3>>0]|0|0)==84:0)?(u[(t[(t[(t[a>>2]|0)+36>>2]|0)+16>>2]|0)+4>>0]|0|0)==69:0)?(u[(t[(t[(t[a>>2]|0)+36>>2]|0)+16>>2]|0)+5>>0]|0|0)==77:0){r=(t[a>>2]|0)+200|0;t[r>>2]=(t[r>>2]|0)+6;r=(t[(t[a>>2]|0)+36>>2]|0)+16|0;t[r>>2]=(t[r>>2]|0)+6;r=(t[(t[a>>2]|0)+36>>2]|0)+32|0;t[r>>2]=(t[r>>2]|0)+6;if((u[t[(t[(t[a>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==37)oE(t[a>>2]|0);if((u[t[(t[(t[a>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==0?(yp(t[(t[a>>2]|0)+36>>2]|0,250)|0)<=0:0)aE(t[a>>2]|0)|0;do if((u[t[(t[(t[a>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)!=32){if(9<=(u[t[(t[(t[a>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)?(u[t[(t[(t[a>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)<=10:0)break;if((u[t[(t[(t[a>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)!=13)BS(t[a>>2]|0,65,66056)}while(0);uE(t[a>>2]|0)|0;t[l>>2]=_E(t[a>>2]|0)|0;if(!(t[l>>2]|0))AS(t[a>>2]|0,70,0)}else k=23;if(((((((k|0)==23?(u[t[(t[(t[a>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==80:0)?(u[(t[(t[(t[a>>2]|0)+36>>2]|0)+16>>2]|0)+1>>0]|0|0)==85:0)?(u[(t[(t[(t[a>>2]|0)+36>>2]|0)+16>>2]|0)+2>>0]|0|0)==66:0)?(u[(t[(t[(t[a>>2]|0)+36>>2]|0)+16>>2]|0)+3>>0]|0|0)==76:0)?(u[(t[(t[(t[a>>2]|0)+36>>2]|0)+16>>2]|0)+4>>0]|0|0)==73:0)?(u[(t[(t[(t[a>>2]|0)+36>>2]|0)+16>>2]|0)+5>>0]|0|0)==67:0){k=(t[a>>2]|0)+200|0;t[k>>2]=(t[k>>2]|0)+6;k=(t[(t[a>>2]|0)+36>>2]|0)+16|0;t[k>>2]=(t[k>>2]|0)+6;k=(t[(t[a>>2]|0)+36>>2]|0)+32|0;t[k>>2]=(t[k>>2]|0)+6;if((u[t[(t[(t[a>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==37)oE(t[a>>2]|0);if((u[t[(t[(t[a>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==0?(yp(t[(t[a>>2]|0)+36>>2]|0,250)|0)<=0:0)aE(t[a>>2]|0)|0;do if((u[t[(t[(t[a>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)!=32){if(9<=(u[t[(t[(t[a>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)?(u[t[(t[(t[a>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)<=10:0)break;if((u[t[(t[(t[a>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)!=13)BS(t[a>>2]|0,65,66088)}while(0);uE(t[a>>2]|0)|0;k=pE(t[a>>2]|0)|0;t[t[o>>2]>>2]=k;if(!(t[t[o>>2]>>2]|0))AS(t[a>>2]|0,71,0);o=t[a>>2]|0;do if(t[c>>2]|0){if((u[t[(t[o+36>>2]|0)+16>>2]>>0]|0|0)!=32){if(9<=(u[t[(t[(t[a>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)?(u[t[(t[(t[a>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)<=10:0)break;if((u[t[(t[(t[a>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)!=13)BS(t[a>>2]|0,65,66120)}}else{if((t[o+292>>2]|0)==0?((t[(t[(t[a>>2]|0)+36>>2]|0)+20>>2]|0)-(t[(t[(t[a>>2]|0)+36>>2]|0)+16>>2]|0)|0)<250:0)CS(t[a>>2]|0);t[b>>2]=t[(t[(t[a>>2]|0)+36>>2]|0)+16>>2];do if((u[t[b>>2]>>0]|0|0)!=32){if(9<=(u[t[b>>2]>>0]|0|0)?(u[t[b>>2]>>0]|0|0)<=10:0)break;if((u[t[b>>2]>>0]|0|0)!=13){t[f>>2]=0;h=t[f>>2]|0;s=n;return h|0}}while(0);while(1){do if((u[t[b>>2]>>0]|0|0)==32)w=1;else{if(9<=(u[t[b>>2]>>0]|0|0)?(u[t[b>>2]>>0]|0|0)<=10:0){w=1;break}w=(u[t[b>>2]>>0]|0|0)==13}while(0);d=t[b>>2]|0;if(!w)break;t[b>>2]=d+1}if((u[d>>0]|0|0)!=39?(u[t[b>>2]>>0]|0|0)!=34:0){t[f>>2]=0;h=t[f>>2]|0;s=n;return h|0}}while(0);uE(t[a>>2]|0)|0;t[l>>2]=_E(t[a>>2]|0)|0;if(!(t[l>>2]|0))AS(t[a>>2]|0,70,0)}t[f>>2]=t[l>>2];h=t[f>>2]|0;s=n;return h|0}function gE(e){e=e|0;var i=0,r=0,f=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0;i=s;s=s+48|0;r=i+36|0;f=i+32|0;a=i+28|0;o=i+24|0;c=i+20|0;l=i+16|0;b=i+12|0;k=i+8|0;h=i+4|0;w=i;t[r>>2]=e;t[f>>2]=0;t[a>>2]=100;t[o>>2]=0;t[b>>2]=0;if((u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)!=60){s=i;return}if((u[(t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)+1>>0]|0|0)!=33){s=i;return}if((u[(t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)+2>>0]|0|0)!=45){s=i;return}if((u[(t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)+3>>0]|0|0)!=45){s=i;return}t[c>>2]=t[(t[r>>2]|0)+172>>2];t[(t[r>>2]|0)+172>>2]=5;t[h>>2]=t[(t[(t[r>>2]|0)+36>>2]|0)+56>>2];e=(t[r>>2]|0)+200|0;t[e>>2]=(t[e>>2]|0)+4;e=(t[(t[r>>2]|0)+36>>2]|0)+16|0;t[e>>2]=(t[e>>2]|0)+4;e=(t[(t[r>>2]|0)+36>>2]|0)+32|0;t[e>>2]=(t[e>>2]|0)+4;if((u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==37)oE(t[r>>2]|0);if((u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==0?(yp(t[(t[r>>2]|0)+36>>2]|0,250)|0)<=0:0)aE(t[r>>2]|0)|0;if(((t[(t[r>>2]|0)+292>>2]|0)==0?((t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)-(t[(t[(t[r>>2]|0)+36>>2]|0)+12>>2]|0)|0)>500:0)?((t[(t[(t[r>>2]|0)+36>>2]|0)+20>>2]|0)-(t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)|0)<500:0)qS(t[r>>2]|0);if((t[(t[r>>2]|0)+292>>2]|0)==0?((t[(t[(t[r>>2]|0)+36>>2]|0)+20>>2]|0)-(t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)|0)<250:0)CS(t[r>>2]|0);t[l>>2]=t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2];e:while(1){if((u[t[l>>2]>>0]|0|0)==10)do{e=(t[(t[r>>2]|0)+36>>2]|0)+28|0;t[e>>2]=(t[e>>2]|0)+1;t[(t[(t[r>>2]|0)+36>>2]|0)+32>>2]=1;t[l>>2]=(t[l>>2]|0)+1}while((u[t[l>>2]>>0]|0|0)==10);
	i:while(1){t[k>>2]=t[(t[(t[r>>2]|0)+36>>2]|0)+32>>2];r:while(1){if(!((u[t[l>>2]>>0]|0|0)>45?(u[t[l>>2]>>0]|0|0)<=127:0))d=23;do if((d|0)==23){d=0;if((u[t[l>>2]>>0]|0|0)>=32?(u[t[l>>2]>>0]|0|0)<45:0)break;if((u[t[l>>2]>>0]|0|0)!=9)break r}while(0);t[l>>2]=(t[l>>2]|0)+1;t[k>>2]=(t[k>>2]|0)+1}t[(t[(t[r>>2]|0)+36>>2]|0)+32>>2]=t[k>>2];if((u[t[l>>2]>>0]|0|0)==10)while(1){e=(t[(t[r>>2]|0)+36>>2]|0)+28|0;t[e>>2]=(t[e>>2]|0)+1;t[(t[(t[r>>2]|0)+36>>2]|0)+32>>2]=1;t[l>>2]=(t[l>>2]|0)+1;if((u[t[l>>2]>>0]|0|0)!=10)continue i}t[b>>2]=(t[l>>2]|0)-(t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0);if(((t[b>>2]|0)>>>0>0?(t[t[r>>2]>>2]|0)!=0:0)?(t[(t[t[r>>2]>>2]|0)+80>>2]|0)!=0:0){if(t[f>>2]|0){if(((t[o>>2]|0)+(t[b>>2]|0)+1|0)>>>0>=(t[a>>2]|0)>>>0){t[a>>2]=(t[a>>2]|0)+((t[o>>2]|0)+(t[b>>2]|0)+100);t[w>>2]=MAi[t[135760>>2]&511](t[f>>2]|0,t[a>>2]|0)|0;if(!(t[w>>2]|0)){d=42;break e}t[f>>2]=t[w>>2]}}else{do if((u[t[l>>2]>>0]|0|0)==45){if((u[(t[l>>2]|0)+1>>0]|0|0)!=45){d=36;break}t[a>>2]=(t[b>>2]|0)+1}else d=36;while(0);if((d|0)==36){d=0;t[a>>2]=100+(t[b>>2]|0)}t[f>>2]=gAi[t[135752>>2]&511](t[a>>2]|0)|0;if(!(t[f>>2]|0)){d=38;break e}t[o>>2]=0}YY((t[f>>2]|0)+(t[o>>2]|0)|0,t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0,t[b>>2]|0)|0;t[o>>2]=(t[o>>2]|0)+(t[b>>2]|0);n[(t[f>>2]|0)+(t[o>>2]|0)>>0]=0}if((t[o>>2]|0)>>>0>1e7?(t[(t[r>>2]|0)+360>>2]&524288|0)==0:0){d=47;break e}t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]=t[l>>2];if((u[t[l>>2]>>0]|0|0)==10){t[l>>2]=(t[l>>2]|0)+1;e=(t[(t[r>>2]|0)+36>>2]|0)+28|0;t[e>>2]=(t[e>>2]|0)+1;t[(t[(t[r>>2]|0)+36>>2]|0)+32>>2]=1}if((u[t[l>>2]>>0]|0|0)==13){t[l>>2]=(t[l>>2]|0)+1;v=t[l>>2]|0;if((u[t[l>>2]>>0]|0|0)==10){d=52;break}t[l>>2]=v+-1}if(((t[(t[r>>2]|0)+292>>2]|0)==0?((t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)-(t[(t[(t[r>>2]|0)+36>>2]|0)+12>>2]|0)|0)>500:0)?((t[(t[(t[r>>2]|0)+36>>2]|0)+20>>2]|0)-(t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)|0)<500:0)qS(t[r>>2]|0);if((t[(t[r>>2]|0)+292>>2]|0)==0?((t[(t[(t[r>>2]|0)+36>>2]|0)+20>>2]|0)-(t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)|0)<250:0)CS(t[r>>2]|0);if((t[(t[r>>2]|0)+172>>2]|0)==-1){d=62;break e}t[l>>2]=t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2];if((u[t[l>>2]>>0]|0|0)!=45)break;if((u[(t[l>>2]|0)+1>>0]|0|0)==45){if((u[(t[l>>2]|0)+2>>0]|0|0)==62){d=66;break e}e=t[r>>2]|0;if(t[f>>2]|0)MS(e,80,66248,t[f>>2]|0);else MS(e,80,66296,0);t[l>>2]=(t[l>>2]|0)+1;e=(t[(t[r>>2]|0)+36>>2]|0)+32|0;t[e>>2]=(t[e>>2]|0)+1}t[l>>2]=(t[l>>2]|0)+1;e=(t[(t[r>>2]|0)+36>>2]|0)+32|0;t[e>>2]=(t[e>>2]|0)+1}if((d|0)==52){d=0;t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]=v;t[l>>2]=(t[l>>2]|0)+1;e=(t[(t[r>>2]|0)+36>>2]|0)+28|0;t[e>>2]=(t[e>>2]|0)+1;t[(t[(t[r>>2]|0)+36>>2]|0)+32>>2]=1}if((u[t[l>>2]>>0]|0|0)>=32?(u[t[l>>2]>>0]|0|0)<=127:0)continue;if((u[t[l>>2]>>0]|0|0)!=9){d=91;break}}if((d|0)==38){Sp(t[r>>2]|0,0);t[(t[r>>2]|0)+172>>2]=t[c>>2];s=i;return}else if((d|0)==42){pAi[t[135736>>2]&511](t[f>>2]|0);Sp(t[r>>2]|0,0);t[(t[r>>2]|0)+172>>2]=t[c>>2];s=i;return}else if((d|0)==47){MS(t[r>>2]|0,45,66168,0);pAi[t[135736>>2]&511](t[f>>2]|0);s=i;return}else if((d|0)==62){pAi[t[135736>>2]&511](t[f>>2]|0);s=i;return}else if((d|0)==66){if((t[(t[(t[r>>2]|0)+36>>2]|0)+56>>2]|0)!=(t[h>>2]|0))BS(t[r>>2]|0,90,66192);h=(t[r>>2]|0)+200|0;t[h>>2]=(t[h>>2]|0)+3;h=(t[(t[r>>2]|0)+36>>2]|0)+16|0;t[h>>2]=(t[h>>2]|0)+3;h=(t[(t[r>>2]|0)+36>>2]|0)+32|0;t[h>>2]=(t[h>>2]|0)+3;if((u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==37)oE(t[r>>2]|0);if((u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==0?(yp(t[(t[r>>2]|0)+36>>2]|0,250)|0)<=0:0)aE(t[r>>2]|0)|0;do if(((t[t[r>>2]>>2]|0)!=0?(t[(t[t[r>>2]>>2]|0)+80>>2]|0)!=0:0)?(t[(t[r>>2]|0)+212>>2]|0)==0:0){h=t[(t[t[r>>2]>>2]|0)+80>>2]|0;l=t[(t[r>>2]|0)+4>>2]|0;if(t[f>>2]|0){EAi[h&511](l,t[f>>2]|0);break}else{EAi[h&511](l,65640);break}}while(0);if(t[f>>2]|0)pAi[t[135736>>2]&511](t[f>>2]|0);if((t[(t[r>>2]|0)+172>>2]|0)==-1){s=i;return}t[(t[r>>2]|0)+172>>2]=t[c>>2];s=i;return}else if((d|0)==91){WS(t[r>>2]|0,t[f>>2]|0,t[o>>2]|0,t[a>>2]|0);t[(t[r>>2]|0)+172>>2]=t[c>>2];s=i;return}}function yE(e){e=e|0;var i=0,r=0,n=0,f=0,a=0,o=0,c=0;i=s;s=s+16|0;r=i+12|0;n=i+8|0;f=i+4|0;a=i;t[n>>2]=e;t[f>>2]=sE(t[n>>2]|0)|0;do if(t[f>>2]|0){if((u[t[f>>2]>>0]|0|0)!=120?(u[t[f>>2]>>0]|0|0)!=88:0)break;if((u[(t[f>>2]|0)+1>>0]|0|0)!=109?(u[(t[f>>2]|0)+1>>0]|0|0)!=77:0)break;if((u[(t[f>>2]|0)+2>>0]|0|0)!=108?(u[(t[f>>2]|0)+2>>0]|0|0)!=76:0)break;if((((u[t[f>>2]>>0]|0|0)==120?(u[(t[f>>2]|0)+1>>0]|0|0)==109:0)?(u[(t[f>>2]|0)+2>>0]|0|0)==108:0)?(u[(t[f>>2]|0)+3>>0]|0|0)==0:0){BS(t[n>>2]|0,64,66328);t[r>>2]=t[f>>2];o=t[r>>2]|0;s=i;return o|0}if(!(u[(t[f>>2]|0)+3>>0]|0)){AS(t[n>>2]|0,64,0);t[r>>2]=t[f>>2];o=t[r>>2]|0;s=i;return o|0}t[a>>2]=0;while(1){if(!(t[66392+(t[a>>2]<<2)>>2]|0)){c=20;break}if(Xl(t[f>>2]|0,t[66392+(t[a>>2]<<2)>>2]|0)|0)break;t[a>>2]=(t[a>>2]|0)+1}if((c|0)==20){NS(t[n>>2]|0,64,66408,0,0);break}t[r>>2]=t[f>>2];o=t[r>>2]|0;s=i;return o|0}while(0);if((t[f>>2]|0)!=0?(es(t[f>>2]|0,58)|0)!=0:0)KS(t[n>>2]|0,205,66456,t[f>>2]|0,0,0);t[r>>2]=t[f>>2];o=t[r>>2]|0;s=i;return o|0}function FE(e){e=e|0;var i=0,r=0,f=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0,S=0,g=0;i=s;s=s+64|0;r=i+48|0;f=i+44|0;a=i+40|0;o=i+36|0;c=i+32|0;l=i+28|0;b=i+24|0;k=i+20|0;h=i+16|0;w=i+12|0;d=i+8|0;v=i+4|0;m=i;t[r>>2]=e;t[f>>2]=0;t[a>>2]=0;t[o>>2]=100;t[h>>2]=0;if((u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)!=60){s=i;return}if((u[(t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)+1>>0]|0|0)!=63){s=i;return}t[w>>2]=t[(t[r>>2]|0)+36>>2];t[k>>2]=t[(t[r>>2]|0)+172>>2];t[(t[r>>2]|0)+172>>2]=2;e=(t[r>>2]|0)+200|0;t[e>>2]=(t[e>>2]|0)+2;e=(t[(t[r>>2]|0)+36>>2]|0)+16|0;t[e>>2]=(t[e>>2]|0)+2;e=(t[(t[r>>2]|0)+36>>2]|0)+32|0;t[e>>2]=(t[e>>2]|0)+2;if((u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==37)oE(t[r>>2]|0);if((u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==0?(yp(t[(t[r>>2]|0)+36>>2]|0,250)|0)<=0:0)aE(t[r>>2]|0)|0;if(((t[(t[r>>2]|0)+292>>2]|0)==0?((t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)-(t[(t[(t[r>>2]|0)+36>>2]|0)+12>>2]|0)|0)>500:0)?((t[(t[(t[r>>2]|0)+36>>2]|0)+20>>2]|0)-(t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)|0)<500:0)qS(t[r>>2]|0);t[b>>2]=yE(t[r>>2]|0)|0;e=t[r>>2]|0;do if(t[b>>2]|0){if((u[t[(t[e+36>>2]|0)+16>>2]>>0]|0|0)==63?(u[(t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)+1>>0]|0|0)==62:0){if((t[w>>2]|0)!=(t[(t[r>>2]|0)+36>>2]|0))BS(t[r>>2]|0,90,66504);_=(t[r>>2]|0)+200|0;t[_>>2]=(t[_>>2]|0)+2;_=(t[(t[r>>2]|0)+36>>2]|0)+16|0;t[_>>2]=(t[_>>2]|0)+2;_=(t[(t[r>>2]|0)+36>>2]|0)+32|0;t[_>>2]=(t[_>>2]|0)+2;if((u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==37)oE(t[r>>2]|0);if((u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==0?(yp(t[(t[r>>2]|0)+36>>2]|0,250)|0)<=0:0)aE(t[r>>2]|0)|0;if(((t[t[r>>2]>>2]|0)!=0?(t[(t[r>>2]|0)+212>>2]|0)==0:0)?(t[(t[t[r>>2]>>2]|0)+76>>2]|0)!=0:0)yAi[t[(t[t[r>>2]>>2]|0)+76>>2]&511](t[(t[r>>2]|0)+4>>2]|0,t[b>>2]|0,0);if((t[(t[r>>2]|0)+172>>2]|0)==-1){s=i;return}t[(t[r>>2]|0)+172>>2]=t[k>>2];s=i;return}t[f>>2]=gAi[t[135752>>2]&511](t[o>>2]|0)|0;_=t[r>>2]|0;if(!(t[f>>2]|0)){Sp(_,0);t[(t[r>>2]|0)+172>>2]=t[k>>2];s=i;return}t[c>>2]=u[t[(t[_+36>>2]|0)+16>>2]>>0];if((t[c>>2]|0)<256){if((t[c>>2]|0)!=32?!(9<=(t[c>>2]|0)&(t[c>>2]|0)<=10|(t[c>>2]|0)==13):0)p=33}else p=33;if((p|0)==33)MS(t[r>>2]|0,65,66568,t[b>>2]|0);uE(t[r>>2]|0)|0;t[c>>2]=Ap(t[r>>2]|0,l)|0;while(1){_=t[c>>2]|0;if((t[c>>2]|0)<256)if(9<=(_|0)&(t[c>>2]|0)<=10|(t[c>>2]|0)==13|32<=(t[c>>2]|0))p=40;else E=0;else if((!(256<=(_|0)&(t[c>>2]|0)<=55295)?!(57344<=(t[c>>2]|0)&(t[c>>2]|0)<=65533):0)?!(65536<=(t[c>>2]|0)&(t[c>>2]|0)<=1114111):0)E=0;else p=40;if((p|0)==40){p=0;if((t[c>>2]|0)!=63)E=1;else E=(u[(t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)+1>>0]|0|0)!=62}S=t[a>>2]|0;if(!E){p=73;break}if((S+5|0)>>>0>=(t[o>>2]|0)>>>0){t[v>>2]=t[o>>2]<<1;t[d>>2]=MAi[t[135760>>2]&511](t[f>>2]|0,t[v>>2]|0)|0;if(!(t[d>>2]|0)){p=45;break}t[f>>2]=t[d>>2];t[o>>2]=t[v>>2]}t[h>>2]=(t[h>>2]|0)+1;if((t[h>>2]|0)>50){if((t[(t[r>>2]|0)+292>>2]|0)==0?((t[(t[(t[r>>2]|0)+36>>2]|0)+20>>2]|0)-(t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)|0)<250:0)CS(t[r>>2]|0);if((t[(t[r>>2]|0)+172>>2]|0)==-1){p=52;break}t[h>>2]=0;if((t[a>>2]|0)>>>0>1e7?(t[(t[r>>2]|0)+360>>2]&524288|0)==0:0){p=55;break}}if((t[l>>2]|0)==1){_=t[c>>2]&255;g=t[a>>2]|0;t[a>>2]=g+1;n[(t[f>>2]|0)+g>>0]=_}else{_=Rp((t[f>>2]|0)+(t[a>>2]|0)|0,t[c>>2]|0)|0;t[a>>2]=(t[a>>2]|0)+_}_=t[(t[r>>2]|0)+36>>2]|0;if((u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==10){g=_+28|0;t[g>>2]=(t[g>>2]|0)+1;t[(t[(t[r>>2]|0)+36>>2]|0)+32>>2]=1}else{g=_+32|0;t[g>>2]=(t[g>>2]|0)+1}g=(t[(t[r>>2]|0)+36>>2]|0)+16|0;t[g>>2]=(t[g>>2]|0)+(t[l>>2]|0);if((u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==37)oE(t[r>>2]|0);t[c>>2]=Ap(t[r>>2]|0,l)|0;if(t[c>>2]|0)continue;do if(!(t[(t[r>>2]|0)+292>>2]|0)){if(((t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)-(t[(t[(t[r>>2]|0)+36>>2]|0)+12>>2]|0)|0)<=500)break;if(((t[(t[(t[r>>2]|0)+36>>2]|0)+20>>2]|0)-(t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)|0)>=500)break;qS(t[r>>2]|0)}while(0);do if(!(t[(t[r>>2]|0)+292>>2]|0)){if(((t[(t[(t[r>>2]|0)+36>>2]|0)+20>>2]|0)-(t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)|0)>=250)break;CS(t[r>>2]|0)}while(0);t[c>>2]=Ap(t[r>>2]|0,l)|0}if((p|0)==45){Sp(t[r>>2]|0,0);pAi[t[135736>>2]&511](t[f>>2]|0);t[(t[r>>2]|0)+172>>2]=t[k>>2];s=i;return}else if((p|0)==52){pAi[t[135736>>2]&511](t[f>>2]|0);s=i;return}else if((p|0)==55){MS(t[r>>2]|0,47,66600,t[b>>2]|0);pAi[t[135736>>2]&511](t[f>>2]|0);t[(t[r>>2]|0)+172>>2]=t[k>>2];s=i;return}else if((p|0)==73){if(S>>>0>1e7?(t[(t[r>>2]|0)+360>>2]&524288|0)==0:0){MS(t[r>>2]|0,47,66600,t[b>>2]|0);pAi[t[135736>>2]&511](t[f>>2]|0);t[(t[r>>2]|0)+172>>2]=t[k>>2];s=i;return}n[(t[f>>2]|0)+(t[a>>2]|0)>>0]=0;do if((t[c>>2]|0)==63){if((t[w>>2]|0)!=(t[(t[r>>2]|0)+36>>2]|0))BS(t[r>>2]|0,65,66504);g=(t[r>>2]|0)+200|0;t[g>>2]=(t[g>>2]|0)+2;g=(t[(t[r>>2]|0)+36>>2]|0)+16|0;t[g>>2]=(t[g>>2]|0)+2;g=(t[(t[r>>2]|0)+36>>2]|0)+32|0;t[g>>2]=(t[g>>2]|0)+2;if((u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==37)oE(t[r>>2]|0);if((u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==0?(yp(t[(t[r>>2]|0)+36>>2]|0,250)|0)<=0:0)aE(t[r>>2]|0)|0;do if((t[k>>2]|0)==1|(t[k>>2]|0)==0?(Xl(t[b>>2]|0,66656)|0)!=0:0){t[m>>2]=sc()|0;if(!((t[m>>2]|0)==2|(t[m>>2]|0)==3))break;XS(t[r>>2]|0,t[f>>2]|0)}while(0);if((t[t[r>>2]>>2]|0)!=0?(t[(t[r>>2]|0)+212>>2]|0)==0:0){if(!(t[(t[t[r>>2]>>2]|0)+76>>2]|0))break;yAi[t[(t[t[r>>2]>>2]|0)+76>>2]&511](t[(t[r>>2]|0)+4>>2]|0,t[b>>2]|0,t[f>>2]|0)}}else MS(t[r>>2]|0,47,66624,t[b>>2]|0);while(0);pAi[t[135736>>2]&511](t[f>>2]|0);break}}else AS(e,46,0);while(0);if((t[(t[r>>2]|0)+172>>2]|0)==-1){s=i;return}t[(t[r>>2]|0)+172>>2]=t[k>>2];s=i;return}function OE(e){e=e|0;var i=0,r=0,n=0,f=0,a=0,o=0;i=s;s=s+32|0;r=i+16|0;n=i+12|0;f=i+8|0;a=i+4|0;o=i;t[r>>2]=e;if((u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)!=60){s=i;return}if((u[(t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)+1>>0]|0|0)!=33){s=i;return}if((u[(t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)+2>>0]|0|0)!=78){s=i;return}if((u[(t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)+3>>0]|0|0)!=79){s=i;return}if((u[(t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)+4>>0]|0|0)!=84){s=i;return}if((u[(t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)+5>>0]|0|0)!=65){s=i;return}if((u[(t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)+6>>0]|0|0)!=84){s=i;return}if((u[(t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)+7>>0]|0|0)!=73){s=i;return}if((u[(t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)+8>>0]|0|0)!=79){s=i;return}if((u[(t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)+9>>0]|0|0)!=78){s=i;return}t[o>>2]=t[(t[r>>2]|0)+36>>2];if(((t[(t[r>>2]|0)+292>>2]|0)==0?((t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)-(t[(t[(t[r>>2]|0)+36>>2]|0)+12>>2]|0)|0)>500:0)?((t[(t[(t[r>>2]|0)+36>>2]|0)+20>>2]|0)-(t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)|0)<500:0)qS(t[r>>2]|0);e=(t[r>>2]|0)+200|0;t[e>>2]=(t[e>>2]|0)+10;e=(t[(t[r>>2]|0)+36>>2]|0)+16|0;t[e>>2]=(t[e>>2]|0)+10;e=(t[(t[r>>2]|0)+36>>2]|0)+32|0;t[e>>2]=(t[e>>2]|0)+10;if((u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==37)oE(t[r>>2]|0);if((u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==0?(yp(t[(t[r>>2]|0)+36>>2]|0,250)|0)<=0:0)aE(t[r>>2]|0)|0;do if((u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)!=32){if(9<=(u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)?(u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)<=10:0)break;if((u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)!=13){BS(t[r>>2]|0,65,66680);s=i;return}}while(0);uE(t[r>>2]|0)|0;t[n>>2]=sE(t[r>>2]|0)|0;e=t[r>>2]|0;if(!(t[n>>2]|0)){AS(e,48,0);s=i;return}do if((u[t[(t[e+36>>2]|0)+16>>2]>>0]|0|0)!=32){if(9<=(u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)?(u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)<=10:0)break;if((u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)!=13){BS(t[r>>2]|0,65,66720);s=i;return}}while(0);if(es(t[n>>2]|0,58)|0)KS(t[r>>2]|0,205,66768,t[n>>2]|0,0,0);uE(t[r>>2]|0)|0;t[a>>2]=SE(t[r>>2]|0,f,0)|0;uE(t[r>>2]|0)|0;do if((u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==62){if((t[o>>2]|0)!=(t[(t[r>>2]|0)+36>>2]|0))BS(t[r>>2]|0,65,66816);Op(t[r>>2]|0);if(!(t[t[r>>2]>>2]|0))break;if(t[(t[r>>2]|0)+212>>2]|0)break;if(!(t[(t[t[r>>2]>>2]|0)+28>>2]|0))break;NAi[t[(t[t[r>>2]>>2]|0)+28>>2]&511](t[(t[r>>2]|0)+4>>2]|0,t[n>>2]|0,t[f>>2]|0,t[a>>2]|0)}else AS(t[r>>2]|0,49,0);while(0);if(t[a>>2]|0)pAi[t[135736>>2]&511](t[a>>2]|0);if(!(t[f>>2]|0)){s=i;return}pAi[t[135736>>2]&511](t[f>>2]|0);s=i;return}function AE(e){e=e|0;var i=0,r=0,n=0,f=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0;i=s;s=s+64|0;r=i+48|0;n=i+44|0;f=i+40|0;a=i+36|0;o=i+32|0;c=i+28|0;l=i+24|0;b=i+20|0;k=i+16|0;h=i+12|0;w=i+8|0;d=i+4|0;v=i;t[r>>2]=e;t[n>>2]=0;t[f>>2]=0;t[a>>2]=0;t[o>>2]=0;t[c>>2]=0;t[l>>2]=0;t[b>>2]=0;if((u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)!=60){s=i;return}if((u[(t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)+1>>0]|0|0)!=33){s=i;return}if((u[(t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)+2>>0]|0|0)!=69){s=i;return}if((u[(t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)+3>>0]|0|0)!=78){s=i;return}if((u[(t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)+4>>0]|0|0)!=84){s=i;return}if((u[(t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)+5>>0]|0|0)!=73){s=i;return}if((u[(t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)+6>>0]|0|0)!=84){s=i;return}if((u[(t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)+7>>0]|0|0)!=89){s=i;return}t[h>>2]=t[(t[r>>2]|0)+36>>2];if(((t[(t[r>>2]|0)+292>>2]|0)==0?((t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)-(t[(t[(t[r>>2]|0)+36>>2]|0)+12>>2]|0)|0)>500:0)?((t[(t[(t[r>>2]|0)+36>>2]|0)+20>>2]|0)-(t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)|0)<500:0)qS(t[r>>2]|0);e=(t[r>>2]|0)+200|0;t[e>>2]=(t[e>>2]|0)+8;e=(t[(t[r>>2]|0)+36>>2]|0)+16|0;t[e>>2]=(t[e>>2]|0)+8;e=(t[(t[r>>2]|0)+36>>2]|0)+32|0;t[e>>2]=(t[e>>2]|0)+8;if((u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==37)oE(t[r>>2]|0);if((u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==0?(yp(t[(t[r>>2]|0)+36>>2]|0,250)|0)<=0:0)aE(t[r>>2]|0)|0;t[k>>2]=uE(t[r>>2]|0)|0;if(!(t[k>>2]|0))BS(t[r>>2]|0,65,66880);if((u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==37){Op(t[r>>2]|0);t[k>>2]=uE(t[r>>2]|0)|0;if(!(t[k>>2]|0))BS(t[r>>2]|0,65,66920);t[l>>2]=1}t[n>>2]=sE(t[r>>2]|0)|0;if(!(t[n>>2]|0)){BS(t[r>>2]|0,68,66952);s=i;return}if(es(t[n>>2]|0,58)|0)KS(t[r>>2]|0,205,66984,t[n>>2]|0,0,0);t[k>>2]=uE(t[r>>2]|0)|0;if(!(t[k>>2]|0))BS(t[r>>2]|0,65,67032);t[(t[r>>2]|0)+172>>2]=10;k=(u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==34;e:do if(t[l>>2]|0){do if(!k){if((u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==39)break;t[a>>2]=SE(t[r>>2]|0,o,1)|0;if((t[a>>2]|0)==0&(t[o>>2]|0)==0)AS(t[r>>2]|0,84,0);if(!(t[a>>2]|0))break e;t[w>>2]=IA(t[a>>2]|0)|0;if(!(t[w>>2]|0)){ZS(t[r>>2]|0,91,67072,t[a>>2]|0);break e}e=t[r>>2]|0;do if(t[(t[w>>2]|0)+32>>2]|0)AS(e,92,0);else{if(!(t[e>>2]|0))break;if(t[(t[r>>2]|0)+212>>2]|0)break;if(!(t[(t[t[r>>2]>>2]|0)+24>>2]|0))break;AAi[t[(t[t[r>>2]>>2]|0)+24>>2]&511](t[(t[r>>2]|0)+4>>2]|0,t[n>>2]|0,5,t[o>>2]|0,t[a>>2]|0,0)}while(0);xA(t[w>>2]|0);break e}while(0);t[f>>2]=vE(t[r>>2]|0,b)|0;if(t[f>>2]|0){if(!(t[t[r>>2]>>2]|0))break;if(t[(t[r>>2]|0)+212>>2]|0)break;if(!(t[(t[t[r>>2]>>2]|0)+24>>2]|0))break;AAi[t[(t[t[r>>2]>>2]|0)+24>>2]&511](t[(t[r>>2]|0)+4>>2]|0,t[n>>2]|0,4,0,0,t[f>>2]|0)}}else{do if(!k){if((u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==39)break;t[a>>2]=SE(t[r>>2]|0,o,1)|0;if((t[a>>2]|0)==0&(t[o>>2]|0)==0)AS(t[r>>2]|0,84,0);do if(t[a>>2]|0){t[d>>2]=IA(t[a>>2]|0)|0;if(!(t[d>>2]|0)){ZS(t[r>>2]|0,91,67072,t[a>>2]|0);break}if(t[(t[d>>2]|0)+32>>2]|0)AS(t[r>>2]|0,92,0);xA(t[d>>2]|0)}while(0);do if((u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)!=62){if((u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==32)break;if(9<=(u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)?(u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)<=10:0)break;if((u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==13)break;BS(t[r>>2]|0,65,67152)}while(0);uE(t[r>>2]|0)|0;do if((u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==78){if((u[(t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)+1>>0]|0|0)!=68)break;if((u[(t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)+2>>0]|0|0)!=65)break;if((u[(t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)+3>>0]|0|0)!=84)break;if((u[(t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)+4>>0]|0|0)!=65)break;e=(t[r>>2]|0)+200|0;t[e>>2]=(t[e>>2]|0)+5;e=(t[(t[r>>2]|0)+36>>2]|0)+16|0;t[e>>2]=(t[e>>2]|0)+5;e=(t[(t[r>>2]|0)+36>>2]|0)+32|0;t[e>>2]=(t[e>>2]|0)+5;if((u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==37)oE(t[r>>2]|0);do if(!(u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0)){if((yp(t[(t[r>>2]|0)+36>>2]|0,250)|0)>0)break;aE(t[r>>2]|0)|0}while(0);do if((u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)!=32){if(9<=(u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)?(u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)<=10:0)break;if((u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==13)break;BS(t[r>>2]|0,65,67184)}while(0);uE(t[r>>2]|0)|0;t[c>>2]=sE(t[r>>2]|0)|0;if(!(t[t[r>>2]>>2]|0))break e;if(t[(t[r>>2]|0)+212>>2]|0)break e;if(!(t[(t[t[r>>2]>>2]|0)+40>>2]|0))break e;mAi[t[(t[t[r>>2]>>2]|0)+40>>2]&511](t[(t[r>>2]|0)+4>>2]|0,t[n>>2]|0,t[o>>2]|0,t[a>>2]|0,t[c>>2]|0);break e}while(0);do if(t[t[r>>2]>>2]|0){if(t[(t[r>>2]|0)+212>>2]|0)break;if(!(t[(t[t[r>>2]>>2]|0)+24>>2]|0))break;AAi[t[(t[t[r>>2]>>2]|0)+24>>2]&511](t[(t[r>>2]|0)+4>>2]|0,t[n>>2]|0,2,t[o>>2]|0,t[a>>2]|0,0)}while(0);if(!(t[(t[r>>2]|0)+16>>2]|0))break e;if((t[(t[r>>2]|0)+8>>2]|0)!=0?(Xl(t[(t[(t[r>>2]|0)+8>>2]|0)+56>>2]|0,67096)|0)==0:0)break e;do if(!(t[(t[r>>2]|0)+8>>2]|0)){e=ny(67096)|0;t[(t[r>>2]|0)+8>>2]=e;e=t[r>>2]|0;if(t[(t[r>>2]|0)+8>>2]|0){t[(t[e+8>>2]|0)+92>>2]=64;break}Sp(e,67128);s=i;return}while(0);if(!(t[(t[(t[r>>2]|0)+8>>2]|0)+44>>2]|0)){e=Jg(t[(t[r>>2]|0)+8>>2]|0,67144,0,0)|0;t[(t[(t[r>>2]|0)+8>>2]|0)+44>>2]=e}Bz(t[r>>2]|0,t[n>>2]|0,2,t[o>>2]|0,t[a>>2]|0,0);break e}while(0);t[f>>2]=vE(t[r>>2]|0,b)|0;do if(t[t[r>>2]>>2]|0){if(t[(t[r>>2]|0)+212>>2]|0)break;if(!(t[(t[t[r>>2]>>2]|0)+24>>2]|0))break;AAi[t[(t[t[r>>2]>>2]|0)+24>>2]&511](t[(t[r>>2]|0)+4>>2]|0,t[n>>2]|0,1,0,0,t[f>>2]|0)}while(0);if((t[(t[r>>2]|0)+8>>2]|0)!=0?(Xl(t[(t[(t[r>>2]|0)+8>>2]|0)+56>>2]|0,67096)|0)==0:0)break;do if(!(t[(t[r>>2]|0)+8>>2]|0)){e=ny(67096)|0;t[(t[r>>2]|0)+8>>2]=e;e=t[r>>2]|0;if(t[(t[r>>2]|0)+8>>2]|0){t[(t[e+8>>2]|0)+92>>2]=64;break}Sp(e,67128);s=i;return}while(0);if(!(t[(t[(t[r>>2]|0)+8>>2]|0)+44>>2]|0)){e=Jg(t[(t[r>>2]|0)+8>>2]|0,67144,0,0)|0;t[(t[(t[r>>2]|0)+8>>2]|0)+44>>2]=e}Bz(t[r>>2]|0,t[n>>2]|0,1,0,0,t[f>>2]|0)}while(0);if((t[(t[r>>2]|0)+172>>2]|0)==-1){s=i;return}uE(t[r>>2]|0)|0;if((u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)!=62)MS(t[r>>2]|0,37,67216,t[n>>2]|0);else{if((t[h>>2]|0)!=(t[(t[r>>2]|0)+36>>2]|0))BS(t[r>>2]|0,90,67264);Op(t[r>>2]|0)}do if(t[b>>2]|0){t[v>>2]=0;h=(t[t[r>>2]>>2]|0)!=0;do if(t[l>>2]|0){if(!h)break;if(!(t[(t[t[r>>2]>>2]|0)+96>>2]|0))break;t[v>>2]=MAi[t[(t[t[r>>2]>>2]|0)+96>>2]&511](t[(t[r>>2]|0)+4>>2]|0,t[n>>2]|0)|0}else{do if(h){if(!(t[(t[t[r>>2]>>2]|0)+20>>2]|0))break;t[v>>2]=MAi[t[(t[t[r>>2]>>2]|0)+20>>2]&511](t[(t[r>>2]|0)+4>>2]|0,t[n>>2]|0)|0}while(0);if(t[v>>2]|0)break;if((t[(t[r>>2]|0)+4>>2]|0)!=(t[r>>2]|0))break;t[v>>2]=Cz(t[r>>2]|0,t[n>>2]|0)|0}while(0);if(!(t[v>>2]|0)){pAi[t[135736>>2]&511](t[b>>2]|0);break}if(t[(t[v>>2]|0)+36>>2]|0){pAi[t[135736>>2]&511](t[b>>2]|0);break}else{t[(t[v>>2]|0)+36>>2]=t[b>>2];break}}while(0);if(t[f>>2]|0)pAi[t[135736>>2]&511](t[f>>2]|0);if(t[a>>2]|0)pAi[t[135736>>2]&511](t[a>>2]|0);if(!(t[o>>2]|0)){s=i;return}pAi[t[135736>>2]&511](t[o>>2]|0);s=i;return}function ME(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,a=0,o=0,c=0,l=0;r=s;s=s+32|0;n=r+16|0;f=r+12|0;a=r+8|0;o=r+4|0;c=r;t[f>>2]=e;t[a>>2]=i;t[t[a>>2]>>2]=0;if(((((((((u[t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==35?(u[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+1>>0]|0|0)==82:0)?(u[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+2>>0]|0|0)==69:0)?(u[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+3>>0]|0|0)==81:0)?(u[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+4>>0]|0|0)==85:0)?(u[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+5>>0]|0|0)==73:0)?(u[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+6>>0]|0|0)==82:0)?(u[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+7>>0]|0|0)==69:0)?(u[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+8>>0]|0|0)==68:0){i=(t[f>>2]|0)+200|0;t[i>>2]=(t[i>>2]|0)+9;i=(t[(t[f>>2]|0)+36>>2]|0)+16|0;t[i>>2]=(t[i>>2]|0)+9;i=(t[(t[f>>2]|0)+36>>2]|0)+32|0;t[i>>2]=(t[i>>2]|0)+9;if((u[t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==37)oE(t[f>>2]|0);if((u[t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==0?(yp(t[(t[f>>2]|0)+36>>2]|0,250)|0)<=0:0)aE(t[f>>2]|0)|0;t[n>>2]=2;l=t[n>>2]|0;s=r;return l|0}if((((((((u[t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==35?(u[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+1>>0]|0|0)==73:0)?(u[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+2>>0]|0|0)==77:0)?(u[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+3>>0]|0|0)==80:0)?(u[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+4>>0]|0|0)==76:0)?(u[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+5>>0]|0|0)==73:0)?(u[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+6>>0]|0|0)==69:0)?(u[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+7>>0]|0|0)==68:0){i=(t[f>>2]|0)+200|0;t[i>>2]=(t[i>>2]|0)+8;i=(t[(t[f>>2]|0)+36>>2]|0)+16|0;t[i>>2]=(t[i>>2]|0)+8;i=(t[(t[f>>2]|0)+36>>2]|0)+32|0;t[i>>2]=(t[i>>2]|0)+8;if((u[t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==37)oE(t[f>>2]|0);if((u[t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==0?(yp(t[(t[f>>2]|0)+36>>2]|0,250)|0)<=0:0)aE(t[f>>2]|0)|0;t[n>>2]=3;l=t[n>>2]|0;s=r;return l|0}t[o>>2]=1;if((((((u[t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==35?(u[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+1>>0]|0|0)==70:0)?(u[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+2>>0]|0|0)==73:0)?(u[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+3>>0]|0|0)==88:0)?(u[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+4>>0]|0|0)==69:0)?(u[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+5>>0]|0|0)==68:0){i=(t[f>>2]|0)+200|0;t[i>>2]=(t[i>>2]|0)+6;i=(t[(t[f>>2]|0)+36>>2]|0)+16|0;t[i>>2]=(t[i>>2]|0)+6;i=(t[(t[f>>2]|0)+36>>2]|0)+32|0;t[i>>2]=(t[i>>2]|0)+6;if((u[t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==37)oE(t[f>>2]|0);if((u[t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==0?(yp(t[(t[f>>2]|0)+36>>2]|0,250)|0)<=0:0)aE(t[f>>2]|0)|0;t[o>>2]=4;do if((u[t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)!=32){if(9<=(u[t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)?(u[t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)<=10:0)break;if((u[t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)!=13)BS(t[f>>2]|0,65,67328)}while(0);uE(t[f>>2]|0)|0}t[c>>2]=mE(t[f>>2]|0)|0;t[(t[f>>2]|0)+172>>2]=3;if(!(t[c>>2]|0))BS(t[f>>2]|0,t[(t[f>>2]|0)+84>>2]|0,67360);else t[t[a>>2]>>2]=t[c>>2];t[n>>2]=t[o>>2];l=t[n>>2]|0;s=r;return l|0}function RE(e){e=e|0;var i=0,r=0,n=0,f=0,a=0,o=0,c=0,l=0,b=0,k=0;i=s;s=s+32|0;r=i+24|0;n=i+20|0;f=i+16|0;a=i+12|0;o=i+8|0;c=i+4|0;l=i;t[n>>2]=e;t[a>>2]=0;t[o>>2]=0;e=t[n>>2]|0;if((u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)!=40){AS(e,48,0);t[r>>2]=0;b=t[r>>2]|0;s=i;return b|0}if(((t[e+292>>2]|0)==0?((t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]|0)-(t[(t[(t[n>>2]|0)+36>>2]|0)+12>>2]|0)|0)>500:0)?((t[(t[(t[n>>2]|0)+36>>2]|0)+20>>2]|0)-(t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]|0)|0)<500:0)qS(t[n>>2]|0);e:while(1){Op(t[n>>2]|0);uE(t[n>>2]|0)|0;t[f>>2]=sE(t[n>>2]|0)|0;if(!(t[f>>2]|0)){k=8;break}t[l>>2]=t[a>>2];while(1){if(!(t[l>>2]|0))break;if(Xl(t[f>>2]|0,t[(t[l>>2]|0)+4>>2]|0)|0){k=12;break}t[l>>2]=t[t[l>>2]>>2]}if((k|0)==12?(k=0,RS(t[n>>2]|0,541,67448,t[f>>2]|0,0),(wz(t[(t[n>>2]|0)+296>>2]|0,t[f>>2]|0)|0)==0):0)pAi[t[135736>>2]&511](t[f>>2]|0);do if(!(t[l>>2]|0)){t[c>>2]=RM(t[f>>2]|0)|0;if(!(t[c>>2]|0)){k=17;break e}e=t[c>>2]|0;if(!(t[o>>2]|0)){t[o>>2]=e;t[a>>2]=e;break}else{t[t[o>>2]>>2]=e;t[o>>2]=t[c>>2];break}}while(0);uE(t[n>>2]|0)|0;if((u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)!=124){k=22;break}}if((k|0)==8){BS(t[n>>2]|0,68,67408);NM(t[a>>2]|0);t[r>>2]=0;b=t[r>>2]|0;s=i;return b|0}else if((k|0)==17){NM(t[a>>2]|0);t[r>>2]=0;b=t[r>>2]|0;s=i;return b|0}else if((k|0)==22){k=t[n>>2]|0;if((u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)!=41){AS(k,49,0);NM(t[a>>2]|0);t[r>>2]=0;b=t[r>>2]|0;s=i;return b|0}else{Op(k);t[r>>2]=t[a>>2];b=t[r>>2]|0;s=i;return b|0}}return 0}function NE(e){e=e|0;var i=0,r=0,n=0,f=0,a=0,o=0,c=0,l=0,b=0,k=0;i=s;s=s+32|0;r=i+24|0;n=i+20|0;f=i+16|0;a=i+12|0;o=i+8|0;c=i+4|0;l=i;t[n>>2]=e;t[a>>2]=0;t[o>>2]=0;e=t[n>>2]|0;if((u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)!=40){AS(e,50,0);t[r>>2]=0;b=t[r>>2]|0;s=i;return b|0}if(((t[e+292>>2]|0)==0?((t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]|0)-(t[(t[(t[n>>2]|0)+36>>2]|0)+12>>2]|0)|0)>500:0)?((t[(t[(t[n>>2]|0)+36>>2]|0)+20>>2]|0)-(t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]|0)|0)<500:0)qS(t[n>>2]|0);e:while(1){Op(t[n>>2]|0);uE(t[n>>2]|0)|0;t[f>>2]=dE(t[n>>2]|0)|0;if(!(t[f>>2]|0)){k=8;break}t[l>>2]=t[a>>2];while(1){if(!(t[l>>2]|0))break;if(Xl(t[f>>2]|0,t[(t[l>>2]|0)+4>>2]|0)|0){k=12;break}t[l>>2]=t[t[l>>2]>>2]}if((k|0)==12?(k=0,RS(t[n>>2]|0,541,67512,t[f>>2]|0,0),(wz(t[(t[n>>2]|0)+296>>2]|0,t[f>>2]|0)|0)==0):0)pAi[t[135736>>2]&511](t[f>>2]|0);do if(!(t[l>>2]|0)){t[c>>2]=RM(t[f>>2]|0)|0;if(!(wz(t[(t[n>>2]|0)+296>>2]|0,t[f>>2]|0)|0))pAi[t[135736>>2]&511](t[f>>2]|0);if(!(t[c>>2]|0)){k=19;break e}e=t[c>>2]|0;if(!(t[o>>2]|0)){t[o>>2]=e;t[a>>2]=e;break}else{t[t[o>>2]>>2]=e;t[o>>2]=t[c>>2];break}}while(0);uE(t[n>>2]|0)|0;if((u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)!=124){k=24;break}}if((k|0)==8){AS(t[n>>2]|0,67,0);t[r>>2]=t[a>>2];b=t[r>>2]|0;s=i;return b|0}else if((k|0)==19){NM(t[a>>2]|0);t[r>>2]=0;b=t[r>>2]|0;s=i;return b|0}else if((k|0)==24){k=t[n>>2]|0;if((u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)!=41){AS(k,51,0);t[r>>2]=t[a>>2];b=t[r>>2]|0;s=i;return b|0}else{Op(k);t[r>>2]=t[a>>2];b=t[r>>2]|0;s=i;return b|0}}return 0}function TE(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,a=0,o=0;r=s;s=s+16|0;n=r+8|0;f=r+4|0;a=r;t[f>>2]=e;t[a>>2]=i;if((((((((u[t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==78?(u[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+1>>0]|0|0)==79:0)?(u[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+2>>0]|0|0)==84:0)?(u[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+3>>0]|0|0)==65:0)?(u[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+4>>0]|0|0)==84:0)?(u[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+5>>0]|0|0)==73:0)?(u[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+6>>0]|0|0)==79:0)?(u[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+7>>0]|0|0)==78:0){i=(t[f>>2]|0)+200|0;t[i>>2]=(t[i>>2]|0)+8;i=(t[(t[f>>2]|0)+36>>2]|0)+16|0;t[i>>2]=(t[i>>2]|0)+8;i=(t[(t[f>>2]|0)+36>>2]|0)+32|0;t[i>>2]=(t[i>>2]|0)+8;if((u[t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==37)oE(t[f>>2]|0);if((u[t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==0?(yp(t[(t[f>>2]|0)+36>>2]|0,250)|0)<=0:0)aE(t[f>>2]|0)|0;do if((u[t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)!=32){if(9<=(u[t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)?(u[t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)<=10:0)break;if((u[t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)!=13){BS(t[f>>2]|0,65,67576);t[n>>2]=0;o=t[n>>2]|0;s=r;return o|0}}while(0);uE(t[f>>2]|0)|0;i=RE(t[f>>2]|0)|0;t[t[a>>2]>>2]=i;if(!(t[t[a>>2]>>2]|0)){t[n>>2]=0;o=t[n>>2]|0;s=r;return o|0}else{t[n>>2]=10;o=t[n>>2]|0;s=r;return o|0}}i=NE(t[f>>2]|0)|0;t[t[a>>2]>>2]=i;if(!(t[t[a>>2]>>2]|0)){t[n>>2]=0;o=t[n>>2]|0;s=r;return o|0}else{t[n>>2]=9;o=t[n>>2]|0;s=r;return o|0}return 0}function LE(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,a=0,o=0;r=s;s=s+16|0;n=r+8|0;f=r+4|0;a=r;t[f>>2]=e;t[a>>2]=i;if(((t[(t[f>>2]|0)+292>>2]|0)==0?((t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)-(t[(t[(t[f>>2]|0)+36>>2]|0)+12>>2]|0)|0)>500:0)?((t[(t[(t[f>>2]|0)+36>>2]|0)+20>>2]|0)-(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)|0)<500:0)qS(t[f>>2]|0);if(((((u[t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==67?(u[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+1>>0]|0|0)==68:0)?(u[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+2>>0]|0|0)==65:0)?(u[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+3>>0]|0|0)==84:0)?(u[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+4>>0]|0|0)==65:0){i=(t[f>>2]|0)+200|0;t[i>>2]=(t[i>>2]|0)+5;i=(t[(t[f>>2]|0)+36>>2]|0)+16|0;t[i>>2]=(t[i>>2]|0)+5;i=(t[(t[f>>2]|0)+36>>2]|0)+32|0;t[i>>2]=(t[i>>2]|0)+5;if((u[t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==37)oE(t[f>>2]|0);if((u[t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==0?(yp(t[(t[f>>2]|0)+36>>2]|0,250)|0)<=0:0)aE(t[f>>2]|0)|0;t[n>>2]=1;o=t[n>>2]|0;s=r;return o|0}if((((((u[t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==73?(u[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+1>>0]|0|0)==68:0)?(u[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+2>>0]|0|0)==82:0)?(u[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+3>>0]|0|0)==69:0)?(u[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+4>>0]|0|0)==70:0)?(u[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+5>>0]|0|0)==83:0){i=(t[f>>2]|0)+200|0;t[i>>2]=(t[i>>2]|0)+6;i=(t[(t[f>>2]|0)+36>>2]|0)+16|0;t[i>>2]=(t[i>>2]|0)+6;i=(t[(t[f>>2]|0)+36>>2]|0)+32|0;t[i>>2]=(t[i>>2]|0)+6;if((u[t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==37)oE(t[f>>2]|0);if((u[t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==0?(yp(t[(t[f>>2]|0)+36>>2]|0,250)|0)<=0:0)aE(t[f>>2]|0)|0;t[n>>2]=4;o=t[n>>2]|0;s=r;return o|0}if(((((u[t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==73?(u[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+1>>0]|0|0)==68:0)?(u[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+2>>0]|0|0)==82:0)?(u[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+3>>0]|0|0)==69:0)?(u[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+4>>0]|0|0)==70:0){i=(t[f>>2]|0)+200|0;t[i>>2]=(t[i>>2]|0)+5;i=(t[(t[f>>2]|0)+36>>2]|0)+16|0;t[i>>2]=(t[i>>2]|0)+5;i=(t[(t[f>>2]|0)+36>>2]|0)+32|0;t[i>>2]=(t[i>>2]|0)+5;if((u[t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==37)oE(t[f>>2]|0);if((u[t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==0?(yp(t[(t[f>>2]|0)+36>>2]|0,250)|0)<=0:0)aE(t[f>>2]|0)|0;t[n>>2]=3;o=t[n>>2]|0;s=r;return o|0}if((u[t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==73?(u[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+1>>0]|0|0)==68:0){i=(t[f>>2]|0)+200|0;t[i>>2]=(t[i>>2]|0)+2;i=(t[(t[f>>2]|0)+36>>2]|0)+16|0;t[i>>2]=(t[i>>2]|0)+2;i=(t[(t[f>>2]|0)+36>>2]|0)+32|0;t[i>>2]=(t[i>>2]|0)+2;if((u[t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==37)oE(t[f>>2]|0);if((u[t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==0?(yp(t[(t[f>>2]|0)+36>>2]|0,250)|0)<=0:0)aE(t[f>>2]|0)|0;t[n>>2]=2;o=t[n>>2]|0;s=r;return o|0}if((((((u[t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==69?(u[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+1>>0]|0|0)==78:0)?(u[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+2>>0]|0|0)==84:0)?(u[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+3>>0]|0|0)==73:0)?(u[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+4>>0]|0|0)==84:0)?(u[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+5>>0]|0|0)==89:0){i=(t[f>>2]|0)+200|0;t[i>>2]=(t[i>>2]|0)+6;i=(t[(t[f>>2]|0)+36>>2]|0)+16|0;t[i>>2]=(t[i>>2]|0)+6;i=(t[(t[f>>2]|0)+36>>2]|0)+32|0;t[i>>2]=(t[i>>2]|0)+6;if((u[t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==37)oE(t[f>>2]|0);if((u[t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==0?(yp(t[(t[f>>2]|0)+36>>2]|0,250)|0)<=0:0)aE(t[f>>2]|0)|0;t[n>>2]=5;o=t[n>>2]|0;s=r;return o|0}if((((((((u[t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==69?(u[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+1>>0]|0|0)==78:0)?(u[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+2>>0]|0|0)==84:0)?(u[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+3>>0]|0|0)==73:0)?(u[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+4>>0]|0|0)==84:0)?(u[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+5>>0]|0|0)==73:0)?(u[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+6>>0]|0|0)==69:0)?(u[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+7>>0]|0|0)==83:0){i=(t[f>>2]|0)+200|0;t[i>>2]=(t[i>>2]|0)+8;i=(t[(t[f>>2]|0)+36>>2]|0)+16|0;t[i>>2]=(t[i>>2]|0)+8;i=(t[(t[f>>2]|0)+36>>2]|0)+32|0;t[i>>2]=(t[i>>2]|0)+8;if((u[t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==37)oE(t[f>>2]|0);if((u[t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==0?(yp(t[(t[f>>2]|0)+36>>2]|0,250)|0)<=0:0)aE(t[f>>2]|0)|0;t[n>>2]=6;o=t[n>>2]|0;s=r;return o|0}if((((((((u[t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==78?(u[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+1>>0]|0|0)==77:0)?(u[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+2>>0]|0|0)==84:0)?(u[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+3>>0]|0|0)==79:0)?(u[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+4>>0]|0|0)==75:0)?(u[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+5>>0]|0|0)==69:0)?(u[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+6>>0]|0|0)==78:0)?(u[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+7>>0]|0|0)==83:0){
	i=(t[f>>2]|0)+200|0;t[i>>2]=(t[i>>2]|0)+8;i=(t[(t[f>>2]|0)+36>>2]|0)+16|0;t[i>>2]=(t[i>>2]|0)+8;i=(t[(t[f>>2]|0)+36>>2]|0)+32|0;t[i>>2]=(t[i>>2]|0)+8;if((u[t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==37)oE(t[f>>2]|0);if((u[t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==0?(yp(t[(t[f>>2]|0)+36>>2]|0,250)|0)<=0:0)aE(t[f>>2]|0)|0;t[n>>2]=8;o=t[n>>2]|0;s=r;return o|0}if(((((((u[t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==78?(u[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+1>>0]|0|0)==77:0)?(u[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+2>>0]|0|0)==84:0)?(u[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+3>>0]|0|0)==79:0)?(u[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+4>>0]|0|0)==75:0)?(u[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+5>>0]|0|0)==69:0)?(u[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+6>>0]|0|0)==78:0){i=(t[f>>2]|0)+200|0;t[i>>2]=(t[i>>2]|0)+7;i=(t[(t[f>>2]|0)+36>>2]|0)+16|0;t[i>>2]=(t[i>>2]|0)+7;i=(t[(t[f>>2]|0)+36>>2]|0)+32|0;t[i>>2]=(t[i>>2]|0)+7;if((u[t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==37)oE(t[f>>2]|0);if((u[t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==0?(yp(t[(t[f>>2]|0)+36>>2]|0,250)|0)<=0:0)aE(t[f>>2]|0)|0;t[n>>2]=7;o=t[n>>2]|0;s=r;return o|0}t[n>>2]=TE(t[f>>2]|0,t[a>>2]|0)|0;o=t[n>>2]|0;s=r;return o|0}function DE(e){e=e|0;var i=0,r=0,n=0,f=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0;i=s;s=s+48|0;r=i+32|0;n=i+28|0;f=i+24|0;a=i+20|0;o=i+16|0;c=i+12|0;l=i+8|0;b=i+4|0;k=i;t[r>>2]=e;if((u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)!=60){s=i;return}if((u[(t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)+1>>0]|0|0)!=33){s=i;return}if((u[(t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)+2>>0]|0|0)!=65){s=i;return}if((u[(t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)+3>>0]|0|0)!=84){s=i;return}if((u[(t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)+4>>0]|0|0)!=84){s=i;return}if((u[(t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)+5>>0]|0|0)!=76){s=i;return}if((u[(t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)+6>>0]|0|0)!=73){s=i;return}if((u[(t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)+7>>0]|0|0)!=83){s=i;return}if((u[(t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)+8>>0]|0|0)!=84){s=i;return}t[o>>2]=t[(t[r>>2]|0)+36>>2];e=(t[r>>2]|0)+200|0;t[e>>2]=(t[e>>2]|0)+9;e=(t[(t[r>>2]|0)+36>>2]|0)+16|0;t[e>>2]=(t[e>>2]|0)+9;e=(t[(t[r>>2]|0)+36>>2]|0)+32|0;t[e>>2]=(t[e>>2]|0)+9;if((u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==37)oE(t[r>>2]|0);if((u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==0?(yp(t[(t[r>>2]|0)+36>>2]|0,250)|0)<=0:0)aE(t[r>>2]|0)|0;do if((u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)!=32){if(9<=(u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)?(u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)<=10:0)break;if((u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)!=13)BS(t[r>>2]|0,65,67616)}while(0);uE(t[r>>2]|0)|0;t[n>>2]=sE(t[r>>2]|0)|0;e=t[r>>2]|0;if(!(t[n>>2]|0)){BS(e,68,67656);s=i;return}uE(e)|0;if((t[(t[r>>2]|0)+292>>2]|0)==0?((t[(t[(t[r>>2]|0)+36>>2]|0)+20>>2]|0)-(t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)|0)<250:0)CS(t[r>>2]|0);e:while(1){if((u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==62)break;if((t[(t[r>>2]|0)+172>>2]|0)==-1)break;t[c>>2]=t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2];t[k>>2]=0;if((t[(t[r>>2]|0)+292>>2]|0)==0?((t[(t[(t[r>>2]|0)+36>>2]|0)+20>>2]|0)-(t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)|0)<250:0)CS(t[r>>2]|0);t[a>>2]=0;t[f>>2]=sE(t[r>>2]|0)|0;h=t[r>>2]|0;if(!(t[f>>2]|0)){w=31;break}do if(!(t[h+292>>2]|0)){if(((t[(t[(t[r>>2]|0)+36>>2]|0)+20>>2]|0)-(t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)|0)>=250)break;CS(t[r>>2]|0)}while(0);do if((u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)!=32){if(9<=(u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)?(u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)<=10:0)break;if((u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)!=13){w=39;break e}}while(0);uE(t[r>>2]|0)|0;t[l>>2]=LE(t[r>>2]|0,a)|0;if((t[l>>2]|0)<=0)break;do if(!(t[(t[r>>2]|0)+292>>2]|0)){if(((t[(t[(t[r>>2]|0)+36>>2]|0)+20>>2]|0)-(t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)|0)>=250)break;CS(t[r>>2]|0)}while(0);do if((u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)!=32){if(9<=(u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)?(u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)<=10:0)break;if((u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)!=13){w=48;break e}}while(0);uE(t[r>>2]|0)|0;t[b>>2]=ME(t[r>>2]|0,k)|0;if((t[b>>2]|0)<=0){w=51;break}if((t[l>>2]|0)!=1&(t[k>>2]|0)!=0)JS(t[k>>2]|0,t[k>>2]|0)|0;do if(!(t[(t[r>>2]|0)+292>>2]|0)){if(((t[(t[(t[r>>2]|0)+36>>2]|0)+20>>2]|0)-(t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)|0)>=250)break;CS(t[r>>2]|0)}while(0);if((u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)!=62){do if((u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)!=32){if(9<=(u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)?(u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)<=10:0)break;if((u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)!=13){w=65;break e}}while(0);uE(t[r>>2]|0)|0}d=t[r>>2]|0;if((t[c>>2]|0)==(t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)){w=71;break}do if(t[d>>2]|0){if(t[(t[r>>2]|0)+212>>2]|0){w=79;break}if(!(t[(t[t[r>>2]>>2]|0)+32>>2]|0)){w=79;break}vAi[t[(t[t[r>>2]>>2]|0)+32>>2]&511](t[(t[r>>2]|0)+4>>2]|0,t[n>>2]|0,t[f>>2]|0,t[l>>2]|0,t[b>>2]|0,t[k>>2]|0,t[a>>2]|0)}else w=79;while(0);do if((w|0)==79){w=0;if(!(t[a>>2]|0))break;NM(t[a>>2]|0)}while(0);if(((t[k>>2]|0)!=0?(t[(t[r>>2]|0)+324>>2]|0)!=0:0)&(t[b>>2]|0)!=3&(t[b>>2]|0)!=2)QS(t[r>>2]|0,t[n>>2]|0,t[f>>2]|0,t[k>>2]|0);if(t[(t[r>>2]|0)+324>>2]|0)$S(t[r>>2]|0,t[n>>2]|0,t[f>>2]|0,t[l>>2]|0);if(t[k>>2]|0)pAi[t[135736>>2]&511](t[k>>2]|0);if(t[(t[r>>2]|0)+292>>2]|0)continue;if(((t[(t[(t[r>>2]|0)+36>>2]|0)+20>>2]|0)-(t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)|0)>=250)continue;CS(t[r>>2]|0)}if((w|0)==31)BS(h,68,67688);else if((w|0)==39)BS(t[r>>2]|0,65,67720);else if((w|0)==48){BS(t[r>>2]|0,65,67768);if(t[a>>2]|0)NM(t[a>>2]|0)}else if((w|0)==51){if(t[k>>2]|0)pAi[t[135736>>2]&511](t[k>>2]|0);if(t[a>>2]|0)NM(t[a>>2]|0)}else if((w|0)==65){BS(t[r>>2]|0,65,67816);if(t[k>>2]|0)pAi[t[135736>>2]&511](t[k>>2]|0);if(t[a>>2]|0)NM(t[a>>2]|0)}else if((w|0)==71){AS(d,1,67872);if(t[k>>2]|0)pAi[t[135736>>2]&511](t[k>>2]|0);if(t[a>>2]|0)NM(t[a>>2]|0)}if((u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)!=62){s=i;return}if((t[o>>2]|0)!=(t[(t[r>>2]|0)+36>>2]|0))RS(t[r>>2]|0,90,67904,0,0);Op(t[r>>2]|0);s=i;return}function CE(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0;r=s;s=s+32|0;n=r+24|0;f=r+20|0;a=r+16|0;o=r+12|0;c=r+8|0;l=r+4|0;b=r;t[f>>2]=e;t[a>>2]=i;t[o>>2]=0;t[c>>2]=0;t[b>>2]=0;if((t[(t[f>>2]|0)+292>>2]|0)==0?((t[(t[(t[f>>2]|0)+36>>2]|0)+20>>2]|0)-(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)|0)<250:0)CS(t[f>>2]|0);do if(((((((u[t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==35?(u[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+1>>0]|0|0)==80:0)?(u[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+2>>0]|0|0)==67:0)?(u[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+3>>0]|0|0)==68:0)?(u[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+4>>0]|0|0)==65:0)?(u[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+5>>0]|0|0)==84:0)?(u[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+6>>0]|0|0)==65:0){i=(t[f>>2]|0)+200|0;t[i>>2]=(t[i>>2]|0)+7;i=(t[(t[f>>2]|0)+36>>2]|0)+16|0;t[i>>2]=(t[i>>2]|0)+7;i=(t[(t[f>>2]|0)+36>>2]|0)+32|0;t[i>>2]=(t[i>>2]|0)+7;if((u[t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==37)oE(t[f>>2]|0);if((u[t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==0?(yp(t[(t[f>>2]|0)+36>>2]|0,250)|0)<=0:0)aE(t[f>>2]|0)|0;uE(t[f>>2]|0)|0;if(((t[(t[f>>2]|0)+292>>2]|0)==0?((t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)-(t[(t[(t[f>>2]|0)+36>>2]|0)+12>>2]|0)|0)>500:0)?((t[(t[(t[f>>2]|0)+36>>2]|0)+20>>2]|0)-(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)|0)<500:0)qS(t[f>>2]|0);i=t[f>>2]|0;if((u[t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==41){if((t[i+104>>2]|0)!=0?(t[(t[(t[f>>2]|0)+36>>2]|0)+56>>2]|0)!=(t[a>>2]|0):0)RS(t[f>>2]|0,90,67976,0,0);Op(t[f>>2]|0);t[o>>2]=EM(t[(t[f>>2]|0)+8>>2]|0,0,1)|0;if(!(t[o>>2]|0)){t[n>>2]=0;k=t[n>>2]|0;s=r;return k|0}if((u[t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==42){t[(t[o>>2]|0)+4>>2]=3;Op(t[f>>2]|0)}t[n>>2]=t[o>>2];k=t[n>>2]|0;s=r;return k|0}if(!((u[t[(t[i+36>>2]|0)+16>>2]>>0]|0|0)!=40?(u[t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)!=124:0))h=31;if((h|0)==31?(i=EM(t[(t[f>>2]|0)+8>>2]|0,0,1)|0,t[c>>2]=i,t[o>>2]=i,(t[o>>2]|0)==0):0){t[n>>2]=0;k=t[n>>2]|0;s=r;return k|0}while(1){if((u[t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==124)w=(t[(t[f>>2]|0)+172>>2]|0)!=-1;else w=0;d=t[f>>2]|0;if(!w){h=54;break}Op(d);i=(t[b>>2]|0)==0;e=EM(t[(t[f>>2]|0)+8>>2]|0,0,4)|0;if(i){t[o>>2]=e;if(!(t[o>>2]|0)){h=38;break}t[(t[o>>2]|0)+12>>2]=t[c>>2];if(t[c>>2]|0)t[(t[c>>2]|0)+20>>2]=t[o>>2];t[c>>2]=t[o>>2]}else{t[l>>2]=e;if(!(t[l>>2]|0)){h=43;break}e=EM(t[(t[f>>2]|0)+8>>2]|0,t[b>>2]|0,2)|0;t[(t[l>>2]|0)+12>>2]=e;if(t[(t[l>>2]|0)+12>>2]|0)t[(t[(t[l>>2]|0)+12>>2]|0)+20>>2]=t[l>>2];t[(t[c>>2]|0)+16>>2]=t[l>>2];if(t[l>>2]|0)t[(t[l>>2]|0)+20>>2]=t[c>>2];t[c>>2]=t[l>>2]}uE(t[f>>2]|0)|0;t[b>>2]=sE(t[f>>2]|0)|0;v=t[f>>2]|0;if(!(t[b>>2]|0)){h=50;break}uE(v)|0;if(t[(t[f>>2]|0)+292>>2]|0)continue;if(((t[(t[(t[f>>2]|0)+36>>2]|0)+20>>2]|0)-(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)|0)>=250)continue;CS(t[f>>2]|0)}if((h|0)==38){t[n>>2]=0;k=t[n>>2]|0;s=r;return k|0}else if((h|0)==43){t[n>>2]=0;k=t[n>>2]|0;s=r;return k|0}else if((h|0)==50){BS(v,68,68048);yM(t[(t[f>>2]|0)+8>>2]|0,t[c>>2]|0);t[n>>2]=0;k=t[n>>2]|0;s=r;return k|0}else if((h|0)==54){if((u[t[(t[d+36>>2]|0)+16>>2]>>0]|0|0)==41?(u[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+1>>0]|0|0)==42:0){do if(t[b>>2]|0){e=EM(t[(t[f>>2]|0)+8>>2]|0,t[b>>2]|0,2)|0;t[(t[c>>2]|0)+16>>2]=e;if(!(t[(t[c>>2]|0)+16>>2]|0))break;t[(t[(t[c>>2]|0)+16>>2]|0)+20>>2]=t[c>>2]}while(0);if(t[o>>2]|0)t[(t[o>>2]|0)+4>>2]=3;do if(t[(t[f>>2]|0)+104>>2]|0){if((t[(t[(t[f>>2]|0)+36>>2]|0)+56>>2]|0)==(t[a>>2]|0))break;RS(t[f>>2]|0,90,67976,0,0)}while(0);e=(t[f>>2]|0)+200|0;t[e>>2]=(t[e>>2]|0)+2;e=(t[(t[f>>2]|0)+36>>2]|0)+16|0;t[e>>2]=(t[e>>2]|0)+2;e=(t[(t[f>>2]|0)+36>>2]|0)+32|0;t[e>>2]=(t[e>>2]|0)+2;if((u[t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==37)oE(t[f>>2]|0);if(u[t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]>>0]|0)break;if((yp(t[(t[f>>2]|0)+36>>2]|0,250)|0)>0)break;aE(t[f>>2]|0)|0;break}yM(t[(t[f>>2]|0)+8>>2]|0,t[o>>2]|0);AS(t[f>>2]|0,52,0);t[n>>2]=0;k=t[n>>2]|0;s=r;return k|0}}else h=70;while(0);if((h|0)==70)AS(t[f>>2]|0,69,0);t[n>>2]=t[o>>2];k=t[n>>2]|0;s=r;return k|0}function PE(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0;n=s;s=s+32|0;f=n+24|0;a=n+20|0;o=n+16|0;c=n+12|0;l=n+8|0;b=n+4|0;k=n;t[a>>2]=e;t[o>>2]=i;t[c>>2]=r;t[l>>2]=0;t[b>>2]=t[(t[(t[a>>2]|0)+36>>2]|0)+56>>2];t[t[c>>2]>>2]=0;r=t[a>>2]|0;if((u[t[(t[(t[a>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)!=40){MS(r,54,68104,t[o>>2]|0);t[f>>2]=-1;h=t[f>>2]|0;s=n;return h|0}Op(r);if((t[(t[a>>2]|0)+292>>2]|0)==0?((t[(t[(t[a>>2]|0)+36>>2]|0)+20>>2]|0)-(t[(t[(t[a>>2]|0)+36>>2]|0)+16>>2]|0)|0)<250:0)CS(t[a>>2]|0);if((t[(t[a>>2]|0)+172>>2]|0)==-1){t[f>>2]=-1;h=t[f>>2]|0;s=n;return h|0}uE(t[a>>2]|0)|0;if(((((((u[t[(t[(t[a>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==35?(u[(t[(t[(t[a>>2]|0)+36>>2]|0)+16>>2]|0)+1>>0]|0|0)==80:0)?(u[(t[(t[(t[a>>2]|0)+36>>2]|0)+16>>2]|0)+2>>0]|0|0)==67:0)?(u[(t[(t[(t[a>>2]|0)+36>>2]|0)+16>>2]|0)+3>>0]|0|0)==68:0)?(u[(t[(t[(t[a>>2]|0)+36>>2]|0)+16>>2]|0)+4>>0]|0|0)==65:0)?(u[(t[(t[(t[a>>2]|0)+36>>2]|0)+16>>2]|0)+5>>0]|0|0)==84:0)?(u[(t[(t[(t[a>>2]|0)+36>>2]|0)+16>>2]|0)+6>>0]|0|0)==65:0){t[l>>2]=CE(t[a>>2]|0,t[b>>2]|0)|0;t[k>>2]=3}else{t[l>>2]=eg(t[a>>2]|0,t[b>>2]|0,1)|0;t[k>>2]=4}uE(t[a>>2]|0)|0;t[t[c>>2]>>2]=t[l>>2];t[f>>2]=t[k>>2];h=t[f>>2]|0;s=n;return h|0}function BE(e){e=e|0;var i=0,r=0,n=0,f=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0;i=s;s=s+32|0;r=i+20|0;n=i+16|0;f=i+12|0;a=i+8|0;o=i+4|0;c=i;t[n>>2]=e;t[a>>2]=-1;t[o>>2]=0;e:do if(((((((((u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==60?(u[(t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]|0)+1>>0]|0|0)==33:0)?(u[(t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]|0)+2>>0]|0|0)==69:0)?(u[(t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]|0)+3>>0]|0|0)==76:0)?(u[(t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]|0)+4>>0]|0|0)==69:0)?(u[(t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]|0)+5>>0]|0|0)==77:0)?(u[(t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]|0)+6>>0]|0|0)==69:0)?(u[(t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]|0)+7>>0]|0|0)==78:0)?(u[(t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]|0)+8>>0]|0|0)==84:0){t[c>>2]=t[(t[n>>2]|0)+36>>2];e=(t[n>>2]|0)+200|0;t[e>>2]=(t[e>>2]|0)+9;e=(t[(t[n>>2]|0)+36>>2]|0)+16|0;t[e>>2]=(t[e>>2]|0)+9;e=(t[(t[n>>2]|0)+36>>2]|0)+32|0;t[e>>2]=(t[e>>2]|0)+9;if((u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==37)oE(t[n>>2]|0);if((u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==0?(yp(t[(t[n>>2]|0)+36>>2]|0,250)|0)<=0:0)aE(t[n>>2]|0)|0;do if((u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)!=32){if(9<=(u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)?(u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)<=10:0)break;if((u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)!=13)BS(t[n>>2]|0,65,68152)}while(0);uE(t[n>>2]|0)|0;t[f>>2]=sE(t[n>>2]|0)|0;if(!(t[f>>2]|0)){BS(t[n>>2]|0,68,68184);t[r>>2]=-1;l=t[r>>2]|0;s=i;return l|0}while(1){if(!(u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0))b=(t[(t[n>>2]|0)+40>>2]|0)>1;else b=0;k=t[n>>2]|0;if(!b)break;aE(k)|0}do if((u[t[(t[k+36>>2]|0)+16>>2]>>0]|0|0)!=32){if(9<=(u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)?(u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)<=10:0)break;if((u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)!=13)BS(t[n>>2]|0,65,68232)}while(0);uE(t[n>>2]|0)|0;do if((((u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==69?(u[(t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]|0)+1>>0]|0|0)==77:0)?(u[(t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]|0)+2>>0]|0|0)==80:0)?(u[(t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]|0)+3>>0]|0|0)==84:0){if((u[(t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]|0)+4>>0]|0|0)!=89){h=42;break}e=(t[n>>2]|0)+200|0;t[e>>2]=(t[e>>2]|0)+5;e=(t[(t[n>>2]|0)+36>>2]|0)+16|0;t[e>>2]=(t[e>>2]|0)+5;e=(t[(t[n>>2]|0)+36>>2]|0)+32|0;t[e>>2]=(t[e>>2]|0)+5;if((u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==37)oE(t[n>>2]|0);do if(!(u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0)){if((yp(t[(t[n>>2]|0)+36>>2]|0,250)|0)>0)break;aE(t[n>>2]|0)|0}while(0);t[a>>2]=1}else h=42;while(0);i:do if((h|0)==42){do if((u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==65?(u[(t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]|0)+1>>0]|0|0)==78:0){if((u[(t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]|0)+2>>0]|0|0)!=89)break;e=(t[n>>2]|0)+200|0;t[e>>2]=(t[e>>2]|0)+3;e=(t[(t[n>>2]|0)+36>>2]|0)+16|0;t[e>>2]=(t[e>>2]|0)+3;e=(t[(t[n>>2]|0)+36>>2]|0)+32|0;t[e>>2]=(t[e>>2]|0)+3;if((u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==37)oE(t[n>>2]|0);do if(!(u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0)){if((yp(t[(t[n>>2]|0)+36>>2]|0,250)|0)>0)break;aE(t[n>>2]|0)|0}while(0);t[a>>2]=2;break i}while(0);e=t[n>>2]|0;if((u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==40){t[a>>2]=PE(e,t[f>>2]|0,o)|0;break}do if((u[t[(t[e+36>>2]|0)+16>>2]>>0]|0|0)==37){if(t[(t[n>>2]|0)+96>>2]|0){h=57;break}if((t[(t[n>>2]|0)+40>>2]|0)!=1){h=57;break}BS(t[n>>2]|0,21,68272)}else h=57;while(0);if((h|0)==57)BS(t[n>>2]|0,54,68336);t[r>>2]=-1;l=t[r>>2]|0;s=i;return l|0}while(0);uE(t[n>>2]|0)|0;while(1){if(!(u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0))w=(t[(t[n>>2]|0)+40>>2]|0)>1;else w=0;d=t[n>>2]|0;if(!w)break;aE(d)|0}uE(d)|0;if((u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)!=62){AS(t[n>>2]|0,73,0);if(!(t[o>>2]|0))break;yM(t[(t[n>>2]|0)+8>>2]|0,t[o>>2]|0);break}if((t[c>>2]|0)!=(t[(t[n>>2]|0)+36>>2]|0))BS(t[n>>2]|0,90,68392);Op(t[n>>2]|0);do if(t[t[n>>2]>>2]|0){if(t[(t[n>>2]|0)+212>>2]|0)break;if(!(t[(t[t[n>>2]>>2]|0)+36>>2]|0))break;if(t[o>>2]|0)t[(t[o>>2]|0)+20>>2]=0;NAi[t[(t[t[n>>2]>>2]|0)+36>>2]&511](t[(t[n>>2]|0)+4>>2]|0,t[f>>2]|0,t[a>>2]|0,t[o>>2]|0);if(!(t[o>>2]|0))break e;if(t[(t[o>>2]|0)+20>>2]|0)break e;yM(t[(t[n>>2]|0)+8>>2]|0,t[o>>2]|0);break e}while(0);if(t[o>>2]|0)yM(t[(t[n>>2]|0)+8>>2]|0,t[o>>2]|0)}while(0);t[r>>2]=t[a>>2];l=t[r>>2]|0;s=i;return l|0}function IE(e){e=e|0;var i=0,r=0,n=0,f=0,a=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if((t[(t[r>>2]|0)+292>>2]|0)==0?((t[(t[(t[r>>2]|0)+36>>2]|0)+20>>2]|0)-(t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)|0)<250:0)CS(t[r>>2]|0);do if((u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==60){e=t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0;if((u[(t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)+1>>0]|0|0)!=33){if((u[e+1>>0]|0|0)!=63)break;FE(t[r>>2]|0);break}n=u[e+2>>0]|0;if((n|0)==78){OE(t[r>>2]|0);break}else if((n|0)==65){DE(t[r>>2]|0);break}else if((n|0)==45){gE(t[r>>2]|0);break}else if((n|0)==69){n=t[r>>2]|0;if((u[(t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)+3>>0]|0|0)==76){BE(n)|0;break}if((u[(t[(t[n+36>>2]|0)+16>>2]|0)+3>>0]|0|0)!=78)break;AE(t[r>>2]|0);break}else break}while(0);if((t[(t[r>>2]|0)+96>>2]|0)==0?(t[(t[r>>2]|0)+40>>2]|0)==1:0)HE(t[r>>2]|0);if(t[(t[r>>2]|0)+96>>2]|0){f=t[r>>2]|0;a=f+172|0;t[a>>2]=3;s=i;return}if((t[(t[r>>2]|0)+40>>2]|0)<=1){f=t[r>>2]|0;a=f+172|0;t[a>>2]=3;s=i;return}if((u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)!=60){f=t[r>>2]|0;a=f+172|0;t[a>>2]=3;s=i;return}if((u[(t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)+1>>0]|0|0)!=33){f=t[r>>2]|0;a=f+172|0;t[a>>2]=3;s=i;return}if((u[(t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)+2>>0]|0|0)!=91){f=t[r>>2]|0;a=f+172|0;t[a>>2]=3;s=i;return}ig(t[r>>2]|0);f=t[r>>2]|0;a=f+172|0;t[a>>2]=3;s=i;return}function HE(e){e=e|0;var i=0,r=0,n=0,f=0,a=0,o=0,c=0;i=s;s=s+16|0;r=i+12|0;n=i+8|0;f=i+4|0;a=i;t[r>>2]=e;t[f>>2]=0;if((u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)!=37){s=i;return}Op(t[r>>2]|0);t[n>>2]=sE(t[r>>2]|0)|0;e=t[r>>2]|0;if(!(t[n>>2]|0)){BS(e,68,68904);s=i;return}o=t[r>>2]|0;if((u[t[(t[e+36>>2]|0)+16>>2]>>0]|0|0)!=59){AS(o,23,0);s=i;return}Op(o);o=(t[r>>2]|0)+440|0;t[o>>2]=(t[o>>2]|0)+1;if((t[t[r>>2]>>2]|0)!=0?(t[(t[t[r>>2]>>2]|0)+96>>2]|0)!=0:0)t[f>>2]=MAi[t[(t[t[r>>2]>>2]|0)+96>>2]&511](t[(t[r>>2]|0)+4>>2]|0,t[n>>2]|0)|0;if((t[(t[r>>2]|0)+172>>2]|0)==-1){s=i;return}e:do if(t[f>>2]|0){if((t[(t[f>>2]|0)+48>>2]|0)!=4?(t[(t[f>>2]|0)+48>>2]|0)!=5:0){NS(t[r>>2]|0,27,68936,t[n>>2]|0,0);break}o=t[r>>2]|0;e=t[f>>2]|0;if((t[(t[(t[r>>2]|0)+36>>2]|0)+40>>2]|0)!=226){t[a>>2]=DS(o,e)|0;if((cE(t[r>>2]|0,t[a>>2]|0)|0)>=0)break;s=i;return}t[a>>2]=Bp(o,e)|0;if((cE(t[r>>2]|0,t[a>>2]|0)|0)<0){s=i;return}if((((((t[(t[f>>2]|0)+48>>2]|0)==5?(u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==60:0)?(u[(t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)+1>>0]|0|0)==63:0)?(u[(t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)+2>>0]|0|0)==120:0)?(u[(t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)+3>>0]|0|0)==109:0)?(u[(t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)+4>>0]|0|0)==108:0){do if((u[(t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)+5>>0]|0|0)!=32){if(9<=(u[(t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)+5>>0]|0|0)?(u[(t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)+5>>0]|0|0)<=10:0)break;if((u[(t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)+5>>0]|0|0)!=13)break e}while(0);bE(t[r>>2]|0);if((t[(t[r>>2]|0)+84>>2]|0)==32){t[(t[r>>2]|0)+172>>2]=-1;s=i;return}}}else{do if((t[(t[r>>2]|0)+28>>2]|0)==1)c=14;else{if((t[(t[r>>2]|0)+88>>2]|0)==0?(t[(t[r>>2]|0)+92>>2]|0)==0:0){c=14;break}NS(t[r>>2]|0,27,65432,t[n>>2]|0,0);t[(t[r>>2]|0)+100>>2]=0}while(0);if((c|0)==14)MS(t[r>>2]|0,26,65432,t[n>>2]|0);TS(t[r>>2]|0,0,0,0)|0}while(0);t[(t[r>>2]|0)+92>>2]=1;s=i;return}function xE(e){e=e|0;var i=0,r=0,n=0,f=0,a=0,o=0;i=s;s=s+16|0;r=i+8|0;n=i+4|0;f=i;t[n>>2]=e;t[f>>2]=0;do if(((((((u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==118?(u[(t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]|0)+1>>0]|0|0)==101:0)?(u[(t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]|0)+2>>0]|0|0)==114:0)?(u[(t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]|0)+3>>0]|0|0)==115:0)?(u[(t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]|0)+4>>0]|0|0)==105:0)?(u[(t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]|0)+5>>0]|0|0)==111:0)?(u[(t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]|0)+6>>0]|0|0)==110:0){e=(t[n>>2]|0)+200|0;t[e>>2]=(t[e>>2]|0)+7;e=(t[(t[n>>2]|0)+36>>2]|0)+16|0;t[e>>2]=(t[e>>2]|0)+7;e=(t[(t[n>>2]|0)+36>>2]|0)+32|0;t[e>>2]=(t[e>>2]|0)+7;if((u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==37)oE(t[n>>2]|0);if((u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==0?(yp(t[(t[n>>2]|0)+36>>2]|0,250)|0)<=0:0)aE(t[n>>2]|0)|0;uE(t[n>>2]|0)|0;e=t[n>>2]|0;if((u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)!=61){AS(e,75,0);t[r>>2]=0;a=t[r>>2]|0;s=i;return a|0}Op(e);uE(t[n>>2]|0)|0;e=t[n>>2]|0;if((u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==34){Op(e);t[f>>2]=ZE(t[n>>2]|0)|0;o=t[n>>2]|0;if((u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)!=34){AS(o,34,0);break}else{Op(o);break}}o=t[n>>2]|0;if((u[t[(t[e+36>>2]|0)+16>>2]>>0]|0|0)!=39){AS(o,33,0);break}Op(o);t[f>>2]=ZE(t[n>>2]|0)|0;o=t[n>>2]|0;if((u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)!=39){AS(o,34,0);break}else{Op(o);break}}while(0);t[r>>2]=t[f>>2];a=t[r>>2]|0;s=i;return a|0}function UE(e){e=e|0;var i=0,r=0,n=0,f=0,a=0,o=0,c=0;i=s;s=s+16|0;r=i+12|0;n=i+8|0;f=i+4|0;a=i;t[n>>2]=e;t[f>>2]=0;uE(t[n>>2]|0)|0;e:do if((((((((u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==101?(u[(t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]|0)+1>>0]|0|0)==110:0)?(u[(t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]|0)+2>>0]|0|0)==99:0)?(u[(t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]|0)+3>>0]|0|0)==111:0)?(u[(t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]|0)+4>>0]|0|0)==100:0)?(u[(t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]|0)+5>>0]|0|0)==105:0)?(u[(t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]|0)+6>>0]|0|0)==110:0)?(u[(t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]|0)+7>>0]|0|0)==103:0){e=(t[n>>2]|0)+200|0;t[e>>2]=(t[e>>2]|0)+8;e=(t[(t[n>>2]|0)+36>>2]|0)+16|0;t[e>>2]=(t[e>>2]|0)+8;e=(t[(t[n>>2]|0)+36>>2]|0)+32|0;t[e>>2]=(t[e>>2]|0)+8;if((u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==37)oE(t[n>>2]|0);if((u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==0?(yp(t[(t[n>>2]|0)+36>>2]|0,250)|0)<=0:0)aE(t[n>>2]|0)|0;uE(t[n>>2]|0)|0;e=t[n>>2]|0;if((u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)!=61){AS(e,75,0);t[r>>2]=0;o=t[r>>2]|0;s=i;return o|0}Op(e);uE(t[n>>2]|0)|0;e=t[n>>2]|0;do if((u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==34){Op(e);t[f>>2]=JE(t[n>>2]|0)|0;c=t[n>>2]|0;if((u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)!=34){AS(c,34,0);break}else{Op(c);break}}else{c=t[n>>2]|0;if((u[t[(t[e+36>>2]|0)+16>>2]>>0]|0|0)!=39){AS(c,33,0);break}Op(c);t[f>>2]=JE(t[n>>2]|0)|0;c=t[n>>2]|0;if((u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)!=39){AS(c,34,0);break}else{Op(c);break}}while(0);if(t[(t[n>>2]|0)+360>>2]&2097152){pAi[t[135736>>2]&511](t[f>>2]|0);t[r>>2]=0;o=t[r>>2]|0;s=i;return o|0}do if(t[f>>2]|0){if((Ql(t[f>>2]|0,69608)|0)!=0?(Ql(t[f>>2]|0,69616)|0)!=0:0)break;do if((t[(t[n>>2]|0)+24>>2]|0)==0?(t[t[(t[n>>2]|0)+36>>2]>>2]|0)!=0:0){if(t[(t[t[(t[n>>2]|0)+36>>2]>>2]|0)+12>>2]|0)break;BS(t[n>>2]|0,81,69624)}while(0);if(t[(t[n>>2]|0)+24>>2]|0)pAi[t[135736>>2]&511](t[(t[n>>2]|0)+24>>2]|0);t[(t[n>>2]|0)+24>>2]=t[f>>2];break e}while(0);do if(t[f>>2]|0){if((Ql(t[f>>2]|0,69672)|0)!=0?(Ql(t[f>>2]|0,69680)|0)!=0:0)break;if(t[(t[n>>2]|0)+24>>2]|0)pAi[t[135736>>2]&511](t[(t[n>>2]|0)+24>>2]|0);t[(t[n>>2]|0)+24>>2]=t[f>>2];break e}while(0);if(t[f>>2]|0){if(t[(t[(t[n>>2]|0)+36>>2]|0)+44>>2]|0)pAi[t[135736>>2]&511](t[(t[(t[n>>2]|0)+36>>2]|0)+44>>2]|0);t[(t[(t[n>>2]|0)+36>>2]|0)+44>>2]=t[f>>2];t[a>>2]=V_(t[f>>2]|0)|0;e=t[n>>2]|0;if(t[a>>2]|0){Lp(e,t[a>>2]|0)|0;break}MS(e,32,69688,t[f>>2]|0);t[r>>2]=0;o=t[r>>2]|0;s=i;return o|0}}while(0);t[r>>2]=t[f>>2];o=t[r>>2]|0;s=i;return o|0}function zE(e,i,r){e=e|0;i=i|0;r=r|0;var f=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0;f=s;s=s+32|0;a=f+20|0;o=f+16|0;c=f+12|0;l=f+24|0;b=f+8|0;k=f+4|0;h=f;t[a>>2]=e;t[o>>2]=i;t[c>>2]=r;rg(t[a>>2]|0);if((t[(t[a>>2]|0)+292>>2]|0)==0?((t[(t[(t[a>>2]|0)+36>>2]|0)+20>>2]|0)-(t[(t[(t[a>>2]|0)+36>>2]|0)+16>>2]|0)|0)<250:0)CS(t[a>>2]|0);if(((t[(t[a>>2]|0)+24>>2]|0)==0?((t[(t[(t[a>>2]|0)+36>>2]|0)+20>>2]|0)-(t[(t[(t[a>>2]|0)+36>>2]|0)+16>>2]|0)|0)>=4:0)?(n[l>>0]=n[t[(t[(t[a>>2]|0)+36>>2]|0)+16>>2]>>0]|0,n[l+1>>0]=n[(t[(t[(t[a>>2]|0)+36>>2]|0)+16>>2]|0)+1>>0]|0,n[l+2>>0]=n[(t[(t[(t[a>>2]|0)+36>>2]|0)+16>>2]|0)+2>>0]|0,n[l+3>>0]=n[(t[(t[(t[a>>2]|0)+36>>2]|0)+16>>2]|0)+3>>0]|0,t[b>>2]=L_(l,4)|0,(t[b>>2]|0)!=0):0)Tp(t[a>>2]|0,t[b>>2]|0)|0;if((((((u[t[(t[(t[a>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==60?(u[(t[(t[(t[a>>2]|0)+36>>2]|0)+16>>2]|0)+1>>0]|0|0)==63:0)?(u[(t[(t[(t[a>>2]|0)+36>>2]|0)+16>>2]|0)+2>>0]|0|0)==120:0)?(u[(t[(t[(t[a>>2]|0)+36>>2]|0)+16>>2]|0)+3>>0]|0|0)==109:0)?(u[(t[(t[(t[a>>2]|0)+36>>2]|0)+16>>2]|0)+4>>0]|0|0)==108:0)?(bE(t[a>>2]|0),(t[(t[a>>2]|0)+84>>2]|0)==32):0){t[(t[a>>2]|0)+172>>2]=-1;s=f;return}do if(!(t[(t[a>>2]|0)+8>>2]|0)){b=ny(68488)|0;t[(t[a>>2]|0)+8>>2]=b;b=t[a>>2]|0;if(t[(t[a>>2]|0)+8>>2]|0){t[(t[b+8>>2]|0)+92>>2]=64;break}Sp(b,67128);s=f;return}while(0);if((t[(t[a>>2]|0)+8>>2]|0)!=0?(t[(t[(t[a>>2]|0)+8>>2]|0)+44>>2]|0)==0:0)$g(t[(t[a>>2]|0)+8>>2]|0,0,t[o>>2]|0,t[c>>2]|0)|0;t[(t[a>>2]|0)+172>>2]=3;t[(t[a>>2]|0)+96>>2]=1;e:while(1){if(!((u[t[(t[(t[a>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==60?(u[(t[(t[(t[a>>2]|0)+36>>2]|0)+16>>2]|0)+1>>0]|0|0)==63:0))w=25;do if((w|0)==25){w=0;if((u[t[(t[(t[a>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==60?(u[(t[(t[(t[a>>2]|0)+36>>2]|0)+16>>2]|0)+1>>0]|0|0)==33:0)break;if((u[t[(t[(t[a>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)!=37?(u[t[(t[(t[a>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)!=32:0){if(9<=(u[t[(t[(t[a>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)?(u[t[(t[(t[a>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)<=10:0)break;if((u[t[(t[(t[a>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)!=13)break e}}while(0);t[k>>2]=t[(t[(t[a>>2]|0)+36>>2]|0)+16>>2];t[h>>2]=t[(t[(t[a>>2]|0)+36>>2]|0)+36>>2];if((t[(t[a>>2]|0)+292>>2]|0)==0?((t[(t[(t[a>>2]|0)+36>>2]|0)+20>>2]|0)-(t[(t[(t[a>>2]|0)+36>>2]|0)+16>>2]|0)|0)<250:0)CS(t[a>>2]|0);if(((u[t[(t[(t[a>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==60?(u[(t[(t[(t[a>>2]|0)+36>>2]|0)+16>>2]|0)+1>>0]|0|0)==33:0)?(u[(t[(t[(t[a>>2]|0)+36>>2]|0)+16>>2]|0)+2>>0]|0|0)==91:0)ig(t[a>>2]|0);else w=39;i:do if((w|0)==39){w=0;do if((u[t[(t[(t[a>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)!=32){if(9<=(u[t[(t[(t[a>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)?(u[t[(t[(t[a>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)<=10:0)break;if((u[t[(t[(t[a>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)!=13){c=t[a>>2]|0;if((u[t[(t[(t[a>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==37){HE(c);break i}else{IE(c);break i}}}while(0);Op(t[a>>2]|0)}while(0);while(1){if(!(u[t[(t[(t[a>>2]|0)+36>>2]|0)+16>>2]>>0]|0))d=(t[(t[a>>2]|0)+40>>2]|0)>1;else d=0;v=t[a>>2]|0;if(!d)break;aE(v)|0}if((t[(t[v+36>>2]|0)+16>>2]|0)!=(t[k>>2]|0))continue;if((t[h>>2]|0)==(t[(t[(t[a>>2]|0)+36>>2]|0)+36>>2]|0)){w=53;break}}if((w|0)==53)AS(t[a>>2]|0,60,0);if(!(u[t[(t[(t[a>>2]|0)+36>>2]|0)+16>>2]>>0]|0)){s=f;return}AS(t[a>>2]|0,60,0);s=f;return}function jE(e){e=e|0;var i=0,r=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0,S=0,g=0,y=0,F=0,O=0,A=0,M=0,R=0,N=0;i=s;s=s+112|0;r=i;a=i+84|0;o=i+80|0;c=i+76|0;l=i+72|0;b=i+68|0;k=i+64|0;h=i+60|0;w=i+88|0;d=i+56|0;v=i+52|0;m=i+48|0;_=i+44|0;p=i+40|0;E=i+36|0;S=i+32|0;g=i+28|0;y=i+24|0;F=i+20|0;O=i+16|0;A=i+12|0;M=i+8|0;R=i+4|0;t[a>>2]=e;t[b>>2]=0;t[k>>2]=0;if((u[t[(t[(t[a>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)!=38){s=i;return}if((u[(t[(t[(t[a>>2]|0)+36>>2]|0)+16>>2]|0)+1>>0]|0|0)==35){t[h>>2]=0;t[d>>2]=u[(t[(t[(t[a>>2]|0)+36>>2]|0)+16>>2]|0)+2>>0];t[v>>2]=lE(t[a>>2]|0)|0;if(!(t[v>>2]|0)){s=i;return}if((t[(t[a>>2]|0)+256>>2]|0)==1){e=Rp(w+(t[h>>2]|0)|0,t[v>>2]|0)|0;t[h>>2]=(t[h>>2]|0)+e;n[w+(t[h>>2]|0)>>0]=0;if(!(t[t[a>>2]>>2]|0)){s=i;return}if(!(t[(t[t[a>>2]>>2]|0)+68>>2]|0)){s=i;return}if(t[(t[a>>2]|0)+212>>2]|0){s=i;return}yAi[t[(t[t[a>>2]>>2]|0)+68>>2]&511](t[(t[a>>2]|0)+4>>2]|0,w,t[h>>2]|0);s=i;return}if((t[v>>2]|0)<=255){n[w>>0]=t[v>>2];n[w+1>>0]=0;if(!(t[t[a>>2]>>2]|0)){s=i;return}if(!(t[(t[t[a>>2]>>2]|0)+68>>2]|0)){s=i;return}if(t[(t[a>>2]|0)+212>>2]|0){s=i;return}yAi[t[(t[t[a>>2]>>2]|0)+68>>2]&511](t[(t[a>>2]|0)+4>>2]|0,w,1);s=i;return}h=t[v>>2]|0;if((t[d>>2]|0)==120|(t[d>>2]|0)==88){t[r>>2]=h;SY(w,10,68560,r)|0}else{t[r>>2]=h;SY(w,10,68568,r)|0}if(!(t[t[a>>2]>>2]|0)){s=i;return}if(!(t[(t[t[a>>2]>>2]|0)+64>>2]|0)){s=i;return}if(t[(t[a>>2]|0)+212>>2]|0){s=i;return}EAi[t[(t[t[a>>2]>>2]|0)+64>>2]&511](t[(t[a>>2]|0)+4>>2]|0,w);s=i;return}t[o>>2]=VE(t[a>>2]|0)|0;if(!(t[o>>2]|0)){s=i;return}if(!(t[(t[a>>2]|0)+12>>2]|0)){s=i;return}t[l>>2]=t[(t[o>>2]|0)+72>>2];if((t[(t[o>>2]|0)+8>>2]|0)!=0?(t[(t[o>>2]|0)+48>>2]|0)!=6:0){do if(!(t[(t[o>>2]|0)+72>>2]|0)){if((t[(t[o>>2]|0)+48>>2]|0)==2?(t[(t[a>>2]|0)+360>>2]&18|0)==0:0){N=76;break}t[m>>2]=t[(t[a>>2]|0)+440>>2];if((t[(t[a>>2]|0)+4>>2]|0)==(t[a>>2]|0))t[_>>2]=0;else t[_>>2]=t[(t[a>>2]|0)+4>>2];do if((t[(t[o>>2]|0)+48>>2]|0)!=1)if((t[(t[o>>2]|0)+48>>2]|0)==2){w=(t[a>>2]|0)+248|0;t[w>>2]=(t[w>>2]|0)+1;t[k>>2]=fg(t[(t[a>>2]|0)+8>>2]|0,t[a>>2]|0,t[t[a>>2]>>2]|0,t[_>>2]|0,t[(t[a>>2]|0)+248>>2]|0,t[(t[o>>2]|0)+64>>2]|0,t[(t[o>>2]|0)+52>>2]|0,b)|0;w=(t[a>>2]|0)+248|0;t[w>>2]=(t[w>>2]|0)+-1;break}else{t[k>>2]=88;ZS(t[a>>2]|0,1,68576,0);break}else{w=(t[a>>2]|0)+248|0;t[w>>2]=(t[w>>2]|0)+1;t[k>>2]=ng(t[a>>2]|0,t[(t[o>>2]|0)+40>>2]|0,t[_>>2]|0,b)|0;w=(t[a>>2]|0)+248|0;t[w>>2]=(t[w>>2]|0)+-1}while(0);t[(t[o>>2]|0)+72>>2]=(t[(t[a>>2]|0)+440>>2]|0)-(t[m>>2]|0)+1<<1;if((t[(t[o>>2]|0)+40>>2]|0)!=0?(es(t[(t[o>>2]|0)+40>>2]|0,60)|0)!=0:0){w=(t[o>>2]|0)+72|0;t[w>>2]=t[w>>2]|1}w=t[a>>2]|0;if((t[k>>2]|0)==89){AS(w,89,0);ty(t[b>>2]|0);s=i;return}if(TS(w,0,t[o>>2]|0,0)|0){ty(t[b>>2]|0);s=i;return}e:do if(!((t[k>>2]|0)==0&(t[b>>2]|0)!=0)){if((t[k>>2]|0)!=0&(t[k>>2]|0)!=27){MS(t[a>>2]|0,26,68608,t[(t[o>>2]|0)+8>>2]|0);TS(t[a>>2]|0,0,t[o>>2]|0,0)|0;break}if(t[b>>2]|0){ty(t[b>>2]|0);t[b>>2]=0}}else{if(!((t[(t[o>>2]|0)+48>>2]|0)!=1?(t[(t[o>>2]|0)+48>>2]|0)!=2:0))N=51;if((N|0)==51?(t[(t[o>>2]|0)+12>>2]|0)==0:0){t[(t[o>>2]|0)+12>>2]=t[b>>2];if(!(t[(t[a>>2]|0)+16>>2]|0)){t[(t[o>>2]|0)+68>>2]=1;while(1){if(!(t[b>>2]|0))break e;t[(t[b>>2]|0)+20>>2]=t[o>>2];Ny(t[b>>2]|0,t[(t[o>>2]|0)+32>>2]|0);if(!(t[(t[b>>2]|0)+24>>2]|0))t[(t[o>>2]|0)+16>>2]=t[b>>2];t[b>>2]=t[(t[b>>2]|0)+24>>2]}}if(!((t[(t[b>>2]|0)+4>>2]|0)==3?(t[(t[b>>2]|0)+24>>2]|0)==0:0))N=55;do if((N|0)==55){if((t[(t[a>>2]|0)+436>>2]|0)==5)break;t[(t[o>>2]|0)+68>>2]=0;while(1){if(!(t[b>>2]|0))break;t[(t[b>>2]|0)+20>>2]=t[(t[a>>2]|0)+52>>2];t[(t[b>>2]|0)+32>>2]=t[(t[a>>2]|0)+8>>2];if(!(t[(t[b>>2]|0)+24>>2]|0))t[(t[o>>2]|0)+16>>2]=t[b>>2];t[b>>2]=t[(t[b>>2]|0)+24>>2]}t[b>>2]=t[(t[o>>2]|0)+12>>2];if((t[(t[o>>2]|0)+48>>2]|0)!=2)break e;tg(t[o>>2]|0,t[b>>2]|0,0);break e}while(0);t[(t[b>>2]|0)+20>>2]=t[o>>2];t[b>>2]=0;t[(t[o>>2]|0)+68>>2]=1;break}ty(t[b>>2]|0);t[b>>2]=0}while(0);if(!(t[(t[o>>2]|0)+72>>2]|0))t[(t[o>>2]|0)+72>>2]=2}else N=76;while(0);if((N|0)==76?(t[(t[o>>2]|0)+72>>2]|0)!=1:0){m=(t[a>>2]|0)+440|0;t[m>>2]=(t[m>>2]|0)+((t[(t[o>>2]|0)+72>>2]|0)/2|0)}if(!(t[(t[o>>2]|0)+12>>2]|0)){if(t[l>>2]|0){if((t[(t[a>>2]|0)+4>>2]|0)==(t[a>>2]|0))t[p>>2]=0;else t[p>>2]=t[(t[a>>2]|0)+4>>2];do if((t[(t[o>>2]|0)+48>>2]|0)!=1)if((t[(t[o>>2]|0)+48>>2]|0)==2){l=(t[a>>2]|0)+248|0;t[l>>2]=(t[l>>2]|0)+1;t[k>>2]=fg(t[(t[a>>2]|0)+8>>2]|0,t[a>>2]|0,t[t[a>>2]>>2]|0,t[p>>2]|0,t[(t[a>>2]|0)+248>>2]|0,t[(t[o>>2]|0)+64>>2]|0,t[(t[o>>2]|0)+52>>2]|0,0)|0;l=(t[a>>2]|0)+248|0;t[l>>2]=(t[l>>2]|0)+-1;break}else{t[k>>2]=88;ZS(t[a>>2]|0,1,68576,0);break}else{l=(t[a>>2]|0)+248|0;t[l>>2]=(t[l>>2]|0)+1;t[k>>2]=ng(t[a>>2]|0,t[(t[o>>2]|0)+40>>2]|0,t[p>>2]|0,0)|0;l=(t[a>>2]|0)+248|0;t[l>>2]=(t[l>>2]|0)+-1}while(0);if((t[k>>2]|0)==89){AS(t[a>>2]|0,89,0);s=i;return}}if(!(t[t[a>>2]>>2]|0)){s=i;return}if(!(t[(t[t[a>>2]>>2]|0)+64>>2]|0)){s=i;return}if(t[(t[a>>2]|0)+16>>2]|0){s=i;return}if(t[(t[a>>2]|0)+212>>2]|0){s=i;return}EAi[t[(t[t[a>>2]>>2]|0)+64>>2]&511](t[(t[a>>2]|0)+4>>2]|0,t[(t[o>>2]|0)+8>>2]|0);s=i;return}if((((t[t[a>>2]>>2]|0)!=0?(t[(t[t[a>>2]>>2]|0)+64>>2]|0)!=0:0)?(t[(t[a>>2]|0)+16>>2]|0)==0:0)?(t[(t[a>>2]|0)+212>>2]|0)==0:0){EAi[t[(t[t[a>>2]>>2]|0)+64>>2]&511](t[(t[a>>2]|0)+4>>2]|0,t[(t[o>>2]|0)+8>>2]|0);s=i;return}if((t[(t[a>>2]|0)+16>>2]|0)==0?(t[(t[o>>2]|0)+12>>2]|0)!=0:0){s=i;return}if(!(t[(t[a>>2]|0)+52>>2]|0)){s=i;return}if(!(t[(t[o>>2]|0)+12>>2]|0)){s=i;return}if((t[b>>2]|0)==0?(t[(t[o>>2]|0)+68>>2]|0)==0:0)N=107;else N=106;do if((N|0)==106)if((t[(t[a>>2]|0)+436>>2]|0)!=5){if((t[b>>2]|0)!=0?(t[(t[a>>2]|0)+40>>2]|0)<=0:0){t[R>>2]=kz(t[(t[a>>2]|0)+296>>2]|0,68640,-1)|0;if((t[(t[(t[o>>2]|0)+12>>2]|0)+4>>2]|0)==3)t[(t[(t[o>>2]|0)+12>>2]|0)+8>>2]=t[R>>2];do if((t[(t[o>>2]|0)+16>>2]|0)!=(t[(t[o>>2]|0)+12>>2]|0)){if((t[(t[(t[o>>2]|0)+16>>2]|0)+4>>2]|0)!=3)break;t[(t[(t[o>>2]|0)+16>>2]|0)+8>>2]=t[R>>2]}while(0);Iy(t[(t[a>>2]|0)+52>>2]|0,t[(t[o>>2]|0)+12>>2]|0)|0;break}t[y>>2]=0;t[M>>2]=0;k=(t[a>>2]|0)+468|0;t[k>>2]=(t[k>>2]|0)+((t[(t[o>>2]|0)+44>>2]|0)+5);if(TS(t[a>>2]|0,0,t[o>>2]|0,t[(t[a>>2]|0)+468>>2]|0)|0){s=i;return}t[F>>2]=t[(t[o>>2]|0)+12>>2];t[(t[o>>2]|0)+12>>2]=0;t[A>>2]=t[(t[o>>2]|0)+16>>2];t[(t[o>>2]|0)+16>>2]=0;while(1){if(!(t[F>>2]|0))break;t[O>>2]=t[(t[F>>2]|0)+24>>2];t[(t[F>>2]|0)+24>>2]=0;t[(t[F>>2]|0)+20>>2]=0;t[y>>2]=Wy(t[F>>2]|0,t[(t[a>>2]|0)+8>>2]|0,1)|0;if(t[y>>2]|0){if(!(t[t[y>>2]>>2]|0))t[t[y>>2]>>2]=t[t[F>>2]>>2];
	if(!(t[M>>2]|0))t[M>>2]=t[F>>2];Hy(t[o>>2]|0,t[y>>2]|0)|0;Hy(t[(t[a>>2]|0)+52>>2]|0,t[F>>2]|0)|0}if((t[F>>2]|0)==(t[A>>2]|0))break;t[F>>2]=t[O>>2]}if(!(t[(t[o>>2]|0)+68>>2]|0))t[(t[o>>2]|0)+68>>2]=1;if((t[(t[o>>2]|0)+48>>2]|0)==2)tg(t[o>>2]|0,t[M>>2]|0,t[y>>2]|0)}else N=107;while(0);if((N|0)==107){t[E>>2]=0;t[g>>2]=0;y=(t[a>>2]|0)+468|0;t[y>>2]=(t[y>>2]|0)+((t[(t[o>>2]|0)+44>>2]|0)+5);if(TS(t[a>>2]|0,0,t[o>>2]|0,t[(t[a>>2]|0)+468>>2]|0)|0){s=i;return}t[S>>2]=t[(t[o>>2]|0)+12>>2];while(1){if(!(t[S>>2]|0))break;t[E>>2]=Wy(t[S>>2]|0,t[(t[a>>2]|0)+8>>2]|0,1)|0;if(t[E>>2]|0){if(!(t[t[E>>2]>>2]|0))t[t[E>>2]>>2]=t[t[S>>2]>>2];if(!(t[g>>2]|0))t[g>>2]=t[E>>2];t[E>>2]=Hy(t[(t[a>>2]|0)+52>>2]|0,t[E>>2]|0)|0}if((t[S>>2]|0)==(t[(t[o>>2]|0)+16>>2]|0)){N=117;break}t[S>>2]=t[(t[S>>2]|0)+24>>2]}if((((N|0)==117?(t[E>>2]|0)!=0?(t[(t[a>>2]|0)+436>>2]|0)==5:0:0)?(t[(t[E>>2]|0)+4>>2]|0)==1:0)?(t[(t[E>>2]|0)+12>>2]|0)==0:0)f[(t[E>>2]|0)+58>>1]=1;if((t[(t[o>>2]|0)+48>>2]|0)==2)tg(t[o>>2]|0,t[g>>2]|0,t[E>>2]|0)}t[(t[a>>2]|0)+264>>2]=0;t[(t[a>>2]|0)+260>>2]=0;s=i;return}t[c>>2]=t[(t[o>>2]|0)+40>>2];if(!(t[c>>2]|0)){s=i;return}if(!(t[t[a>>2]>>2]|0)){s=i;return}if(!(t[(t[t[a>>2]>>2]|0)+68>>2]|0)){s=i;return}if(t[(t[a>>2]|0)+212>>2]|0){s=i;return}o=t[(t[t[a>>2]>>2]|0)+68>>2]|0;E=t[(t[a>>2]|0)+4>>2]|0;a=t[c>>2]|0;g=rs(t[c>>2]|0)|0;yAi[o&511](E,a,g);s=i;return}function VE(e){e=e|0;var i=0,r=0,n=0,f=0,a=0,o=0,c=0,l=0;i=s;s=s+16|0;r=i+12|0;n=i+8|0;f=i+4|0;a=i;t[n>>2]=e;t[a>>2]=0;if((t[(t[n>>2]|0)+292>>2]|0)==0?((t[(t[(t[n>>2]|0)+36>>2]|0)+20>>2]|0)-(t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]|0)|0)<250:0)CS(t[n>>2]|0);if((t[(t[n>>2]|0)+172>>2]|0)==-1){t[r>>2]=0;o=t[r>>2]|0;s=i;return o|0}if((u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)!=38){t[r>>2]=0;o=t[r>>2]|0;s=i;return o|0}Op(t[n>>2]|0);t[f>>2]=sE(t[n>>2]|0)|0;e=t[n>>2]|0;if(!(t[f>>2]|0)){BS(e,68,68648);t[r>>2]=0;o=t[r>>2]|0;s=i;return o|0}c=t[n>>2]|0;if((u[t[(t[e+36>>2]|0)+16>>2]>>0]|0|0)!=59){AS(c,23,0);t[r>>2]=0;o=t[r>>2]|0;s=i;return o|0}Op(c);if((t[(t[n>>2]|0)+360>>2]&1048576|0)==0?(t[a>>2]=l_(t[f>>2]|0)|0,(t[a>>2]|0)!=0):0){t[r>>2]=t[a>>2];o=t[r>>2]|0;s=i;return o|0}c=(t[n>>2]|0)+440|0;t[c>>2]=(t[c>>2]|0)+1;if(t[t[n>>2]>>2]|0){if(t[(t[t[n>>2]>>2]|0)+20>>2]|0)t[a>>2]=MAi[t[(t[t[n>>2]>>2]|0)+20>>2]&511](t[(t[n>>2]|0)+4>>2]|0,t[f>>2]|0)|0;if(((t[a>>2]|0)==0?(t[(t[n>>2]|0)+12>>2]|0)==1:0)?(t[(t[n>>2]|0)+360>>2]&1048576|0)!=0:0)t[a>>2]=l_(t[f>>2]|0)|0;if(((t[a>>2]|0)==0?(t[(t[n>>2]|0)+12>>2]|0)==1:0)?(t[(t[n>>2]|0)+4>>2]|0)==(t[n>>2]|0):0)t[a>>2]=Cz(t[n>>2]|0,t[f>>2]|0)|0}if((t[(t[n>>2]|0)+172>>2]|0)==-1){t[r>>2]=0;o=t[r>>2]|0;s=i;return o|0}do if(t[a>>2]|0){c=t[n>>2]|0;if((t[(t[a>>2]|0)+48>>2]|0)==3){MS(c,28,68712,t[f>>2]|0);break}if((t[c+172>>2]|0)==12?(t[(t[a>>2]|0)+48>>2]|0)==2:0){MS(t[n>>2]|0,29,68752,t[f>>2]|0);break}if(((t[a>>2]|0)!=0?(t[(t[n>>2]|0)+172>>2]|0)==12:0)?(t[(t[a>>2]|0)+48>>2]|0)!=6:0){if((t[(t[a>>2]|0)+72>>2]&1|0)==0?(t[(t[a>>2]|0)+72>>2]|0)!=0:0)break;if(!(t[(t[a>>2]|0)+40>>2]|0))break;if(!(es(t[(t[a>>2]|0)+40>>2]|0,60)|0))break;MS(t[n>>2]|0,38,68800,t[f>>2]|0);break}if(((t[(t[a>>2]|0)+48>>2]|0)+-4|0)>>>0<2)MS(t[n>>2]|0,30,68856,t[f>>2]|0)}else{do if((t[(t[n>>2]|0)+28>>2]|0)!=1){if((t[(t[n>>2]|0)+88>>2]|0)==0?(t[(t[n>>2]|0)+92>>2]|0)==0:0){l=30;break}ZS(t[n>>2]|0,27,68680,t[f>>2]|0);if(((t[(t[n>>2]|0)+216>>2]|0)==0?(t[t[n>>2]>>2]|0)!=0:0)?(t[(t[t[n>>2]>>2]|0)+64>>2]|0)!=0:0)EAi[t[(t[t[n>>2]>>2]|0)+64>>2]&511](t[(t[n>>2]|0)+4>>2]|0,t[f>>2]|0)}else l=30;while(0);if((l|0)==30)MS(t[n>>2]|0,26,68680,t[f>>2]|0);TS(t[n>>2]|0,0,t[a>>2]|0,0)|0;t[(t[n>>2]|0)+100>>2]=0}while(0);t[r>>2]=t[a>>2];o=t[r>>2]|0;s=i;return o|0}function qE(e){e=e|0;var i=0,r=0,n=0,f=0,a=0;i=s;s=s+16|0;r=i+12|0;n=i+8|0;f=i+4|0;a=i;t[r>>2]=e;t[n>>2]=0;t[f>>2]=0;t[a>>2]=0;e=(t[r>>2]|0)+200|0;t[e>>2]=(t[e>>2]|0)+9;e=(t[(t[r>>2]|0)+36>>2]|0)+16|0;t[e>>2]=(t[e>>2]|0)+9;e=(t[(t[r>>2]|0)+36>>2]|0)+32|0;t[e>>2]=(t[e>>2]|0)+9;if((u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==37)oE(t[r>>2]|0);if((u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==0?(yp(t[(t[r>>2]|0)+36>>2]|0,250)|0)<=0:0)aE(t[r>>2]|0)|0;uE(t[r>>2]|0)|0;t[n>>2]=sE(t[r>>2]|0)|0;if(!(t[n>>2]|0))BS(t[r>>2]|0,68,68984);t[(t[r>>2]|0)+220>>2]=t[n>>2];uE(t[r>>2]|0)|0;t[a>>2]=SE(t[r>>2]|0,f,1)|0;if((t[a>>2]|0)!=0|(t[f>>2]|0)!=0)t[(t[r>>2]|0)+88>>2]=1;t[(t[r>>2]|0)+224>>2]=t[a>>2];t[(t[r>>2]|0)+228>>2]=t[f>>2];uE(t[r>>2]|0)|0;if(((t[t[r>>2]>>2]|0)!=0?(t[t[t[r>>2]>>2]>>2]|0)!=0:0)?(t[(t[r>>2]|0)+212>>2]|0)==0:0)NAi[t[t[t[r>>2]>>2]>>2]&511](t[(t[r>>2]|0)+4>>2]|0,t[n>>2]|0,t[f>>2]|0,t[a>>2]|0);if((t[(t[r>>2]|0)+172>>2]|0)==-1){s=i;return}if((u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==91){s=i;return}if((u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)!=62)AS(t[r>>2]|0,61,0);Op(t[r>>2]|0);s=i;return}function YE(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,a=0,o=0,c=0,l=0;r=s;s=s+32|0;n=r+16|0;f=r+12|0;a=r+8|0;o=r+4|0;c=r;t[f>>2]=e;t[a>>2]=i;t[t[a>>2]>>2]=0;if((t[(t[f>>2]|0)+292>>2]|0)==0?((t[(t[(t[f>>2]|0)+36>>2]|0)+20>>2]|0)-(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)|0)<250:0)CS(t[f>>2]|0);t[o>>2]=sE(t[f>>2]|0)|0;i=t[f>>2]|0;if(!(t[o>>2]|0)){BS(i,68,69032);t[n>>2]=0;l=t[n>>2]|0;s=r;return l|0}uE(i)|0;i=t[f>>2]|0;if((u[t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)!=61){MS(i,41,69064,t[o>>2]|0);t[n>>2]=0;l=t[n>>2]|0;s=r;return l|0}Op(i);uE(t[f>>2]|0)|0;t[c>>2]=mE(t[f>>2]|0)|0;t[(t[f>>2]|0)+172>>2]=7;if(((t[(t[f>>2]|0)+268>>2]|0)!=0?(Xl(t[o>>2]|0,69112)|0)!=0:0)?($p(t[c>>2]|0)|0)==0:0)NS(t[f>>2]|0,98,69128,t[c>>2]|0,0);do if(Xl(t[o>>2]|0,69168)|0){if(Xl(t[c>>2]|0,69184)|0){t[t[(t[f>>2]|0)+232>>2]>>2]=0;break}i=(Xl(t[c>>2]|0,69192)|0)!=0;e=t[f>>2]|0;if(i){t[t[e+232>>2]>>2]=1;break}else{NS(e,102,69208,t[c>>2]|0,0);break}}while(0);t[t[a>>2]>>2]=t[c>>2];t[n>>2]=t[o>>2];l=t[n>>2]|0;s=r;return l|0}function GE(e){e=e|0;var i=0,r=0,n=0,f=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0;i=s;s=s+48|0;r=i+44|0;n=i+40|0;f=i+36|0;a=i+32|0;o=i+28|0;c=i+24|0;l=i+20|0;b=i+16|0;k=i+12|0;h=i+8|0;w=i+4|0;d=i;t[n>>2]=e;t[c>>2]=t[(t[n>>2]|0)+300>>2];t[l>>2]=0;t[b>>2]=t[(t[n>>2]|0)+304>>2];if((u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)!=60){t[r>>2]=0;v=t[r>>2]|0;s=i;return v|0}e=(t[(t[n>>2]|0)+36>>2]|0)+32|0;t[e>>2]=(t[e>>2]|0)+1;e=(t[(t[n>>2]|0)+36>>2]|0)+16|0;t[e>>2]=(t[e>>2]|0)+1;e=(t[n>>2]|0)+200|0;t[e>>2]=(t[e>>2]|0)+1;if(!(u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0))yp(t[(t[n>>2]|0)+36>>2]|0,250)|0;t[f>>2]=sE(t[n>>2]|0)|0;e=t[n>>2]|0;if(!(t[f>>2]|0)){BS(e,68,69280);t[r>>2]=0;v=t[r>>2]|0;s=i;return v|0}uE(e)|0;if((t[(t[n>>2]|0)+292>>2]|0)==0?((t[(t[(t[n>>2]|0)+36>>2]|0)+20>>2]|0)-(t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]|0)|0)<250:0)CS(t[n>>2]|0);while(1){if((u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==62)break;if((u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==47?(u[(t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]|0)+1>>0]|0|0)==62:0)break;if(!(9<=(u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)?(u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)<=10:0))m=15;if(((m|0)==15?(m=0,(u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)!=13):0)?32>(u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0):0)break;if((t[(t[n>>2]|0)+172>>2]|0)==-1)break;t[h>>2]=t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2];t[w>>2]=t[(t[(t[n>>2]|0)+36>>2]|0)+36>>2];t[a>>2]=YE(t[n>>2]|0,o)|0;e:do if(!((t[a>>2]|0)!=0&(t[o>>2]|0)!=0)){if(t[o>>2]|0)pAi[t[135736>>2]&511](t[o>>2]|0)}else{t[k>>2]=0;while(1){if((t[k>>2]|0)>=(t[l>>2]|0))break;if(Xl(t[(t[c>>2]|0)+(t[k>>2]<<2)>>2]|0,t[a>>2]|0)|0){m=22;break}t[k>>2]=(t[k>>2]|0)+2}if((m|0)==22){m=0;ug(t[n>>2]|0,0,t[a>>2]|0);pAi[t[135736>>2]&511](t[o>>2]|0);break}do if(t[c>>2]|0){if(((t[l>>2]|0)+4|0)>(t[b>>2]|0)){t[b>>2]=t[b>>2]<<1;t[d>>2]=MAi[t[135760>>2]&511](t[c>>2]|0,t[b>>2]<<2)|0;if(t[d>>2]|0){t[c>>2]=t[d>>2];t[(t[n>>2]|0)+300>>2]=t[c>>2];t[(t[n>>2]|0)+304>>2]=t[b>>2];break}Sp(t[n>>2]|0,0);if(!(t[o>>2]|0))break e;pAi[t[135736>>2]&511](t[o>>2]|0);break e}}else{t[b>>2]=22;t[c>>2]=gAi[t[135744>>2]&511](t[b>>2]<<2)|0;if(t[c>>2]|0){t[(t[n>>2]|0)+300>>2]=t[c>>2];t[(t[n>>2]|0)+304>>2]=t[b>>2];break}Sp(t[n>>2]|0,0);if(!(t[o>>2]|0))break e;pAi[t[135736>>2]&511](t[o>>2]|0);break e}while(0);e=t[a>>2]|0;_=t[l>>2]|0;t[l>>2]=_+1;t[(t[c>>2]|0)+(_<<2)>>2]=e;e=t[o>>2]|0;_=t[l>>2]|0;t[l>>2]=_+1;t[(t[c>>2]|0)+(_<<2)>>2]=e;t[(t[c>>2]|0)+(t[l>>2]<<2)>>2]=0;t[(t[c>>2]|0)+((t[l>>2]|0)+1<<2)>>2]=0}while(0);if((t[(t[n>>2]|0)+292>>2]|0)==0?((t[(t[(t[n>>2]|0)+36>>2]|0)+20>>2]|0)-(t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]|0)|0)<250:0)CS(t[n>>2]|0);if((u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==62)break;if((u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==47?(u[(t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]|0)+1>>0]|0|0)==62:0)break;do if((u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)!=32){if(9<=(u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)?(u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)<=10:0)break;if((u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)!=13)BS(t[n>>2]|0,65,69320)}while(0);uE(t[n>>2]|0)|0;if((t[w>>2]|0)==(t[(t[(t[n>>2]|0)+36>>2]|0)+36>>2]|0)?((t[a>>2]|0)==0?(t[h>>2]|0)==(t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]|0):0)&(t[o>>2]|0)==0:0){m=50;break}if(((t[(t[n>>2]|0)+292>>2]|0)==0?((t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]|0)-(t[(t[(t[n>>2]|0)+36>>2]|0)+12>>2]|0)|0)>500:0)?((t[(t[(t[n>>2]|0)+36>>2]|0)+20>>2]|0)-(t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]|0)|0)<500:0)qS(t[n>>2]|0);if(t[(t[n>>2]|0)+292>>2]|0)continue;if(((t[(t[(t[n>>2]|0)+36>>2]|0)+20>>2]|0)-(t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]|0)|0)>=250)continue;CS(t[n>>2]|0)}if((m|0)==50)BS(t[n>>2]|0,1,69352);do if(((t[t[n>>2]>>2]|0)!=0?(t[(t[t[n>>2]>>2]|0)+56>>2]|0)!=0:0)?(t[(t[n>>2]|0)+212>>2]|0)==0:0){m=t[(t[t[n>>2]>>2]|0)+56>>2]|0;o=t[(t[n>>2]|0)+4>>2]|0;h=t[f>>2]|0;if((t[l>>2]|0)>0){yAi[m&511](o,h,t[c>>2]|0);break}else{yAi[m&511](o,h,0);break}}while(0);e:do if(t[c>>2]|0){t[k>>2]=1;while(1){if((t[k>>2]|0)>=(t[l>>2]|0))break e;if(t[(t[c>>2]|0)+(t[k>>2]<<2)>>2]|0)pAi[t[135736>>2]&511](t[(t[c>>2]|0)+(t[k>>2]<<2)>>2]|0);t[k>>2]=(t[k>>2]|0)+2}}while(0);t[r>>2]=t[f>>2];v=t[r>>2]|0;s=i;return v|0}function WE(e){e=e|0;var i=0,r=0,f=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0;i=s;s=s+48|0;r=i+44|0;f=i+40|0;a=i+36|0;o=i+32|0;c=i+28|0;l=i+24|0;b=i+20|0;k=i+16|0;h=i+12|0;w=i+8|0;d=i+4|0;v=i;t[r>>2]=e;t[f>>2]=0;t[a>>2]=0;t[o>>2]=100;t[d>>2]=0;if((u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)!=60){s=i;return}if((u[(t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)+1>>0]|0|0)!=33){s=i;return}if((u[(t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)+2>>0]|0|0)!=91){s=i;return}if((u[(t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)+3>>0]|0|0)!=67){s=i;return}if((u[(t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)+4>>0]|0|0)!=68){s=i;return}if((u[(t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)+5>>0]|0|0)!=65){s=i;return}if((u[(t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)+6>>0]|0|0)!=84){s=i;return}if((u[(t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)+7>>0]|0|0)!=65){s=i;return}if((u[(t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)+8>>0]|0|0)!=91){s=i;return}e=(t[r>>2]|0)+200|0;t[e>>2]=(t[e>>2]|0)+9;e=(t[(t[r>>2]|0)+36>>2]|0)+16|0;t[e>>2]=(t[e>>2]|0)+9;e=(t[(t[r>>2]|0)+36>>2]|0)+32|0;t[e>>2]=(t[e>>2]|0)+9;if((u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==37)oE(t[r>>2]|0);if((u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==0?(yp(t[(t[r>>2]|0)+36>>2]|0,250)|0)<=0:0)aE(t[r>>2]|0)|0;t[(t[r>>2]|0)+172>>2]=8;t[c>>2]=Ap(t[r>>2]|0,l)|0;e=t[c>>2]|0;if((t[c>>2]|0)<256){if(!(9<=(e|0)&(t[c>>2]|0)<=10|(t[c>>2]|0)==13|32<=(t[c>>2]|0)))m=20}else if((!(256<=(e|0)&(t[c>>2]|0)<=55295)?!(57344<=(t[c>>2]|0)&(t[c>>2]|0)<=65533):0)?!(65536<=(t[c>>2]|0)&(t[c>>2]|0)<=1114111):0)m=20;if((m|0)==20){AS(t[r>>2]|0,63,0);t[(t[r>>2]|0)+172>>2]=7;s=i;return}e=t[(t[r>>2]|0)+36>>2]|0;if((u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==10){_=e+28|0;t[_>>2]=(t[_>>2]|0)+1;t[(t[(t[r>>2]|0)+36>>2]|0)+32>>2]=1}else{_=e+32|0;t[_>>2]=(t[_>>2]|0)+1}_=(t[(t[r>>2]|0)+36>>2]|0)+16|0;t[_>>2]=(t[_>>2]|0)+(t[l>>2]|0);if((u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==37)oE(t[r>>2]|0);t[b>>2]=Ap(t[r>>2]|0,k)|0;_=t[b>>2]|0;if((t[b>>2]|0)<256){if(!(9<=(_|0)&(t[b>>2]|0)<=10|(t[b>>2]|0)==13|32<=(t[b>>2]|0)))m=31}else if((!(256<=(_|0)&(t[b>>2]|0)<=55295)?!(57344<=(t[b>>2]|0)&(t[b>>2]|0)<=65533):0)?!(65536<=(t[b>>2]|0)&(t[b>>2]|0)<=1114111):0)m=31;if((m|0)==31){AS(t[r>>2]|0,63,0);t[(t[r>>2]|0)+172>>2]=7;s=i;return}_=t[(t[r>>2]|0)+36>>2]|0;if((u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==10){e=_+28|0;t[e>>2]=(t[e>>2]|0)+1;t[(t[(t[r>>2]|0)+36>>2]|0)+32>>2]=1}else{e=_+32|0;t[e>>2]=(t[e>>2]|0)+1}e=(t[(t[r>>2]|0)+36>>2]|0)+16|0;t[e>>2]=(t[e>>2]|0)+(t[k>>2]|0);if((u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==37)oE(t[r>>2]|0);t[h>>2]=Ap(t[r>>2]|0,w)|0;t[f>>2]=gAi[t[135752>>2]&511](t[o>>2]|0)|0;if(!(t[f>>2]|0)){Sp(t[r>>2]|0,0);s=i;return}while(1){e=t[h>>2]|0;do if((t[h>>2]|0)<256)if(9<=(e|0)&(t[h>>2]|0)<=10|(t[h>>2]|0)==13|32<=(t[h>>2]|0))m=44;else p=0;else{if(256<=(e|0)&(t[h>>2]|0)<=55295){m=44;break}if(57344<=(t[h>>2]|0)&(t[h>>2]|0)<=65533){m=44;break}if(65536<=(t[h>>2]|0)&(t[h>>2]|0)<=1114111)m=44;else p=0}while(0);do if((m|0)==44){m=0;if((t[c>>2]|0)!=93|(t[b>>2]|0)!=93){p=1;break}p=(t[h>>2]|0)!=62}while(0);E=t[a>>2]|0;if(!p){m=70;break}if((E+5|0)>=(t[o>>2]|0)){if((t[o>>2]|0)>1e7?(t[(t[r>>2]|0)+360>>2]&524288|0)==0:0){m=50;break}t[v>>2]=MAi[t[135760>>2]&511](t[f>>2]|0,t[o>>2]<<1)|0;if(!(t[v>>2]|0)){m=52;break}t[f>>2]=t[v>>2];t[o>>2]=t[o>>2]<<1}if((t[l>>2]|0)==1){e=t[c>>2]&255;_=t[a>>2]|0;t[a>>2]=_+1;n[(t[f>>2]|0)+_>>0]=e}else{e=Rp((t[f>>2]|0)+(t[a>>2]|0)|0,t[c>>2]|0)|0;t[a>>2]=(t[a>>2]|0)+e}t[c>>2]=t[b>>2];t[l>>2]=t[k>>2];t[b>>2]=t[h>>2];t[k>>2]=t[w>>2];t[d>>2]=(t[d>>2]|0)+1;if((t[d>>2]|0)>50){do if(!(t[(t[r>>2]|0)+292>>2]|0)){if(((t[(t[(t[r>>2]|0)+36>>2]|0)+20>>2]|0)-(t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)|0)>=250)break;CS(t[r>>2]|0)}while(0);if((t[(t[r>>2]|0)+172>>2]|0)==-1){m=62;break}t[d>>2]=0}e=t[(t[r>>2]|0)+36>>2]|0;if((u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==10){_=e+28|0;t[_>>2]=(t[_>>2]|0)+1;t[(t[(t[r>>2]|0)+36>>2]|0)+32>>2]=1}else{_=e+32|0;t[_>>2]=(t[_>>2]|0)+1}_=(t[(t[r>>2]|0)+36>>2]|0)+16|0;t[_>>2]=(t[_>>2]|0)+(t[w>>2]|0);if((u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==37)oE(t[r>>2]|0);t[h>>2]=Ap(t[r>>2]|0,w)|0}if((m|0)==50){MS(t[r>>2]|0,63,69400,0);pAi[t[135736>>2]&511](t[f>>2]|0);s=i;return}else if((m|0)==52){pAi[t[135736>>2]&511](t[f>>2]|0);Sp(t[r>>2]|0,0);s=i;return}else if((m|0)==62){pAi[t[135736>>2]&511](t[f>>2]|0);s=i;return}else if((m|0)==70){n[(t[f>>2]|0)+E>>0]=0;t[(t[r>>2]|0)+172>>2]=7;E=t[r>>2]|0;if((t[h>>2]|0)!=62){MS(E,63,69432,t[f>>2]|0);pAi[t[135736>>2]&511](t[f>>2]|0);s=i;return}h=t[(t[r>>2]|0)+36>>2]|0;if((u[t[(t[E+36>>2]|0)+16>>2]>>0]|0|0)==10){E=h+28|0;t[E>>2]=(t[E>>2]|0)+1;t[(t[(t[r>>2]|0)+36>>2]|0)+32>>2]=1}else{E=h+32|0;t[E>>2]=(t[E>>2]|0)+1}E=(t[(t[r>>2]|0)+36>>2]|0)+16|0;t[E>>2]=(t[E>>2]|0)+(t[w>>2]|0);if((u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==37)oE(t[r>>2]|0);do if(t[t[r>>2]>>2]|0){if(t[(t[r>>2]|0)+212>>2]|0)break;w=t[t[r>>2]>>2]|0;if(t[(t[t[r>>2]>>2]|0)+100>>2]|0){yAi[t[w+100>>2]&511](t[(t[r>>2]|0)+4>>2]|0,t[f>>2]|0,t[a>>2]|0);break}if(!(t[w+68>>2]|0))break;yAi[t[(t[t[r>>2]>>2]|0)+68>>2]&511](t[(t[r>>2]|0)+4>>2]|0,t[f>>2]|0,t[a>>2]|0)}while(0);pAi[t[135736>>2]&511](t[f>>2]|0);s=i;return}}function KE(e){e=e|0;var i=0,r=0,n=0,f=0,a=0,o=0,c=0,l=0;i=s;s=s+16|0;r=i+12|0;n=i+8|0;f=i+4|0;a=i;t[r>>2]=e;if((t[(t[r>>2]|0)+292>>2]|0)==0?((t[(t[(t[r>>2]|0)+36>>2]|0)+20>>2]|0)-(t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)|0)<250:0)CS(t[r>>2]|0);while(1){if(!(u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0)){o=45;break}if((u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==60?(u[(t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)+1>>0]|0|0)==47:0){o=45;break}if((t[(t[r>>2]|0)+172>>2]|0)==-1){o=45;break}t[n>>2]=t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2];t[f>>2]=t[(t[(t[r>>2]|0)+36>>2]|0)+36>>2];t[a>>2]=t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2];if((u[t[a>>2]>>0]|0|0)==60?(u[(t[a>>2]|0)+1>>0]|0|0)==63:0)FE(t[r>>2]|0);else o=11;do if((o|0)==11){o=0;if(((((((((u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==60?(u[(t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)+1>>0]|0|0)==33:0)?(u[(t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)+2>>0]|0|0)==91:0)?(u[(t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)+3>>0]|0|0)==67:0)?(u[(t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)+4>>0]|0|0)==68:0)?(u[(t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)+5>>0]|0|0)==65:0)?(u[(t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)+6>>0]|0|0)==84:0)?(u[(t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)+7>>0]|0|0)==65:0)?(u[(t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)+8>>0]|0|0)==91:0){WE(t[r>>2]|0);break}if((((u[t[a>>2]>>0]|0|0)==60?(u[(t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)+1>>0]|0|0)==33:0)?(u[(t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)+2>>0]|0|0)==45:0)?(u[(t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)+3>>0]|0|0)==45:0){gE(t[r>>2]|0);t[(t[r>>2]|0)+172>>2]=7;break}if((u[t[a>>2]>>0]|0|0)==60){XE(t[r>>2]|0);break}e=t[r>>2]|0;if((u[t[a>>2]>>0]|0|0)==38){jE(e);break}else{EE(e,0);break}}while(0);if((t[(t[r>>2]|0)+292>>2]|0)==0?((t[(t[(t[r>>2]|0)+36>>2]|0)+20>>2]|0)-(t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)|0)<250:0)CS(t[r>>2]|0);while(1){if(!(u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0))c=(t[(t[r>>2]|0)+40>>2]|0)>1;else c=0;l=t[r>>2]|0;if(!c)break;aE(l)|0}if(((t[l+292>>2]|0)==0?((t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)-(t[(t[(t[r>>2]|0)+36>>2]|0)+12>>2]|0)|0)>500:0)?((t[(t[(t[r>>2]|0)+36>>2]|0)+20>>2]|0)-(t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)|0)<500:0)qS(t[r>>2]|0);if((t[f>>2]|0)!=(t[(t[(t[r>>2]|0)+36>>2]|0)+36>>2]|0))continue;if((t[n>>2]|0)==(t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)){o=44;break}}if((o|0)==44){AS(t[r>>2]|0,1,69472);t[(t[r>>2]|0)+172>>2]=-1;s=i;return}else if((o|0)==45){s=i;return}}function XE(e){e=e|0;var i=0,r=0,n=0,f=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0;i=s;s=s+64|0;r=i+48|0;n=i+44|0;f=i+40|0;a=i+36|0;o=i+16|0;c=i+12|0;l=i+8|0;b=i+4|0;k=i;t[r>>2]=e;t[f>>2]=0;t[a>>2]=0;t[l>>2]=0;t[k>>2]=t[(t[r>>2]|0)+328>>2];if((t[(t[r>>2]|0)+188>>2]|0)>>>0>(t[16304]|0)>>>0?(t[(t[r>>2]|0)+360>>2]&524288|0)==0:0){OS(t[r>>2]|0,1,65224,t[16304]|0);t[(t[r>>2]|0)+172>>2]=-1;s=i;return}if(t[(t[r>>2]|0)+68>>2]|0){t[o+4>>2]=(t[(t[(t[r>>2]|0)+36>>2]|0)+36>>2]|0)+((t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)-(t[(t[(t[r>>2]|0)+36>>2]|0)+12>>2]|0));t[o+8>>2]=t[(t[(t[r>>2]|0)+36>>2]|0)+28>>2]}e=t[r>>2]|0;do if(t[(t[r>>2]|0)+236>>2]|0){h=t[r>>2]|0;if((t[t[e+232>>2]>>2]|0)==-2){og(h,-1)|0;break}else{og(h,t[t[(t[r>>2]|0)+232>>2]>>2]|0)|0;break}}else og(e,-1)|0;while(0);t[c>>2]=t[(t[(t[r>>2]|0)+36>>2]|0)+28>>2];e=t[r>>2]|0;if(t[(t[r>>2]|0)+324>>2]|0)t[n>>2]=cg(e,f,a,l)|0;else t[n>>2]=GE(e)|0;if((t[(t[r>>2]|0)+172>>2]|0)==-1){s=i;return}e=t[r>>2]|0;if(!(t[n>>2]|0)){lg(e)|0;s=i;return}fE(e,t[n>>2]|0)|0;t[b>>2]=t[(t[r>>2]|0)+52>>2];if(((((t[(t[r>>2]|0)+104>>2]|0)!=0?(t[(t[r>>2]|0)+12>>2]|0)!=0:0)?(t[(t[r>>2]|0)+8>>2]|0)!=0:0)?(t[(t[r>>2]|0)+52>>2]|0)!=0:0)?(t[(t[r>>2]|0)+52>>2]|0)==(t[(t[(t[r>>2]|0)+8>>2]|0)+12>>2]|0):0){e=kR((t[r>>2]|0)+108|0,t[(t[r>>2]|0)+8>>2]|0)|0;h=(t[r>>2]|0)+100|0;t[h>>2]=t[h>>2]&e}if((u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==47?(u[(t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)+1>>0]|0|0)==62:0){e=(t[r>>2]|0)+200|0;t[e>>2]=(t[e>>2]|0)+2;e=(t[(t[r>>2]|0)+36>>2]|0)+16|0;t[e>>2]=(t[e>>2]|0)+2;e=(t[(t[r>>2]|0)+36>>2]|0)+32|0;t[e>>2]=(t[e>>2]|0)+2;if((u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==37)oE(t[r>>2]|0);if((u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==0?(yp(t[(t[r>>2]|0)+36>>2]|0,250)|0)<=0:0)aE(t[r>>2]|0)|0;e=(t[t[r>>2]>>2]|0)!=0;if(t[(t[r>>2]|0)+324>>2]|0){if((e?(t[(t[t[r>>2]>>2]|0)+120>>2]|0)!=0:0)?(t[(t[r>>2]|0)+212>>2]|0)==0:0)NAi[t[(t[t[r>>2]>>2]|0)+120>>2]&511](t[(t[r>>2]|0)+4>>2]|0,t[n>>2]|0,t[f>>2]|0,t[a>>2]|0)}else if((e?(t[(t[t[r>>2]>>2]|0)+60>>2]|0)!=0:0)?(t[(t[r>>2]|0)+212>>2]|0)==0:0)EAi[t[(t[t[r>>2]>>2]|0)+60>>2]&511](t[(t[r>>2]|0)+4>>2]|0,t[n>>2]|0);tE(t[r>>2]|0)|0;lg(t[r>>2]|0)|0;if((t[k>>2]|0)!=(t[(t[r>>2]|0)+328>>2]|0))sg(t[r>>2]|0,(t[(t[r>>2]|0)+328>>2]|0)-(t[k>>2]|0)|0)|0;if(!(t[b>>2]|0)){s=i;return}if(!(t[(t[r>>2]|0)+68>>2]|0)){s=i;return}t[o+12>>2]=(t[(t[(t[r>>2]|0)+36>>2]|0)+36>>2]|0)+((t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)-(t[(t[(t[r>>2]|0)+36>>2]|0)+12>>2]|0));t[o+16>>2]=t[(t[(t[r>>2]|0)+36>>2]|0)+28>>2];t[o>>2]=t[b>>2];Vp(t[r>>2]|0,o);s=i;return}e=t[r>>2]|0;if((u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)!=62){bg(e,73,69512,t[n>>2]|0,t[c>>2]|0,0);nE(t[r>>2]|0)|0;tE(t[r>>2]|0)|0;lg(t[r>>2]|0)|0;if((t[k>>2]|0)!=(t[(t[r>>2]|0)+328>>2]|0))sg(t[r>>2]|0,(t[(t[r>>2]|0)+328>>2]|0)-(t[k>>2]|0)|0)|0;if(!(t[b>>2]|0)){s=i;return}if(!(t[(t[r>>2]|0)+68>>2]|0)){s=i;return}t[o+12>>2]=(t[(t[(t[r>>2]|0)+36>>2]|0)+36>>2]|0)+((t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)-(t[(t[(t[r>>2]|0)+36>>2]|0)+12>>2]|0));t[o+16>>2]=t[(t[(t[r>>2]|0)+36>>2]|0)+28>>2];t[o>>2]=t[b>>2];Vp(t[r>>2]|0,o);s=i;return}h=(t[e+36>>2]|0)+32|0;t[h>>2]=(t[h>>2]|0)+1;h=(t[(t[r>>2]|0)+36>>2]|0)+16|0;t[h>>2]=(t[h>>2]|0)+1;h=(t[r>>2]|0)+200|0;t[h>>2]=(t[h>>2]|0)+1;if(!(u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0))yp(t[(t[r>>2]|0)+36>>2]|0,250)|0;KE(t[r>>2]|0);if((t[(t[r>>2]|0)+172>>2]|0)==-1){s=i;return}if(!(9<=(u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)?(u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)<=10:0))w=55;if(((w|0)==55?(u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)!=13:0)?32>(u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0):0){bg(t[r>>2]|0,77,69560,t[n>>2]|0,t[c>>2]|0,0);nE(t[r>>2]|0)|0;tE(t[r>>2]|0)|0;lg(t[r>>2]|0)|0;if((t[k>>2]|0)==(t[(t[r>>2]|0)+328>>2]|0)){s=i;return}sg(t[r>>2]|0,(t[(t[r>>2]|0)+328>>2]|0)-(t[k>>2]|0)|0)|0;s=i;return}n=t[r>>2]|0;if(t[(t[r>>2]|0)+324>>2]|0){kg(n,t[f>>2]|0,t[a>>2]|0,t[c>>2]|0,(t[(t[r>>2]|0)+328>>2]|0)-(t[k>>2]|0)|0,t[l>>2]|0);tE(t[r>>2]|0)|0}else ag(n,t[c>>2]|0);if(!(t[b>>2]|0)){s=i;return}if(!(t[(t[r>>2]|0)+68>>2]|0)){s=i;return}t[o+12>>2]=(t[(t[(t[r>>2]|0)+36>>2]|0)+36>>2]|0)+((t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)-(t[(t[(t[r>>2]|0)+36>>2]|0)+12>>2]|0));t[o+16>>2]=t[(t[(t[r>>2]|0)+36>>2]|0)+28>>2];t[o>>2]=t[b>>2];Vp(t[r>>2]|0,o);s=i;return}function ZE(e){e=e|0;var i=0,r=0,f=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0;i=s;s=s+32|0;r=i+20|0;f=i+16|0;a=i+12|0;o=i+8|0;c=i+4|0;l=i+24|0;b=i;t[f>>2]=e;t[a>>2]=0;t[o>>2]=0;t[c>>2]=10;t[a>>2]=gAi[t[135752>>2]&511](t[c>>2]|0)|0;e=t[f>>2]|0;if(!(t[a>>2]|0)){Sp(e,0);t[r>>2]=0;k=t[r>>2]|0;s=i;return k|0}n[l>>0]=n[t[(t[e+36>>2]|0)+16>>2]>>0]|0;if((u[l>>0]|0|0)>=48?(u[l>>0]|0|0)<=57:0){e=n[l>>0]|0;h=t[o>>2]|0;t[o>>2]=h+1;n[(t[a>>2]|0)+h>>0]=e;Op(t[f>>2]|0);n[l>>0]=n[t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]>>0]|0;if((u[l>>0]|0|0)!=46){pAi[t[135736>>2]&511](t[a>>2]|0);t[r>>2]=0;k=t[r>>2]|0;s=i;return k|0}e=n[l>>0]|0;h=t[o>>2]|0;t[o>>2]=h+1;n[(t[a>>2]|0)+h>>0]=e;Op(t[f>>2]|0);n[l>>0]=n[t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]>>0]|0;while(1){if((u[l>>0]|0|0)>=48)w=(u[l>>0]|0|0)<=57;else w=0;d=t[o>>2]|0;if(!w){v=17;break}if((d+1|0)>=(t[c>>2]|0)){t[c>>2]=t[c>>2]<<1;t[b>>2]=MAi[t[135760>>2]&511](t[a>>2]|0,t[c>>2]|0)|0;if(!(t[b>>2]|0)){v=14;break}t[a>>2]=t[b>>2]}e=n[l>>0]|0;h=t[o>>2]|0;t[o>>2]=h+1;n[(t[a>>2]|0)+h>>0]=e;Op(t[f>>2]|0);n[l>>0]=n[t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]>>0]|0}if((v|0)==14){pAi[t[135736>>2]&511](t[a>>2]|0);Sp(t[f>>2]|0,0);t[r>>2]=0;k=t[r>>2]|0;s=i;return k|0}else if((v|0)==17){n[(t[a>>2]|0)+d>>0]=0;t[r>>2]=t[a>>2];k=t[r>>2]|0;s=i;return k|0}}pAi[t[135736>>2]&511](t[a>>2]|0);t[r>>2]=0;k=t[r>>2]|0;s=i;return k|0}function JE(e){e=e|0;var i=0,r=0,f=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0;i=s;s=s+32|0;r=i+20|0;f=i+16|0;a=i+12|0;o=i+8|0;c=i+4|0;l=i+24|0;b=i;t[f>>2]=e;t[a>>2]=0;t[o>>2]=0;t[c>>2]=10;n[l>>0]=n[t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]>>0]|0;if((u[l>>0]|0|0)>=97?(u[l>>0]|0|0)<=122:0)k=5;else k=3;do if((k|0)==3){if((u[l>>0]|0|0)>=65?(u[l>>0]|0|0)<=90:0){k=5;break}AS(t[f>>2]|0,79,0)}while(0);do if((k|0)==5){t[a>>2]=gAi[t[135752>>2]&511](t[c>>2]|0)|0;if(!(t[a>>2]|0)){Sp(t[f>>2]|0,0);t[r>>2]=0;h=t[r>>2]|0;s=i;return h|0}e=n[l>>0]|0;w=t[o>>2]|0;t[o>>2]=w+1;n[(t[a>>2]|0)+w>>0]=e;Op(t[f>>2]|0);n[l>>0]=n[t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]>>0]|0;while(1){if((u[l>>0]|0|0)>=97?(u[l>>0]|0|0)<=122:0)d=1;else k=10;do if((k|0)==10){k=0;if((u[l>>0]|0|0)>=65?(u[l>>0]|0|0)<=90:0){d=1;break}if((u[l>>0]|0|0)>=48?(u[l>>0]|0|0)<=57:0){d=1;break}if((u[l>>0]|0|0)!=46?(u[l>>0]|0|0)!=95:0)d=(u[l>>0]|0|0)==45;else d=1}while(0);v=t[o>>2]|0;if(!d){k=31;break}if((v+1|0)>=(t[c>>2]|0)){t[c>>2]=t[c>>2]<<1;t[b>>2]=MAi[t[135760>>2]&511](t[a>>2]|0,t[c>>2]|0)|0;if(!(t[b>>2]|0))break;t[a>>2]=t[b>>2]}e=n[l>>0]|0;w=t[o>>2]|0;t[o>>2]=w+1;n[(t[a>>2]|0)+w>>0]=e;Op(t[f>>2]|0);n[l>>0]=n[t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]>>0]|0;if(u[l>>0]|0)continue;if(((t[(t[f>>2]|0)+292>>2]|0)==0?((t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)-(t[(t[(t[f>>2]|0)+36>>2]|0)+12>>2]|0)|0)>500:0)?((t[(t[(t[f>>2]|0)+36>>2]|0)+20>>2]|0)-(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)|0)<500:0)qS(t[f>>2]|0);if((t[(t[f>>2]|0)+292>>2]|0)==0?((t[(t[(t[f>>2]|0)+36>>2]|0)+20>>2]|0)-(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)|0)<250:0)CS(t[f>>2]|0);n[l>>0]=n[t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]>>0]|0}if((k|0)==31){n[(t[a>>2]|0)+v>>0]=0;break}Sp(t[f>>2]|0,0);pAi[t[135736>>2]&511](t[a>>2]|0);t[r>>2]=0;h=t[r>>2]|0;s=i;return h|0}while(0);t[r>>2]=t[a>>2];h=t[r>>2]|0;s=i;return h|0}function QE(e){e=e|0;var i=0,r=0,n=0,f=0,a=0,o=0,c=0;i=s;s=s+16|0;r=i+8|0;n=i+4|0;f=i;t[n>>2]=e;t[f>>2]=-2;uE(t[n>>2]|0)|0;do if((((((((((u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==115?(u[(t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]|0)+1>>0]|0|0)==116:0)?(u[(t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]|0)+2>>0]|0|0)==97:0)?(u[(t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]|0)+3>>0]|0|0)==110:0)?(u[(t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]|0)+4>>0]|0|0)==100:0)?(u[(t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]|0)+5>>0]|0|0)==97:0)?(u[(t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]|0)+6>>0]|0|0)==108:0)?(u[(t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]|0)+7>>0]|0|0)==111:0)?(u[(t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]|0)+8>>0]|0|0)==110:0)?(u[(t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]|0)+9>>0]|0|0)==101:0){e=(t[n>>2]|0)+200|0;t[e>>2]=(t[e>>2]|0)+10;e=(t[(t[n>>2]|0)+36>>2]|0)+16|0;t[e>>2]=(t[e>>2]|0)+10;e=(t[(t[n>>2]|0)+36>>2]|0)+32|0;t[e>>2]=(t[e>>2]|0)+10;if((u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==37)oE(t[n>>2]|0);if((u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==0?(yp(t[(t[n>>2]|0)+36>>2]|0,250)|0)<=0:0)aE(t[n>>2]|0)|0;uE(t[n>>2]|0)|0;e=t[n>>2]|0;if((u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)!=61){AS(e,75,0);t[r>>2]=t[f>>2];a=t[r>>2]|0;s=i;return a|0}Op(e);uE(t[n>>2]|0)|0;e=t[n>>2]|0;if((u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==39){Op(e);do if((u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==110?(u[(t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]|0)+1>>0]|0|0)==111:0){t[f>>2]=0;o=(t[n>>2]|0)+200|0;t[o>>2]=(t[o>>2]|0)+2;o=(t[(t[n>>2]|0)+36>>2]|0)+16|0;t[o>>2]=(t[o>>2]|0)+2;o=(t[(t[n>>2]|0)+36>>2]|0)+32|0;t[o>>2]=(t[o>>2]|0)+2;if((u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==37)oE(t[n>>2]|0);if(u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0)break;if((yp(t[(t[n>>2]|0)+36>>2]|0,250)|0)>0)break;aE(t[n>>2]|0)|0}else c=26;while(0);e:do if((c|0)==26){do if((u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==121){if((u[(t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]|0)+1>>0]|0|0)!=101)break;if((u[(t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]|0)+2>>0]|0|0)!=115)break;t[f>>2]=1;o=(t[n>>2]|0)+200|0;t[o>>2]=(t[o>>2]|0)+3;o=(t[(t[n>>2]|0)+36>>2]|0)+16|0;t[o>>2]=(t[o>>2]|0)+3;o=(t[(t[n>>2]|0)+36>>2]|0)+32|0;t[o>>2]=(t[o>>2]|0)+3;if((u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==37)oE(t[n>>2]|0);if(u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0)break e;if((yp(t[(t[n>>2]|0)+36>>2]|0,250)|0)>0)break e;aE(t[n>>2]|0)|0;break e}while(0);AS(t[n>>2]|0,78,0)}while(0);o=t[n>>2]|0;if((u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)!=39){AS(o,34,0);break}else{Op(o);break}}o=t[n>>2]|0;if((u[t[(t[e+36>>2]|0)+16>>2]>>0]|0|0)!=34){AS(o,33,0);break}Op(o);do if((u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==110?(u[(t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]|0)+1>>0]|0|0)==111:0){t[f>>2]=0;o=(t[n>>2]|0)+200|0;t[o>>2]=(t[o>>2]|0)+2;o=(t[(t[n>>2]|0)+36>>2]|0)+16|0;t[o>>2]=(t[o>>2]|0)+2;o=(t[(t[n>>2]|0)+36>>2]|0)+32|0;t[o>>2]=(t[o>>2]|0)+2;if((u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==37)oE(t[n>>2]|0);if(u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0)break;if((yp(t[(t[n>>2]|0)+36>>2]|0,250)|0)>0)break;aE(t[n>>2]|0)|0}else c=46;while(0);e:do if((c|0)==46){do if((u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==121){if((u[(t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]|0)+1>>0]|0|0)!=101)break;if((u[(t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]|0)+2>>0]|0|0)!=115)break;t[f>>2]=1;e=(t[n>>2]|0)+200|0;t[e>>2]=(t[e>>2]|0)+3;e=(t[(t[n>>2]|0)+36>>2]|0)+16|0;t[e>>2]=(t[e>>2]|0)+3;e=(t[(t[n>>2]|0)+36>>2]|0)+32|0;t[e>>2]=(t[e>>2]|0)+3;if((u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==37)oE(t[n>>2]|0);if(u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0)break e;if((yp(t[(t[n>>2]|0)+36>>2]|0,250)|0)>0)break e;aE(t[n>>2]|0)|0;break e}while(0);AS(t[n>>2]|0,78,0)}while(0);e=t[n>>2]|0;if((u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)!=34){AS(e,34,0);break}else{Op(e);break}}while(0);t[r>>2]=t[f>>2];a=t[r>>2]|0;s=i;return a|0}function $E(e){e=e|0;var i=0,r=0,n=0,f=0,a=0;i=s;s=s+16|0;r=i+4|0;n=i;t[r>>2]=e;t[(t[(t[r>>2]|0)+36>>2]|0)+52>>2]=-2;e=(t[r>>2]|0)+200|0;t[e>>2]=(t[e>>2]|0)+5;e=(t[(t[r>>2]|0)+36>>2]|0)+16|0;t[e>>2]=(t[e>>2]|0)+5;e=(t[(t[r>>2]|0)+36>>2]|0)+32|0;t[e>>2]=(t[e>>2]|0)+5;if((u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==37)oE(t[r>>2]|0);if((u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==0?(yp(t[(t[r>>2]|0)+36>>2]|0,250)|0)<=0:0)aE(t[r>>2]|0)|0;do if((u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)!=32){if(9<=(u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)?(u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)<=10:0)break;if((u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)!=13)BS(t[r>>2]|0,65,69720)}while(0);uE(t[r>>2]|0)|0;t[n>>2]=xE(t[r>>2]|0)|0;if(!(t[n>>2]|0))AS(t[r>>2]|0,96,0);else{do if(!(Xl(t[n>>2]|0,68488)|0)){if(t[(t[r>>2]|0)+360>>2]&131072){MS(t[r>>2]|0,108,69752,t[n>>2]|0);break}if((u[t[n>>2]>>0]|0|0)==49?(u[(t[n>>2]|0)+1>>0]|0|0)==46:0){NS(t[r>>2]|0,97,69752,t[n>>2]|0,0);break}MS(t[r>>2]|0,108,69752,t[n>>2]|0)}while(0);if(t[(t[r>>2]|0)+20>>2]|0)pAi[t[135736>>2]&511](t[(t[r>>2]|0)+20>>2]|0);t[(t[r>>2]|0)+20>>2]=t[n>>2]}do if((u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)!=32){if(9<=(u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)?(u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)<=10:0)break;if((u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)!=13){if((u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==63?(u[(t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)+1>>0]|0|0)==62:0){n=(t[r>>2]|0)+200|0;t[n>>2]=(t[n>>2]|0)+2;n=(t[(t[r>>2]|0)+36>>2]|0)+16|0;t[n>>2]=(t[n>>2]|0)+2;n=(t[(t[r>>2]|0)+36>>2]|0)+32|0;t[n>>2]=(t[n>>2]|0)+2;if((u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==37)oE(t[r>>2]|0);if(u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0){s=i;return}if((yp(t[(t[r>>2]|0)+36>>2]|0,250)|0)>0){s=i;return}aE(t[r>>2]|0)|0;s=i;return}BS(t[r>>2]|0,65,69784)}}while(0);UE(t[r>>2]|0)|0;if((t[(t[r>>2]|0)+84>>2]|0)==32){s=i;return}do if((t[(t[(t[r>>2]|0)+36>>2]|0)+44>>2]|0)!=0?(u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)!=32:0){if(9<=(u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)?(u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)<=10:0)break;if((u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)!=13){if((u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==63?(u[(t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)+1>>0]|0|0)==62:0){n=(t[r>>2]|0)+200|0;t[n>>2]=(t[n>>2]|0)+2;n=(t[(t[r>>2]|0)+36>>2]|0)+16|0;t[n>>2]=(t[n>>2]|0)+2;n=(t[(t[r>>2]|0)+36>>2]|0)+32|0;t[n>>2]=(t[n>>2]|0)+2;if((u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==37)oE(t[r>>2]|0);if(u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0){s=i;return}if((yp(t[(t[r>>2]|0)+36>>2]|0,250)|0)>0){s=i;return}aE(t[r>>2]|0)|0;s=i;return}BS(t[r>>2]|0,65,69784)}}while(0);if((t[(t[r>>2]|0)+292>>2]|0)==0?((t[(t[(t[r>>2]|0)+36>>2]|0)+20>>2]|0)-(t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)|0)<250:0)CS(t[r>>2]|0);uE(t[r>>2]|0)|0;n=QE(t[r>>2]|0)|0;t[(t[(t[r>>2]|0)+36>>2]|0)+52>>2]=n;uE(t[r>>2]|0)|0;if((u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==63?(u[(t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)+1>>0]|0|0)==62:0){n=(t[r>>2]|0)+200|0;t[n>>2]=(t[n>>2]|0)+2;n=(t[(t[r>>2]|0)+36>>2]|0)+16|0;t[n>>2]=(t[n>>2]|0)+2;n=(t[(t[r>>2]|0)+36>>2]|0)+32|0;t[n>>2]=(t[n>>2]|0)+2;if((u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==37)oE(t[r>>2]|0);if(u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0){s=i;return}if((yp(t[(t[r>>2]|0)+36>>2]|0,250)|0)>0){s=i;return}aE(t[r>>2]|0)|0;s=i;return}n=(u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==62;AS(t[r>>2]|0,57,0);if(n){Op(t[r>>2]|0);s=i;return}while(1){if(u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0)f=(u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)!=62;else f=0;a=t[r>>2]|0;if(!f)break;n=(t[a+36>>2]|0)+16|0;t[n>>2]=(t[n>>2]|0)+1}Op(a);
	s=i;return}function eS(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i;t[r>>2]=e;e:while(1){if((t[(t[r>>2]|0)+172>>2]|0)==-1){n=22;break}if(!((u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==60?(u[(t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)+1>>0]|0|0)==63:0))n=5;do if((n|0)==5){n=0;if((((u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==60?(u[(t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)+1>>0]|0|0)==33:0)?(u[(t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)+2>>0]|0|0)==45:0)?(u[(t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)+3>>0]|0|0)==45:0)break;if((u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)!=32){if(9<=(u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)?(u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)<=10:0)break;if((u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)!=13){n=22;break e}}}while(0);if((u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==60?(u[(t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)+1>>0]|0|0)==63:0){FE(t[r>>2]|0);continue}do if((u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)!=32){if(9<=(u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)?(u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)<=10:0)break;if((u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)!=13){gE(t[r>>2]|0);continue e}}while(0);Op(t[r>>2]|0)}if((n|0)==22){s=i;return}}function iS(e){e=e|0;var i=0,r=0,f=0,a=0,o=0,c=0,l=0;i=s;s=s+16|0;r=i+8|0;f=i+4|0;a=i+12|0;o=i;t[f>>2]=e;rS();if((t[f>>2]|0)!=0?(t[(t[f>>2]|0)+36>>2]|0)!=0:0){if((t[(t[f>>2]|0)+292>>2]|0)==0?((t[(t[(t[f>>2]|0)+36>>2]|0)+20>>2]|0)-(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)|0)<250:0)CS(t[f>>2]|0);rg(t[f>>2]|0);if((t[t[f>>2]>>2]|0)!=0?(t[(t[t[f>>2]>>2]|0)+44>>2]|0)!=0:0)EAi[t[(t[t[f>>2]>>2]|0)+44>>2]&511](t[(t[f>>2]|0)+4>>2]|0,136080);if((t[(t[f>>2]|0)+172>>2]|0)==-1){t[r>>2]=-1;c=t[r>>2]|0;s=i;return c|0}if(((t[(t[f>>2]|0)+24>>2]|0)==0?((t[(t[(t[f>>2]|0)+36>>2]|0)+20>>2]|0)-(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)|0)>=4:0)?(n[a>>0]=n[t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]>>0]|0,n[a+1>>0]=n[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+1>>0]|0,n[a+2>>0]=n[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+2>>0]|0,n[a+3>>0]=n[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+3>>0]|0,t[o>>2]=L_(a,4)|0,(t[o>>2]|0)!=0):0)Tp(t[f>>2]|0,t[o>>2]|0)|0;if(!(u[t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]>>0]|0))AS(t[f>>2]|0,4,0);if((((t[(t[(t[f>>2]|0)+36>>2]|0)+20>>2]|0)-(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)|0)<35?(t[(t[f>>2]|0)+292>>2]|0)==0:0)?((t[(t[(t[f>>2]|0)+36>>2]|0)+20>>2]|0)-(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)|0)<250:0)CS(t[f>>2]|0);e:do if(((((u[t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==60?(u[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+1>>0]|0|0)==63:0)?(u[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+2>>0]|0|0)==120:0)?(u[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+3>>0]|0|0)==109:0)?(u[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+4>>0]|0|0)==108:0){do if((u[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+5>>0]|0|0)!=32){if(9<=(u[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+5>>0]|0|0)?(u[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+5>>0]|0|0)<=10:0)break;if((u[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+5>>0]|0|0)!=13){l=34;break e}}while(0);$E(t[f>>2]|0);if((t[(t[f>>2]|0)+84>>2]|0)!=32){t[(t[f>>2]|0)+28>>2]=t[(t[(t[f>>2]|0)+36>>2]|0)+52>>2];uE(t[f>>2]|0)|0;break}t[r>>2]=-1;c=t[r>>2]|0;s=i;return c|0}else l=34;while(0);if((l|0)==34){l=Wl(68488)|0;t[(t[f>>2]|0)+20>>2]=l}if(((t[t[f>>2]>>2]|0)!=0?(t[(t[t[f>>2]>>2]|0)+48>>2]|0)!=0:0)?(t[(t[f>>2]|0)+212>>2]|0)==0:0)pAi[t[(t[t[f>>2]>>2]|0)+48>>2]&511](t[(t[f>>2]|0)+4>>2]|0);if((t[(t[f>>2]|0)+172>>2]|0)==-1){t[r>>2]=-1;c=t[r>>2]|0;s=i;return c|0}if((((t[(t[f>>2]|0)+8>>2]|0)!=0?(t[(t[f>>2]|0)+36>>2]|0)!=0:0)?(t[t[(t[f>>2]|0)+36>>2]>>2]|0)!=0:0)?(t[(t[t[(t[f>>2]|0)+36>>2]>>2]|0)+24>>2]|0)>=0:0)t[(t[(t[f>>2]|0)+8>>2]|0)+36>>2]=t[(t[t[(t[f>>2]|0)+36>>2]>>2]|0)+24>>2];if((t[(t[f>>2]|0)+292>>2]|0)==0?((t[(t[(t[f>>2]|0)+36>>2]|0)+20>>2]|0)-(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)|0)<250:0)CS(t[f>>2]|0);eS(t[f>>2]|0);if((t[(t[f>>2]|0)+292>>2]|0)==0?((t[(t[(t[f>>2]|0)+36>>2]|0)+20>>2]|0)-(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)|0)<250:0)CS(t[f>>2]|0);do if((((u[t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==60?(u[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+1>>0]|0|0)==33:0)?(u[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+2>>0]|0|0)==68:0)?(u[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+3>>0]|0|0)==79:0){if((u[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+4>>0]|0|0)!=67)break;if((u[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+5>>0]|0|0)!=84)break;if((u[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+6>>0]|0|0)!=89)break;if((u[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+7>>0]|0|0)!=80)break;if((u[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+8>>0]|0|0)!=69)break;t[(t[f>>2]|0)+216>>2]=1;qE(t[f>>2]|0);do if((u[t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==91){t[(t[f>>2]|0)+172>>2]=3;hg(t[f>>2]|0);if((t[(t[f>>2]|0)+172>>2]|0)!=-1)break;t[r>>2]=-1;c=t[r>>2]|0;s=i;return c|0}while(0);t[(t[f>>2]|0)+216>>2]=2;do if(t[t[f>>2]>>2]|0){if(!(t[(t[t[f>>2]>>2]|0)+104>>2]|0))break;if(t[(t[f>>2]|0)+212>>2]|0)break;NAi[t[(t[t[f>>2]>>2]|0)+104>>2]&511](t[(t[f>>2]|0)+4>>2]|0,t[(t[f>>2]|0)+220>>2]|0,t[(t[f>>2]|0)+228>>2]|0,t[(t[f>>2]|0)+224>>2]|0)}while(0);if((t[(t[f>>2]|0)+172>>2]|0)!=-1){t[(t[f>>2]|0)+216>>2]=0;wg(t[f>>2]|0);t[(t[f>>2]|0)+172>>2]=4;eS(t[f>>2]|0);break}t[r>>2]=-1;c=t[r>>2]|0;s=i;return c|0}while(0);if((t[(t[f>>2]|0)+292>>2]|0)==0?((t[(t[(t[f>>2]|0)+36>>2]|0)+20>>2]|0)-(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)|0)<250:0)CS(t[f>>2]|0);l=t[f>>2]|0;if((u[t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)!=60)BS(l,4,69808);else{t[l+172>>2]=7;XE(t[f>>2]|0);t[(t[f>>2]|0)+172>>2]=14;eS(t[f>>2]|0);if(u[t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]>>0]|0)AS(t[f>>2]|0,5,0);t[(t[f>>2]|0)+172>>2]=-1}do if(t[t[f>>2]>>2]|0){if(!(t[(t[t[f>>2]>>2]|0)+52>>2]|0))break;pAi[t[(t[t[f>>2]>>2]|0)+52>>2]&511](t[(t[f>>2]|0)+4>>2]|0)}while(0);do if(t[(t[f>>2]|0)+8>>2]|0){if(!(Xl(t[(t[(t[f>>2]|0)+8>>2]|0)+56>>2]|0,67096)|0))break;fy(t[(t[f>>2]|0)+8>>2]|0);t[(t[f>>2]|0)+8>>2]=0}while(0);do if(t[(t[f>>2]|0)+12>>2]|0){if(!(t[(t[f>>2]|0)+8>>2]|0))break;l=(t[(t[f>>2]|0)+8>>2]|0)+92|0;t[l>>2]=t[l>>2]|1;if(t[(t[f>>2]|0)+100>>2]|0){l=(t[(t[f>>2]|0)+8>>2]|0)+92|0;t[l>>2]=t[l>>2]|8}if(t[(t[f>>2]|0)+356>>2]|0){l=(t[(t[f>>2]|0)+8>>2]|0)+92|0;t[l>>2]=t[l>>2]|2}if(!(t[(t[f>>2]|0)+360>>2]&131072))break;l=(t[(t[f>>2]|0)+8>>2]|0)+92|0;t[l>>2]=t[l>>2]|4}while(0);if(t[(t[f>>2]|0)+12>>2]|0){t[r>>2]=0;c=t[r>>2]|0;s=i;return c|0}else{t[(t[f>>2]|0)+100>>2]=0;t[r>>2]=-1;c=t[r>>2]|0;s=i;return c|0}}t[r>>2]=-1;c=t[r>>2]|0;s=i;return c|0}function rS(){var e=0;e=s;if(t[17532]|0){s=e;return}fl();qc();if((t[33976]|0)==35|(t[33976]|0)==0)up(0);yA()|0;uz()|0;U_();rj();LO();DO();bN();fj();kn();tc();t[17532]=1;s=e;return}function nS(e,i,r,f){e=e|0;i=i|0;r=r|0;f=f|0;var u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0,S=0,g=0,y=0,F=0,O=0,A=0,M=0,R=0,N=0,T=0,L=0;u=s;s=s+96|0;a=u;o=u+80|0;c=u+76|0;l=u+72|0;b=u+68|0;k=u+64|0;h=u+60|0;w=u+56|0;d=u+52|0;v=u+48|0;m=u+44|0;_=u+40|0;p=u+36|0;E=u+32|0;S=u+28|0;g=u+24|0;y=u+20|0;F=u+16|0;O=u+12|0;A=u+8|0;M=u+4|0;t[c>>2]=e;t[l>>2]=i;t[b>>2]=r;t[k>>2]=f;t[h>>2]=0;t[w>>2]=0;t[d>>2]=0;t[v>>2]=0;if(!(t[c>>2]|0)){t[o>>2]=1;R=t[o>>2]|0;s=u;return R|0}if((t[(t[c>>2]|0)+84>>2]|0)!=0?(t[(t[c>>2]|0)+212>>2]|0)==1:0){t[o>>2]=t[(t[c>>2]|0)+84>>2];R=t[o>>2]|0;s=u;return R|0}if((t[(t[c>>2]|0)+172>>2]|0)==-1){t[o>>2]=-1;R=t[o>>2]|0;s=u;return R|0}if(!(t[(t[c>>2]|0)+172>>2]|0))rg(t[c>>2]|0);if(!((t[b>>2]|0)>0&(t[l>>2]|0)!=0^1|(t[k>>2]|0)!=0)?(n[(t[l>>2]|0)+((t[b>>2]|0)-1)>>0]|0)==13:0){t[h>>2]=1;t[b>>2]=(t[b>>2]|0)+-1}while(1){if((((t[b>>2]|0)>0&(t[l>>2]|0)!=0?(t[(t[c>>2]|0)+36>>2]|0)!=0:0)?(t[t[(t[c>>2]|0)+36>>2]>>2]|0)!=0:0)?(t[(t[c>>2]|0)+172>>2]|0)!=-1:0){t[m>>2]=js(t[(t[t[(t[c>>2]|0)+36>>2]>>2]|0)+16>>2]|0,t[(t[c>>2]|0)+36>>2]|0)|0;t[_>>2]=(t[(t[(t[c>>2]|0)+36>>2]|0)+16>>2]|0)-(t[(t[(t[c>>2]|0)+36>>2]|0)+12>>2]|0);t[d>>2]=Ts(t[(t[t[(t[c>>2]|0)+36>>2]>>2]|0)+16>>2]|0)|0;do if((((t[(t[c>>2]|0)+172>>2]|0)==0?(t[(t[c>>2]|0)+36>>2]|0)!=0:0)?(t[t[(t[c>>2]|0)+36>>2]>>2]|0)!=0:0)?(t[(t[t[(t[c>>2]|0)+36>>2]>>2]|0)+12>>2]|0)!=0:0){t[E>>2]=45;do if((ns(t[t[(t[t[(t[c>>2]|0)+36>>2]>>2]|0)+12>>2]>>2]|0,69608)|0)==0?(ns(t[t[(t[t[(t[c>>2]|0)+36>>2]>>2]|0)+12>>2]>>2]|0,69616)|0)==0:0){if((ns(t[t[(t[t[(t[c>>2]|0)+36>>2]>>2]|0)+12>>2]>>2]|0,69848)|0)==0?(ns(t[t[(t[t[(t[c>>2]|0)+36>>2]>>2]|0)+12>>2]>>2]|0,69856)|0)==0:0)break;t[E>>2]=180}else N=23;while(0);if((N|0)==23){N=0;t[E>>2]=90}if((t[(t[t[(t[c>>2]|0)+36>>2]>>2]|0)+32>>2]|0)>>>0<(t[E>>2]|0)>>>0)t[E>>2]=(t[E>>2]|0)-(t[(t[t[(t[c>>2]|0)+36>>2]>>2]|0)+32>>2]|0);if((t[b>>2]|0)>>>0>(t[E>>2]|0)>>>0){t[w>>2]=(t[b>>2]|0)-(t[E>>2]|0);t[b>>2]=t[E>>2];break}else{t[w>>2]=0;break}}while(0);t[p>>2]=ZO(t[t[(t[c>>2]|0)+36>>2]>>2]|0,t[b>>2]|0,t[l>>2]|0)|0;T=t[c>>2]|0;if((t[p>>2]|0)<0){N=33;break}Vs(t[(t[t[T+36>>2]>>2]|0)+16>>2]|0,t[(t[c>>2]|0)+36>>2]|0,t[m>>2]|0,t[_>>2]|0)|0}else N=35;if(((((((N|0)==35?(N=0,(t[(t[c>>2]|0)+172>>2]|0)!=-1):0)?(t[(t[c>>2]|0)+36>>2]|0)!=0:0)?(t[t[(t[c>>2]|0)+36>>2]>>2]|0)!=0:0)?(t[S>>2]=t[t[(t[c>>2]|0)+36>>2]>>2],(t[(t[S>>2]|0)+12>>2]|0)!=0):0)?(t[(t[S>>2]|0)+16>>2]|0)!=0:0)?(t[(t[S>>2]|0)+20>>2]|0)!=0:0){t[y>>2]=js(t[(t[S>>2]|0)+16>>2]|0,t[(t[c>>2]|0)+36>>2]|0)|0;t[F>>2]=(t[(t[(t[c>>2]|0)+36>>2]|0)+16>>2]|0)-(t[(t[(t[c>>2]|0)+36>>2]|0)+12>>2]|0);t[g>>2]=Y_(t[S>>2]|0,t[k>>2]|0)|0;if((t[g>>2]|0)<0){N=42;break}Vs(t[(t[S>>2]|0)+16>>2]|0,t[(t[c>>2]|0)+36>>2]|0,t[y>>2]|0,t[F>>2]|0)|0}f=t[c>>2]|0;do if(t[w>>2]|0)dg(f,0)|0;else{if((t[f+36>>2]|0)!=0?(t[t[(t[c>>2]|0)+36>>2]>>2]|0)!=0:0)t[v>>2]=Ts(t[(t[t[(t[c>>2]|0)+36>>2]>>2]|0)+16>>2]|0)|0;if(!((t[k>>2]|0)!=0|(t[v>>2]|0)>>>0>1e7|(t[d>>2]|0)==0|(t[v>>2]|0)==0)?(vg(t[c>>2]|0,(t[(t[(t[c>>2]|0)+36>>2]|0)+12>>2]|0)+(t[d>>2]|0)|0,(t[v>>2]|0)-(t[d>>2]|0)|0)|0)==0:0)break;dg(t[c>>2]|0,t[k>>2]|0)|0}while(0);L=t[c>>2]|0;if((t[(t[c>>2]|0)+172>>2]|0)==-1){N=53;break}do if(t[L+36>>2]|0){if(((t[(t[(t[c>>2]|0)+36>>2]|0)+20>>2]|0)-(t[(t[(t[c>>2]|0)+36>>2]|0)+16>>2]|0)|0)<=1e7?((t[(t[(t[c>>2]|0)+36>>2]|0)+16>>2]|0)-(t[(t[(t[c>>2]|0)+36>>2]|0)+12>>2]|0)|0)<=1e7:0)break;if(!(t[(t[c>>2]|0)+360>>2]&524288)){AS(t[c>>2]|0,1,69896);t[(t[c>>2]|0)+172>>2]=-1}}while(0);if((t[(t[c>>2]|0)+84>>2]|0)!=0?(t[(t[c>>2]|0)+212>>2]|0)==1:0){N=61;break}if(!(t[w>>2]|0)){N=64;break}t[l>>2]=(t[l>>2]|0)+(t[b>>2]|0);t[b>>2]=t[w>>2];t[w>>2]=0}if((N|0)==33){t[T+84>>2]=-1;t[(t[c>>2]|0)+212>>2]=1;t[o>>2]=-1;R=t[o>>2]|0;s=u;return R|0}else if((N|0)==42){yAi[t[135904>>2]&511](t[33980]|0,69864,a);t[o>>2]=81;R=t[o>>2]|0;s=u;return R|0}else if((N|0)==53){t[o>>2]=t[L+84>>2];R=t[o>>2]|0;s=u;return R|0}else if((N|0)==61){t[o>>2]=t[(t[c>>2]|0)+84>>2];R=t[o>>2]|0;s=u;return R|0}else if((N|0)==64){if(((t[h>>2]|0)==1?(t[(t[c>>2]|0)+36>>2]|0)!=0:0)?(t[t[(t[c>>2]|0)+36>>2]>>2]|0)!=0:0){t[O>>2]=js(t[(t[t[(t[c>>2]|0)+36>>2]>>2]|0)+16>>2]|0,t[(t[c>>2]|0)+36>>2]|0)|0;t[A>>2]=(t[(t[(t[c>>2]|0)+36>>2]|0)+16>>2]|0)-(t[(t[(t[c>>2]|0)+36>>2]|0)+12>>2]|0);ZO(t[t[(t[c>>2]|0)+36>>2]>>2]|0,1,69920)|0;Vs(t[(t[t[(t[c>>2]|0)+36>>2]>>2]|0)+16>>2]|0,t[(t[c>>2]|0)+36>>2]|0,t[O>>2]|0,t[A>>2]|0)|0}if(t[k>>2]|0){t[M>>2]=0;do if(t[(t[c>>2]|0)+36>>2]|0){k=t[(t[c>>2]|0)+36>>2]|0;if(!(t[t[(t[c>>2]|0)+36>>2]>>2]|0)){t[M>>2]=(t[k+24>>2]|0)-((t[(t[(t[c>>2]|0)+36>>2]|0)+16>>2]|0)-(t[(t[(t[c>>2]|0)+36>>2]|0)+12>>2]|0));break}else{A=Ts(t[(t[k>>2]|0)+16>>2]|0)|0;t[M>>2]=A-((t[(t[(t[c>>2]|0)+36>>2]|0)+16>>2]|0)-(t[(t[(t[c>>2]|0)+36>>2]|0)+12>>2]|0));break}}while(0);if((t[(t[c>>2]|0)+172>>2]|0)!=-1?(t[(t[c>>2]|0)+172>>2]|0)!=14:0)AS(t[c>>2]|0,5,0);if((t[M>>2]|0)>0?(t[(t[c>>2]|0)+172>>2]|0)==14:0)AS(t[c>>2]|0,5,0);if(((t[(t[c>>2]|0)+172>>2]|0)!=-1?(t[t[c>>2]>>2]|0)!=0:0)?(t[(t[t[c>>2]>>2]|0)+52>>2]|0)!=0:0)pAi[t[(t[t[c>>2]>>2]|0)+52>>2]&511](t[(t[c>>2]|0)+4>>2]|0);t[(t[c>>2]|0)+172>>2]=-1}if(!(t[(t[c>>2]|0)+12>>2]|0)){t[o>>2]=t[(t[c>>2]|0)+84>>2];R=t[o>>2]|0;s=u;return R|0}else{t[o>>2]=0;R=t[o>>2]|0;s=u;return R|0}}return 0}function fS(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;var u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0;u=s;s=s+48|0;a=u+44|0;o=u+40|0;c=u+36|0;l=u+32|0;b=u+28|0;k=u+24|0;h=u+20|0;w=u+16|0;d=u+12|0;v=u+8|0;m=u+4|0;_=u;t[o>>2]=e;t[c>>2]=i;t[l>>2]=r;t[b>>2]=n;t[k>>2]=f;t[v>>2]=0;if((t[l>>2]|0)!=0&(t[b>>2]|0)>=4)t[v>>2]=L_(t[l>>2]|0,t[b>>2]|0)|0;t[d>>2]=CO(t[v>>2]|0)|0;if(!(t[d>>2]|0)){t[a>>2]=0;p=t[a>>2]|0;s=u;return p|0}t[h>>2]=zp()|0;if(!(t[h>>2]|0)){Sp(0,69928);IO(t[d>>2]|0);t[a>>2]=0;p=t[a>>2]|0;s=u;return p|0}t[(t[h>>2]|0)+364>>2]=1;f=gAi[t[135744>>2]&511]((t[(t[h>>2]|0)+192>>2]|0)*3<<2)|0;t[(t[h>>2]|0)+344>>2]=f;if(!(t[(t[h>>2]|0)+344>>2]|0)){Sp(t[h>>2]|0,0);IO(t[d>>2]|0);Up(t[h>>2]|0);t[a>>2]=0;p=t[a>>2]|0;s=u;return p|0}if(t[o>>2]|0){if((t[t[h>>2]>>2]|0)!=135968)pAi[t[135736>>2]&511](t[t[h>>2]>>2]|0);f=gAi[t[135744>>2]&511](128)|0;t[t[h>>2]>>2]=f;f=t[h>>2]|0;if(!(t[t[h>>2]>>2]|0)){Sp(f,0);IO(t[d>>2]|0);Up(t[h>>2]|0);t[a>>2]=0;p=t[a>>2]|0;s=u;return p|0}n=(t[f>>2]|0)+0|0;f=n+128|0;do{t[n>>2]=0;n=n+4|0}while((n|0)<(f|0));r=t[t[h>>2]>>2]|0;i=t[o>>2]|0;if((t[(t[o>>2]|0)+108>>2]|0)==-554844497){n=r+0|0;E=i+0|0;f=n+128|0;do{t[n>>2]=t[E>>2];n=n+4|0;E=E+4|0}while((n|0)<(f|0))}else{n=r+0|0;E=i+0|0;f=n+112|0;do{t[n>>2]=t[E>>2];n=n+4|0;E=E+4|0}while((n|0)<(f|0))}if(t[c>>2]|0)t[(t[h>>2]|0)+4>>2]=t[c>>2]}if(!(t[k>>2]|0))t[(t[h>>2]|0)+180>>2]=0;else{c=rA(t[k>>2]|0)|0;t[(t[h>>2]|0)+180>>2]=c}t[w>>2]=Cp(t[h>>2]|0)|0;if(!(t[w>>2]|0)){Up(t[h>>2]|0);IO(t[d>>2]|0);t[a>>2]=0;p=t[a>>2]|0;s=u;return p|0}if(t[k>>2]|0){c=KA(t[k>>2]|0)|0;t[(t[w>>2]|0)+4>>2]=c;if(!(t[(t[w>>2]|0)+4>>2]|0)){Up(t[h>>2]|0);IO(t[d>>2]|0);t[a>>2]=0;p=t[a>>2]|0;s=u;return p|0}}else t[(t[w>>2]|0)+4>>2]=0;t[t[w>>2]>>2]=t[d>>2];zs(t[(t[t[w>>2]>>2]|0)+16>>2]|0,t[w>>2]|0)|0;eE(t[h>>2]|0,t[w>>2]|0)|0;w=t[h>>2]|0;if(!((t[b>>2]|0)==0|(t[l>>2]|0)==0)){if((t[w+36>>2]|0)!=0?(t[t[(t[h>>2]|0)+36>>2]>>2]|0)!=0:0){t[m>>2]=js(t[(t[t[(t[h>>2]|0)+36>>2]>>2]|0)+16>>2]|0,t[(t[h>>2]|0)+36>>2]|0)|0;t[_>>2]=(t[(t[(t[h>>2]|0)+36>>2]|0)+16>>2]|0)-(t[(t[(t[h>>2]|0)+36>>2]|0)+12>>2]|0);ZO(t[t[(t[h>>2]|0)+36>>2]>>2]|0,t[b>>2]|0,t[l>>2]|0)|0;Vs(t[(t[t[(t[h>>2]|0)+36>>2]>>2]|0)+16>>2]|0,t[(t[h>>2]|0)+36>>2]|0,t[m>>2]|0,t[_>>2]|0)|0}}else t[w+256>>2]=0;if(t[v>>2]|0)Tp(t[h>>2]|0,t[v>>2]|0)|0;t[a>>2]=t[h>>2];p=t[a>>2]|0;s=u;return p|0}function tS(e){e=e|0;var i=0,r=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if(!(t[r>>2]|0)){s=i;return}t[(t[r>>2]|0)+172>>2]=-1;t[(t[r>>2]|0)+84>>2]=111;t[(t[r>>2]|0)+212>>2]=1;if(!(t[(t[r>>2]|0)+36>>2]|0)){s=i;return}t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]=65640;t[(t[(t[r>>2]|0)+36>>2]|0)+12>>2]=t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2];s=i;return}function uS(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0;n=s;s=s+48|0;f=n+36|0;u=n+32|0;a=n+28|0;o=n+24|0;c=n+20|0;l=n+16|0;b=n+12|0;k=n+8|0;h=n+4|0;w=n;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;t[c>>2]=0;t[b>>2]=0;if((t[a>>2]|0)==0&(t[o>>2]|0)==0){t[f>>2]=0;d=t[f>>2]|0;s=n;return d|0}t[l>>2]=zp()|0;if(!(t[l>>2]|0)){t[f>>2]=0;d=t[f>>2]|0;s=n;return d|0}r=(t[l>>2]|0)+360|0;t[r>>2]=t[r>>2]|4;if(t[u>>2]|0){if(t[t[l>>2]>>2]|0)pAi[t[135736>>2]&511](t[t[l>>2]>>2]|0);t[t[l>>2]>>2]=t[u>>2];t[(t[l>>2]|0)+4>>2]=t[l>>2]}t[h>>2]=KA(t[o>>2]|0)|0;r=t[l>>2]|0;if((t[o>>2]|0)!=0&(t[h>>2]|0)==0){Up(r);t[f>>2]=0;d=t[f>>2]|0;s=n;return d|0}if((t[r>>2]|0)!=0?(t[(t[t[l>>2]>>2]|0)+16>>2]|0)!=0:0)t[b>>2]=dAi[t[(t[t[l>>2]>>2]|0)+16>>2]&511](t[(t[l>>2]|0)+4>>2]|0,t[a>>2]|0,t[h>>2]|0)|0;if(!(t[b>>2]|0)){if(t[u>>2]|0)t[t[l>>2]>>2]=0;Up(t[l>>2]|0);if(t[h>>2]|0)pAi[t[135736>>2]&511](t[h>>2]|0);t[f>>2]=0;d=t[f>>2]|0;s=n;return d|0}if((cE(t[l>>2]|0,t[b>>2]|0)|0)<0){if(t[u>>2]|0)t[t[l>>2]>>2]=0;Up(t[l>>2]|0);if(t[h>>2]|0)pAi[t[135736>>2]&511](t[h>>2]|0);t[f>>2]=0;d=t[f>>2]|0;s=n;return d|0}if(((t[(t[(t[l>>2]|0)+36>>2]|0)+20>>2]|0)-(t[(t[(t[l>>2]|0)+36>>2]|0)+16>>2]|0)|0)>=4){t[k>>2]=L_(t[(t[(t[l>>2]|0)+36>>2]|0)+16>>2]|0,4)|0;Tp(t[l>>2]|0,t[k>>2]|0)|0}if(!(t[(t[b>>2]|0)+4>>2]|0))t[(t[b>>2]|0)+4>>2]=t[h>>2];else pAi[t[135736>>2]&511](t[h>>2]|0);t[(t[b>>2]|0)+28>>2]=1;t[(t[b>>2]|0)+32>>2]=1;t[(t[b>>2]|0)+12>>2]=t[(t[(t[l>>2]|0)+36>>2]|0)+16>>2];t[(t[b>>2]|0)+16>>2]=t[(t[(t[l>>2]|0)+36>>2]|0)+16>>2];t[(t[b>>2]|0)+40>>2]=0;t[(t[l>>2]|0)+216>>2]=2;b=ny(68488)|0;t[(t[l>>2]|0)+8>>2]=b;b=t[l>>2]|0;if(!(t[(t[l>>2]|0)+8>>2]|0)){Sp(b,67128);if(t[u>>2]|0)t[t[l>>2]>>2]=0;Up(t[l>>2]|0);t[f>>2]=0;d=t[f>>2]|0;s=n;return d|0}t[(t[b+8>>2]|0)+92>>2]=64;b=Jg(t[(t[l>>2]|0)+8>>2]|0,69960,t[a>>2]|0,t[o>>2]|0)|0;t[(t[(t[l>>2]|0)+8>>2]|0)+48>>2]=b;zE(t[l>>2]|0,t[a>>2]|0,t[o>>2]|0);if(t[(t[l>>2]|0)+8>>2]|0){e:do if(t[(t[l>>2]|0)+12>>2]|0){t[c>>2]=t[(t[(t[l>>2]|0)+8>>2]|0)+48>>2];t[(t[(t[l>>2]|0)+8>>2]|0)+48>>2]=0;if(t[c>>2]|0){t[(t[c>>2]|0)+32>>2]=0;t[w>>2]=t[(t[c>>2]|0)+12>>2];while(1){if(!(t[w>>2]|0))break e;t[(t[w>>2]|0)+32>>2]=0;t[w>>2]=t[(t[w>>2]|0)+24>>2]}}}else t[c>>2]=0;while(0);fy(t[(t[l>>2]|0)+8>>2]|0);t[(t[l>>2]|0)+8>>2]=0}if(t[u>>2]|0)t[t[l>>2]>>2]=0;Up(t[l>>2]|0);t[f>>2]=t[c>>2];d=t[f>>2]|0;s=n;return d|0}function aS(e,i){e=e|0;i=i|0;var r=0,n=0,f=0;r=s;s=s+16|0;n=r+4|0;f=r;t[n>>2]=e;t[f>>2]=i;i=uS(0,t[n>>2]|0,t[f>>2]|0)|0;s=r;return i|0}function oS(e,i,r,f){e=e|0;i=i|0;r=r|0;f=f|0;var a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0,S=0,g=0;a=s;s=s+64|0;o=a+44|0;c=a+40|0;l=a+36|0;b=a+32|0;k=a+28|0;h=a+24|0;w=a+20|0;d=a+16|0;v=a+12|0;m=a+8|0;_=a+48|0;p=a+4|0;E=a;t[c>>2]=e;t[l>>2]=i;t[b>>2]=r;t[k>>2]=f;t[v>>2]=0;t[m>>2]=0;if(!(t[c>>2]|0)){t[o>>2]=-1;S=t[o>>2]|0;s=a;return S|0}if(!((t[(t[c>>2]|0)+248>>2]|0)>40?(t[(t[c>>2]|0)+360>>2]&524288|0)==0:0))g=5;if((g|0)==5?(t[(t[c>>2]|0)+248>>2]|0)<=1024:0){if(t[k>>2]|0)t[t[k>>2]>>2]=0;if((t[l>>2]|0)==0&(t[b>>2]|0)==0){t[o>>2]=-1;S=t[o>>2]|0;s=a;return S|0}if(!(t[(t[c>>2]|0)+8>>2]|0)){t[o>>2]=-1;S=t[o>>2]|0;s=a;return S|0}t[h>>2]=mg(t[l>>2]|0,t[b>>2]|0,0,t[c>>2]|0)|0;if(!(t[h>>2]|0)){t[o>>2]=-1;S=t[o>>2]|0;s=a;return S|0}t[v>>2]=t[t[h>>2]>>2];t[t[h>>2]>>2]=t[t[c>>2]>>2];rg(t[h>>2]|0);t[w>>2]=ny(68488)|0;if(!(t[w>>2]|0)){Up(t[h>>2]|0);t[o>>2]=-1;S=t[o>>2]|0;s=a;return S|0}t[(t[w>>2]|0)+92>>2]=64;if(t[(t[(t[c>>2]|0)+8>>2]|0)+80>>2]|0){t[(t[w>>2]|0)+80>>2]=t[(t[(t[c>>2]|0)+8>>2]|0)+80>>2];sz(t[(t[w>>2]|0)+80>>2]|0)|0}if(t[(t[c>>2]|0)+8>>2]|0){t[(t[w>>2]|0)+44>>2]=t[(t[(t[c>>2]|0)+8>>2]|0)+44>>2];t[(t[w>>2]|0)+48>>2]=t[(t[(t[c>>2]|0)+8>>2]|0)+48>>2]}if(t[(t[(t[c>>2]|0)+8>>2]|0)+72>>2]|0){b=Yl(t[(t[(t[c>>2]|0)+8>>2]|0)+72>>2]|0)|0;t[(t[w>>2]|0)+72>>2]=b}t[d>>2]=Sy(t[w>>2]|0,0,69968,0)|0;if(!(t[d>>2]|0)){t[t[h>>2]>>2]=t[v>>2];Up(t[h>>2]|0);t[(t[w>>2]|0)+44>>2]=0;t[(t[w>>2]|0)+48>>2]=0;fy(t[w>>2]|0);t[o>>2]=-1;S=t[o>>2]|0;s=a;return S|0}Hy(t[w>>2]|0,t[d>>2]|0)|0;rE(t[h>>2]|0,t[(t[w>>2]|0)+12>>2]|0)|0;if(!(t[(t[c>>2]|0)+8>>2]|0))t[(t[h>>2]|0)+8>>2]=t[w>>2];else{t[(t[h>>2]|0)+8>>2]=t[(t[c>>2]|0)+8>>2];t[(t[(t[w>>2]|0)+12>>2]|0)+32>>2]=t[(t[c>>2]|0)+8>>2]}if((t[(t[h>>2]|0)+292>>2]|0)==0?((t[(t[(t[h>>2]|0)+36>>2]|0)+20>>2]|0)-(t[(t[(t[h>>2]|0)+36>>2]|0)+16>>2]|0)|0)<250:0)CS(t[h>>2]|0);if(((t[(t[(t[h>>2]|0)+36>>2]|0)+20>>2]|0)-(t[(t[(t[h>>2]|0)+36>>2]|0)+16>>2]|0)|0)>=4?(n[_>>0]=n[t[(t[(t[h>>2]|0)+36>>2]|0)+16>>2]>>0]|0,n[_+1>>0]=n[(t[(t[(t[h>>2]|0)+36>>2]|0)+16>>2]|0)+1>>0]|0,n[_+2>>0]=n[(t[(t[(t[h>>2]|0)+36>>2]|0)+16>>2]|0)+2>>0]|0,n[_+3>>0]=n[(t[(t[(t[h>>2]|0)+36>>2]|0)+16>>2]|0)+3>>0]|0,t[p>>2]=L_(_,4)|0,(t[p>>2]|0)!=0):0)Tp(t[h>>2]|0,t[p>>2]|0)|0;e:do if(((u[t[(t[(t[h>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==60?(u[(t[(t[(t[h>>2]|0)+36>>2]|0)+16>>2]|0)+1>>0]|0|0)==63:0)?(u[(t[(t[(t[h>>2]|0)+36>>2]|0)+16>>2]|0)+2>>0]|0|0)==120:0){if((u[(t[(t[(t[h>>2]|0)+36>>2]|0)+16>>2]|0)+3>>0]|0|0)!=109)break;if((u[(t[(t[(t[h>>2]|0)+36>>2]|0)+16>>2]|0)+4>>0]|0|0)!=108)break;do if((u[(t[(t[(t[h>>2]|0)+36>>2]|0)+16>>2]|0)+5>>0]|0|0)!=32){if(9<=(u[(t[(t[(t[h>>2]|0)+36>>2]|0)+16>>2]|0)+5>>0]|0|0)?(u[(t[(t[(t[h>>2]|0)+36>>2]|0)+16>>2]|0)+5>>0]|0|0)<=10:0)break;if((u[(t[(t[(t[h>>2]|0)+36>>2]|0)+16>>2]|0)+5>>0]|0|0)!=13)break e}while(0);bE(t[h>>2]|0);if(!(Xl(t[(t[c>>2]|0)+20>>2]|0,68488)|0))break;if(Xl(t[(t[(t[h>>2]|0)+36>>2]|0)+48>>2]|0,68488)|0)break;BS(t[h>>2]|0,109,69984)}while(0);if((t[(t[c>>2]|0)+4>>2]|0)==(t[c>>2]|0))t[(t[h>>2]|0)+4>>2]=t[h>>2];else t[(t[h>>2]|0)+4>>2]=t[(t[c>>2]|0)+4>>2];t[(t[h>>2]|0)+172>>2]=7;t[(t[h>>2]|0)+104>>2]=t[(t[c>>2]|0)+104>>2];t[(t[h>>2]|0)+100>>2]=t[(t[c>>2]|0)+100>>2];t[(t[h>>2]|0)+276>>2]=t[(t[c>>2]|0)+276>>2];t[(t[h>>2]|0)+248>>2]=(t[(t[c>>2]|0)+248>>2]|0)+1;t[(t[h>>2]|0)+16>>2]=t[(t[c>>2]|0)+16>>2];if(t[(t[h>>2]|0)+104>>2]|0){t[(t[h>>2]|0)+112>>2]=t[(t[c>>2]|0)+112>>2];t[(t[h>>2]|0)+116>>2]=t[(t[c>>2]|0)+116>>2]}else{t[(t[h>>2]|0)+112>>2]=0;t[(t[h>>2]|0)+116>>2]=0}t[(t[h>>2]|0)+132>>2]=0;t[(t[h>>2]|0)+124>>2]=0;t[(t[h>>2]|0)+128>>2]=0;t[(t[h>>2]|0)+120>>2]=0;if(t[(t[h>>2]|0)+296>>2]|0)bz(t[(t[h>>2]|0)+296>>2]|0);t[(t[h>>2]|0)+296>>2]=t[(t[c>>2]|0)+296>>2];p=kz(t[(t[h>>2]|0)+296>>2]|0,70032,3)|0;t[(t[h>>2]|0)+312>>2]=p;p=kz(t[(t[h>>2]|0)+296>>2]|0,70040,5)|0;t[(t[h>>2]|0)+316>>2]=p;p=kz(t[(t[h>>2]|0)+296>>2]|0,70048,36)|0;t[(t[h>>2]|0)+320>>2]=p;t[(t[h>>2]|0)+364>>2]=t[(t[c>>2]|0)+364>>2];t[(t[h>>2]|0)+348>>2]=t[(t[c>>2]|0)+348>>2];t[(t[h>>2]|0)+352>>2]=t[(t[c>>2]|0)+352>>2];t[(t[h>>2]|0)+280>>2]=t[(t[c>>2]|0)+280>>2];KE(t[h>>2]|0);t[(t[c>>2]|0)+104>>2]=t[(t[h>>2]|0)+104>>2];t[(t[c>>2]|0)+100>>2]=t[(t[h>>2]|0)+100>>2];do if((u[t[(t[(t[h>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==60){if((u[(t[(t[(t[h>>2]|0)+36>>2]|0)+16>>2]|0)+1>>0]|0|0)!=47){g=57;break}AS(t[h>>2]|0,85,0)}else g=57;while(0);do if((g|0)==57){if(!(u[t[(t[(t[h>>2]|0)+36>>2]|0)+16>>2]>>0]|0))break;AS(t[h>>2]|0,86,0)}while(0);if((t[(t[h>>2]|0)+52>>2]|0)!=(t[(t[w>>2]|0)+12>>2]|0))AS(t[h>>2]|0,85,0);do if(!(t[(t[h>>2]|0)+12>>2]|0))if(!(t[(t[h>>2]|0)+84>>2]|0)){t[m>>2]=1;break}else{t[m>>2]=t[(t[h>>2]|0)+84>>2];break}else{if(t[k>>2]|0){t[E>>2]=t[(t[(t[w>>2]|0)+12>>2]|0)+12>>2];t[t[k>>2]>>2]=t[E>>2];while(1){if(!(t[E>>2]|0))break;t[(t[E>>2]|0)+20>>2]=0;t[E>>2]=t[(t[E>>2]|0)+24>>2]}t[(t[(t[w>>2]|0)+12>>2]|0)+12>>2]=0}t[m>>2]=0}while(0);t[t[h>>2]>>2]=t[v>>2];t[(t[h>>2]|0)+296>>2]=0;t[(t[h>>2]|0)+348>>2]=0;t[(t[h>>2]|0)+352>>2]=0;Up(t[h>>2]|0);t[(t[w>>2]|0)+44>>2]=0;t[(t[w>>2]|0)+48>>2]=0;fy(t[w>>2]|0);t[o>>2]=t[m>>2];S=t[o>>2]|0;s=a;return S|0}t[o>>2]=89;S=t[o>>2]|0;s=a;return S|0}function cS(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;var a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0,S=0,g=0,y=0,F=0,O=0,A=0,M=0;a=s;s=s+64|0;o=a+60|0;c=a+56|0;l=a+52|0;b=a+48|0;k=a+44|0;h=a+40|0;w=a+36|0;d=a+32|0;v=a+28|0;m=a+24|0;_=a+20|0;p=a+16|0;E=a+12|0;S=a+8|0;g=a+4|0;y=a;t[c>>2]=e;t[l>>2]=i;t[b>>2]=r;t[k>>2]=n;t[h>>2]=f;t[d>>2]=0;t[_>>2]=0;t[p>>2]=0;if((t[h>>2]|0)==0|(t[c>>2]|0)==0|(t[l>>2]|0)==0|(t[b>>2]|0)<0){t[o>>2]=1;F=t[o>>2]|0;s=a;return F|0}switch(t[(t[c>>2]|0)+4>>2]|0){case 13:case 9:case 8:case 7:case 5:case 4:case 3:case 2:case 1:break;default:{t[o>>2]=1;F=t[o>>2]|0;s=a;return F|0}}while(1){if(((t[c>>2]|0)!=0?(t[(t[c>>2]|0)+4>>2]|0)!=1:0)?(t[(t[c>>2]|0)+4>>2]|0)!=9:0)O=(t[(t[c>>2]|0)+4>>2]|0)!=13;else O=0;A=t[c>>2]|0;if(!O)break;t[c>>2]=t[A+20>>2]}if(!A){t[o>>2]=1;F=t[o>>2]|0;s=a;return F|0}A=t[c>>2]|0;if((t[(t[c>>2]|0)+4>>2]|0)==1)t[d>>2]=t[A+32>>2];else t[d>>2]=A;if(!(t[d>>2]|0)){t[o>>2]=1;F=t[o>>2]|0;s=a;return F|0}do if((t[(t[d>>2]|0)+4>>2]|0)==9)t[w>>2]=lS(t[l>>2]|0,t[b>>2]|0)|0;else{if((t[(t[d>>2]|0)+4>>2]|0)==13){t[w>>2]=yN(t[l>>2]|0,t[b>>2]|0)|0;t[k>>2]=t[k>>2]|8192;break}t[o>>2]=1;F=t[o>>2]|0;s=a;return F|0}while(0);if(!(t[w>>2]|0)){t[o>>2]=2;F=t[o>>2]|0;s=a;return F|0}if(t[(t[d>>2]|0)+80>>2]|0){if(t[(t[w>>2]|0)+296>>2]|0)bz(t[(t[w>>2]|0)+296>>2]|0);t[(t[w>>2]|0)+296>>2]=t[(t[d>>2]|0)+80>>2]}else t[k>>2]=t[k>>2]|4096;do if(t[(t[d>>2]|0)+60>>2]|0){if(t[(t[w>>2]|0)+24>>2]|0)pAi[t[135736>>2]&511](t[(t[w>>2]|0)+24>>2]|0);b=Yl(t[(t[d>>2]|0)+60>>2]|0)|0;t[(t[w>>2]|0)+24>>2]=b;t[E>>2]=V_(t[(t[d>>2]|0)+60>>2]|0)|0;if(t[E>>2]|0){Lp(t[w>>2]|0,t[E>>2]|0)|0;break}t[o>>2]=32;F=t[o>>2]|0;s=a;return F|0}while(0);_g(t[w>>2]|0,t[k>>2]|0,0)|0;rg(t[w>>2]|0);t[(t[w>>2]|0)+8>>2]=t[d>>2];t[(t[w>>2]|0)+172>>2]=7;t[v>>2]=Ay(0)|0;if(!(t[v>>2]|0)){Up(t[w>>2]|0);t[o>>2]=2;F=t[o>>2]|0;s=a;return F|0}Hy(t[c>>2]|0,t[v>>2]|0)|0;e:do if((t[(t[c>>2]|0)+4>>2]|0)==1){rE(t[w>>2]|0,t[c>>2]|0)|0;t[m>>2]=t[c>>2];while(1){if(!(t[m>>2]|0))break e;if((t[(t[m>>2]|0)+4>>2]|0)!=1)break e;t[S>>2]=t[(t[m>>2]|0)+48>>2];while(1){if(!(t[S>>2]|0))break;if(t[(t[w>>2]|0)+296>>2]|0){t[g>>2]=kz(t[(t[w>>2]|0)+296>>2]|0,t[(t[S>>2]|0)+12>>2]|0,-1)|0;t[y>>2]=kz(t[(t[w>>2]|0)+296>>2]|0,t[(t[S>>2]|0)+8>>2]|0,-1)|0}else{t[g>>2]=t[(t[S>>2]|0)+12>>2];t[y>>2]=t[(t[S>>2]|0)+8>>2]}if(!(pg(t[w>>2]|0,t[g>>2]|0)|0)){Eg(t[w>>2]|0,t[g>>2]|0,t[y>>2]|0)|0;t[_>>2]=(t[_>>2]|0)+1}t[S>>2]=t[t[S>>2]>>2]}t[m>>2]=t[(t[m>>2]|0)+20>>2]}}while(0);if(!((t[(t[w>>2]|0)+104>>2]|0)==0?(t[(t[w>>2]|0)+16>>2]|0)==0:0)){S=(t[w>>2]|0)+276|0;t[S>>2]=t[S>>2]|8}S=t[w>>2]|0;if((t[(t[d>>2]|0)+4>>2]|0)==13)pN(S);else KE(S);sg(t[w>>2]|0,t[_>>2]|0)|0;if((u[t[(t[(t[w>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==60?(u[(t[(t[(t[w>>2]|0)+36>>2]|0)+16>>2]|0)+1>>0]|0|0)==47:0)AS(t[w>>2]|0,85,0);else M=60;if((M|0)==60?(u[t[(t[(t[w>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)!=0:0)AS(t[w>>2]|0,86,0);if((t[(t[w>>2]|0)+52>>2]|0)!=0?(t[(t[w>>2]|0)+52>>2]|0)!=(t[c>>2]|0):0){AS(t[w>>2]|0,85,0);t[(t[w>>2]|0)+12>>2]=0}do if(!(t[(t[w>>2]|0)+12>>2]|0))if(!(t[(t[w>>2]|0)+84>>2]|0)){t[p>>2]=1;break}else{t[p>>2]=t[(t[w>>2]|0)+84>>2];break}else t[p>>2]=0;while(0);t[m>>2]=t[(t[v>>2]|0)+24>>2];t[(t[v>>2]|0)+24>>2]=0;t[(t[c>>2]|0)+16>>2]=t[v>>2];if(t[m>>2]|0)t[(t[m>>2]|0)+28>>2]=0;t[t[h>>2]>>2]=t[m>>2];while(1){if(!(t[m>>2]|0))break;t[(t[m>>2]|0)+20>>2]=0;t[m>>2]=t[(t[m>>2]|0)+24>>2]}iy(t[v>>2]|0);ry(t[v>>2]|0);if(t[p>>2]|0){ty(t[t[h>>2]>>2]|0);t[t[h>>2]>>2]=0}if(t[(t[d>>2]|0)+80>>2]|0)t[(t[w>>2]|0)+296>>2]=0;Up(t[w>>2]|0);t[o>>2]=t[p>>2];F=t[o>>2]|0;s=a;return F|0}function lS(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0;r=s;s=s+32|0;n=r+20|0;f=r+16|0;u=r+12|0;a=r+8|0;o=r+4|0;c=r;t[f>>2]=e;t[u>>2]=i;if(!(t[f>>2]|0)){t[n>>2]=0;l=t[n>>2]|0;s=r;return l|0}if((t[u>>2]|0)<=0){t[n>>2]=0;l=t[n>>2]|0;s=r;return l|0}t[a>>2]=zp()|0;if(!(t[a>>2]|0)){t[n>>2]=0;l=t[n>>2]|0;s=r;return l|0}t[c>>2]=GO(t[f>>2]|0,t[u>>2]|0,0)|0;u=t[a>>2]|0;if(!(t[c>>2]|0)){Up(u);t[n>>2]=0;l=t[n>>2]|0;s=r;return l|0}t[o>>2]=Cp(u)|0;if(!(t[o>>2]|0)){IO(t[c>>2]|0);Up(t[a>>2]|0);t[n>>2]=0;l=t[n>>2]|0;s=r;return l|0}else{t[(t[o>>2]|0)+4>>2]=0;t[t[o>>2]>>2]=t[c>>2];zs(t[(t[t[o>>2]>>2]|0)+16>>2]|0,t[o>>2]|0)|0;eE(t[a>>2]|0,t[o>>2]|0)|0;t[n>>2]=t[a>>2];l=t[n>>2]|0;s=r;return l|0}return 0}function sS(e){e=e|0;var i=0,r=0;i=s;s=s+16|0;r=i;t[r>>2]=e;e=bS(t[r>>2]|0,0)|0;s=i;return e|0}function bS(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0;r=s;s=s+32|0;n=r+20|0;f=r+16|0;u=r+12|0;a=r+8|0;o=r+4|0;c=r;t[f>>2]=e;t[u>>2]=i;t[c>>2]=0;t[a>>2]=zp()|0;if(!(t[a>>2]|0)){Sp(0,70088);t[n>>2]=0;l=t[n>>2]|0;s=r;return l|0}if(t[u>>2]|0)_g(t[a>>2]|0,t[u>>2]|0,0)|0;t[(t[a>>2]|0)+280>>2]=1;t[o>>2]=uA(t[f>>2]|0,0,t[a>>2]|0)|0;u=t[a>>2]|0;if(!(t[o>>2]|0)){Up(u);t[n>>2]=0;l=t[n>>2]|0;s=r;return l|0}eE(u,t[o>>2]|0)|0;if((t[c>>2]|0)==0?(t[(t[a>>2]|0)+180>>2]|0)==0:0)t[c>>2]=rA(t[f>>2]|0)|0;if((t[c>>2]|0)!=0?(t[(t[a>>2]|0)+180>>2]|0)==0:0)t[(t[a>>2]|0)+180>>2]=t[c>>2];t[n>>2]=t[a>>2];l=t[n>>2]|0;s=r;return l|0}function kS(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0;f=s;s=s+32|0;u=f+24|0;a=f+20|0;o=f+16|0;c=f+12|0;l=f+8|0;b=f+4|0;k=f;t[a>>2]=e;t[o>>2]=i;t[c>>2]=r;t[l>>2]=n;rS();t[k>>2]=sS(t[o>>2]|0)|0;if(!(t[k>>2]|0)){t[u>>2]=0;h=t[u>>2]|0;s=f;return h|0}if(t[a>>2]|0){if(t[t[k>>2]>>2]|0)pAi[t[135736>>2]&511](t[t[k>>2]>>2]|0);t[t[k>>2]>>2]=t[a>>2]}rg(t[k>>2]|0);if(t[l>>2]|0)t[(t[k>>2]|0)+272>>2]=t[l>>2];if(!(t[(t[k>>2]|0)+180>>2]|0)){l=rA(t[o>>2]|0)|0;t[(t[k>>2]|0)+180>>2]=l}t[(t[k>>2]|0)+288>>2]=t[c>>2];iS(t[k>>2]|0)|0;do if((t[c>>2]|0)!=0?1:(t[(t[k>>2]|0)+12>>2]|0)!=0){t[b>>2]=t[(t[k>>2]|0)+8>>2];if(t[b>>2]|0)if((t[(t[t[(t[k>>2]|0)+36>>2]>>2]|0)+24>>2]|0)>0){t[(t[b>>2]|0)+36>>2]=9;break}else{t[(t[b>>2]|0)+36>>2]=t[(t[t[(t[k>>2]|0)+36>>2]>>2]|0)+24>>2];break}}else{t[b>>2]=0;fy(t[(t[k>>2]|0)+8>>2]|0);t[(t[k>>2]|0)+8>>2]=0}while(0);if(t[a>>2]|0)t[t[k>>2]>>2]=0;Up(t[k>>2]|0);t[u>>2]=t[b>>2];h=t[u>>2]|0;s=f;return h|0}function hS(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0;n=s;s=s+16|0;f=n+8|0;u=n+4|0;a=n;t[f>>2]=e;t[u>>2]=i;t[a>>2]=r;r=kS(t[f>>2]|0,t[u>>2]|0,t[a>>2]|0,0)|0;s=n;return r|0}function wS(e){e=e|0;var i=0,r=0;i=s;s=s+16|0;r=i;t[r>>2]=e;e=hS(0,t[r>>2]|0,0)|0;s=i;return e|0}function dS(){var e=0;e=s;if(!(t[17532]|0)){s=e;return}z_();oc();cz();SO();gO();_D();BH();mp();Yc();tl();CA();t[17532]=0;s=e;return}function vS(e){e=e|0;var i=0,r=0,n=0,f=0;i=s;s=s+16|0;r=i+8|0;n=i+4|0;f=i;t[r>>2]=e;if(!(t[r>>2]|0)){s=i;return}t[f>>2]=t[(t[r>>2]|0)+296>>2];while(1){e=iE(t[r>>2]|0)|0;t[n>>2]=e;if(!e)break;Dp(t[n>>2]|0)}t[(t[r>>2]|0)+40>>2]=0;t[(t[r>>2]|0)+36>>2]=0;t[(t[r>>2]|0)+236>>2]=0;n=t[r>>2]|0;if(t[(t[r>>2]|0)+244>>2]|0){t[t[n+244>>2]>>2]=-1;t[(t[r>>2]|0)+232>>2]=t[(t[r>>2]|0)+244>>2]}else t[n+232>>2]=0;t[(t[r>>2]|0)+56>>2]=0;t[(t[r>>2]|0)+52>>2]=0;t[(t[r>>2]|0)+188>>2]=0;t[(t[r>>2]|0)+184>>2]=0;do if(t[(t[r>>2]|0)+20>>2]|0){if((t[f>>2]|0)!=0?(wz(t[f>>2]|0,t[(t[r>>2]|0)+20>>2]|0)|0)!=0:0)break;pAi[t[135736>>2]&511](t[(t[r>>2]|0)+20>>2]|0)}while(0);t[(t[r>>2]|0)+20>>2]=0;do if(t[(t[r>>2]|0)+24>>2]|0){if((t[f>>2]|0)!=0?(wz(t[f>>2]|0,t[(t[r>>2]|0)+24>>2]|0)|0)!=0:0)break;pAi[t[135736>>2]&511](t[(t[r>>2]|0)+24>>2]|0)}while(0);t[(t[r>>2]|0)+24>>2]=0;do if(t[(t[r>>2]|0)+180>>2]|0){if((t[f>>2]|0)!=0?(wz(t[f>>2]|0,t[(t[r>>2]|0)+180>>2]|0)|0)!=0:0)break;pAi[t[135736>>2]&511](t[(t[r>>2]|0)+180>>2]|0)}while(0);t[(t[r>>2]|0)+180>>2]=0;do if(t[(t[r>>2]|0)+224>>2]|0){if((t[f>>2]|0)!=0?(wz(t[f>>2]|0,t[(t[r>>2]|0)+224>>2]|0)|0)!=0:0)break;pAi[t[135736>>2]&511](t[(t[r>>2]|0)+224>>2]|0)}while(0);t[(t[r>>2]|0)+224>>2]=0;do if(t[(t[r>>2]|0)+228>>2]|0){if((t[f>>2]|0)!=0?(wz(t[f>>2]|0,t[(t[r>>2]|0)+228>>2]|0)|0)!=0:0)break;pAi[t[135736>>2]&511](t[(t[r>>2]|0)+228>>2]|0)}while(0);t[(t[r>>2]|0)+228>>2]=0;if(t[(t[r>>2]|0)+8>>2]|0)fy(t[(t[r>>2]|0)+8>>2]|0);t[(t[r>>2]|0)+8>>2]=0;t[(t[r>>2]|0)+28>>2]=-1;t[(t[r>>2]|0)+88>>2]=0;t[(t[r>>2]|0)+92>>2]=0;t[(t[r>>2]|0)+32>>2]=0;t[(t[r>>2]|0)+96>>2]=0;t[(t[r>>2]|0)+172>>2]=0;t[(t[r>>2]|0)+176>>2]=0;t[(t[r>>2]|0)+12>>2]=1;t[(t[r>>2]|0)+356>>2]=1;t[(t[r>>2]|0)+212>>2]=0;t[(t[r>>2]|0)+100>>2]=1;t[(t[r>>2]|0)+68>>2]=0;t[(t[r>>2]|0)+200>>2]=0;t[(t[r>>2]|0)+204>>2]=0;t[(t[r>>2]|0)+216>>2]=0;t[(t[r>>2]|0)+84>>2]=0;t[(t[r>>2]|0)+248>>2]=0;t[(t[r>>2]|0)+256>>2]=1;t[(t[r>>2]|0)+284>>2]=0;t[(t[r>>2]|0)+440>>2]=0;t[(t[r>>2]|0)+444>>2]=0;t[(t[r>>2]|0)+468>>2]=0;xp((t[r>>2]|0)+72|0);if(t[(t[r>>2]|0)+348>>2]|0){XF(t[(t[r>>2]|0)+348>>2]|0,t[33934]|0);t[(t[r>>2]|0)+348>>2]=0}if(t[(t[r>>2]|0)+352>>2]|0){XF(t[(t[r>>2]|0)+352>>2]|0,0);t[(t[r>>2]|0)+352>>2]=0}if(t[(t[r>>2]|0)+284>>2]|0)bc(t[(t[r>>2]|0)+284>>2]|0);if(!(t[(t[r>>2]|0)+388>>2]|0)){s=i;return}lp((t[r>>2]|0)+384|0);s=i;return}function mS(e,i){e=e|0;i=i|0;var r=0,n=0,f=0;r=s;s=s+16|0;n=r+4|0;f=r;t[n>>2]=e;t[f>>2]=i;i=_g(t[n>>2]|0,t[f>>2]|0,0)|0;s=r;return i|0}function _S(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,l=0;n=s;s=s+32|0;f=n+16|0;u=n+12|0;a=n+8|0;o=n+4|0;c=n;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;rS();t[c>>2]=bS(t[u>>2]|0,t[o>>2]|0)|0;if(!(t[c>>2]|0)){t[f>>2]=0;l=t[f>>2]|0;s=n;return l|0}else{t[f>>2]=Sg(t[c>>2]|0,0,t[a>>2]|0,t[o>>2]|0,0)|0;l=t[f>>2]|0;s=n;return l|0}return 0}function pS(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;var u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0;u=s;s=s+32|0;a=u+24|0;o=u+20|0;c=u+16|0;l=u+12|0;b=u+8|0;k=u+4|0;h=u;t[o>>2]=e;t[c>>2]=i;t[l>>2]=r;t[b>>2]=n;t[k>>2]=f;rS();t[h>>2]=lS(t[o>>2]|0,t[c>>2]|0)|0;if(!(t[h>>2]|0)){t[a>>2]=0;w=t[a>>2]|0;s=u;return w|0}else{t[a>>2]=Sg(t[h>>2]|0,t[l>>2]|0,t[b>>2]|0,t[k>>2]|0,0)|0;w=t[a>>2]|0;s=u;return w|0}return 0}function ES(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0;f=s;s=s+32|0;u=f+28|0;a=f+24|0;o=f+20|0;c=f+16|0;l=f+12|0;b=f+8|0;k=f+4|0;h=f;t[a>>2]=e;t[o>>2]=i;t[c>>2]=r;t[l>>2]=n;if((t[a>>2]|0)<0){t[u>>2]=0;w=t[u>>2]|0;s=f;return w|0}rS();t[k>>2]=YO(t[a>>2]|0,0)|0;if(!(t[k>>2]|0)){t[u>>2]=0;w=t[u>>2]|0;s=f;return w|0}t[(t[k>>2]|0)+8>>2]=0;t[b>>2]=zp()|0;if(!(t[b>>2]|0)){IO(t[k>>2]|0);t[u>>2]=0;w=t[u>>2]|0;s=f;return w|0}t[h>>2]=Pp(t[b>>2]|0,t[k>>2]|0,0)|0;if(!(t[h>>2]|0)){IO(t[k>>2]|0);Up(t[b>>2]|0);t[u>>2]=0;w=t[u>>2]|0;s=f;return w|0}else{eE(t[b>>2]|0,t[h>>2]|0)|0;t[u>>2]=Sg(t[b>>2]|0,t[o>>2]|0,t[c>>2]|0,t[l>>2]|0,0)|0;w=t[u>>2]|0;s=f;return w|0}return 0}function SS(e,i,r,n,f,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;u=u|0;var a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0;
	a=s;s=s+48|0;o=a+36|0;c=a+32|0;l=a+28|0;b=a+24|0;k=a+20|0;h=a+16|0;w=a+12|0;d=a+8|0;v=a+4|0;m=a;t[c>>2]=e;t[l>>2]=i;t[b>>2]=r;t[k>>2]=n;t[h>>2]=f;t[w>>2]=u;if(!(t[c>>2]|0)){t[o>>2]=0;_=t[o>>2]|0;s=a;return _|0}rS();t[v>>2]=XO(t[c>>2]|0,t[l>>2]|0,t[b>>2]|0,0)|0;if(!(t[v>>2]|0)){if(t[l>>2]|0)gAi[t[l>>2]&511](t[b>>2]|0)|0;t[o>>2]=0;_=t[o>>2]|0;s=a;return _|0}t[d>>2]=zp()|0;if(!(t[d>>2]|0)){IO(t[v>>2]|0);t[o>>2]=0;_=t[o>>2]|0;s=a;return _|0}t[m>>2]=Pp(t[d>>2]|0,t[v>>2]|0,0)|0;if(!(t[m>>2]|0)){IO(t[v>>2]|0);Up(t[d>>2]|0);t[o>>2]=0;_=t[o>>2]|0;s=a;return _|0}else{eE(t[d>>2]|0,t[m>>2]|0)|0;t[o>>2]=Sg(t[d>>2]|0,t[k>>2]|0,t[h>>2]|0,t[w>>2]|0,0)|0;_=t[o>>2]|0;s=a;return _|0}return 0}function gS(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0;f=s;s=s+32|0;u=f+20|0;a=f+16|0;o=f+12|0;c=f+8|0;l=f+4|0;b=f;t[a>>2]=e;t[o>>2]=i;t[c>>2]=r;t[l>>2]=n;if(!(t[o>>2]|0)){t[u>>2]=0;k=t[u>>2]|0;s=f;return k|0}if(!(t[a>>2]|0)){t[u>>2]=0;k=t[u>>2]|0;s=f;return k|0}rS();vS(t[a>>2]|0);t[b>>2]=uA(t[o>>2]|0,0,t[a>>2]|0)|0;if(!(t[b>>2]|0)){t[u>>2]=0;k=t[u>>2]|0;s=f;return k|0}else{eE(t[a>>2]|0,t[b>>2]|0)|0;t[u>>2]=Sg(t[a>>2]|0,0,t[c>>2]|0,t[l>>2]|0,1)|0;k=t[u>>2]|0;s=f;return k|0}return 0}function yS(e,i,r,n,f,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;u=u|0;var a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0;a=s;s=s+48|0;o=a+32|0;c=a+28|0;l=a+24|0;b=a+20|0;k=a+16|0;h=a+12|0;w=a+8|0;d=a+4|0;v=a;t[c>>2]=e;t[l>>2]=i;t[b>>2]=r;t[k>>2]=n;t[h>>2]=f;t[w>>2]=u;if(!(t[c>>2]|0)){t[o>>2]=0;m=t[o>>2]|0;s=a;return m|0}if(!(t[l>>2]|0)){t[o>>2]=0;m=t[o>>2]|0;s=a;return m|0}rS();vS(t[c>>2]|0);t[d>>2]=GO(t[l>>2]|0,t[b>>2]|0,0)|0;if(!(t[d>>2]|0)){t[o>>2]=0;m=t[o>>2]|0;s=a;return m|0}t[v>>2]=Pp(t[c>>2]|0,t[d>>2]|0,0)|0;if(!(t[v>>2]|0)){IO(t[d>>2]|0);t[o>>2]=0;m=t[o>>2]|0;s=a;return m|0}else{eE(t[c>>2]|0,t[v>>2]|0)|0;t[o>>2]=Sg(t[c>>2]|0,t[k>>2]|0,t[h>>2]|0,t[w>>2]|0,1)|0;m=t[o>>2]|0;s=a;return m|0}return 0}function FS(e,i,r,n,f,u,a){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;u=u|0;a=a|0;var o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0;o=s;s=s+48|0;c=o+36|0;l=o+32|0;b=o+28|0;k=o+24|0;h=o+20|0;w=o+16|0;d=o+12|0;v=o+8|0;m=o+4|0;_=o;t[l>>2]=e;t[b>>2]=i;t[k>>2]=r;t[h>>2]=n;t[w>>2]=f;t[d>>2]=u;t[v>>2]=a;if(!(t[b>>2]|0)){t[c>>2]=0;p=t[c>>2]|0;s=o;return p|0}if(!(t[l>>2]|0)){t[c>>2]=0;p=t[c>>2]|0;s=o;return p|0}rS();vS(t[l>>2]|0);t[m>>2]=XO(t[b>>2]|0,t[k>>2]|0,t[h>>2]|0,0)|0;if(!(t[m>>2]|0)){if(t[k>>2]|0)gAi[t[k>>2]&511](t[h>>2]|0)|0;t[c>>2]=0;p=t[c>>2]|0;s=o;return p|0}t[_>>2]=Pp(t[l>>2]|0,t[m>>2]|0,0)|0;if(!(t[_>>2]|0)){IO(t[m>>2]|0);t[c>>2]=0;p=t[c>>2]|0;s=o;return p|0}else{eE(t[l>>2]|0,t[_>>2]|0)|0;t[c>>2]=Sg(t[l>>2]|0,t[w>>2]|0,t[d>>2]|0,t[v>>2]|0,1)|0;p=t[c>>2]|0;s=o;return p|0}return 0}function OS(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,u=0,a=0,o=0,c=0,l=0;f=s;s=s+32|0;u=f;a=f+16|0;o=f+12|0;c=f+8|0;l=f+4|0;t[a>>2]=e;t[o>>2]=i;t[c>>2]=r;t[l>>2]=n;if(((t[a>>2]|0)!=0?(t[(t[a>>2]|0)+212>>2]|0)!=0:0)?(t[(t[a>>2]|0)+172>>2]|0)==-1:0){s=f;return}if(t[a>>2]|0)t[(t[a>>2]|0)+84>>2]=t[o>>2];n=t[a>>2]|0;r=t[o>>2]|0;o=t[l>>2]|0;i=t[c>>2]|0;t[u>>2]=t[l>>2];cp(0,0,0,n,0,1,r,3,0,0,0,0,0,o,0,i,u);if(!(t[a>>2]|0)){s=f;return}t[(t[a>>2]|0)+12>>2]=0;if(t[(t[a>>2]|0)+288>>2]|0){s=f;return}t[(t[a>>2]|0)+212>>2]=1;s=f;return}function AS(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,l=0;n=s;s=s+160|0;f=n;u=n+16|0;a=n+12|0;o=n+8|0;c=n+4|0;l=n+20|0;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;VY(l|0,0,129)|0;if(((t[u>>2]|0)!=0?(t[(t[u>>2]|0)+212>>2]|0)!=0:0)?(t[(t[u>>2]|0)+172>>2]|0)==-1:0){s=n;return}do switch(t[a>>2]|0){case 69:{t[c>>2]=74048;break}case 33:{t[c>>2]=74696;break}case 55:{t[c>>2]=74128;break}case 34:{t[c>>2]=74656;break}case 71:{t[c>>2]=73600;break}case 89:{t[c>>2]=73240;break}case 52:{t[c>>2]=74008;break}case 19:{t[c>>2]=73136;break}case 67:{t[c>>2]=73920;break}case 79:{t[c>>2]=74736;break}case 38:{t[c>>2]=73392;break}case 82:{t[c>>2]=74504;break}case 50:{t[c>>2]=73872;break}case 73:{t[c>>2]=74232;break}case 18:{t[c>>2]=73104;break}case 80:{t[c>>2]=73648;break}case 49:{t[c>>2]=73776;break}case 44:{t[c>>2]=73472;break}case 85:{t[c>>2]=74880;break}case 4:{t[c>>2]=74808;break}case 48:{t[c>>2]=73744;break}case 84:{t[c>>2]=73824;break}case 46:{t[c>>2]=73696;break}case 110:{t[c>>2]=75e3;break}case 74:{t[c>>2]=74616;break}case 7:{t[c>>2]=73032;break}case 8:{t[c>>2]=73064;break}case 88:{t[c>>2]=73312;break}case 70:{t[c>>2]=73560;break}case 25:{t[c>>2]=73208;break}case 20:{t[c>>2]=73160;break}case 5:{t[c>>2]=74832;break}case 61:{t[c>>2]=74584;break}case 54:{t[c>>2]=74088;break}case 78:{t[c>>2]=74768;break}case 62:{t[c>>2]=73520;break}case 96:{t[c>>2]=74960;break}case 23:{t[c>>2]=74552;break}case 36:{t[c>>2]=73280;break}case 6:{t[c>>2]=72992;break}case 51:{t[c>>2]=73960;break}case 1:{t[c>>2]=73088;break}case 56:{t[c>>2]=74424;break}case 75:{t[c>>2]=74640;break}case 60:{t[c>>2]=74288;break}case 83:{t[c>>2]=74248;break}case 57:{t[c>>2]=74464;break}case 21:{t[c>>2]=74168;break}case 95:{t[c>>2]=74328;break}case 59:{t[c>>2]=74384;break}case 64:{t[c>>2]=73728;break}case 43:{t[c>>2]=73440;break}case 24:{t[c>>2]=73184;break}case 92:{t[c>>2]=73848;break}case 37:{t[c>>2]=73280;break}case 86:{t[c>>2]=74912;break}case 39:{t[c>>2]=73360;break}default:t[c>>2]=75040}while(0);r=t[c>>2]|0;if(!(t[o>>2]|0)){t[f>>2]=r;SY(l,128,75072,f)|0}else{t[f>>2]=r;SY(l,128,75080,f)|0}if(t[u>>2]|0)t[(t[u>>2]|0)+84>>2]=t[a>>2];r=t[u>>2]|0;c=t[a>>2]|0;a=t[o>>2]|0;t[f>>2]=t[o>>2];cp(0,0,0,r,0,1,c,3,0,0,a,0,0,0,0,l,f);if(!(t[u>>2]|0)){s=n;return}t[(t[u>>2]|0)+12>>2]=0;if(t[(t[u>>2]|0)+288>>2]|0){s=n;return}t[(t[u>>2]|0)+212>>2]=1;s=n;return}function MS(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,u=0,a=0,o=0,c=0,l=0;f=s;s=s+32|0;u=f;a=f+16|0;o=f+12|0;c=f+8|0;l=f+4|0;t[a>>2]=e;t[o>>2]=i;t[c>>2]=r;t[l>>2]=n;if(((t[a>>2]|0)!=0?(t[(t[a>>2]|0)+212>>2]|0)!=0:0)?(t[(t[a>>2]|0)+172>>2]|0)==-1:0){s=f;return}if(t[a>>2]|0)t[(t[a>>2]|0)+84>>2]=t[o>>2];n=t[a>>2]|0;r=t[o>>2]|0;o=t[l>>2]|0;i=t[c>>2]|0;t[u>>2]=t[l>>2];cp(0,0,0,n,0,1,r,3,0,0,o,0,0,0,0,i,u);if(!(t[a>>2]|0)){s=f;return}t[(t[a>>2]|0)+12>>2]=0;if(t[(t[a>>2]|0)+288>>2]|0){s=f;return}t[(t[a>>2]|0)+212>>2]=1;s=f;return}function RS(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;var u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0;u=s;s=s+32|0;a=u;o=u+28|0;c=u+24|0;l=u+20|0;b=u+16|0;k=u+12|0;h=u+8|0;t[o>>2]=e;t[c>>2]=i;t[l>>2]=r;t[b>>2]=n;t[k>>2]=f;t[h>>2]=0;if(((t[o>>2]|0)!=0?(t[(t[o>>2]|0)+212>>2]|0)!=0:0)?(t[(t[o>>2]|0)+172>>2]|0)==-1:0){s=u;return}if(((t[o>>2]|0)!=0?(t[(t[o>>2]|0)+84>>2]=t[c>>2],(t[t[o>>2]>>2]|0)!=0):0)?(t[(t[t[o>>2]>>2]|0)+108>>2]|0)==-554844497:0)t[h>>2]=t[(t[t[o>>2]>>2]|0)+124>>2];f=t[h>>2]|0;h=t[o>>2]|0;if(t[o>>2]|0){n=t[h+112>>2]|0;r=t[(t[o>>2]|0)+108>>2]|0;i=t[o>>2]|0;e=t[c>>2]|0;w=t[b>>2]|0;d=t[k>>2]|0;v=t[l>>2]|0;m=t[k>>2]|0;t[a>>2]=t[b>>2];t[a+4>>2]=m;cp(f,n,r,i,0,4,e,2,0,0,w,d,0,0,0,v,a);t[(t[o>>2]|0)+100>>2]=0;s=u;return}else{o=t[c>>2]|0;c=t[b>>2]|0;v=t[k>>2]|0;d=t[l>>2]|0;l=t[k>>2]|0;t[a>>2]=t[b>>2];t[a+4>>2]=l;cp(f,0,0,h,0,4,o,2,0,0,c,v,0,0,0,d,a);s=u;return}}function NS(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;var u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0;u=s;s=s+32|0;a=u;o=u+28|0;c=u+24|0;l=u+20|0;b=u+16|0;k=u+12|0;h=u+8|0;t[o>>2]=e;t[c>>2]=i;t[l>>2]=r;t[b>>2]=n;t[k>>2]=f;t[h>>2]=0;if(((t[o>>2]|0)!=0?(t[(t[o>>2]|0)+212>>2]|0)!=0:0)?(t[(t[o>>2]|0)+172>>2]|0)==-1:0){s=u;return}if(((t[o>>2]|0)!=0?(t[t[o>>2]>>2]|0)!=0:0)?(t[(t[t[o>>2]>>2]|0)+108>>2]|0)==-554844497:0)t[h>>2]=t[(t[t[o>>2]>>2]|0)+124>>2];f=t[h>>2]|0;h=t[o>>2]|0;if(!(t[o>>2]|0)){n=t[c>>2]|0;r=t[b>>2]|0;i=t[k>>2]|0;e=t[l>>2]|0;w=t[k>>2]|0;t[a>>2]=t[b>>2];t[a+4>>2]=w;cp(f,0,0,h,0,1,n,1,0,0,r,i,0,0,0,e,a);s=u;return}if(t[h>>2]|0)d=t[(t[t[o>>2]>>2]|0)+84>>2]|0;else d=0;h=t[(t[o>>2]|0)+4>>2]|0;e=t[o>>2]|0;o=t[c>>2]|0;c=t[b>>2]|0;i=t[k>>2]|0;r=t[l>>2]|0;l=t[k>>2]|0;t[a>>2]=t[b>>2];t[a+4>>2]=l;cp(f,d,h,e,0,1,o,1,0,0,c,i,0,0,0,r,a);s=u;return}function TS(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0;f=s;s=s+32|0;u=f+28|0;a=f+24|0;o=f+20|0;c=f+16|0;l=f+12|0;b=f+8|0;k=f+4|0;h=f;t[a>>2]=e;t[o>>2]=i;t[c>>2]=r;t[l>>2]=n;t[b>>2]=0;if((t[a>>2]|0)!=0?(t[(t[a>>2]|0)+360>>2]&524288|0)==0:0){if((t[(t[a>>2]|0)+388>>2]|0)==89){t[u>>2]=1;w=t[u>>2]|0;s=f;return w|0}if(((((t[c>>2]|0)!=0?(t[(t[c>>2]|0)+48>>2]|0)!=6:0)?(t[(t[c>>2]|0)+40>>2]|0)!=0:0)?(t[(t[c>>2]|0)+72>>2]|0)==0:0)?(t[k>>2]=t[(t[a>>2]|0)+440>>2],t[(t[c>>2]|0)+72>>2]=1,t[h>>2]=hE(t[a>>2]|0,t[(t[c>>2]|0)+40>>2]|0,1,0,0,0)|0,t[(t[c>>2]|0)+72>>2]=(t[(t[a>>2]|0)+440>>2]|0)-(t[k>>2]|0)+1<<1,(t[h>>2]|0)!=0):0){if(es(t[h>>2]|0,60)|0){k=(t[c>>2]|0)+72|0;t[k>>2]=t[k>>2]|1}pAi[t[135736>>2]&511](t[h>>2]|0);t[h>>2]=0}do if(t[l>>2]|0){if((t[l>>2]|0)>>>0<1e7){t[u>>2]=0;w=t[u>>2]|0;s=f;return w|0}if(t[(t[a>>2]|0)+36>>2]|0)t[b>>2]=(t[(t[(t[a>>2]|0)+36>>2]|0)+36>>2]|0)+((t[(t[(t[a>>2]|0)+36>>2]|0)+16>>2]|0)-(t[(t[(t[a>>2]|0)+36>>2]|0)+12>>2]|0));t[b>>2]=(t[b>>2]|0)+(t[(t[a>>2]|0)+444>>2]|0);if((t[l>>2]|0)>>>0<((t[b>>2]|0)*10|0)>>>0){t[u>>2]=0;w=t[u>>2]|0;s=f;return w|0}}else{if(t[o>>2]|0){if((t[o>>2]|0)>>>0<1e3){t[u>>2]=0;w=t[u>>2]|0;s=f;return w|0}if(t[(t[a>>2]|0)+36>>2]|0)t[b>>2]=(t[(t[(t[a>>2]|0)+36>>2]|0)+36>>2]|0)+((t[(t[(t[a>>2]|0)+36>>2]|0)+16>>2]|0)-(t[(t[(t[a>>2]|0)+36>>2]|0)+12>>2]|0));t[b>>2]=(t[b>>2]|0)+(t[(t[a>>2]|0)+444>>2]|0);if((t[o>>2]|0)>>>0>=((t[b>>2]|0)*10|0)>>>0)break;if(((t[(t[a>>2]|0)+440>>2]|0)*3|0)>>>0>=((t[b>>2]|0)*10|0)>>>0)break;t[u>>2]=0;w=t[u>>2]|0;s=f;return w|0}if(t[c>>2]|0){t[o>>2]=(t[(t[c>>2]|0)+72>>2]|0)/2|0;if(t[(t[a>>2]|0)+36>>2]|0)t[b>>2]=(t[(t[(t[a>>2]|0)+36>>2]|0)+36>>2]|0)+((t[(t[(t[a>>2]|0)+36>>2]|0)+16>>2]|0)-(t[(t[(t[a>>2]|0)+36>>2]|0)+12>>2]|0));t[b>>2]=(t[b>>2]|0)+(t[(t[a>>2]|0)+444>>2]|0);if(((t[o>>2]|0)*3|0)>>>0>=((t[b>>2]|0)*10|0)>>>0)break;t[u>>2]=0;w=t[u>>2]|0;s=f;return w|0}else{if(!((t[(t[a>>2]|0)+388>>2]|0)!=26?(t[(t[a>>2]|0)+388>>2]|0)!=27:0))d=36;if((d|0)==36?(t[(t[a>>2]|0)+440>>2]|0)>>>0>1e4:0)break;t[u>>2]=0;w=t[u>>2]|0;s=f;return w|0}}while(0);AS(t[a>>2]|0,89,0);t[u>>2]=1;w=t[u>>2]|0;s=f;return w|0}t[u>>2]=0;w=t[u>>2]|0;s=f;return w|0}function LS(e){e=e|0;var i=0,r=0;i=s;s=s+16|0;r=i;t[r>>2]=e;pAi[t[135736>>2]&511](t[r>>2]|0);s=i;return}function DS(e,i){e=e|0;i=i|0;var r=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0;r=s;s=s+32|0;f=r;u=r+24|0;a=r+20|0;o=r+16|0;c=r+12|0;l=r+8|0;b=r+4|0;t[a>>2]=e;t[o>>2]=i;if(!(t[o>>2]|0)){AS(t[a>>2]|0,1,72912);t[u>>2]=0;k=t[u>>2]|0;s=r;return k|0}if(t[33952]|0){i=t[33976]|0;e=t[33980]|0;t[f>>2]=t[(t[o>>2]|0)+8>>2];yAi[i&511](e,72952,f)}t[c>>2]=Cp(t[a>>2]|0)|0;if(!(t[c>>2]|0)){t[u>>2]=0;k=t[u>>2]|0;s=r;return k|0}t[b>>2]=(rs(t[(t[o>>2]|0)+8>>2]|0)|0)+5;t[l>>2]=gAi[t[135752>>2]&511](t[b>>2]|0)|0;if(!(t[l>>2]|0)){Sp(t[a>>2]|0,0);pAi[t[135736>>2]&511](t[c>>2]|0);t[u>>2]=0;k=t[u>>2]|0;s=r;return k|0}else{n[t[l>>2]>>0]=32;n[(t[l>>2]|0)+1>>0]=37;n[(t[l>>2]|0)+((t[b>>2]|0)-3)>>0]=59;n[(t[l>>2]|0)+((t[b>>2]|0)-2)>>0]=32;n[(t[l>>2]|0)+((t[b>>2]|0)-1)>>0]=0;YY((t[l>>2]|0)+2|0,t[(t[o>>2]|0)+8>>2]|0,(t[b>>2]|0)-5|0)|0;t[(t[c>>2]|0)+40>>2]=226;t[(t[c>>2]|0)+12>>2]=t[l>>2];t[(t[c>>2]|0)+16>>2]=t[l>>2];t[(t[c>>2]|0)+24>>2]=t[b>>2];t[(t[c>>2]|0)+20>>2]=(t[l>>2]|0)+(t[b>>2]|0);t[u>>2]=t[c>>2];k=t[u>>2]|0;s=r;return k|0}return 0}function CS(e){e=e|0;var i=0,r=0,n=0,f=0;i=s;s=s+16|0;r=i+8|0;n=i+4|0;f=i;t[r>>2]=e;t[n>>2]=(t[(t[(t[r>>2]|0)+36>>2]|0)+20>>2]|0)-(t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0);t[f>>2]=(t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)-(t[(t[(t[r>>2]|0)+36>>2]|0)+12>>2]|0);if((((t[n>>2]|0)>>>0>1e7|(t[f>>2]|0)>>>0>1e7?(t[t[(t[r>>2]|0)+36>>2]>>2]|0)!=0:0)?(t[(t[t[(t[r>>2]|0)+36>>2]>>2]|0)+4>>2]|0)!=227:0)?(t[(t[r>>2]|0)+360>>2]&524288|0)==0:0){AS(t[r>>2]|0,1,69896);t[(t[r>>2]|0)+172>>2]=-1}yp(t[(t[r>>2]|0)+36>>2]|0,250)|0;if(!(t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)){s=i;return}if(u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0){s=i;return}if((yp(t[(t[r>>2]|0)+36>>2]|0,250)|0)>0){s=i;return}aE(t[r>>2]|0)|0;s=i;return}function PS(e){e=e|0;var i=0,r=0,n=0,f=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0;i=s;s=s+32|0;r=i+20|0;n=i+16|0;f=i+12|0;a=i+8|0;o=i+4|0;c=i;t[n>>2]=e;t[f>>2]=0;t[c>>2]=0;if((t[(t[n>>2]|0)+292>>2]|0)==0?((t[(t[(t[n>>2]|0)+36>>2]|0)+20>>2]|0)-(t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]|0)|0)<250:0)CS(t[n>>2]|0);if((t[(t[n>>2]|0)+172>>2]|0)==-1){t[r>>2]=0;l=t[r>>2]|0;s=i;return l|0}t[o>>2]=Ap(t[n>>2]|0,a)|0;e=(t[o>>2]|0)==32|(t[o>>2]|0)==62|(t[o>>2]|0)==47;e:do if(!(t[(t[n>>2]|0)+360>>2]&131072)){do if(!e){if(((((((((((((!((t[o>>2]|0)>=97&(t[o>>2]|0)<=122)?!((t[o>>2]|0)>=65&(t[o>>2]|0)<=90|(t[o>>2]|0)==95|(t[o>>2]|0)==58):0)?!((t[o>>2]|0)>=192&(t[o>>2]|0)<=214):0)?!((t[o>>2]|0)>=216&(t[o>>2]|0)<=246):0)?!((t[o>>2]|0)>=248&(t[o>>2]|0)<=767):0)?!((t[o>>2]|0)>=880&(t[o>>2]|0)<=893):0)?!((t[o>>2]|0)>=895&(t[o>>2]|0)<=8191):0)?!((t[o>>2]|0)>=8204&(t[o>>2]|0)<=8205):0)?!((t[o>>2]|0)>=8304&(t[o>>2]|0)<=8591):0)?!((t[o>>2]|0)>=11264&(t[o>>2]|0)<=12271):0)?!((t[o>>2]|0)>=12289&(t[o>>2]|0)<=55295):0)?!((t[o>>2]|0)>=63744&(t[o>>2]|0)<=64975):0)?!((t[o>>2]|0)>=65008&(t[o>>2]|0)<=65533):0)?!((t[o>>2]|0)>=65536&(t[o>>2]|0)<=983039):0)break;t[f>>2]=(t[f>>2]|0)+(t[a>>2]|0);b=t[(t[n>>2]|0)+36>>2]|0;if((u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==10){k=b+28|0;t[k>>2]=(t[k>>2]|0)+1;t[(t[(t[n>>2]|0)+36>>2]|0)+32>>2]=1}else{k=b+32|0;t[k>>2]=(t[k>>2]|0)+1}k=(t[(t[n>>2]|0)+36>>2]|0)+16|0;t[k>>2]=(t[k>>2]|0)+(t[a>>2]|0);if((u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==37)oE(t[n>>2]|0);t[o>>2]=Ap(t[n>>2]|0,a)|0;while(1){if(!((t[o>>2]|0)!=32&(t[o>>2]|0)!=62&(t[o>>2]|0)!=47))break e;do if(((((((!((t[o>>2]|0)>=97&(t[o>>2]|0)<=122)?!((t[o>>2]|0)>=65&(t[o>>2]|0)<=90):0)?!((t[o>>2]|0)>=48&(t[o>>2]|0)<=57|(t[o>>2]|0)==95|(t[o>>2]|0)==58|(t[o>>2]|0)==45|(t[o>>2]|0)==46|(t[o>>2]|0)==183):0)?!((t[o>>2]|0)>=192&(t[o>>2]|0)<=214):0)?!((t[o>>2]|0)>=216&(t[o>>2]|0)<=246):0)?!((t[o>>2]|0)>=248&(t[o>>2]|0)<=767):0)?!((t[o>>2]|0)>=768&(t[o>>2]|0)<=879):0)?!((t[o>>2]|0)>=880&(t[o>>2]|0)<=893):0){if((t[o>>2]|0)>=895&(t[o>>2]|0)<=8191)break;if((t[o>>2]|0)>=8204&(t[o>>2]|0)<=8205)break;if((t[o>>2]|0)>=8255&(t[o>>2]|0)<=8256)break;if((t[o>>2]|0)>=8304&(t[o>>2]|0)<=8591)break;if((t[o>>2]|0)>=11264&(t[o>>2]|0)<=12271)break;if((t[o>>2]|0)>=12289&(t[o>>2]|0)<=55295)break;if((t[o>>2]|0)>=63744&(t[o>>2]|0)<=64975)break;if((t[o>>2]|0)>=65008&(t[o>>2]|0)<=65533)break;if(!((t[o>>2]|0)>=65536&(t[o>>2]|0)<=983039))break e}while(0);k=t[c>>2]|0;t[c>>2]=k+1;if((k|0)>100){t[c>>2]=0;if((t[(t[n>>2]|0)+292>>2]|0)==0?((t[(t[(t[n>>2]|0)+36>>2]|0)+20>>2]|0)-(t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]|0)|0)<250:0)CS(t[n>>2]|0);if((t[(t[n>>2]|0)+172>>2]|0)==-1)break}t[f>>2]=(t[f>>2]|0)+(t[a>>2]|0);k=t[(t[n>>2]|0)+36>>2]|0;if((u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==10){b=k+28|0;t[b>>2]=(t[b>>2]|0)+1;t[(t[(t[n>>2]|0)+36>>2]|0)+32>>2]=1}else{b=k+32|0;t[b>>2]=(t[b>>2]|0)+1}b=(t[(t[n>>2]|0)+36>>2]|0)+16|0;t[b>>2]=(t[b>>2]|0)+(t[a>>2]|0);if((u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==37)oE(t[n>>2]|0);t[o>>2]=Ap(t[n>>2]|0,a)|0}t[r>>2]=0;l=t[r>>2]|0;s=i;return l|0}while(0);t[r>>2]=0;l=t[r>>2]|0;s=i;return l|0}else{i:do if(!e){b=t[o>>2]|0;if((t[o>>2]|0)<256){if(((!(65<=(b|0)&(t[o>>2]|0)<=90)?!(97<=(t[o>>2]|0)&(t[o>>2]|0)<=122):0)?!(192<=(t[o>>2]|0)&(t[o>>2]|0)<=214):0)?!(216<=(t[o>>2]|0)&(t[o>>2]|0)<=246|248<=(t[o>>2]|0)):0)h=66}else if(!(dj(b,199744)|0))h=66;do if((h|0)==66){b=t[o>>2]|0;if((t[o>>2]|0)<256)if((b|0)!=95&(t[o>>2]|0)!=58)break i;else break;if(!(19968<=(b|0)&(t[o>>2]|0)<=40869|(t[o>>2]|0)==12295)?(12321<=(t[o>>2]|0)&(t[o>>2]|0)<=12329^1)&(t[o>>2]|0)!=95&(t[o>>2]|0)!=58:0)break i}while(0);t[f>>2]=(t[f>>2]|0)+(t[a>>2]|0);b=t[(t[n>>2]|0)+36>>2]|0;if((u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==10){k=b+28|0;t[k>>2]=(t[k>>2]|0)+1;t[(t[(t[n>>2]|0)+36>>2]|0)+32>>2]=1}else{k=b+32|0;t[k>>2]=(t[k>>2]|0)+1}k=(t[(t[n>>2]|0)+36>>2]|0)+16|0;t[k>>2]=(t[k>>2]|0)+(t[a>>2]|0);if((u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==37)oE(t[n>>2]|0);t[o>>2]=Ap(t[n>>2]|0,a)|0;while(1){if(!((t[o>>2]|0)!=32&(t[o>>2]|0)!=62&(t[o>>2]|0)!=47))break e;k=t[o>>2]|0;if((t[o>>2]|0)<256){if(((!(65<=(k|0)&(t[o>>2]|0)<=90)?!(97<=(t[o>>2]|0)&(t[o>>2]|0)<=122):0)?!(192<=(t[o>>2]|0)&(t[o>>2]|0)<=214):0)?!(216<=(t[o>>2]|0)&(t[o>>2]|0)<=246|248<=(t[o>>2]|0)):0)h=84}else if(!(dj(k,199744)|0))h=84;do if((h|0)==84){h=0;if((t[o>>2]|0)>=256){if(19968<=(t[o>>2]|0)&(t[o>>2]|0)<=40869|(t[o>>2]|0)==12295)break;if(12321<=(t[o>>2]|0)&(t[o>>2]|0)<=12329)break}k=t[o>>2]|0;if((t[o>>2]|0)<256){if(48<=(k|0)&(t[o>>2]|0)<=57|(t[o>>2]|0)==46|(t[o>>2]|0)==45|(t[o>>2]|0)==95|(t[o>>2]|0)==58)break}else{b=(dj(k,200216)|0)!=0;if(b|(t[o>>2]|0)==46|(t[o>>2]|0)==45|(t[o>>2]|0)==95|(t[o>>2]|0)==58)break}if((t[o>>2]|0)>=256?(dj(t[o>>2]|0,200144)|0)!=0:0)break;b=t[o>>2]|0;if((t[o>>2]|0)<256)w=(b|0)==183&1;else w=dj(b,200272)|0;if(!w)break e}while(0);b=t[c>>2]|0;t[c>>2]=b+1;if((b|0)>100){t[c>>2]=0;if((t[(t[n>>2]|0)+292>>2]|0)==0?((t[(t[(t[n>>2]|0)+36>>2]|0)+20>>2]|0)-(t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]|0)|0)<250:0)CS(t[n>>2]|0);if((t[(t[n>>2]|0)+172>>2]|0)==-1){h=101;break}}t[f>>2]=(t[f>>2]|0)+(t[a>>2]|0);b=t[(t[n>>2]|0)+36>>2]|0;if((u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==10){k=b+28|0;t[k>>2]=(t[k>>2]|0)+1;t[(t[(t[n>>2]|0)+36>>2]|0)+32>>2]=1}else{k=b+32|0;t[k>>2]=(t[k>>2]|0)+1}k=(t[(t[n>>2]|0)+36>>2]|0)+16|0;t[k>>2]=(t[k>>2]|0)+(t[a>>2]|0);if((u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==37)oE(t[n>>2]|0);t[o>>2]=Ap(t[n>>2]|0,a)|0;if(t[o>>2]|0)continue;t[c>>2]=0;if((t[(t[n>>2]|0)+292>>2]|0)==0?((t[(t[(t[n>>2]|0)+36>>2]|0)+20>>2]|0)-(t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]|0)|0)<250:0)CS(t[n>>2]|0);if((t[(t[n>>2]|0)+172>>2]|0)==-1){h=112;break}t[o>>2]=Ap(t[n>>2]|0,a)|0}if((h|0)==101){t[r>>2]=0;l=t[r>>2]|0;s=i;return l|0}else if((h|0)==112){t[r>>2]=0;l=t[r>>2]|0;s=i;return l|0}}while(0);t[r>>2]=0;l=t[r>>2]|0;s=i;return l|0}while(0);if((t[f>>2]|0)>5e4?(t[(t[n>>2]|0)+360>>2]&524288|0)==0:0){AS(t[n>>2]|0,110,65688);t[r>>2]=0;l=t[r>>2]|0;s=i;return l|0}if((u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==10?(u[(t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]|0)+-1>>0]|0|0)==13:0){t[r>>2]=kz(t[(t[n>>2]|0)+296>>2]|0,(t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]|0)+(0-((t[f>>2]|0)+1))|0,t[f>>2]|0)|0;l=t[r>>2]|0;s=i;return l|0}t[r>>2]=kz(t[(t[n>>2]|0)+296>>2]|0,(t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]|0)+(0-(t[f>>2]|0))|0,t[f>>2]|0)|0;l=t[r>>2]|0;s=i;return l|0}function BS(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0;n=s;s=s+16|0;f=n;u=n+12|0;a=n+8|0;o=n+4|0;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;if(((t[u>>2]|0)!=0?(t[(t[u>>2]|0)+212>>2]|0)!=0:0)?(t[(t[u>>2]|0)+172>>2]|0)==-1:0){s=n;return}if(t[u>>2]|0)t[(t[u>>2]|0)+84>>2]=t[a>>2];r=t[u>>2]|0;i=t[a>>2]|0;t[f>>2]=t[o>>2];cp(0,0,0,r,0,1,i,3,0,0,0,0,0,0,0,72848,f);if(!(t[u>>2]|0)){s=n;return}t[(t[u>>2]|0)+12>>2]=0;if(t[(t[u>>2]|0)+288>>2]|0){s=n;return}t[(t[u>>2]|0)+212>>2]=1;s=n;return}function IS(e,i){e=e|0;i=i|0;var r=0,f=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0;r=s;s=s+32|0;f=r+20|0;a=r+16|0;o=r+12|0;c=r+8|0;l=r+24|0;b=r+4|0;k=r;t[a>>2]=e;t[o>>2]=i;t[b>>2]=0;t[k>>2]=0;if((t[o>>2]|0)!=0?(t[t[o>>2]>>2]|0)!=0:0){t[c>>2]=t[t[o>>2]>>2];n[l>>0]=n[t[c>>2]>>0]|0;if(((u[l>>0]|0|0)==38?(u[(t[c>>2]|0)+1>>0]|0|0)==35:0)?(u[(t[c>>2]|0)+2>>0]|0|0)==120:0){t[c>>2]=(t[c>>2]|0)+3;n[l>>0]=n[t[c>>2]>>0]|0;e:while(1){if((u[l>>0]|0|0)==59)break;if((u[l>>0]|0|0)>=48?(u[l>>0]|0|0)<=57:0)t[b>>2]=(t[b>>2]<<4)+((u[l>>0]|0)-48);else h=12;do if((h|0)==12){h=0;if((u[l>>0]|0|0)>=97?(u[l>>0]|0|0)<=102:0){t[b>>2]=(t[b>>2]<<4)+((u[l>>0]|0)-97)+10;break}if((u[l>>0]|0|0)<65){h=18;break e}if((u[l>>0]|0|0)>70){h=18;break e}t[b>>2]=(t[b>>2]<<4)+((u[l>>0]|0)-65)+10}while(0);if((t[b>>2]|0)>>>0>1114111)t[k>>2]=t[b>>2];t[c>>2]=(t[c>>2]|0)+1;n[l>>0]=n[t[c>>2]>>0]|0}if((h|0)==18){AS(t[a>>2]|0,6,0);t[b>>2]=0}if((u[l>>0]|0|0)==59)t[c>>2]=(t[c>>2]|0)+1}else h=24;do if((h|0)==24){if((u[l>>0]|0|0)==38?(u[(t[c>>2]|0)+1>>0]|0|0)==35:0){t[c>>2]=(t[c>>2]|0)+2;n[l>>0]=n[t[c>>2]>>0]|0;while(1){if((u[l>>0]|0|0)==59)break;if((u[l>>0]|0|0)<48){h=31;break}if((u[l>>0]|0|0)>57){h=31;break}t[b>>2]=((t[b>>2]|0)*10|0)+((u[l>>0]|0)-48);if((t[b>>2]|0)>>>0>1114111)t[k>>2]=t[b>>2];t[c>>2]=(t[c>>2]|0)+1;n[l>>0]=n[t[c>>2]>>0]|0}if((h|0)==31){AS(t[a>>2]|0,7,0);t[b>>2]=0}if((u[l>>0]|0|0)!=59)break;t[c>>2]=(t[c>>2]|0)+1;break}AS(t[a>>2]|0,8,0);t[f>>2]=0;w=t[f>>2]|0;s=r;return w|0}while(0);t[t[o>>2]>>2]=t[c>>2];c=t[b>>2]|0;do if((t[b>>2]|0)>>>0<256)if((9<=c>>>0&(t[b>>2]|0)>>>0<=10|(t[b>>2]|0)==13|32<=(t[b>>2]|0)>>>0)&(t[k>>2]|0)==0)h=43;else h=44;else{if(!(256<=c>>>0&(t[b>>2]|0)>>>0<=55295)?!(57344<=(t[b>>2]|0)>>>0&(t[b>>2]|0)>>>0<=65533):0)if(65536<=(t[b>>2]|0)>>>0&(t[b>>2]|0)>>>0<=1114111&(t[k>>2]|0)==0){h=43;break}else{h=44;break}if(!(t[k>>2]|0))h=43;else h=44}while(0);if((h|0)==43){t[f>>2]=t[b>>2];w=t[f>>2]|0;s=r;return w|0}else if((h|0)==44){OS(t[a>>2]|0,9,72856,t[b>>2]|0);t[f>>2]=0;w=t[f>>2]|0;s=r;return w|0}}t[f>>2]=0;w=t[f>>2]|0;s=r;return w|0}function HS(e,i){e=e|0;i=i|0;var r=0,f=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0;r=s;s=s+32|0;f=r+20|0;a=r+16|0;o=r+12|0;c=r+8|0;l=r+4|0;b=r+24|0;k=r;t[a>>2]=e;t[o>>2]=i;t[k>>2]=0;if((t[o>>2]|0)!=0?(t[t[o>>2]>>2]|0)!=0:0){t[l>>2]=t[t[o>>2]>>2];n[b>>0]=n[t[l>>2]>>0]|0;if((u[b>>0]|0|0)!=38){t[f>>2]=0;h=t[f>>2]|0;s=r;return h|0}t[l>>2]=(t[l>>2]|0)+1;t[c>>2]=jS(t[a>>2]|0,l)|0;if(!(t[c>>2]|0)){BS(t[a>>2]|0,68,72152);t[t[o>>2]>>2]=t[l>>2];t[f>>2]=0;h=t[f>>2]|0;s=r;return h|0}if((u[t[l>>2]>>0]|0|0)!=59){AS(t[a>>2]|0,23,0);pAi[t[135736>>2]&511](t[c>>2]|0);t[t[o>>2]>>2]=t[l>>2];t[f>>2]=0;h=t[f>>2]|0;s=r;return h|0}t[l>>2]=(t[l>>2]|0)+1;if((t[(t[a>>2]|0)+360>>2]&1048576|0)==0?(t[k>>2]=l_(t[c>>2]|0)|0,(t[k>>2]|0)!=0):0){pAi[t[135736>>2]&511](t[c>>2]|0);t[t[o>>2]>>2]=t[l>>2];t[f>>2]=t[k>>2];h=t[f>>2]|0;s=r;return h|0}b=(t[a>>2]|0)+440|0;t[b>>2]=(t[b>>2]|0)+1;if(t[t[a>>2]>>2]|0){if(t[(t[t[a>>2]>>2]|0)+20>>2]|0)t[k>>2]=MAi[t[(t[t[a>>2]>>2]|0)+20>>2]&511](t[(t[a>>2]|0)+4>>2]|0,t[c>>2]|0)|0;if((t[k>>2]|0)==0?(t[(t[a>>2]|0)+360>>2]&1048576|0)!=0:0)t[k>>2]=l_(t[c>>2]|0)|0;if((t[k>>2]|0)==0?(t[(t[a>>2]|0)+4>>2]|0)==(t[a>>2]|0):0)t[k>>2]=Cz(t[a>>2]|0,t[c>>2]|0)|0}if((t[(t[a>>2]|0)+172>>2]|0)==-1){pAi[t[135736>>2]&511](t[c>>2]|0);t[f>>2]=0;h=t[f>>2]|0;s=r;return h|0}do if(t[k>>2]|0){b=t[a>>2]|0;if((t[(t[k>>2]|0)+48>>2]|0)==3){MS(b,28,68712,t[c>>2]|0);break}if((t[b+172>>2]|0)==12?(t[(t[k>>2]|0)+48>>2]|0)==2:0){MS(t[a>>2]|0,29,68752,t[c>>2]|0);break}if(((((t[k>>2]|0)!=0?(t[(t[a>>2]|0)+172>>2]|0)==12:0)?(t[(t[k>>2]|0)+40>>2]|0)!=0:0)?(t[(t[k>>2]|0)+48>>2]|0)!=6:0)?(es(t[(t[k>>2]|0)+40>>2]|0,60)|0)!=0:0){MS(t[a>>2]|0,38,68800,t[c>>2]|0);break}if(((t[(t[k>>2]|0)+48>>2]|0)+-4|0)>>>0<2)MS(t[a>>2]|0,30,68856,t[c>>2]|0)}else{do if((t[(t[a>>2]|0)+28>>2]|0)==1)w=28;else{if((t[(t[a>>2]|0)+88>>2]|0)==0?(t[(t[a>>2]|0)+92>>2]|0)==0:0){w=28;break}ZS(t[a>>2]|0,27,68680,t[c>>2]|0)}while(0);if((w|0)==28)MS(t[a>>2]|0,26,68680,t[c>>2]|0);TS(t[a>>2]|0,0,t[k>>2]|0,0)|0}while(0);pAi[t[135736>>2]&511](t[c>>2]|0);t[t[o>>2]>>2]=t[l>>2];t[f>>2]=t[k>>2];h=t[f>>2]|0;s=r;return h|0}t[f>>2]=0;h=t[f>>2]|0;s=r;return h|0}function xS(e,i){e=e|0;i=i|0;var r=0,f=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0;r=s;s=s+32|0;f=r+20|0;a=r+16|0;o=r+12|0;c=r+8|0;l=r+24|0;b=r+4|0;k=r;t[a>>2]=e;t[o>>2]=i;t[k>>2]=0;if((t[o>>2]|0)!=0?(t[t[o>>2]>>2]|0)!=0:0){t[c>>2]=t[t[o>>2]>>2];n[l>>0]=n[t[c>>2]>>0]|0;if((u[l>>0]|0|0)!=37){t[f>>2]=0;h=t[f>>2]|0;s=r;return h|0}t[c>>2]=(t[c>>2]|0)+1;t[b>>2]=jS(t[a>>2]|0,c)|0;if(!(t[b>>2]|0)){BS(t[a>>2]|0,68,71904);t[t[o>>2]>>2]=t[c>>2];t[f>>2]=0;h=t[f>>2]|0;s=r;return h|0}n[l>>0]=n[t[c>>2]>>0]|0;if((u[l>>0]|0|0)!=59){AS(t[a>>2]|0,23,0);pAi[t[135736>>2]&511](t[b>>2]|0);t[t[o>>2]>>2]=t[c>>2];t[f>>2]=0;h=t[f>>2]|0;s=r;return h|0}t[c>>2]=(t[c>>2]|0)+1;l=(t[a>>2]|0)+440|0;t[l>>2]=(t[l>>2]|0)+1;if((t[t[a>>2]>>2]|0)!=0?(t[(t[t[a>>2]>>2]|0)+96>>2]|0)!=0:0)t[k>>2]=MAi[t[(t[t[a>>2]>>2]|0)+96>>2]&511](t[(t[a>>2]|0)+4>>2]|0,t[b>>2]|0)|0;if((t[(t[a>>2]|0)+172>>2]|0)==-1){pAi[t[135736>>2]&511](t[b>>2]|0);t[f>>2]=0;h=t[f>>2]|0;s=r;return h|0}if(t[k>>2]|0){if((t[(t[k>>2]|0)+48>>2]|0)!=4?(t[(t[k>>2]|0)+48>>2]|0)!=5:0)NS(t[a>>2]|0,27,71944,t[b>>2]|0,0)}else{do if((t[(t[a>>2]|0)+28>>2]|0)==1)w=19;else{if((t[(t[a>>2]|0)+88>>2]|0)==0?(t[(t[a>>2]|0)+92>>2]|0)==0:0){w=19;break}NS(t[a>>2]|0,27,65432,t[b>>2]|0,0);t[(t[a>>2]|0)+100>>2]=0}while(0);if((w|0)==19)MS(t[a>>2]|0,26,65432,t[b>>2]|0);TS(t[a>>2]|0,0,0,0)|0}t[(t[a>>2]|0)+92>>2]=1;pAi[t[135736>>2]&511](t[b>>2]|0);t[t[o>>2]>>2]=t[c>>2];t[f>>2]=t[k>>2];h=t[f>>2]|0;s=r;return h|0}t[f>>2]=0;h=t[f>>2]|0;s=r;return h|0}function US(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0;r=s;s=s+48|0;n=r;f=r+32|0;a=r+28|0;o=r+24|0;c=r+20|0;l=r+16|0;b=r+12|0;k=r+8|0;h=r+4|0;t[a>>2]=e;t[o>>2]=i;t[h>>2]=0;do if(!((t[a>>2]|0)==0|(t[o>>2]|0)==0)){if((t[(t[o>>2]|0)+48>>2]|0)!=5?(t[(t[o>>2]|0)+48>>2]|0)!=2:0)break;if(!(t[(t[o>>2]|0)+40>>2]|0)){if(t[33952]|0){i=t[33976]|0;e=t[33980]|0;t[n>>2]=t[(t[o>>2]|0)+8>>2];yAi[i&511](e,72024,n)}t[l>>2]=gF()|0;e=t[a>>2]|0;if(!(t[l>>2]|0)){AS(e,1,71984);t[f>>2]=-1;w=t[f>>2]|0;s=r;return w|0}t[c>>2]=Bp(e,t[o>>2]|0)|0;e=t[a>>2]|0;if(!(t[c>>2]|0)){AS(e,1,72064);yF(t[l>>2]|0);t[f>>2]=-1;w=t[f>>2]|0;s=r;return w|0}if((cE(e,t[c>>2]|0)|0)<0){yF(t[l>>2]|0);t[f>>2]=-1;w=t[f>>2]|0;s=r;return w|0}if((t[(t[a>>2]|0)+292>>2]|0)==0?((t[(t[(t[a>>2]|0)+36>>2]|0)+20>>2]|0)-(t[(t[(t[a>>2]|0)+36>>2]|0)+16>>2]|0)|0)<250:0)CS(t[a>>2]|0);t[k>>2]=Ap(t[a>>2]|0,b)|0;while(1){if((t[(t[a>>2]|0)+36>>2]|0)!=(t[c>>2]|0)){d=46;break}if((t[(t[(t[a>>2]|0)+36>>2]|0)+16>>2]|0)>>>0>=(t[(t[(t[a>>2]|0)+36>>2]|0)+20>>2]|0)>>>0){d=46;break}e=t[k>>2]|0;if((t[k>>2]|0)<256)if(9<=(e|0)&(t[k>>2]|0)<=10|(t[k>>2]|0)==13)v=1;else v=32<=(t[k>>2]|0);else if(!(256<=(e|0)&(t[k>>2]|0)<=55295)?!(57344<=(t[k>>2]|0)&(t[k>>2]|0)<=65533):0)if(65536<=(t[k>>2]|0))v=(t[k>>2]|0)<=1114111;else v=0;else v=1;if(!(v&1)){d=46;break}OF(t[l>>2]|0,t[(t[(t[a>>2]|0)+36>>2]|0)+16>>2]|0,t[b>>2]|0)|0;e=t[h>>2]|0;t[h>>2]=e+1;if((e|0)>100){t[h>>2]=0;if((t[(t[a>>2]|0)+292>>2]|0)==0?((t[(t[(t[a>>2]|0)+36>>2]|0)+20>>2]|0)-(t[(t[(t[a>>2]|0)+36>>2]|0)+16>>2]|0)|0)<250:0)CS(t[a>>2]|0);if((t[(t[a>>2]|0)+172>>2]|0)==-1){d=33;break}}e=t[(t[a>>2]|0)+36>>2]|0;if((u[t[(t[(t[a>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==10){i=e+28|0;t[i>>2]=(t[i>>2]|0)+1;t[(t[(t[a>>2]|0)+36>>2]|0)+32>>2]=1}else{i=e+32|0;t[i>>2]=(t[i>>2]|0)+1}i=(t[(t[a>>2]|0)+36>>2]|0)+16|0;t[i>>2]=(t[i>>2]|0)+(t[b>>2]|0);if((u[t[(t[(t[a>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==37)oE(t[a>>2]|0);t[k>>2]=Ap(t[a>>2]|0,b)|0;if(t[k>>2]|0)continue;t[h>>2]=0;do if(!(t[(t[a>>2]|0)+292>>2]|0)){if(((t[(t[(t[a>>2]|0)+36>>2]|0)+20>>2]|0)-(t[(t[(t[a>>2]|0)+36>>2]|0)+16>>2]|0)|0)>=250)break;CS(t[a>>2]|0)}while(0);if((t[(t[a>>2]|0)+172>>2]|0)==-1){d=44;break}t[k>>2]=Ap(t[a>>2]|0,b)|0}if((d|0)==33){yF(t[l>>2]|0);t[f>>2]=-1;w=t[f>>2]|0;s=r;return w|0}else if((d|0)==44){yF(t[l>>2]|0);t[f>>2]=-1;w=t[f>>2]|0;s=r;return w|0}else if((d|0)==46){if((t[(t[a>>2]|0)+36>>2]|0)==(t[c>>2]|0)?(t[(t[(t[a>>2]|0)+36>>2]|0)+16>>2]|0)>>>0>=(t[(t[(t[a>>2]|0)+36>>2]|0)+20>>2]|0)>>>0:0)aE(t[a>>2]|0)|0;else d=49;do if((d|0)==49){i=t[k>>2]|0;if((t[k>>2]|0)<256){if(9<=(i|0)&(t[k>>2]|0)<=10|(t[k>>2]|0)==13|32<=(t[k>>2]|0))break}else{if(256<=(i|0)&(t[k>>2]|0)<=55295)break;if(57344<=(t[k>>2]|0)&(t[k>>2]|0)<=65533)break;if(65536<=(t[k>>2]|0)&(t[k>>2]|0)<=1114111)break}OS(t[a>>2]|0,9,72104,t[k>>2]|0);yF(t[l>>2]|0);t[f>>2]=-1;w=t[f>>2]|0;s=r;return w|0}while(0);t[(t[o>>2]|0)+40>>2]=t[t[l>>2]>>2];t[t[l>>2]>>2]=0;yF(t[l>>2]|0);t[f>>2]=0;w=t[f>>2]|0;s=r;return w|0}}}while(0);AS(t[a>>2]|0,1,71984);t[f>>2]=-1;w=t[f>>2]|0;s=r;return w|0}function zS(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0;r=s;s=s+16|0;n=r+8|0;f=r+4|0;u=r;t[f>>2]=e;t[u>>2]=i;i=t[u>>2]|0;e:do if(!(t[(t[f>>2]|0)+360>>2]&131072)){if((i|0)!=32&(t[u>>2]|0)!=62&(t[u>>2]|0)!=47){if((((((((((((((((!((t[u>>2]|0)>=97&(t[u>>2]|0)<=122)?!((t[u>>2]|0)>=65&(t[u>>2]|0)<=90):0)?!((t[u>>2]|0)>=48&(t[u>>2]|0)<=57|(t[u>>2]|0)==95|(t[u>>2]|0)==58|(t[u>>2]|0)==45|(t[u>>2]|0)==46|(t[u>>2]|0)==183):0)?!((t[u>>2]|0)>=192&(t[u>>2]|0)<=214):0)?!((t[u>>2]|0)>=216&(t[u>>2]|0)<=246):0)?!((t[u>>2]|0)>=248&(t[u>>2]|0)<=767):0)?!((t[u>>2]|0)>=768&(t[u>>2]|0)<=879):0)?!((t[u>>2]|0)>=880&(t[u>>2]|0)<=893):0)?!((t[u>>2]|0)>=895&(t[u>>2]|0)<=8191):0)?!((t[u>>2]|0)>=8204&(t[u>>2]|0)<=8205):0)?!((t[u>>2]|0)>=8255&(t[u>>2]|0)<=8256):0)?!((t[u>>2]|0)>=8304&(t[u>>2]|0)<=8591):0)?!((t[u>>2]|0)>=11264&(t[u>>2]|0)<=12271):0)?!((t[u>>2]|0)>=12289&(t[u>>2]|0)<=55295):0)?!((t[u>>2]|0)>=63744&(t[u>>2]|0)<=64975):0)?!((t[u>>2]|0)>=65008&(t[u>>2]|0)<=65533):0)?!((t[u>>2]|0)>=65536&(t[u>>2]|0)<=983039):0)break;t[n>>2]=1;a=t[n>>2]|0;s=r;return a|0}}else{e=t[u>>2]|0;if((i|0)<256){if(((!(65<=(e|0)&(t[u>>2]|0)<=90)?!(97<=(t[u>>2]|0)&(t[u>>2]|0)<=122):0)?!(192<=(t[u>>2]|0)&(t[u>>2]|0)<=214):0)?!(216<=(t[u>>2]|0)&(t[u>>2]|0)<=246|248<=(t[u>>2]|0)):0)o=27}else if(!(dj(e,199744)|0))o=27;do if((o|0)==27){if((t[u>>2]|0)>=256){if(19968<=(t[u>>2]|0)&(t[u>>2]|0)<=40869|(t[u>>2]|0)==12295)break;if(12321<=(t[u>>2]|0)&(t[u>>2]|0)<=12329)break}e=t[u>>2]|0;if((t[u>>2]|0)<256){if(48<=(e|0)&(t[u>>2]|0)<=57|(t[u>>2]|0)==46|(t[u>>2]|0)==45|(t[u>>2]|0)==95|(t[u>>2]|0)==58)break}else{c=(dj(e,200216)|0)!=0;if(c|(t[u>>2]|0)==46|(t[u>>2]|0)==45|(t[u>>2]|0)==95|(t[u>>2]|0)==58)break}if((t[u>>2]|0)>=256?(dj(t[u>>2]|0,200144)|0)!=0:0)break;c=t[u>>2]|0;if((t[u>>2]|0)<256)if((c|0)==183)break;else break e;else if(dj(c,200272)|0)break;else break e}while(0);t[n>>2]=1;a=t[n>>2]|0;s=r;return a|0}while(0);t[n>>2]=0;a=t[n>>2]|0;s=r;return a|0}function jS(e,i){e=e|0;i=i|0;var r=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0;r=s;s=s+160|0;f=r+36|0;u=r+32|0;a=r+28|0;o=r+40|0;c=r+24|0;l=r+20|0;b=r+16|0;k=r+12|0;h=r+8|0;w=r+4|0;d=r;t[u>>2]=e;t[a>>2]=i;t[c>>2]=t[t[a>>2]>>2];t[l>>2]=0;t[k>>2]=Mp(t[u>>2]|0,t[c>>2]|0,b)|0;if(!(gg(t[u>>2]|0,t[k>>2]|0)|0)){t[f>>2]=0;v=t[f>>2]|0;s=r;return v|0}if((t[b>>2]|0)==1){i=t[k>>2]&255;e=t[l>>2]|0;t[l>>2]=e+1;n[o+e>>0]=i}else{i=Rp(o+(t[l>>2]|0)|0,t[k>>2]|0)|0;t[l>>2]=(t[l>>2]|0)+i}t[c>>2]=(t[c>>2]|0)+(t[b>>2]|0);t[k>>2]=Mp(t[u>>2]|0,t[c>>2]|0,b)|0;do{if(!(zS(t[u>>2]|0,t[k>>2]|0)|0)){m=28;break}if((t[b>>2]|0)==1){i=t[k>>2]&255;e=t[l>>2]|0;t[l>>2]=e+1;n[o+e>>0]=i}else{i=Rp(o+(t[l>>2]|0)|0,t[k>>2]|0)|0;t[l>>2]=(t[l>>2]|0)+i}t[c>>2]=(t[c>>2]|0)+(t[b>>2]|0);t[k>>2]=Mp(t[u>>2]|0,t[c>>2]|0,b)|0}while((t[l>>2]|0)<100);if((m|0)==28){if((t[l>>2]|0)>5e4?(t[(t[u>>2]|0)+360>>2]&524288|0)==0:0){AS(t[u>>2]|0,110,70920);t[f>>2]=0;v=t[f>>2]|0;s=r;return v|0}t[t[a>>2]>>2]=t[c>>2];t[f>>2]=ql(o,t[l>>2]|0)|0;v=t[f>>2]|0;s=r;return v|0}t[w>>2]=t[l>>2]<<1;t[h>>2]=gAi[t[135752>>2]&511](t[w>>2]|0)|0;if(!(t[h>>2]|0)){Sp(t[u>>2]|0,0);t[f>>2]=0;v=t[f>>2]|0;s=r;return v|0}YY(t[h>>2]|0,o|0,t[l>>2]|0)|0;while(1){o=(zS(t[u>>2]|0,t[k>>2]|0)|0)!=0;_=t[l>>2]|0;if(!o){m=27;break}if((_+10|0)>(t[w>>2]|0)){if((t[l>>2]|0)>5e4?(t[(t[u>>2]|0)+360>>2]&524288|0)==0:0){m=19;break}t[w>>2]=t[w>>2]<<1;t[d>>2]=MAi[t[135760>>2]&511](t[h>>2]|0,t[w>>2]|0)|0;if(!(t[d>>2]|0)){m=21;break}t[h>>2]=t[d>>2]}if((t[b>>2]|0)==1){o=t[k>>2]&255;i=t[l>>2]|0;t[l>>2]=i+1;n[(t[h>>2]|0)+i>>0]=o}else{o=Rp((t[h>>2]|0)+(t[l>>2]|0)|0,t[k>>2]|0)|0;t[l>>2]=(t[l>>2]|0)+o}t[c>>2]=(t[c>>2]|0)+(t[b>>2]|0);t[k>>2]=Mp(t[u>>2]|0,t[c>>2]|0,b)|0}if((m|0)==19){AS(t[u>>2]|0,110,70920);pAi[t[135736>>2]&511](t[h>>2]|0);t[f>>2]=0;v=t[f>>2]|0;s=r;return v|0}else if((m|0)==21){Sp(t[u>>2]|0,0);pAi[t[135736>>2]&511](t[h>>2]|0);t[f>>2]=0;v=t[f>>2]|0;s=r;return v|0}else if((m|0)==27){n[(t[h>>2]|0)+_>>0]=0;t[t[a>>2]>>2]=t[c>>2];t[f>>2]=t[h>>2];v=t[f>>2]|0;s=r;return v|0}return 0}function VS(e,i,r,f){e=e|0;i=i|0;r=r|0;f=f|0;var a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0,S=0,g=0,y=0,F=0,O=0,A=0,M=0,R=0,N=0,T=0,L=0,D=0,C=0,P=0,B=0,I=0;a=s;s=s+96|0;o=a+84|0;c=a+80|0;l=a+76|0;b=a+72|0;k=a+68|0;h=a+88|0;w=a+64|0;d=a+60|0;v=a+56|0;m=a+52|0;_=a+48|0;p=a+44|0;E=a+40|0;S=a+36|0;g=a+32|0;y=a+28|0;F=a+24|0;O=a+20|0;A=a+16|0;M=a+12|0;R=a+8|0;N=a+4|0;T=a;t[c>>2]=e;t[l>>2]=i;t[b>>2]=r;t[k>>2]=f;n[h>>0]=0;t[w>>2]=0;t[_>>2]=0;if((t[(t[c>>2]|0)+292>>2]|0)==0?((t[(t[(t[c>>2]|0)+36>>2]|0)+20>>2]|0)-(t[(t[(t[c>>2]|0)+36>>2]|0)+16>>2]|0)|0)<250:0)CS(t[c>>2]|0);t[w>>2]=t[(t[(t[c>>2]|0)+36>>2]|0)+16>>2];t[p>>2]=t[(t[(t[c>>2]|0)+36>>2]|0)+28>>2];t[E>>2]=t[(t[(t[c>>2]|0)+36>>2]|0)+32>>2];if((u[t[w>>2]>>0]|0|0)!=34?(u[t[w>>2]>>0]|0|0)!=39:0){AS(t[c>>2]|0,39,0);t[o>>2]=0;L=t[o>>2]|0;s=a;return L|0}t[(t[c>>2]|0)+172>>2]=12;f=t[w>>2]|0;t[w>>2]=f+1;n[h>>0]=n[f>>0]|0;t[E>>2]=(t[E>>2]|0)+1;t[v>>2]=t[(t[(t[c>>2]|0)+36>>2]|0)+20>>2];
	t[d>>2]=t[w>>2];if((t[w>>2]|0)>>>0>=(t[v>>2]|0)>>>0){t[S>>2]=t[(t[(t[c>>2]|0)+36>>2]|0)+12>>2];if((t[(t[c>>2]|0)+292>>2]|0)==0?((t[(t[(t[c>>2]|0)+36>>2]|0)+20>>2]|0)-(t[(t[(t[c>>2]|0)+36>>2]|0)+16>>2]|0)|0)<250:0)CS(t[c>>2]|0);if((t[S>>2]|0)!=(t[(t[(t[c>>2]|0)+36>>2]|0)+12>>2]|0)){t[g>>2]=(t[(t[(t[c>>2]|0)+36>>2]|0)+12>>2]|0)-(t[S>>2]|0);t[d>>2]=(t[d>>2]|0)+(t[g>>2]|0);t[w>>2]=(t[w>>2]|0)+(t[g>>2]|0)}t[v>>2]=t[(t[(t[c>>2]|0)+36>>2]|0)+20>>2]}do if(t[k>>2]|0){while(1){if((t[w>>2]|0)>>>0>=(t[v>>2]|0)>>>0){D=35;break}if((u[t[w>>2]>>0]|0|0)==(u[h>>0]|0|0)){D=35;break}if((((u[t[w>>2]>>0]|0|0)!=32?(u[t[w>>2]>>0]|0|0)!=9:0)?(u[t[w>>2]>>0]|0|0)!=10:0)?(u[t[w>>2]>>0]|0|0)!=13:0){D=35;break}if((u[t[w>>2]>>0]|0|0)==10){t[p>>2]=(t[p>>2]|0)+1;t[E>>2]=1}else t[E>>2]=(t[E>>2]|0)+1;t[w>>2]=(t[w>>2]|0)+1;t[d>>2]=t[w>>2];if((t[w>>2]|0)>>>0<(t[v>>2]|0)>>>0)continue;t[y>>2]=t[(t[(t[c>>2]|0)+36>>2]|0)+12>>2];if((t[(t[c>>2]|0)+292>>2]|0)==0?((t[(t[(t[c>>2]|0)+36>>2]|0)+20>>2]|0)-(t[(t[(t[c>>2]|0)+36>>2]|0)+16>>2]|0)|0)<250:0)CS(t[c>>2]|0);if((t[(t[c>>2]|0)+172>>2]|0)==-1){D=29;break}if((t[y>>2]|0)!=(t[(t[(t[c>>2]|0)+36>>2]|0)+12>>2]|0)){t[F>>2]=(t[(t[(t[c>>2]|0)+36>>2]|0)+12>>2]|0)-(t[y>>2]|0);t[d>>2]=(t[d>>2]|0)+(t[F>>2]|0);t[w>>2]=(t[w>>2]|0)+(t[F>>2]|0)}t[v>>2]=t[(t[(t[c>>2]|0)+36>>2]|0)+20>>2];if(((t[w>>2]|0)-(t[d>>2]|0)|0)<=1e7)continue;if(!(t[(t[c>>2]|0)+360>>2]&524288)){D=34;break}}if((D|0)==29){t[o>>2]=0;L=t[o>>2]|0;s=a;return L|0}else if((D|0)==34){BS(t[c>>2]|0,40,71720);t[o>>2]=0;L=t[o>>2]|0;s=a;return L|0}else if((D|0)==35){while(1){D=0;if((t[w>>2]|0)>>>0>=(t[v>>2]|0)>>>0){D=54;break}if((u[t[w>>2]>>0]|0|0)==(u[h>>0]|0|0)){D=54;break}if((u[t[w>>2]>>0]|0|0)<32){D=54;break}if((u[t[w>>2]>>0]|0|0)>127){D=54;break}if((u[t[w>>2]>>0]|0|0)==38){D=54;break}if((u[t[w>>2]>>0]|0|0)==60){D=54;break}t[E>>2]=(t[E>>2]|0)+1;g=t[w>>2]|0;t[w>>2]=g+1;if((u[g>>0]|0|0)==32?(u[t[w>>2]>>0]|0|0)==32:0){D=54;break}if((t[w>>2]|0)>>>0<(t[v>>2]|0)>>>0){D=35;continue}t[O>>2]=t[(t[(t[c>>2]|0)+36>>2]|0)+12>>2];if((t[(t[c>>2]|0)+292>>2]|0)==0?((t[(t[(t[c>>2]|0)+36>>2]|0)+20>>2]|0)-(t[(t[(t[c>>2]|0)+36>>2]|0)+16>>2]|0)|0)<250:0)CS(t[c>>2]|0);if((t[(t[c>>2]|0)+172>>2]|0)==-1){D=48;break}if((t[O>>2]|0)!=(t[(t[(t[c>>2]|0)+36>>2]|0)+12>>2]|0)){t[A>>2]=(t[(t[(t[c>>2]|0)+36>>2]|0)+12>>2]|0)-(t[O>>2]|0);t[d>>2]=(t[d>>2]|0)+(t[A>>2]|0);t[w>>2]=(t[w>>2]|0)+(t[A>>2]|0)}t[v>>2]=t[(t[(t[c>>2]|0)+36>>2]|0)+20>>2];if(((t[w>>2]|0)-(t[d>>2]|0)|0)<=1e7){D=35;continue}if(!(t[(t[c>>2]|0)+360>>2]&524288)){D=53;break}else D=35}if((D|0)==48){t[o>>2]=0;L=t[o>>2]|0;s=a;return L|0}else if((D|0)==53){BS(t[c>>2]|0,40,71720);t[o>>2]=0;L=t[o>>2]|0;s=a;return L|0}else if((D|0)==54){t[m>>2]=t[w>>2];while(1){if((u[(t[m>>2]|0)+-1>>0]|0|0)!=32)break;if((t[m>>2]|0)>>>0<=(t[d>>2]|0)>>>0)break;t[m>>2]=(t[m>>2]|0)+-1}while(1){if((t[w>>2]|0)>>>0<(t[v>>2]|0)>>>0?(u[t[w>>2]>>0]|0|0)!=(u[h>>0]|0|0):0)if(((u[t[w>>2]>>0]|0|0)!=32?(u[t[w>>2]>>0]|0|0)!=9:0)?(u[t[w>>2]>>0]|0|0)!=10:0)C=(u[t[w>>2]>>0]|0|0)==13;else C=1;else C=0;P=t[w>>2]|0;if(!C){D=79;break}if((u[P>>0]|0|0)==10){t[p>>2]=(t[p>>2]|0)+1;t[E>>2]=1}else t[E>>2]=(t[E>>2]|0)+1;t[w>>2]=(t[w>>2]|0)+1;if((t[w>>2]|0)>>>0<(t[v>>2]|0)>>>0)continue;t[M>>2]=t[(t[(t[c>>2]|0)+36>>2]|0)+12>>2];if((t[(t[c>>2]|0)+292>>2]|0)==0?((t[(t[(t[c>>2]|0)+36>>2]|0)+20>>2]|0)-(t[(t[(t[c>>2]|0)+36>>2]|0)+16>>2]|0)|0)<250:0)CS(t[c>>2]|0);if((t[(t[c>>2]|0)+172>>2]|0)==-1){D=73;break}if((t[M>>2]|0)!=(t[(t[(t[c>>2]|0)+36>>2]|0)+12>>2]|0)){t[R>>2]=(t[(t[(t[c>>2]|0)+36>>2]|0)+12>>2]|0)-(t[M>>2]|0);t[d>>2]=(t[d>>2]|0)+(t[R>>2]|0);t[w>>2]=(t[w>>2]|0)+(t[R>>2]|0);t[m>>2]=(t[m>>2]|0)+(t[R>>2]|0)}t[v>>2]=t[(t[(t[c>>2]|0)+36>>2]|0)+20>>2];if(((t[w>>2]|0)-(t[d>>2]|0)|0)<=1e7)continue;if(!(t[(t[c>>2]|0)+360>>2]&524288)){D=78;break}}if((D|0)==73){t[o>>2]=0;L=t[o>>2]|0;s=a;return L|0}else if((D|0)==78){BS(t[c>>2]|0,40,71720);t[o>>2]=0;L=t[o>>2]|0;s=a;return L|0}else if((D|0)==79){if((P-(t[d>>2]|0)|0)>1e7?(t[(t[c>>2]|0)+360>>2]&524288|0)==0:0){BS(t[c>>2]|0,40,71720);t[o>>2]=0;L=t[o>>2]|0;s=a;return L|0}if((u[t[w>>2]>>0]|0|0)!=(u[h>>0]|0|0)){D=113;break}else break}}}}else{while(1){if(((((t[w>>2]|0)>>>0<(t[v>>2]|0)>>>0?(u[t[w>>2]>>0]|0|0)!=(u[h>>0]|0|0):0)?(u[t[w>>2]>>0]|0|0)>=32:0)?(u[t[w>>2]>>0]|0|0)<=127:0)?(u[t[w>>2]>>0]|0|0)!=38:0)B=(u[t[w>>2]>>0]|0|0)!=60;else B=0;I=t[w>>2]|0;if(!B){D=101;break}t[w>>2]=I+1;t[E>>2]=(t[E>>2]|0)+1;if((t[w>>2]|0)>>>0<(t[v>>2]|0)>>>0)continue;t[N>>2]=t[(t[(t[c>>2]|0)+36>>2]|0)+12>>2];if((t[(t[c>>2]|0)+292>>2]|0)==0?((t[(t[(t[c>>2]|0)+36>>2]|0)+20>>2]|0)-(t[(t[(t[c>>2]|0)+36>>2]|0)+16>>2]|0)|0)<250:0)CS(t[c>>2]|0);if((t[(t[c>>2]|0)+172>>2]|0)==-1){D=95;break}if((t[N>>2]|0)!=(t[(t[(t[c>>2]|0)+36>>2]|0)+12>>2]|0)){t[T>>2]=(t[(t[(t[c>>2]|0)+36>>2]|0)+12>>2]|0)-(t[N>>2]|0);t[d>>2]=(t[d>>2]|0)+(t[T>>2]|0);t[w>>2]=(t[w>>2]|0)+(t[T>>2]|0)}t[v>>2]=t[(t[(t[c>>2]|0)+36>>2]|0)+20>>2];if(((t[w>>2]|0)-(t[d>>2]|0)|0)<=1e7)continue;if(!(t[(t[c>>2]|0)+360>>2]&524288)){D=100;break}}if((D|0)==95){t[o>>2]=0;L=t[o>>2]|0;s=a;return L|0}else if((D|0)==100){BS(t[c>>2]|0,40,71720);t[o>>2]=0;L=t[o>>2]|0;s=a;return L|0}else if((D|0)==101){t[m>>2]=I;if(((t[w>>2]|0)-(t[d>>2]|0)|0)>1e7?(t[(t[c>>2]|0)+360>>2]&524288|0)==0:0){BS(t[c>>2]|0,40,71720);t[o>>2]=0;L=t[o>>2]|0;s=a;return L|0}if((u[t[w>>2]>>0]|0|0)!=(u[h>>0]|0|0)){D=113;break}else break}}while(0);if((D|0)==113){if(t[b>>2]|0)t[t[b>>2]>>2]=1;t[o>>2]=yg(t[c>>2]|0,t[l>>2]|0,t[k>>2]|0)|0;L=t[o>>2]|0;s=a;return L|0}t[w>>2]=(t[w>>2]|0)+1;t[E>>2]=(t[E>>2]|0)+1;if(t[l>>2]|0){t[t[l>>2]>>2]=(t[m>>2]|0)-(t[d>>2]|0);t[_>>2]=t[d>>2]}else{if(t[b>>2]|0)t[t[b>>2]>>2]=1;t[_>>2]=ql(t[d>>2]|0,(t[m>>2]|0)-(t[d>>2]|0)|0)|0}t[(t[(t[c>>2]|0)+36>>2]|0)+16>>2]=t[w>>2];t[(t[(t[c>>2]|0)+36>>2]|0)+28>>2]=t[p>>2];t[(t[(t[c>>2]|0)+36>>2]|0)+32>>2]=t[E>>2];if(t[b>>2]|0)t[t[b>>2]>>2]=0;t[o>>2]=t[_>>2];L=t[o>>2]|0;s=a;return L|0}function qS(e){e=e|0;var i=0,r=0;i=s;s=s+16|0;r=i;t[r>>2]=e;Fp(t[(t[r>>2]|0)+36>>2]|0);if(u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0){s=i;return}if((yp(t[(t[r>>2]|0)+36>>2]|0,250)|0)>0){s=i;return}aE(t[r>>2]|0)|0;s=i;return}function YS(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0;f=s;s=s+32|0;a=f+28|0;o=f+24|0;c=f+20|0;l=f+16|0;b=f+12|0;k=f+8|0;h=f+4|0;w=f;t[o>>2]=e;t[c>>2]=i;t[l>>2]=r;t[b>>2]=n;if((t[(t[t[o>>2]>>2]|0)+72>>2]|0)==(t[(t[t[o>>2]>>2]|0)+68>>2]|0)){t[a>>2]=0;d=t[a>>2]|0;s=f;return d|0}if(((t[(t[o>>2]|0)+232>>2]|0)!=0?(t[t[(t[o>>2]|0)+232>>2]>>2]|0)!=1:0)?(t[t[(t[o>>2]|0)+232>>2]>>2]|0)!=-2:0){e:do if(!(t[b>>2]|0)){t[k>>2]=0;i:while(1){if((t[k>>2]|0)>=(t[l>>2]|0))break e;do if((u[(t[c>>2]|0)+(t[k>>2]|0)>>0]|0|0)!=32){if(9<=(u[(t[c>>2]|0)+(t[k>>2]|0)>>0]|0|0)?(u[(t[c>>2]|0)+(t[k>>2]|0)>>0]|0|0)<=10:0)break;if((u[(t[c>>2]|0)+(t[k>>2]|0)>>0]|0|0)!=13)break i}while(0);t[k>>2]=(t[k>>2]|0)+1}t[a>>2]=0;d=t[a>>2]|0;s=f;return d|0}while(0);if(!(t[(t[o>>2]|0)+52>>2]|0)){t[a>>2]=0;d=t[a>>2]|0;s=f;return d|0}if(t[(t[o>>2]|0)+8>>2]|0){t[h>>2]=iR(t[(t[o>>2]|0)+8>>2]|0,t[(t[(t[o>>2]|0)+52>>2]|0)+8>>2]|0)|0;if(!(t[h>>2]|0)){t[a>>2]=1;d=t[a>>2]|0;s=f;return d|0}if((t[h>>2]|0)==1){t[a>>2]=0;d=t[a>>2]|0;s=f;return d|0}}if((u[t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)!=60?(u[t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)!=13:0){t[a>>2]=0;d=t[a>>2]|0;s=f;return d|0}if(((t[(t[(t[o>>2]|0)+52>>2]|0)+12>>2]|0)==0?(u[t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==60:0)?(u[(t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]|0)+1>>0]|0|0)==47:0){t[a>>2]=0;d=t[a>>2]|0;s=f;return d|0}t[w>>2]=Uy(t[(t[o>>2]|0)+52>>2]|0)|0;if(!(t[w>>2]|0)){if((t[(t[(t[o>>2]|0)+52>>2]|0)+4>>2]|0)!=1?(t[(t[(t[o>>2]|0)+52>>2]|0)+40>>2]|0)!=0:0){t[a>>2]=0;d=t[a>>2]|0;s=f;return d|0}}else{if(pF(t[w>>2]|0)|0){t[a>>2]=0;d=t[a>>2]|0;s=f;return d|0}if((t[(t[(t[o>>2]|0)+52>>2]|0)+12>>2]|0)!=0?(pF(t[(t[(t[o>>2]|0)+52>>2]|0)+12>>2]|0)|0)!=0:0){t[a>>2]=0;d=t[a>>2]|0;s=f;return d|0}}t[a>>2]=1;d=t[a>>2]|0;s=f;return d|0}t[a>>2]=0;d=t[a>>2]|0;s=f;return d|0}function GS(e,i){e=e|0;i=i|0;var r=0,f=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0;r=s;s=s+336|0;f=r+20|0;a=r+16|0;o=r+24|0;c=r+12|0;l=r+8|0;b=r+4|0;k=r;t[f>>2]=e;t[a>>2]=i;t[c>>2]=0;t[k>>2]=0;if(((t[(t[f>>2]|0)+292>>2]|0)==0?((t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)-(t[(t[(t[f>>2]|0)+36>>2]|0)+12>>2]|0)|0)>500:0)?((t[(t[(t[f>>2]|0)+36>>2]|0)+20>>2]|0)-(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)|0)<500:0)qS(t[f>>2]|0);if((t[(t[f>>2]|0)+292>>2]|0)==0?((t[(t[(t[f>>2]|0)+36>>2]|0)+20>>2]|0)-(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)|0)<250:0)CS(t[f>>2]|0);t[l>>2]=Ap(t[f>>2]|0,b)|0;while(1){if(!((t[l>>2]|0)!=60&(t[l>>2]|0)!=38)){h=49;break}i=t[l>>2]|0;if((t[l>>2]|0)<256)if(9<=(i|0)&(t[l>>2]|0)<=10|(t[l>>2]|0)==13)w=1;else w=32<=(t[l>>2]|0);else if(!(256<=(i|0)&(t[l>>2]|0)<=55295)?!(57344<=(t[l>>2]|0)&(t[l>>2]|0)<=65533):0)if(65536<=(t[l>>2]|0))w=(t[l>>2]|0)<=1114111;else w=0;else w=1;if(!(w&1)){h=49;break}if(((t[l>>2]|0)==93?(u[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+1>>0]|0|0)==93:0)?(u[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+2>>0]|0|0)==62:0){if(t[a>>2]|0){h=49;break}AS(t[f>>2]|0,62,0)}if((t[b>>2]|0)==1){i=t[l>>2]&255;e=t[c>>2]|0;t[c>>2]=e+1;n[o+e>>0]=i}else{i=Rp(o+(t[c>>2]|0)|0,t[l>>2]|0)|0;t[c>>2]=(t[c>>2]|0)+i}if((t[c>>2]|0)>=300){n[o+(t[c>>2]|0)>>0]=0;do if((t[t[f>>2]>>2]|0)!=0?(t[(t[f>>2]|0)+212>>2]|0)==0:0){i=(YS(t[f>>2]|0,o,t[c>>2]|0,0)|0)!=0;e=t[t[f>>2]>>2]|0;if(i){if(!(t[e+72>>2]|0))break;yAi[t[(t[t[f>>2]>>2]|0)+72>>2]&511](t[(t[f>>2]|0)+4>>2]|0,o,t[c>>2]|0);break}if(t[e+68>>2]|0)yAi[t[(t[t[f>>2]>>2]|0)+68>>2]&511](t[(t[f>>2]|0)+4>>2]|0,o,t[c>>2]|0);if((t[(t[t[f>>2]>>2]|0)+68>>2]|0)!=(t[(t[t[f>>2]>>2]|0)+72>>2]|0)?(t[t[(t[f>>2]|0)+232>>2]>>2]|0)==-1:0)t[t[(t[f>>2]|0)+232>>2]>>2]=-2}while(0);t[c>>2]=0;if((t[(t[f>>2]|0)+172>>2]|0)!=7){h=71;break}}t[k>>2]=(t[k>>2]|0)+1;if((t[k>>2]|0)>50){if((t[(t[f>>2]|0)+292>>2]|0)==0?((t[(t[(t[f>>2]|0)+36>>2]|0)+20>>2]|0)-(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)|0)<250:0)CS(t[f>>2]|0);t[k>>2]=0;if((t[(t[f>>2]|0)+172>>2]|0)==-1){h=71;break}}e=t[(t[f>>2]|0)+36>>2]|0;if((u[t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==10){i=e+28|0;t[i>>2]=(t[i>>2]|0)+1;t[(t[(t[f>>2]|0)+36>>2]|0)+32>>2]=1}else{i=e+32|0;t[i>>2]=(t[i>>2]|0)+1}i=(t[(t[f>>2]|0)+36>>2]|0)+16|0;t[i>>2]=(t[i>>2]|0)+(t[b>>2]|0);if((u[t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==37)oE(t[f>>2]|0);t[l>>2]=Ap(t[f>>2]|0,b)|0}if((h|0)==49){do if(((t[c>>2]|0)!=0?(n[o+(t[c>>2]|0)>>0]=0,(t[t[f>>2]>>2]|0)!=0):0)?(t[(t[f>>2]|0)+212>>2]|0)==0:0){k=(YS(t[f>>2]|0,o,t[c>>2]|0,0)|0)!=0;a=t[t[f>>2]>>2]|0;if(k){if(!(t[a+72>>2]|0))break;yAi[t[(t[t[f>>2]>>2]|0)+72>>2]&511](t[(t[f>>2]|0)+4>>2]|0,o,t[c>>2]|0);break}if(t[a+68>>2]|0)yAi[t[(t[t[f>>2]>>2]|0)+68>>2]&511](t[(t[f>>2]|0)+4>>2]|0,o,t[c>>2]|0);if((t[(t[t[f>>2]>>2]|0)+68>>2]|0)!=(t[(t[t[f>>2]>>2]|0)+72>>2]|0)?(t[t[(t[f>>2]|0)+232>>2]>>2]|0)==-1:0)t[t[(t[f>>2]|0)+232>>2]>>2]=-2}while(0);if(!(t[l>>2]|0)){s=r;return}c=t[l>>2]|0;if((t[l>>2]|0)<256){if(9<=(c|0)&(t[l>>2]|0)<=10|(t[l>>2]|0)==13|32<=(t[l>>2]|0)){s=r;return}}else{if(256<=(c|0)&(t[l>>2]|0)<=55295){s=r;return}if(57344<=(t[l>>2]|0)&(t[l>>2]|0)<=65533){s=r;return}if(65536<=(t[l>>2]|0)&(t[l>>2]|0)<=1114111){s=r;return}}OS(t[f>>2]|0,9,72816,t[l>>2]|0);l=t[(t[f>>2]|0)+36>>2]|0;if((u[t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==10){c=l+28|0;t[c>>2]=(t[c>>2]|0)+1;t[(t[(t[f>>2]|0)+36>>2]|0)+32>>2]=1}else{c=l+32|0;t[c>>2]=(t[c>>2]|0)+1}c=(t[(t[f>>2]|0)+36>>2]|0)+16|0;t[c>>2]=(t[c>>2]|0)+(t[b>>2]|0);if((u[t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)!=37){s=r;return}oE(t[f>>2]|0);s=r;return}else if((h|0)==71){s=r;return}}function WS(e,i,r,f){e=e|0;i=i|0;r=r|0;f=f|0;var a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0,S=0,g=0;a=s;s=s+64|0;o=a+52|0;c=a+48|0;l=a+44|0;b=a+40|0;k=a+36|0;h=a+32|0;w=a+28|0;d=a+24|0;v=a+20|0;m=a+16|0;_=a+12|0;p=a+8|0;E=a+4|0;S=a;t[o>>2]=e;t[c>>2]=i;t[l>>2]=r;t[b>>2]=f;t[_>>2]=0;t[p>>2]=t[(t[(t[o>>2]|0)+36>>2]|0)+56>>2];if((t[c>>2]|0)==0?(t[l>>2]=0,t[b>>2]=100,t[c>>2]=gAi[t[135752>>2]&511](t[b>>2]|0)|0,(t[c>>2]|0)==0):0){Sp(t[o>>2]|0,0);s=a;return}if((t[(t[o>>2]|0)+292>>2]|0)==0?((t[(t[(t[o>>2]|0)+36>>2]|0)+20>>2]|0)-(t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]|0)|0)<250:0)CS(t[o>>2]|0);t[k>>2]=Ap(t[o>>2]|0,h)|0;if(t[k>>2]|0){f=t[k>>2]|0;if((t[k>>2]|0)<256){if(!(9<=(f|0)&(t[k>>2]|0)<=10|(t[k>>2]|0)==13|32<=(t[k>>2]|0)))g=13}else if((!(256<=(f|0)&(t[k>>2]|0)<=55295)?!(57344<=(t[k>>2]|0)&(t[k>>2]|0)<=65533):0)?!(65536<=(t[k>>2]|0)&(t[k>>2]|0)<=1114111):0)g=13;if((g|0)==13){OS(t[o>>2]|0,9,72648,t[k>>2]|0);pAi[t[135736>>2]&511](t[c>>2]|0);s=a;return}f=t[(t[o>>2]|0)+36>>2]|0;if((u[t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==10){r=f+28|0;t[r>>2]=(t[r>>2]|0)+1;t[(t[(t[o>>2]|0)+36>>2]|0)+32>>2]=1}else{r=f+32|0;t[r>>2]=(t[r>>2]|0)+1}r=(t[(t[o>>2]|0)+36>>2]|0)+16|0;t[r>>2]=(t[r>>2]|0)+(t[h>>2]|0);if((u[t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==37)oE(t[o>>2]|0);t[w>>2]=Ap(t[o>>2]|0,d)|0;if(t[w>>2]|0){r=t[w>>2]|0;if((t[w>>2]|0)<256){if(!(9<=(r|0)&(t[w>>2]|0)<=10|(t[w>>2]|0)==13|32<=(t[w>>2]|0)))g=25}else if((!(256<=(r|0)&(t[w>>2]|0)<=55295)?!(57344<=(t[w>>2]|0)&(t[w>>2]|0)<=65533):0)?!(65536<=(t[w>>2]|0)&(t[w>>2]|0)<=1114111):0)g=25;if((g|0)==25){OS(t[o>>2]|0,9,72648,t[k>>2]|0);pAi[t[135736>>2]&511](t[c>>2]|0);s=a;return}r=t[(t[o>>2]|0)+36>>2]|0;if((u[t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==10){f=r+28|0;t[f>>2]=(t[f>>2]|0)+1;t[(t[(t[o>>2]|0)+36>>2]|0)+32>>2]=1}else{f=r+32|0;t[f>>2]=(t[f>>2]|0)+1}f=(t[(t[o>>2]|0)+36>>2]|0)+16|0;t[f>>2]=(t[f>>2]|0)+(t[d>>2]|0);if((u[t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==37)oE(t[o>>2]|0);t[v>>2]=Ap(t[o>>2]|0,m)|0;if(t[v>>2]|0){while(1){f=t[v>>2]|0;if((t[v>>2]|0)<256){if(!(9<=(f|0)&(t[v>>2]|0)<=10|(t[v>>2]|0)==13|32<=(t[v>>2]|0))){g=70;break}}else if((!(256<=(f|0)&(t[v>>2]|0)<=55295)?!(57344<=(t[v>>2]|0)&(t[v>>2]|0)<=65533):0)?!(65536<=(t[v>>2]|0)&(t[v>>2]|0)<=1114111):0){g=70;break}if(!((t[v>>2]|0)!=62|(t[w>>2]|0)!=45|(t[k>>2]|0)!=45)){g=70;break}if((t[w>>2]|0)==45&(t[k>>2]|0)==45)AS(t[o>>2]|0,80,0);if((t[l>>2]|0)>>>0>1e7?(t[(t[o>>2]|0)+360>>2]&524288|0)==0:0){g=42;break}if(((t[l>>2]|0)+5|0)>>>0>=(t[b>>2]|0)>>>0){t[S>>2]=t[b>>2]<<1;t[E>>2]=MAi[t[135760>>2]&511](t[c>>2]|0,t[S>>2]|0)|0;if(!(t[E>>2]|0)){g=45;break}t[c>>2]=t[E>>2];t[b>>2]=t[S>>2]}if((t[h>>2]|0)==1){f=t[k>>2]&255;r=t[l>>2]|0;t[l>>2]=r+1;n[(t[c>>2]|0)+r>>0]=f}else{f=Rp((t[c>>2]|0)+(t[l>>2]|0)|0,t[k>>2]|0)|0;t[l>>2]=(t[l>>2]|0)+f}t[k>>2]=t[w>>2];t[h>>2]=t[d>>2];t[w>>2]=t[v>>2];t[d>>2]=t[m>>2];t[_>>2]=(t[_>>2]|0)+1;if((t[_>>2]|0)>>>0>50){do if(!(t[(t[o>>2]|0)+292>>2]|0)){if(((t[(t[(t[o>>2]|0)+36>>2]|0)+20>>2]|0)-(t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]|0)|0)>=250)break;CS(t[o>>2]|0)}while(0);t[_>>2]=0;if((t[(t[o>>2]|0)+172>>2]|0)==-1){g=55;break}}f=t[(t[o>>2]|0)+36>>2]|0;if((u[t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==10){r=f+28|0;t[r>>2]=(t[r>>2]|0)+1;t[(t[(t[o>>2]|0)+36>>2]|0)+32>>2]=1}else{r=f+32|0;t[r>>2]=(t[r>>2]|0)+1}r=(t[(t[o>>2]|0)+36>>2]|0)+16|0;t[r>>2]=(t[r>>2]|0)+(t[m>>2]|0);if((u[t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==37)oE(t[o>>2]|0);t[v>>2]=Ap(t[o>>2]|0,m)|0;if(t[v>>2]|0)continue;do if(!(t[(t[o>>2]|0)+292>>2]|0)){if(((t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]|0)-(t[(t[(t[o>>2]|0)+36>>2]|0)+12>>2]|0)|0)<=500)break;if(((t[(t[(t[o>>2]|0)+36>>2]|0)+20>>2]|0)-(t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]|0)|0)>=500)break;qS(t[o>>2]|0)}while(0);do if(!(t[(t[o>>2]|0)+292>>2]|0)){if(((t[(t[(t[o>>2]|0)+36>>2]|0)+20>>2]|0)-(t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]|0)|0)>=250)break;CS(t[o>>2]|0)}while(0);t[v>>2]=Ap(t[o>>2]|0,m)|0}if((g|0)==42){MS(t[o>>2]|0,45,66168,0);pAi[t[135736>>2]&511](t[c>>2]|0);s=a;return}else if((g|0)==45){pAi[t[135736>>2]&511](t[c>>2]|0);Sp(t[o>>2]|0,0);s=a;return}else if((g|0)==55){pAi[t[135736>>2]&511](t[c>>2]|0);s=a;return}else if((g|0)==70){n[(t[c>>2]|0)+(t[l>>2]|0)>>0]=0;do if(t[v>>2]|0){l=t[v>>2]|0;if((t[v>>2]|0)<256){if(!(9<=(l|0)&(t[v>>2]|0)<=10|(t[v>>2]|0)==13|32<=(t[v>>2]|0)))g=77}else if((!(256<=(l|0)&(t[v>>2]|0)<=55295)?!(57344<=(t[v>>2]|0)&(t[v>>2]|0)<=65533):0)?!(65536<=(t[v>>2]|0)&(t[v>>2]|0)<=1114111):0)g=77;if((g|0)==77){OS(t[o>>2]|0,9,72648,t[v>>2]|0);break}if((t[p>>2]|0)!=(t[(t[(t[o>>2]|0)+36>>2]|0)+56>>2]|0))BS(t[o>>2]|0,90,72736);Op(t[o>>2]|0);if(((t[t[o>>2]>>2]|0)!=0?(t[(t[t[o>>2]>>2]|0)+80>>2]|0)!=0:0)?(t[(t[o>>2]|0)+212>>2]|0)==0:0)EAi[t[(t[t[o>>2]>>2]|0)+80>>2]&511](t[(t[o>>2]|0)+4>>2]|0,t[c>>2]|0)}else MS(t[o>>2]|0,45,72696,t[c>>2]|0);while(0);pAi[t[135736>>2]&511](t[c>>2]|0);s=a;return}}}}MS(t[o>>2]|0,45,72792,0);pAi[t[135736>>2]&511](t[c>>2]|0);s=a;return}function KS(e,i,r,n,f,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;u=u|0;var a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0;a=s;s=s+48|0;o=a;c=a+32|0;l=a+28|0;b=a+24|0;k=a+20|0;h=a+16|0;w=a+12|0;t[c>>2]=e;t[l>>2]=i;t[b>>2]=r;t[k>>2]=n;t[h>>2]=f;t[w>>2]=u;if(((t[c>>2]|0)!=0?(t[(t[c>>2]|0)+212>>2]|0)!=0:0)?(t[(t[c>>2]|0)+172>>2]|0)==-1:0){s=a;return}if(t[c>>2]|0)t[(t[c>>2]|0)+84>>2]=t[l>>2];u=t[c>>2]|0;f=t[l>>2]|0;l=t[k>>2]|0;n=t[h>>2]|0;r=t[w>>2]|0;i=t[b>>2]|0;b=t[h>>2]|0;h=t[w>>2]|0;t[o>>2]=t[k>>2];t[o+4>>2]=b;t[o+8>>2]=h;cp(0,0,0,u,0,3,f,2,0,0,l,n,r,0,0,i,o);if(!(t[c>>2]|0)){s=a;return}t[(t[c>>2]|0)+356>>2]=0;s=a;return}function XS(e,i){e=e|0;i=i|0;var r=0,f=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0,S=0;r=s;s=s+32|0;f=r+16|0;a=r+12|0;o=r+8|0;c=r+4|0;l=r;b=r+20|0;t[f>>2]=e;t[a>>2]=i;t[o>>2]=0;t[c>>2]=t[a>>2];while(1){do if((u[t[c>>2]>>0]|0|0)==32)k=1;else{if(9<=(u[t[c>>2]>>0]|0|0)?(u[t[c>>2]>>0]|0|0)<=10:0){k=1;break}k=(u[t[c>>2]>>0]|0|0)==13}while(0);h=t[c>>2]|0;if(!k)break;t[c>>2]=h+1}do if(!(Jl(h,72576,7)|0)){t[c>>2]=(t[c>>2]|0)+7;while(1){do if((u[t[c>>2]>>0]|0|0)==32)w=1;else{if(9<=(u[t[c>>2]>>0]|0|0)?(u[t[c>>2]>>0]|0|0)<=10:0){w=1;break}w=(u[t[c>>2]>>0]|0|0)==13}while(0);d=t[c>>2]|0;if(!w)break;t[c>>2]=d+1}if((u[d>>0]|0|0)!=61){s=r;return}t[c>>2]=(t[c>>2]|0)+1;while(1){do if((u[t[c>>2]>>0]|0|0)==32)v=1;else{if(9<=(u[t[c>>2]>>0]|0|0)?(u[t[c>>2]>>0]|0|0)<=10:0){v=1;break}v=(u[t[c>>2]>>0]|0|0)==13}while(0);m=t[c>>2]|0;if(!v)break;t[c>>2]=m+1}n[b>>0]=n[m>>0]|0;if((u[b>>0]|0|0)!=39?(u[b>>0]|0|0)!=34:0)break;t[c>>2]=(t[c>>2]|0)+1;t[l>>2]=t[c>>2];while(1){if(u[t[c>>2]>>0]|0)_=(u[t[c>>2]>>0]|0|0)!=(u[b>>0]|0|0);else _=0;p=t[c>>2]|0;if(!_)break;t[c>>2]=p+1}if(u[p>>0]|0){t[o>>2]=ql(t[l>>2]|0,(t[c>>2]|0)-(t[l>>2]|0)|0)|0;t[c>>2]=(t[c>>2]|0)+1;while(1){do if((u[t[c>>2]>>0]|0|0)==32)E=1;else{if(9<=(u[t[c>>2]>>0]|0|0)?(u[t[c>>2]>>0]|0|0)<=10:0){E=1;break}E=(u[t[c>>2]>>0]|0|0)==13}while(0);S=t[c>>2]|0;if(!E)break;t[c>>2]=S+1}if(!(u[S>>0]|0)){if(!(t[o>>2]|0)){s=r;return}k=kc(t[(t[f>>2]|0)+284>>2]|0,t[o>>2]|0)|0;t[(t[f>>2]|0)+284>>2]=k;pAi[t[135736>>2]&511](t[o>>2]|0);s=r;return}}}while(0);NS(t[f>>2]|0,93,72584,t[a>>2]|0,0);if(!(t[o>>2]|0)){s=r;return}pAi[t[135736>>2]&511](t[o>>2]|0);s=r;return}function ZS(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,u=0,a=0,o=0,c=0,l=0;f=s;s=s+32|0;u=f;a=f+16|0;o=f+12|0;c=f+8|0;l=f+4|0;t[a>>2]=e;t[o>>2]=i;t[c>>2]=r;t[l>>2]=n;if(((t[a>>2]|0)!=0?(t[(t[a>>2]|0)+212>>2]|0)!=0:0)?(t[(t[a>>2]|0)+172>>2]|0)==-1:0){s=f;return}if(t[a>>2]|0)t[(t[a>>2]|0)+84>>2]=t[o>>2];n=t[a>>2]|0;a=t[o>>2]|0;o=t[l>>2]|0;r=t[c>>2]|0;t[u>>2]=t[l>>2];cp(0,0,0,n,0,1,a,2,0,0,o,0,0,0,0,r,u);s=f;return}function JS(e,i){e=e|0;i=i|0;var r=0,f=0,a=0,o=0,c=0,l=0;r=s;s=s+16|0;f=r+8|0;a=r+4|0;o=r;t[a>>2]=e;t[o>>2]=i;if((t[a>>2]|0)==0|(t[o>>2]|0)==0){t[f>>2]=0;c=t[f>>2]|0;s=r;return c|0}while(1){if((u[t[a>>2]>>0]|0|0)!=32)break;t[a>>2]=(t[a>>2]|0)+1}while(1){if(!(u[t[a>>2]>>0]|0))break;if((u[t[a>>2]>>0]|0|0)!=32){i=t[a>>2]|0;t[a>>2]=i+1;e=n[i>>0]|0;i=t[o>>2]|0;t[o>>2]=i+1;n[i>>0]=e;continue}while(1){l=t[a>>2]|0;if((u[t[a>>2]>>0]|0|0)!=32)break;t[a>>2]=l+1}if(!(u[l>>0]|0))continue;e=t[o>>2]|0;t[o>>2]=e+1;n[e>>0]=32}n[t[o>>2]>>0]=0;if((t[o>>2]|0)==(t[a>>2]|0)){t[f>>2]=0;c=t[f>>2]|0;s=r;return c|0}else{t[f>>2]=t[o>>2];c=t[f>>2]|0;s=r;return c|0}return 0}function QS(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0;f=s;s=s+48|0;u=f+32|0;a=f+28|0;o=f+24|0;c=f+20|0;l=f+16|0;b=f+12|0;k=f+8|0;h=f+4|0;w=f;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;t[c>>2]=n;if((t[(t[u>>2]|0)+352>>2]|0)!=0?(fO(t[(t[u>>2]|0)+352>>2]|0,t[a>>2]|0,t[o>>2]|0)|0)!=0:0){s=f;return}if(!((t[(t[u>>2]|0)+348>>2]|0)==0?(n=KF(10,t[(t[u>>2]|0)+296>>2]|0)|0,t[(t[u>>2]|0)+348>>2]=n,(t[(t[u>>2]|0)+348>>2]|0)==0):0))d=5;do if((d|0)==5){t[k>>2]=jg(t[a>>2]|0,b)|0;n=t[(t[u>>2]|0)+296>>2]|0;if(!(t[k>>2]|0)){t[k>>2]=kz(n,t[a>>2]|0,-1)|0;t[h>>2]=0}else{t[k>>2]=kz(n,t[k>>2]|0,-1)|0;t[h>>2]=kz(t[(t[u>>2]|0)+296>>2]|0,t[a>>2]|0,t[b>>2]|0)|0}t[l>>2]=fO(t[(t[u>>2]|0)+348>>2]|0,t[k>>2]|0,t[h>>2]|0)|0;if(!(t[l>>2]|0)){t[l>>2]=gAi[t[135744>>2]&511](108)|0;if(!(t[l>>2]|0))break;t[t[l>>2]>>2]=0;t[(t[l>>2]|0)+4>>2]=4;if((iO(t[(t[u>>2]|0)+348>>2]|0,t[k>>2]|0,t[h>>2]|0,t[l>>2]|0,0)|0)<0){pAi[t[135736>>2]&511](t[l>>2]|0);break}}else if((t[t[l>>2]>>2]|0)>=(t[(t[l>>2]|0)+4>>2]|0)){t[w>>2]=MAi[t[135760>>2]&511](t[l>>2]|0,28+((t[(t[l>>2]|0)+4>>2]<<1)*5<<2)|0)|0;if(!(t[w>>2]|0))break;t[l>>2]=t[w>>2];n=(t[l>>2]|0)+4|0;t[n>>2]=t[n>>2]<<1;if((iO(t[(t[u>>2]|0)+348>>2]|0,t[k>>2]|0,t[h>>2]|0,t[l>>2]|0,0)|0)<0){pAi[t[135736>>2]&511](t[l>>2]|0);break}}t[k>>2]=jg(t[o>>2]|0,b)|0;n=t[(t[u>>2]|0)+296>>2]|0;if(!(t[k>>2]|0)){t[k>>2]=kz(n,t[o>>2]|0,-1)|0;t[h>>2]=0}else{t[k>>2]=kz(n,t[k>>2]|0,-1)|0;t[h>>2]=kz(t[(t[u>>2]|0)+296>>2]|0,t[o>>2]|0,t[b>>2]|0)|0}t[(t[l>>2]|0)+8+((t[t[l>>2]>>2]|0)*5<<2)>>2]=t[k>>2];t[(t[l>>2]|0)+8+(((t[t[l>>2]>>2]|0)*5|0)+1<<2)>>2]=t[h>>2];t[b>>2]=rs(t[c>>2]|0)|0;t[c>>2]=kz(t[(t[u>>2]|0)+296>>2]|0,t[c>>2]|0,t[b>>2]|0)|0;t[(t[l>>2]|0)+8+(((t[t[l>>2]>>2]|0)*5|0)+2<<2)>>2]=t[c>>2];t[(t[l>>2]|0)+8+(((t[t[l>>2]>>2]|0)*5|0)+3<<2)>>2]=(t[c>>2]|0)+(t[b>>2]|0);n=(t[l>>2]|0)+8+(((t[t[l>>2]>>2]|0)*5|0)+4<<2)|0;if(t[(t[u>>2]|0)+96>>2]|0)t[n>>2]=72560;else t[n>>2]=0;n=t[l>>2]|0;t[n>>2]=(t[n>>2]|0)+1;s=f;return}while(0);Sp(t[u>>2]|0,0);s=f;return}function $S(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,u=0,a=0,o=0,c=0;f=s;s=s+16|0;u=f+12|0;a=f+8|0;o=f+4|0;c=f;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;t[c>>2]=n;if((t[(t[u>>2]|0)+352>>2]|0)==0?(n=KF(10,t[(t[u>>2]|0)+296>>2]|0)|0,t[(t[u>>2]|0)+352>>2]=n,(t[(t[u>>2]|0)+352>>2]|0)==0):0){Sp(t[u>>2]|0,0);s=f;return}if(fO(t[(t[u>>2]|0)+352>>2]|0,t[a>>2]|0,t[o>>2]|0)|0){s=f;return}QF(t[(t[u>>2]|0)+352>>2]|0,t[a>>2]|0,t[o>>2]|0,t[c>>2]|0)|0;s=f;return}function eg(e,i,r){e=e|0;i=i|0;r=r|0;var f=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0,S=0,g=0,y=0,F=0;f=s;s=s+64|0;a=f+44|0;o=f+40|0;c=f+36|0;l=f+32|0;b=f+28|0;k=f+24|0;h=f+20|0;w=f+16|0;d=f+12|0;v=f+48|0;m=f+8|0;_=f+4|0;p=f;t[o>>2]=e;t[c>>2]=i;t[l>>2]=r;t[b>>2]=0;t[k>>2]=0;t[h>>2]=0;t[w>>2]=0;n[v>>0]=0;if((t[l>>2]|0)>128){if((t[l>>2]|0)>2048?1:(t[(t[o>>2]|0)+360>>2]&524288|0)==0)E=4}else if((t[l>>2]|0)>2048)E=4;if((E|0)==4){OS(t[o>>2]|0,55,72424,t[l>>2]|0);t[a>>2]=0;S=t[a>>2]|0;s=f;return S|0}uE(t[o>>2]|0)|0;if((t[(t[o>>2]|0)+292>>2]|0)==0?((t[(t[(t[o>>2]|0)+36>>2]|0)+20>>2]|0)-(t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]|0)|0)<250:0)CS(t[o>>2]|0);r=t[o>>2]|0;if((u[t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==40){t[m>>2]=t[(t[r+36>>2]|0)+56>>2];Op(t[o>>2]|0);uE(t[o>>2]|0)|0;i=eg(t[o>>2]|0,t[m>>2]|0,(t[l>>2]|0)+1|0)|0;t[b>>2]=i;t[k>>2]=i;uE(t[o>>2]|0)|0;if((t[(t[o>>2]|0)+292>>2]|0)==0?((t[(t[(t[o>>2]|0)+36>>2]|0)+20>>2]|0)-(t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]|0)|0)<250:0)CS(t[o>>2]|0)}else{t[d>>2]=sE(r)|0;r=t[o>>2]|0;if(!(t[d>>2]|0)){AS(r,54,0);t[a>>2]=0;S=t[a>>2]|0;s=f;return S|0}i=EM(t[r+8>>2]|0,t[d>>2]|0,2)|0;t[b>>2]=i;t[k>>2]=i;i=t[o>>2]|0;if(!(t[k>>2]|0)){Sp(i,0);t[a>>2]=0;S=t[a>>2]|0;s=f;return S|0}if((t[i+292>>2]|0)==0?((t[(t[(t[o>>2]|0)+36>>2]|0)+20>>2]|0)-(t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]|0)|0)<250:0)CS(t[o>>2]|0);do if((u[t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)!=63){if((u[t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==42){t[(t[k>>2]|0)+4>>2]=3;Op(t[o>>2]|0);break}i=(t[k>>2]|0)+4|0;if((u[t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==43){t[i>>2]=4;Op(t[o>>2]|0);break}else{t[i>>2]=1;break}}else{t[(t[k>>2]|0)+4>>2]=2;Op(t[o>>2]|0)}while(0);if((t[(t[o>>2]|0)+292>>2]|0)==0?((t[(t[(t[o>>2]|0)+36>>2]|0)+20>>2]|0)-(t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]|0)|0)<250:0)CS(t[o>>2]|0)}uE(t[o>>2]|0)|0;if(((t[(t[o>>2]|0)+292>>2]|0)==0?((t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]|0)-(t[(t[(t[o>>2]|0)+36>>2]|0)+12>>2]|0)|0)>500:0)?((t[(t[(t[o>>2]|0)+36>>2]|0)+20>>2]|0)-(t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]|0)|0)<500:0)qS(t[o>>2]|0);e:while(1){if((u[t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==41){E=117;break}if((t[(t[o>>2]|0)+172>>2]|0)==-1){E=117;break}do if((u[t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==44){if(u[v>>0]|0){if((u[v>>0]|0|0)!=(u[t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)){E=39;break e}}else n[v>>0]=n[t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]>>0]|0;Op(t[o>>2]|0);t[w>>2]=EM(t[(t[o>>2]|0)+8>>2]|0,0,3)|0;g=t[h>>2]|0;if(!(t[w>>2]|0)){E=46;break e}if(!g){t[(t[w>>2]|0)+12>>2]=t[b>>2];if(t[b>>2]|0)t[(t[b>>2]|0)+20>>2]=t[w>>2];i=t[w>>2]|0;t[k>>2]=i;t[b>>2]=i;break}t[(t[k>>2]|0)+16>>2]=t[w>>2];if(t[w>>2]|0)t[(t[w>>2]|0)+20>>2]=t[k>>2];t[(t[w>>2]|0)+12>>2]=t[h>>2];if(t[h>>2]|0)t[(t[h>>2]|0)+20>>2]=t[w>>2];t[k>>2]=t[w>>2];t[h>>2]=0}else{if((u[t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)!=124){E=85;break e}if(u[v>>0]|0){if((u[v>>0]|0|0)!=(u[t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)){E=63;break e}}else n[v>>0]=n[t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]>>0]|0;Op(t[o>>2]|0);t[w>>2]=EM(t[(t[o>>2]|0)+8>>2]|0,0,4)|0;y=t[h>>2]|0;if(!(t[w>>2]|0)){E=70;break e}if(!y){t[(t[w>>2]|0)+12>>2]=t[b>>2];if(t[b>>2]|0)t[(t[b>>2]|0)+20>>2]=t[w>>2];i=t[w>>2]|0;t[k>>2]=i;t[b>>2]=i;break}t[(t[k>>2]|0)+16>>2]=t[w>>2];if(t[w>>2]|0)t[(t[w>>2]|0)+20>>2]=t[k>>2];t[(t[w>>2]|0)+12>>2]=t[h>>2];if(t[h>>2]|0)t[(t[h>>2]|0)+20>>2]=t[w>>2];t[k>>2]=t[w>>2];t[h>>2]=0}while(0);if((t[(t[o>>2]|0)+292>>2]|0)==0?((t[(t[(t[o>>2]|0)+36>>2]|0)+20>>2]|0)-(t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]|0)|0)<250:0)CS(t[o>>2]|0);uE(t[o>>2]|0)|0;if((t[(t[o>>2]|0)+292>>2]|0)==0?((t[(t[(t[o>>2]|0)+36>>2]|0)+20>>2]|0)-(t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]|0)|0)<250:0)CS(t[o>>2]|0);i=t[o>>2]|0;do if((u[t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)!=40){t[d>>2]=sE(i)|0;F=t[o>>2]|0;if(!(t[d>>2]|0)){E=100;break e}t[h>>2]=EM(t[F+8>>2]|0,t[d>>2]|0,2)|0;if(!(t[h>>2]|0)){E=104;break e}if((u[t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==63){t[(t[h>>2]|0)+4>>2]=2;Op(t[o>>2]|0);break}if((u[t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==42){t[(t[h>>2]|0)+4>>2]=3;Op(t[o>>2]|0);break}r=(t[h>>2]|0)+4|0;if((u[t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==43){t[r>>2]=4;Op(t[o>>2]|0);break}else{t[r>>2]=1;break}}else{t[_>>2]=t[(t[i+36>>2]|0)+56>>2];Op(t[o>>2]|0);uE(t[o>>2]|0)|0;t[h>>2]=eg(t[o>>2]|0,t[_>>2]|0,(t[l>>2]|0)+1|0)|0;uE(t[o>>2]|0)|0}while(0);uE(t[o>>2]|0)|0;if(t[(t[o>>2]|0)+292>>2]|0)continue;if(((t[(t[(t[o>>2]|0)+36>>2]|0)+20>>2]|0)-(t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]|0)|0)>=250)continue;CS(t[o>>2]|0)}if((E|0)==39){OS(t[o>>2]|0,66,72504,u[v>>0]|0);if((t[h>>2]|0)!=0?(t[h>>2]|0)!=(t[b>>2]|0):0)yM(t[(t[o>>2]|0)+8>>2]|0,t[h>>2]|0);if(t[b>>2]|0)yM(t[(t[o>>2]|0)+8>>2]|0,t[b>>2]|0);t[a>>2]=0;S=t[a>>2]|0;s=f;return S|0}else if((E|0)==46){if((g|0)!=0?(t[h>>2]|0)!=(t[b>>2]|0):0)yM(t[(t[o>>2]|0)+8>>2]|0,t[h>>2]|0);yM(t[(t[o>>2]|0)+8>>2]|0,t[b>>2]|0);t[a>>2]=0;S=t[a>>2]|0;s=f;return S|0}else if((E|0)==63){OS(t[o>>2]|0,66,72504,u[v>>0]|0);if((t[h>>2]|0)!=0?(t[h>>2]|0)!=(t[b>>2]|0):0)yM(t[(t[o>>2]|0)+8>>2]|0,t[h>>2]|0);if(t[b>>2]|0)yM(t[(t[o>>2]|0)+8>>2]|0,t[b>>2]|0);t[a>>2]=0;S=t[a>>2]|0;s=f;return S|0}else if((E|0)==70){if((y|0)!=0?(t[h>>2]|0)!=(t[b>>2]|0):0)yM(t[(t[o>>2]|0)+8>>2]|0,t[h>>2]|0);if(t[b>>2]|0)yM(t[(t[o>>2]|0)+8>>2]|0,t[b>>2]|0);t[a>>2]=0;S=t[a>>2]|0;s=f;return S|0}else if((E|0)==85){AS(t[o>>2]|0,55,0);if((t[h>>2]|0)!=0?(t[h>>2]|0)!=(t[b>>2]|0):0)yM(t[(t[o>>2]|0)+8>>2]|0,t[h>>2]|0);if(t[b>>2]|0)yM(t[(t[o>>2]|0)+8>>2]|0,t[b>>2]|0);t[a>>2]=0;S=t[a>>2]|0;s=f;return S|0}else if((E|0)==100){AS(F,54,0);if(t[b>>2]|0)yM(t[(t[o>>2]|0)+8>>2]|0,t[b>>2]|0);t[a>>2]=0;S=t[a>>2]|0;s=f;return S|0}else if((E|0)==104){if(t[b>>2]|0)yM(t[(t[o>>2]|0)+8>>2]|0,t[b>>2]|0);t[a>>2]=0;S=t[a>>2]|0;s=f;return S|0}else if((E|0)==117){if((t[k>>2]|0)!=0&(t[h>>2]|0)!=0?(t[(t[k>>2]|0)+16>>2]=t[h>>2],(t[h>>2]|0)!=0):0)t[(t[h>>2]|0)+20>>2]=t[k>>2];if((t[(t[o>>2]|0)+104>>2]|0)!=0?(t[(t[(t[o>>2]|0)+36>>2]|0)+56>>2]|0)!=(t[c>>2]|0):0)RS(t[o>>2]|0,90,67976,0,0);Op(t[o>>2]|0);do if((u[t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)!=63){if((u[t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==42){e:do if(t[b>>2]|0){t[(t[b>>2]|0)+4>>2]=3;t[k>>2]=t[b>>2];while(1){if(!(t[k>>2]|0))break e;if((t[t[k>>2]>>2]|0)!=4)break e;do if(t[(t[k>>2]|0)+12>>2]|0){if((t[(t[(t[k>>2]|0)+12>>2]|0)+4>>2]|0)!=2?(t[(t[(t[k>>2]|0)+12>>2]|0)+4>>2]|0)!=3:0)break;t[(t[(t[k>>2]|0)+12>>2]|0)+4>>2]=1}while(0);do if(t[(t[k>>2]|0)+16>>2]|0){if((t[(t[(t[k>>2]|0)+16>>2]|0)+4>>2]|0)!=2?(t[(t[(t[k>>2]|0)+16>>2]|0)+4>>2]|0)!=3:0)break;t[(t[(t[k>>2]|0)+16>>2]|0)+4>>2]=1}while(0);t[k>>2]=t[(t[k>>2]|0)+16>>2]}}while(0);Op(t[o>>2]|0);break}if((u[t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==43){if(t[b>>2]|0){t[p>>2]=0;if((t[(t[b>>2]|0)+4>>2]|0)!=2?(t[(t[b>>2]|0)+4>>2]|0)!=3:0)t[(t[b>>2]|0)+4>>2]=4;else t[(t[b>>2]|0)+4>>2]=3;while(1){if(!(t[k>>2]|0))break;if((t[t[k>>2]>>2]|0)!=4)break;do if(t[(t[k>>2]|0)+12>>2]|0){if((t[(t[(t[k>>2]|0)+12>>2]|0)+4>>2]|0)!=2?(t[(t[(t[k>>2]|0)+12>>2]|0)+4>>2]|0)!=3:0)break;t[(t[(t[k>>2]|0)+12>>2]|0)+4>>2]=1;t[p>>2]=1}while(0);do if(t[(t[k>>2]|0)+16>>2]|0){if((t[(t[(t[k>>2]|0)+16>>2]|0)+4>>2]|0)!=2?(t[(t[(t[k>>2]|0)+16>>2]|0)+4>>2]|0)!=3:0)break;t[(t[(t[k>>2]|0)+16>>2]|0)+4>>2]=1;t[p>>2]=1}while(0);t[k>>2]=t[(t[k>>2]|0)+16>>2]}if(t[p>>2]|0)t[(t[b>>2]|0)+4>>2]=3}Op(t[o>>2]|0)}}else{do if(t[b>>2]|0){if((t[(t[b>>2]|0)+4>>2]|0)!=4?(t[(t[b>>2]|0)+4>>2]|0)!=3:0){t[(t[b>>2]|0)+4>>2]=2;break}t[(t[b>>2]|0)+4>>2]=3}while(0);Op(t[o>>2]|0)}while(0);t[a>>2]=t[b>>2];S=t[a>>2]|0;s=f;return S|0}return 0}function ig(e){e=e|0;var i=0,r=0,n=0,f=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0;i=s;s=s+48|0;r=i;n=i+32|0;f=i+28|0;a=i+24|0;o=i+20|0;c=i+16|0;l=i+12|0;b=i+8|0;t[n>>2]=e;t[f>>2]=t[(t[(t[n>>2]|0)+36>>2]|0)+56>>2];e=(t[n>>2]|0)+200|0;t[e>>2]=(t[e>>2]|0)+3;e=(t[(t[n>>2]|0)+36>>2]|0)+16|0;t[e>>2]=(t[e>>2]|0)+3;e=(t[(t[n>>2]|0)+36>>2]|0)+32|0;t[e>>2]=(t[e>>2]|0)+3;if((u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==37)oE(t[n>>2]|0);if((u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==0?(yp(t[(t[n>>2]|0)+36>>2]|0,250)|0)<=0:0)aE(t[n>>2]|0)|0;uE(t[n>>2]|0)|0;if(((((((u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==73?(u[(t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]|0)+1>>0]|0|0)==78:0)?(u[(t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]|0)+2>>0]|0|0)==67:0)?(u[(t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]|0)+3>>0]|0|0)==76:0)?(u[(t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]|0)+4>>0]|0|0)==85:0)?(u[(t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]|0)+5>>0]|0|0)==68:0)?(u[(t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]|0)+6>>0]|0|0)==69:0){e=(t[n>>2]|0)+200|0;t[e>>2]=(t[e>>2]|0)+7;e=(t[(t[n>>2]|0)+36>>2]|0)+16|0;t[e>>2]=(t[e>>2]|0)+7;e=(t[(t[n>>2]|0)+36>>2]|0)+32|0;t[e>>2]=(t[e>>2]|0)+7;if((u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==37)oE(t[n>>2]|0);if((u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==0?(yp(t[(t[n>>2]|0)+36>>2]|0,250)|0)<=0:0)aE(t[n>>2]|0)|0;uE(t[n>>2]|0)|0;e=t[n>>2]|0;if((u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)!=91)AS(e,83,0);else{if((t[(t[e+36>>2]|0)+56>>2]|0)!=(t[f>>2]|0))RS(t[n>>2]|0,90,72192,0,0);Op(t[n>>2]|0)}if(t[33952]|0){if((t[(t[n>>2]|0)+36>>2]|0)!=0?(t[(t[(t[n>>2]|0)+36>>2]|0)+4>>2]|0)!=0:0){e=t[33976]|0;k=t[33980]|0;h=t[(t[(t[n>>2]|0)+36>>2]|0)+28>>2]|0;t[r>>2]=t[(t[(t[n>>2]|0)+36>>2]|0)+4>>2];t[r+4>>2]=h;yAi[e&511](k,65312,r)}yAi[t[135904>>2]&511](t[33980]|0,72264,r)}while(1){if(!(u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0))break;if(((u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==93?(u[(t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]|0)+1>>0]|0|0)==93:0)?(u[(t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]|0)+2>>0]|0|0)==62:0)break;if((t[(t[n>>2]|0)+172>>2]|0)==-1)break;t[a>>2]=t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2];t[o>>2]=t[(t[(t[n>>2]|0)+36>>2]|0)+36>>2];do if((u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==60){if((u[(t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]|0)+1>>0]|0|0)!=33){w=37;break}if((u[(t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]|0)+2>>0]|0|0)!=91){w=37;break}ig(t[n>>2]|0)}else w=37;while(0);e:do if((w|0)==37){w=0;do if((u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)!=32){if(9<=(u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)?(u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)<=10:0)break;if((u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==13)break;k=t[n>>2]|0;if((u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==37){
	HE(k);break e}else{IE(k);break e}}while(0);Op(t[n>>2]|0)}while(0);while(1){if(!(u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0))d=(t[(t[n>>2]|0)+40>>2]|0)>1;else d=0;v=t[n>>2]|0;if(!d)break;aE(v)|0}if((t[(t[v+36>>2]|0)+16>>2]|0)!=(t[a>>2]|0))continue;if((t[o>>2]|0)==(t[(t[(t[n>>2]|0)+36>>2]|0)+36>>2]|0)){w=51;break}}if((w|0)==51)AS(t[n>>2]|0,60,0);if(t[33952]|0){if((t[(t[n>>2]|0)+36>>2]|0)!=0?(t[(t[(t[n>>2]|0)+36>>2]|0)+4>>2]|0)!=0:0){o=t[33976]|0;a=t[33980]|0;v=t[(t[(t[n>>2]|0)+36>>2]|0)+28>>2]|0;t[r>>2]=t[(t[(t[n>>2]|0)+36>>2]|0)+4>>2];t[r+4>>2]=v;yAi[o&511](a,65312,r)}yAi[t[135904>>2]&511](t[33980]|0,72304,r)}}else w=57;do if((w|0)==57){if((((((u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==73?(u[(t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]|0)+1>>0]|0|0)==71:0)?(u[(t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]|0)+2>>0]|0|0)==78:0)?(u[(t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]|0)+3>>0]|0|0)==79:0)?(u[(t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]|0)+4>>0]|0|0)==82:0)?(u[(t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]|0)+5>>0]|0|0)==69:0){t[b>>2]=0;a=(t[n>>2]|0)+200|0;t[a>>2]=(t[a>>2]|0)+6;a=(t[(t[n>>2]|0)+36>>2]|0)+16|0;t[a>>2]=(t[a>>2]|0)+6;a=(t[(t[n>>2]|0)+36>>2]|0)+32|0;t[a>>2]=(t[a>>2]|0)+6;if((u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==37)oE(t[n>>2]|0);if((u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==0?(yp(t[(t[n>>2]|0)+36>>2]|0,250)|0)<=0:0)aE(t[n>>2]|0)|0;uE(t[n>>2]|0)|0;a=t[n>>2]|0;if((u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)!=91)AS(a,83,0);else{if((t[(t[a+36>>2]|0)+56>>2]|0)!=(t[f>>2]|0))RS(t[n>>2]|0,90,72192,0,0);Op(t[n>>2]|0)}if(t[33952]|0){if((t[(t[n>>2]|0)+36>>2]|0)!=0?(t[(t[(t[n>>2]|0)+36>>2]|0)+4>>2]|0)!=0:0){a=t[33976]|0;o=t[33980]|0;v=t[(t[(t[n>>2]|0)+36>>2]|0)+28>>2]|0;t[r>>2]=t[(t[(t[n>>2]|0)+36>>2]|0)+4>>2];t[r+4>>2]=v;yAi[a&511](o,65312,r)}yAi[t[135904>>2]&511](t[33980]|0,72344,r)}t[c>>2]=t[(t[n>>2]|0)+212>>2];t[l>>2]=t[(t[n>>2]|0)+172>>2];if(!(t[(t[n>>2]|0)+288>>2]|0))t[(t[n>>2]|0)+212>>2]=1;t[(t[n>>2]|0)+172>>2]=15;e:while(1){if((t[b>>2]|0)<0)break;if(!(u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0))break;if((t[(t[n>>2]|0)+172>>2]|0)==-1)break;do if((u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==60){if((u[(t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]|0)+1>>0]|0|0)!=33)break;if((u[(t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]|0)+2>>0]|0|0)!=91)break;t[b>>2]=(t[b>>2]|0)+1;o=(t[n>>2]|0)+200|0;t[o>>2]=(t[o>>2]|0)+3;o=(t[(t[n>>2]|0)+36>>2]|0)+16|0;t[o>>2]=(t[o>>2]|0)+3;o=(t[(t[n>>2]|0)+36>>2]|0)+32|0;t[o>>2]=(t[o>>2]|0)+3;if((u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==37)oE(t[n>>2]|0);if(u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0)continue e;if((yp(t[(t[n>>2]|0)+36>>2]|0,250)|0)>0)continue e;aE(t[n>>2]|0)|0;continue e}while(0);do if((u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==93){if((u[(t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]|0)+1>>0]|0|0)!=93)break;if((u[(t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]|0)+2>>0]|0|0)!=62)break;o=(t[b>>2]|0)+-1|0;t[b>>2]=o;if((o|0)<0)continue e;o=(t[n>>2]|0)+200|0;t[o>>2]=(t[o>>2]|0)+3;o=(t[(t[n>>2]|0)+36>>2]|0)+16|0;t[o>>2]=(t[o>>2]|0)+3;o=(t[(t[n>>2]|0)+36>>2]|0)+32|0;t[o>>2]=(t[o>>2]|0)+3;if((u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==37)oE(t[n>>2]|0);if(u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0)continue e;if((yp(t[(t[n>>2]|0)+36>>2]|0,250)|0)>0)continue e;aE(t[n>>2]|0)|0;continue e}while(0);Op(t[n>>2]|0)}t[(t[n>>2]|0)+212>>2]=t[c>>2];t[(t[n>>2]|0)+172>>2]=t[l>>2];if(!(t[33952]|0))break;if((t[(t[n>>2]|0)+36>>2]|0)!=0?(t[(t[(t[n>>2]|0)+36>>2]|0)+4>>2]|0)!=0:0){o=t[33976]|0;a=t[33980]|0;v=t[(t[(t[n>>2]|0)+36>>2]|0)+28>>2]|0;t[r>>2]=t[(t[(t[n>>2]|0)+36>>2]|0)+4>>2];t[r+4>>2]=v;yAi[o&511](a,65312,r)}yAi[t[135904>>2]&511](t[33980]|0,72384,r);break}AS(t[n>>2]|0,95,0)}while(0);if((((u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==0?(t[(t[n>>2]|0)+292>>2]|0)==0:0)?((t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]|0)-(t[(t[(t[n>>2]|0)+36>>2]|0)+12>>2]|0)|0)>500:0)?((t[(t[(t[n>>2]|0)+36>>2]|0)+20>>2]|0)-(t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]|0)|0)<500:0)qS(t[n>>2]|0);r=t[n>>2]|0;if(!(u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0)){AS(r,59,0);s=i;return}if((t[(t[r+36>>2]|0)+56>>2]|0)!=(t[f>>2]|0))RS(t[n>>2]|0,90,72192,0,0);f=(t[n>>2]|0)+200|0;t[f>>2]=(t[f>>2]|0)+3;f=(t[(t[n>>2]|0)+36>>2]|0)+16|0;t[f>>2]=(t[f>>2]|0)+3;f=(t[(t[n>>2]|0)+36>>2]|0)+32|0;t[f>>2]=(t[f>>2]|0)+3;if((u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==37)oE(t[n>>2]|0);if(u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0){s=i;return}if((yp(t[(t[n>>2]|0)+36>>2]|0,250)|0)>0){s=i;return}aE(t[n>>2]|0)|0;s=i;return}function rg(e){e=e|0;var i=0,r=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if(!(t[r>>2]|0)){s=i;return}do if((t[t[r>>2]>>2]|0)!=0?(t[(t[t[r>>2]>>2]|0)+108>>2]|0)==-554844497:0){if((t[(t[t[r>>2]>>2]|0)+116>>2]|0)==0?(t[(t[t[r>>2]>>2]|0)+120>>2]|0)==0:0)break;t[(t[r>>2]|0)+324>>2]=1}while(0);e=kz(t[(t[r>>2]|0)+296>>2]|0,70032,3)|0;t[(t[r>>2]|0)+312>>2]=e;e=kz(t[(t[r>>2]|0)+296>>2]|0,70040,5)|0;t[(t[r>>2]|0)+316>>2]=e;e=kz(t[(t[r>>2]|0)+296>>2]|0,70048,36)|0;t[(t[r>>2]|0)+320>>2]=e;if(((t[(t[r>>2]|0)+312>>2]|0)!=0?(t[(t[r>>2]|0)+316>>2]|0)!=0:0)?(t[(t[r>>2]|0)+320>>2]|0)!=0:0){s=i;return}Sp(t[r>>2]|0,0);s=i;return}function ng(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0,S=0,g=0,y=0,F=0;f=s;s=s+64|0;a=f+56|0;o=f+52|0;c=f+48|0;l=f+44|0;b=f+40|0;k=f+36|0;h=f+32|0;w=f+28|0;d=f+24|0;v=f+20|0;m=f+16|0;_=f+12|0;p=f+8|0;E=f+4|0;S=f;t[o>>2]=e;t[c>>2]=i;t[l>>2]=r;t[b>>2]=n;t[h>>2]=0;t[d>>2]=0;t[v>>2]=0;t[m>>2]=0;t[p>>2]=0;if(!((t[(t[o>>2]|0)+248>>2]|0)>40?(t[(t[o>>2]|0)+360>>2]&524288|0)==0:0))g=3;if((g|0)==3?(t[(t[o>>2]|0)+248>>2]|0)<=1024:0){if(t[b>>2]|0)t[t[b>>2]>>2]=0;if(!(t[c>>2]|0)){t[a>>2]=1;y=t[a>>2]|0;s=f;return y|0}t[_>>2]=rs(t[c>>2]|0)|0;t[k>>2]=lS(t[c>>2]|0,t[_>>2]|0)|0;if(!(t[k>>2]|0)){t[a>>2]=27;y=t[a>>2]|0;s=f;return y|0}if(t[l>>2]|0)t[(t[k>>2]|0)+4>>2]=t[l>>2];else t[(t[k>>2]|0)+4>>2]=t[k>>2];if(t[(t[k>>2]|0)+296>>2]|0)bz(t[(t[k>>2]|0)+296>>2]|0);t[(t[k>>2]|0)+296>>2]=t[(t[o>>2]|0)+296>>2];l=kz(t[(t[k>>2]|0)+296>>2]|0,70032,3)|0;t[(t[k>>2]|0)+312>>2]=l;l=kz(t[(t[k>>2]|0)+296>>2]|0,70040,5)|0;t[(t[k>>2]|0)+316>>2]=l;l=kz(t[(t[k>>2]|0)+296>>2]|0,70048,36)|0;t[(t[k>>2]|0)+320>>2]=l;t[E>>2]=0;while(1){F=t[k>>2]|0;if((t[E>>2]|0)>=(t[(t[o>>2]|0)+328>>2]|0))break;Eg(F,t[(t[(t[o>>2]|0)+336>>2]|0)+(t[E>>2]<<2)>>2]|0,t[(t[(t[o>>2]|0)+336>>2]|0)+((t[E>>2]|0)+1<<2)>>2]|0)|0;t[E>>2]=(t[E>>2]|0)+2}t[d>>2]=t[F>>2];t[t[k>>2]>>2]=t[t[o>>2]>>2];rg(t[k>>2]|0);t[(t[k>>2]|0)+16>>2]=t[(t[o>>2]|0)+16>>2];t[(t[k>>2]|0)+360>>2]=t[(t[o>>2]|0)+360>>2];t[(t[k>>2]|0)+272>>2]=t[(t[o>>2]|0)+272>>2];do if(!(t[(t[o>>2]|0)+8>>2]|0)){t[h>>2]=ny(68488)|0;if(t[h>>2]|0){t[(t[h>>2]|0)+92>>2]=64;t[(t[h>>2]|0)+80>>2]=t[(t[k>>2]|0)+296>>2];sz(t[(t[h>>2]|0)+80>>2]|0)|0;t[(t[k>>2]|0)+8>>2]=t[h>>2];break}t[t[k>>2]>>2]=t[d>>2];t[(t[k>>2]|0)+296>>2]=0;Up(t[k>>2]|0);t[a>>2]=1;y=t[a>>2]|0;s=f;return y|0}else{t[(t[k>>2]|0)+8>>2]=t[(t[o>>2]|0)+8>>2];t[v>>2]=t[(t[(t[k>>2]|0)+8>>2]|0)+12>>2];t[m>>2]=t[(t[(t[k>>2]|0)+8>>2]|0)+16>>2]}while(0);t[w>>2]=Sy(t[(t[k>>2]|0)+8>>2]|0,0,69968,0)|0;if(!(t[w>>2]|0)){t[t[k>>2]>>2]=t[d>>2];t[(t[k>>2]|0)+296>>2]=0;Up(t[k>>2]|0);if(t[h>>2]|0)fy(t[h>>2]|0);t[a>>2]=1;y=t[a>>2]|0;s=f;return y|0}t[(t[(t[k>>2]|0)+8>>2]|0)+12>>2]=0;t[(t[(t[k>>2]|0)+8>>2]|0)+16>>2]=0;Hy(t[(t[k>>2]|0)+8>>2]|0,t[w>>2]|0)|0;rE(t[k>>2]|0,t[(t[(t[k>>2]|0)+8>>2]|0)+12>>2]|0)|0;t[(t[k>>2]|0)+172>>2]=7;t[(t[k>>2]|0)+248>>2]=(t[(t[o>>2]|0)+248>>2]|0)+1;t[(t[k>>2]|0)+104>>2]=0;t[(t[k>>2]|0)+276>>2]=t[(t[o>>2]|0)+276>>2];if(!((t[(t[o>>2]|0)+104>>2]|0)==0?(t[(t[o>>2]|0)+16>>2]|0)==0:0)){w=(t[k>>2]|0)+276|0;t[w>>2]=t[w>>2]|8}t[(t[k>>2]|0)+364>>2]=t[(t[o>>2]|0)+364>>2];t[(t[k>>2]|0)+348>>2]=t[(t[o>>2]|0)+348>>2];t[(t[k>>2]|0)+352>>2]=t[(t[o>>2]|0)+352>>2];KE(t[k>>2]|0);if((u[t[(t[(t[k>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==60?(u[(t[(t[(t[k>>2]|0)+36>>2]|0)+16>>2]|0)+1>>0]|0|0)==47:0)AS(t[k>>2]|0,85,0);else g=34;if((g|0)==34?(u[t[(t[(t[k>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)!=0:0)AS(t[k>>2]|0,86,0);if((t[(t[k>>2]|0)+52>>2]|0)!=(t[(t[(t[k>>2]|0)+8>>2]|0)+12>>2]|0))AS(t[k>>2]|0,85,0);do if(!(t[(t[k>>2]|0)+12>>2]|0))if(!(t[(t[k>>2]|0)+84>>2]|0)){t[p>>2]=1;break}else{t[p>>2]=t[(t[k>>2]|0)+84>>2];break}else t[p>>2]=0;while(0);if((t[b>>2]|0)!=0&(t[p>>2]|0)==0){t[S>>2]=t[(t[(t[(t[k>>2]|0)+8>>2]|0)+12>>2]|0)+12>>2];t[t[b>>2]>>2]=t[S>>2];while(1){if(!(t[S>>2]|0))break;do if(t[(t[o>>2]|0)+104>>2]|0){if(!(t[(t[o>>2]|0)+12>>2]|0))break;if(!(t[(t[o>>2]|0)+8>>2]|0))break;if(!(t[(t[(t[o>>2]|0)+8>>2]|0)+44>>2]|0))break;if((t[(t[S>>2]|0)+4>>2]|0)!=1)break;b=hR((t[o>>2]|0)+108|0,t[(t[o>>2]|0)+8>>2]|0,t[S>>2]|0)|0;g=(t[o>>2]|0)+100|0;t[g>>2]=t[g>>2]&b}while(0);t[(t[S>>2]|0)+20>>2]=0;t[S>>2]=t[(t[S>>2]|0)+24>>2]}t[(t[(t[(t[k>>2]|0)+8>>2]|0)+12>>2]|0)+12>>2]=0}if(t[(t[k>>2]|0)+8>>2]|0){ry(t[(t[(t[k>>2]|0)+8>>2]|0)+12>>2]|0);t[(t[(t[k>>2]|0)+8>>2]|0)+12>>2]=t[v>>2];t[(t[(t[k>>2]|0)+8>>2]|0)+16>>2]=t[m>>2]}if(t[o>>2]|0){m=(t[o>>2]|0)+440|0;t[m>>2]=(t[m>>2]|0)+(t[(t[k>>2]|0)+440>>2]|0)}if(t[(t[k>>2]|0)+388>>2]|0)sp((t[k>>2]|0)+384|0,(t[o>>2]|0)+384|0)|0;t[t[k>>2]>>2]=t[d>>2];t[(t[k>>2]|0)+296>>2]=0;t[(t[k>>2]|0)+348>>2]=0;t[(t[k>>2]|0)+352>>2]=0;Up(t[k>>2]|0);if(t[h>>2]|0)fy(t[h>>2]|0);t[a>>2]=t[p>>2];y=t[a>>2]|0;s=f;return y|0}t[a>>2]=89;y=t[a>>2]|0;s=f;return y|0}function fg(e,i,r,f,a,o,c,l){e=e|0;i=i|0;r=r|0;f=f|0;a=a|0;o=o|0;c=c|0;l=l|0;var b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0,S=0,g=0,y=0,F=0,O=0,A=0,M=0,R=0,N=0,T=0;b=s;s=s+80|0;k=b+60|0;h=b+56|0;w=b+52|0;d=b+48|0;v=b+44|0;m=b+40|0;_=b+36|0;p=b+32|0;E=b+28|0;S=b+24|0;g=b+20|0;y=b+16|0;F=b+12|0;O=b+8|0;A=b+64|0;M=b+4|0;R=b;t[h>>2]=e;t[w>>2]=i;t[d>>2]=r;t[v>>2]=f;t[m>>2]=a;t[_>>2]=o;t[p>>2]=c;t[E>>2]=l;t[F>>2]=0;t[O>>2]=0;if((t[m>>2]|0)>40){if(!((t[w>>2]|0)!=0?!((t[m>>2]|0)>1024?1:(t[(t[w>>2]|0)+360>>2]&524288|0)==0):0))N=5}else if((t[m>>2]|0)>1024)N=5;if((N|0)==5){t[k>>2]=89;T=t[k>>2]|0;s=b;return T|0}if(t[E>>2]|0)t[t[E>>2]>>2]=0;if((t[_>>2]|0)==0&(t[p>>2]|0)==0){t[k>>2]=1;T=t[k>>2]|0;s=b;return T|0}if(!(t[h>>2]|0)){t[k>>2]=1;T=t[k>>2]|0;s=b;return T|0}t[S>>2]=mg(t[_>>2]|0,t[p>>2]|0,0,t[w>>2]|0)|0;if(!(t[S>>2]|0)){t[k>>2]=27;T=t[k>>2]|0;s=b;return T|0}t[(t[S>>2]|0)+4>>2]=t[S>>2];if(t[w>>2]|0){t[(t[S>>2]|0)+272>>2]=t[(t[w>>2]|0)+272>>2];t[(t[S>>2]|0)+276>>2]=t[(t[w>>2]|0)+276>>2];t[(t[S>>2]|0)+104>>2]=t[(t[w>>2]|0)+104>>2];t[(t[S>>2]|0)+96>>2]=t[(t[w>>2]|0)+96>>2];t[(t[S>>2]|0)+68>>2]=t[(t[w>>2]|0)+68>>2];t[(t[S>>2]|0)+72>>2]=t[(t[w>>2]|0)+72>>2];t[(t[S>>2]|0)+76>>2]=t[(t[w>>2]|0)+76>>2];t[(t[S>>2]|0)+80>>2]=t[(t[w>>2]|0)+80>>2]}else{t[(t[S>>2]|0)+272>>2]=0;t[(t[S>>2]|0)+104>>2]=0;t[(t[S>>2]|0)+96>>2]=2;t[(t[S>>2]|0)+276>>2]=0}if((t[d>>2]|0)!=0?(t[F>>2]=t[t[S>>2]>>2],t[t[S>>2]>>2]=t[d>>2],(t[v>>2]|0)!=0):0)t[(t[S>>2]|0)+4>>2]=t[v>>2];rg(t[S>>2]|0);t[g>>2]=ny(68488)|0;if(!(t[g>>2]|0)){t[(t[S>>2]|0)+72>>2]=0;t[(t[S>>2]|0)+76>>2]=0;t[(t[S>>2]|0)+80>>2]=0;Up(t[S>>2]|0);t[k>>2]=1;T=t[k>>2]|0;s=b;return T|0}t[(t[g>>2]|0)+92>>2]=64;t[(t[g>>2]|0)+44>>2]=t[(t[h>>2]|0)+44>>2];t[(t[g>>2]|0)+48>>2]=t[(t[h>>2]|0)+48>>2];t[(t[g>>2]|0)+80>>2]=t[(t[h>>2]|0)+80>>2];sz(t[(t[g>>2]|0)+80>>2]|0)|0;if(t[(t[h>>2]|0)+72>>2]|0){v=Yl(t[(t[h>>2]|0)+72>>2]|0)|0;t[(t[g>>2]|0)+72>>2]=v}t[y>>2]=Sy(t[g>>2]|0,0,69968,0)|0;if(!(t[y>>2]|0)){if(t[d>>2]|0)t[t[S>>2]>>2]=t[F>>2];t[(t[S>>2]|0)+72>>2]=0;t[(t[S>>2]|0)+76>>2]=0;t[(t[S>>2]|0)+80>>2]=0;Up(t[S>>2]|0);t[(t[g>>2]|0)+44>>2]=0;t[(t[g>>2]|0)+48>>2]=0;fy(t[g>>2]|0);t[k>>2]=1;T=t[k>>2]|0;s=b;return T|0}Hy(t[g>>2]|0,t[y>>2]|0)|0;rE(t[S>>2]|0,t[(t[g>>2]|0)+12>>2]|0)|0;t[(t[S>>2]|0)+8>>2]=t[h>>2];t[(t[y>>2]|0)+32>>2]=t[h>>2];if((t[(t[S>>2]|0)+292>>2]|0)==0?((t[(t[(t[S>>2]|0)+36>>2]|0)+20>>2]|0)-(t[(t[(t[S>>2]|0)+36>>2]|0)+16>>2]|0)|0)<250:0)CS(t[S>>2]|0);if(((t[(t[(t[S>>2]|0)+36>>2]|0)+20>>2]|0)-(t[(t[(t[S>>2]|0)+36>>2]|0)+16>>2]|0)|0)>=4?(n[A>>0]=n[t[(t[(t[S>>2]|0)+36>>2]|0)+16>>2]>>0]|0,n[A+1>>0]=n[(t[(t[(t[S>>2]|0)+36>>2]|0)+16>>2]|0)+1>>0]|0,n[A+2>>0]=n[(t[(t[(t[S>>2]|0)+36>>2]|0)+16>>2]|0)+2>>0]|0,n[A+3>>0]=n[(t[(t[(t[S>>2]|0)+36>>2]|0)+16>>2]|0)+3>>0]|0,t[M>>2]=L_(A,4)|0,(t[M>>2]|0)!=0):0)Tp(t[S>>2]|0,t[M>>2]|0)|0;e:do if(((((u[t[(t[(t[S>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==60?(u[(t[(t[(t[S>>2]|0)+36>>2]|0)+16>>2]|0)+1>>0]|0|0)==63:0)?(u[(t[(t[(t[S>>2]|0)+36>>2]|0)+16>>2]|0)+2>>0]|0|0)==120:0)?(u[(t[(t[(t[S>>2]|0)+36>>2]|0)+16>>2]|0)+3>>0]|0|0)==109:0)?(u[(t[(t[(t[S>>2]|0)+36>>2]|0)+16>>2]|0)+4>>0]|0|0)==108:0){do if((u[(t[(t[(t[S>>2]|0)+36>>2]|0)+16>>2]|0)+5>>0]|0|0)!=32){if(9<=(u[(t[(t[(t[S>>2]|0)+36>>2]|0)+16>>2]|0)+5>>0]|0|0)?(u[(t[(t[(t[S>>2]|0)+36>>2]|0)+16>>2]|0)+5>>0]|0|0)<=10:0)break;if((u[(t[(t[(t[S>>2]|0)+36>>2]|0)+16>>2]|0)+5>>0]|0|0)!=13)break e}while(0);bE(t[S>>2]|0)}while(0);t[(t[S>>2]|0)+172>>2]=7;t[(t[S>>2]|0)+248>>2]=t[m>>2];KE(t[S>>2]|0);if((u[t[(t[(t[S>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==60?(u[(t[(t[(t[S>>2]|0)+36>>2]|0)+16>>2]|0)+1>>0]|0|0)==47:0)AS(t[S>>2]|0,85,0);else N=47;if((N|0)==47?(u[t[(t[(t[S>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)!=0:0)AS(t[S>>2]|0,86,0);if((t[(t[S>>2]|0)+52>>2]|0)!=(t[(t[g>>2]|0)+12>>2]|0))AS(t[S>>2]|0,85,0);do if(!(t[(t[S>>2]|0)+12>>2]|0))if(!(t[(t[S>>2]|0)+84>>2]|0)){t[O>>2]=1;break}else{t[O>>2]=t[(t[S>>2]|0)+84>>2];break}else{if(t[E>>2]|0){t[R>>2]=t[(t[(t[g>>2]|0)+12>>2]|0)+12>>2];t[t[E>>2]>>2]=t[R>>2];while(1){if(!(t[R>>2]|0))break;t[(t[R>>2]|0)+20>>2]=0;t[R>>2]=t[(t[R>>2]|0)+24>>2]}t[(t[(t[g>>2]|0)+12>>2]|0)+12>>2]=0}t[O>>2]=0}while(0);if(t[w>>2]|0){R=(t[w>>2]|0)+440|0;t[R>>2]=(t[R>>2]|0)+(t[(t[S>>2]|0)+440>>2]|0)}if(t[(t[S>>2]|0)+36>>2]|0){R=(t[w>>2]|0)+444|0;t[R>>2]=(t[R>>2]|0)+(t[(t[(t[S>>2]|0)+36>>2]|0)+36>>2]|0);R=(t[w>>2]|0)+444|0;t[R>>2]=(t[R>>2]|0)+((t[(t[(t[S>>2]|0)+36>>2]|0)+16>>2]|0)-(t[(t[(t[S>>2]|0)+36>>2]|0)+12>>2]|0))}if(t[(t[S>>2]|0)+388>>2]|0)sp((t[S>>2]|0)+384|0,(t[w>>2]|0)+384|0)|0;if(t[d>>2]|0)t[t[S>>2]>>2]=t[F>>2];t[(t[w>>2]|0)+72>>2]=t[(t[S>>2]|0)+72>>2];t[(t[w>>2]|0)+76>>2]=t[(t[S>>2]|0)+76>>2];t[(t[w>>2]|0)+80>>2]=t[(t[S>>2]|0)+80>>2];t[(t[S>>2]|0)+72>>2]=0;t[(t[S>>2]|0)+76>>2]=0;t[(t[S>>2]|0)+80>>2]=0;Up(t[S>>2]|0);t[(t[g>>2]|0)+44>>2]=0;t[(t[g>>2]|0)+48>>2]=0;fy(t[g>>2]|0);t[k>>2]=t[O>>2];T=t[k>>2]|0;s=b;return T|0}function tg(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0;n=s;s=s+16|0;f=n+8|0;u=n+4|0;a=n;t[f>>2]=e;t[u>>2]=i;t[a>>2]=r;if(!(t[17530]|0)){s=n;return}yAi[t[70120>>2]&511](t[f>>2]|0,t[u>>2]|0,t[a>>2]|0);s=n;return}function ug(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0;n=s;s=s+32|0;f=n;u=n+16|0;a=n+12|0;o=n+8|0;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;if(((t[u>>2]|0)!=0?(t[(t[u>>2]|0)+212>>2]|0)!=0:0)?(t[(t[u>>2]|0)+172>>2]|0)==-1:0){s=n;return}if(t[u>>2]|0)t[(t[u>>2]|0)+84>>2]=42;r=t[u>>2]|0;if(!(t[a>>2]|0)){i=t[o>>2]|0;t[f>>2]=t[o>>2];cp(0,0,0,r,0,1,42,3,0,0,i,0,0,0,0,71848,f)}else{i=t[a>>2]|0;e=t[o>>2]|0;c=t[o>>2]|0;t[f>>2]=t[a>>2];t[f+4>>2]=c;cp(0,0,0,r,0,1,42,3,0,0,i,e,0,0,0,71872,f)}if(!(t[u>>2]|0)){s=n;return}t[(t[u>>2]|0)+12>>2]=0;if(t[(t[u>>2]|0)+288>>2]|0){s=n;return}t[(t[u>>2]|0)+212>>2]=1;s=n;return}function ag(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,a=0,o=0;r=s;s=s+16|0;n=r+8|0;f=r+4|0;a=r;t[n>>2]=e;t[f>>2]=i;if((t[(t[n>>2]|0)+292>>2]|0)==0?((t[(t[(t[n>>2]|0)+36>>2]|0)+20>>2]|0)-(t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]|0)|0)<250:0)CS(t[n>>2]|0);if((u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==60?(u[(t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]|0)+1>>0]|0|0)==47:0){i=(t[n>>2]|0)+200|0;t[i>>2]=(t[i>>2]|0)+2;i=(t[(t[n>>2]|0)+36>>2]|0)+16|0;t[i>>2]=(t[i>>2]|0)+2;i=(t[(t[n>>2]|0)+36>>2]|0)+32|0;t[i>>2]=(t[i>>2]|0)+2;if((u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==37)oE(t[n>>2]|0);if((u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==0?(yp(t[(t[n>>2]|0)+36>>2]|0,250)|0)<=0:0)aE(t[n>>2]|0)|0;t[a>>2]=Fg(t[n>>2]|0,t[(t[n>>2]|0)+184>>2]|0)|0;if((t[(t[n>>2]|0)+292>>2]|0)==0?((t[(t[(t[n>>2]|0)+36>>2]|0)+20>>2]|0)-(t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]|0)|0)<250:0)CS(t[n>>2]|0);uE(t[n>>2]|0)|0;if(9<=(u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)?(u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)<=10:0)o=19;else if((u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)!=13?32>(u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0):0)o=20;else o=19;if((o|0)==19)if((u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==62){i=(t[(t[n>>2]|0)+36>>2]|0)+32|0;t[i>>2]=(t[i>>2]|0)+1;i=(t[(t[n>>2]|0)+36>>2]|0)+16|0;t[i>>2]=(t[i>>2]|0)+1;i=(t[n>>2]|0)+200|0;t[i>>2]=(t[i>>2]|0)+1;if(!(u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0))yp(t[(t[n>>2]|0)+36>>2]|0,250)|0}else o=20;if((o|0)==20)AS(t[n>>2]|0,73,0);if((t[a>>2]|0)!=1){if(!(t[a>>2]|0))t[a>>2]=70752;bg(t[n>>2]|0,76,70768,t[(t[n>>2]|0)+184>>2]|0,t[f>>2]|0,t[a>>2]|0)}if(((t[t[n>>2]>>2]|0)!=0?(t[(t[t[n>>2]>>2]|0)+60>>2]|0)!=0:0)?(t[(t[n>>2]|0)+212>>2]|0)==0:0)EAi[t[(t[t[n>>2]>>2]|0)+60>>2]&511](t[(t[n>>2]|0)+4>>2]|0,t[(t[n>>2]|0)+184>>2]|0);tE(t[n>>2]|0)|0;lg(t[n>>2]|0)|0;s=r;return}BS(t[n>>2]|0,74,71816);s=r;return}function og(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0;r=s;s=s+16|0;n=r+12|0;f=r+8|0;u=r+4|0;a=r;t[f>>2]=e;t[u>>2]=i;do if((t[(t[f>>2]|0)+236>>2]|0)>=(t[(t[f>>2]|0)+240>>2]|0)){i=(t[f>>2]|0)+240|0;t[i>>2]=t[i>>2]<<1;t[a>>2]=MAi[t[135760>>2]&511](t[(t[f>>2]|0)+244>>2]|0,t[(t[f>>2]|0)+240>>2]<<2)|0;if(t[a>>2]|0){t[(t[f>>2]|0)+244>>2]=t[a>>2];break}Sp(t[f>>2]|0,0);i=(t[f>>2]|0)+240|0;t[i>>2]=(t[i>>2]|0)/2|0;t[n>>2]=-1;o=t[n>>2]|0;s=r;return o|0}while(0);t[(t[(t[f>>2]|0)+244>>2]|0)+(t[(t[f>>2]|0)+236>>2]<<2)>>2]=t[u>>2];t[(t[f>>2]|0)+232>>2]=(t[(t[f>>2]|0)+244>>2]|0)+(t[(t[f>>2]|0)+236>>2]<<2);u=(t[f>>2]|0)+236|0;f=t[u>>2]|0;t[u>>2]=f+1;t[n>>2]=f;o=t[n>>2]|0;s=r;return o|0}function cg(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0,S=0,g=0,y=0,F=0,O=0,A=0,M=0,R=0,N=0,T=0,L=0,D=0,C=0,P=0,B=0,I=0,H=0,x=0,U=0,z=0,j=0,V=0,q=0;f=s;s=s+144|0;a=f+132|0;o=f+128|0;c=f+124|0;l=f+120|0;b=f+116|0;k=f+112|0;h=f+108|0;w=f+104|0;d=f+100|0;v=f+96|0;m=f+92|0;_=f+88|0;p=f+84|0;E=f+80|0;S=f+76|0;g=f+72|0;y=f+68|0;F=f+64|0;O=f+60|0;A=f+56|0;M=f+52|0;R=f+48|0;N=f+44|0;T=f+40|0;L=f+36|0;D=f+32|0;C=f+28|0;P=f+24|0;B=f+20|0;I=f+16|0;H=f+12|0;x=f+8|0;U=f+4|0;z=f;t[o>>2]=e;t[c>>2]=i;t[l>>2]=r;t[b>>2]=n;t[_>>2]=t[(t[o>>2]|0)+300>>2];t[p>>2]=t[(t[o>>2]|0)+304>>2];t[L>>2]=t[(t[o>>2]|0)+328>>2];if((u[t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)!=60){t[a>>2]=0;j=t[a>>2]|0;s=f;return j|0}n=(t[(t[o>>2]|0)+36>>2]|0)+32|0;t[n>>2]=(t[n>>2]|0)+1;n=(t[(t[o>>2]|0)+36>>2]|0)+16|0;t[n>>2]=(t[n>>2]|0)+1;n=(t[o>>2]|0)+200|0;t[n>>2]=(t[n>>2]|0)+1;if(!(u[t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]>>0]|0))yp(t[(t[o>>2]|0)+36>>2]|0,250)|0;e:while(1){if(((t[(t[o>>2]|0)+292>>2]|0)==0?((t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]|0)-(t[(t[(t[o>>2]|0)+36>>2]|0)+12>>2]|0)|0)>500:0)?((t[(t[(t[o>>2]|0)+36>>2]|0)+20>>2]|0)-(t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]|0)|0)<500:0)qS(t[o>>2]|0);t[N>>2]=t[(t[(t[o>>2]|0)+36>>2]|0)+12>>2];t[T>>2]=(t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]|0)-(t[(t[(t[o>>2]|0)+36>>2]|0)+12>>2]|0);t[M>>2]=t[(t[(t[o>>2]|0)+36>>2]|0)+28>>2];t[R>>2]=t[(t[(t[o>>2]|0)+36>>2]|0)+32>>2];t[S>>2]=0;t[E>>2]=0;t[g>>2]=0;t[O>>2]=0;t[A>>2]=0;t[(t[o>>2]|0)+328>>2]=t[L>>2];t[k>>2]=Og(t[o>>2]|0,h)|0;V=t[o>>2]|0;if(!(t[k>>2]|0)){q=10;break}t[t[b>>2]>>2]=(t[(t[V+36>>2]|0)+16>>2]|0)-(t[(t[(t[o>>2]|0)+36>>2]|0)+12>>2]|0)-(t[T>>2]|0);uE(t[o>>2]|0)|0;if((t[(t[o>>2]|0)+292>>2]|0)==0?((t[(t[(t[o>>2]|0)+36>>2]|0)+20>>2]|0)-(t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]|0)|0)<250:0)CS(t[o>>2]|0);i:do if((t[(t[(t[o>>2]|0)+36>>2]|0)+12>>2]|0)==(t[N>>2]|0)){r:while(1){if((u[t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==62)break e;if((u[t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==47?(u[(t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]|0)+1>>0]|0|0)==62:0)break e;if(!(9<=(u[t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)?(u[t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)<=10:0))q=20;if(((q|0)==20?(q=0,(u[t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)!=13):0)?32>(u[t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0):0)break e;if((t[(t[o>>2]|0)+172>>2]|0)==-1)break e;t[D>>2]=t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2];t[C>>2]=t[(t[(t[o>>2]|0)+36>>2]|0)+36>>2];t[P>>2]=-1;t[B>>2]=0;t[w>>2]=Ag(t[o>>2]|0,t[h>>2]|0,t[k>>2]|0,d,m,P,B)|0;if((t[(t[(t[o>>2]|0)+36>>2]|0)+12>>2]|0)!=(t[N>>2]|0))break;n:do if((t[w>>2]|0)!=0&(t[m>>2]|0)!=0){if((t[P>>2]|0)<0)t[P>>2]=rs(t[m>>2]|0)|0;if((t[d>>2]|0)==0?(t[w>>2]|0)==(t[(t[o>>2]|0)+316>>2]|0):0){t[I>>2]=kz(t[(t[o>>2]|0)+296>>2]|0,t[m>>2]|0,t[P>>2]|0)|0;if(!(t[I>>2]|0)){q=32;break e}do if(u[t[I>>2]>>0]|0){t[H>>2]=IA(t[I>>2]|0)|0;if(!(t[H>>2]|0))KS(t[o>>2]|0,99,71016,t[I>>2]|0,0,0);else{if(!(t[t[H>>2]>>2]|0))Mg(t[o>>2]|0,100,71048,t[I>>2]|0,0,0);xA(t[H>>2]|0)}if((t[I>>2]|0)==(t[(t[o>>2]|0)+320>>2]|0)){if((t[w>>2]|0)==(t[(t[o>>2]|0)+312>>2]|0))break;KS(t[o>>2]|0,200,71080,0,0,0);break}if((t[P>>2]|0)!=29){q=47;break}if(!(Xl(t[I>>2]|0,71136)|0)){q=47;break}KS(t[o>>2]|0,200,71168,0,0,0)}else q=47;while(0);do if((q|0)==47){q=0;t[F>>2]=1;while(1){if((t[F>>2]|0)>(t[O>>2]|0))break;if(!(t[(t[(t[o>>2]|0)+336>>2]|0)+((t[(t[o>>2]|0)+328>>2]|0)-(t[F>>2]<<1)<<2)>>2]|0))break;t[F>>2]=(t[F>>2]|0)+1}n=t[o>>2]|0;if((t[F>>2]|0)<=(t[O>>2]|0)){ug(n,0,t[w>>2]|0);break}if((Eg(n,0,t[I>>2]|0)|0)<=0)break;t[O>>2]=(t[O>>2]|0)+1}while(0);if(t[B>>2]|0)pAi[t[135736>>2]&511](t[m>>2]|0);if((u[t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==62)break e;if((u[t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==47?(u[(t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]|0)+1>>0]|0|0)==62:0)break e;do if((u[t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)!=32){if(9<=(u[t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)?(u[t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)<=10:0)break;if((u[t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)!=13){q=64;break e}}while(0);uE(t[o>>2]|0)|0;continue r}if((t[d>>2]|0)!=(t[(t[o>>2]|0)+316>>2]|0)){if(!((t[_>>2]|0)!=0?((t[S>>2]|0)+5|0)<=(t[p>>2]|0):0))q=108;do if((q|0)==108){q=0;if((Rg(t[o>>2]|0,(t[S>>2]|0)+5|0)|0)>=0){t[p>>2]=t[(t[o>>2]|0)+304>>2];t[_>>2]=t[(t[o>>2]|0)+300>>2];break}if(u[(t[m>>2]|0)+(t[P>>2]|0)>>0]|0)break n;pAi[t[135736>>2]&511](t[m>>2]|0);break n}while(0);n=t[B>>2]|0;r=t[E>>2]|0;t[E>>2]=r+1;t[(t[(t[o>>2]|0)+340>>2]|0)+(r<<2)>>2]=n;n=t[w>>2]|0;r=t[S>>2]|0;t[S>>2]=r+1;t[(t[_>>2]|0)+(r<<2)>>2]=n;n=t[d>>2]|0;r=t[S>>2]|0;t[S>>2]=r+1;t[(t[_>>2]|0)+(r<<2)>>2]=n;n=t[S>>2]|0;t[S>>2]=n+1;t[(t[_>>2]|0)+(n<<2)>>2]=0;n=t[m>>2]|0;r=t[S>>2]|0;t[S>>2]=r+1;t[(t[_>>2]|0)+(r<<2)>>2]=n;t[m>>2]=(t[m>>2]|0)+(t[P>>2]|0);n=t[m>>2]|0;r=t[S>>2]|0;t[S>>2]=r+1;t[(t[_>>2]|0)+(r<<2)>>2]=n;if(!(t[B>>2]|0))break;t[A>>2]=1;break}t[x>>2]=kz(t[(t[o>>2]|0)+296>>2]|0,t[m>>2]|0,t[P>>2]|0)|0;n=t[x>>2]|0;r=t[(t[o>>2]|0)+320>>2]|0;f:do if((t[w>>2]|0)==(t[(t[o>>2]|0)+312>>2]|0)){if((n|0)==(r|0))break;KS(t[o>>2]|0,200,71216,0,0,0)}else{i=t[w>>2]|0;e=t[o>>2]|0;if((n|0)==(r|0)){if((i|0)==(t[e+312>>2]|0))break;KS(t[o>>2]|0,200,71264,0,0,0);break}if((i|0)==(t[e+316>>2]|0)){KS(t[o>>2]|0,200,71312,0,0,0);break}do if((t[P>>2]|0)==29){if(!(Xl(t[x>>2]|0,71136)|0))break;KS(t[o>>2]|0,200,71168,0,0,0);break f}while(0);do if(t[x>>2]|0){if(!(u[t[x>>2]>>0]|0))break;t[U>>2]=IA(t[x>>2]|0)|0;e=t[o>>2]|0;if(!(t[U>>2]|0))KS(e,99,71408,t[w>>2]|0,t[x>>2]|0,0);else{do if(t[e+268>>2]|0){if(t[t[U>>2]>>2]|0)break;Mg(t[o>>2]|0,100,71448,t[w>>2]|0,t[x>>2]|0,0)}while(0);xA(t[U>>2]|0)}t[F>>2]=1;while(1){if((t[F>>2]|0)>(t[O>>2]|0))break;if((t[(t[(t[o>>2]|0)+336>>2]|0)+((t[(t[o>>2]|0)+328>>2]|0)-(t[F>>2]<<1)<<2)>>2]|0)==(t[w>>2]|0))break;t[F>>2]=(t[F>>2]|0)+1}e=t[o>>2]|0;if((t[F>>2]|0)<=(t[O>>2]|0)){ug(e,t[d>>2]|0,t[w>>2]|0);break f}if((Eg(e,t[w>>2]|0,t[x>>2]|0)|0)<=0)break f;t[O>>2]=(t[O>>2]|0)+1;break f}while(0);KS(t[o>>2]|0,200,71360,t[w>>2]|0,0,0)}while(0);if(t[B>>2]|0)pAi[t[135736>>2]&511](t[m>>2]|0);if((u[t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==62)break e;if((u[t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==47?(u[(t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]|0)+1>>0]|0|0)==62:0)break e;do if((u[t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)!=32){if(9<=(u[t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)?(u[t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)<=10:0)break;if((u[t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)!=13){q=104;break e}}while(0);uE(t[o>>2]|0)|0;if((t[(t[(t[o>>2]|0)+36>>2]|0)+12>>2]|0)!=(t[N>>2]|0))break i;else continue r}else if((t[m>>2]|0)!=0?(u[(t[m>>2]|0)+(t[P>>2]|0)>>0]|0|0)==0:0)pAi[t[135736>>2]&511](t[m>>2]|0);while(0);if((t[(t[o>>2]|0)+292>>2]|0)==0?((t[(t[(t[o>>2]|0)+36>>2]|0)+20>>2]|0)-(t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]|0)|0)<250:0)CS(t[o>>2]|0);if((t[(t[o>>2]|0)+172>>2]|0)==-1)break e;if((t[(t[(t[o>>2]|0)+36>>2]|0)+12>>2]|0)!=(t[N>>2]|0))break i;if((u[t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==62)break e;if((u[t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==47?(u[(t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]|0)+1>>0]|0|0)==62:0)break e;do if((u[t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)!=32){if(9<=(u[t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)?(u[t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)<=10:0)break;if((u[t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)!=13){q=129;break e}}while(0);uE(t[o>>2]|0)|0;if((t[C>>2]|0)==(t[(t[(t[o>>2]|0)+36>>2]|0)+36>>2]|0)?((t[w>>2]|0)==0?(t[D>>2]|0)==(t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]|0):0)&(t[m>>2]|0)==0:0){q=132;break e}do if(!(t[(t[o>>2]|0)+292>>2]|0)){if(((t[(t[(t[o>>2]|0)+36>>2]|0)+20>>2]|0)-(t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]|0)|0)>=250)break;CS(t[o>>2]|0)}while(0);if((t[(t[(t[o>>2]|0)+36>>2]|0)+12>>2]|0)!=(t[N>>2]|0))break i}if((t[m>>2]|0)!=0&(t[B>>2]|0)!=0)pAi[t[135736>>2]&511](t[m>>2]|0);t[m>>2]=0}while(0);i:do if(t[A>>2]|0){t[y>>2]=3;t[F>>2]=0;while(1){if((t[F>>2]|0)>=(t[E>>2]|0))break i;if((t[(t[(t[o>>2]|0)+340>>2]|0)+(t[F>>2]<<2)>>2]|0)!=0?(t[(t[_>>2]|0)+(t[y>>2]<<2)>>2]|0)!=0:0)pAi[t[135736>>2]&511](t[(t[_>>2]|0)+(t[y>>2]<<2)>>2]|0);t[y>>2]=(t[y>>2]|0)+5;t[F>>2]=(t[F>>2]|0)+1}}while(0);t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]=(t[(t[(t[o>>2]|0)+36>>2]|0)+12>>2]|0)+(t[T>>2]|0);t[(t[(t[o>>2]|0)+36>>2]|0)+28>>2]=t[M>>2];t[(t[(t[o>>2]|0)+36>>2]|0)+32>>2]=t[R>>2];if((t[(t[o>>2]|0)+12>>2]|0)!=1){q=219;break}}if((q|0)==10){BS(V,68,70952);t[a>>2]=0;j=t[a>>2]|0;s=f;return j|0}else if((q|0)==32){Sp(t[o>>2]|0,70984);if((t[m>>2]|0)!=0&(t[B>>2]|0)!=0)pAi[t[135736>>2]&511](t[m>>2]|0);t[a>>2]=0;j=t[a>>2]|0;s=f;return j|0}else if((q|0)==64)BS(t[o>>2]|0,65,69320);else if((q|0)==104)BS(t[o>>2]|0,65,69320);else if((q|0)==129)BS(t[o>>2]|0,65,69320);else if((q|0)==132)AS(t[o>>2]|0,1,69352);else if((q|0)==219){t[a>>2]=0;j=t[a>>2]|0;s=f;return j|0}e:do if((t[(t[o>>2]|0)+348>>2]|0)!=0?(t[z>>2]=fO(t[(t[o>>2]|0)+348>>2]|0,t[k>>2]|0,t[h>>2]|0)|0,(t[z>>2]|0)!=0):0){t[y>>2]=0;i:while(1){if((t[y>>2]|0)>=(t[t[z>>2]>>2]|0))break e;t[w>>2]=t[(t[z>>2]|0)+8+((t[y>>2]|0)*5<<2)>>2];t[d>>2]=t[(t[z>>2]|0)+8+(((t[y>>2]|0)*5|0)+1<<2)>>2];do if((t[d>>2]|0)==0?(t[w>>2]|0)==(t[(t[o>>2]|0)+316>>2]|0):0){t[F>>2]=1;while(1){if((t[F>>2]|0)>(t[O>>2]|0))break;if(!(t[(t[(t[o>>2]|0)+336>>2]|0)+((t[(t[o>>2]|0)+328>>2]|0)-(t[F>>2]<<1)<<2)>>2]|0))break;t[F>>2]=(t[F>>2]|0)+1}if(((t[F>>2]|0)>(t[O>>2]|0)?(t[v>>2]=pg(t[o>>2]|0,0)|0,(t[v>>2]|0)!=(t[(t[z>>2]|0)+8+(((t[y>>2]|0)*5|0)+2<<2)>>2]|0)):0)?(Eg(t[o>>2]|0,0,t[(t[z>>2]|0)+8+(((t[y>>2]|0)*5|0)+2<<2)>>2]|0)|0)>0:0)t[O>>2]=(t[O>>2]|0)+1}else{if((t[d>>2]|0)==(t[(t[o>>2]|0)+316>>2]|0)){t[F>>2]=1;while(1){if((t[F>>2]|0)>(t[O>>2]|0))break;if((t[(t[(t[o>>2]|0)+336>>2]|0)+((t[(t[o>>2]|0)+328>>2]|0)-(t[F>>2]<<1)<<2)>>2]|0)==(t[w>>2]|0))break;t[F>>2]=(t[F>>2]|0)+1}if((t[F>>2]|0)<=(t[O>>2]|0))break;t[v>>2]=pg(t[o>>2]|0,t[w>>2]|0)|0;if((t[v>>2]|0)==(t[(t[z>>2]|0)+16>>2]|0))break;if((Eg(t[o>>2]|0,t[w>>2]|0,t[(t[z>>2]|0)+8+(((t[y>>2]|0)*5|0)+2<<2)>>2]|0)|0)<=0)break;t[O>>2]=(t[O>>2]|0)+1;break}t[F>>2]=0;while(1){if((t[F>>2]|0)>=(t[S>>2]|0))break;if((t[w>>2]|0)==(t[(t[_>>2]|0)+(t[F>>2]<<2)>>2]|0)?(t[d>>2]|0)==(t[(t[_>>2]|0)+((t[F>>2]|0)+1<<2)>>2]|0):0)break;t[F>>2]=(t[F>>2]|0)+5}if((t[F>>2]|0)>=(t[S>>2]|0)){if(!((t[_>>2]|0)!=0?((t[S>>2]|0)+5|0)<=(t[p>>2]|0):0)){if((Rg(t[o>>2]|0,(t[S>>2]|0)+5|0)|0)<0)break i;t[p>>2]=t[(t[o>>2]|0)+304>>2];t[_>>2]=t[(t[o>>2]|0)+300>>2]}m=t[w>>2]|0;B=t[S>>2]|0;t[S>>2]=B+1;t[(t[_>>2]|0)+(B<<2)>>2]=m;m=t[d>>2]|0;B=t[S>>2]|0;t[S>>2]=B+1;t[(t[_>>2]|0)+(B<<2)>>2]=m;if(!(t[d>>2]|0)){m=t[S>>2]|0;t[S>>2]=m+1;t[(t[_>>2]|0)+(m<<2)>>2]=0}else{m=pg(t[o>>2]|0,t[d>>2]|0)|0;B=t[S>>2]|0;t[S>>2]=B+1;t[(t[_>>2]|0)+(B<<2)>>2]=m}m=t[(t[z>>2]|0)+8+(((t[y>>2]|0)*5|0)+2<<2)>>2]|0;B=t[S>>2]|0;t[S>>2]=B+1;t[(t[_>>2]|0)+(B<<2)>>2]=m;m=t[(t[z>>2]|0)+8+(((t[y>>2]|0)*5|0)+3<<2)>>2]|0;B=t[S>>2]|0;t[S>>2]=B+1;t[(t[_>>2]|0)+(B<<2)>>2]=m;if((t[(t[o>>2]|0)+28>>2]|0)==1?(t[(t[z>>2]|0)+8+(((t[y>>2]|0)*5|0)+4<<2)>>2]|0)!=0:0)RS(t[o>>2]|0,538,71488,t[w>>2]|0,t[k>>2]|0);t[g>>2]=(t[g>>2]|0)+1}}while(0);t[y>>2]=(t[y>>2]|0)+1}t[a>>2]=0;j=t[a>>2]|0;s=f;return j|0}while(0);t[y>>2]=0;while(1){if((t[y>>2]|0)>=(t[S>>2]|0))break;if(t[(t[_>>2]|0)+((t[y>>2]|0)+1<<2)>>2]|0){t[v>>2]=pg(t[o>>2]|0,t[(t[_>>2]|0)+((t[y>>2]|0)+1<<2)>>2]|0)|0;if(!(t[v>>2]|0))KS(t[o>>2]|0,201,71552,t[(t[_>>2]|0)+((t[y>>2]|0)+1<<2)>>2]|0,t[(t[_>>2]|0)+(t[y>>2]<<2)>>2]|0,t[k>>2]|0);t[(t[_>>2]|0)+((t[y>>2]|0)+2<<2)>>2]=t[v>>2]}else t[v>>2]=0;t[F>>2]=0;while(1){if((t[F>>2]|0)>=(t[y>>2]|0))break;if((t[(t[_>>2]|0)+(t[y>>2]<<2)>>2]|0)==(t[(t[_>>2]|0)+(t[F>>2]<<2)>>2]|0)){if((t[(t[_>>2]|0)+((t[y>>2]|0)+1<<2)>>2]|0)==(t[(t[_>>2]|0)+((t[F>>2]|0)+1<<2)>>2]|0)){q=189;break}if((t[v>>2]|0)!=0?(t[(t[_>>2]|0)+((t[F>>2]|0)+2<<2)>>2]|0)==(t[v>>2]|0):0){q=192;break}}t[F>>2]=(t[F>>2]|0)+5}if((q|0)==189){q=0;ug(t[o>>2]|0,t[(t[_>>2]|0)+((t[y>>2]|0)+1<<2)>>2]|0,t[(t[_>>2]|0)+(t[y>>2]<<2)>>2]|0)}else if((q|0)==192){q=0;KS(t[o>>2]|0,203,71608,t[(t[_>>2]|0)+(t[y>>2]<<2)>>2]|0,t[v>>2]|0,0)}t[y>>2]=(t[y>>2]|0)+5}t[v>>2]=pg(t[o>>2]|0,t[h>>2]|0)|0;if((t[h>>2]|0)!=0&(t[v>>2]|0)==0)KS(t[o>>2]|0,201,71656,t[h>>2]|0,t[k>>2]|0,0);t[t[c>>2]>>2]=t[h>>2];t[t[l>>2]>>2]=t[v>>2];do if(((t[t[o>>2]>>2]|0)!=0?(t[(t[t[o>>2]>>2]|0)+116>>2]|0)!=0:0)?(t[(t[o>>2]|0)+212>>2]|0)==0:0){l=t[(t[t[o>>2]>>2]|0)+116>>2]|0;c=t[(t[o>>2]|0)+4>>2]|0;q=t[k>>2]|0;w=t[h>>2]|0;z=t[v>>2]|0;if((t[O>>2]|0)>0){FAi[l&511](c,q,w,z,t[O>>2]|0,(t[(t[o>>2]|0)+336>>2]|0)+((t[(t[o>>2]|0)+328>>2]|0)-(t[O>>2]<<1)<<2)|0,(t[S>>2]|0)/5|0,t[g>>2]|0,t[_>>2]|0);break}else{FAi[l&511](c,q,w,z,0,0,(t[S>>2]|0)/5|0,t[g>>2]|0,t[_>>2]|0);break}}while(0);e:do if(t[A>>2]|0){t[y>>2]=3;t[F>>2]=0;while(1){if((t[F>>2]|0)>=(t[E>>2]|0))break e;if((t[(t[(t[o>>2]|0)+340>>2]|0)+(t[F>>2]<<2)>>2]|0)!=0?(t[(t[_>>2]|0)+(t[y>>2]<<2)>>2]|0)!=0:0)pAi[t[135736>>2]&511](t[(t[_>>2]|0)+(t[y>>2]<<2)>>2]|0);t[y>>2]=(t[y>>2]|0)+5;t[F>>2]=(t[F>>2]|0)+1}}while(0);t[a>>2]=t[k>>2];j=t[a>>2]|0;s=f;return j|0}function lg(e){e=e|0;var i=0,r=0,n=0,f=0,u=0;i=s;s=s+16|0;r=i+8|0;n=i+4|0;f=i;t[n>>2]=e;if((t[(t[n>>2]|0)+236>>2]|0)<=0){t[r>>2]=0;u=t[r>>2]|0;s=i;return u|0}e=(t[n>>2]|0)+236|0;t[e>>2]=(t[e>>2]|0)+-1;e=t[n>>2]|0;if((t[(t[n>>2]|0)+236>>2]|0)>0)t[(t[n>>2]|0)+232>>2]=(t[(t[n>>2]|0)+244>>2]|0)+((t[e+236>>2]|0)-1<<2);else t[(t[n>>2]|0)+232>>2]=t[e+244>>2];t[f>>2]=t[(t[(t[n>>2]|0)+244>>2]|0)+(t[(t[n>>2]|0)+236>>2]<<2)>>2];t[(t[(t[n>>2]|0)+244>>2]|0)+(t[(t[n>>2]|0)+236>>2]<<2)>>2]=-1;t[r>>2]=t[f>>2];u=t[r>>2]|0;s=i;return u|0}function sg(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0;r=s;s=s+32|0;n=r;f=r+16|0;u=r+12|0;a=r+8|0;o=r+4|0;t[u>>2]=e;t[a>>2]=i;if(!(t[(t[u>>2]|0)+336>>2]|0)){t[f>>2]=0;c=t[f>>2]|0;s=r;return c|0}if((t[(t[u>>2]|0)+328>>2]|0)<(t[a>>2]|0)){i=t[33976]|0;e=t[33980]|0;t[n>>2]=t[a>>2];yAi[i&511](e,70928,n);t[a>>2]=t[(t[u>>2]|0)+328>>2]}if((t[(t[u>>2]|0)+328>>2]|0)<=0){t[f>>2]=0;c=t[f>>2]|0;s=r;return c|0}t[o>>2]=0;while(1){if((t[o>>2]|0)>=(t[a>>2]|0))break;n=(t[u>>2]|0)+328|0;t[n>>2]=(t[n>>2]|0)+-1;t[(t[(t[u>>2]|0)+336>>2]|0)+(t[(t[u>>2]|0)+328>>2]<<2)>>2]=0;t[o>>2]=(t[o>>2]|0)+1}t[f>>2]=t[a>>2];c=t[f>>2]|0;s=r;return c|0}function bg(e,i,r,n,f,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;u=u|0;var a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0;a=s;s=s+48|0;o=a;c=a+32|0;l=a+28|0;b=a+24|0;k=a+20|0;h=a+16|0;w=a+12|0;t[c>>2]=e;t[l>>2]=i;t[b>>2]=r;t[k>>2]=n;t[h>>2]=f;t[w>>2]=u;if(((t[c>>2]|0)!=0?(t[(t[c>>2]|0)+212>>2]|0)!=0:0)?(t[(t[c>>2]|0)+172>>2]|0)==-1:0){s=a;return}if(t[c>>2]|0)t[(t[c>>2]|0)+84>>2]=t[l>>2];u=t[c>>2]|0;f=t[l>>2]|0;l=t[k>>2]|0;n=t[w>>2]|0;r=t[h>>2]|0;i=t[b>>2]|0;b=t[h>>2]|0;h=t[w>>2]|0;t[o>>2]=t[k>>2];t[o+4>>2]=b;t[o+8>>2]=h;cp(0,0,0,u,0,1,f,3,0,0,l,n,0,r,0,i,o);if(!(t[c>>2]|0)){s=a;return}t[(t[c>>2]|0)+12>>2]=0;if(t[(t[c>>2]|0)+288>>2]|0){s=a;return}t[(t[c>>2]|0)+212>>2]=1;s=a;return}function kg(e,i,r,n,f,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;o=o|0;var c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0;c=s;s=s+32|0;l=c+24|0;b=c+20|0;k=c+16|0;h=c+12|0;w=c+8|0;d=c+4|0;v=c;t[l>>2]=e;t[b>>2]=i;t[k>>2]=r;t[h>>2]=n;t[w>>2]=f;t[d>>2]=o;if((t[(t[l>>2]|0)+292>>2]|0)==0?((t[(t[(t[l>>2]|0)+36>>2]|0)+20>>2]|0)-(t[(t[(t[l>>2]|0)+36>>2]|0)+16>>2]|0)|0)<250:0)CS(t[l>>2]|0);
	if((u[t[(t[(t[l>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==60?(u[(t[(t[(t[l>>2]|0)+36>>2]|0)+16>>2]|0)+1>>0]|0|0)==47:0){o=(t[l>>2]|0)+200|0;t[o>>2]=(t[o>>2]|0)+2;o=(t[(t[l>>2]|0)+36>>2]|0)+16|0;t[o>>2]=(t[o>>2]|0)+2;o=(t[(t[l>>2]|0)+36>>2]|0)+32|0;t[o>>2]=(t[o>>2]|0)+2;if((u[t[(t[(t[l>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==37)oE(t[l>>2]|0);if((u[t[(t[(t[l>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==0?(yp(t[(t[l>>2]|0)+36>>2]|0,250)|0)<=0:0)aE(t[l>>2]|0)|0;do if((t[d>>2]|0)>0?(Jl(t[(t[(t[l>>2]|0)+36>>2]|0)+16>>2]|0,t[(t[l>>2]|0)+184>>2]|0,t[d>>2]|0)|0)==0:0){o=t[d>>2]|0;if((u[(t[(t[(t[l>>2]|0)+36>>2]|0)+16>>2]|0)+(t[d>>2]|0)>>0]|0|0)==62){f=(t[(t[l>>2]|0)+36>>2]|0)+16|0;t[f>>2]=(t[f>>2]|0)+(o+1);f=(t[(t[l>>2]|0)+36>>2]|0)+32|0;t[f>>2]=(t[f>>2]|0)+((t[d>>2]|0)+1);break}else{f=(t[(t[l>>2]|0)+36>>2]|0)+16|0;t[f>>2]=(t[f>>2]|0)+o;o=(t[(t[l>>2]|0)+36>>2]|0)+32|0;t[o>>2]=(t[o>>2]|0)+(t[d>>2]|0);t[v>>2]=1;m=20;break}}else m=17;while(0);do if((m|0)==17){d=t[l>>2]|0;o=t[(t[l>>2]|0)+184>>2]|0;if(!(t[b>>2]|0)){t[v>>2]=Fg(d,o)|0;m=20;break}else{t[v>>2]=Ng(d,o,t[b>>2]|0)|0;m=20;break}}while(0);if((m|0)==20){if((t[(t[l>>2]|0)+292>>2]|0)==0?((t[(t[(t[l>>2]|0)+36>>2]|0)+20>>2]|0)-(t[(t[(t[l>>2]|0)+36>>2]|0)+16>>2]|0)|0)<250:0)CS(t[l>>2]|0);if((t[(t[l>>2]|0)+172>>2]|0)==-1){s=c;return}uE(t[l>>2]|0)|0;if(9<=(u[t[(t[(t[l>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)?(u[t[(t[(t[l>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)<=10:0)m=28;else if((u[t[(t[(t[l>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)!=13?32>(u[t[(t[(t[l>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0):0)m=29;else m=28;if((m|0)==28)if((u[t[(t[(t[l>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==62){o=(t[(t[l>>2]|0)+36>>2]|0)+32|0;t[o>>2]=(t[o>>2]|0)+1;o=(t[(t[l>>2]|0)+36>>2]|0)+16|0;t[o>>2]=(t[o>>2]|0)+1;o=(t[l>>2]|0)+200|0;t[o>>2]=(t[o>>2]|0)+1;if(!(u[t[(t[(t[l>>2]|0)+36>>2]|0)+16>>2]>>0]|0))yp(t[(t[l>>2]|0)+36>>2]|0,250)|0}else m=29;if((m|0)==29)AS(t[l>>2]|0,73,0);if((t[v>>2]|0)!=1){if(!(t[v>>2]|0))t[v>>2]=70752;if((t[h>>2]|0)==0?(t[(t[l>>2]|0)+52>>2]|0)!=0:0)t[h>>2]=a[(t[(t[l>>2]|0)+52>>2]|0)+56>>1];bg(t[l>>2]|0,76,70768,t[(t[l>>2]|0)+184>>2]|0,t[h>>2]|0,t[v>>2]|0)}}if(((t[t[l>>2]>>2]|0)!=0?(t[(t[t[l>>2]>>2]|0)+120>>2]|0)!=0:0)?(t[(t[l>>2]|0)+212>>2]|0)==0:0)NAi[t[(t[t[l>>2]>>2]|0)+120>>2]&511](t[(t[l>>2]|0)+4>>2]|0,t[(t[l>>2]|0)+184>>2]|0,t[b>>2]|0,t[k>>2]|0);lg(t[l>>2]|0)|0;if(!(t[w>>2]|0)){s=c;return}sg(t[l>>2]|0,t[w>>2]|0)|0;s=c;return}AS(t[l>>2]|0,74,0);s=c;return}function hg(e){e=e|0;var i=0,r=0,n=0,f=0,a=0,o=0,c=0,l=0;i=s;s=s+16|0;r=i+8|0;n=i+4|0;f=i;t[r>>2]=e;if((u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==91){t[(t[r>>2]|0)+172>>2]=3;Op(t[r>>2]|0);while(1){if((u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==93)break;if((t[(t[r>>2]|0)+172>>2]|0)==-1)break;t[n>>2]=t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2];t[f>>2]=t[(t[(t[r>>2]|0)+36>>2]|0)+36>>2];uE(t[r>>2]|0)|0;IE(t[r>>2]|0);HE(t[r>>2]|0);while(1){if(!(u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0))a=(t[(t[r>>2]|0)+40>>2]|0)>1;else a=0;o=t[r>>2]|0;if(!a)break;aE(o)|0}if((t[(t[o+36>>2]|0)+16>>2]|0)!=(t[n>>2]|0))continue;if((t[f>>2]|0)==(t[(t[(t[r>>2]|0)+36>>2]|0)+36>>2]|0)){c=12;break}}if((c|0)==12)AS(t[r>>2]|0,1,70688);if((u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==93){Op(t[r>>2]|0);uE(t[r>>2]|0)|0}}if((u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==62){l=t[r>>2]|0;Op(l);s=i;return}AS(t[r>>2]|0,61,0);l=t[r>>2]|0;Op(l);s=i;return}function wg(e){e=e|0;var i=0,r=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if(!(t[(t[r>>2]|0)+352>>2]|0)){s=i;return}oO(t[(t[r>>2]|0)+352>>2]|0,228,t[r>>2]|0);if(bO(t[(t[r>>2]|0)+352>>2]|0)|0){s=i;return}XF(t[(t[r>>2]|0)+352>>2]|0,0);t[(t[r>>2]|0)+352>>2]=0;s=i;return}function dg(e,i){e=e|0;i=i|0;var r=0,f=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0,S=0,g=0,y=0,F=0,O=0,A=0,M=0,R=0,N=0,T=0,L=0,D=0,C=0,P=0,B=0,I=0,H=0,x=0,U=0,z=0,j=0,V=0,q=0,Y=0,G=0,W=0,K=0,X=0;r=s;s=s+288|0;f=r;a=r+124|0;o=r+120|0;c=r+116|0;l=r+112|0;b=r+108|0;k=r+104|0;h=r+285|0;w=r+284|0;d=r+100|0;v=r+96|0;m=r+92|0;_=r+88|0;p=r+280|0;E=r+84|0;S=r+80|0;g=r+76|0;y=r+72|0;F=r+68|0;O=r+64|0;A=r+60|0;M=r+56|0;R=r+52|0;N=r+48|0;T=r+44|0;L=r+40|0;D=r+36|0;C=r+32|0;P=r+28|0;B=r+24|0;I=r+278|0;H=r+20|0;x=r+16|0;U=r+128|0;t[o>>2]=e;t[c>>2]=i;t[l>>2]=0;if(!(t[(t[o>>2]|0)+36>>2]|0)){t[a>>2]=0;z=t[a>>2]|0;s=r;return z|0}if((t[(t[o>>2]|0)+36>>2]|0)!=0?((t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]|0)-(t[(t[(t[o>>2]|0)+36>>2]|0)+12>>2]|0)|0)>4096:0){qS(t[o>>2]|0);t[(t[o>>2]|0)+204>>2]=0}Lg(t[o>>2]|0,d,v);e:while(1){if((t[(t[o>>2]|0)+172>>2]|0)==-1){j=407;break}if((t[(t[o>>2]|0)+84>>2]|0)!=0?(t[(t[o>>2]|0)+212>>2]|0)==1:0){j=10;break}while(1){if(!(u[t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]>>0]|0))V=(t[(t[o>>2]|0)+40>>2]|0)>1;else V=0;q=t[o>>2]|0;if(!V)break;aE(q)|0}if(!(t[q+36>>2]|0)){j=407;break}i=t[o>>2]|0;if(!(t[t[(t[o>>2]|0)+36>>2]>>2]|0))t[b>>2]=(t[(t[i+36>>2]|0)+24>>2]|0)-((t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]|0)-(t[(t[(t[o>>2]|0)+36>>2]|0)+12>>2]|0));else{if(((t[i+172>>2]|0)!=0?(t[(t[t[(t[o>>2]|0)+36>>2]>>2]|0)+20>>2]|0)!=0:0)?(Ds(t[(t[t[(t[o>>2]|0)+36>>2]>>2]|0)+20>>2]|0)|0)==0:0){t[m>>2]=js(t[(t[t[(t[o>>2]|0)+36>>2]>>2]|0)+16>>2]|0,t[(t[o>>2]|0)+36>>2]|0)|0;t[_>>2]=(t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]|0)-(t[(t[(t[o>>2]|0)+36>>2]|0)+12>>2]|0);ZO(t[t[(t[o>>2]|0)+36>>2]>>2]|0,0,65640)|0;Vs(t[(t[t[(t[o>>2]|0)+36>>2]>>2]|0)+16>>2]|0,t[(t[o>>2]|0)+36>>2]|0,t[m>>2]|0,t[_>>2]|0)|0}i=Ts(t[(t[t[(t[o>>2]|0)+36>>2]>>2]|0)+16>>2]|0)|0;t[b>>2]=i-((t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]|0)-(t[(t[(t[o>>2]|0)+36>>2]|0)+12>>2]|0))}if((t[b>>2]|0)<1){j=407;break}do switch(t[(t[o>>2]|0)+172>>2]|0){case 1:{uE(t[o>>2]|0)|0;i=t[(t[o>>2]|0)+36>>2]|0;if(!(t[t[(t[o>>2]|0)+36>>2]>>2]|0))t[b>>2]=(t[i+24>>2]|0)-((t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]|0)-(t[(t[(t[o>>2]|0)+36>>2]|0)+12>>2]|0));else{e=Ts(t[(t[i>>2]|0)+16>>2]|0)|0;t[b>>2]=e-((t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]|0)-(t[(t[(t[o>>2]|0)+36>>2]|0)+12>>2]|0))}if((t[b>>2]|0)<2){j=407;break e}n[h>>0]=n[t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]>>0]|0;n[w>>0]=n[(t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]|0)+1>>0]|0;if((u[h>>0]|0|0)==60?(u[w>>0]|0|0)==63:0){if((t[c>>2]|0)==0?(Dg(t[o>>2]|0,63,62,0)|0)<0:0){j=265;break e}FE(t[o>>2]|0);if((t[(t[o>>2]|0)+172>>2]|0)==-1){j=407;break e}t[(t[o>>2]|0)+172>>2]=1;t[(t[o>>2]|0)+292>>2]=1;t[(t[o>>2]|0)+204>>2]=0;continue e}if((((u[h>>0]|0|0)==60?(u[w>>0]|0|0)==33:0)?(u[(t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]|0)+2>>0]|0|0)==45:0)?(u[(t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]|0)+3>>0]|0|0)==45:0){if((t[c>>2]|0)==0?(Dg(t[o>>2]|0,45,45,62)|0)<0:0){j=274;break e}gE(t[o>>2]|0);if((t[(t[o>>2]|0)+172>>2]|0)==-1){j=407;break e}t[(t[o>>2]|0)+172>>2]=1;t[(t[o>>2]|0)+292>>2]=1;t[(t[o>>2]|0)+204>>2]=0;continue e}do if((((((u[h>>0]|0|0)==60?(u[w>>0]|0|0)==33:0)?(u[(t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]|0)+2>>0]|0|0)==68:0)?(u[(t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]|0)+3>>0]|0|0)==79:0)?(u[(t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]|0)+4>>0]|0|0)==67:0)?(u[(t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]|0)+5>>0]|0|0)==84:0){if((u[(t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]|0)+6>>0]|0|0)!=89)break;if((u[(t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]|0)+7>>0]|0|0)!=80)break;if((u[(t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]|0)+8>>0]|0|0)!=69)break;if((t[c>>2]|0)==0?(Dg(t[o>>2]|0,62,0,0)|0)<0:0){j=288;break e}t[(t[o>>2]|0)+216>>2]=1;t[(t[o>>2]|0)+292>>2]=0;t[(t[o>>2]|0)+204>>2]=0;qE(t[o>>2]|0);if((t[(t[o>>2]|0)+172>>2]|0)==-1){j=407;break e}e=t[o>>2]|0;if((u[t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==91){t[e+172>>2]=3;continue e}t[e+216>>2]=2;do if(t[t[o>>2]>>2]|0){if(t[(t[o>>2]|0)+212>>2]|0)break;if(!(t[(t[t[o>>2]>>2]|0)+104>>2]|0))break;NAi[t[(t[t[o>>2]>>2]|0)+104>>2]&511](t[(t[o>>2]|0)+4>>2]|0,t[(t[o>>2]|0)+220>>2]|0,t[(t[o>>2]|0)+228>>2]|0,t[(t[o>>2]|0)+224>>2]|0)}while(0);t[(t[o>>2]|0)+216>>2]=0;wg(t[o>>2]|0);t[(t[o>>2]|0)+172>>2]=4;continue e}while(0);if((u[h>>0]|0|0)==60?(u[w>>0]|0|0)==33&(t[b>>2]|0)<9:0){j=407;break e}t[(t[o>>2]|0)+172>>2]=6;t[(t[o>>2]|0)+292>>2]=6;Lg(t[o>>2]|0,d,v);continue e;break}case 9:{if((t[b>>2]|0)<2){j=407;break e}do if(!(t[c>>2]|0)){if(!(t[(t[o>>2]|0)+292>>2]|0))if((Dg(t[o>>2]|0,62,0,0)|0)<0){j=407;break e}else break;if(!(t[v>>2]|0)){j=407;break e}if((t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]|0)>>>0>=(t[v>>2]|0)>>>0){j=407;break e}}while(0);e=t[o>>2]|0;if(t[(t[o>>2]|0)+324>>2]|0){kg(e,t[(t[(t[o>>2]|0)+344>>2]|0)+(((t[(t[o>>2]|0)+188>>2]|0)*3|0)-3<<2)>>2]|0,t[(t[(t[o>>2]|0)+344>>2]|0)+(((t[(t[o>>2]|0)+188>>2]|0)*3|0)-2<<2)>>2]|0,0,t[(t[(t[o>>2]|0)+344>>2]|0)+(((t[(t[o>>2]|0)+188>>2]|0)*3|0)-1<<2)>>2]|0,0);Pg(t[o>>2]|0)|0}else ag(e,0);if((t[(t[o>>2]|0)+172>>2]|0)==-1)continue e;e=(t[o>>2]|0)+172|0;if(!(t[(t[o>>2]|0)+188>>2]|0)){t[e>>2]=14;continue e}else{t[e>>2]=7;continue e}break}case 8:{t[R>>2]=Dg(t[o>>2]|0,93,93,62)|0;if((t[R>>2]|0)<0){j=207;break e}t[L>>2]=Bg(t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]|0,t[R>>2]|0)|0;if((t[L>>2]|0)<0){j=231;break e}if((t[L>>2]|0)!=(t[R>>2]|0)){j=231;break e}if((((t[R>>2]|0)==0?(t[t[o>>2]>>2]|0)!=0:0)?(t[(t[t[o>>2]>>2]|0)+100>>2]|0)!=0:0)?(t[(t[o>>2]|0)+212>>2]|0)==0:0){if(((t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]|0)-(t[(t[(t[o>>2]|0)+36>>2]|0)+12>>2]|0)|0)>=9?(RY((t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]|0)+-9|0,70176,9)|0)==0:0)yAi[t[(t[t[o>>2]>>2]|0)+100>>2]&511](t[(t[o>>2]|0)+4>>2]|0,65640,0)}else j=238;do if(((j|0)==238?(j=0,(t[R>>2]|0)>0?(t[t[o>>2]>>2]|0)!=0:0):0)?(t[(t[o>>2]|0)+212>>2]|0)==0:0){e=t[t[o>>2]>>2]|0;if(t[(t[t[o>>2]>>2]|0)+100>>2]|0){yAi[t[e+100>>2]&511](t[(t[o>>2]|0)+4>>2]|0,t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]|0,t[R>>2]|0);break}if(t[e+68>>2]|0)yAi[t[(t[t[o>>2]>>2]|0)+68>>2]&511](t[(t[o>>2]|0)+4>>2]|0,t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]|0,t[R>>2]|0)}while(0);if((t[(t[o>>2]|0)+172>>2]|0)==-1){j=407;break e}t[D>>2]=0;while(1){Y=u[t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]>>0]|0;if((t[D>>2]|0)>=((t[R>>2]|0)+3|0))break;e=t[(t[o>>2]|0)+36>>2]|0;if((Y|0)==10){i=e+28|0;t[i>>2]=(t[i>>2]|0)+1;t[(t[(t[o>>2]|0)+36>>2]|0)+32>>2]=1}else{i=e+32|0;t[i>>2]=(t[i>>2]|0)+1}i=(t[o>>2]|0)+200|0;t[i>>2]=(t[i>>2]|0)+1;i=(t[(t[o>>2]|0)+36>>2]|0)+16|0;t[i>>2]=(t[i>>2]|0)+1;t[D>>2]=(t[D>>2]|0)+1}if((Y|0)==37)oE(t[o>>2]|0);if((u[t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==0?(yp(t[(t[o>>2]|0)+36>>2]|0,250)|0)<=0:0)aE(t[o>>2]|0)|0;t[(t[o>>2]|0)+204>>2]=0;t[(t[o>>2]|0)+172>>2]=7;continue e;break}case 0:{i=t[b>>2]|0;if(!(t[(t[o>>2]|0)+256>>2]|0)){if((i|0)<4){j=407;break e}n[p>>0]=n[t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]>>0]|0;n[p+1>>0]=n[(t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]|0)+1>>0]|0;n[p+2>>0]=n[(t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]|0)+2>>0]|0;n[p+3>>0]=n[(t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]|0)+3>>0]|0;t[E>>2]=L_(p,4)|0;Tp(t[o>>2]|0,t[E>>2]|0)|0;continue e}if((i|0)<2){j=407;break e}n[h>>0]=n[t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]>>0]|0;n[w>>0]=n[(t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]|0)+1>>0]|0;if(!(u[h>>0]|0)){j=30;break e}if((u[h>>0]|0|0)==60?(u[w>>0]|0|0)==63:0){if((t[b>>2]|0)<5){j=39;break e}if((t[c>>2]|0)==0?(Dg(t[o>>2]|0,63,62,0)|0)<0:0){j=42;break e}if((t[t[o>>2]>>2]|0)!=0?(t[(t[t[o>>2]>>2]|0)+44>>2]|0)!=0:0)EAi[t[(t[t[o>>2]>>2]|0)+44>>2]&511](t[(t[o>>2]|0)+4>>2]|0,136080);i:do if((u[(t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]|0)+2>>0]|0|0)==120){if((u[(t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]|0)+3>>0]|0|0)!=109)break;if((u[(t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]|0)+4>>0]|0|0)!=108)break;do if((u[(t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]|0)+5>>0]|0|0)!=32){if(9<=(u[(t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]|0)+5>>0]|0|0)?(u[(t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]|0)+5>>0]|0|0)<=10:0)break;if((u[(t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]|0)+5>>0]|0|0)!=13)break i}while(0);t[l>>2]=(t[l>>2]|0)+5;$E(t[o>>2]|0);G=t[o>>2]|0;if((t[(t[o>>2]|0)+84>>2]|0)==32){j=54;break e}t[(t[o>>2]|0)+28>>2]=t[(t[G+36>>2]|0)+52>>2];do if(!(t[(t[o>>2]|0)+24>>2]|0)){if(!(t[(t[(t[o>>2]|0)+36>>2]|0)+44>>2]|0))break;i=Yl(t[(t[(t[o>>2]|0)+36>>2]|0)+44>>2]|0)|0;t[(t[o>>2]|0)+24>>2]=i}while(0);do if(t[t[o>>2]>>2]|0){if(!(t[(t[t[o>>2]>>2]|0)+48>>2]|0))break;if(t[(t[o>>2]|0)+212>>2]|0)break;pAi[t[(t[t[o>>2]>>2]|0)+48>>2]&511](t[(t[o>>2]|0)+4>>2]|0)}while(0);t[(t[o>>2]|0)+172>>2]=1;continue e}while(0);i=Wl(68488)|0;t[(t[o>>2]|0)+20>>2]=i;do if(t[t[o>>2]>>2]|0){if(!(t[(t[t[o>>2]>>2]|0)+48>>2]|0))break;if(t[(t[o>>2]|0)+212>>2]|0)break;pAi[t[(t[t[o>>2]>>2]|0)+48>>2]&511](t[(t[o>>2]|0)+4>>2]|0)}while(0);t[(t[o>>2]|0)+172>>2]=1;continue e}if((t[t[o>>2]>>2]|0)!=0?(t[(t[t[o>>2]>>2]|0)+44>>2]|0)!=0:0)EAi[t[(t[t[o>>2]>>2]|0)+44>>2]&511](t[(t[o>>2]|0)+4>>2]|0,136080);i=Wl(68488)|0;t[(t[o>>2]|0)+20>>2]=i;i=t[o>>2]|0;if(!(t[(t[o>>2]|0)+20>>2]|0)){Sp(i,0);continue e}if(((t[i>>2]|0)!=0?(t[(t[t[o>>2]>>2]|0)+48>>2]|0)!=0:0)?(t[(t[o>>2]|0)+212>>2]|0)==0:0)pAi[t[(t[t[o>>2]>>2]|0)+48>>2]&511](t[(t[o>>2]|0)+4>>2]|0);t[(t[o>>2]|0)+172>>2]=1;continue e;break}case 7:{if((t[b>>2]|0)<2?(t[(t[o>>2]|0)+40>>2]|0)==1:0){j=407;break e}n[h>>0]=n[t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]>>0]|0;n[w>>0]=n[(t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]|0)+1>>0]|0;t[O>>2]=t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2];t[A>>2]=t[(t[(t[o>>2]|0)+36>>2]|0)+36>>2];if((u[h>>0]|0|0)==60?(u[w>>0]|0|0)==47:0){t[(t[o>>2]|0)+172>>2]=9;continue e}if((u[h>>0]|0|0)==60?(u[w>>0]|0|0)==63:0){if((t[c>>2]|0)==0?(Dg(t[o>>2]|0,63,62,0)|0)<0:0){j=147;break e}FE(t[o>>2]|0);t[(t[o>>2]|0)+172>>2]=7;t[(t[o>>2]|0)+292>>2]=1}else j=149;do if((j|0)==149){j=0;if((u[h>>0]|0|0)==60?(u[w>>0]|0|0)!=33:0){t[(t[o>>2]|0)+172>>2]=6;continue e}if((((u[h>>0]|0|0)==60?(u[w>>0]|0|0)==33:0)?(u[(t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]|0)+2>>0]|0|0)==45:0)?(u[(t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]|0)+3>>0]|0|0)==45:0){if((t[b>>2]|0)<4){j=407;break e}i=(t[(t[o>>2]|0)+36>>2]|0)+16|0;t[i>>2]=(t[i>>2]|0)+4;t[M>>2]=Dg(t[o>>2]|0,45,45,62)|0;i=(t[(t[o>>2]|0)+36>>2]|0)+16|0;t[i>>2]=(t[i>>2]|0)+-4;W=t[o>>2]|0;if((t[c>>2]|0)==0&(t[M>>2]|0)<0){j=158;break e}gE(W);t[(t[o>>2]|0)+172>>2]=7;t[(t[o>>2]|0)+292>>2]=1;break}do if((((u[h>>0]|0|0)==60?(u[(t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]|0)+1>>0]|0|0)==33:0)?(u[(t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]|0)+2>>0]|0|0)==91:0)?(u[(t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]|0)+3>>0]|0|0)==67:0){if((u[(t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]|0)+4>>0]|0|0)!=68)break;if((u[(t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]|0)+5>>0]|0|0)!=65)break;if((u[(t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]|0)+6>>0]|0|0)!=84)break;if((u[(t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]|0)+7>>0]|0|0)!=65)break;if((u[(t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]|0)+8>>0]|0|0)!=91)break;i=(t[o>>2]|0)+200|0;t[i>>2]=(t[i>>2]|0)+9;i=(t[(t[o>>2]|0)+36>>2]|0)+16|0;t[i>>2]=(t[i>>2]|0)+9;i=(t[(t[o>>2]|0)+36>>2]|0)+32|0;t[i>>2]=(t[i>>2]|0)+9;if((u[t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==37)oE(t[o>>2]|0);do if(!(u[t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]>>0]|0)){if((yp(t[(t[o>>2]|0)+36>>2]|0,250)|0)>0)break;aE(t[o>>2]|0)|0}while(0);t[(t[o>>2]|0)+172>>2]=8;continue e}while(0);if((u[h>>0]|0|0)==60?(u[w>>0]|0|0)==33&(t[b>>2]|0)<9:0){j=407;break e}if((u[h>>0]|0|0)==38){if((t[c>>2]|0)==0?(Dg(t[o>>2]|0,59,0,0)|0)<0:0){j=407;break e}jE(t[o>>2]|0);break}do if(!(((t[b>>2]|0)<300?(t[(t[o>>2]|0)+40>>2]|0)==1:0)^1|(t[c>>2]|0)!=0)){if(!(t[(t[o>>2]|0)+292>>2]|0))if((Dg(t[o>>2]|0,60,0,0)|0)<0){j=407;break e}else break;if(!(t[d>>2]|0)){j=407;break e}if((t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]|0)>>>0>(t[d>>2]|0)>>>0){j=407;break e}}while(0);t[(t[o>>2]|0)+204>>2]=0;EE(t[o>>2]|0,0)}while(0);while(1){if(u[t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]>>0]|0)break;if((t[(t[o>>2]|0)+40>>2]|0)<=1)break;aE(t[o>>2]|0)|0}if((t[A>>2]|0)!=(t[(t[(t[o>>2]|0)+36>>2]|0)+36>>2]|0))continue e;if((t[O>>2]|0)!=(t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]|0))continue e;AS(t[o>>2]|0,1,69472);t[(t[o>>2]|0)+172>>2]=-1;continue e;break}case 6:{t[g>>2]=0;t[y>>2]=0;t[F>>2]=t[(t[o>>2]|0)+328>>2];if((t[b>>2]|0)<2?(t[(t[o>>2]|0)+40>>2]|0)==1:0){j=407;break e}n[h>>0]=n[t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]>>0]|0;if((u[h>>0]|0|0)!=60){j=81;break e}do if(!(t[c>>2]|0)){if(!(t[(t[o>>2]|0)+292>>2]|0))if((Dg(t[o>>2]|0,62,0,0)|0)<0){j=407;break e}else break;if(!(t[v>>2]|0)){j=407;break e}if((t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]|0)>>>0>=(t[v>>2]|0)>>>0){j=407;break e}}while(0);i=t[o>>2]|0;do if(t[(t[o>>2]|0)+236>>2]|0){e=t[o>>2]|0;if((t[t[i+232>>2]>>2]|0)==-2){og(e,-1)|0;break}else{og(e,t[t[(t[o>>2]|0)+232>>2]>>2]|0)|0;break}}else og(i,-1)|0;while(0);i=t[o>>2]|0;if(t[(t[o>>2]|0)+324>>2]|0)t[S>>2]=cg(i,g,y,k)|0;else t[S>>2]=GE(i)|0;if((t[(t[o>>2]|0)+172>>2]|0)==-1){j=407;break e}K=t[o>>2]|0;if(!(t[S>>2]|0)){j=99;break e}do if(((t[K+104>>2]|0)!=0?(t[(t[o>>2]|0)+12>>2]|0)!=0:0)?(t[(t[o>>2]|0)+8>>2]|0)!=0:0){if(!(t[(t[o>>2]|0)+52>>2]|0))break;if((t[(t[o>>2]|0)+52>>2]|0)!=(t[(t[(t[o>>2]|0)+8>>2]|0)+12>>2]|0))break;i=kR((t[o>>2]|0)+108|0,t[(t[o>>2]|0)+8>>2]|0)|0;e=(t[o>>2]|0)+100|0;t[e>>2]=t[e>>2]&i}while(0);if((u[t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==47?(u[(t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]|0)+1>>0]|0|0)==62:0){i=(t[o>>2]|0)+200|0;t[i>>2]=(t[i>>2]|0)+2;i=(t[(t[o>>2]|0)+36>>2]|0)+16|0;t[i>>2]=(t[i>>2]|0)+2;i=(t[(t[o>>2]|0)+36>>2]|0)+32|0;t[i>>2]=(t[i>>2]|0)+2;if((u[t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==37)oE(t[o>>2]|0);do if(!(u[t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]>>0]|0)){if((yp(t[(t[o>>2]|0)+36>>2]|0,250)|0)>0)break;aE(t[o>>2]|0)|0}while(0);i=(t[t[o>>2]>>2]|0)!=0;do if(t[(t[o>>2]|0)+324>>2]|0){do if(i){if(!(t[(t[t[o>>2]>>2]|0)+120>>2]|0))break;if(t[(t[o>>2]|0)+212>>2]|0)break;NAi[t[(t[t[o>>2]>>2]|0)+120>>2]&511](t[(t[o>>2]|0)+4>>2]|0,t[S>>2]|0,t[g>>2]|0,t[y>>2]|0)}while(0);if(((t[(t[o>>2]|0)+328>>2]|0)-(t[F>>2]|0)|0)<=0)break;sg(t[o>>2]|0,(t[(t[o>>2]|0)+328>>2]|0)-(t[F>>2]|0)|0)|0}else{if(!i)break;if(!(t[(t[t[o>>2]>>2]|0)+60>>2]|0))break;if(t[(t[o>>2]|0)+212>>2]|0)break;EAi[t[(t[t[o>>2]>>2]|0)+60>>2]&511](t[(t[o>>2]|0)+4>>2]|0,t[S>>2]|0)}while(0);if((t[(t[o>>2]|0)+172>>2]|0)==-1){j=407;break e}lg(t[o>>2]|0)|0;i=(t[o>>2]|0)+172|0;if(!(t[(t[o>>2]|0)+188>>2]|0))t[i>>2]=14;else t[i>>2]=7;t[(t[o>>2]|0)+292>>2]=1;continue e}i=t[o>>2]|0;if((u[t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==62)Op(i);else{MS(i,73,70136,t[S>>2]|0);nE(t[o>>2]|0)|0;lg(t[o>>2]|0)|0}i=t[o>>2]|0;e=t[S>>2]|0;if(t[(t[o>>2]|0)+324>>2]|0)Cg(i,e,t[g>>2]|0,t[y>>2]|0,(t[(t[o>>2]|0)+328>>2]|0)-(t[F>>2]|0)|0)|0;else fE(i,e)|0;t[(t[o>>2]|0)+172>>2]=7;t[(t[o>>2]|0)+292>>2]=1;continue e;break}case 4:{uE(t[o>>2]|0)|0;e=t[(t[o>>2]|0)+36>>2]|0;if(!(t[t[(t[o>>2]|0)+36>>2]>>2]|0))t[b>>2]=(t[e+24>>2]|0)-((t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]|0)-(t[(t[(t[o>>2]|0)+36>>2]|0)+12>>2]|0));else{i=Ts(t[(t[e>>2]|0)+16>>2]|0)|0;t[b>>2]=i-((t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]|0)-(t[(t[(t[o>>2]|0)+36>>2]|0)+12>>2]|0))}if((t[b>>2]|0)<2){j=407;break e}n[h>>0]=n[t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]>>0]|0;n[w>>0]=n[(t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]|0)+1>>0]|0;if((u[h>>0]|0|0)==60?(u[w>>0]|0|0)==63:0){if((t[c>>2]|0)==0?(Dg(t[o>>2]|0,63,62,0)|0)<0:0){j=308;break e}FE(t[o>>2]|0);if((t[(t[o>>2]|0)+172>>2]|0)==-1){j=407;break e}t[(t[o>>2]|0)+172>>2]=4;t[(t[o>>2]|0)+292>>2]=1;continue e}if((((u[h>>0]|0|0)==60?(u[w>>0]|0|0)==33:0)?(u[(t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]|0)+2>>0]|0|0)==45:0)?(u[(t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]|0)+3>>0]|0|0)==45:0){if((t[c>>2]|0)==0?(Dg(t[o>>2]|0,45,45,62)|0)<0:0){j=317;break e}gE(t[o>>2]|0);if((t[(t[o>>2]|0)+172>>2]|0)==-1){j=407;break e}t[(t[o>>2]|0)+172>>2]=4;t[(t[o>>2]|0)+292>>2]=1;continue e}if((u[h>>0]|0|0)==60?(u[w>>0]|0|0)==33&(t[b>>2]|0)<4:0){j=407;break e}t[(t[o>>2]|0)+172>>2]=6;if(!(t[(t[o>>2]|0)+292>>2]|0))t[(t[o>>2]|0)+292>>2]=6;Lg(t[o>>2]|0,d,v);continue e;break}case 14:{uE(t[o>>2]|0)|0;i=t[(t[o>>2]|0)+36>>2]|0;if(!(t[t[(t[o>>2]|0)+36>>2]>>2]|0))t[b>>2]=(t[i+24>>2]|0)-((t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]|0)-(t[(t[(t[o>>2]|0)+36>>2]|0)+12>>2]|0));else{e=Ts(t[(t[i>>2]|0)+16>>2]|0)|0;t[b>>2]=e-((t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]|0)-(t[(t[(t[o>>2]|0)+36>>2]|0)+12>>2]|0))}if((t[b>>2]|0)<2){j=407;break e}n[h>>0]=n[t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]>>0]|0;n[w>>0]=n[(t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]|0)+1>>0]|0;if((u[h>>0]|0|0)==60?(u[w>>0]|0|0)==63:0){if((t[c>>2]|0)==0?(Dg(t[o>>2]|0,63,62,0)|0)<0:0){j=333;break e}FE(t[o>>2]|0);if((t[(t[o>>2]|0)+172>>2]|0)==-1){j=407;break e}t[(t[o>>2]|0)+172>>2]=14;t[(t[o>>2]|0)+292>>2]=1;continue e}if((u[h>>0]|0|0)!=60){j=345;break e}if((u[w>>0]|0|0)!=33){j=345;break e}if((u[(t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]|0)+2>>0]|0|0)!=45){j=345;break e}if((u[(t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]|0)+3>>0]|0|0)!=45){j=345;break e}if((t[c>>2]|0)==0?(Dg(t[o>>2]|0,45,45,62)|0)<0:0){j=342;break e}gE(t[o>>2]|0);if((t[(t[o>>2]|0)+172>>2]|0)==-1){j=407;break e}t[(t[o>>2]|0)+172>>2]=14;t[(t[o>>2]|0)+292>>2]=1;continue e;break}case 3:{n[I>>0]=0;t[C>>2]=(t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]|0)-(t[(t[(t[o>>2]|0)+36>>2]|0)+12>>2]|0);if((t[C>>2]|0)<0){j=351;break e}if((t[(t[o>>2]|0)+204>>2]|0)>(t[C>>2]|0))t[C>>2]=t[(t[o>>2]|0)+204>>2];t[B>>2]=Os(t[(t[t[(t[o>>2]|0)+36>>2]>>2]|0)+16>>2]|0)|0;t[H>>2]=Ts(t[(t[t[(t[o>>2]|0)+36>>2]>>2]|0)+16>>2]|0)|0;i:while(1){if((t[C>>2]|0)>>>0>=(t[H>>2]|0)>>>0){j=389;break e}r:do if(u[I>>0]|0){if((u[(t[B>>2]|0)+(t[C>>2]|0)>>0]|0|0)==(u[I>>0]|0|0))n[I>>0]=0}else{do if((((u[I>>0]|0|0)==0?(u[(t[B>>2]|0)+(t[C>>2]|0)>>0]|0|0)==60:0)?(t[x>>2]=0,((t[C>>2]|0)+4|0)>>>0<(t[H>>2]|0)>>>0):0)?(u[(t[B>>2]|0)+((t[C>>2]|0)+1)>>0]|0|0)==33:0){if((u[(t[B>>2]|0)+((t[C>>2]|0)+2)>>0]|0|0)!=45)break;if((u[(t[B>>2]|0)+((t[C>>2]|0)+3)>>0]|0|0)!=45)break;n:while(1){if(((t[C>>2]|0)+3|0)>>>0>=(t[H>>2]|0)>>>0)break;do if((u[(t[B>>2]|0)+(t[C>>2]|0)>>0]|0|0)==45){if((u[(t[B>>2]|0)+((t[C>>2]|0)+1)>>0]|0|0)!=45)break;if((u[(t[B>>2]|0)+((t[C>>2]|0)+2)>>0]|0|0)==62){j=369;break n}}while(0);t[C>>2]=(t[C>>2]|0)+1}if((j|0)==369){j=0;t[x>>2]=1;t[C>>2]=(t[C>>2]|0)+2}if(t[x>>2]|0)break r;else{j=389;break e}}while(0);if((u[(t[B>>2]|0)+(t[C>>2]|0)>>0]|0|0)==34){n[I>>0]=34;break}if((u[(t[B>>2]|0)+(t[C>>2]|0)>>0]|0|0)==39){n[I>>0]=39;break}if((u[(t[B>>2]|0)+(t[C>>2]|0)>>0]|0|0)==93){if(((t[C>>2]|0)+1|0)>>>0>=(t[H>>2]|0)>>>0){j=389;break e}if((u[(t[B>>2]|0)+((t[C>>2]|0)+1)>>0]|0|0)==93){t[C>>2]=(t[C>>2]|0)+1;break}t[P>>2]=1;while(1){if(((t[C>>2]|0)+(t[P>>2]|0)|0)>>>0>=(t[H>>2]|0)>>>0){j=389;break e}if((u[(t[B>>2]|0)+((t[C>>2]|0)+(t[P>>2]|0))>>0]|0|0)==62)break i;do if((u[(t[B>>2]|0)+((t[C>>2]|0)+(t[P>>2]|0))>>0]|0|0)!=32){if(9<=(u[(t[B>>2]|0)+((t[C>>2]|0)+(t[P>>2]|0))>>0]|0|0)?(u[(t[B>>2]|0)+((t[C>>2]|0)+(t[P>>2]|0))>>0]|0|0)<=10:0)break;if((u[(t[B>>2]|0)+((t[C>>2]|0)+(t[P>>2]|0))>>0]|0|0)!=13)break r}while(0);t[P>>2]=(t[P>>2]|0)+1}}}while(0);t[C>>2]=(t[C>>2]|0)+1}t[(t[o>>2]|0)+204>>2]=0;hg(t[o>>2]|0);if((t[(t[o>>2]|0)+172>>2]|0)==-1){j=407;break e}t[(t[o>>2]|0)+216>>2]=2;if(((t[t[o>>2]>>2]|0)!=0?(t[(t[o>>2]|0)+212>>2]|0)==0:0)?(t[(t[t[o>>2]>>2]|0)+104>>2]|0)!=0:0)NAi[t[(t[t[o>>2]>>2]|0)+104>>2]&511](t[(t[o>>2]|0)+4>>2]|0,t[(t[o>>2]|0)+220>>2]|0,t[(t[o>>2]|0)+228>>2]|0,t[(t[o>>2]|0)+224>>2]|0);t[(t[o>>2]|0)+216>>2]=0;wg(t[o>>2]|0);if((t[(t[o>>2]|0)+172>>2]|0)==-1){j=407;break e}t[(t[o>>2]|0)+172>>2]=4;t[(t[o>>2]|0)+204>>2]=0;continue e;break}case 5:{yAi[t[135904>>2]&511](t[33980]|0,70192,f);t[(t[o>>2]|0)+172>>2]=7;continue e;break}case 15:{yAi[t[135904>>2]&511](t[33980]|0,70232,f);t[(t[o>>2]|0)+172>>2]=3;continue e;break}case 2:{yAi[t[135904>>2]&511](t[33980]|0,70272,f);t[(t[o>>2]|0)+172>>2]=7;continue e;break}case 10:{yAi[t[135904>>2]&511](t[33980]|0,70312,f);t[(t[o>>2]|0)+172>>2]=3;continue e;break}case 11:{yAi[t[135904>>2]&511](t[33980]|0,70360,f);t[(t[o>>2]|0)+172>>2]=7;continue e;break}case 12:{yAi[t[135904>>2]&511](t[33980]|0,70408,f);t[(t[o>>2]|0)+172>>2]=6;continue e;break}case 13:{yAi[t[135904>>2]&511](t[33980]|0,70456,f);t[(t[o>>2]|0)+172>>2]=6;continue e;break}case 16:{yAi[t[135904>>2]&511](t[33980]|0,70504,f);t[(t[o>>2]|0)+172>>2]=6;continue e;break}case-1:{j=407;break e;break}default:continue e}while(0)}switch(j|0){case 10:{t[a>>2]=0;z=t[a>>2]|0;s=r;return z|0}case 30:{if((t[t[o>>2]>>2]|0)!=0?(t[(t[t[o>>2]>>2]|0)+44>>2]|0)!=0:0)EAi[t[(t[t[o>>2]>>2]|0)+44>>2]&511](t[(t[o>>2]|0)+4>>2]|0,136080);AS(t[o>>2]|0,4,0);t[(t[o>>2]|0)+172>>2]=-1;if((t[t[o>>2]>>2]|0)!=0?(t[(t[t[o>>2]>>2]|0)+52>>2]|0)!=0:0){pAi[t[(t[t[o>>2]>>2]|0)+52>>2]&511](t[(t[o>>2]|0)+4>>2]|0);j=407}else j=407;break}case 39:{t[a>>2]=t[l>>2];z=t[a>>2]|0;s=r;return z|0}case 42:{t[a>>2]=t[l>>2];z=t[a>>2]|0;s=r;return z|0}case 54:{t[G+172>>2]=-1;t[a>>2]=0;z=t[a>>2]|0;s=r;return z|0}case 81:{AS(t[o>>2]|0,4,0);t[(t[o>>2]|0)+172>>2]=-1;if((t[t[o>>2]>>2]|0)!=0?(t[(t[t[o>>2]>>2]|0)+52>>2]|0)!=0:0){pAi[t[(t[t[o>>2]>>2]|0)+52>>2]&511](t[(t[o>>2]|0)+4>>2]|0);j=407}else j=407;break}case 99:{lg(K)|0;t[(t[o>>2]|0)+172>>2]=-1;if((t[t[o>>2]>>2]|0)!=0?(t[(t[t[o>>2]>>2]|0)+52>>2]|0)!=0:0){pAi[t[(t[t[o>>2]>>2]|0)+52>>2]&511](t[(t[o>>2]|0)+4>>2]|0);j=407}else j=407;break}case 147:{t[(t[o>>2]|0)+292>>2]=2;j=407;break}case 158:{t[W+292>>2]=5;j=407;break}case 207:{if((t[b>>2]|0)>=302){t[N>>2]=Bg(t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]|0,300)|0;if((t[N>>2]|0)<0){t[N>>2]=0-(t[N>>2]|0);W=(t[(t[o>>2]|0)+36>>2]|0)+16|0;t[W>>2]=(t[W>>2]|0)+(t[N>>2]|0);j=408;break}do if((t[t[o>>2]>>2]|0)!=0?(t[(t[o>>2]|0)+212>>2]|0)==0:0){W=t[t[o>>2]>>2]|0;if(t[(t[t[o>>2]>>2]|0)+100>>2]|0){yAi[t[W+100>>2]&511](t[(t[o>>2]|0)+4>>2]|0,t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]|0,t[N>>2]|0);break}if(t[W+68>>2]|0)yAi[t[(t[t[o>>2]>>2]|0)+68>>2]&511](t[(t[o>>2]|0)+4>>2]|0,t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]|0,t[N>>2]|0)}while(0);if((t[(t[o>>2]|0)+172>>2]|0)!=-1){t[T>>2]=0;while(1){X=u[t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]>>0]|0;if((t[T>>2]|0)>=(t[N>>2]|0))break;W=t[(t[o>>2]|0)+36>>2]|0;if((X|0)==10){K=W+28|0;t[K>>2]=(t[K>>2]|0)+1;t[(t[(t[o>>2]|0)+36>>2]|0)+32>>2]=1}else{K=W+32|0;t[K>>2]=(t[K>>2]|0)+1}K=(t[o>>2]|0)+200|0;t[K>>2]=(t[K>>2]|0)+1;K=(t[(t[o>>2]|0)+36>>2]|0)+16|0;t[K>>2]=(t[K>>2]|0)+1;t[T>>2]=(t[T>>2]|0)+1}if((X|0)==37)oE(t[o>>2]|0);if((u[t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==0?(yp(t[(t[o>>2]|0)+36>>2]|0,250)|0)<=0:0)aE(t[o>>2]|0)|0;t[(t[o>>2]|0)+204>>2]=0;j=407}else j=407}else j=407;break}case 231:{t[L>>2]=0-(t[L>>2]|0);X=(t[(t[o>>2]|0)+36>>2]|0)+16|0;t[X>>2]=(t[X>>2]|0)+(t[L>>2]|0);j=408;break}case 265:{t[(t[o>>2]|0)+292>>2]=2;j=407;break}case 274:{t[(t[o>>2]|0)+292>>2]=5;j=407;break}case 288:{t[(t[o>>2]|0)+292>>2]=3;j=407;break}case 308:{t[(t[o>>2]|0)+292>>2]=2;j=407;break}case 317:{t[(t[o>>2]|0)+292>>2]=5;j=407;break}case 333:{t[(t[o>>2]|0)+292>>2]=2;j=407;break}case 342:{t[(t[o>>2]|0)+292>>2]=5;j=407;break}case 345:{if((u[h>>0]|0|0)==60?(u[w>>0]|0|0)==33&(t[b>>2]|0)<4:0){j=407;break}AS(t[o>>2]|0,5,0);t[(t[o>>2]|0)+172>>2]=-1;if((t[t[o>>2]>>2]|0)!=0?(t[(t[t[o>>2]>>2]|0)+52>>2]|0)!=0:0){pAi[t[(t[t[o>>2]>>2]|0)+52>>2]&511](t[(t[o>>2]|0)+4>>2]|0);j=407}else j=407;break}case 351:{t[a>>2]=0;z=t[a>>2]|0;s=r;return z|0}case 389:{if(!(u[I>>0]|0)){t[(t[o>>2]|0)+204>>2]=t[C>>2];j=407;break}else{t[(t[o>>2]|0)+204>>2]=0;j=407;break}break}}if((j|0)==407){t[a>>2]=t[l>>2];z=t[a>>2]|0;s=r;return z|0}else if((j|0)==408){j=u[(t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]|0)+1>>0]|0;l=u[(t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]|0)+2>>0]|0;C=u[(t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]|0)+3>>0]|0;t[f>>2]=u[t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]>>0];t[f+4>>2]=j;t[f+8>>2]=l;t[f+12>>2]=C;SY(U,149,70552,f)|0;gp(t[o>>2]|0,9,70592,U,0);t[a>>2]=0;z=t[a>>2]|0;s=r;return z|0}return 0}function vg(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0;n=s;s=s+16|0;f=n+12|0;u=n+8|0;a=n+4|0;o=n;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;do if(!((t[u>>2]|0)==0|(t[a>>2]|0)==0|(t[o>>2]|0)<0)){if((t[(t[u>>2]|0)+172>>2]|0)==6)if(OY(t[a>>2]|0,62,t[o>>2]|0)|0){t[f>>2]=1;break}else{t[f>>2]=0;break}if((t[(t[u>>2]|0)+292>>2]|0)==5)if(OY(t[a>>2]|0,62,t[o>>2]|0)|0){t[f>>2]=1;break}else{t[f>>2]=0;break}if((t[(t[u>>2]|0)+172>>2]|0)==8)if(OY(t[a>>2]|0,62,t[o>>2]|0)|0){t[f>>2]=1;break}else{t[f>>2]=0;break}if((t[(t[u>>2]|0)+292>>2]|0)==2)if(OY(t[a>>2]|0,62,t[o>>2]|0)|0){t[f>>2]=1;break}else{t[f>>2]=0;break}if((t[(t[u>>2]|0)+172>>2]|0)==9)if(OY(t[a>>2]|0,62,t[o>>2]|0)|0){t[f>>2]=1;break}else{t[f>>2]=0;break}if((t[(t[u>>2]|0)+292>>2]|0)!=3?(t[(t[u>>2]|0)+172>>2]|0)!=3:0){t[f>>2]=1;break}if(OY(t[a>>2]|0,62,t[o>>2]|0)|0){t[f>>2]=1;break}else{t[f>>2]=0;break}}else t[f>>2]=-1;while(0);s=n;return t[f>>2]|0}function mg(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0;f=s;s=s+48|0;u=f+32|0;a=f+28|0;o=f+24|0;c=f+20|0;l=f+16|0;b=f+12|0;k=f+8|0;h=f+4|0;w=f;t[a>>2]=e;t[o>>2]=i;t[c>>2]=r;t[l>>2]=n;t[h>>2]=0;t[b>>2]=zp()|0;if(!(t[b>>2]|0)){t[u>>2]=0;d=t[u>>2]|0;s=f;return d|0}if(t[l>>2]|0){t[(t[b>>2]|0)+360>>2]=t[(t[l>>2]|0)+360>>2];t[(t[b>>2]|0)+272>>2]=t[(t[l>>2]|0)+272>>2]}t[w>>2]=GA(t[a>>2]|0,t[c>>2]|0)|0;if(!(t[w>>2]|0)){t[k>>2]=uA(t[a>>2]|0,t[o>>2]|0,t[b>>2]|0)|0;c=t[b>>2]|0;if(!(t[k>>2]|0)){Up(c);t[u>>2]=0;d=t[u>>2]|0;s=f;return d|0}eE(c,t[k>>2]|0)|0;if((t[h>>2]|0)==0?(t[(t[b>>2]|0)+180>>2]|0)==0:0)t[h>>2]=rA(t[a>>2]|0)|0;if((t[h>>2]|0)!=0?(t[(t[b>>2]|0)+180>>2]|0)==0:0)t[(t[b>>2]|0)+180>>2]=t[h>>2]}else{t[k>>2]=uA(t[w>>2]|0,t[o>>2]|0,t[b>>2]|0)|0;if(!(t[k>>2]|0)){pAi[t[135736>>2]&511](t[w>>2]|0);Up(t[b>>2]|0);t[u>>2]=0;d=t[u>>2]|0;s=f;return d|0}eE(t[b>>2]|0,t[k>>2]|0)|0;if((t[h>>2]|0)==0?(t[(t[b>>2]|0)+180>>2]|0)==0:0)t[h>>2]=rA(t[w>>2]|0)|0;if((t[h>>2]|0)!=0?(t[(t[b>>2]|0)+180>>2]|0)==0:0)t[(t[b>>2]|0)+180>>2]=t[h>>2];pAi[t[135736>>2]&511](t[w>>2]|0)}t[u>>2]=t[b>>2];d=t[u>>2]|0;s=f;return d|0}function _g(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0;n=s;s=s+16|0;f=n+12|0;u=n+8|0;a=n+4|0;o=n;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;if(!(t[u>>2]|0)){t[f>>2]=-1;c=t[f>>2]|0;s=n;return c|0}if(t[o>>2]|0){if(t[(t[u>>2]|0)+24>>2]|0)pAi[t[135736>>2]&511](t[(t[u>>2]|0)+24>>2]|0);r=Yl(t[o>>2]|0)|0;t[(t[u>>2]|0)+24>>2]=r}r=(t[u>>2]|0)+288|0;if(t[a>>2]&1){t[r>>2]=1;t[a>>2]=(t[a>>2]|0)-1;o=(t[u>>2]|0)+360|0;t[o>>2]=t[o>>2]|1}else t[r>>2]=0;r=(t[u>>2]|0)+276|0;if(t[a>>2]&4){t[r>>2]=2;t[a>>2]=(t[a>>2]|0)-4;o=(t[u>>2]|0)+360|0;t[o>>2]=t[o>>2]|4}else t[r>>2]=0;if(t[a>>2]&8){r=(t[u>>2]|0)+276|0;t[r>>2]=t[r>>2]|4;t[a>>2]=(t[a>>2]|0)-8;r=(t[u>>2]|0)+360|0;t[r>>2]=t[r>>2]|8}r=(t[u>>2]|0)+16|0;if(t[a>>2]&2){t[r>>2]=1;t[a>>2]=(t[a>>2]|0)-2;o=(t[u>>2]|0)+360|0;t[o>>2]=t[o>>2]|2}else t[r>>2]=0;r=(t[u>>2]|0)+268|0;if(t[a>>2]&128){t[r>>2]=1;t[a>>2]=(t[a>>2]|0)-128;o=(t[u>>2]|0)+360|0;t[o>>2]=t[o>>2]|128}else t[r>>2]=0;r=(t[u>>2]|0)+208|0;if(t[a>>2]&256){t[r>>2]=0;t[(t[t[u>>2]>>2]|0)+72>>2]=65;t[a>>2]=(t[a>>2]|0)-256;o=(t[u>>2]|0)+360|0;t[o>>2]=t[o>>2]|256}else t[r>>2]=1;r=(t[u>>2]|0)+104|0;if(t[a>>2]&16){t[r>>2]=1;if(t[a>>2]&64)t[(t[u>>2]|0)+116>>2]=0;if(t[a>>2]&32)t[(t[u>>2]|0)+112>>2]=0;t[a>>2]=(t[a>>2]|0)-16;o=(t[u>>2]|0)+360|0;t[o>>2]=t[o>>2]|16}else t[r>>2]=0;if(t[a>>2]&64){t[(t[t[u>>2]>>2]|0)+84>>2]=0;t[a>>2]=(t[a>>2]|0)-64}if(t[a>>2]&32){t[(t[t[u>>2]>>2]|0)+88>>2]=0;t[(t[t[u>>2]>>2]|0)+92>>2]=0;t[a>>2]=(t[a>>2]|0)-32}if(t[a>>2]&512){t[(t[t[u>>2]>>2]|0)+56>>2]=50;t[(t[t[u>>2]>>2]|0)+60>>2]=51;t[(t[t[u>>2]>>2]|0)+116>>2]=0;t[(t[t[u>>2]>>2]|0)+120>>2]=0;t[(t[t[u>>2]>>2]|0)+108>>2]=1;t[a>>2]=(t[a>>2]|0)-512;r=(t[u>>2]|0)+360|0;t[r>>2]=t[r>>2]|512}r=(t[u>>2]|0)+364|0;if(t[a>>2]&4096){t[r>>2]=0;t[a>>2]=(t[a>>2]|0)-4096;o=(t[u>>2]|0)+360|0;t[o>>2]=t[o>>2]|4096}else t[r>>2]=1;if(t[a>>2]&16384){t[(t[t[u>>2]>>2]|0)+100>>2]=0;t[a>>2]=(t[a>>2]|0)-16384;r=(t[u>>2]|0)+360|0;t[r>>2]=t[r>>2]|16384}if(t[a>>2]&8192){r=(t[u>>2]|0)+360|0;t[r>>2]=t[r>>2]|8192;t[a>>2]=(t[a>>2]|0)-8192}if(t[a>>2]&2048){r=(t[u>>2]|0)+360|0;t[r>>2]=t[r>>2]|2048;t[a>>2]=(t[a>>2]|0)-2048}if(t[a>>2]&65536){r=(t[u>>2]|0)+360|0;t[r>>2]=t[r>>2]|65536;t[a>>2]=(t[a>>2]|0)-65536}if(t[a>>2]&131072){r=(t[u>>2]|0)+360|0;t[r>>2]=t[r>>2]|131072;t[a>>2]=(t[a>>2]|0)-131072}if(t[a>>2]&262144){r=(t[u>>2]|0)+360|0;t[r>>2]=t[r>>2]|262144;t[a>>2]=(t[a>>2]|0)-262144}do if(t[a>>2]&524288){r=(t[u>>2]|0)+360|0;t[r>>2]=t[r>>2]|524288;t[a>>2]=(t[a>>2]|0)-524288;if(!(t[(t[u>>2]|0)+296>>2]|0))break;dz(t[(t[u>>2]|0)+296>>2]|0,0)|0}while(0);if(t[a>>2]&1048576){r=(t[u>>2]|0)+360|0;t[r>>2]=t[r>>2]|1048576;t[a>>2]=(t[a>>2]|0)-1048576}if(t[a>>2]&2097152){r=(t[u>>2]|0)+360|0;t[r>>2]=t[r>>2]|2097152;t[a>>2]=(t[a>>2]|0)-2097152}if(t[a>>2]&4194304){r=(t[u>>2]|0)+360|0;t[r>>2]=t[r>>2]|4194304;t[a>>2]=(t[a>>2]|0)-4194304}t[(t[u>>2]|0)+280>>2]=1;t[f>>2]=t[a>>2];c=t[f>>2]|0;s=n;return c|0}function pg(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,a=0,o=0,c=0,l=0;r=s;s=s+16|0;n=r+12|0;f=r+8|0;a=r+4|0;o=r;t[f>>2]=e;t[a>>2]=i;i=t[f>>2]|0;if((t[a>>2]|0)==(t[(t[f>>2]|0)+312>>2]|0)){t[n>>2]=t[i+320>>2];c=t[n>>2]|0;s=r;return c|0}t[o>>2]=(t[i+328>>2]|0)-2;while(1){if((t[o>>2]|0)<0){l=11;break}if((t[(t[(t[f>>2]|0)+336>>2]|0)+(t[o>>2]<<2)>>2]|0)==(t[a>>2]|0))break;t[o>>2]=(t[o>>2]|0)-2}if((l|0)==11){t[n>>2]=0;c=t[n>>2]|0;s=r;return c|0}if((t[a>>2]|0)==0?(u[t[(t[(t[f>>2]|0)+336>>2]|0)+((t[o>>2]|0)+1<<2)>>2]>>0]|0|0)==0:0){t[n>>2]=0;c=t[n>>2]|0;s=r;return c|0}t[n>>2]=t[(t[(t[f>>2]|0)+336>>2]|0)+((t[o>>2]|0)+1<<2)>>2];
	c=t[n>>2]|0;s=r;return c|0}function Eg(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0;n=s;s=s+32|0;f=n+20|0;u=n+16|0;a=n+12|0;o=n+8|0;c=n+4|0;l=n;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;e:do if(t[(t[u>>2]|0)+360>>2]&8192){t[c>>2]=(t[(t[u>>2]|0)+328>>2]|0)-2;while(1){if((t[c>>2]|0)<0)break e;b=t[c>>2]|0;if((t[(t[(t[u>>2]|0)+336>>2]|0)+(t[c>>2]<<2)>>2]|0)==(t[a>>2]|0))break;t[c>>2]=b-2}if((t[(t[(t[u>>2]|0)+336>>2]|0)+(b+1<<2)>>2]|0)==(t[o>>2]|0)){t[f>>2]=-2;k=t[f>>2]|0;s=n;return k|0}}while(0);do if((t[(t[u>>2]|0)+332>>2]|0)!=0?(t[(t[u>>2]|0)+336>>2]|0)!=0:0){if((t[(t[u>>2]|0)+328>>2]|0)>=(t[(t[u>>2]|0)+332>>2]|0)){b=(t[u>>2]|0)+332|0;t[b>>2]=t[b>>2]<<1;t[l>>2]=MAi[t[135760>>2]&511](t[(t[u>>2]|0)+336>>2]|0,t[(t[u>>2]|0)+332>>2]<<2)|0;if(t[l>>2]|0){t[(t[u>>2]|0)+336>>2]=t[l>>2];break}Sp(t[u>>2]|0,0);b=(t[u>>2]|0)+332|0;t[b>>2]=(t[b>>2]|0)/2|0;t[f>>2]=-1;k=t[f>>2]|0;s=n;return k|0}}else h=10;while(0);if((h|0)==10?(t[(t[u>>2]|0)+332>>2]=10,t[(t[u>>2]|0)+328>>2]=0,h=gAi[t[135744>>2]&511](t[(t[u>>2]|0)+332>>2]<<2)|0,t[(t[u>>2]|0)+336>>2]=h,(t[(t[u>>2]|0)+336>>2]|0)==0):0){Sp(t[u>>2]|0,0);t[(t[u>>2]|0)+332>>2]=0;t[f>>2]=-1;k=t[f>>2]|0;s=n;return k|0}h=t[a>>2]|0;a=(t[u>>2]|0)+328|0;l=t[a>>2]|0;t[a>>2]=l+1;t[(t[(t[u>>2]|0)+336>>2]|0)+(l<<2)>>2]=h;h=t[o>>2]|0;o=(t[u>>2]|0)+328|0;l=t[o>>2]|0;t[o>>2]=l+1;t[(t[(t[u>>2]|0)+336>>2]|0)+(l<<2)>>2]=h;t[f>>2]=t[(t[u>>2]|0)+328>>2];k=t[f>>2]|0;s=n;return k|0}function Sg(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;var u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0;u=s;s=s+32|0;a=u+24|0;o=u+20|0;c=u+16|0;l=u+12|0;b=u+8|0;k=u+4|0;h=u;t[a>>2]=e;t[o>>2]=i;t[c>>2]=r;t[l>>2]=n;t[b>>2]=f;_g(t[a>>2]|0,t[l>>2]|0,t[c>>2]|0)|0;if((t[c>>2]|0)!=0?(t[h>>2]=V_(t[c>>2]|0)|0,(t[h>>2]|0)!=0):0)Lp(t[a>>2]|0,t[h>>2]|0)|0;if(((t[o>>2]|0)!=0?(t[(t[a>>2]|0)+36>>2]|0)!=0:0)?(t[(t[(t[a>>2]|0)+36>>2]|0)+4>>2]|0)==0:0){h=Yl(t[o>>2]|0)|0;t[(t[(t[a>>2]|0)+36>>2]|0)+4>>2]=h}iS(t[a>>2]|0)|0;if((t[(t[a>>2]|0)+12>>2]|0)==0?(t[(t[a>>2]|0)+288>>2]|0)==0:0){t[k>>2]=0;if(t[(t[a>>2]|0)+8>>2]|0)fy(t[(t[a>>2]|0)+8>>2]|0)}else t[k>>2]=t[(t[a>>2]|0)+8>>2];t[(t[a>>2]|0)+8>>2]=0;if(t[b>>2]|0){w=t[k>>2]|0;s=u;return w|0}Up(t[a>>2]|0);w=t[k>>2]|0;s=u;return w|0}function gg(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0;r=s;s=s+16|0;n=r+8|0;f=r+4|0;u=r;t[f>>2]=e;t[u>>2]=i;i=t[u>>2]|0;e:do if(!(t[(t[f>>2]|0)+360>>2]&131072)){if((i|0)!=32&(t[u>>2]|0)!=62&(t[u>>2]|0)!=47){if(((((((((((((!((t[u>>2]|0)>=97&(t[u>>2]|0)<=122)?!((t[u>>2]|0)>=65&(t[u>>2]|0)<=90|(t[u>>2]|0)==95|(t[u>>2]|0)==58):0)?!((t[u>>2]|0)>=192&(t[u>>2]|0)<=214):0)?!((t[u>>2]|0)>=216&(t[u>>2]|0)<=246):0)?!((t[u>>2]|0)>=248&(t[u>>2]|0)<=767):0)?!((t[u>>2]|0)>=880&(t[u>>2]|0)<=893):0)?!((t[u>>2]|0)>=895&(t[u>>2]|0)<=8191):0)?!((t[u>>2]|0)>=8204&(t[u>>2]|0)<=8205):0)?!((t[u>>2]|0)>=8304&(t[u>>2]|0)<=8591):0)?!((t[u>>2]|0)>=11264&(t[u>>2]|0)<=12271):0)?!((t[u>>2]|0)>=12289&(t[u>>2]|0)<=55295):0)?!((t[u>>2]|0)>=63744&(t[u>>2]|0)<=64975):0)?!((t[u>>2]|0)>=65008&(t[u>>2]|0)<=65533):0)?!((t[u>>2]|0)>=65536&(t[u>>2]|0)<=983039):0)break;t[n>>2]=1;a=t[n>>2]|0;s=r;return a|0}}else{e=t[u>>2]|0;if((i|0)<256){if(((!(65<=(e|0)&(t[u>>2]|0)<=90)?!(97<=(t[u>>2]|0)&(t[u>>2]|0)<=122):0)?!(192<=(t[u>>2]|0)&(t[u>>2]|0)<=214):0)?!(216<=(t[u>>2]|0)&(t[u>>2]|0)<=246|248<=(t[u>>2]|0)):0)o=24}else if(!(dj(e,199744)|0))o=24;do if((o|0)==24){e=t[u>>2]|0;if((t[u>>2]|0)<256)if((e|0)==95|(t[u>>2]|0)==58)break;else break e;if(!(19968<=(e|0)&(t[u>>2]|0)<=40869|(t[u>>2]|0)==12295)?!(12321<=(t[u>>2]|0)&(t[u>>2]|0)<=12329|(t[u>>2]|0)==95|(t[u>>2]|0)==58):0)break e}while(0);t[n>>2]=1;a=t[n>>2]|0;s=r;return a|0}while(0);t[n>>2]=0;a=t[n>>2]|0;s=r;return a|0}function yg(e,i,r){e=e|0;i=i|0;r=r|0;var f=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0,S=0,g=0,y=0,F=0,O=0,A=0,M=0,R=0,N=0,T=0,L=0,D=0,C=0,P=0,B=0,I=0,H=0,x=0,U=0,z=0,j=0,V=0,q=0,Y=0;f=s;s=s+144|0;a=f+136|0;o=f+132|0;c=f+128|0;l=f+124|0;b=f+140|0;k=f+120|0;h=f+116|0;w=f+112|0;d=f+108|0;v=f+104|0;m=f+100|0;_=f+96|0;p=f+92|0;E=f+88|0;S=f+84|0;g=f+80|0;y=f+76|0;F=f+72|0;O=f+68|0;A=f+64|0;M=f+60|0;R=f+56|0;N=f+52|0;T=f+48|0;L=f+44|0;D=f+40|0;C=f+36|0;P=f+32|0;B=f+28|0;I=f+24|0;H=f+20|0;x=f+16|0;U=f+12|0;z=f+8|0;j=f+4|0;V=f;t[o>>2]=e;t[c>>2]=i;t[l>>2]=r;n[b>>0]=0;t[k>>2]=0;t[h>>2]=0;t[w>>2]=0;t[d>>2]=0;t[_>>2]=0;t[p>>2]=0;r=t[o>>2]|0;do if((u[t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==34){t[r+172>>2]=12;n[b>>0]=34;Op(t[o>>2]|0)}else{if((u[t[(t[r+36>>2]|0)+16>>2]>>0]|0|0)==39){n[b>>0]=39;t[(t[o>>2]|0)+172>>2]=12;Op(t[o>>2]|0);break}AS(t[o>>2]|0,39,0);t[a>>2]=0;q=t[a>>2]|0;s=f;return q|0}while(0);t[d>>2]=100;t[k>>2]=gAi[t[135752>>2]&511](t[d>>2]|0)|0;e:do if(t[k>>2]|0){t[v>>2]=Ap(t[o>>2]|0,m)|0;i:while(1){if((u[t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==(u[b>>0]|0|0))break;r=t[v>>2]|0;do if((t[v>>2]|0)<256){if(!((9<=(r|0)&(t[v>>2]|0)<=10|(t[v>>2]|0)==13|32<=(t[v>>2]|0))&(t[v>>2]|0)!=60))break i}else{if(!(256<=(r|0)&(t[v>>2]|0)<=55295)?!(57344<=(t[v>>2]|0)&(t[v>>2]|0)<=65533):0)if(65536<=(t[v>>2]|0)&(t[v>>2]|0)<=1114111&(t[v>>2]|0)!=60)break;else break i;if((t[v>>2]|0)==60)break i}while(0);if((t[(t[o>>2]|0)+172>>2]|0)==-1)break;if((t[w>>2]|0)>>>0>1e7?(t[(t[o>>2]|0)+360>>2]&524288|0)==0:0){Y=18;break}if(!(t[v>>2]|0))break;do if((t[v>>2]|0)==38){t[_>>2]=0;r=t[o>>2]|0;if((u[(t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]|0)+1>>0]|0|0)==35){t[S>>2]=lE(r)|0;if((t[S>>2]|0)!=38){if(!(t[S>>2]|0))break;if(((t[w>>2]|0)+10|0)>>>0>(t[d>>2]|0)>>>0){t[M>>2]=(t[d>>2]<<1)+10;if((t[M>>2]|0)>>>0<(t[d>>2]|0)>>>0){Y=138;break e}t[A>>2]=MAi[t[135760>>2]&511](t[k>>2]|0,t[M>>2]|0)|0;if(!(t[A>>2]|0)){Y=138;break e}t[k>>2]=t[A>>2];t[d>>2]=t[M>>2]}i=Np(0,(t[k>>2]|0)+(t[w>>2]|0)|0,t[S>>2]|0)|0;t[w>>2]=(t[w>>2]|0)+i;break}i=((t[w>>2]|0)+10|0)>>>0>(t[d>>2]|0)>>>0;if(t[(t[o>>2]|0)+16>>2]|0){if(i){t[y>>2]=(t[d>>2]<<1)+10;if((t[y>>2]|0)>>>0<(t[d>>2]|0)>>>0){Y=138;break e}t[g>>2]=MAi[t[135760>>2]&511](t[k>>2]|0,t[y>>2]|0)|0;if(!(t[g>>2]|0)){Y=138;break e}t[k>>2]=t[g>>2];t[d>>2]=t[y>>2]}e=t[w>>2]|0;t[w>>2]=e+1;n[(t[k>>2]|0)+e>>0]=38;break}else{if(i){t[O>>2]=(t[d>>2]<<1)+10;if((t[O>>2]|0)>>>0<(t[d>>2]|0)>>>0){Y=138;break e}t[F>>2]=MAi[t[135760>>2]&511](t[k>>2]|0,t[O>>2]|0)|0;if(!(t[F>>2]|0)){Y=138;break e}t[k>>2]=t[F>>2];t[d>>2]=t[O>>2]}i=t[w>>2]|0;t[w>>2]=i+1;n[(t[k>>2]|0)+i>>0]=38;i=t[w>>2]|0;t[w>>2]=i+1;n[(t[k>>2]|0)+i>>0]=35;i=t[w>>2]|0;t[w>>2]=i+1;n[(t[k>>2]|0)+i>>0]=51;i=t[w>>2]|0;t[w>>2]=i+1;n[(t[k>>2]|0)+i>>0]=56;i=t[w>>2]|0;t[w>>2]=i+1;n[(t[k>>2]|0)+i>>0]=59;break}}t[E>>2]=VE(r)|0;r=(t[o>>2]|0)+440|0;t[r>>2]=(t[r>>2]|0)+1;if(t[E>>2]|0){r=(t[o>>2]|0)+440|0;t[r>>2]=(t[r>>2]|0)+(t[(t[E>>2]|0)+68>>2]|0)}if((t[E>>2]|0)!=0?(t[(t[E>>2]|0)+48>>2]|0)==6:0){if(((t[w>>2]|0)+10|0)>>>0>(t[d>>2]|0)>>>0){t[N>>2]=(t[d>>2]<<1)+10;if((t[N>>2]|0)>>>0<(t[d>>2]|0)>>>0){Y=138;break e}t[R>>2]=MAi[t[135760>>2]&511](t[k>>2]|0,t[N>>2]|0)|0;if(!(t[R>>2]|0)){Y=138;break e}t[k>>2]=t[R>>2];t[d>>2]=t[N>>2]}if((t[(t[o>>2]|0)+16>>2]|0)==0?(u[t[(t[E>>2]|0)+40>>2]>>0]|0|0)==38:0){r=t[w>>2]|0;t[w>>2]=r+1;n[(t[k>>2]|0)+r>>0]=38;r=t[w>>2]|0;t[w>>2]=r+1;n[(t[k>>2]|0)+r>>0]=35;r=t[w>>2]|0;t[w>>2]=r+1;n[(t[k>>2]|0)+r>>0]=51;r=t[w>>2]|0;t[w>>2]=r+1;n[(t[k>>2]|0)+r>>0]=56;r=t[w>>2]|0;t[w>>2]=r+1;n[(t[k>>2]|0)+r>>0]=59;break}r=n[t[(t[E>>2]|0)+40>>2]>>0]|0;i=t[w>>2]|0;t[w>>2]=i+1;n[(t[k>>2]|0)+i>>0]=r;break}if((t[E>>2]|0)!=0?(t[(t[o>>2]|0)+16>>2]|0)!=0:0){if((t[(t[E>>2]|0)+48>>2]|0)==6){if(((t[w>>2]|0)+10|0)>>>0>(t[d>>2]|0)>>>0){t[C>>2]=(t[d>>2]<<1)+10;if((t[C>>2]|0)>>>0<(t[d>>2]|0)>>>0){Y=138;break e}t[D>>2]=MAi[t[135760>>2]&511](t[k>>2]|0,t[C>>2]|0)|0;if(!(t[D>>2]|0)){Y=138;break e}t[k>>2]=t[D>>2];t[d>>2]=t[C>>2]}if(!(t[(t[E>>2]|0)+40>>2]|0))break;r=n[t[(t[E>>2]|0)+40>>2]>>0]|0;i=t[w>>2]|0;t[w>>2]=i+1;n[(t[k>>2]|0)+i>>0]=r;break}t[h>>2]=hE(t[o>>2]|0,t[(t[E>>2]|0)+40>>2]|0,1,0,0,0)|0;if(!(t[h>>2]|0))break;t[p>>2]=t[h>>2];while(1){if(!(u[t[p>>2]>>0]|0))break;do if((u[t[p>>2]>>0]|0|0)==13)Y=61;else{if((u[t[p>>2]>>0]|0|0)==10){Y=61;break}if((u[t[p>>2]>>0]|0|0)==9){Y=61;break}r=t[p>>2]|0;t[p>>2]=r+1;i=n[r>>0]|0;r=t[w>>2]|0;t[w>>2]=r+1;n[(t[k>>2]|0)+r>>0]=i}while(0);if((Y|0)==61){Y=0;i=t[w>>2]|0;t[w>>2]=i+1;n[(t[k>>2]|0)+i>>0]=32;t[p>>2]=(t[p>>2]|0)+1}if(((t[w>>2]|0)+10|0)>>>0<=(t[d>>2]|0)>>>0)continue;t[L>>2]=(t[d>>2]<<1)+10;if((t[L>>2]|0)>>>0<(t[d>>2]|0)>>>0){Y=138;break e}t[T>>2]=MAi[t[135760>>2]&511](t[k>>2]|0,t[L>>2]|0)|0;if(!(t[T>>2]|0)){Y=138;break e}t[k>>2]=t[T>>2];t[d>>2]=t[L>>2]}pAi[t[135736>>2]&511](t[h>>2]|0);t[h>>2]=0;break}if(t[E>>2]|0){t[P>>2]=rs(t[(t[E>>2]|0)+8>>2]|0)|0;t[B>>2]=t[(t[E>>2]|0)+8>>2];do if(((t[(t[E>>2]|0)+48>>2]|0)!=6?(t[(t[E>>2]|0)+40>>2]|0)!=0:0)?(t[(t[E>>2]|0)+72>>2]|0)==0:0){t[I>>2]=t[(t[o>>2]|0)+440>>2];t[h>>2]=hE(t[o>>2]|0,t[(t[E>>2]|0)+40>>2]|0,1,0,0,0)|0;t[(t[E>>2]|0)+72>>2]=(t[(t[o>>2]|0)+440>>2]|0)-(t[I>>2]|0)+1<<1;if(!(t[h>>2]|0))break;if(es(t[h>>2]|0,60)|0){i=(t[E>>2]|0)+72|0;t[i>>2]=t[i>>2]|1}pAi[t[135736>>2]&511](t[h>>2]|0);t[h>>2]=0}while(0);i=t[w>>2]|0;t[w>>2]=i+1;n[(t[k>>2]|0)+i>>0]=38;while(1){if(((t[w>>2]|0)+(t[P>>2]|0)+10|0)>>>0<=(t[d>>2]|0)>>>0)break;t[x>>2]=(t[d>>2]<<1)+(t[P>>2]|0)+10;if((t[x>>2]|0)>>>0<(t[d>>2]|0)>>>0){Y=138;break e}t[H>>2]=MAi[t[135760>>2]&511](t[k>>2]|0,t[x>>2]|0)|0;if(!(t[H>>2]|0)){Y=138;break e}t[k>>2]=t[H>>2];t[d>>2]=t[x>>2]}while(1){if((t[P>>2]|0)<=0)break;i=t[B>>2]|0;t[B>>2]=i+1;r=n[i>>0]|0;i=t[w>>2]|0;t[w>>2]=i+1;n[(t[k>>2]|0)+i>>0]=r;t[P>>2]=(t[P>>2]|0)+-1}r=t[w>>2]|0;t[w>>2]=r+1;n[(t[k>>2]|0)+r>>0]=59}}else{if((t[v>>2]|0)==32|(t[v>>2]|0)==13|(t[v>>2]|0)==10|(t[v>>2]|0)==9){if(!((t[w>>2]|0)==0&(t[l>>2]|0)!=0)){r:do if(!((t[l>>2]|0)!=0&(t[_>>2]|0)!=0)){r=t[w>>2]|0;if((t[m>>2]|0)==1){t[w>>2]=r+1;n[(t[k>>2]|0)+r>>0]=32}else{i=Rp((t[k>>2]|0)+r|0,32)|0;t[w>>2]=(t[w>>2]|0)+i}while(1){if(((t[w>>2]|0)+10|0)>>>0<=(t[d>>2]|0)>>>0)break r;t[z>>2]=(t[d>>2]<<1)+10;if((t[z>>2]|0)>>>0<(t[d>>2]|0)>>>0){Y=138;break e}t[U>>2]=MAi[t[135760>>2]&511](t[k>>2]|0,t[z>>2]|0)|0;if(!(t[U>>2]|0)){Y=138;break e}t[k>>2]=t[U>>2];t[d>>2]=t[z>>2]}}while(0);t[_>>2]=1}}else{t[_>>2]=0;if((t[m>>2]|0)==1){i=t[v>>2]&255;r=t[w>>2]|0;t[w>>2]=r+1;n[(t[k>>2]|0)+r>>0]=i}else{i=Rp((t[k>>2]|0)+(t[w>>2]|0)|0,t[v>>2]|0)|0;t[w>>2]=(t[w>>2]|0)+i}if(((t[w>>2]|0)+10|0)>>>0>(t[d>>2]|0)>>>0){t[V>>2]=(t[d>>2]<<1)+10;if((t[V>>2]|0)>>>0<(t[d>>2]|0)>>>0){Y=138;break e}t[j>>2]=MAi[t[135760>>2]&511](t[k>>2]|0,t[V>>2]|0)|0;if(!(t[j>>2]|0)){Y=138;break e}t[k>>2]=t[j>>2];t[d>>2]=t[V>>2]}}i=t[(t[o>>2]|0)+36>>2]|0;if((u[t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==10){r=i+28|0;t[r>>2]=(t[r>>2]|0)+1;t[(t[(t[o>>2]|0)+36>>2]|0)+32>>2]=1}else{r=i+32|0;t[r>>2]=(t[r>>2]|0)+1}r=(t[(t[o>>2]|0)+36>>2]|0)+16|0;t[r>>2]=(t[r>>2]|0)+(t[m>>2]|0);if((u[t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==37)oE(t[o>>2]|0)}while(0);if((t[(t[o>>2]|0)+292>>2]|0)==0?((t[(t[(t[o>>2]|0)+36>>2]|0)+20>>2]|0)-(t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]|0)|0)<250:0)CS(t[o>>2]|0);t[v>>2]=Ap(t[o>>2]|0,m)|0}if((Y|0)==18){BS(t[o>>2]|0,40,71720);Y=138;break}if((t[(t[o>>2]|0)+172>>2]|0)!=-1){i:do if((t[_>>2]|0)!=0&(t[l>>2]|0)!=0&(t[w>>2]|0)>>>0>0)do{if((u[(t[k>>2]|0)+((t[w>>2]|0)-1)>>0]|0|0)!=32)break i;t[w>>2]=(t[w>>2]|0)+-1}while((t[w>>2]|0)>>>0>0);while(0);n[(t[k>>2]|0)+(t[w>>2]|0)>>0]=0;r=t[o>>2]|0;i:do if((u[t[(t[(t[o>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==60)AS(r,38,0);else{if((u[t[(t[r+36>>2]|0)+16>>2]>>0]|0|0)==(u[b>>0]|0|0)){Op(t[o>>2]|0);break}do if(t[v>>2]|0){i=t[v>>2]|0;if((t[v>>2]|0)<256){if(9<=(i|0)&(t[v>>2]|0)<=10|(t[v>>2]|0)==13|32<=(t[v>>2]|0))break}else{if(256<=(i|0)&(t[v>>2]|0)<=55295)break;if(57344<=(t[v>>2]|0)&(t[v>>2]|0)<=65533)break;if(65536<=(t[v>>2]|0)&(t[v>>2]|0)<=1114111)break}BS(t[o>>2]|0,9,71752);break i}while(0);BS(t[o>>2]|0,40,71792)}while(0);if((t[w>>2]|0)>>>0>=2147483647){BS(t[o>>2]|0,40,71720);Y=138;break}if(t[c>>2]|0)t[t[c>>2]>>2]=t[w>>2];t[a>>2]=t[k>>2];q=t[a>>2]|0;s=f;return q|0}}else Y=138;while(0);if((Y|0)==138)Sp(t[o>>2]|0,0);if(t[k>>2]|0)pAi[t[135736>>2]&511](t[k>>2]|0);if(t[h>>2]|0)pAi[t[135736>>2]&511](t[h>>2]|0);t[a>>2]=0;q=t[a>>2]|0;s=f;return q|0}function Fg(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,a=0,o=0,c=0,l=0,b=0;r=s;s=s+32|0;n=r+20|0;f=r+16|0;a=r+12|0;o=r+8|0;c=r+4|0;l=r;t[f>>2]=e;t[a>>2]=i;t[o>>2]=t[a>>2];if((t[(t[f>>2]|0)+292>>2]|0)==0?((t[(t[(t[f>>2]|0)+36>>2]|0)+20>>2]|0)-(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)|0)<250:0)CS(t[f>>2]|0);if((t[(t[f>>2]|0)+172>>2]|0)==-1){t[n>>2]=0;b=t[n>>2]|0;s=r;return b|0}t[c>>2]=t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2];while(1){if(!(u[t[c>>2]>>0]|0))break;if((u[t[c>>2]>>0]|0|0)!=(u[t[o>>2]>>0]|0|0))break;t[c>>2]=(t[c>>2]|0)+1;t[o>>2]=(t[o>>2]|0)+1;i=(t[(t[f>>2]|0)+36>>2]|0)+32|0;t[i>>2]=(t[i>>2]|0)+1}e:do if(!(u[t[o>>2]>>0]|0)){do if((u[t[c>>2]>>0]|0|0)!=62?(u[t[c>>2]>>0]|0|0)!=32:0){if(9<=(u[t[c>>2]>>0]|0|0)?(u[t[c>>2]>>0]|0|0)<=10:0)break;if((u[t[c>>2]>>0]|0|0)!=13)break e}while(0);t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]=t[c>>2];t[n>>2]=1;b=t[n>>2]|0;s=r;return b|0}while(0);t[l>>2]=sE(t[f>>2]|0)|0;if((t[l>>2]|0)==(t[a>>2]|0)){t[n>>2]=1;b=t[n>>2]|0;s=r;return b|0}else{t[n>>2]=t[l>>2];b=t[n>>2]|0;s=r;return b|0}return 0}function Og(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,a=0,o=0,c=0,l=0,b=0,k=0;r=s;s=s+32|0;n=r+24|0;f=r+20|0;a=r+16|0;o=r+12|0;c=r+8|0;l=r+4|0;b=r;t[f>>2]=e;t[a>>2]=i;if((t[(t[f>>2]|0)+292>>2]|0)==0?((t[(t[(t[f>>2]|0)+36>>2]|0)+20>>2]|0)-(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)|0)<250:0)CS(t[f>>2]|0);t[o>>2]=Ig(t[f>>2]|0)|0;i=(u[t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==58;if(!(t[o>>2]|0)){if(i?(t[o>>2]=sE(t[f>>2]|0)|0,(t[o>>2]|0)!=0):0){KS(t[f>>2]|0,202,70824,t[o>>2]|0,0,0);t[t[a>>2]>>2]=0;t[n>>2]=t[o>>2];k=t[n>>2]|0;s=r;return k|0}t[n>>2]=0;k=t[n>>2]|0;s=r;return k|0}do if(i){Op(t[f>>2]|0);t[c>>2]=t[o>>2];t[o>>2]=Ig(t[f>>2]|0)|0;e=t[f>>2]|0;if(!(t[o>>2]|0)){KS(e,202,70856,t[c>>2]|0,0,0);t[o>>2]=dE(t[f>>2]|0)|0;if(!(t[o>>2]|0))t[l>>2]=Ug(65640,t[c>>2]|0,0,0)|0;else{t[l>>2]=Ug(t[o>>2]|0,t[c>>2]|0,0,0)|0;pAi[t[135736>>2]&511](t[o>>2]|0)}t[c>>2]=kz(t[(t[f>>2]|0)+296>>2]|0,t[l>>2]|0,-1)|0;if(t[l>>2]|0)pAi[t[135736>>2]&511](t[l>>2]|0);t[t[a>>2]>>2]=0;t[n>>2]=t[c>>2];k=t[n>>2]|0;s=r;return k|0}if((u[t[(t[e+36>>2]|0)+16>>2]>>0]|0|0)!=58){t[t[a>>2]>>2]=t[c>>2];break}KS(t[f>>2]|0,202,70888,t[c>>2]|0,t[o>>2]|0,0);Op(t[f>>2]|0);t[b>>2]=sE(t[f>>2]|0)|0;if(t[b>>2]|0){t[b>>2]=Ug(t[b>>2]|0,t[o>>2]|0,0,0)|0;t[o>>2]=kz(t[(t[f>>2]|0)+296>>2]|0,t[b>>2]|0,-1)|0;if(t[b>>2]|0)pAi[t[135736>>2]&511](t[b>>2]|0);t[t[a>>2]>>2]=t[c>>2];t[n>>2]=t[o>>2];k=t[n>>2]|0;s=r;return k|0}else{t[b>>2]=Ug(65640,t[o>>2]|0,0,0)|0;t[o>>2]=kz(t[(t[f>>2]|0)+296>>2]|0,t[b>>2]|0,-1)|0;if(t[b>>2]|0)pAi[t[135736>>2]&511](t[b>>2]|0);t[t[a>>2]>>2]=t[c>>2];t[n>>2]=t[o>>2];k=t[n>>2]|0;s=r;return k|0}}else t[t[a>>2]>>2]=0;while(0);t[n>>2]=t[o>>2];k=t[n>>2]|0;s=r;return k|0}function Ag(e,i,r,n,f,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;a=a|0;o=o|0;var c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0,S=0,g=0,y=0,F=0;c=s;s=s+64|0;l=c+52|0;b=c+48|0;k=c+44|0;h=c+40|0;w=c+36|0;d=c+32|0;v=c+28|0;m=c+24|0;_=c+20|0;p=c+16|0;E=c+12|0;S=c+8|0;g=c+4|0;y=c;t[b>>2]=e;t[k>>2]=i;t[h>>2]=r;t[w>>2]=n;t[d>>2]=f;t[v>>2]=a;t[m>>2]=o;t[E>>2]=0;t[S>>2]=0;t[t[d>>2]>>2]=0;if((t[(t[b>>2]|0)+292>>2]|0)==0?((t[(t[(t[b>>2]|0)+36>>2]|0)+20>>2]|0)-(t[(t[(t[b>>2]|0)+36>>2]|0)+16>>2]|0)|0)<250:0)CS(t[b>>2]|0);t[_>>2]=Og(t[b>>2]|0,t[w>>2]|0)|0;o=t[b>>2]|0;if(!(t[_>>2]|0)){BS(o,68,69032);t[l>>2]=0;F=t[l>>2]|0;s=c;return F|0}if((t[o+352>>2]|0)!=0?(t[g>>2]=uO(t[(t[b>>2]|0)+352>>2]|0,t[k>>2]|0,t[h>>2]|0,t[t[w>>2]>>2]|0,t[_>>2]|0)|0,(t[g>>2]|0)!=0):0)t[S>>2]=1;uE(t[b>>2]|0)|0;g=t[b>>2]|0;if((u[t[(t[(t[b>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)!=61){MS(g,41,69064,t[_>>2]|0);t[l>>2]=0;F=t[l>>2]|0;s=c;return F|0}Op(g);uE(t[b>>2]|0)|0;t[p>>2]=VS(t[b>>2]|0,t[v>>2]|0,t[m>>2]|0,t[S>>2]|0)|0;if((((t[S>>2]|0)!=0?(t[t[m>>2]>>2]|0)!=0:0)?(t[y>>2]=Hg(t[b>>2]|0,t[p>>2]|0,t[v>>2]|0)|0,(t[y>>2]|0)!=0):0)?(t[y>>2]|0)!=(t[p>>2]|0):0){pAi[t[135736>>2]&511](t[p>>2]|0);t[p>>2]=t[y>>2]}t[(t[b>>2]|0)+172>>2]=7;if((t[t[w>>2]>>2]|0)==(t[(t[b>>2]|0)+312>>2]|0)){if(((t[(t[b>>2]|0)+268>>2]|0)!=0?(Xl(t[_>>2]|0,71704)|0)!=0:0)?(t[E>>2]=ql(t[p>>2]|0,t[t[v>>2]>>2]|0)|0,($p(t[E>>2]|0)|0)==0):0)NS(t[b>>2]|0,98,69128,t[E>>2]|0,0);do if(Xl(t[_>>2]|0,71712)|0){t[E>>2]=ql(t[p>>2]|0,t[t[v>>2]>>2]|0)|0;if(Xl(t[E>>2]|0,69184)|0){t[t[(t[b>>2]|0)+232>>2]>>2]=0;break}w=(Xl(t[E>>2]|0,69192)|0)!=0;y=t[b>>2]|0;if(w){t[t[y+232>>2]>>2]=1;break}else{NS(y,102,69208,t[E>>2]|0,0);break}}while(0);if(t[E>>2]|0)pAi[t[135736>>2]&511](t[E>>2]|0)}t[t[d>>2]>>2]=t[p>>2];t[l>>2]=t[_>>2];F=t[l>>2]|0;s=c;return F|0}function Mg(e,i,r,n,f,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;u=u|0;var a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0;a=s;s=s+48|0;o=a;c=a+32|0;l=a+28|0;b=a+24|0;k=a+20|0;h=a+16|0;w=a+12|0;t[c>>2]=e;t[l>>2]=i;t[b>>2]=r;t[k>>2]=n;t[h>>2]=f;t[w>>2]=u;if(((t[c>>2]|0)!=0?(t[(t[c>>2]|0)+212>>2]|0)!=0:0)?(t[(t[c>>2]|0)+172>>2]|0)==-1:0){s=a;return}u=t[c>>2]|0;c=t[l>>2]|0;l=t[k>>2]|0;f=t[h>>2]|0;n=t[w>>2]|0;r=t[b>>2]|0;b=t[h>>2]|0;h=t[w>>2]|0;t[o>>2]=t[k>>2];t[o+4>>2]=b;t[o+8>>2]=h;cp(0,0,0,u,0,3,c,1,0,0,l,f,n,0,0,r,o);s=a;return}function Rg(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0;r=s;s=s+32|0;n=r+20|0;f=r+16|0;u=r+12|0;a=r+8|0;o=r+4|0;c=r;t[f>>2]=e;t[u>>2]=i;if(!(t[(t[f>>2]|0)+300>>2]|0)){t[c>>2]=55;t[a>>2]=gAi[t[135744>>2]&511](t[c>>2]<<2)|0;if((t[a>>2]|0)!=0?(t[(t[f>>2]|0)+300>>2]=t[a>>2],t[o>>2]=gAi[t[135744>>2]&511](((t[c>>2]|0)/5|0)<<2)|0,(t[o>>2]|0)!=0):0){t[(t[f>>2]|0)+340>>2]=t[o>>2];t[(t[f>>2]|0)+304>>2]=t[c>>2];l=9}else l=10}else if(((t[u>>2]|0)+5|0)>(t[(t[f>>2]|0)+304>>2]|0)){t[c>>2]=(t[u>>2]|0)+5<<1;t[a>>2]=MAi[t[135760>>2]&511](t[(t[f>>2]|0)+300>>2]|0,t[c>>2]<<2)|0;if((t[a>>2]|0)!=0?(t[(t[f>>2]|0)+300>>2]=t[a>>2],t[o>>2]=MAi[t[135760>>2]&511](t[(t[f>>2]|0)+340>>2]|0,((t[c>>2]|0)/5|0)<<2)|0,(t[o>>2]|0)!=0):0){t[(t[f>>2]|0)+340>>2]=t[o>>2];t[(t[f>>2]|0)+304>>2]=t[c>>2];l=9}else l=10}else l=9;if((l|0)==9){t[n>>2]=t[(t[f>>2]|0)+304>>2];b=t[n>>2]|0;s=r;return b|0}else if((l|0)==10){Sp(t[f>>2]|0,0);t[n>>2]=-1;b=t[n>>2]|0;s=r;return b|0}return 0}function Ng(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0;n=s;s=s+32|0;f=n+28|0;a=n+24|0;o=n+20|0;c=n+16|0;l=n+12|0;b=n+8|0;k=n+4|0;h=n;t[a>>2]=e;t[o>>2]=i;t[c>>2]=r;r=t[a>>2]|0;if(!(t[c>>2]|0)){t[f>>2]=Fg(r,t[o>>2]|0)|0;w=t[f>>2]|0;s=n;return w|0}if((t[r+292>>2]|0)==0?((t[(t[(t[a>>2]|0)+36>>2]|0)+20>>2]|0)-(t[(t[(t[a>>2]|0)+36>>2]|0)+16>>2]|0)|0)<250:0)CS(t[a>>2]|0);t[b>>2]=t[(t[(t[a>>2]|0)+36>>2]|0)+16>>2];t[l>>2]=t[c>>2];while(1){if(!(u[t[b>>2]>>0]|0))break;if((u[t[b>>2]>>0]|0|0)!=(u[t[l>>2]>>0]|0|0))break;t[b>>2]=(t[b>>2]|0)+1;t[l>>2]=(t[l>>2]|0)+1}e:do if((u[t[l>>2]>>0]|0|0)==0?(u[t[b>>2]>>0]|0|0)==58:0){t[b>>2]=(t[b>>2]|0)+1;t[l>>2]=t[o>>2];while(1){if(!(u[t[b>>2]>>0]|0))break;if((u[t[b>>2]>>0]|0|0)!=(u[t[l>>2]>>0]|0|0))break;t[b>>2]=(t[b>>2]|0)+1;t[l>>2]=(t[l>>2]|0)+1}if(!(u[t[l>>2]>>0]|0)){do if((u[t[b>>2]>>0]|0|0)!=62?(u[t[b>>2]>>0]|0|0)!=32:0){if(9<=(u[t[b>>2]>>0]|0|0)?(u[t[b>>2]>>0]|0|0)<=10:0)break;if((u[t[b>>2]>>0]|0|0)!=13)break e}while(0);t[(t[(t[a>>2]|0)+36>>2]|0)+16>>2]=t[b>>2];t[f>>2]=1;w=t[f>>2]|0;s=n;return w|0}}while(0);t[k>>2]=Og(t[a>>2]|0,h)|0;if((t[k>>2]|0)==(t[o>>2]|0)?(t[c>>2]|0)==(t[h>>2]|0):0){t[f>>2]=1;w=t[f>>2]|0;s=n;return w|0}t[f>>2]=t[k>>2];w=t[f>>2]|0;s=n;return w|0}function Tg(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;var u=0,a=0,o=0,c=0,l=0,b=0;u=s;s=s+32|0;a=u+20|0;o=u+16|0;c=u+12|0;l=u+8|0;b=u;t[a>>2]=e;t[o>>2]=i;t[c>>2]=r;t[l>>2]=n;t[u+4>>2]=f;t[b>>2]=t[o>>2];if((t[a>>2]|0)!=1){s=u;return}wO(t[(t[b>>2]|0)+352>>2]|0,t[c>>2]|0,t[l>>2]|0,0)|0;s=u;return}function Lg(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0;n=s;s=s+32|0;f=n+16|0;a=n+12|0;o=n+8|0;c=n+4|0;t[f>>2]=e;t[a>>2]=i;t[o>>2]=r;if((t[f>>2]|0)==0|(t[a>>2]|0)==0|(t[o>>2]|0)==0){yAi[t[135904>>2]&511](t[33980]|0,70648,n);s=n;return}if((t[(t[f>>2]|0)+292>>2]|0)!=0?(t[(t[f>>2]|0)+40>>2]|0)==1:0){t[c>>2]=t[(t[(t[f>>2]|0)+36>>2]|0)+20>>2];t[c>>2]=(t[c>>2]|0)+-1;while(1){if((t[c>>2]|0)>>>0>=(t[(t[(t[f>>2]|0)+36>>2]|0)+12>>2]|0)>>>0)l=(u[t[c>>2]>>0]|0|0)!=60;else l=0;b=t[c>>2]|0;if(!l)break;t[c>>2]=b+-1}if(b>>>0<(t[(t[(t[f>>2]|0)+36>>2]|0)+12>>2]|0)>>>0){t[t[a>>2]>>2]=0;t[t[o>>2]>>2]=0;s=n;return}t[t[a>>2]>>2]=t[c>>2];t[c>>2]=(t[c>>2]|0)+1;while(1){if((t[c>>2]|0)>>>0<(t[(t[(t[f>>2]|0)+36>>2]|0)+20>>2]|0)>>>0)k=(u[t[c>>2]>>0]|0|0)!=62;else k=0;h=t[c>>2]|0;if(!k)break;b=t[c>>2]|0;if((u[h>>0]|0|0)==39){t[c>>2]=b+1;while(1){if((t[c>>2]|0)>>>0<(t[(t[(t[f>>2]|0)+36>>2]|0)+20>>2]|0)>>>0)w=(u[t[c>>2]>>0]|0|0)!=39;else w=0;d=t[c>>2]|0;if(!w)break;t[c>>2]=d+1}if(d>>>0>=(t[(t[(t[f>>2]|0)+36>>2]|0)+20>>2]|0)>>>0)continue;t[c>>2]=(t[c>>2]|0)+1;continue}else{l=(u[b>>0]|0|0)==34;t[c>>2]=(t[c>>2]|0)+1;if(!l)continue;while(1){if((t[c>>2]|0)>>>0<(t[(t[(t[f>>2]|0)+36>>2]|0)+20>>2]|0)>>>0)v=(u[t[c>>2]>>0]|0|0)!=34;else v=0;m=t[c>>2]|0;if(!v)break;t[c>>2]=m+1}if(m>>>0>=(t[(t[(t[f>>2]|0)+36>>2]|0)+20>>2]|0)>>>0)continue;t[c>>2]=(t[c>>2]|0)+1;continue}}if(h>>>0<(t[(t[(t[f>>2]|0)+36>>2]|0)+20>>2]|0)>>>0){t[t[o>>2]>>2]=t[c>>2];s=n;return}t[c>>2]=t[t[a>>2]>>2];t[c>>2]=(t[c>>2]|0)+-1;while(1){if((t[c>>2]|0)>>>0>=(t[(t[(t[f>>2]|0)+36>>2]|0)+12>>2]|0)>>>0)_=(u[t[c>>2]>>0]|0|0)!=62;else _=0;p=t[c>>2]|0;if(!_)break;t[c>>2]=p+-1}if(p>>>0>=(t[(t[(t[f>>2]|0)+36>>2]|0)+12>>2]|0)>>>0){t[t[o>>2]>>2]=t[c>>2];s=n;return}else{t[t[o>>2]>>2]=0;s=n;return}}t[t[a>>2]>>2]=0;t[t[o>>2]>>2]=0;s=n;return}function Dg(e,i,r,f){e=e|0;i=i|0;r=r|0;f=f|0;var a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0;a=s;s=s+32|0;o=a+20|0;c=a+16|0;l=a+26|0;b=a+25|0;k=a+24|0;h=a+12|0;w=a+8|0;d=a+4|0;v=a;t[c>>2]=e;n[l>>0]=i;n[b>>0]=r;n[k>>0]=f;t[d>>2]=t[(t[c>>2]|0)+36>>2];if(!(t[d>>2]|0)){t[o>>2]=-1;m=t[o>>2]|0;s=a;return m|0}t[h>>2]=(t[(t[d>>2]|0)+16>>2]|0)-(t[(t[d>>2]|0)+12>>2]|0);if((t[h>>2]|0)<0){t[o>>2]=-1;m=t[o>>2]|0;s=a;return m|0}if((t[(t[c>>2]|0)+204>>2]|0)>(t[h>>2]|0))t[h>>2]=t[(t[c>>2]|0)+204>>2];f=t[d>>2]|0;if(!(t[t[d>>2]>>2]|0)){t[v>>2]=t[f+12>>2];t[w>>2]=t[(t[d>>2]|0)+24>>2]}else{t[v>>2]=Os(t[(t[f>>2]|0)+16>>2]|0)|0;t[w>>2]=Ts(t[(t[t[d>>2]>>2]|0)+16>>2]|0)|0}if(!(n[k>>0]|0)){if(n[b>>0]|0)t[w>>2]=(t[w>>2]|0)+-1}else t[w>>2]=(t[w>>2]|0)-2;e:while(1){_=t[h>>2]|0;if((t[h>>2]|0)>=(t[w>>2]|0)){p=23;break}do if((u[(t[v>>2]|0)+_>>0]|0)==(u[l>>0]|0))if(u[k>>0]|0){if((u[(t[v>>2]|0)+((t[h>>2]|0)+1)>>0]|0)!=(u[b>>0]|0))break;if((u[(t[v>>2]|0)+((t[h>>2]|0)+2)>>0]|0)!=(u[k>>0]|0))break;else{p=21;break e}}else{if(!(u[b>>0]|0)){p=21;break e}if((u[(t[v>>2]|0)+((t[h>>2]|0)+1)>>0]|0)!=(u[b>>0]|0))break;else{p=21;break e}}while(0);t[h>>2]=(t[h>>2]|0)+1}if((p|0)==21){t[(t[c>>2]|0)+204>>2]=0;t[o>>2]=(t[h>>2]|0)-((t[(t[d>>2]|0)+16>>2]|0)-(t[(t[d>>2]|0)+12>>2]|0));m=t[o>>2]|0;s=a;return m|0}else if((p|0)==23){t[(t[c>>2]|0)+204>>2]=_;t[o>>2]=-1;m=t[o>>2]|0;s=a;return m|0}return 0}function Cg(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;var u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0;u=s;s=s+32|0;a=u+28|0;o=u+24|0;c=u+20|0;l=u+16|0;b=u+12|0;k=u+8|0;h=u+4|0;w=u;t[o>>2]=e;t[c>>2]=i;t[l>>2]=r;t[b>>2]=n;t[k>>2]=f;e:do if((t[(t[o>>2]|0)+188>>2]|0)>=(t[(t[o>>2]|0)+192>>2]|0)){f=(t[o>>2]|0)+192|0;t[f>>2]=t[f>>2]<<1;t[h>>2]=MAi[t[135760>>2]&511](t[(t[o>>2]|0)+196>>2]|0,t[(t[o>>2]|0)+192>>2]<<2)|0;do if(t[h>>2]|0){t[(t[o>>2]|0)+196>>2]=t[h>>2];t[w>>2]=MAi[t[135760>>2]&511](t[(t[o>>2]|0)+344>>2]|0,(t[(t[o>>2]|0)+192>>2]|0)*3<<2)|0;if(!(t[w>>2]|0)){f=(t[o>>2]|0)+192|0;t[f>>2]=(t[f>>2]|0)/2|0;break}else{t[(t[o>>2]|0)+344>>2]=t[w>>2];break e}}else{f=(t[o>>2]|0)+192|0;t[f>>2]=(t[f>>2]|0)/2|0}while(0);Sp(t[o>>2]|0,0);t[a>>2]=-1;d=t[a>>2]|0;s=u;return d|0}while(0);t[(t[(t[o>>2]|0)+196>>2]|0)+(t[(t[o>>2]|0)+188>>2]<<2)>>2]=t[c>>2];t[(t[o>>2]|0)+184>>2]=t[c>>2];t[(t[(t[o>>2]|0)+344>>2]|0)+((t[(t[o>>2]|0)+188>>2]|0)*3<<2)>>2]=t[l>>2];t[(t[(t[o>>2]|0)+344>>2]|0)+(((t[(t[o>>2]|0)+188>>2]|0)*3|0)+1<<2)>>2]=t[b>>2];t[(t[(t[o>>2]|0)+344>>2]|0)+(((t[(t[o>>2]|0)+188>>2]|0)*3|0)+2<<2)>>2]=t[k>>2];k=(t[o>>2]|0)+188|0;o=t[k>>2]|0;t[k>>2]=o+1;t[a>>2]=o;d=t[a>>2]|0;s=u;return d|0}function Pg(e){e=e|0;var i=0,r=0,n=0,f=0,u=0;i=s;s=s+16|0;r=i+8|0;n=i+4|0;f=i;t[n>>2]=e;if((t[(t[n>>2]|0)+188>>2]|0)<=0){t[r>>2]=0;u=t[r>>2]|0;s=i;return u|0}e=(t[n>>2]|0)+188|0;t[e>>2]=(t[e>>2]|0)+-1;e=t[n>>2]|0;if((t[(t[n>>2]|0)+188>>2]|0)>0)t[(t[n>>2]|0)+184>>2]=t[(t[(t[n>>2]|0)+196>>2]|0)+((t[e+188>>2]|0)-1<<2)>>2];else t[e+184>>2]=0;t[f>>2]=t[(t[(t[n>>2]|0)+196>>2]|0)+(t[(t[n>>2]|0)+188>>2]<<2)>>2];t[(t[(t[n>>2]|0)+196>>2]|0)+(t[(t[n>>2]|0)+188>>2]<<2)>>2]=0;t[r>>2]=t[f>>2];u=t[r>>2]|0;s=i;return u|0}function Bg(e,i){e=e|0;i=i|0;var r=0,f=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0;r=s;s=s+32|0;f=r+16|0;a=r+12|0;o=r+8|0;c=r+4|0;l=r+20|0;b=r;t[a>>2]=e;t[o>>2]=i;if((t[a>>2]|0)==0|(t[o>>2]|0)<=0){t[f>>2]=0;k=t[f>>2]|0;s=r;return k|0}t[c>>2]=0;while(1){h=t[c>>2]|0;if((t[c>>2]|0)>=(t[o>>2]|0)){w=53;break}n[l>>0]=n[(t[a>>2]|0)+h>>0]|0;i=u[l>>0]|0;if(!((u[l>>0]|0)&128)){if((i|0)>=32){t[c>>2]=(t[c>>2]|0)+1;continue}if(((u[l>>0]|0|0)!=10?(u[l>>0]|0|0)!=13:0)?(u[l>>0]|0|0)!=9:0){w=12;break}t[c>>2]=(t[c>>2]|0)+1;continue}if((i&224|0)==192){d=t[c>>2]|0;if(((t[c>>2]|0)+2|0)>(t[o>>2]|0)){w=15;break}v=t[c>>2]|0;if(((u[(t[a>>2]|0)+(d+1)>>0]|0)&192|0)!=128){w=17;break}t[b>>2]=((u[(t[a>>2]|0)+v>>0]|0)&31)<<6;t[b>>2]=t[b>>2]|(u[(t[a>>2]|0)+((t[c>>2]|0)+1)>>0]|0)&63;i=t[b>>2]|0;if((t[b>>2]|0)<256){if(!(9<=(i|0)&(t[b>>2]|0)<=10|(t[b>>2]|0)==13|32<=(t[b>>2]|0))){w=23;break}}else if((!(256<=(i|0)&(t[b>>2]|0)<=55295)?!(57344<=(t[b>>2]|0)&(t[b>>2]|0)<=65533):0)?!(65536<=(t[b>>2]|0)&(t[b>>2]|0)<=1114111):0){w=23;break}t[c>>2]=(t[c>>2]|0)+2;continue}if(((u[l>>0]|0)&240|0)==224){m=t[c>>2]|0;if(((t[c>>2]|0)+3|0)>(t[o>>2]|0)){w=27;break}if(((u[(t[a>>2]|0)+(m+1)>>0]|0)&192|0)!=128){w=30;break}if(((u[(t[a>>2]|0)+((t[c>>2]|0)+2)>>0]|0)&192|0)!=128){w=30;break}t[b>>2]=((u[(t[a>>2]|0)+(t[c>>2]|0)>>0]|0)&15)<<12;t[b>>2]=t[b>>2]|((u[(t[a>>2]|0)+((t[c>>2]|0)+1)>>0]|0)&63)<<6;t[b>>2]=t[b>>2]|(u[(t[a>>2]|0)+((t[c>>2]|0)+2)>>0]|0)&63;i=t[b>>2]|0;if((t[b>>2]|0)<256){if(!(9<=(i|0)&(t[b>>2]|0)<=10|(t[b>>2]|0)==13|32<=(t[b>>2]|0))){w=36;break}}else if((!(256<=(i|0)&(t[b>>2]|0)<=55295)?!(57344<=(t[b>>2]|0)&(t[b>>2]|0)<=65533):0)?!(65536<=(t[b>>2]|0)&(t[b>>2]|0)<=1114111):0){w=36;break}t[c>>2]=(t[c>>2]|0)+3;continue}_=t[c>>2]|0;if(((u[l>>0]|0)&248|0)!=240){w=52;break}p=t[c>>2]|0;if((_+4|0)>(t[o>>2]|0)){w=40;break}if(((u[(t[a>>2]|0)+(p+1)>>0]|0)&192|0)!=128){w=44;break}if(((u[(t[a>>2]|0)+((t[c>>2]|0)+2)>>0]|0)&192|0)!=128){w=44;break}if(((u[(t[a>>2]|0)+((t[c>>2]|0)+3)>>0]|0)&192|0)!=128){w=44;break}t[b>>2]=((u[(t[a>>2]|0)+(t[c>>2]|0)>>0]|0)&7)<<18;t[b>>2]=t[b>>2]|((u[(t[a>>2]|0)+((t[c>>2]|0)+1)>>0]|0)&63)<<12;t[b>>2]=t[b>>2]|((u[(t[a>>2]|0)+((t[c>>2]|0)+2)>>0]|0)&63)<<6;t[b>>2]=t[b>>2]|(u[(t[a>>2]|0)+((t[c>>2]|0)+3)>>0]|0)&63;i=t[b>>2]|0;if((t[b>>2]|0)<256){if(!(9<=(i|0)&(t[b>>2]|0)<=10|(t[b>>2]|0)==13|32<=(t[b>>2]|0))){w=50;break}}else if((!(256<=(i|0)&(t[b>>2]|0)<=55295)?!(57344<=(t[b>>2]|0)&(t[b>>2]|0)<=65533):0)?!(65536<=(t[b>>2]|0)&(t[b>>2]|0)<=1114111):0){w=50;break}t[c>>2]=(t[c>>2]|0)+4}switch(w|0){case 12:{t[f>>2]=0-(t[c>>2]|0);k=t[f>>2]|0;s=r;return k|0}case 15:{t[f>>2]=d;k=t[f>>2]|0;s=r;return k|0}case 17:{t[f>>2]=0-v;k=t[f>>2]|0;s=r;return k|0}case 23:{t[f>>2]=0-(t[c>>2]|0);k=t[f>>2]|0;s=r;return k|0}case 27:{t[f>>2]=m;k=t[f>>2]|0;s=r;return k|0}case 30:{t[f>>2]=0-(t[c>>2]|0);k=t[f>>2]|0;s=r;return k|0}case 36:{t[f>>2]=0-(t[c>>2]|0);k=t[f>>2]|0;s=r;return k|0}case 40:{t[f>>2]=p;k=t[f>>2]|0;s=r;return k|0}case 44:{t[f>>2]=0-(t[c>>2]|0);k=t[f>>2]|0;s=r;return k|0}case 50:{t[f>>2]=0-(t[c>>2]|0);k=t[f>>2]|0;s=r;return k|0}case 52:{t[f>>2]=0-_;k=t[f>>2]|0;s=r;return k|0}case 53:{t[f>>2]=h;k=t[f>>2]|0;s=r;return k|0}}return 0}function Ig(e){e=e|0;var i=0,r=0,n=0,f=0,a=0,o=0,c=0,l=0,b=0,k=0;i=s;s=s+32|0;r=i+16|0;n=i+12|0;f=i+8|0;a=i+4|0;o=i;t[n>>2]=e;t[o>>2]=0;t[f>>2]=t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2];if((u[t[f>>2]>>0]|0|0)>=97?(u[t[f>>2]>>0]|0|0)<=122:0)c=6;else c=3;do if((c|0)==3){if((u[t[f>>2]>>0]|0|0)>=65?(u[t[f>>2]>>0]|0|0)<=90:0){c=6;break}if((u[t[f>>2]>>0]|0|0)==95)c=6}while(0);if((c|0)==6){t[f>>2]=(t[f>>2]|0)+1;while(1){if((u[t[f>>2]>>0]|0|0)>=97?(u[t[f>>2]>>0]|0|0)<=122:0)l=1;else c=9;do if((c|0)==9){c=0;if((u[t[f>>2]>>0]|0|0)>=65?(u[t[f>>2]>>0]|0|0)<=90:0){l=1;break}if((u[t[f>>2]>>0]|0|0)>=48?(u[t[f>>2]>>0]|0|0)<=57:0){l=1;break}if((u[t[f>>2]>>0]|0|0)!=95?(u[t[f>>2]>>0]|0|0)!=45:0)l=(u[t[f>>2]>>0]|0|0)==46;else l=1}while(0);b=t[f>>2]|0;if(!l)break;t[f>>2]=b+1}if((u[b>>0]|0|0)>0?(u[t[f>>2]>>0]|0|0)<128:0){t[o>>2]=(t[f>>2]|0)-(t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]|0);if((t[o>>2]|0)>5e4?(t[(t[n>>2]|0)+360>>2]&524288|0)==0:0){AS(t[n>>2]|0,110,70920);t[r>>2]=0;k=t[r>>2]|0;s=i;return k|0}t[a>>2]=kz(t[(t[n>>2]|0)+296>>2]|0,t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]|0,t[o>>2]|0)|0;t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]=t[f>>2];f=(t[n>>2]|0)+200|0;t[f>>2]=(t[f>>2]|0)+(t[o>>2]|0);f=(t[(t[n>>2]|0)+36>>2]|0)+32|0;t[f>>2]=(t[f>>2]|0)+(t[o>>2]|0);if(!(t[a>>2]|0))Sp(t[n>>2]|0,0);t[r>>2]=t[a>>2];k=t[r>>2]|0;s=i;return k|0}}t[r>>2]=xg(t[n>>2]|0)|0;k=t[r>>2]|0;s=i;return k|0}function Hg(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0;n=s;s=s+48|0;f=n+32|0;a=n+28|0;o=n+24|0;c=n+20|0;l=n+16|0;b=n+12|0;k=n+8|0;h=n+4|0;w=n;t[a>>2]=e;t[o>>2]=i;t[c>>2]=r;t[b>>2]=0;t[k>>2]=0;if((t[a>>2]|0)==0|(t[o>>2]|0)==0|(t[c>>2]|0)==0){t[f>>2]=0;d=t[f>>2]|0;s=n;return d|0}t[l>>2]=t[t[c>>2]>>2];if((t[l>>2]|0)<=0){t[f>>2]=0;d=t[f>>2]|0;s=n;return d|0}t[h>>2]=t[o>>2];while(1){if((u[t[h>>2]>>0]|0|0)!=32)break;t[h>>2]=(t[h>>2]|0)+1;t[b>>2]=(t[b>>2]|0)+1}while(1){if(!(u[t[h>>2]>>0]|0))break;r=(u[t[h>>2]>>0]|0|0)==32;t[h>>2]=(t[h>>2]|0)+1;if(!r)continue;if((u[t[h>>2]>>0]|0|0)==32){v=12;break}if(!(u[t[h>>2]>>0]|0)){v=12;break}}if((v|0)==12)t[k>>2]=1;if(t[k>>2]|0){t[w>>2]=ql((t[o>>2]|0)+(t[b>>2]|0)|0,(t[l>>2]|0)-(t[b>>2]|0)+1|0)|0;if(!(t[w>>2]|0)){Sp(t[a>>2]|0,0);t[f>>2]=0;d=t[f>>2]|0;s=n;return d|0}else{JS(t[w>>2]|0,t[w>>2]|0)|0;a=HY(t[w>>2]|0)|0;t[t[c>>2]>>2]=a;t[f>>2]=t[w>>2];d=t[f>>2]|0;s=n;return d|0}}else if(t[b>>2]|0){w=t[c>>2]|0;t[w>>2]=(t[w>>2]|0)-(t[b>>2]|0);GY(t[o>>2]|0,(t[o>>2]|0)+(t[b>>2]|0)|0,1+(t[t[c>>2]>>2]|0)|0)|0;t[f>>2]=t[o>>2];d=t[f>>2]|0;s=n;return d|0}else{t[f>>2]=0;d=t[f>>2]|0;s=n;return d|0}return 0}function xg(e){e=e|0;var i=0,r=0,n=0,f=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0;i=s;s=s+32|0;r=i+24|0;n=i+20|0;f=i+16|0;a=i+12|0;o=i+8|0;c=i+4|0;l=i;t[n>>2]=e;t[f>>2]=0;t[c>>2]=0;if((t[(t[n>>2]|0)+292>>2]|0)==0?((t[(t[(t[n>>2]|0)+36>>2]|0)+20>>2]|0)-(t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]|0)|0)<250:0)CS(t[n>>2]|0);t[l>>2]=t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2];t[o>>2]=Ap(t[n>>2]|0,a)|0;if(!((t[o>>2]|0)==32|(t[o>>2]|0)==62|(t[o>>2]|0)==47)?(e=(gg(t[n>>2]|0,t[o>>2]|0)|0)==0,!(e|(t[o>>2]|0)==58)):0){while(1){if(!((t[o>>2]|0)!=32&(t[o>>2]|0)!=62&(t[o>>2]|0)!=47)){b=30;break}e=(zS(t[n>>2]|0,t[o>>2]|0)|0)!=0;if(!(e&(t[o>>2]|0)!=58)){b=30;break}e=t[c>>2]|0;t[c>>2]=e+1;if((e|0)>100){if((t[f>>2]|0)>5e4?(t[(t[n>>2]|0)+360>>2]&524288|0)==0:0){b=12;break}t[c>>2]=0;if((t[(t[n>>2]|0)+292>>2]|0)==0?((t[(t[(t[n>>2]|0)+36>>2]|0)+20>>2]|0)-(t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]|0)|0)<250:0)CS(t[n>>2]|0);if((t[(t[n>>2]|0)+172>>2]|0)==-1){b=17;break}}t[f>>2]=(t[f>>2]|0)+(t[a>>2]|0);e=t[(t[n>>2]|0)+36>>2]|0;if((u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==10){k=e+28|0;t[k>>2]=(t[k>>2]|0)+1;t[(t[(t[n>>2]|0)+36>>2]|0)+32>>2]=1}else{k=e+32|0;t[k>>2]=(t[k>>2]|0)+1}k=(t[(t[n>>2]|0)+36>>2]|0)+16|0;t[k>>2]=(t[k>>2]|0)+(t[a>>2]|0);if((u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==37)oE(t[n>>2]|0);t[l>>2]=t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2];t[o>>2]=Ap(t[n>>2]|0,a)|0;if(t[o>>2]|0)continue;t[c>>2]=0;if((t[(t[n>>2]|0)+292>>2]|0)==0?((t[(t[(t[n>>2]|0)+36>>2]|0)+20>>2]|0)-(t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]|0)|0)<250:0)CS(t[n>>2]|0);if((t[(t[n>>2]|0)+172>>2]|0)==-1){b=28;break}t[l>>2]=t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2];t[o>>2]=Ap(t[n>>2]|0,a)|0}if((b|0)==12){AS(t[n>>2]|0,110,70920);t[r>>2]=0;h=t[r>>2]|0;s=i;return h|0}else if((b|0)==17){t[r>>2]=0;h=t[r>>2]|0;s=i;return h|0}else if((b|0)==28){t[r>>2]=0;h=t[r>>2]|0;s=i;return h|0}else if((b|0)==30){if((t[f>>2]|0)>5e4?(t[(t[n>>2]|0)+360>>2]&524288|0)==0:0){AS(t[n>>2]|0,110,70920);t[r>>2]=0;h=t[r>>2]|0;s=i;return h|0}t[r>>2]=kz(t[(t[n>>2]|0)+296>>2]|0,(t[l>>2]|0)+(0-(t[f>>2]|0))|0,t[f>>2]|0)|0;h=t[r>>2]|0;s=i;return h|0}}t[r>>2]=0;h=t[r>>2]|0;s=i;return h|0}function Ug(e,i,r,f){e=e|0;i=i|0;r=r|0;f=f|0;var u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0;
	u=s;s=s+32|0;a=u+28|0;o=u+24|0;c=u+20|0;l=u+16|0;b=u+12|0;k=u+8|0;h=u+4|0;w=u;t[o>>2]=e;t[c>>2]=i;t[l>>2]=r;t[b>>2]=f;if(!(t[o>>2]|0)){t[a>>2]=0;d=t[a>>2]|0;s=u;return d|0}f=t[o>>2]|0;if(!(t[c>>2]|0)){t[a>>2]=f;d=t[a>>2]|0;s=u;return d|0}t[k>>2]=HY(f|0)|0;t[h>>2]=HY(t[c>>2]|0)|0;if((t[l>>2]|0)!=0?(t[b>>2]|0)>=((t[k>>2]|0)+(t[h>>2]|0)+2|0):0)t[w>>2]=t[l>>2];else v=7;if((v|0)==7?(t[w>>2]=gAi[t[135752>>2]&511]((t[k>>2]|0)+(t[h>>2]|0)+2|0)|0,(t[w>>2]|0)==0):0){LF(75136);t[a>>2]=0;d=t[a>>2]|0;s=u;return d|0}YY(t[w>>2]|0,t[c>>2]|0,t[h>>2]|0)|0;n[(t[w>>2]|0)+(t[h>>2]|0)>>0]=58;YY((t[w>>2]|0)+((t[h>>2]|0)+1)|0,t[o>>2]|0,t[k>>2]|0)|0;n[(t[w>>2]|0)+((t[k>>2]|0)+(t[h>>2]|0)+1)>>0]=0;t[a>>2]=t[w>>2];d=t[a>>2]|0;s=u;return d|0}function zg(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,a=0,o=0,c=0,l=0,b=0,k=0;r=s;s=s+32|0;n=r+16|0;f=r+12|0;a=r+8|0;o=r+4|0;c=r;t[f>>2]=e;t[a>>2]=i;t[o>>2]=0;t[c>>2]=0;if(!(t[a>>2]|0)){t[n>>2]=0;l=t[n>>2]|0;s=r;return l|0}t[t[a>>2]>>2]=0;if(!(t[f>>2]|0)){t[n>>2]=0;l=t[n>>2]|0;s=r;return l|0}if((u[t[f>>2]>>0]|0|0)==58){t[n>>2]=0;l=t[n>>2]|0;s=r;return l|0}while(1){if(u[(t[f>>2]|0)+(t[o>>2]|0)>>0]|0)b=(u[(t[f>>2]|0)+(t[o>>2]|0)>>0]|0|0)!=58;else b=0;k=t[o>>2]|0;if(!b)break;t[o>>2]=k+1}if(!(u[(t[f>>2]|0)+k>>0]|0)){t[n>>2]=0;l=t[n>>2]|0;s=r;return l|0}k=ql(t[f>>2]|0,t[o>>2]|0)|0;t[t[a>>2]>>2]=k;if(!(t[t[a>>2]>>2]|0)){LF(75152);t[n>>2]=0;l=t[n>>2]|0;s=r;return l|0}t[c>>2]=Yl((t[f>>2]|0)+((t[o>>2]|0)+1)|0)|0;if(t[c>>2]|0){t[n>>2]=t[c>>2];l=t[n>>2]|0;s=r;return l|0}LF(75152);if(t[t[a>>2]>>2]|0){pAi[t[135736>>2]&511](t[t[a>>2]>>2]|0);t[t[a>>2]>>2]=0}t[n>>2]=0;l=t[n>>2]|0;s=r;return l|0}function jg(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,a=0,o=0,c=0,l=0;r=s;s=s+16|0;n=r+12|0;f=r+8|0;a=r+4|0;o=r;t[f>>2]=e;t[a>>2]=i;t[o>>2]=0;do if(t[f>>2]|0){if(!(t[a>>2]|0)){t[n>>2]=0;break}if((u[t[f>>2]>>0]|0|0)==58){t[n>>2]=0;break}while(1){if(u[(t[f>>2]|0)+(t[o>>2]|0)>>0]|0)c=(u[(t[f>>2]|0)+(t[o>>2]|0)>>0]|0|0)!=58;else c=0;l=t[o>>2]|0;if(!c)break;t[o>>2]=l+1}if(!(u[(t[f>>2]|0)+l>>0]|0)){t[n>>2]=0;break}else{t[t[a>>2]>>2]=t[o>>2];t[n>>2]=(t[f>>2]|0)+((t[o>>2]|0)+1);break}}else t[n>>2]=0;while(0);s=r;return t[n>>2]|0}function Vg(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0;r=s;s=s+32|0;n=r+20|0;f=r+16|0;a=r+12|0;o=r+8|0;c=r+4|0;l=r;t[f>>2]=e;t[a>>2]=i;t[o>>2]=t[f>>2];if(!(t[f>>2]|0)){t[n>>2]=-1;b=t[n>>2]|0;s=r;return b|0}e:do if(t[a>>2]|0)while(1){do if((u[t[o>>2]>>0]|0|0)!=32){if(9<=(u[t[o>>2]>>0]|0|0)?(u[t[o>>2]>>0]|0|0)<=10:0)break;if((u[t[o>>2]>>0]|0|0)!=13)break e}while(0);t[o>>2]=(t[o>>2]|0)+1}while(0);if((u[t[o>>2]>>0]|0|0)>=97?(u[t[o>>2]>>0]|0|0)<=122:0)k=14;else k=11;do if((k|0)==11){if((u[t[o>>2]>>0]|0|0)>=65?(u[t[o>>2]>>0]|0|0)<=90:0){k=14;break}if((u[t[o>>2]>>0]|0|0)==95)k=14}while(0);if((k|0)==14){t[o>>2]=(t[o>>2]|0)+1;e:while(1){if(!((u[t[o>>2]>>0]|0|0)>=97?(u[t[o>>2]>>0]|0|0)<=122:0))k=17;do if((k|0)==17){k=0;if((u[t[o>>2]>>0]|0|0)>=65?(u[t[o>>2]>>0]|0|0)<=90:0)break;if((u[t[o>>2]>>0]|0|0)>=48?(u[t[o>>2]>>0]|0|0)<=57:0)break;if(((u[t[o>>2]>>0]|0|0)!=95?(u[t[o>>2]>>0]|0|0)!=45:0)?(u[t[o>>2]>>0]|0|0)!=46:0)break e}while(0);t[o>>2]=(t[o>>2]|0)+1}e:do if(t[a>>2]|0)while(1){do if((u[t[o>>2]>>0]|0|0)!=32){if(9<=(u[t[o>>2]>>0]|0|0)?(u[t[o>>2]>>0]|0|0)<=10:0)break;if((u[t[o>>2]>>0]|0|0)!=13)break e}while(0);t[o>>2]=(t[o>>2]|0)+1}while(0);if(!(u[t[o>>2]>>0]|0)){t[n>>2]=0;b=t[n>>2]|0;s=r;return b|0}}t[o>>2]=t[f>>2];t[c>>2]=Mp(0,t[o>>2]|0,l)|0;e:do if(t[a>>2]|0)while(1){if((t[c>>2]|0)<256){if((t[c>>2]|0)!=32?!(9<=(t[c>>2]|0)&(t[c>>2]|0)<=10):0)h=(t[c>>2]|0)==13;else h=1;w=h&1}else w=0;if(!w)break e;t[o>>2]=(t[o>>2]|0)+(t[l>>2]|0);t[c>>2]=Mp(0,t[o>>2]|0,l)|0}while(0);w=t[c>>2]|0;if((t[c>>2]|0)<256){if(((!(65<=(w|0)&(t[c>>2]|0)<=90)?!(97<=(t[c>>2]|0)&(t[c>>2]|0)<=122):0)?!(192<=(t[c>>2]|0)&(t[c>>2]|0)<=214):0)?!(216<=(t[c>>2]|0)&(t[c>>2]|0)<=246|248<=(t[c>>2]|0)):0)k=47}else if(!(dj(w,199744)|0))k=47;do if((k|0)==47){w=t[c>>2]|0;if((t[c>>2]|0)<256){if((w|0)==95)break}else{if(19968<=(w|0)&(t[c>>2]|0)<=40869|(t[c>>2]|0)==12295)break;if(!((12321<=(t[c>>2]|0)&(t[c>>2]|0)<=12329^1)&(t[c>>2]|0)!=95))break}t[n>>2]=1;b=t[n>>2]|0;s=r;return b|0}while(0);t[o>>2]=(t[o>>2]|0)+(t[l>>2]|0);t[c>>2]=Mp(0,t[o>>2]|0,l)|0;e:while(1){w=t[c>>2]|0;if((t[c>>2]|0)<256){if(((!(65<=(w|0)&(t[c>>2]|0)<=90)?!(97<=(t[c>>2]|0)&(t[c>>2]|0)<=122):0)?!(192<=(t[c>>2]|0)&(t[c>>2]|0)<=214):0)?!(216<=(t[c>>2]|0)&(t[c>>2]|0)<=246|248<=(t[c>>2]|0)):0)k=59}else if(!(dj(w,199744)|0))k=59;do if((k|0)==59){k=0;if((t[c>>2]|0)>=256){if(19968<=(t[c>>2]|0)&(t[c>>2]|0)<=40869|(t[c>>2]|0)==12295)break;if(12321<=(t[c>>2]|0)&(t[c>>2]|0)<=12329)break}w=t[c>>2]|0;if((t[c>>2]|0)<256){if(48<=(w|0)&(t[c>>2]|0)<=57|(t[c>>2]|0)==46|(t[c>>2]|0)==45|(t[c>>2]|0)==95)break}else{h=(dj(w,200216)|0)!=0;if(h|(t[c>>2]|0)==46|(t[c>>2]|0)==45|(t[c>>2]|0)==95)break}if((t[c>>2]|0)>=256?(dj(t[c>>2]|0,200144)|0)!=0:0)break;h=t[c>>2]|0;if((t[c>>2]|0)<256)d=(h|0)==183&1;else d=dj(h,200272)|0;if(!d)break e}while(0);t[o>>2]=(t[o>>2]|0)+(t[l>>2]|0);t[c>>2]=Mp(0,t[o>>2]|0,l)|0}e:do if(t[a>>2]|0)while(1){if((t[c>>2]|0)<256){if((t[c>>2]|0)!=32?!(9<=(t[c>>2]|0)&(t[c>>2]|0)<=10):0)v=(t[c>>2]|0)==13;else v=1;m=v&1}else m=0;if(!m)break e;t[o>>2]=(t[o>>2]|0)+(t[l>>2]|0);t[c>>2]=Mp(0,t[o>>2]|0,l)|0}while(0);if(t[c>>2]|0){t[n>>2]=1;b=t[n>>2]|0;s=r;return b|0}else{t[n>>2]=0;b=t[n>>2]|0;s=r;return b|0}return 0}function qg(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0;r=s;s=s+32|0;n=r+20|0;f=r+16|0;a=r+12|0;o=r+8|0;c=r+4|0;l=r;t[f>>2]=e;t[a>>2]=i;t[o>>2]=t[f>>2];if(!(t[f>>2]|0)){t[n>>2]=-1;b=t[n>>2]|0;s=r;return b|0}e:do if(t[a>>2]|0)while(1){do if((u[t[o>>2]>>0]|0|0)!=32){if(9<=(u[t[o>>2]>>0]|0|0)?(u[t[o>>2]>>0]|0|0)<=10:0)break;if((u[t[o>>2]>>0]|0|0)!=13)break e}while(0);t[o>>2]=(t[o>>2]|0)+1}while(0);if((u[t[o>>2]>>0]|0|0)>=97?(u[t[o>>2]>>0]|0|0)<=122:0)k=14;else k=11;do if((k|0)==11){if((u[t[o>>2]>>0]|0|0)>=65?(u[t[o>>2]>>0]|0|0)<=90:0){k=14;break}if((u[t[o>>2]>>0]|0|0)==95)k=14}while(0);e:do if((k|0)==14){t[o>>2]=(t[o>>2]|0)+1;while(1){if((u[t[o>>2]>>0]|0|0)>=97?(u[t[o>>2]>>0]|0|0)<=122:0)h=1;else k=17;do if((k|0)==17){k=0;if((u[t[o>>2]>>0]|0|0)>=65?(u[t[o>>2]>>0]|0|0)<=90:0){h=1;break}if((u[t[o>>2]>>0]|0|0)>=48?(u[t[o>>2]>>0]|0|0)<=57:0){h=1;break}if((u[t[o>>2]>>0]|0|0)!=95?(u[t[o>>2]>>0]|0|0)!=45:0)h=(u[t[o>>2]>>0]|0|0)==46;else h=1}while(0);w=t[o>>2]|0;if(!h)break;t[o>>2]=w+1}i:do if((u[w>>0]|0|0)==58){t[o>>2]=(t[o>>2]|0)+1;if(!((u[t[o>>2]>>0]|0|0)>=97?(u[t[o>>2]>>0]|0|0)<=122:0))k=29;do if((k|0)==29){if((u[t[o>>2]>>0]|0|0)>=65?(u[t[o>>2]>>0]|0|0)<=90:0)break;if((u[t[o>>2]>>0]|0|0)!=95)break e}while(0);t[o>>2]=(t[o>>2]|0)+1;while(1){if(!((u[t[o>>2]>>0]|0|0)>=97?(u[t[o>>2]>>0]|0|0)<=122:0))k=35;do if((k|0)==35){k=0;if((u[t[o>>2]>>0]|0|0)>=65?(u[t[o>>2]>>0]|0|0)<=90:0)break;if((u[t[o>>2]>>0]|0|0)>=48?(u[t[o>>2]>>0]|0|0)<=57:0)break;if(((u[t[o>>2]>>0]|0|0)!=95?(u[t[o>>2]>>0]|0|0)!=45:0)?(u[t[o>>2]>>0]|0|0)!=46:0)break i}while(0);t[o>>2]=(t[o>>2]|0)+1}}while(0);i:do if(t[a>>2]|0)while(1){do if((u[t[o>>2]>>0]|0|0)!=32){if(9<=(u[t[o>>2]>>0]|0|0)?(u[t[o>>2]>>0]|0|0)<=10:0)break;if((u[t[o>>2]>>0]|0|0)!=13)break i}while(0);t[o>>2]=(t[o>>2]|0)+1}while(0);if(!(u[t[o>>2]>>0]|0)){t[n>>2]=0;b=t[n>>2]|0;s=r;return b|0}}while(0);t[o>>2]=t[f>>2];t[c>>2]=Mp(0,t[o>>2]|0,l)|0;e:do if(t[a>>2]|0)while(1){if((t[c>>2]|0)<256){if((t[c>>2]|0)!=32?!(9<=(t[c>>2]|0)&(t[c>>2]|0)<=10):0)d=(t[c>>2]|0)==13;else d=1;v=d&1}else v=0;if(!v)break e;t[o>>2]=(t[o>>2]|0)+(t[l>>2]|0);t[c>>2]=Mp(0,t[o>>2]|0,l)|0}while(0);v=t[c>>2]|0;if((t[c>>2]|0)<256){if(((!(65<=(v|0)&(t[c>>2]|0)<=90)?!(97<=(t[c>>2]|0)&(t[c>>2]|0)<=122):0)?!(192<=(t[c>>2]|0)&(t[c>>2]|0)<=214):0)?!(216<=(t[c>>2]|0)&(t[c>>2]|0)<=246|248<=(t[c>>2]|0)):0)k=65}else if(!(dj(v,199744)|0))k=65;do if((k|0)==65){v=t[c>>2]|0;if((t[c>>2]|0)<256){if((v|0)==95)break}else{if(19968<=(v|0)&(t[c>>2]|0)<=40869|(t[c>>2]|0)==12295)break;if(!((12321<=(t[c>>2]|0)&(t[c>>2]|0)<=12329^1)&(t[c>>2]|0)!=95))break}t[n>>2]=1;b=t[n>>2]|0;s=r;return b|0}while(0);t[o>>2]=(t[o>>2]|0)+(t[l>>2]|0);t[c>>2]=Mp(0,t[o>>2]|0,l)|0;e:while(1){v=t[c>>2]|0;if((t[c>>2]|0)<256){if(((!(65<=(v|0)&(t[c>>2]|0)<=90)?!(97<=(t[c>>2]|0)&(t[c>>2]|0)<=122):0)?!(192<=(t[c>>2]|0)&(t[c>>2]|0)<=214):0)?!(216<=(t[c>>2]|0)&(t[c>>2]|0)<=246|248<=(t[c>>2]|0)):0)k=77}else if(!(dj(v,199744)|0))k=77;do if((k|0)==77){k=0;if((t[c>>2]|0)>=256){if(19968<=(t[c>>2]|0)&(t[c>>2]|0)<=40869|(t[c>>2]|0)==12295)break;if(12321<=(t[c>>2]|0)&(t[c>>2]|0)<=12329)break}v=t[c>>2]|0;if((t[c>>2]|0)<256){if(48<=(v|0)&(t[c>>2]|0)<=57|(t[c>>2]|0)==46|(t[c>>2]|0)==45|(t[c>>2]|0)==95)break}else{d=(dj(v,200216)|0)!=0;if(d|(t[c>>2]|0)==46|(t[c>>2]|0)==45|(t[c>>2]|0)==95)break}if((t[c>>2]|0)>=256?(dj(t[c>>2]|0,200144)|0)!=0:0)break;d=t[c>>2]|0;if((t[c>>2]|0)<256)m=(d|0)==183&1;else m=dj(d,200272)|0;if(!m)break e}while(0);t[o>>2]=(t[o>>2]|0)+(t[l>>2]|0);t[c>>2]=Mp(0,t[o>>2]|0,l)|0}e:do if((t[c>>2]|0)==58){t[o>>2]=(t[o>>2]|0)+(t[l>>2]|0);t[c>>2]=Mp(0,t[o>>2]|0,l)|0;m=t[c>>2]|0;if((t[c>>2]|0)<256){if(((!(65<=(m|0)&(t[c>>2]|0)<=90)?!(97<=(t[c>>2]|0)&(t[c>>2]|0)<=122):0)?!(192<=(t[c>>2]|0)&(t[c>>2]|0)<=214):0)?!(216<=(t[c>>2]|0)&(t[c>>2]|0)<=246|248<=(t[c>>2]|0)):0)k=97}else if(!(dj(m,199744)|0))k=97;do if((k|0)==97){m=t[c>>2]|0;if((t[c>>2]|0)<256){if((m|0)==95)break}else{if(19968<=(m|0)&(t[c>>2]|0)<=40869|(t[c>>2]|0)==12295)break;if(!((12321<=(t[c>>2]|0)&(t[c>>2]|0)<=12329^1)&(t[c>>2]|0)!=95))break}t[n>>2]=1;b=t[n>>2]|0;s=r;return b|0}while(0);t[o>>2]=(t[o>>2]|0)+(t[l>>2]|0);t[c>>2]=Mp(0,t[o>>2]|0,l)|0;while(1){m=t[c>>2]|0;if((t[c>>2]|0)<256){if(((!(65<=(m|0)&(t[c>>2]|0)<=90)?!(97<=(t[c>>2]|0)&(t[c>>2]|0)<=122):0)?!(192<=(t[c>>2]|0)&(t[c>>2]|0)<=214):0)?!(216<=(t[c>>2]|0)&(t[c>>2]|0)<=246|248<=(t[c>>2]|0)):0)k=109}else if(!(dj(m,199744)|0))k=109;do if((k|0)==109){k=0;if((t[c>>2]|0)>=256){if(19968<=(t[c>>2]|0)&(t[c>>2]|0)<=40869|(t[c>>2]|0)==12295)break;if(12321<=(t[c>>2]|0)&(t[c>>2]|0)<=12329)break}m=t[c>>2]|0;if((t[c>>2]|0)<256){if(48<=(m|0)&(t[c>>2]|0)<=57|(t[c>>2]|0)==46|(t[c>>2]|0)==45|(t[c>>2]|0)==95)break}else{d=(dj(m,200216)|0)!=0;if(d|(t[c>>2]|0)==46|(t[c>>2]|0)==45|(t[c>>2]|0)==95)break}if((t[c>>2]|0)>=256?(dj(t[c>>2]|0,200144)|0)!=0:0)break;d=t[c>>2]|0;if((t[c>>2]|0)<256)_=(d|0)==183&1;else _=dj(d,200272)|0;if(!_)break e}while(0);t[o>>2]=(t[o>>2]|0)+(t[l>>2]|0);t[c>>2]=Mp(0,t[o>>2]|0,l)|0}}while(0);e:do if(t[a>>2]|0)while(1){if((t[c>>2]|0)<256){if((t[c>>2]|0)!=32?!(9<=(t[c>>2]|0)&(t[c>>2]|0)<=10):0)p=(t[c>>2]|0)==13;else p=1;E=p&1}else E=0;if(!E)break e;t[o>>2]=(t[o>>2]|0)+(t[l>>2]|0);t[c>>2]=Mp(0,t[o>>2]|0,l)|0}while(0);if(t[c>>2]|0){t[n>>2]=1;b=t[n>>2]|0;s=r;return b|0}else{t[n>>2]=0;b=t[n>>2]|0;s=r;return b|0}return 0}function Yg(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0;r=s;s=s+32|0;n=r+20|0;f=r+16|0;a=r+12|0;o=r+8|0;c=r+4|0;l=r;t[f>>2]=e;t[a>>2]=i;t[o>>2]=t[f>>2];if(!(t[f>>2]|0)){t[n>>2]=-1;b=t[n>>2]|0;s=r;return b|0}e:do if(t[a>>2]|0)while(1){do if((u[t[o>>2]>>0]|0|0)!=32){if(9<=(u[t[o>>2]>>0]|0|0)?(u[t[o>>2]>>0]|0|0)<=10:0)break;if((u[t[o>>2]>>0]|0|0)!=13)break e}while(0);t[o>>2]=(t[o>>2]|0)+1}while(0);if((u[t[o>>2]>>0]|0|0)>=97?(u[t[o>>2]>>0]|0|0)<=122:0)k=15;else k=11;do if((k|0)==11){if((u[t[o>>2]>>0]|0|0)>=65?(u[t[o>>2]>>0]|0|0)<=90:0){k=15;break}if(!((u[t[o>>2]>>0]|0|0)!=95?(u[t[o>>2]>>0]|0|0)!=58:0))k=15}while(0);if((k|0)==15){t[o>>2]=(t[o>>2]|0)+1;e:while(1){if(!((u[t[o>>2]>>0]|0|0)>=97?(u[t[o>>2]>>0]|0|0)<=122:0))k=18;do if((k|0)==18){k=0;if((u[t[o>>2]>>0]|0|0)>=65?(u[t[o>>2]>>0]|0|0)<=90:0)break;if((u[t[o>>2]>>0]|0|0)>=48?(u[t[o>>2]>>0]|0|0)<=57:0)break;if((((u[t[o>>2]>>0]|0|0)!=95?(u[t[o>>2]>>0]|0|0)!=45:0)?(u[t[o>>2]>>0]|0|0)!=46:0)?(u[t[o>>2]>>0]|0|0)!=58:0)break e}while(0);t[o>>2]=(t[o>>2]|0)+1}e:do if(t[a>>2]|0)while(1){do if((u[t[o>>2]>>0]|0|0)!=32){if(9<=(u[t[o>>2]>>0]|0|0)?(u[t[o>>2]>>0]|0|0)<=10:0)break;if((u[t[o>>2]>>0]|0|0)!=13)break e}while(0);t[o>>2]=(t[o>>2]|0)+1}while(0);if(!(u[t[o>>2]>>0]|0)){t[n>>2]=0;b=t[n>>2]|0;s=r;return b|0}}t[o>>2]=t[f>>2];t[c>>2]=Mp(0,t[o>>2]|0,l)|0;e:do if(t[a>>2]|0)while(1){if((t[c>>2]|0)<256){if((t[c>>2]|0)!=32?!(9<=(t[c>>2]|0)&(t[c>>2]|0)<=10):0)h=(t[c>>2]|0)==13;else h=1;w=h&1}else w=0;if(!w)break e;t[o>>2]=(t[o>>2]|0)+(t[l>>2]|0);t[c>>2]=Mp(0,t[o>>2]|0,l)|0}while(0);w=t[c>>2]|0;if((t[c>>2]|0)<256){if(((!(65<=(w|0)&(t[c>>2]|0)<=90)?!(97<=(t[c>>2]|0)&(t[c>>2]|0)<=122):0)?!(192<=(t[c>>2]|0)&(t[c>>2]|0)<=214):0)?!(216<=(t[c>>2]|0)&(t[c>>2]|0)<=246|248<=(t[c>>2]|0)):0)k=49}else if(!(dj(w,199744)|0))k=49;do if((k|0)==49){w=t[c>>2]|0;if((t[c>>2]|0)<256){if(!((w|0)!=95&(t[c>>2]|0)!=58))break}else{if(19968<=(w|0)&(t[c>>2]|0)<=40869|(t[c>>2]|0)==12295)break;if(!((12321<=(t[c>>2]|0)&(t[c>>2]|0)<=12329^1)&(t[c>>2]|0)!=95&(t[c>>2]|0)!=58))break}t[n>>2]=1;b=t[n>>2]|0;s=r;return b|0}while(0);t[o>>2]=(t[o>>2]|0)+(t[l>>2]|0);t[c>>2]=Mp(0,t[o>>2]|0,l)|0;e:while(1){w=t[c>>2]|0;if((t[c>>2]|0)<256){if(((!(65<=(w|0)&(t[c>>2]|0)<=90)?!(97<=(t[c>>2]|0)&(t[c>>2]|0)<=122):0)?!(192<=(t[c>>2]|0)&(t[c>>2]|0)<=214):0)?!(216<=(t[c>>2]|0)&(t[c>>2]|0)<=246|248<=(t[c>>2]|0)):0)k=61}else if(!(dj(w,199744)|0))k=61;do if((k|0)==61){k=0;if((t[c>>2]|0)>=256){if(19968<=(t[c>>2]|0)&(t[c>>2]|0)<=40869|(t[c>>2]|0)==12295)break;if(12321<=(t[c>>2]|0)&(t[c>>2]|0)<=12329)break}w=t[c>>2]|0;if((t[c>>2]|0)<256){if(48<=(w|0)&(t[c>>2]|0)<=57|(t[c>>2]|0)==46|(t[c>>2]|0)==58|(t[c>>2]|0)==45|(t[c>>2]|0)==95)break}else{h=(dj(w,200216)|0)!=0;if(h|(t[c>>2]|0)==46|(t[c>>2]|0)==58|(t[c>>2]|0)==45|(t[c>>2]|0)==95)break}if((t[c>>2]|0)>=256?(dj(t[c>>2]|0,200144)|0)!=0:0)break;h=t[c>>2]|0;if((t[c>>2]|0)<256)d=(h|0)==183&1;else d=dj(h,200272)|0;if(!d)break e}while(0);t[o>>2]=(t[o>>2]|0)+(t[l>>2]|0);t[c>>2]=Mp(0,t[o>>2]|0,l)|0}e:do if(t[a>>2]|0)while(1){if((t[c>>2]|0)<256){if((t[c>>2]|0)!=32?!(9<=(t[c>>2]|0)&(t[c>>2]|0)<=10):0)v=(t[c>>2]|0)==13;else v=1;m=v&1}else m=0;if(!m)break e;t[o>>2]=(t[o>>2]|0)+(t[l>>2]|0);t[c>>2]=Mp(0,t[o>>2]|0,l)|0}while(0);if(t[c>>2]|0){t[n>>2]=1;b=t[n>>2]|0;s=r;return b|0}else{t[n>>2]=0;b=t[n>>2]|0;s=r;return b|0}return 0}function Gg(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0;r=s;s=s+32|0;n=r+20|0;f=r+16|0;a=r+12|0;o=r+8|0;c=r+4|0;l=r;t[f>>2]=e;t[a>>2]=i;t[o>>2]=t[f>>2];if(!(t[f>>2]|0)){t[n>>2]=-1;b=t[n>>2]|0;s=r;return b|0}e:do if(t[a>>2]|0)while(1){do if((u[t[o>>2]>>0]|0|0)!=32){if(9<=(u[t[o>>2]>>0]|0|0)?(u[t[o>>2]>>0]|0|0)<=10:0)break;if((u[t[o>>2]>>0]|0|0)!=13)break e}while(0);t[o>>2]=(t[o>>2]|0)+1}while(0);if((u[t[o>>2]>>0]|0|0)>=97?(u[t[o>>2]>>0]|0|0)<=122:0)k=19;else k=11;do if((k|0)==11){if((u[t[o>>2]>>0]|0|0)>=65?(u[t[o>>2]>>0]|0|0)<=90:0){k=19;break}if((u[t[o>>2]>>0]|0|0)>=48?(u[t[o>>2]>>0]|0|0)<=57:0){k=19;break}if(!((((u[t[o>>2]>>0]|0|0)!=95?(u[t[o>>2]>>0]|0|0)!=45:0)?(u[t[o>>2]>>0]|0|0)!=46:0)?(u[t[o>>2]>>0]|0|0)!=58:0))k=19}while(0);if((k|0)==19){t[o>>2]=(t[o>>2]|0)+1;e:while(1){if(!((u[t[o>>2]>>0]|0|0)>=97?(u[t[o>>2]>>0]|0|0)<=122:0))k=22;do if((k|0)==22){k=0;if((u[t[o>>2]>>0]|0|0)>=65?(u[t[o>>2]>>0]|0|0)<=90:0)break;if((u[t[o>>2]>>0]|0|0)>=48?(u[t[o>>2]>>0]|0|0)<=57:0)break;if((((u[t[o>>2]>>0]|0|0)!=95?(u[t[o>>2]>>0]|0|0)!=45:0)?(u[t[o>>2]>>0]|0|0)!=46:0)?(u[t[o>>2]>>0]|0|0)!=58:0)break e}while(0);t[o>>2]=(t[o>>2]|0)+1}e:do if(t[a>>2]|0)while(1){do if((u[t[o>>2]>>0]|0|0)!=32){if(9<=(u[t[o>>2]>>0]|0|0)?(u[t[o>>2]>>0]|0|0)<=10:0)break;if((u[t[o>>2]>>0]|0|0)!=13)break e}while(0);t[o>>2]=(t[o>>2]|0)+1}while(0);if(!(u[t[o>>2]>>0]|0)){t[n>>2]=0;b=t[n>>2]|0;s=r;return b|0}}t[o>>2]=t[f>>2];t[c>>2]=Mp(0,t[o>>2]|0,l)|0;e:do if(t[a>>2]|0)while(1){if((t[c>>2]|0)<256){if((t[c>>2]|0)!=32?!(9<=(t[c>>2]|0)&(t[c>>2]|0)<=10):0)h=(t[c>>2]|0)==13;else h=1;w=h&1}else w=0;if(!w)break e;t[o>>2]=(t[o>>2]|0)+(t[l>>2]|0);t[c>>2]=Mp(0,t[o>>2]|0,l)|0}while(0);w=t[c>>2]|0;if((t[c>>2]|0)<256){if(((!(65<=(w|0)&(t[c>>2]|0)<=90)?!(97<=(t[c>>2]|0)&(t[c>>2]|0)<=122):0)?!(192<=(t[c>>2]|0)&(t[c>>2]|0)<=214):0)?!(216<=(t[c>>2]|0)&(t[c>>2]|0)<=246|248<=(t[c>>2]|0)):0)k=53}else if(!(dj(w,199744)|0))k=53;do if((k|0)==53){if((t[c>>2]|0)>=256){if(19968<=(t[c>>2]|0)&(t[c>>2]|0)<=40869|(t[c>>2]|0)==12295)break;if(12321<=(t[c>>2]|0)&(t[c>>2]|0)<=12329)break}w=t[c>>2]|0;if((t[c>>2]|0)<256){if(48<=(w|0)&(t[c>>2]|0)<=57|(t[c>>2]|0)==46|(t[c>>2]|0)==58|(t[c>>2]|0)==45|(t[c>>2]|0)==95)break}else{h=(dj(w,200216)|0)!=0;if(h|(t[c>>2]|0)==46|(t[c>>2]|0)==58|(t[c>>2]|0)==45|(t[c>>2]|0)==95)break}if((t[c>>2]|0)>=256?(dj(t[c>>2]|0,200144)|0)!=0:0)break;h=t[c>>2]|0;if((t[c>>2]|0)<256){if((h|0)==183)break}else if(dj(h,200272)|0)break;t[n>>2]=1;b=t[n>>2]|0;s=r;return b|0}while(0);t[o>>2]=(t[o>>2]|0)+(t[l>>2]|0);t[c>>2]=Mp(0,t[o>>2]|0,l)|0;e:while(1){h=t[c>>2]|0;if((t[c>>2]|0)<256){if(((!(65<=(h|0)&(t[c>>2]|0)<=90)?!(97<=(t[c>>2]|0)&(t[c>>2]|0)<=122):0)?!(192<=(t[c>>2]|0)&(t[c>>2]|0)<=214):0)?!(216<=(t[c>>2]|0)&(t[c>>2]|0)<=246|248<=(t[c>>2]|0)):0)k=72}else if(!(dj(h,199744)|0))k=72;do if((k|0)==72){k=0;if((t[c>>2]|0)>=256){if(19968<=(t[c>>2]|0)&(t[c>>2]|0)<=40869|(t[c>>2]|0)==12295)break;if(12321<=(t[c>>2]|0)&(t[c>>2]|0)<=12329)break}h=t[c>>2]|0;if((t[c>>2]|0)<256){if(48<=(h|0)&(t[c>>2]|0)<=57|(t[c>>2]|0)==46|(t[c>>2]|0)==58|(t[c>>2]|0)==45|(t[c>>2]|0)==95)break}else{w=(dj(h,200216)|0)!=0;if(w|(t[c>>2]|0)==46|(t[c>>2]|0)==58|(t[c>>2]|0)==45|(t[c>>2]|0)==95)break}if((t[c>>2]|0)>=256?(dj(t[c>>2]|0,200144)|0)!=0:0)break;w=t[c>>2]|0;if((t[c>>2]|0)<256)d=(w|0)==183&1;else d=dj(w,200272)|0;if(!d)break e}while(0);t[o>>2]=(t[o>>2]|0)+(t[l>>2]|0);t[c>>2]=Mp(0,t[o>>2]|0,l)|0}e:do if(t[a>>2]|0)while(1){if((t[c>>2]|0)<256){if((t[c>>2]|0)!=32?!(9<=(t[c>>2]|0)&(t[c>>2]|0)<=10):0)v=(t[c>>2]|0)==13;else v=1;m=v&1}else m=0;if(!m)break e;t[o>>2]=(t[o>>2]|0)+(t[l>>2]|0);t[c>>2]=Mp(0,t[o>>2]|0,l)|0}while(0);if(t[c>>2]|0){t[n>>2]=1;b=t[n>>2]|0;s=r;return b|0}else{t[n>>2]=0;b=t[n>>2]|0;s=r;return b|0}return 0}function Wg(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0;n=s;s=s+32|0;f=n+20|0;u=n+16|0;a=n+12|0;o=n+8|0;c=n+4|0;l=n;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;if((t[u>>2]|0)!=0?(t[(t[u>>2]|0)+4>>2]|0)!=1:0){t[f>>2]=0;b=t[f>>2]|0;s=n;return b|0}if(((t[o>>2]|0)!=0?(Xl(t[o>>2]|0,75168)|0)!=0:0)?(Xl(t[a>>2]|0,75176)|0)!=0:0){t[f>>2]=0;b=t[f>>2]|0;s=n;return b|0}t[c>>2]=gAi[t[135744>>2]&511](24)|0;if(!(t[c>>2]|0)){LF(75216);t[f>>2]=0;b=t[f>>2]|0;s=n;return b|0}r=t[c>>2]|0;t[r+0>>2]=0;t[r+4>>2]=0;t[r+8>>2]=0;t[r+12>>2]=0;t[r+16>>2]=0;t[r+20>>2]=0;t[(t[c>>2]|0)+4>>2]=18;if(t[a>>2]|0){r=Yl(t[a>>2]|0)|0;t[(t[c>>2]|0)+8>>2]=r}if(t[o>>2]|0){r=Yl(t[o>>2]|0)|0;t[(t[c>>2]|0)+12>>2]=r}do if(t[u>>2]|0){if(!(t[(t[u>>2]|0)+48>>2]|0)){t[(t[u>>2]|0)+48>>2]=t[c>>2];break}t[l>>2]=t[(t[u>>2]|0)+48>>2];if(!((t[(t[l>>2]|0)+12>>2]|0)==0?(t[(t[c>>2]|0)+12>>2]|0)==0:0))k=19;if((k|0)==19?(Xl(t[(t[l>>2]|0)+12>>2]|0,t[(t[c>>2]|0)+12>>2]|0)|0)==0:0){do{if(!(t[t[l>>2]>>2]|0)){k=26;break}t[l>>2]=t[t[l>>2]>>2];if((t[(t[l>>2]|0)+12>>2]|0)==0?(t[(t[c>>2]|0)+12>>2]|0)==0:0)break}while((Xl(t[(t[l>>2]|0)+12>>2]|0,t[(t[c>>2]|0)+12>>2]|0)|0)==0);if((k|0)==26){t[t[l>>2]>>2]=t[c>>2];break}Kg(t[c>>2]|0);t[f>>2]=0;b=t[f>>2]|0;s=n;return b|0}Kg(t[c>>2]|0);t[f>>2]=0;b=t[f>>2]|0;s=n;return b|0}while(0);t[f>>2]=t[c>>2];b=t[f>>2]|0;s=n;return b|0}function Kg(e){e=e|0;var i=0,r=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if(!(t[r>>2]|0)){s=i;return}if(t[(t[r>>2]|0)+8>>2]|0)pAi[t[135736>>2]&511](t[(t[r>>2]|0)+8>>2]|0);if(t[(t[r>>2]|0)+12>>2]|0)pAi[t[135736>>2]&511](t[(t[r>>2]|0)+12>>2]|0);pAi[t[135736>>2]&511](t[r>>2]|0);s=i;return}function Xg(e,i){e=e|0;i=i|0;var r=0,n=0,f=0;r=s;s=s+16|0;n=r+4|0;f=r;t[n>>2]=e;t[f>>2]=i;if(!(t[n>>2]|0)){s=r;return}if((t[(t[n>>2]|0)+4>>2]|0)!=1?(t[(t[n>>2]|0)+4>>2]|0)!=2:0){s=r;return}t[(t[n>>2]|0)+36>>2]=t[f>>2];s=r;return}function Zg(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i+4|0;n=i;t[r>>2]=e;if(!((t[r>>2]|0)!=0&(t[r>>2]|0)!=0)){s=i;return}do{t[n>>2]=t[t[r>>2]>>2];Kg(t[r>>2]|0);t[r>>2]=t[n>>2]}while((t[r>>2]|0)!=0);s=i;return}function Jg(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0;f=s;s=s+32|0;u=f+20|0;a=f+16|0;o=f+12|0;c=f+8|0;l=f+4|0;b=f;t[a>>2]=e;t[o>>2]=i;t[c>>2]=r;t[l>>2]=n;if((t[a>>2]|0)!=0?(t[(t[a>>2]|0)+48>>2]|0)!=0:0){t[u>>2]=0;k=t[u>>2]|0;s=f;return k|0}t[b>>2]=gAi[t[135744>>2]&511](64)|0;if(!(t[b>>2]|0)){LF(75240);t[u>>2]=0;k=t[u>>2]|0;s=f;return k|0}n=(t[b>>2]|0)+0|0;r=n+64|0;do{t[n>>2]=0;n=n+4|0}while((n|0)<(r|0));t[(t[b>>2]|0)+4>>2]=14;if(t[o>>2]|0){n=Yl(t[o>>2]|0)|0;t[(t[b>>2]|0)+8>>2]=n}if(t[c>>2]|0){n=Yl(t[c>>2]|0)|0;t[(t[b>>2]|0)+52>>2]=n}if(t[l>>2]|0){n=Yl(t[l>>2]|0)|0;t[(t[b>>2]|0)+56>>2]=n}if(t[a>>2]|0)t[(t[a>>2]|0)+48>>2]=t[b>>2];t[(t[b>>2]|0)+32>>2]=t[a>>2];if((t[18774]|0)!=0&(t[33968]|0)!=0)pAi[t[135872>>2]&511](t[b>>2]|0);t[u>>2]=t[b>>2];k=t[u>>2]|0;s=f;return k|0}function Qg(e){e=e|0;var i=0,r=0,n=0,f=0,u=0,a=0,o=0;i=s;s=s+16|0;r=i+8|0;n=i+4|0;f=i;t[n>>2]=e;if(!(t[n>>2]|0)){t[r>>2]=0;u=t[r>>2]|0;s=i;return u|0}t[f>>2]=t[(t[n>>2]|0)+12>>2];while(1){if(!(t[f>>2]|0)){a=8;break}o=t[f>>2]|0;if((t[(t[f>>2]|0)+4>>2]|0)==14){a=6;break}t[f>>2]=t[o+24>>2]}if((a|0)==6){t[r>>2]=o;u=t[r>>2]|0;s=i;return u|0}else if((a|0)==8){t[r>>2]=t[(t[n>>2]|0)+44>>2];u=t[r>>2]|0;s=i;return u|0}return 0}function $g(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0;f=s;s=s+32|0;u=f+28|0;a=f+24|0;o=f+20|0;c=f+16|0;l=f+12|0;b=f+8|0;k=f+4|0;h=f;t[a>>2]=e;t[o>>2]=i;t[c>>2]=r;t[l>>2]=n;if((t[a>>2]|0)!=0?(Qg(t[a>>2]|0)|0)!=0:0){t[u>>2]=0;w=t[u>>2]|0;s=f;return w|0}t[b>>2]=gAi[t[135744>>2]&511](64)|0;if(!(t[b>>2]|0)){LF(75256);t[u>>2]=0;w=t[u>>2]|0;s=f;return w|0}n=(t[b>>2]|0)+0|0;r=n+64|0;do{t[n>>2]=0;n=n+4|0}while((n|0)<(r|0));t[(t[b>>2]|0)+4>>2]=14;if((t[o>>2]|0)!=0?(n=Yl(t[o>>2]|0)|0,t[(t[b>>2]|0)+8>>2]=n,(t[(t[b>>2]|0)+8>>2]|0)==0):0){LF(75256);pAi[t[135736>>2]&511](t[b>>2]|0);t[u>>2]=0;w=t[u>>2]|0;s=f;return w|0}if((t[c>>2]|0)!=0?(n=Yl(t[c>>2]|0)|0,t[(t[b>>2]|0)+52>>2]=n,(t[(t[b>>2]|0)+52>>2]|0)==0):0){LF(75256);if(t[(t[b>>2]|0)+8>>2]|0)pAi[t[135736>>2]&511](t[(t[b>>2]|0)+8>>2]|0);pAi[t[135736>>2]&511](t[b>>2]|0);t[u>>2]=0;w=t[u>>2]|0;s=f;return w|0}if((t[l>>2]|0)!=0?(n=Yl(t[l>>2]|0)|0,t[(t[b>>2]|0)+56>>2]=n,(t[(t[b>>2]|0)+56>>2]|0)==0):0){LF(75256);if(t[(t[b>>2]|0)+8>>2]|0)pAi[t[135736>>2]&511](t[(t[b>>2]|0)+8>>2]|0);if(t[(t[b>>2]|0)+52>>2]|0)pAi[t[135736>>2]&511](t[(t[b>>2]|0)+52>>2]|0);pAi[t[135736>>2]&511](t[b>>2]|0);t[u>>2]=0;w=t[u>>2]|0;s=f;return w|0}do if(t[a>>2]|0){t[(t[a>>2]|0)+44>>2]=t[b>>2];t[(t[b>>2]|0)+20>>2]=t[a>>2];t[(t[b>>2]|0)+32>>2]=t[a>>2];if(!(t[(t[a>>2]|0)+12>>2]|0)){t[(t[a>>2]|0)+12>>2]=t[b>>2];t[(t[a>>2]|0)+16>>2]=t[b>>2];break}n=t[(t[a>>2]|0)+12>>2]|0;if((t[(t[a>>2]|0)+4>>2]|0)==13){t[k>>2]=n;t[(t[k>>2]|0)+28>>2]=t[b>>2];t[(t[b>>2]|0)+24>>2]=t[k>>2];t[(t[a>>2]|0)+12>>2]=t[b>>2];break}t[h>>2]=n;while(1){if(t[h>>2]|0)d=(t[(t[h>>2]|0)+4>>2]|0)!=1;else d=0;v=t[h>>2]|0;if(!d)break;t[h>>2]=t[v+24>>2]}if(!v){t[(t[b>>2]|0)+28>>2]=t[(t[a>>2]|0)+16>>2];t[(t[(t[b>>2]|0)+28>>2]|0)+24>>2]=t[b>>2];t[(t[b>>2]|0)+24>>2]=0;t[(t[a>>2]|0)+16>>2]=t[b>>2];break}t[(t[b>>2]|0)+24>>2]=t[h>>2];t[(t[b>>2]|0)+28>>2]=t[(t[h>>2]|0)+28>>2];n=t[b>>2]|0;if(!(t[(t[b>>2]|0)+28>>2]|0))t[(t[a>>2]|0)+12>>2]=n;else t[(t[(t[b>>2]|0)+28>>2]|0)+24>>2]=n;t[(t[h>>2]|0)+28>>2]=t[b>>2]}while(0);if((t[18774]|0)!=0&(t[33968]|0)!=0)pAi[t[135872>>2]&511](t[b>>2]|0);t[u>>2]=t[b>>2];w=t[u>>2]|0;s=f;return w|0}function ey(e){e=e|0;var i=0,r=0,n=0,f=0,u=0;i=s;s=s+16|0;r=i+12|0;n=i+8|0;f=i+4|0;u=i;t[r>>2]=e;t[n>>2]=0;if(!(t[r>>2]|0)){s=i;return}if(t[(t[r>>2]|0)+32>>2]|0)t[n>>2]=t[(t[(t[r>>2]|0)+32>>2]|0)+80>>2];if((t[18774]|0)!=0&(t[33970]|0)!=0)pAi[t[135880>>2]&511](t[r>>2]|0);e:do if(t[(t[r>>2]|0)+12>>2]|0){t[u>>2]=t[(t[r>>2]|0)+12>>2];while(1){if(!(t[u>>2]|0))break e;t[f>>2]=t[(t[u>>2]|0)+24>>2];if((((t[(t[u>>2]|0)+4>>2]|0)!=12?(t[(t[u>>2]|0)+4>>2]|0)!=15:0)?(t[(t[u>>2]|0)+4>>2]|0)!=16:0)?(t[(t[u>>2]|0)+4>>2]|0)!=17:0){iy(t[u>>2]|0);ry(t[u>>2]|0)}t[u>>2]=t[f>>2]}}while(0);do if(t[(t[r>>2]|0)+8>>2]|0){if((t[n>>2]|0)!=0?(wz(t[n>>2]|0,t[(t[r>>2]|0)+8>>2]|0)|0)!=0:0)break;pAi[t[135736>>2]&511](t[(t[r>>2]|0)+8>>2]|0)}while(0);do if(t[(t[r>>2]|0)+56>>2]|0){if((t[n>>2]|0)!=0?(wz(t[n>>2]|0,t[(t[r>>2]|0)+56>>2]|0)|0)!=0:0)break;pAi[t[135736>>2]&511](t[(t[r>>2]|0)+56>>2]|0)}while(0);do if(t[(t[r>>2]|0)+52>>2]|0){if((t[n>>2]|0)!=0?(wz(t[n>>2]|0,t[(t[r>>2]|0)+52>>2]|0)|0)!=0:0)break;pAi[t[135736>>2]&511](t[(t[r>>2]|0)+52>>2]|0)}while(0);if(t[(t[r>>2]|0)+36>>2]|0)IM(t[(t[r>>2]|0)+36>>2]|0);if(t[(t[r>>2]|0)+40>>2]|0)OM(t[(t[r>>2]|0)+40>>2]|0);if(t[(t[r>>2]|0)+44>>2]|0)DM(t[(t[r>>2]|0)+44>>2]|0);if(t[(t[r>>2]|0)+48>>2]|0)v_(t[(t[r>>2]|0)+48>>2]|0);if(t[(t[r>>2]|0)+60>>2]|0)v_(t[(t[r>>2]|0)+60>>2]|0);pAi[t[135736>>2]&511](t[r>>2]|0);s=i;return}function iy(e){e=e|0;var i=0,r=0,n=0,f=0,u=0;i=s;s=s+16|0;r=i+12|0;n=i+8|0;f=i+4|0;u=i;t[r>>2]=e;if(!(t[r>>2]|0)){s=i;return}if((t[(t[r>>2]|0)+4>>2]|0)==18){s=i;return}if((t[(t[r>>2]|0)+4>>2]|0)==14?(t[n>>2]=t[(t[r>>2]|0)+32>>2],(t[n>>2]|0)!=0):0){if((t[(t[n>>2]|0)+44>>2]|0)==(t[r>>2]|0))t[(t[n>>2]|0)+44>>2]=0;if((t[(t[n>>2]|0)+48>>2]|0)==(t[r>>2]|0))t[(t[n>>2]|0)+48>>2]=0}if((t[(t[r>>2]|0)+4>>2]|0)==17?(t[f>>2]=t[(t[r>>2]|0)+32>>2],(t[f>>2]|0)!=0):0){if(t[(t[f>>2]|0)+44>>2]|0){n=rO(t[(t[(t[f>>2]|0)+44>>2]|0)+48>>2]|0,t[(t[r>>2]|0)+8>>2]|0)|0;if((n|0)==(t[r>>2]|0))kO(t[(t[(t[f>>2]|0)+44>>2]|0)+48>>2]|0,t[(t[r>>2]|0)+8>>2]|0,0)|0;n=rO(t[(t[(t[f>>2]|0)+44>>2]|0)+60>>2]|0,t[(t[r>>2]|0)+8>>2]|0)|0;if((n|0)==(t[r>>2]|0))kO(t[(t[(t[f>>2]|0)+44>>2]|0)+60>>2]|0,t[(t[r>>2]|0)+8>>2]|0,0)|0}if(t[(t[f>>2]|0)+48>>2]|0){n=rO(t[(t[(t[f>>2]|0)+48>>2]|0)+48>>2]|0,t[(t[r>>2]|0)+8>>2]|0)|0;if((n|0)==(t[r>>2]|0))kO(t[(t[(t[f>>2]|0)+48>>2]|0)+48>>2]|0,t[(t[r>>2]|0)+8>>2]|0,0)|0;n=rO(t[(t[(t[f>>2]|0)+48>>2]|0)+60>>2]|0,t[(t[r>>2]|0)+8>>2]|0)|0;if((n|0)==(t[r>>2]|0))kO(t[(t[(t[f>>2]|0)+48>>2]|0)+60>>2]|0,t[(t[r>>2]|0)+8>>2]|0,0)|0}}if(t[(t[r>>2]|0)+20>>2]|0){t[u>>2]=t[(t[r>>2]|0)+20>>2];f=t[u>>2]|0;if((t[(t[r>>2]|0)+4>>2]|0)==2){if((t[f+44>>2]|0)==(t[r>>2]|0))t[(t[u>>2]|0)+44>>2]=t[(t[r>>2]|0)+24>>2]}else{if((t[f+12>>2]|0)==(t[r>>2]|0))t[(t[u>>2]|0)+12>>2]=t[(t[r>>2]|0)+24>>2];if((t[(t[u>>2]|0)+16>>2]|0)==(t[r>>2]|0))t[(t[u>>2]|0)+16>>2]=t[(t[r>>2]|0)+28>>2]}t[(t[r>>2]|0)+20>>2]=0}if(t[(t[r>>2]|0)+24>>2]|0)t[(t[(t[r>>2]|0)+24>>2]|0)+28>>2]=t[(t[r>>2]|0)+28>>2];if(t[(t[r>>2]|0)+28>>2]|0)t[(t[(t[r>>2]|0)+28>>2]|0)+24>>2]=t[(t[r>>2]|0)+24>>2];t[(t[r>>2]|0)+28>>2]=0;t[(t[r>>2]|0)+24>>2]=0;s=i;return}function ry(e){e=e|0;var i=0,r=0,n=0,f=0,u=0,a=0;i=s;s=s+16|0;r=i+8|0;n=i+4|0;f=i;t[r>>2]=e;t[n>>2]=0;if(!(t[r>>2]|0)){s=i;return}e=t[r>>2]|0;if((t[(t[r>>2]|0)+4>>2]|0)==14){ey(e);s=i;return}u=t[r>>2]|0;if((t[e+4>>2]|0)==18){Kg(u);s=i;return}if((t[u+4>>2]|0)==2){vy(t[r>>2]|0);s=i;return}if((t[18774]|0)!=0&(t[33970]|0)!=0)pAi[t[135880>>2]&511](t[r>>2]|0);if(t[(t[r>>2]|0)+32>>2]|0)t[n>>2]=t[(t[(t[r>>2]|0)+32>>2]|0)+80>>2];do if((t[(t[r>>2]|0)+4>>2]|0)==17){t[f>>2]=t[r>>2];do if(t[(t[f>>2]|0)+56>>2]|0){if((t[n>>2]|0)!=0?(wz(t[n>>2]|0,t[(t[f>>2]|0)+56>>2]|0)|0)!=0:0)break;pAi[t[135736>>2]&511](t[(t[f>>2]|0)+56>>2]|0)}while(0);if(t[(t[f>>2]|0)+52>>2]|0){if((t[n>>2]|0)!=0?(wz(t[n>>2]|0,t[(t[f>>2]|0)+52>>2]|0)|0)!=0:0)break;pAi[t[135736>>2]&511](t[(t[f>>2]|0)+52>>2]|0)}}while(0);if((t[(t[r>>2]|0)+12>>2]|0)!=0?(t[(t[r>>2]|0)+4>>2]|0)!=5:0)ty(t[(t[r>>2]|0)+12>>2]|0);if(!(((t[(t[r>>2]|0)+4>>2]|0)!=1?(t[(t[r>>2]|0)+4>>2]|0)!=19:0)?(t[(t[r>>2]|0)+4>>2]|0)!=20:0))a=27;if((a|0)==27?(t[(t[r>>2]|0)+44>>2]|0)!=0:0)dy(t[(t[r>>2]|0)+44>>2]|0);do if(((((((t[(t[r>>2]|0)+4>>2]|0)!=1?(t[(t[r>>2]|0)+40>>2]|0)!=0:0)?(t[(t[r>>2]|0)+4>>2]|0)!=5:0)?(t[(t[r>>2]|0)+4>>2]|0)!=20:0)?(t[(t[r>>2]|0)+4>>2]|0)!=19:0)?(t[(t[r>>2]|0)+40>>2]|0)!=((t[r>>2]|0)+44|0):0)?(t[(t[r>>2]|0)+40>>2]|0)!=0:0){if((t[n>>2]|0)!=0?(wz(t[n>>2]|0,t[(t[r>>2]|0)+40>>2]|0)|0)!=0:0)break;pAi[t[135736>>2]&511](t[(t[r>>2]|0)+40>>2]|0)}while(0);do if((((t[(t[r>>2]|0)+8>>2]|0)!=0?(t[(t[r>>2]|0)+4>>2]|0)!=3:0)?(t[(t[r>>2]|0)+4>>2]|0)!=8:0)?(t[(t[r>>2]|0)+8>>2]|0)!=0:0){if((t[n>>2]|0)!=0?(wz(t[n>>2]|0,t[(t[r>>2]|0)+8>>2]|0)|0)!=0:0)break;pAi[t[135736>>2]&511](t[(t[r>>2]|0)+8>>2]|0)}while(0);if(!(((t[(t[r>>2]|0)+4>>2]|0)!=1?(t[(t[r>>2]|0)+4>>2]|0)!=19:0)?(t[(t[r>>2]|0)+4>>2]|0)!=20:0))a=49;if((a|0)==49?(t[(t[r>>2]|0)+48>>2]|0)!=0:0)Zg(t[(t[r>>2]|0)+48>>2]|0);pAi[t[135736>>2]&511](t[r>>2]|0);s=i;return}function ny(e){e=e|0;var i=0,r=0,n=0,f=0,u=0,a=0;i=s;s=s+16|0;r=i+8|0;n=i+4|0;f=i;t[n>>2]=e;t[n>>2]=(t[n>>2]|0)==0?75288:e;t[f>>2]=gAi[t[135744>>2]&511](96)|0;if(!(t[f>>2]|0)){LF(75296);t[r>>2]=0;u=t[r>>2]|0;s=i;return u|0}e=(t[f>>2]|0)+0|0;a=e+96|0;do{t[e>>2]=0;e=e+4|0}while((e|0)<(a|0));t[(t[f>>2]|0)+4>>2]=9;e=Yl(t[n>>2]|0)|0;t[(t[f>>2]|0)+56>>2]=e;if(!(t[(t[f>>2]|0)+56>>2]|0)){LF(75296);pAi[t[135736>>2]&511](t[f>>2]|0);t[r>>2]=0;u=t[r>>2]|0;s=i;return u|0}t[(t[f>>2]|0)+40>>2]=-1;t[(t[f>>2]|0)+36>>2]=-1;t[(t[f>>2]|0)+32>>2]=t[f>>2];t[(t[f>>2]|0)+88>>2]=0;t[(t[f>>2]|0)+92>>2]=32;t[(t[f>>2]|0)+76>>2]=1;if((t[18774]|0)!=0&(t[33968]|0)!=0)pAi[t[135872>>2]&511](t[f>>2]|0);t[r>>2]=t[f>>2];u=t[r>>2]|0;s=i;return u|0}function fy(e){e=e|0;var i=0,r=0,n=0,f=0,u=0;i=s;s=s+16|0;r=i+12|0;n=i+8|0;f=i+4|0;u=i;t[r>>2]=e;t[u>>2]=0;if(!(t[r>>2]|0)){s=i;return}if(t[r>>2]|0)t[u>>2]=t[(t[r>>2]|0)+80>>2];if((t[18774]|0)!=0&(t[33970]|0)!=0)pAi[t[135880>>2]&511](t[r>>2]|0);if(t[(t[r>>2]|0)+64>>2]|0)jM(t[(t[r>>2]|0)+64>>2]|0);t[(t[r>>2]|0)+64>>2]=0;if(t[(t[r>>2]|0)+68>>2]|0)KM(t[(t[r>>2]|0)+68>>2]|0);t[(t[r>>2]|0)+68>>2]=0;t[n>>2]=t[(t[r>>2]|0)+48>>2];t[f>>2]=t[(t[r>>2]|0)+44>>2];if((t[f>>2]|0)==(t[n>>2]|0))t[n>>2]=0;if(t[n>>2]|0){iy(t[(t[r>>2]|0)+48>>2]|0);t[(t[r>>2]|0)+48>>2]=0;ey(t[n>>2]|0)}if(t[f>>2]|0){iy(t[(t[r>>2]|0)+44>>2]|0);t[(t[r>>2]|0)+44>>2]=0;ey(t[f>>2]|0)}if(t[(t[r>>2]|0)+12>>2]|0)ty(t[(t[r>>2]|0)+12>>2]|0);if(t[(t[r>>2]|0)+52>>2]|0)Zg(t[(t[r>>2]|0)+52>>2]|0);do if(t[(t[r>>2]|0)+56>>2]|0){if((t[u>>2]|0)!=0?(wz(t[u>>2]|0,t[(t[r>>2]|0)+56>>2]|0)|0)!=0:0)break;pAi[t[135736>>2]&511](t[(t[r>>2]|0)+56>>2]|0)}while(0);do if(t[(t[r>>2]|0)+8>>2]|0){if((t[u>>2]|0)!=0?(wz(t[u>>2]|0,t[(t[r>>2]|0)+8>>2]|0)|0)!=0:0)break;pAi[t[135736>>2]&511](t[(t[r>>2]|0)+8>>2]|0)}while(0);do if(t[(t[r>>2]|0)+60>>2]|0){if((t[u>>2]|0)!=0?(wz(t[u>>2]|0,t[(t[r>>2]|0)+60>>2]|0)|0)!=0:0)break;pAi[t[135736>>2]&511](t[(t[r>>2]|0)+60>>2]|0)}while(0);do if(t[(t[r>>2]|0)+72>>2]|0){if((t[u>>2]|0)!=0?(wz(t[u>>2]|0,t[(t[r>>2]|0)+72>>2]|0)|0)!=0:0)break;pAi[t[135736>>2]&511](t[(t[r>>2]|0)+72>>2]|0)}while(0);pAi[t[135736>>2]&511](t[r>>2]|0);if(!(t[u>>2]|0)){s=i;return}bz(t[u>>2]|0);s=i;return}function ty(e){e=e|0;var i=0,r=0,n=0,f=0,u=0;i=s;s=s+16|0;r=i+8|0;n=i+4|0;f=i;t[r>>2]=e;t[f>>2]=0;if(!(t[r>>2]|0)){s=i;return}e=t[r>>2]|0;if((t[(t[r>>2]|0)+4>>2]|0)==18){Zg(e);s=i;return}if(((t[e+4>>2]|0)!=9?(t[(t[r>>2]|0)+4>>2]|0)!=21:0)?(t[(t[r>>2]|0)+4>>2]|0)!=13:0){if(t[(t[r>>2]|0)+32>>2]|0)t[f>>2]=t[(t[(t[r>>2]|0)+32>>2]|0)+80>>2];while(1){if(!(t[r>>2]|0))break;t[n>>2]=t[(t[r>>2]|0)+24>>2];if((t[(t[r>>2]|0)+4>>2]|0)!=14){if((t[18774]|0)!=0&(t[33970]|0)!=0)pAi[t[135880>>2]&511](t[r>>2]|0);if((t[(t[r>>2]|0)+12>>2]|0)!=0?(t[(t[r>>2]|0)+4>>2]|0)!=5:0)ty(t[(t[r>>2]|0)+12>>2]|0);if(!(((t[(t[r>>2]|0)+4>>2]|0)!=1?(t[(t[r>>2]|0)+4>>2]|0)!=19:0)?(t[(t[r>>2]|0)+4>>2]|0)!=20:0))u=20;if((u|0)==20?(u=0,(t[(t[r>>2]|0)+44>>2]|0)!=0):0)dy(t[(t[r>>2]|0)+44>>2]|0);do if(((((t[(t[r>>2]|0)+4>>2]|0)!=1?(t[(t[r>>2]|0)+4>>2]|0)!=19:0)?(t[(t[r>>2]|0)+4>>2]|0)!=20:0)?(t[(t[r>>2]|0)+4>>2]|0)!=5:0)?(t[(t[r>>2]|0)+40>>2]|0)!=((t[r>>2]|0)+44|0):0){if(!(t[(t[r>>2]|0)+40>>2]|0))break;if((t[f>>2]|0)!=0?(wz(t[f>>2]|0,t[(t[r>>2]|0)+40>>2]|0)|0)!=0:0)break;pAi[t[135736>>2]&511](t[(t[r>>2]|0)+40>>2]|0)}while(0);if(!(((t[(t[r>>2]|0)+4>>2]|0)!=1?(t[(t[r>>2]|0)+4>>2]|0)!=19:0)?(t[(t[r>>2]|0)+4>>2]|0)!=20:0))u=34;if((u|0)==34?(u=0,(t[(t[r>>2]|0)+48>>2]|0)!=0):0)Zg(t[(t[r>>2]|0)+48>>2]|0);do if(((t[(t[r>>2]|0)+8>>2]|0)!=0?(t[(t[r>>2]|0)+4>>2]|0)!=3:0)?(t[(t[r>>2]|0)+4>>2]|0)!=8:0){if(!(t[(t[r>>2]|0)+8>>2]|0))break;if((t[f>>2]|0)!=0?(wz(t[f>>2]|0,t[(t[r>>2]|0)+8>>2]|0)|0)!=0:0)break;pAi[t[135736>>2]&511](t[(t[r>>2]|0)+8>>2]|0)}while(0);pAi[t[135736>>2]&511](t[r>>2]|0)}t[r>>2]=t[n>>2]}s=i;return}fy(t[r>>2]|0);s=i;return}function uy(e,i,r){e=e|0;i=i|0;r=r|0;var f=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0,S=0,g=0,y=0,F=0,O=0,A=0,M=0,R=0,N=0,T=0;f=s;s=s+80|0;a=f+60|0;o=f+56|0;c=f+52|0;l=f+48|0;b=f+44|0;k=f+40|0;
	h=f+36|0;w=f+32|0;d=f+28|0;v=f+24|0;m=f+20|0;_=f+16|0;p=f+12|0;E=f+8|0;S=f+74|0;g=f+4|0;y=f+64|0;F=f;t[o>>2]=e;t[c>>2]=i;t[l>>2]=r;t[b>>2]=0;t[k>>2]=0;t[d>>2]=t[c>>2];t[v>>2]=(t[d>>2]|0)+(t[l>>2]|0);if(!(t[c>>2]|0)){t[a>>2]=0;O=t[a>>2]|0;s=f;return O|0}t[p>>2]=vs(0)|0;if(!(t[p>>2]|0)){t[a>>2]=0;O=t[a>>2]|0;s=f;return O|0}Es(t[p>>2]|0,4)|0;t[m>>2]=t[d>>2];e:while(1){if((t[d>>2]|0)>>>0<(t[v>>2]|0)>>>0)A=(u[t[d>>2]>>0]|0|0)!=0;else A=0;M=t[d>>2]|0;if(!A){R=87;break}if((u[M>>0]|0|0)!=38){t[d>>2]=(t[d>>2]|0)+1;continue}t[E>>2]=0;if((t[d>>2]|0)!=(t[m>>2]|0)?(Ps(t[p>>2]|0,t[m>>2]|0,(t[d>>2]|0)-(t[m>>2]|0)|0)|0)!=0:0)break;t[m>>2]=t[d>>2];if((((t[d>>2]|0)+2|0)>>>0<(t[v>>2]|0)>>>0?(u[(t[d>>2]|0)+1>>0]|0|0)==35:0)?(u[(t[d>>2]|0)+2>>0]|0|0)==120:0){t[d>>2]=(t[d>>2]|0)+3;if((t[d>>2]|0)>>>0<(t[v>>2]|0)>>>0)n[S>>0]=n[t[d>>2]>>0]|0;else n[S>>0]=0;i:while(1){if((u[S>>0]|0|0)==59)break;if((u[S>>0]|0|0)>=48?(u[S>>0]|0|0)<=57:0)t[E>>2]=(t[E>>2]<<4)+((u[S>>0]|0)-48);else R=22;do if((R|0)==22){R=0;if((u[S>>0]|0|0)>=97?(u[S>>0]|0|0)<=102:0){t[E>>2]=(t[E>>2]<<4)+((u[S>>0]|0)-97)+10;break}if((u[S>>0]|0|0)<65){R=28;break i}if((u[S>>0]|0|0)>70){R=28;break i}t[E>>2]=(t[E>>2]<<4)+((u[S>>0]|0)-65)+10}while(0);t[d>>2]=(t[d>>2]|0)+1;if((t[d>>2]|0)>>>0<(t[v>>2]|0)>>>0){n[S>>0]=n[t[d>>2]>>0]|0;continue}else{n[S>>0]=0;continue}}if((R|0)==28){R=0;DF(1300,t[o>>2]|0,0);t[E>>2]=0}if((u[S>>0]|0|0)==59)t[d>>2]=(t[d>>2]|0)+1;t[m>>2]=t[d>>2]}else R=35;do if((R|0)==35){R=0;if(((t[d>>2]|0)+1|0)>>>0<(t[v>>2]|0)>>>0?(u[(t[d>>2]|0)+1>>0]|0|0)==35:0){t[d>>2]=(t[d>>2]|0)+2;if((t[d>>2]|0)>>>0<(t[v>>2]|0)>>>0)n[S>>0]=n[t[d>>2]>>0]|0;else n[S>>0]=0;while(1){if((u[S>>0]|0|0)==59)break;if((u[S>>0]|0|0)<48){R=44;break}if((u[S>>0]|0|0)>57){R=44;break}t[E>>2]=((t[E>>2]|0)*10|0)+((u[S>>0]|0)-48);t[d>>2]=(t[d>>2]|0)+1;if((t[d>>2]|0)>>>0<(t[v>>2]|0)>>>0){n[S>>0]=n[t[d>>2]>>0]|0;continue}else{n[S>>0]=0;continue}}if((R|0)==44){R=0;DF(1301,t[o>>2]|0,0);t[E>>2]=0}if((u[S>>0]|0|0)==59)t[d>>2]=(t[d>>2]|0)+1;t[m>>2]=t[d>>2];break}t[d>>2]=(t[d>>2]|0)+1;t[m>>2]=t[d>>2];while(1){if((t[d>>2]|0)>>>0<(t[v>>2]|0)>>>0?(u[t[d>>2]>>0]|0|0)!=0:0)N=(u[t[d>>2]>>0]|0|0)!=59;else N=0;T=t[d>>2]|0;if(!N)break;t[d>>2]=T+1}if(T>>>0>=(t[v>>2]|0)>>>0){R=58;break e}if(!(u[t[d>>2]>>0]|0)){R=58;break e}if((t[d>>2]|0)!=(t[m>>2]|0)){t[w>>2]=ql(t[m>>2]|0,(t[d>>2]|0)-(t[m>>2]|0)|0)|0;t[_>>2]=h_(t[o>>2]|0,t[w>>2]|0)|0;if((t[_>>2]|0)!=0?(t[(t[_>>2]|0)+48>>2]|0)==6:0){if(Is(t[p>>2]|0,t[(t[_>>2]|0)+40>>2]|0)|0)break e}else R=63;do if((R|0)==63){R=0;do if(!(Ds(t[p>>2]|0)|0)){t[h>>2]=ay(t[o>>2]|0,0)|0;if(!(t[h>>2]|0)){R=65;break e}c=ms(t[p>>2]|0)|0;t[(t[h>>2]|0)+40>>2]=c;if(!(t[k>>2]|0)){c=t[h>>2]|0;t[b>>2]=c;t[k>>2]=c;break}else{t[k>>2]=oy(t[k>>2]|0,t[h>>2]|0)|0;break}}while(0);t[h>>2]=cy(t[o>>2]|0,t[w>>2]|0)|0;if(!(t[h>>2]|0)){R=71;break e}i:do if(t[_>>2]|0){if(t[(t[_>>2]|0)+12>>2]|0)break;c=ly(t[o>>2]|0,t[(t[h>>2]|0)+40>>2]|0)|0;t[(t[_>>2]|0)+12>>2]=c;t[(t[_>>2]|0)+68>>2]=1;t[g>>2]=t[(t[_>>2]|0)+12>>2];while(1){if(!(t[g>>2]|0))break i;t[(t[g>>2]|0)+20>>2]=t[_>>2];t[(t[_>>2]|0)+16>>2]=t[g>>2];t[g>>2]=t[(t[g>>2]|0)+24>>2]}}while(0);if(!(t[k>>2]|0)){c=t[h>>2]|0;t[b>>2]=c;t[k>>2]=c;break}else{t[k>>2]=oy(t[k>>2]|0,t[h>>2]|0)|0;break}}while(0);pAi[t[135736>>2]&511](t[w>>2]|0)}t[d>>2]=(t[d>>2]|0)+1;t[m>>2]=t[d>>2]}while(0);if(!(t[E>>2]|0))continue;t[F>>2]=Rp(y,t[E>>2]|0)|0;n[y+(t[F>>2]|0)>>0]=0;if(Is(t[p>>2]|0,y)|0)break;t[E>>2]=0}do if((R|0)==58)DF(1302,t[o>>2]|0,t[m>>2]|0);else if((R|0)==65){if(t[w>>2]|0)pAi[t[135736>>2]&511](t[w>>2]|0)}else if((R|0)==71){if(t[w>>2]|0)pAi[t[135736>>2]&511](t[w>>2]|0)}else if((R|0)==87){if((M|0)!=(t[m>>2]|0)?(Ps(t[p>>2]|0,t[m>>2]|0,(t[d>>2]|0)-(t[m>>2]|0)|0)|0)!=0:0)break;if(Ds(t[p>>2]|0)|0){if(t[b>>2]|0)break;t[b>>2]=ay(t[o>>2]|0,75312)|0;break}t[h>>2]=ay(t[o>>2]|0,0)|0;if(t[h>>2]|0){E=ms(t[p>>2]|0)|0;t[(t[h>>2]|0)+40>>2]=E;if(!(t[k>>2]|0)){E=t[h>>2]|0;t[b>>2]=E;t[k>>2]=E;break}else{t[k>>2]=oy(t[k>>2]|0,t[h>>2]|0)|0;break}}}while(0);Ss(t[p>>2]|0);t[a>>2]=t[b>>2];O=t[a>>2]|0;s=f;return O|0}function ay(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0;r=s;s=s+16|0;n=r+8|0;f=r+4|0;u=r;t[n>>2]=e;t[f>>2]=i;t[u>>2]=yy(t[f>>2]|0)|0;if(!(t[u>>2]|0)){a=t[u>>2]|0;s=r;return a|0}t[(t[u>>2]|0)+32>>2]=t[n>>2];a=t[u>>2]|0;s=r;return a|0}function oy(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0;r=s;s=s+16|0;n=r+12|0;f=r+8|0;u=r+4|0;a=r;t[f>>2]=e;t[u>>2]=i;if((t[f>>2]|0)!=0?(t[(t[f>>2]|0)+4>>2]|0)!=18:0){if((t[u>>2]|0)!=0?(t[(t[u>>2]|0)+4>>2]|0)!=18:0){if((t[f>>2]|0)==(t[u>>2]|0)){t[n>>2]=0;o=t[n>>2]|0;s=r;return o|0}iy(t[u>>2]|0);if((t[(t[u>>2]|0)+4>>2]|0)==3){i=t[f>>2]|0;if((t[(t[f>>2]|0)+4>>2]|0)==3){Dy(i,t[(t[u>>2]|0)+40>>2]|0);ry(t[u>>2]|0);t[n>>2]=t[f>>2];o=t[n>>2]|0;s=r;return o|0}if(((t[i+24>>2]|0)!=0?(t[(t[(t[f>>2]|0)+24>>2]|0)+4>>2]|0)==3:0)?(t[(t[f>>2]|0)+8>>2]|0)==(t[(t[(t[f>>2]|0)+24>>2]|0)+8>>2]|0):0){t[a>>2]=Yl(t[(t[u>>2]|0)+40>>2]|0)|0;t[a>>2]=us(t[a>>2]|0,t[(t[(t[f>>2]|0)+24>>2]|0)+40>>2]|0)|0;Cy(t[(t[f>>2]|0)+24>>2]|0,t[a>>2]|0);pAi[t[135736>>2]&511](t[a>>2]|0);ry(t[u>>2]|0);t[n>>2]=t[(t[f>>2]|0)+24>>2];o=t[n>>2]|0;s=r;return o|0}}else if((t[(t[u>>2]|0)+4>>2]|0)==2){t[n>>2]=CF(t[f>>2]|0,t[f>>2]|0,t[u>>2]|0)|0;o=t[n>>2]|0;s=r;return o|0}if((t[(t[u>>2]|0)+32>>2]|0)!=(t[(t[f>>2]|0)+32>>2]|0))Ny(t[u>>2]|0,t[(t[f>>2]|0)+32>>2]|0);t[(t[u>>2]|0)+20>>2]=t[(t[f>>2]|0)+20>>2];t[(t[u>>2]|0)+28>>2]=t[f>>2];t[(t[u>>2]|0)+24>>2]=t[(t[f>>2]|0)+24>>2];t[(t[f>>2]|0)+24>>2]=t[u>>2];if(t[(t[u>>2]|0)+24>>2]|0)t[(t[(t[u>>2]|0)+24>>2]|0)+28>>2]=t[u>>2];if((t[(t[u>>2]|0)+20>>2]|0)!=0?(t[(t[(t[u>>2]|0)+20>>2]|0)+16>>2]|0)==(t[f>>2]|0):0)t[(t[(t[u>>2]|0)+20>>2]|0)+16>>2]=t[u>>2];t[n>>2]=t[u>>2];o=t[n>>2]|0;s=r;return o|0}t[n>>2]=0;o=t[n>>2]|0;s=r;return o|0}t[n>>2]=0;o=t[n>>2]|0;s=r;return o|0}function cy(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0;r=s;s=s+32|0;n=r+20|0;f=r+16|0;a=r+12|0;o=r+8|0;c=r+4|0;l=r;t[f>>2]=e;t[a>>2]=i;if(!(t[a>>2]|0)){t[n>>2]=0;b=t[n>>2]|0;s=r;return b|0}t[o>>2]=gAi[t[135744>>2]&511](60)|0;if(!(t[o>>2]|0)){LF(75424);t[n>>2]=0;b=t[n>>2]|0;s=r;return b|0}i=(t[o>>2]|0)+0|0;e=i+60|0;do{t[i>>2]=0;i=i+4|0}while((i|0)<(e|0));t[(t[o>>2]|0)+4>>2]=5;t[(t[o>>2]|0)+32>>2]=t[f>>2];i=t[a>>2]|0;do if((u[t[a>>2]>>0]|0|0)==38){t[a>>2]=i+1;t[l>>2]=rs(t[a>>2]|0)|0;e=t[a>>2]|0;k=t[l>>2]|0;if((u[(t[a>>2]|0)+((t[l>>2]|0)-1)>>0]|0|0)==59){h=ql(e,k-1|0)|0;t[(t[o>>2]|0)+8>>2]=h;break}else{h=ql(e,k)|0;t[(t[o>>2]|0)+8>>2]=h;break}}else{h=Yl(i)|0;t[(t[o>>2]|0)+8>>2]=h}while(0);t[c>>2]=h_(t[f>>2]|0,t[(t[o>>2]|0)+8>>2]|0)|0;if(t[c>>2]|0){t[(t[o>>2]|0)+40>>2]=t[(t[c>>2]|0)+40>>2];t[(t[o>>2]|0)+12>>2]=t[c>>2];t[(t[o>>2]|0)+16>>2]=t[c>>2]}if((t[18774]|0)!=0&(t[33968]|0)!=0)pAi[t[135872>>2]&511](t[o>>2]|0);t[n>>2]=t[o>>2];b=t[n>>2]|0;s=r;return b|0}function ly(e,i){e=e|0;i=i|0;var r=0,f=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0,S=0,g=0,y=0,F=0,O=0,A=0;r=s;s=s+80|0;f=r+52|0;a=r+48|0;o=r+44|0;c=r+40|0;l=r+36|0;b=r+32|0;k=r+28|0;h=r+24|0;w=r+20|0;d=r+16|0;v=r+12|0;m=r+8|0;_=r+66|0;p=r+4|0;E=r+56|0;S=r;t[a>>2]=e;t[o>>2]=i;t[c>>2]=0;t[l>>2]=0;t[h>>2]=t[o>>2];if(!(t[o>>2]|0)){t[f>>2]=0;g=t[f>>2]|0;s=r;return g|0}t[v>>2]=vs(0)|0;if(!(t[v>>2]|0)){t[f>>2]=0;g=t[f>>2]|0;s=r;return g|0}Es(t[v>>2]|0,4)|0;t[w>>2]=t[h>>2];e:while(1){y=t[h>>2]|0;if(!(u[t[h>>2]>>0]|0)){F=70;break}if((u[y>>0]|0|0)!=38){t[h>>2]=(t[h>>2]|0)+1;continue}t[m>>2]=0;if((t[h>>2]|0)!=(t[w>>2]|0)?(Ps(t[v>>2]|0,t[w>>2]|0,(t[h>>2]|0)-(t[w>>2]|0)|0)|0)!=0:0)break;t[w>>2]=t[h>>2];if((u[(t[h>>2]|0)+1>>0]|0|0)==35?(u[(t[h>>2]|0)+2>>0]|0|0)==120:0){t[h>>2]=(t[h>>2]|0)+3;n[_>>0]=n[t[h>>2]>>0]|0;i:while(1){if((u[_>>0]|0|0)==59)break;if((u[_>>0]|0|0)>=48?(u[_>>0]|0|0)<=57:0)t[m>>2]=(t[m>>2]<<4)+((u[_>>0]|0)-48);else F=17;do if((F|0)==17){F=0;if((u[_>>0]|0|0)>=97?(u[_>>0]|0|0)<=102:0){t[m>>2]=(t[m>>2]<<4)+((u[_>>0]|0)-97)+10;break}if((u[_>>0]|0|0)<65){F=23;break i}if((u[_>>0]|0|0)>70){F=23;break i}t[m>>2]=(t[m>>2]<<4)+((u[_>>0]|0)-65)+10}while(0);t[h>>2]=(t[h>>2]|0)+1;n[_>>0]=n[t[h>>2]>>0]|0}if((F|0)==23){F=0;DF(1300,t[a>>2]|0,0);t[m>>2]=0}if((u[_>>0]|0|0)==59)t[h>>2]=(t[h>>2]|0)+1;t[w>>2]=t[h>>2]}else F=28;do if((F|0)==28){F=0;o=t[h>>2]|0;if((u[(t[h>>2]|0)+1>>0]|0|0)==35){t[h>>2]=o+2;n[_>>0]=n[t[h>>2]>>0]|0;while(1){if((u[_>>0]|0|0)==59)break;if((u[_>>0]|0|0)<48){F=34;break}if((u[_>>0]|0|0)>57){F=34;break}t[m>>2]=((t[m>>2]|0)*10|0)+((u[_>>0]|0)-48);t[h>>2]=(t[h>>2]|0)+1;n[_>>0]=n[t[h>>2]>>0]|0}if((F|0)==34){F=0;DF(1301,t[a>>2]|0,0);t[m>>2]=0}if((u[_>>0]|0|0)==59)t[h>>2]=(t[h>>2]|0)+1;t[w>>2]=t[h>>2];break}t[h>>2]=o+1;t[w>>2]=t[h>>2];while(1){if(u[t[h>>2]>>0]|0)O=(u[t[h>>2]>>0]|0|0)!=59;else O=0;A=t[h>>2]|0;if(!O)break;t[h>>2]=A+1}if(!(u[A>>0]|0)){F=44;break e}if((t[h>>2]|0)!=(t[w>>2]|0)){t[k>>2]=ql(t[w>>2]|0,(t[h>>2]|0)-(t[w>>2]|0)|0)|0;t[d>>2]=h_(t[a>>2]|0,t[k>>2]|0)|0;if((t[d>>2]|0)!=0?(t[(t[d>>2]|0)+48>>2]|0)==6:0){if(Is(t[v>>2]|0,t[(t[d>>2]|0)+40>>2]|0)|0)break e}else F=49;do if((F|0)==49){F=0;do if(!(Ds(t[v>>2]|0)|0)){t[b>>2]=ay(t[a>>2]|0,0)|0;o=ms(t[v>>2]|0)|0;t[(t[b>>2]|0)+40>>2]=o;if(!(t[l>>2]|0)){o=t[b>>2]|0;t[c>>2]=o;t[l>>2]=o;break}else{t[l>>2]=oy(t[l>>2]|0,t[b>>2]|0)|0;break}}while(0);t[b>>2]=cy(t[a>>2]|0,t[k>>2]|0)|0;if(!(t[b>>2]|0)){F=54;break e}i:do if((t[d>>2]|0)!=0?(t[(t[d>>2]|0)+12>>2]|0)==0:0){o=ly(t[a>>2]|0,t[(t[b>>2]|0)+40>>2]|0)|0;t[(t[d>>2]|0)+12>>2]=o;t[(t[d>>2]|0)+68>>2]=1;t[p>>2]=t[(t[d>>2]|0)+12>>2];while(1){if(!(t[p>>2]|0))break i;t[(t[p>>2]|0)+20>>2]=t[d>>2];t[p>>2]=t[(t[p>>2]|0)+24>>2]}}while(0);if(!(t[l>>2]|0)){o=t[b>>2]|0;t[c>>2]=o;t[l>>2]=o;break}else{t[l>>2]=oy(t[l>>2]|0,t[b>>2]|0)|0;break}}while(0);pAi[t[135736>>2]&511](t[k>>2]|0)}t[h>>2]=(t[h>>2]|0)+1;t[w>>2]=t[h>>2]}while(0);if(!(t[m>>2]|0))continue;t[S>>2]=Rp(E,t[m>>2]|0)|0;n[E+(t[S>>2]|0)>>0]=0;if(Is(t[v>>2]|0,E)|0)break;t[m>>2]=0}do if((F|0)==44)DF(1302,t[a>>2]|0,t[w>>2]|0);else if((F|0)==54){if(t[k>>2]|0)pAi[t[135736>>2]&511](t[k>>2]|0)}else if((F|0)==70){if((t[c>>2]|0)==0?1:(y|0)!=(t[w>>2]|0))Ps(t[v>>2]|0,t[w>>2]|0,(t[h>>2]|0)-(t[w>>2]|0)|0)|0;if(!(Ds(t[v>>2]|0)|0)){t[b>>2]=ay(t[a>>2]|0,0)|0;m=ms(t[v>>2]|0)|0;t[(t[b>>2]|0)+40>>2]=m;if(!(t[l>>2]|0)){m=t[b>>2]|0;t[c>>2]=m;t[l>>2]=m;break}else{t[l>>2]=oy(t[l>>2]|0,t[b>>2]|0)|0;break}}}while(0);Ss(t[v>>2]|0);t[f>>2]=t[c>>2];g=t[f>>2]|0;s=r;return g|0}function sy(e,i,r){e=e|0;i=i|0;r=r|0;var f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0;f=s;s=s+48|0;u=f+36|0;a=f+32|0;o=f+28|0;c=f+24|0;l=f+20|0;b=f+16|0;k=f+12|0;h=f+8|0;w=f+4|0;d=f;v=f+40|0;t[a>>2]=e;t[o>>2]=i;t[c>>2]=r;t[l>>2]=t[o>>2];t[b>>2]=0;if(!(t[o>>2]|0)){t[u>>2]=0;m=t[u>>2]|0;s=f;return m|0}if((t[(t[o>>2]|0)+20>>2]|0)!=0?(t[(t[(t[o>>2]|0)+20>>2]|0)+4>>2]|0)==2:0)t[h>>2]=1;else t[h>>2]=0;while(1){if(!(t[l>>2]|0))break;do if((t[(t[l>>2]|0)+4>>2]|0)!=3?(t[(t[l>>2]|0)+4>>2]|0)!=4:0){if((t[(t[l>>2]|0)+4>>2]|0)==5){if(!(t[c>>2]|0)){n[v>>0]=38;n[v+1>>0]=0;t[b>>2]=fs(t[b>>2]|0,v,1)|0;t[b>>2]=us(t[b>>2]|0,t[(t[l>>2]|0)+8>>2]|0)|0;n[v>>0]=59;n[v+1>>0]=0;t[b>>2]=fs(t[b>>2]|0,v,1)|0;break}t[k>>2]=h_(t[a>>2]|0,t[(t[l>>2]|0)+8>>2]|0)|0;if(!(t[k>>2]|0)){t[b>>2]=us(t[b>>2]|0,t[(t[l>>2]|0)+40>>2]|0)|0;break}t[d>>2]=sy(t[a>>2]|0,t[(t[k>>2]|0)+12>>2]|0,1)|0;if(t[d>>2]|0){t[b>>2]=us(t[b>>2]|0,t[d>>2]|0)|0;pAi[t[135736>>2]&511](t[d>>2]|0)}}}else _=10;while(0);do if((_|0)==10){_=0;if(t[c>>2]|0){t[b>>2]=us(t[b>>2]|0,t[(t[l>>2]|0)+40>>2]|0)|0;break}o=t[a>>2]|0;r=t[(t[l>>2]|0)+40>>2]|0;if(t[h>>2]|0)t[w>>2]=w_(o,r)|0;else t[w>>2]=d_(o,r)|0;if(t[w>>2]|0){t[b>>2]=us(t[b>>2]|0,t[w>>2]|0)|0;pAi[t[135736>>2]&511](t[w>>2]|0)}}while(0);t[l>>2]=t[(t[l>>2]|0)+24>>2]}t[u>>2]=t[b>>2];m=t[u>>2]|0;s=f;return m|0}function by(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0;n=s;s=s+16|0;f=n+12|0;u=n+8|0;a=n+4|0;o=n;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;if(!(t[a>>2]|0)){t[f>>2]=0;c=t[f>>2]|0;s=n;return c|0}else{t[f>>2]=PF(t[u>>2]|0,0,t[a>>2]|0,t[o>>2]|0,0)|0;c=t[f>>2]|0;s=n;return c|0}return 0}function ky(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,u=0,a=0,o=0,c=0,l=0,b=0;f=s;s=s+32|0;u=f+16|0;a=f+12|0;o=f+8|0;c=f+4|0;l=f;t[a>>2]=e;t[o>>2]=i;t[c>>2]=r;t[l>>2]=n;if(!(t[c>>2]|0)){t[u>>2]=0;b=t[u>>2]|0;s=f;return b|0}else{t[u>>2]=PF(t[a>>2]|0,t[o>>2]|0,t[c>>2]|0,t[l>>2]|0,0)|0;b=t[u>>2]|0;s=f;return b|0}return 0}function hy(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,u=0,a=0,o=0,c=0,l=0,b=0;f=s;s=s+32|0;u=f+16|0;a=f+12|0;o=f+8|0;c=f+4|0;l=f;t[a>>2]=e;t[o>>2]=i;t[c>>2]=r;t[l>>2]=n;if(!(t[c>>2]|0)){t[u>>2]=0;b=t[u>>2]|0;s=f;return b|0}else{t[u>>2]=PF(t[a>>2]|0,t[o>>2]|0,t[c>>2]|0,t[l>>2]|0,1)|0;b=t[u>>2]|0;s=f;return b|0}return 0}function wy(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0;n=s;s=s+32|0;f=n+20|0;u=n+16|0;a=n+12|0;o=n+8|0;c=n+4|0;l=n;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;if(!(t[a>>2]|0)){t[f>>2]=0;b=t[f>>2]|0;s=n;return b|0}t[c>>2]=gAi[t[135744>>2]&511](48)|0;if(!(t[c>>2]|0)){LF(75320);t[f>>2]=0;b=t[f>>2]|0;s=n;return b|0}r=(t[c>>2]|0)+0|0;i=r+48|0;do{t[r>>2]=0;r=r+4|0}while((r|0)<(i|0));t[(t[c>>2]|0)+4>>2]=2;if((t[u>>2]|0)!=0?(t[(t[u>>2]|0)+80>>2]|0)!=0:0){r=kz(t[(t[u>>2]|0)+80>>2]|0,t[a>>2]|0,-1)|0;t[(t[c>>2]|0)+8>>2]=r}else{r=Yl(t[a>>2]|0)|0;t[(t[c>>2]|0)+8>>2]=r}t[(t[c>>2]|0)+32>>2]=t[u>>2];e:do if(t[o>>2]|0){r=ly(t[u>>2]|0,t[o>>2]|0)|0;t[(t[c>>2]|0)+12>>2]=r;t[(t[c>>2]|0)+16>>2]=0;t[l>>2]=t[(t[c>>2]|0)+12>>2];while(1){if(!(t[l>>2]|0))break e;t[(t[l>>2]|0)+20>>2]=t[c>>2];if(!(t[(t[l>>2]|0)+24>>2]|0))t[(t[c>>2]|0)+16>>2]=t[l>>2];t[l>>2]=t[(t[l>>2]|0)+24>>2]}}while(0);if((t[18774]|0)!=0&(t[33968]|0)!=0)pAi[t[135872>>2]&511](t[c>>2]|0);t[f>>2]=t[c>>2];b=t[f>>2]|0;s=n;return b|0}function dy(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i+4|0;n=i;t[r>>2]=e;if(!((t[r>>2]|0)!=0&(t[r>>2]|0)!=0)){s=i;return}do{t[n>>2]=t[(t[r>>2]|0)+24>>2];vy(t[r>>2]|0);t[r>>2]=t[n>>2]}while((t[r>>2]|0)!=0);s=i;return}function vy(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i+4|0;n=i;t[r>>2]=e;t[n>>2]=0;if(!(t[r>>2]|0)){s=i;return}if(t[(t[r>>2]|0)+32>>2]|0)t[n>>2]=t[(t[(t[r>>2]|0)+32>>2]|0)+80>>2];if((t[18774]|0)!=0&(t[33970]|0)!=0)pAi[t[135880>>2]&511](t[r>>2]|0);if((t[(t[r>>2]|0)+32>>2]|0)!=0?(t[(t[r>>2]|0)+40>>2]|0)==2:0)YM(t[(t[r>>2]|0)+32>>2]|0,t[r>>2]|0)|0;if(t[(t[r>>2]|0)+12>>2]|0)ty(t[(t[r>>2]|0)+12>>2]|0);do if(t[(t[r>>2]|0)+8>>2]|0){if((t[n>>2]|0)!=0?(wz(t[n>>2]|0,t[(t[r>>2]|0)+8>>2]|0)|0)!=0:0)break;pAi[t[135736>>2]&511](t[(t[r>>2]|0)+8>>2]|0)}while(0);pAi[t[135736>>2]&511](t[r>>2]|0);s=i;return}function my(e){e=e|0;var i=0,r=0,n=0,f=0,u=0,a=0;i=s;s=s+16|0;r=i+8|0;n=i+4|0;f=i;t[n>>2]=e;if(!(t[n>>2]|0)){t[r>>2]=-1;u=t[r>>2]|0;s=i;return u|0}if(!(t[(t[n>>2]|0)+20>>2]|0)){t[r>>2]=-1;u=t[r>>2]|0;s=i;return u|0}t[f>>2]=t[(t[(t[n>>2]|0)+20>>2]|0)+44>>2];if((t[f>>2]|0)==(t[n>>2]|0)){t[(t[(t[n>>2]|0)+20>>2]|0)+44>>2]=t[(t[n>>2]|0)+24>>2];if(t[(t[n>>2]|0)+24>>2]|0)t[(t[(t[n>>2]|0)+24>>2]|0)+28>>2]=0;vy(t[n>>2]|0);t[r>>2]=0;u=t[r>>2]|0;s=i;return u|0}while(1){if(!(t[f>>2]|0)){a=15;break}if((t[(t[f>>2]|0)+24>>2]|0)==(t[n>>2]|0))break;t[f>>2]=t[(t[f>>2]|0)+24>>2]}if((a|0)==15){t[r>>2]=-1;u=t[r>>2]|0;s=i;return u|0}t[(t[f>>2]|0)+24>>2]=t[(t[n>>2]|0)+24>>2];if(t[(t[f>>2]|0)+24>>2]|0)t[(t[(t[f>>2]|0)+24>>2]|0)+28>>2]=t[f>>2];vy(t[n>>2]|0);t[r>>2]=0;u=t[r>>2]|0;s=i;return u|0}function _y(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,l=0;n=s;s=s+32|0;f=n+16|0;u=n+12|0;a=n+8|0;o=n+4|0;c=n;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;if(!(t[a>>2]|0)){t[f>>2]=0;l=t[f>>2]|0;s=n;return l|0}t[c>>2]=gAi[t[135744>>2]&511](60)|0;if(!(t[c>>2]|0)){LF(75344);t[f>>2]=0;l=t[f>>2]|0;s=n;return l|0}r=(t[c>>2]|0)+0|0;i=r+60|0;do{t[r>>2]=0;r=r+4|0}while((r|0)<(i|0));t[(t[c>>2]|0)+4>>2]=7;if((t[u>>2]|0)!=0?(t[(t[u>>2]|0)+80>>2]|0)!=0:0){r=kz(t[(t[u>>2]|0)+80>>2]|0,t[a>>2]|0,-1)|0;t[(t[c>>2]|0)+8>>2]=r}else{r=Yl(t[a>>2]|0)|0;t[(t[c>>2]|0)+8>>2]=r}if(t[o>>2]|0){r=Yl(t[o>>2]|0)|0;t[(t[c>>2]|0)+40>>2]=r}t[(t[c>>2]|0)+32>>2]=t[u>>2];if((t[18774]|0)!=0&(t[33968]|0)!=0)pAi[t[135872>>2]&511](t[c>>2]|0);t[f>>2]=t[c>>2];l=t[f>>2]|0;s=n;return l|0}function py(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0;r=s;s=s+16|0;n=r+12|0;f=r+8|0;u=r+4|0;a=r;t[f>>2]=e;t[u>>2]=i;if(!(t[u>>2]|0)){t[n>>2]=0;o=t[n>>2]|0;s=r;return o|0}t[a>>2]=gAi[t[135744>>2]&511](60)|0;if(!(t[a>>2]|0)){LF(75360);t[n>>2]=0;o=t[n>>2]|0;s=r;return o|0}i=(t[a>>2]|0)+0|0;e=i+60|0;do{t[i>>2]=0;i=i+4|0}while((i|0)<(e|0));t[(t[a>>2]|0)+4>>2]=1;i=Yl(t[u>>2]|0)|0;t[(t[a>>2]|0)+8>>2]=i;t[(t[a>>2]|0)+36>>2]=t[f>>2];if((t[18774]|0)!=0&(t[33968]|0)!=0)pAi[t[135872>>2]&511](t[a>>2]|0);t[n>>2]=t[a>>2];o=t[n>>2]|0;s=r;return o|0}function Ey(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0;r=s;s=s+16|0;n=r+12|0;f=r+8|0;u=r+4|0;a=r;t[f>>2]=e;t[u>>2]=i;if(!(t[u>>2]|0)){t[n>>2]=0;o=t[n>>2]|0;s=r;return o|0}t[a>>2]=gAi[t[135744>>2]&511](60)|0;if(!(t[a>>2]|0)){LF(75360);t[n>>2]=0;o=t[n>>2]|0;s=r;return o|0}i=(t[a>>2]|0)+0|0;e=i+60|0;do{t[i>>2]=0;i=i+4|0}while((i|0)<(e|0));t[(t[a>>2]|0)+4>>2]=1;t[(t[a>>2]|0)+8>>2]=t[u>>2];t[(t[a>>2]|0)+36>>2]=t[f>>2];if((t[18774]|0)!=0&(t[33968]|0)!=0)pAi[t[135872>>2]&511](t[a>>2]|0);t[n>>2]=t[a>>2];o=t[n>>2]|0;s=r;return o|0}function Sy(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0;f=s;s=s+32|0;u=f+20|0;a=f+16|0;o=f+12|0;c=f+8|0;l=f+4|0;b=f;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;t[c>>2]=n;if((t[u>>2]|0)!=0?(t[(t[u>>2]|0)+80>>2]|0)!=0:0){n=t[a>>2]|0;t[l>>2]=Ey(n,kz(t[(t[u>>2]|0)+80>>2]|0,t[o>>2]|0,-1)|0)|0}else t[l>>2]=py(t[a>>2]|0,t[o>>2]|0)|0;if(!(t[l>>2]|0)){k=t[l>>2]|0;s=f;return k|0}t[(t[l>>2]|0)+32>>2]=t[u>>2];if(!(t[c>>2]|0)){k=t[l>>2]|0;s=f;return k|0}o=ly(t[u>>2]|0,t[c>>2]|0)|0;t[(t[l>>2]|0)+12>>2]=o;if(!(t[l>>2]|0)){k=t[l>>2]|0;s=f;return k|0}t[b>>2]=t[(t[l>>2]|0)+12>>2];if(!(t[b>>2]|0)){t[(t[l>>2]|0)+16>>2]=0;k=t[l>>2]|0;s=f;return k|0}while(1){o=(t[(t[b>>2]|0)+24>>2]|0)!=0;t[(t[b>>2]|0)+20>>2]=t[l>>2];h=t[b>>2]|0;if(!o)break;t[b>>2]=t[h+24>>2]}t[(t[l>>2]|0)+16>>2]=h;k=t[l>>2]|0;s=f;return k|0}function gy(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0;f=s;s=s+32|0;u=f+20|0;a=f+16|0;o=f+12|0;c=f+8|0;l=f+4|0;b=f;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;t[c>>2]=n;t[l>>2]=Ey(t[a>>2]|0,t[o>>2]|0)|0;do if(t[l>>2]|0){t[(t[l>>2]|0)+32>>2]=t[u>>2];if((t[c>>2]|0)!=0?(a=ly(t[u>>2]|0,t[c>>2]|0)|0,t[(t[l>>2]|0)+12>>2]=a,(t[l>>2]|0)!=0):0){t[b>>2]=t[(t[l>>2]|0)+12>>2];if(!(t[b>>2]|0)){t[(t[l>>2]|0)+16>>2]=0;break}while(1){a=(t[(t[b>>2]|0)+24>>2]|0)!=0;t[(t[b>>2]|0)+20>>2]=t[l>>2];k=t[b>>2]|0;if(!a)break;t[b>>2]=t[k+24>>2]}t[(t[l>>2]|0)+16>>2]=k}}else if((t[o>>2]|0)!=0&(t[u>>2]|0)!=0?(wz(t[(t[u>>2]|0)+80>>2]|0,t[o>>2]|0)|0)==0:0)pAi[t[135736>>2]&511](t[o>>2]|0);while(0);s=f;return t[l>>2]|0}function yy(e){e=e|0;var i=0,r=0,n=0,f=0,u=0,a=0;i=s;s=s+16|0;r=i+8|0;n=i+4|0;f=i;t[n>>2]=e;t[f>>2]=gAi[t[135744>>2]&511](60)|0;if(!(t[f>>2]|0)){LF(75376);t[r>>2]=0;u=t[r>>2]|0;s=i;return u|0}e=(t[f>>2]|0)+0|0;a=e+60|0;do{t[e>>2]=0;e=e+4|0}while((e|0)<(a|0));t[(t[f>>2]|0)+4>>2]=3;t[(t[f>>2]|0)+8>>2]=75104;if(t[n>>2]|0){e=Yl(t[n>>2]|0)|0;t[(t[f>>2]|0)+40>>2]=e}if((t[18774]|0)!=0&(t[33968]|0)!=0)pAi[t[135872>>2]&511](t[f>>2]|0);t[r>>2]=t[f>>2];u=t[r>>2]|0;s=i;return u|0}function Fy(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,a=0,o=0,c=0,l=0,b=0;r=s;s=s+32|0;n=r+16|0;f=r+12|0;a=r+8|0;o=r+4|0;c=r;t[f>>2]=e;t[a>>2]=i;if(!(t[a>>2]|0)){t[n>>2]=0;l=t[n>>2]|0;s=r;return l|0}t[o>>2]=gAi[t[135744>>2]&511](60)|0;if(!(t[o>>2]|0)){LF(75392);t[n>>2]=0;l=t[n>>2]|0;s=r;return l|0}i=(t[o>>2]|0)+0|0;e=i+60|0;do{t[i>>2]=0;i=i+4|0}while((i|0)<(e|0));t[(t[o>>2]|0)+4>>2]=5;t[(t[o>>2]|0)+32>>2]=t[f>>2];f=t[a>>2]|0;do if((u[t[a>>2]>>0]|0|0)==38){t[a>>2]=f+1;t[c>>2]=rs(t[a>>2]|0)|0;i=t[a>>2]|0;e=t[c>>2]|0;if((u[(t[a>>2]|0)+((t[c>>2]|0)-1)>>0]|0|0)==59){b=ql(i,e-1|0)|0;t[(t[o>>2]|0)+8>>2]=b;break}else{b=ql(i,e)|0;t[(t[o>>2]|0)+8>>2]=b;break}}else{b=Yl(f)|0;t[(t[o>>2]|0)+8>>2]=b}while(0);if((t[18774]|0)!=0&(t[33968]|0)!=0)pAi[t[135872>>2]&511](t[o>>2]|0);t[n>>2]=t[o>>2];l=t[n>>2]|0;s=r;return l|0}function Oy(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0;r=s;s=s+16|0;n=r+12|0;f=r+8|0;u=r+4|0;a=r;t[f>>2]=e;t[u>>2]=i;t[a>>2]=gAi[t[135744>>2]&511](60)|0;if(!(t[a>>2]|0)){LF(75376);t[n>>2]=0;o=t[n>>2]|0;s=r;return o|0}i=(t[a>>2]|0)+0|0;e=i+60|0;do{t[i>>2]=0;i=i+4|0}while((i|0)<(e|0));t[(t[a>>2]|0)+4>>2]=3;t[(t[a>>2]|0)+8>>2]=75104;if(t[f>>2]|0){i=ql(t[f>>2]|0,t[u>>2]|0)|0;t[(t[a>>2]|0)+40>>2]=i}if((t[18774]|0)!=0&(t[33968]|0)!=0)pAi[t[135872>>2]&511](t[a>>2]|0);t[n>>2]=t[a>>2];o=t[n>>2]|0;s=r;return o|0}function Ay(e){e=e|0;var i=0,r=0,n=0,f=0,u=0,a=0;i=s;s=s+16|0;r=i+8|0;n=i+4|0;f=i;t[n>>2]=e;t[f>>2]=gAi[t[135744>>2]&511](60)|0;if(!(t[f>>2]|0)){LF(75448);t[r>>2]=0;u=t[r>>2]|0;s=i;return u|0}e=(t[f>>2]|0)+0|0;a=e+60|0;do{t[e>>2]=0;e=e+4|0}while((e|0)<(a|0));t[(t[f>>2]|0)+4>>2]=8;t[(t[f>>2]|0)+8>>2]=75128;if(t[n>>2]|0){e=Yl(t[n>>2]|0)|0;t[(t[f>>2]|0)+40>>2]=e}if((t[18774]|0)!=0&(t[33968]|0)!=0)pAi[t[135872>>2]&511](t[f>>2]|0);t[r>>2]=t[f>>2];u=t[r>>2]|0;s=i;return u|0}function My(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,l=0;n=s;s=s+32|0;f=n+16|0;u=n+12|0;a=n+8|0;o=n+4|0;c=n;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;t[c>>2]=gAi[t[135744>>2]&511](60)|0;if(!(t[c>>2]|0)){LF(75472);t[f>>2]=0;l=t[f>>2]|0;s=n;return l|0}r=(t[c>>2]|0)+0|0;i=r+60|0;do{t[r>>2]=0;r=r+4|0}while((r|0)<(i|0));t[(t[c>>2]|0)+4>>2]=4;t[(t[c>>2]|0)+32>>2]=t[u>>2];if(t[a>>2]|0){u=ql(t[a>>2]|0,t[o>>2]|0)|0;t[(t[c>>2]|0)+40>>2]=u}if((t[18774]|0)!=0&(t[33968]|0)!=0)pAi[t[135872>>2]&511](t[c>>2]|0);t[f>>2]=t[c>>2];l=t[f>>2]|0;s=n;return l|0}function Ry(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0;r=s;s=s+16|0;n=r+8|0;f=r+4|0;u=r;t[n>>2]=e;t[f>>2]=i;t[u>>2]=Ay(t[f>>2]|0)|0;if(!(t[u>>2]|0)){a=t[u>>2]|0;s=r;return a|0}t[(t[u>>2]|0)+32>>2]=t[n>>2];a=t[u>>2]|0;s=r;return a|0}function Ny(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0;r=s;s=s+16|0;n=r+8|0;f=r+4|0;u=r;t[n>>2]=e;t[f>>2]=i;if(!(t[n>>2]|0)){s=r;return}if((t[(t[n>>2]|0)+4>>2]|0)==18){s=r;return}if((t[(t[n>>2]|0)+32>>2]|0)==(t[f>>2]|0)){s=r;return}e:do if((t[(t[n>>2]|0)+4>>2]|0)==1){t[u>>2]=t[(t[n>>2]|0)+44>>2];while(1){if(!(t[u>>2]|0))break e;t[(t[u>>2]|0)+32>>2]=t[f>>2];Ty(t[(t[u>>2]|0)+12>>2]|0,t[f>>2]|0);t[u>>2]=t[(t[u>>2]|0)+24>>2]}}while(0);if(t[(t[n>>2]|0)+12>>2]|0)Ty(t[(t[n>>2]|0)+12>>2]|0,t[f>>2]|0);t[(t[n>>2]|0)+32>>2]=t[f>>2];s=r;return}function Ty(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0;r=s;s=s+16|0;n=r+8|0;f=r+4|0;u=r;t[n>>2]=e;t[f>>2]=i;if(!(t[n>>2]|0)){s=r;return}if((t[(t[n>>2]|0)+4>>2]|0)==18){s=r;return}t[u>>2]=t[n>>2];while(1){if(!(t[u>>2]|0))break;if((t[(t[u>>2]|0)+32>>2]|0)!=(t[f>>2]|0))Ny(t[u>>2]|0,t[f>>2]|0);t[u>>2]=t[(t[u>>2]|0)+24>>2]}s=r;return}function Ly(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0;f=s;s=s+32|0;u=f+24|0;a=f+20|0;o=f+16|0;c=f+12|0;l=f+8|0;b=f+4|0;k=f;t[a>>2]=e;t[o>>2]=i;t[c>>2]=r;t[l>>2]=n;if(!(t[a>>2]|0)){t[u>>2]=0;h=t[u>>2]|0;s=f;return h|0}if(!(t[c>>2]|0)){t[u>>2]=0;h=t[u>>2]|0;s=f;return h|0}do if((t[(t[a>>2]|0)+4>>2]|0)==1){n=t[(t[a>>2]|0)+32>>2]|0;if(!(t[o>>2]|0)){t[b>>2]=Sy(n,t[(t[a>>2]|0)+36>>2]|0,t[c>>2]|0,t[l>>2]|0)|0;break}else{t[b>>2]=Sy(n,t[o>>2]|0,t[c>>2]|0,t[l>>2]|0)|0;break}}else{if((t[(t[a>>2]|0)+4>>2]|0)!=9?(t[(t[a>>2]|0)+4>>2]|0)!=13:0){if((t[(t[a>>2]|0)+4>>2]|0)==11){t[b>>2]=Sy(t[(t[a>>2]|0)+32>>2]|0,t[o>>2]|0,t[c>>2]|0,t[l>>2]|0)|0;break}t[u>>2]=0;h=t[u>>2]|0;s=f;return h|0}n=t[a>>2]|0;if(!(t[o>>2]|0)){t[b>>2]=Sy(n,0,t[c>>2]|0,t[l>>2]|0)|0;break}else{t[b>>2]=Sy(n,t[o>>2]|0,t[c>>2]|0,t[l>>2]|0)|0;break}}while(0);if(!(t[b>>2]|0)){t[u>>2]=0;h=t[u>>2]|0;s=f;return h|0}t[(t[b>>2]|0)+4>>2]=1;t[(t[b>>2]|0)+20>>2]=t[a>>2];t[(t[b>>2]|0)+32>>2]=t[(t[a>>2]|0)+32>>2];if(!(t[(t[a>>2]|0)+12>>2]|0)){t[(t[a>>2]|0)+12>>2]=t[b>>2];t[(t[a>>2]|0)+16>>2]=t[b>>2]}else{t[k>>2]=t[(t[a>>2]|0)+16>>2];t[(t[k>>2]|0)+24>>2]=t[b>>2];t[(t[b>>2]|0)+28>>2]=t[k>>2];t[(t[a>>2]|0)+16>>2]=t[b>>2]}t[u>>2]=t[b>>2];h=t[u>>2]|0;s=f;return h|0}function Dy(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0;r=s;s=s+16|0;n=r+8|0;f=r+4|0;u=r;t[n>>2]=e;t[f>>2]=i;if((t[n>>2]|0)==0|(t[f>>2]|0)==0){s=r;return}t[u>>2]=rs(t[f>>2]|0)|0;bF(t[n>>2]|0,t[f>>2]|0,t[u>>2]|0);s=r;return}function Cy(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0;r=s;s=s+16|0;n=r+8|0;f=r+4|0;u=r;t[n>>2]=e;t[f>>2]=i;if(!(t[n>>2]|0)){s=r;return}switch(t[(t[n>>2]|0)+4>>2]|0){case 8:case 7:case 6:case 5:case 4:case 3:{do if((t[(t[n>>2]|0)+40>>2]|0)!=0?(t[(t[n>>2]|0)+40>>2]|0)!=((t[n>>2]|0)+44|0):0){if(((t[(t[n>>2]|0)+32>>2]|0)!=0?(t[(t[(t[n>>2]|0)+32>>2]|0)+80>>2]|0)!=0:0)?(wz(t[(t[(t[n>>2]|0)+32>>2]|0)+80>>2]|0,t[(t[n>>2]|0)+40>>2]|0)|0)!=0:0)break;pAi[t[135736>>2]&511](t[(t[n>>2]|0)+40>>2]|0)}while(0);if(t[(t[n>>2]|0)+12>>2]|0)ty(t[(t[n>>2]|0)+12>>2]|0);t[(t[n>>2]|0)+12>>2]=0;t[(t[n>>2]|0)+16>>2]=0;if(t[f>>2]|0){i=Yl(t[f>>2]|0)|0;t[(t[n>>2]|0)+40>>2]=i}else t[(t[n>>2]|0)+40>>2]=0;t[(t[n>>2]|0)+44>>2]=0;t[(t[n>>2]|0)+48>>2]=0;s=r;return}case 2:case 1:case 11:{if(t[(t[n>>2]|0)+12>>2]|0)ty(t[(t[n>>2]|0)+12>>2]|0);i=ly(t[(t[n>>2]|0)+32>>2]|0,t[f>>2]|0)|0;t[(t[n>>2]|0)+12>>2]=i;if(!(t[n>>2]|0)){s=r;return}t[u>>2]=t[(t[n>>2]|0)+12>>2];if(!(t[u>>2]|0)){t[(t[n>>2]|0)+16>>2]=0;s=r;return}while(1){i=(t[(t[u>>2]|0)+24>>2]|0)!=0;t[(t[u>>2]|0)+20>>2]=t[n>>2];a=t[u>>2]|0;if(!i)break;t[u>>2]=t[a+24>>2]}t[(t[n>>2]|0)+16>>2]=a;s=r;return}default:{s=r;return}}}function Py(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0;r=s;s=s+16|0;n=r+12|0;f=r+8|0;u=r+4|0;a=r;t[f>>2]=e;t[u>>2]=i;if((t[f>>2]|0)!=0?(t[(t[f>>2]|0)+4>>2]|0)!=18:0){if((t[u>>2]|0)!=0?(t[(t[u>>2]|0)+4>>2]|0)!=18:0){if((t[f>>2]|0)==(t[u>>2]|0)){t[n>>2]=0;o=t[n>>2]|0;s=r;return o|0}iy(t[u>>2]|0);if((t[(t[u>>2]|0)+4>>2]|0)==3){if((t[(t[f>>2]|0)+4>>2]|0)==3){t[a>>2]=Yl(t[(t[u>>2]|0)+40>>2]|0)|0;t[a>>2]=us(t[a>>2]|0,t[(t[f>>2]|0)+40>>2]|0)|0;Cy(t[f>>2]|0,t[a>>2]|0);pAi[t[135736>>2]&511](t[a>>2]|0);ry(t[u>>2]|0);t[n>>2]=t[f>>2];o=t[n>>2]|0;s=r;return o|0}if(((t[(t[f>>2]|0)+28>>2]|0)!=0?(t[(t[(t[f>>2]|0)+28>>2]|0)+4>>2]|0)==3:0)?(t[(t[f>>2]|0)+8>>2]|0)==(t[(t[(t[f>>2]|0)+28>>2]|0)+8>>2]|0):0){Dy(t[(t[f>>2]|0)+28>>2]|0,t[(t[u>>2]|0)+40>>2]|0);ry(t[u>>2]|0);t[n>>2]=t[(t[f>>2]|0)+28>>2];o=t[n>>2]|0;s=r;return o|0}}else if((t[(t[u>>2]|0)+4>>2]|0)==2){t[n>>2]=CF(t[(t[f>>2]|0)+28>>2]|0,t[f>>2]|0,t[u>>2]|0)|0;o=t[n>>2]|0;s=r;return o|0}if((t[(t[u>>2]|0)+32>>2]|0)!=(t[(t[f>>2]|0)+32>>2]|0))Ny(t[u>>2]|0,t[(t[f>>2]|0)+32>>2]|0);t[(t[u>>2]|0)+20>>2]=t[(t[f>>2]|0)+20>>2];t[(t[u>>2]|0)+24>>2]=t[f>>2];t[(t[u>>2]|0)+28>>2]=t[(t[f>>2]|0)+28>>2];t[(t[f>>2]|0)+28>>2]=t[u>>2];if(t[(t[u>>2]|0)+28>>2]|0)t[(t[(t[u>>2]|0)+28>>2]|0)+24>>2]=t[u>>2];if((t[(t[u>>2]|0)+20>>2]|0)!=0?(t[(t[(t[u>>2]|0)+20>>2]|0)+12>>2]|0)==(t[f>>2]|0):0)t[(t[(t[u>>2]|0)+20>>2]|0)+12>>2]=t[u>>2];t[n>>2]=t[u>>2];o=t[n>>2]|0;s=r;return o|0}t[n>>2]=0;o=t[n>>2]|0;s=r;return o|0}t[n>>2]=0;o=t[n>>2]|0;s=r;return o|0}function By(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0;r=s;s=s+16|0;n=r+12|0;f=r+8|0;u=r+4|0;a=r;t[f>>2]=e;t[u>>2]=i;if((t[f>>2]|0)!=0?(t[(t[f>>2]|0)+4>>2]|0)!=18:0){if((t[u>>2]|0)!=0?(t[(t[u>>2]|0)+4>>2]|0)!=18:0){if((t[f>>2]|0)==(t[u>>2]|0)){t[n>>2]=0;o=t[n>>2]|0;s=r;return o|0}if(((((t[(t[f>>2]|0)+4>>2]|0)!=2?(t[(t[f>>2]|0)+20>>2]|0)!=0:0)?(t[(t[(t[f>>2]|0)+20>>2]|0)+12>>2]|0)!=0:0)?(t[(t[(t[f>>2]|0)+20>>2]|0)+16>>2]|0)!=0:0)?(t[(t[(t[(t[f>>2]|0)+20>>2]|0)+16>>2]|0)+24>>2]|0)==0:0)t[f>>2]=t[(t[(t[f>>2]|0)+20>>2]|0)+16>>2];else c=15;e:do if((c|0)==15)while(1){c=0;if(!(t[(t[f>>2]|0)+24>>2]|0))break e;t[f>>2]=t[(t[f>>2]|0)+24>>2];c=15}while(0);iy(t[u>>2]|0);if(((t[(t[f>>2]|0)+4>>2]|0)==3?(t[(t[u>>2]|0)+4>>2]|0)==3:0)?(t[(t[f>>2]|0)+8>>2]|0)==(t[(t[u>>2]|0)+8>>2]|0):0){Dy(t[f>>2]|0,t[(t[u>>2]|0)+40>>2]|0);ry(t[u>>2]|0);t[n>>2]=t[f>>2];o=t[n>>2]|0;s=r;return o|0}if((t[(t[u>>2]|0)+4>>2]|0)==2){t[n>>2]=CF(t[f>>2]|0,t[f>>2]|0,t[u>>2]|0)|0;o=t[n>>2]|0;s=r;return o|0}if((t[(t[u>>2]|0)+32>>2]|0)!=(t[(t[f>>2]|0)+32>>2]|0))Ny(t[u>>2]|0,t[(t[f>>2]|0)+32>>2]|0);t[a>>2]=t[(t[f>>2]|0)+20>>2];t[(t[u>>2]|0)+28>>2]=t[f>>2];t[(t[u>>2]|0)+24>>2]=0;t[(t[u>>2]|0)+20>>2]=t[a>>2];t[(t[f>>2]|0)+24>>2]=t[u>>2];if(t[a>>2]|0)t[(t[a>>2]|0)+16>>2]=t[u>>2];t[n>>2]=t[u>>2];o=t[n>>2]|0;s=r;return o|0}t[n>>2]=0;o=t[n>>2]|0;s=r;return o|0}t[n>>2]=0;o=t[n>>2]|0;s=r;return o|0}function Iy(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0;r=s;s=s+16|0;n=r+12|0;f=r+8|0;u=r+4|0;a=r;t[f>>2]=e;t[u>>2]=i;if((t[f>>2]|0)!=0?(t[(t[f>>2]|0)+4>>2]|0)!=18:0){if((t[u>>2]|0)!=0?(t[(t[u>>2]|0)+4>>2]|0)!=18:0){i=t[u>>2]|0;if(!(t[(t[f>>2]|0)+12>>2]|0))t[(t[f>>2]|0)+12>>2]=i;else{do if(((t[i+4>>2]|0)==3?(t[(t[(t[f>>2]|0)+16>>2]|0)+4>>2]|0)==3:0)?(t[(t[u>>2]|0)+8>>2]|0)==(t[(t[(t[f>>2]|0)+16>>2]|0)+8>>2]|0):0){Dy(t[(t[f>>2]|0)+16>>2]|0,t[(t[u>>2]|0)+40>>2]|0);e=t[u>>2]|0;if(t[(t[u>>2]|0)+24>>2]|0){t[a>>2]=e;t[u>>2]=t[(t[u>>2]|0)+24>>2];ry(t[a>>2]|0);break}ry(e);t[n>>2]=t[(t[f>>2]|0)+16>>2];o=t[n>>2]|0;s=r;return o|0}while(0);t[a>>2]=t[(t[f>>2]|0)+16>>2];t[(t[a>>2]|0)+24>>2]=t[u>>2];t[(t[u>>2]|0)+28>>2]=t[a>>2]}while(1){a=(t[(t[u>>2]|0)+24>>2]|0)!=0;t[(t[u>>2]|0)+20>>2]=t[f>>2];c=(t[(t[u>>2]|0)+32>>2]|0)!=(t[(t[f>>2]|0)+32>>2]|0);if(!a)break;if(c)Ny(t[u>>2]|0,t[(t[f>>2]|0)+32>>2]|0);t[u>>2]=t[(t[u>>2]|0)+24>>2]}if(c)Ny(t[u>>2]|0,t[(t[f>>2]|0)+32>>2]|0);t[(t[f>>2]|0)+16>>2]=t[u>>2];t[n>>2]=t[u>>2];o=t[n>>2]|0;s=r;return o|0}t[n>>2]=0;o=t[n>>2]|0;s=r;return o|0}t[n>>2]=0;o=t[n>>2]|0;s=r;return o|0}function Hy(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0;r=s;s=s+32|0;n=r+20|0;f=r+16|0;u=r+12|0;a=r+8|0;o=r+4|0;c=r;t[f>>2]=e;t[u>>2]=i;if((t[f>>2]|0)!=0?(t[(t[f>>2]|0)+4>>2]|0)!=18:0){if((t[u>>2]|0)!=0?(t[(t[u>>2]|0)+4>>2]|0)!=18:0){if((t[f>>2]|0)==(t[u>>2]|0)){t[n>>2]=0;l=t[n>>2]|0;s=r;return l|0}if((t[(t[u>>2]|0)+4>>2]|0)==3){if(((t[(t[f>>2]|0)+4>>2]|0)==3?(t[(t[f>>2]|0)+40>>2]|0)!=0:0)?(t[(t[f>>2]|0)+8>>2]|0)==(t[(t[u>>2]|0)+8>>2]|0):0){Dy(t[f>>2]|0,t[(t[u>>2]|0)+40>>2]|0);ry(t[u>>2]|0);t[n>>2]=t[f>>2];l=t[n>>2]|0;s=r;return l|0}if((((t[(t[f>>2]|0)+16>>2]|0)!=0?(t[(t[(t[f>>2]|0)+16>>2]|0)+4>>2]|0)==3:0)?(t[(t[(t[f>>2]|0)+16>>2]|0)+8>>2]|0)==(t[(t[u>>2]|0)+8>>2]|0):0)?(t[(t[f>>2]|0)+16>>2]|0)!=(t[u>>2]|0):0){Dy(t[(t[f>>2]|0)+16>>2]|0,t[(t[u>>2]|0)+40>>2]|0);ry(t[u>>2]|0);t[n>>2]=t[(t[f>>2]|0)+16>>2];l=t[n>>2]|0;s=r;return l|0}}t[a>>2]=t[(t[u>>2]|0)+20>>2];t[(t[u>>2]|0)+20>>2]=t[f>>2];if((t[(t[u>>2]|0)+32>>2]|0)!=(t[(t[f>>2]|0)+32>>2]|0))Ny(t[u>>2]|0,t[(t[f>>2]|0)+32>>2]|0);if((t[a>>2]|0)==(t[f>>2]|0)){t[n>>2]=t[u>>2];l=t[n>>2]|0;s=r;return l|0}if(((t[(t[f>>2]|0)+4>>2]|0)==3?(t[(t[f>>2]|0)+40>>2]|0)!=0:0)?(t[f>>2]|0)!=(t[u>>2]|0):0){Dy(t[f>>2]|0,t[(t[u>>2]|0)+40>>2]|0);ry(t[u>>2]|0);t[n>>2]=t[f>>2];l=t[n>>2]|0;s=r;return l|0}i=t[f>>2]|0;do if((t[(t[u>>2]|0)+4>>2]|0)!=2)if(!(t[i+12>>2]|0)){t[(t[f>>2]|0)+12>>2]=t[u>>2];t[(t[f>>2]|0)+16>>2]=t[u>>2];break}else{t[a>>2]=t[(t[f>>2]|0)+16>>2];t[(t[a>>2]|0)+24>>2]=t[u>>2];t[(t[u>>2]|0)+28>>2]=t[a>>2];t[(t[f>>2]|0)+16>>2]=t[u>>2];break}else{if((t[i+4>>2]|0)!=1){t[n>>2]=0;l=t[n>>2]|0;s=r;return l|0}if(t[(t[f>>2]|0)+44>>2]|0){e=t[f>>2]|0;b=t[(t[u>>2]|0)+8>>2]|0;if(!(t[(t[u>>2]|0)+36>>2]|0))t[o>>2]=xy(e,b,0)|0;else t[o>>2]=xy(e,b,t[(t[(t[u>>2]|0)+36>>2]|0)+8>>2]|0)|0;do if((t[o>>2]|0)!=0?(t[o>>2]|0)!=(t[u>>2]|0):0){if((t[(t[o>>2]|0)+4>>2]|0)==16)break;iy(t[o>>2]|0);vy(t[o>>2]|0)}while(0);if((t[o>>2]|0)==(t[u>>2]|0)){t[n>>2]=t[u>>2];l=t[n>>2]|0;s=r;return l|0}}if(!(t[(t[f>>2]|0)+44>>2]|0)){t[(t[f>>2]|0)+44>>2]=t[u>>2];break}t[c>>2]=t[(t[f>>2]|0)+44>>2];while(1){if(!(t[(t[c>>2]|0)+24>>2]|0))break;t[c>>2]=t[(t[c>>2]|0)+24>>2]}t[(t[c>>2]|0)+24>>2]=t[u>>2];t[(t[u>>2]|0)+28>>2]=t[c>>2]}while(0);t[n>>2]=t[u>>2];l=t[n>>2]|0;s=r;return l|0}t[n>>2]=0;l=t[n>>2]|0;s=r;return l|0}t[n>>2]=0;l=t[n>>2]|0;s=r;return l|0}function xy(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0;n=s;s=s+16|0;f=n+8|0;u=n+4|0;a=n;t[f>>2]=e;t[u>>2]=i;t[a>>2]=r;r=BF(t[f>>2]|0,t[u>>2]|0,t[a>>2]|0,t[18946]|0)|0;s=n;return r|0}function Uy(e){e=e|0;var i=0,r=0,n=0,f=0;i=s;s=s+16|0;r=i+4|0;n=i;t[n>>2]=e;if((t[n>>2]|0)!=0?(t[(t[n>>2]|0)+4>>2]|0)!=18:0){t[r>>2]=t[(t[n>>2]|0)+16>>2];f=t[r>>2]|0;s=i;return f|0}t[r>>2]=0;f=t[r>>2]|0;s=i;return f|0}function zy(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0;r=s;s=s+16|0;n=r+8|0;f=r+4|0;u=r;t[f>>2]=e;t[u>>2]=i;if((t[f>>2]|0)==(t[u>>2]|0)){t[n>>2]=0;a=t[n>>2]|0;s=r;return a|0}if(((t[f>>2]|0)!=0?(t[(t[f>>2]|0)+4>>2]|0)!=18:0)?(t[(t[f>>2]|0)+20>>2]|0)!=0:0){if((t[u>>2]|0)!=0?(t[(t[u>>2]|0)+4>>2]|0)!=18:0){i=t[f>>2]|0;if((t[u>>2]|0)==(t[f>>2]|0)){t[n>>2]=i;a=t[n>>2]|0;s=r;return a|0}if((t[i+4>>2]|0)==2?(t[(t[u>>2]|0)+4>>2]|0)!=2:0){t[n>>2]=t[f>>2];a=t[n>>2]|0;s=r;return a|0}if((t[(t[u>>2]|0)+4>>2]|0)==2?(t[(t[f>>2]|0)+4>>2]|0)!=2:0){
	t[n>>2]=t[f>>2];a=t[n>>2]|0;s=r;return a|0}iy(t[u>>2]|0);Ny(t[u>>2]|0,t[(t[f>>2]|0)+32>>2]|0);t[(t[u>>2]|0)+20>>2]=t[(t[f>>2]|0)+20>>2];t[(t[u>>2]|0)+24>>2]=t[(t[f>>2]|0)+24>>2];if(t[(t[u>>2]|0)+24>>2]|0)t[(t[(t[u>>2]|0)+24>>2]|0)+28>>2]=t[u>>2];t[(t[u>>2]|0)+28>>2]=t[(t[f>>2]|0)+28>>2];if(t[(t[u>>2]|0)+28>>2]|0)t[(t[(t[u>>2]|0)+28>>2]|0)+24>>2]=t[u>>2];do if(t[(t[u>>2]|0)+20>>2]|0){i=t[(t[u>>2]|0)+20>>2]|0;if((t[(t[u>>2]|0)+4>>2]|0)==2){if((t[i+44>>2]|0)!=(t[f>>2]|0))break;t[(t[(t[u>>2]|0)+20>>2]|0)+44>>2]=t[u>>2];break}if((t[i+12>>2]|0)==(t[f>>2]|0))t[(t[(t[u>>2]|0)+20>>2]|0)+12>>2]=t[u>>2];if((t[(t[(t[u>>2]|0)+20>>2]|0)+16>>2]|0)==(t[f>>2]|0))t[(t[(t[u>>2]|0)+20>>2]|0)+16>>2]=t[u>>2]}while(0);t[(t[f>>2]|0)+28>>2]=0;t[(t[f>>2]|0)+24>>2]=0;t[(t[f>>2]|0)+20>>2]=0;t[n>>2]=t[f>>2];a=t[n>>2]|0;s=r;return a|0}iy(t[f>>2]|0);t[n>>2]=t[f>>2];a=t[n>>2]|0;s=r;return a|0}t[n>>2]=0;a=t[n>>2]|0;s=r;return a|0}function jy(e){e=e|0;var i=0,r=0,n=0,f=0;i=s;s=s+16|0;r=i+8|0;n=i+4|0;f=i;t[n>>2]=e;do if(t[n>>2]|0)if((t[(t[n>>2]|0)+4>>2]|0)==18){t[f>>2]=Wg(0,t[(t[n>>2]|0)+8>>2]|0,t[(t[n>>2]|0)+12>>2]|0)|0;t[r>>2]=t[f>>2];break}else{t[r>>2]=0;break}else t[r>>2]=0;while(0);s=i;return t[r>>2]|0}function Vy(e){e=e|0;var i=0,r=0,n=0,f=0,u=0;i=s;s=s+16|0;r=i+12|0;n=i+8|0;f=i+4|0;u=i;t[r>>2]=e;t[n>>2]=0;t[f>>2]=0;while(1){if(!(t[r>>2]|0))break;t[u>>2]=jy(t[r>>2]|0)|0;e=t[u>>2]|0;if(!(t[f>>2]|0)){t[f>>2]=e;t[n>>2]=e}else{t[t[f>>2]>>2]=e;t[f>>2]=t[u>>2]}t[r>>2]=t[t[r>>2]>>2]}s=i;return t[n>>2]|0}function qy(e,i){e=e|0;i=i|0;var r=0,n=0,f=0;r=s;s=s+16|0;n=r+4|0;f=r;t[n>>2]=e;t[f>>2]=i;i=IF(0,t[n>>2]|0,t[f>>2]|0)|0;s=r;return i|0}function Yy(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0;r=s;s=s+32|0;n=r+20|0;f=r+16|0;u=r+12|0;a=r+8|0;o=r+4|0;c=r;t[f>>2]=e;t[u>>2]=i;t[a>>2]=0;t[o>>2]=0;if((t[f>>2]|0)!=0?(t[(t[f>>2]|0)+4>>2]|0)!=1:0){t[n>>2]=0;l=t[n>>2]|0;s=r;return l|0}while(1){if(!(t[u>>2]|0)){b=11;break}t[c>>2]=qy(t[f>>2]|0,t[u>>2]|0)|0;if(!(t[c>>2]|0)){b=6;break}i=t[c>>2]|0;if(!(t[o>>2]|0)){t[o>>2]=i;t[a>>2]=i}else{t[(t[o>>2]|0)+24>>2]=i;t[(t[c>>2]|0)+28>>2]=t[o>>2];t[o>>2]=t[c>>2]}t[u>>2]=t[(t[u>>2]|0)+24>>2]}if((b|0)==6){t[n>>2]=0;l=t[n>>2]|0;s=r;return l|0}else if((b|0)==11){t[n>>2]=t[a>>2];l=t[n>>2]|0;s=r;return l|0}return 0}function Gy(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0;r=s;s=s+16|0;n=r+8|0;f=r+4|0;u=r;t[n>>2]=e;t[f>>2]=i;t[u>>2]=HF(t[n>>2]|0,0,0,t[f>>2]|0)|0;s=r;return t[u>>2]|0}function Wy(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0;n=s;s=s+16|0;f=n+12|0;u=n+8|0;a=n+4|0;o=n;t[f>>2]=e;t[u>>2]=i;t[a>>2]=r;t[o>>2]=HF(t[f>>2]|0,t[u>>2]|0,0,t[a>>2]|0)|0;s=n;return t[o>>2]|0}function Ky(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0;r=s;s=s+16|0;n=r+8|0;f=r+4|0;u=r;t[n>>2]=e;t[f>>2]=i;t[u>>2]=xF(t[f>>2]|0,t[n>>2]|0,0)|0;s=r;return t[u>>2]|0}function Xy(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i+4|0;n=i;t[r>>2]=e;t[n>>2]=xF(t[r>>2]|0,0,0)|0;s=i;return t[n>>2]|0}function Zy(e){e=e|0;var i=0,r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0;i=s;s=s+48|0;r=i+32|0;n=i+28|0;f=i+24|0;u=i+20|0;a=i+16|0;o=i+12|0;c=i+8|0;l=i+4|0;b=i;t[n>>2]=e;t[a>>2]=0;if(!(t[n>>2]|0)){t[r>>2]=0;k=t[r>>2]|0;s=i;return k|0}t[f>>2]=Jg(0,t[(t[n>>2]|0)+8>>2]|0,t[(t[n>>2]|0)+52>>2]|0,t[(t[n>>2]|0)+56>>2]|0)|0;if(!(t[f>>2]|0)){t[r>>2]=0;k=t[r>>2]|0;s=i;return k|0}if(t[(t[n>>2]|0)+48>>2]|0){e=m_(t[(t[n>>2]|0)+48>>2]|0)|0;t[(t[f>>2]|0)+48>>2]=e}if(t[(t[n>>2]|0)+36>>2]|0){e=HM(t[(t[n>>2]|0)+36>>2]|0)|0;t[(t[f>>2]|0)+36>>2]=e}if(t[(t[n>>2]|0)+40>>2]|0){e=AM(t[(t[n>>2]|0)+40>>2]|0)|0;t[(t[f>>2]|0)+40>>2]=e}if(t[(t[n>>2]|0)+44>>2]|0){e=CM(t[(t[n>>2]|0)+44>>2]|0)|0;t[(t[f>>2]|0)+44>>2]=e}if(t[(t[n>>2]|0)+60>>2]|0){e=m_(t[(t[n>>2]|0)+60>>2]|0)|0;t[(t[f>>2]|0)+60>>2]=e}t[u>>2]=t[(t[n>>2]|0)+12>>2];while(1){if(!(t[u>>2]|0))break;t[o>>2]=0;n=t[u>>2]|0;e:do if((t[(t[u>>2]|0)+4>>2]|0)!=17){e=t[u>>2]|0;if((t[n+4>>2]|0)==15){t[l>>2]=e;t[o>>2]=JM(t[f>>2]|0,t[(t[l>>2]|0)+8>>2]|0,t[(t[l>>2]|0)+48>>2]|0)|0;break}h=t[u>>2]|0;if((t[e+4>>2]|0)==16){t[b>>2]=h;t[o>>2]=QM(t[f>>2]|0,t[(t[b>>2]|0)+60>>2]|0,t[(t[b>>2]|0)+8>>2]|0,t[(t[b>>2]|0)+56>>2]|0)|0;break}if((t[h+4>>2]|0)==8)t[o>>2]=Gy(t[u>>2]|0,0)|0}else{t[c>>2]=n;switch(t[(t[c>>2]|0)+48>>2]|0){case 3:case 2:case 1:{t[o>>2]=UF(t[f>>2]|0,t[(t[c>>2]|0)+8>>2]|0)|0;break e;break}case 5:case 4:{t[o>>2]=zF(t[f>>2]|0,t[(t[c>>2]|0)+8>>2]|0)|0;break e;break}default:break e}}while(0);if(!(t[o>>2]|0)){t[u>>2]=t[(t[u>>2]|0)+24>>2];continue}n=t[o>>2]|0;if(!(t[a>>2]|0))t[(t[f>>2]|0)+12>>2]=n;else t[(t[a>>2]|0)+24>>2]=n;t[(t[o>>2]|0)+28>>2]=t[a>>2];t[(t[o>>2]|0)+20>>2]=t[f>>2];t[(t[o>>2]|0)+24>>2]=0;t[(t[f>>2]|0)+16>>2]=t[o>>2];t[a>>2]=t[o>>2];t[u>>2]=t[(t[u>>2]|0)+24>>2]}t[r>>2]=t[f>>2];k=t[r>>2]|0;s=i;return k|0}function Jy(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0;r=s;s=s+32|0;n=r+16|0;f=r+12|0;u=r+8|0;a=r+4|0;o=r;t[f>>2]=e;t[u>>2]=i;if(!(t[f>>2]|0)){t[n>>2]=0;c=t[n>>2]|0;s=r;return c|0}t[a>>2]=ny(t[(t[f>>2]|0)+56>>2]|0)|0;if(!(t[a>>2]|0)){t[n>>2]=0;c=t[n>>2]|0;s=r;return c|0}if(t[(t[f>>2]|0)+8>>2]|0){i=gAi[t[135768>>2]&511](t[(t[f>>2]|0)+8>>2]|0)|0;t[(t[a>>2]|0)+8>>2]=i}if(t[(t[f>>2]|0)+60>>2]|0){i=Yl(t[(t[f>>2]|0)+60>>2]|0)|0;t[(t[a>>2]|0)+60>>2]=i}if(t[(t[f>>2]|0)+72>>2]|0){i=Yl(t[(t[f>>2]|0)+72>>2]|0)|0;t[(t[a>>2]|0)+72>>2]=i}t[(t[a>>2]|0)+76>>2]=t[(t[f>>2]|0)+76>>2];t[(t[a>>2]|0)+36>>2]=t[(t[f>>2]|0)+36>>2];t[(t[a>>2]|0)+40>>2]=t[(t[f>>2]|0)+40>>2];i=t[a>>2]|0;if(!(t[u>>2]|0)){t[n>>2]=i;c=t[n>>2]|0;s=r;return c|0}t[i+16>>2]=0;t[(t[a>>2]|0)+12>>2]=0;do if(t[(t[f>>2]|0)+44>>2]|0){i=Zy(t[(t[f>>2]|0)+44>>2]|0)|0;t[(t[a>>2]|0)+44>>2]=i;i=t[a>>2]|0;if(t[(t[a>>2]|0)+44>>2]|0){Ny(t[i+44>>2]|0,t[a>>2]|0);t[(t[(t[a>>2]|0)+44>>2]|0)+20>>2]=t[a>>2];break}fy(i);t[n>>2]=0;c=t[n>>2]|0;s=r;return c|0}while(0);if(t[(t[f>>2]|0)+52>>2]|0){i=Vy(t[(t[f>>2]|0)+52>>2]|0)|0;t[(t[a>>2]|0)+52>>2]=i}e:do if(t[(t[f>>2]|0)+12>>2]|0){i=xF(t[(t[f>>2]|0)+12>>2]|0,t[a>>2]|0,t[a>>2]|0)|0;t[(t[a>>2]|0)+12>>2]=i;t[(t[a>>2]|0)+16>>2]=0;t[o>>2]=t[(t[a>>2]|0)+12>>2];while(1){if(!(t[o>>2]|0))break e;if(!(t[(t[o>>2]|0)+24>>2]|0))t[(t[a>>2]|0)+16>>2]=t[o>>2];t[o>>2]=t[(t[o>>2]|0)+24>>2]}}while(0);t[n>>2]=t[a>>2];c=t[n>>2]|0;s=r;return c|0}function Qy(e){e=e|0;var i=0,r=0;i=s;s=s+16|0;r=i;t[r>>2]=e;e=jF(t[r>>2]|0,0)|0;s=i;return e|0}function $y(e){e=e|0;var i=0,r=0,f=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0,S=0,g=0,y=0,F=0,O=0;i=s;s=s+176|0;r=i;f=i+64|0;a=i+60|0;o=i+56|0;c=i+52|0;l=i+48|0;b=i+44|0;k=i+40|0;h=i+36|0;w=i+32|0;d=i+28|0;v=i+24|0;m=i+68|0;_=i+20|0;p=i+16|0;t[a>>2]=e;t[b>>2]=0;t[_>>2]=0;if((t[a>>2]|0)!=0?(t[(t[a>>2]|0)+4>>2]|0)!=18:0){t[h>>2]=500;t[b>>2]=gAi[t[135752>>2]&511](t[h>>2]|0)|0;if(!(t[b>>2]|0)){LF(75488);t[f>>2]=0;E=t[f>>2]|0;s=i;return E|0}t[w>>2]=gAi[t[135752>>2]&511](t[h>>2]|0)|0;if(!(t[w>>2]|0)){LF(75488);pAi[t[135736>>2]&511](t[b>>2]|0);t[f>>2]=0;E=t[f>>2]|0;s=i;return E|0}n[t[b>>2]>>0]=0;t[o>>2]=t[a>>2];while(1){t[v>>2]=75312;t[d>>2]=75512;t[_>>2]=0;e:do if((t[(t[o>>2]|0)+4>>2]|0)!=9?(t[(t[o>>2]|0)+4>>2]|0)!=13:0){if((t[(t[o>>2]|0)+4>>2]|0)==1){t[p>>2]=0;t[d>>2]=75520;t[v>>2]=t[(t[o>>2]|0)+8>>2];do if(t[(t[o>>2]|0)+36>>2]|0)if(t[(t[(t[o>>2]|0)+36>>2]|0)+12>>2]|0){a=t[(t[o>>2]|0)+8>>2]|0;t[r>>2]=t[(t[(t[o>>2]|0)+36>>2]|0)+12>>2];t[r+4>>2]=a;SY(m,99,75528,r)|0;n[m+99>>0]=0;t[v>>2]=m;break}else{t[p>>2]=1;t[v>>2]=75536;break}while(0);t[l>>2]=t[(t[o>>2]|0)+20>>2];t[c>>2]=t[(t[o>>2]|0)+28>>2];while(1){if(!(t[c>>2]|0))break;do if((t[(t[c>>2]|0)+4>>2]|0)==1){if(!(t[p>>2]|0)){if(!(Xl(t[(t[o>>2]|0)+8>>2]|0,t[(t[c>>2]|0)+8>>2]|0)|0))break;if((t[(t[c>>2]|0)+36>>2]|0)!=(t[(t[o>>2]|0)+36>>2]|0)){if(!(t[(t[c>>2]|0)+36>>2]|0))break;if(!(t[(t[o>>2]|0)+36>>2]|0))break;if(!(Xl(t[(t[(t[o>>2]|0)+36>>2]|0)+12>>2]|0,t[(t[(t[c>>2]|0)+36>>2]|0)+12>>2]|0)|0))break}}t[_>>2]=(t[_>>2]|0)+1}while(0);t[c>>2]=t[(t[c>>2]|0)+28>>2]}if(t[_>>2]|0){t[_>>2]=(t[_>>2]|0)+1;break}t[c>>2]=t[(t[o>>2]|0)+24>>2];while(1){if(!((t[c>>2]|0)!=0&(t[_>>2]|0)==0))break;i:do if((t[(t[c>>2]|0)+4>>2]|0)==1){do if(!(t[p>>2]|0)){if(!(Xl(t[(t[o>>2]|0)+8>>2]|0,t[(t[c>>2]|0)+8>>2]|0)|0))break i;if((t[(t[c>>2]|0)+36>>2]|0)==(t[(t[o>>2]|0)+36>>2]|0))break;if(!(t[(t[c>>2]|0)+36>>2]|0))break i;if(!(t[(t[o>>2]|0)+36>>2]|0))break i;if(!(Xl(t[(t[(t[o>>2]|0)+36>>2]|0)+12>>2]|0,t[(t[(t[c>>2]|0)+36>>2]|0)+12>>2]|0)|0))break i}while(0);t[_>>2]=(t[_>>2]|0)+1}while(0);t[c>>2]=t[(t[c>>2]|0)+24>>2]}if(!(t[_>>2]|0))break;t[_>>2]=1;break}if((t[(t[o>>2]|0)+4>>2]|0)==8){t[d>>2]=75520;t[v>>2]=75544;t[l>>2]=t[(t[o>>2]|0)+20>>2];t[c>>2]=t[(t[o>>2]|0)+28>>2];while(1){if(!(t[c>>2]|0))break;if((t[(t[c>>2]|0)+4>>2]|0)==8)t[_>>2]=(t[_>>2]|0)+1;t[c>>2]=t[(t[c>>2]|0)+28>>2]}if(t[_>>2]|0){t[_>>2]=(t[_>>2]|0)+1;break}t[c>>2]=t[(t[o>>2]|0)+24>>2];while(1){if(!((t[c>>2]|0)!=0&(t[_>>2]|0)==0))break;if((t[(t[c>>2]|0)+4>>2]|0)==8)t[_>>2]=(t[_>>2]|0)+1;t[c>>2]=t[(t[c>>2]|0)+24>>2]}if(!(t[_>>2]|0))break;t[_>>2]=1;break}if((t[(t[o>>2]|0)+4>>2]|0)!=3?(t[(t[o>>2]|0)+4>>2]|0)!=4:0){if((t[(t[o>>2]|0)+4>>2]|0)!=7){if((t[(t[o>>2]|0)+4>>2]|0)!=2){t[l>>2]=t[(t[o>>2]|0)+20>>2];break}t[d>>2]=75600;t[v>>2]=t[(t[o>>2]|0)+8>>2];if(t[(t[o>>2]|0)+36>>2]|0){a=t[o>>2]|0;if(t[(t[(t[o>>2]|0)+36>>2]|0)+12>>2]|0){e=t[(t[o>>2]|0)+8>>2]|0;t[r>>2]=t[(t[a+36>>2]|0)+12>>2];t[r+4>>2]=e;SY(m,99,75528,r)|0}else{t[r>>2]=t[a+8>>2];SY(m,99,75608,r)|0}n[m+99>>0]=0;t[v>>2]=m}t[l>>2]=t[(t[o>>2]|0)+20>>2];break}t[d>>2]=75520;t[r>>2]=t[(t[o>>2]|0)+8>>2];SY(m,99,75568,r)|0;n[m+99>>0]=0;t[v>>2]=m;t[l>>2]=t[(t[o>>2]|0)+20>>2];t[c>>2]=t[(t[o>>2]|0)+28>>2];while(1){if(!(t[c>>2]|0))break;if((t[(t[c>>2]|0)+4>>2]|0)==7?(Xl(t[(t[o>>2]|0)+8>>2]|0,t[(t[c>>2]|0)+8>>2]|0)|0)!=0:0)t[_>>2]=(t[_>>2]|0)+1;t[c>>2]=t[(t[c>>2]|0)+28>>2]}if(t[_>>2]|0){t[_>>2]=(t[_>>2]|0)+1;break}t[c>>2]=t[(t[o>>2]|0)+24>>2];while(1){if(!((t[c>>2]|0)!=0&(t[_>>2]|0)==0))break;do if((t[(t[c>>2]|0)+4>>2]|0)==7){if(!(Xl(t[(t[o>>2]|0)+8>>2]|0,t[(t[c>>2]|0)+8>>2]|0)|0))break;t[_>>2]=(t[_>>2]|0)+1}while(0);t[c>>2]=t[(t[c>>2]|0)+24>>2]}if(!(t[_>>2]|0))break;t[_>>2]=1;break}t[d>>2]=75520;t[v>>2]=75560;t[l>>2]=t[(t[o>>2]|0)+20>>2];t[c>>2]=t[(t[o>>2]|0)+28>>2];while(1){if(!(t[c>>2]|0))break;if(!((t[(t[c>>2]|0)+4>>2]|0)!=3?(t[(t[c>>2]|0)+4>>2]|0)!=4:0))t[_>>2]=(t[_>>2]|0)+1;t[c>>2]=t[(t[c>>2]|0)+28>>2]}if(t[_>>2]|0){t[_>>2]=(t[_>>2]|0)+1;break}t[c>>2]=t[(t[o>>2]|0)+24>>2];while(1){if(!(t[c>>2]|0))break e;if((t[(t[c>>2]|0)+4>>2]|0)==3)break;if((t[(t[c>>2]|0)+4>>2]|0)==4)break;t[c>>2]=t[(t[c>>2]|0)+24>>2]}t[_>>2]=1}else S=11;while(0);if((S|0)==11){S=0;if((u[t[b>>2]>>0]|0|0)==47){S=110;break}t[d>>2]=75520;t[l>>2]=0}a=(rs(t[b>>2]|0)|0)+120|0;if(a>>>0>(t[h>>2]|0)>>>0){a=t[h>>2]<<1;t[h>>2]=a+(rs(t[b>>2]|0)|0)+120;t[k>>2]=MAi[t[135760>>2]&511](t[b>>2]|0,t[h>>2]|0)|0;if(!(t[k>>2]|0)){S=102;break}t[b>>2]=t[k>>2];t[k>>2]=MAi[t[135760>>2]&511](t[w>>2]|0,t[h>>2]|0)|0;if(!(t[k>>2]|0)){S=104;break}t[w>>2]=t[k>>2]}a=t[w>>2]|0;e=t[h>>2]|0;g=t[d>>2]|0;y=t[v>>2]|0;if(!(t[_>>2]|0)){F=t[b>>2]|0;t[r>>2]=g;t[r+4>>2]=y;t[r+8>>2]=F;SY(a,e,75616,r)|0}else{F=t[_>>2]|0;O=t[b>>2]|0;t[r>>2]=g;t[r+4>>2]=y;t[r+8>>2]=F;t[r+12>>2]=O;SY(a,e,75624,r)|0}e=t[b>>2]|0;a=t[h>>2]|0;t[r>>2]=t[w>>2];SY(e,a,75608,r)|0;t[o>>2]=t[l>>2];if(!(t[o>>2]|0)){S=110;break}}if((S|0)==102){LF(75488);pAi[t[135736>>2]&511](t[w>>2]|0);pAi[t[135736>>2]&511](t[b>>2]|0);t[f>>2]=0;E=t[f>>2]|0;s=i;return E|0}else if((S|0)==104){LF(75488);pAi[t[135736>>2]&511](t[w>>2]|0);pAi[t[135736>>2]&511](t[b>>2]|0);t[f>>2]=0;E=t[f>>2]|0;s=i;return E|0}else if((S|0)==110){pAi[t[135736>>2]&511](t[w>>2]|0);t[f>>2]=t[b>>2];E=t[f>>2]|0;s=i;return E|0}}t[f>>2]=0;E=t[f>>2]|0;s=i;return E|0}function eF(e){e=e|0;var i=0,r=0,n=0,f=0,u=0,a=0,o=0,c=0;i=s;s=s+16|0;r=i+8|0;n=i+4|0;f=i;t[n>>2]=e;if(!(t[n>>2]|0)){t[r>>2]=0;u=t[r>>2]|0;s=i;return u|0}t[f>>2]=t[(t[n>>2]|0)+12>>2];while(1){a=t[f>>2]|0;if(!(t[f>>2]|0)){o=8;break}c=t[f>>2]|0;if((t[a+4>>2]|0)==1){o=6;break}t[f>>2]=t[c+24>>2]}if((o|0)==6){t[r>>2]=c;u=t[r>>2]|0;s=i;return u|0}else if((o|0)==8){t[r>>2]=a;u=t[r>>2]|0;s=i;return u|0}return 0}function iF(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0;r=s;s=s+16|0;n=r+12|0;f=r+8|0;u=r+4|0;a=r;t[f>>2]=e;t[u>>2]=i;t[a>>2]=0;if(!(t[f>>2]|0)){t[n>>2]=0;o=t[n>>2]|0;s=r;return o|0}if((t[u>>2]|0)!=0?(t[(t[u>>2]|0)+4>>2]|0)!=18:0){iy(t[u>>2]|0);Ny(t[u>>2]|0,t[f>>2]|0);t[(t[u>>2]|0)+20>>2]=t[f>>2];t[a>>2]=t[(t[f>>2]|0)+12>>2];while(1){if(!(t[a>>2]|0))break;if((t[(t[a>>2]|0)+4>>2]|0)==1)break;t[a>>2]=t[(t[a>>2]|0)+24>>2]}do if(!(t[a>>2]|0))if(!(t[(t[f>>2]|0)+12>>2]|0)){t[(t[f>>2]|0)+12>>2]=t[u>>2];t[(t[f>>2]|0)+16>>2]=t[u>>2];break}else{By(t[(t[f>>2]|0)+12>>2]|0,t[u>>2]|0)|0;break}else zy(t[a>>2]|0,t[u>>2]|0)|0;while(0);t[n>>2]=t[a>>2];o=t[n>>2]|0;s=r;return o|0}t[n>>2]=0;o=t[n>>2]|0;s=r;return o|0}function rF(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0;n=s;s=s+32|0;f=n+24|0;u=n+20|0;a=n+16|0;o=n+12|0;c=n+8|0;l=n+4|0;b=n;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;t[l>>2]=t[a>>2];if((t[a>>2]|0)!=0?!((t[o>>2]|0)==0?1:(t[(t[a>>2]|0)+4>>2]|0)==18):0){if(Xl(t[o>>2]|0,75176)|0){if((t[u>>2]|0)==0?(t[(t[a>>2]|0)+4>>2]|0)==1:0){t[c>>2]=gAi[t[135744>>2]&511](24)|0;if(!(t[c>>2]|0)){LF(75760);t[f>>2]=0;k=t[f>>2]|0;s=n;return k|0}else{r=t[c>>2]|0;t[r+0>>2]=0;t[r+4>>2]=0;t[r+8>>2]=0;t[r+12>>2]=0;t[r+16>>2]=0;t[r+20>>2]=0;t[(t[c>>2]|0)+4>>2]=18;r=Yl(75176)|0;t[(t[c>>2]|0)+8>>2]=r;r=Yl(75168)|0;t[(t[c>>2]|0)+12>>2]=r;t[t[c>>2]>>2]=t[(t[a>>2]|0)+48>>2];t[(t[a>>2]|0)+48>>2]=t[c>>2];t[f>>2]=t[c>>2];k=t[f>>2]|0;s=n;return k|0}}if((t[u>>2]|0)==0?(t[u>>2]=t[(t[a>>2]|0)+32>>2],(t[u>>2]|0)==0):0){t[f>>2]=0;k=t[f>>2]|0;s=n;return k|0}r=t[u>>2]|0;if(!(t[(t[u>>2]|0)+52>>2]|0)){t[f>>2]=VF(r)|0;k=t[f>>2]|0;s=n;return k|0}else{t[f>>2]=t[r+52>>2];k=t[f>>2]|0;s=n;return k|0}}t[b>>2]=(t[(t[a>>2]|0)+4>>2]|0)==2&1;e:while(1){if(!(t[a>>2]|0)){h=41;break}if((t[(t[a>>2]|0)+4>>2]|0)==5){h=21;break}if((t[(t[a>>2]|0)+4>>2]|0)==6){h=21;break}if((t[(t[a>>2]|0)+4>>2]|0)==17){h=21;break}do if((t[(t[a>>2]|0)+4>>2]|0)==1){t[c>>2]=t[(t[a>>2]|0)+48>>2];while(1){if(!(t[c>>2]|0))break;do if(((t[o>>2]|0)!=0?(t[(t[c>>2]|0)+8>>2]|0)!=0:0)?(Xl(t[(t[c>>2]|0)+8>>2]|0,t[o>>2]|0)|0)!=0:0){if((t[b>>2]|0)!=0?(t[(t[c>>2]|0)+12>>2]|0)==0:0)break;if((qF(t[u>>2]|0,t[l>>2]|0,t[a>>2]|0,t[(t[c>>2]|0)+12>>2]|0)|0)==1){h=30;break e}}while(0);t[c>>2]=t[t[c>>2]>>2]}if((((t[l>>2]|0)!=(t[a>>2]|0)?(t[c>>2]=t[(t[a>>2]|0)+36>>2],(t[c>>2]|0)!=0):0)?(t[o>>2]|0)!=0?(t[(t[c>>2]|0)+8>>2]|0)!=0:0:0)?(Xl(t[(t[c>>2]|0)+8>>2]|0,t[o>>2]|0)|0)!=0:0){if((t[b>>2]|0)!=0?(t[(t[c>>2]|0)+12>>2]|0)==0:0)break;if((qF(t[u>>2]|0,t[l>>2]|0,t[a>>2]|0,t[(t[c>>2]|0)+12>>2]|0)|0)==1){h=39;break e}}}while(0);t[a>>2]=t[(t[a>>2]|0)+20>>2]}if((h|0)==21){t[f>>2]=0;k=t[f>>2]|0;s=n;return k|0}else if((h|0)==30){t[f>>2]=t[c>>2];k=t[f>>2]|0;s=n;return k|0}else if((h|0)==39){t[f>>2]=t[c>>2];k=t[f>>2]|0;s=n;return k|0}else if((h|0)==41){t[f>>2]=0;k=t[f>>2]|0;s=n;return k|0}}t[f>>2]=0;k=t[f>>2]|0;s=n;return k|0}function nF(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0;f=s;s=s+32|0;u=f+24|0;a=f+20|0;o=f+16|0;c=f+12|0;l=f+8|0;b=f+4|0;k=f;t[a>>2]=e;t[o>>2]=i;t[c>>2]=r;t[l>>2]=n;if((t[o>>2]|0)!=0?(t[(t[o>>2]|0)+8>>2]|0)==0:0){t[u>>2]=0;h=t[u>>2]|0;s=f;return h|0}if(t[o>>2]|0)w=t[(t[o>>2]|0)+8>>2]|0;else w=0;t[b>>2]=BF(t[a>>2]|0,t[c>>2]|0,w,0)|0;if(!(t[b>>2]|0)){t[u>>2]=PF(t[a>>2]|0,t[o>>2]|0,t[c>>2]|0,t[l>>2]|0,0)|0;h=t[u>>2]|0;s=f;return h|0}if((t[(t[b>>2]|0)+40>>2]|0)==2){YM(t[(t[a>>2]|0)+32>>2]|0,t[b>>2]|0)|0;t[(t[b>>2]|0)+40>>2]=2}if(t[(t[b>>2]|0)+12>>2]|0)ty(t[(t[b>>2]|0)+12>>2]|0);t[(t[b>>2]|0)+12>>2]=0;t[(t[b>>2]|0)+16>>2]=0;t[(t[b>>2]|0)+36>>2]=t[o>>2];e:do if(t[l>>2]|0){if((ls(t[l>>2]|0)|0)==0?(DF(1303,t[(t[a>>2]|0)+32>>2]|0,0),(t[(t[a>>2]|0)+32>>2]|0)!=0):0){o=Yl(75792)|0;t[(t[(t[a>>2]|0)+32>>2]|0)+60>>2]=o}o=ay(t[(t[a>>2]|0)+32>>2]|0,t[l>>2]|0)|0;t[(t[b>>2]|0)+12>>2]=o;t[(t[b>>2]|0)+16>>2]=0;t[k>>2]=t[(t[b>>2]|0)+12>>2];while(1){if(!(t[k>>2]|0))break e;t[(t[k>>2]|0)+20>>2]=t[b>>2];if(!(t[(t[k>>2]|0)+24>>2]|0))t[(t[b>>2]|0)+16>>2]=t[k>>2];t[k>>2]=t[(t[k>>2]|0)+24>>2]}}while(0);if((t[(t[b>>2]|0)+40>>2]|0)==2)zM(0,t[(t[a>>2]|0)+32>>2]|0,t[l>>2]|0,t[b>>2]|0)|0;t[u>>2]=t[b>>2];h=t[u>>2]|0;s=f;return h|0}function fF(e){e=e|0;var i=0,r=0,n=0,f=0,u=0,a=0;i=s;s=s+16|0;r=i+8|0;n=i+4|0;f=i;t[n>>2]=e;if((t[n>>2]|0)!=0?(t[(t[n>>2]|0)+4>>2]|0)!=18:0){while(1){if(!(t[n>>2]|0)){u=8;break}t[f>>2]=tF(t[n>>2]|0,75640,75176)|0;if(t[f>>2]|0){u=6;break}t[n>>2]=t[(t[n>>2]|0)+20>>2]}if((u|0)==6){t[r>>2]=t[f>>2];a=t[r>>2]|0;s=i;return a|0}else if((u|0)==8){t[r>>2]=0;a=t[r>>2]|0;s=i;return a|0}}t[r>>2]=0;a=t[r>>2]|0;s=i;return a|0}function tF(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,l=0;n=s;s=s+32|0;f=n+16|0;u=n+12|0;a=n+8|0;o=n+4|0;c=n;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;t[c>>2]=BF(t[u>>2]|0,t[a>>2]|0,t[o>>2]|0,t[18946]|0)|0;if(!(t[c>>2]|0)){t[f>>2]=0;l=t[f>>2]|0;s=n;return l|0}else{t[f>>2]=YF(t[c>>2]|0)|0;l=t[f>>2]|0;s=n;return l|0}return 0}function uF(e){e=e|0;var i=0,r=0,n=0,f=0,u=0,a=0;i=s;s=s+16|0;r=i+8|0;n=i+4|0;f=i;t[n>>2]=e;if((t[n>>2]|0)!=0?(t[(t[n>>2]|0)+4>>2]|0)==1:0){while(1){if(!(t[n>>2]|0)){u=11;break}t[f>>2]=tF(t[n>>2]|0,75648,75176)|0;if(t[f>>2]|0){if(Xl(t[f>>2]|0,75664)|0){u=7;break}e=(Xl(t[f>>2]|0,75656)|0)!=0;pAi[t[135736>>2]&511](t[f>>2]|0);if(e){u=9;break}}t[n>>2]=t[(t[n>>2]|0)+20>>2]}if((u|0)==7){pAi[t[135736>>2]&511](t[f>>2]|0);t[r>>2]=1;a=t[r>>2]|0;s=i;return a|0}else if((u|0)==9){t[r>>2]=0;a=t[r>>2]|0;s=i;return a|0}else if((u|0)==11){t[r>>2]=-1;a=t[r>>2]|0;s=i;return a|0}}t[r>>2]=-1;a=t[r>>2]|0;s=i;return a|0}function aF(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0;r=s;s=s+32|0;n=r+16|0;f=r+12|0;u=r+8|0;a=r+4|0;o=r;t[n>>2]=e;t[f>>2]=i;if(!(t[n>>2]|0)){s=r;return}switch(t[(t[n>>2]|0)+4>>2]|0){case 9:case 21:case 13:{t[o>>2]=t[n>>2];if(t[(t[o>>2]|0)+72>>2]|0)pAi[t[135736>>2]&511](t[(t[o>>2]|0)+72>>2]|0);if(!(t[f>>2]|0)){t[(t[o>>2]|0)+72>>2]=0;s=r;return}else{i=XA(t[f>>2]|0)|0;t[(t[o>>2]|0)+72>>2]=i;s=r;return}break}case 20:case 19:case 18:case 6:case 5:case 7:case 17:case 16:case 15:case 14:case 12:case 11:case 10:case 8:case 4:case 3:{s=r;return}default:{t[u>>2]=rF(t[(t[n>>2]|0)+32>>2]|0,t[n>>2]|0,75176)|0;if(!(t[u>>2]|0)){s=r;return}t[a>>2]=XA(t[f>>2]|0)|0;i=t[n>>2]|0;n=t[u>>2]|0;if(t[a>>2]|0){nF(i,n,75680,t[a>>2]|0)|0;pAi[t[135736>>2]&511](t[a>>2]|0);s=r;return}else{nF(i,n,75680,t[f>>2]|0)|0;s=r;return}}}}function oF(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0;r=s;s=s+32|0;n=r+24|0;f=r+20|0;u=r+16|0;a=r+12|0;o=r+8|0;c=r+4|0;l=r;t[f>>2]=e;t[u>>2]=i;t[a>>2]=0;if((t[u>>2]|0)==0&(t[f>>2]|0)==0){t[n>>2]=0;b=t[n>>2]|0;s=r;return b|0}if((t[u>>2]|0)!=0?(t[(t[u>>2]|0)+4>>2]|0)==18:0){t[n>>2]=0;b=t[n>>2]|0;s=r;return b|0}if(!(t[f>>2]|0))t[f>>2]=t[(t[u>>2]|0)+32>>2];if((t[f>>2]|0)!=0?(t[(t[f>>2]|0)+4>>2]|0)==13:0){t[u>>2]=t[(t[f>>2]|0)+12>>2];while(1){if(!(t[u>>2]|0)){k=22;break}if(!(t[(t[u>>2]|0)+8>>2]|0)){k=22;break}i=t[u>>2]|0;if((t[(t[u>>2]|0)+4>>2]|0)!=1){t[u>>2]=t[i+24>>2];continue}e=(Ql(t[i+8>>2]|0,75688)|0)!=0;i=t[u>>2]|0;if(!e){t[u>>2]=t[i+12>>2];continue}e=(Ql(t[i+8>>2]|0,75696)|0)!=0;i=t[u>>2]|0;if(!e){t[u>>2]=t[i+12>>2];continue}e=(Ql(t[i+8>>2]|0,75680)|0)!=0;h=t[u>>2]|0;if(!e){k=20;break}t[u>>2]=t[h+24>>2]}if((k|0)==20){t[n>>2]=cF(h,75704)|0;b=t[n>>2]|0;s=r;return b|0}else if((k|0)==22){t[n>>2]=0;b=t[n>>2]|0;s=r;return b|0}}while(1){if(!(t[u>>2]|0)){k=38;break}w=t[u>>2]|0;if((t[(t[u>>2]|0)+4>>2]|0)==17){k=25;break}if((t[w+4>>2]|0)==1?(t[o>>2]=tF(t[u>>2]|0,75680,75176)|0,(t[o>>2]|0)!=0):0){if(t[a>>2]|0){t[c>>2]=GA(t[a>>2]|0,t[o>>2]|0)|0;h=(t[c>>2]|0)!=0;pAi[t[135736>>2]&511](t[a>>2]|0);pAi[t[135736>>2]&511](t[o>>2]|0);if(!h){k=31;break}t[a>>2]=t[c>>2]}else t[a>>2]=t[o>>2];if(!(Jl(t[a>>2]|0,75712,7)|0)){k=36;break}if(!(Jl(t[a>>2]|0,75720,6)|0)){k=36;break}if(!(Jl(t[a>>2]|0,75728,4)|0)){k=36;break}}t[u>>2]=t[(t[u>>2]|0)+20>>2]}if((k|0)==25){t[l>>2]=w;t[n>>2]=Yl(t[(t[l>>2]|0)+64>>2]|0)|0;b=t[n>>2]|0;s=r;return b|0}else if((k|0)==31){t[n>>2]=0;b=t[n>>2]|0;s=r;return b|0}else if((k|0)==36){t[n>>2]=t[a>>2];b=t[n>>2]|0;s=r;return b|0}else if((k|0)==38){if((t[f>>2]|0)!=0?(t[(t[f>>2]|0)+72>>2]|0)!=0:0)if(!(t[a>>2]|0)){t[n>>2]=Yl(t[(t[f>>2]|0)+72>>2]|0)|0;b=t[n>>2]|0;s=r;return b|0}else{t[c>>2]=GA(t[a>>2]|0,t[(t[f>>2]|0)+72>>2]|0)|0;pAi[t[135736>>2]&511](t[a>>2]|0);t[n>>2]=t[c>>2];b=t[n>>2]|0;s=r;return b|0}t[n>>2]=t[a>>2];b=t[n>>2]|0;s=r;return b|0}return 0}function cF(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0;r=s;s=s+16|0;n=r+12|0;f=r+8|0;u=r+4|0;a=r;t[f>>2]=e;t[u>>2]=i;t[a>>2]=dF(t[f>>2]|0,t[u>>2]|0)|0;if(!(t[a>>2]|0)){t[n>>2]=0;o=t[n>>2]|0;s=r;return o|0}else{t[n>>2]=YF(t[a>>2]|0)|0;o=t[n>>2]|0;s=r;return o|0}return 0}function lF(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0;r=s;s=s+32|0;n=r+28|0;f=r+24|0;u=r+20|0;a=r+16|0;o=r+12|0;c=r+8|0;l=r+4|0;b=r;t[f>>2]=e;t[u>>2]=i;if((t[u>>2]|0)==0|(t[f>>2]|0)==0){t[n>>2]=-1;k=t[n>>2]|0;s=r;return k|0}e:do switch(t[(t[u>>2]|0)+4>>2]|0){case 1:case 11:{t[a>>2]=t[u>>2];i:while(1){if(!(t[a>>2]|0))break e;i=t[(t[a>>2]|0)+4>>2]|0;if((i|0)==5)lF(t[f>>2]|0,t[a>>2]|0)|0;else if((i|0)==3|(i|0)==4?(t[(t[a>>2]|0)+40>>2]|0)!=0:0)Is(t[f>>2]|0,t[(t[a>>2]|0)+40>>2]|0)|0;if((t[(t[a>>2]|0)+12>>2]|0)!=0?(t[(t[(t[a>>2]|0)+12>>2]|0)+4>>2]|0)!=17:0){t[a>>2]=t[(t[a>>2]|0)+12>>2];continue}if((t[a>>2]|0)==(t[u>>2]|0))break e;if(t[(t[a>>2]|0)+24>>2]|0){t[a>>2]=t[(t[a>>2]|0)+24>>2];continue}while(1){t[a>>2]=t[(t[a>>2]|0)+20>>2];if(!(t[a>>2]|0))continue i;if((t[a>>2]|0)==(t[u>>2]|0)){h=19;break}w=t[a>>2]|0;if(t[(t[a>>2]|0)+24>>2]|0){h=21;break}if(!w)continue i}if((h|0)==19){h=0;t[a>>2]=0;continue}else if((h|0)==21){h=0;t[a>>2]=t[w+24>>2];continue}}break}case 3:case 4:{Is(t[f>>2]|0,t[(t[u>>2]|0)+40>>2]|0)|0;break}case 9:case 21:case 13:{t[u>>2]=t[(t[u>>2]|0)+12>>2];while(1){if(!(t[u>>2]|0))break e;if(!(((t[(t[u>>2]|0)+4>>2]|0)!=1?(t[(t[u>>2]|0)+4>>2]|0)!=3:0)?(t[(t[u>>2]|0)+4>>2]|0)!=4:0))lF(t[f>>2]|0,t[u>>2]|0)|0;t[u>>2]=t[(t[u>>2]|0)+24>>2]}break}case 18:{Is(t[f>>2]|0,t[(t[u>>2]|0)+8>>2]|0)|0;break}case 2:{t[o>>2]=t[u>>2];t[c>>2]=t[(t[o>>2]|0)+12>>2];while(1){if(!(t[c>>2]|0))break e;i=t[f>>2]|0;e=t[c>>2]|0;if((t[(t[c>>2]|0)+4>>2]|0)==3)Is(i,t[e+40>>2]|0)|0;else lF(i,e)|0;t[c>>2]=t[(t[c>>2]|0)+24>>2]}break}case 7:case 8:{Is(t[f>>2]|0,t[(t[u>>2]|0)+40>>2]|0)|0;break}case 5:{t[l>>2]=h_(t[(t[u>>2]|0)+32>>2]|0,t[(t[u>>2]|0)+8>>2]|0)|0;if(!(t[l>>2]|0)){t[n>>2]=-1;k=t[n>>2]|0;s=r;return k|0}t[b>>2]=t[(t[l>>2]|0)+12>>2];while(1){if(!(t[b>>2]|0))break e;lF(t[f>>2]|0,t[b>>2]|0)|0;t[b>>2]=t[(t[b>>2]|0)+24>>2]}break}default:{}}while(0);t[n>>2]=0;k=t[n>>2]|0;s=r;return k|0}function sF(e){e=e|0;var i=0,r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0;i=s;s=s+48|0;r=i+36|0;n=i+32|0;f=i+28|0;u=i+24|0;a=i+20|0;o=i+16|0;c=i+12|0;l=i+8|0;b=i+4|0;k=i;t[n>>2]=e;e:do if(!(t[n>>2]|0))t[r>>2]=0;else do switch(t[(t[n>>2]|0)+4>>2]|0){case 13:case 21:case 9:{t[l>>2]=ds()|0;if(!(t[l>>2]|0)){t[r>>2]=0;break e}else{lF(t[l>>2]|0,t[n>>2]|0)|0;t[b>>2]=ms(t[l>>2]|0)|0;Ss(t[l>>2]|0);t[r>>2]=t[b>>2];break e}break}case 2:{t[r>>2]=YF(t[n>>2]|0)|0;break e;break}case 5:{t[a>>2]=h_(t[(t[n>>2]|0)+32>>2]|0,t[(t[n>>2]|0)+8>>2]|0)|0;if(!(t[a>>2]|0)){t[r>>2]=0;break e}t[o>>2]=ds()|0;if(!(t[o>>2]|0)){t[r>>2]=0;break e}else{lF(t[o>>2]|0,t[n>>2]|0)|0;t[c>>2]=ms(t[o>>2]|0)|0;Ss(t[o>>2]|0);t[r>>2]=t[c>>2];break e}break}case 1:case 11:{t[f>>2]=vs(64)|0;if(!(t[f>>2]|0)){t[r>>2]=0;break e}else{lF(t[f>>2]|0,t[n>>2]|0)|0;t[u>>2]=ms(t[f>>2]|0)|0;Ss(t[f>>2]|0);t[r>>2]=t[u>>2];break e}break}case 15:{t[r>>2]=0;break e;break}case 3:case 4:{if(t[(t[n>>2]|0)+40>>2]|0){t[r>>2]=Yl(t[(t[n>>2]|0)+40>>2]|0)|0;break e}else{t[r>>2]=0;break e}break}case 18:{t[k>>2]=Yl(t[(t[n>>2]|0)+8>>2]|0)|0;t[r>>2]=t[k>>2];break e;break}case 17:{t[r>>2]=0;break e;break}case 20:case 19:case 14:case 12:case 10:case 6:{t[r>>2]=0;break e;break}case 16:{t[r>>2]=0;break e;break}case 7:case 8:{if(t[(t[n>>2]|0)+40>>2]|0){t[r>>2]=Yl(t[(t[n>>2]|0)+40>>2]|0)|0;break e}else{t[r>>2]=0;break e}break}default:{t[r>>2]=0;break e}}while(0);while(0);s=i;return t[r>>2]|0}function bF(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,l=0;n=s;s=s+32|0;f=n+20|0;u=n+16|0;a=n+12|0;o=n+8|0;c=n+4|0;l=n;t[f>>2]=e;t[u>>2]=i;t[a>>2]=r;if((t[f>>2]|0)==0|(t[a>>2]|0)<=0){s=n;return}switch(t[(t[f>>2]|0)+4>>2]|0){case 8:case 7:case 6:case 5:case 4:case 3:case 12:{if(!(t[u>>2]|0)){s=n;return}do if((t[(t[f>>2]|0)+40>>2]|0)!=((t[f>>2]|0)+44|0)){if(((t[(t[f>>2]|0)+32>>2]|0)!=0?(t[(t[(t[f>>2]|0)+32>>2]|0)+80>>2]|0)!=0:0)?(wz(t[(t[(t[f>>2]|0)+32>>2]|0)+80>>2]|0,t[(t[f>>2]|0)+40>>2]|0)|0)!=0:0)break;r=fs(t[(t[f>>2]|0)+40>>2]|0,t[u>>2]|0,t[a>>2]|0)|0;t[(t[f>>2]|0)+40>>2]=r;s=n;return}while(0);r=ts(t[(t[f>>2]|0)+40>>2]|0,t[u>>2]|0,t[a>>2]|0)|0;t[(t[f>>2]|0)+40>>2]=r;t[(t[f>>2]|0)+44>>2]=0;t[(t[f>>2]|0)+48>>2]=0;s=n;return}case 1:case 11:{t[o>>2]=t[(t[f>>2]|0)+16>>2];t[c>>2]=Oy(t[u>>2]|0,t[a>>2]|0)|0;if(!(t[c>>2]|0)){s=n;return}t[l>>2]=Hy(t[f>>2]|0,t[c>>2]|0)|0;if(!((t[o>>2]|0)!=0?(t[l>>2]|0)==(t[c>>2]|0):0)){s=n;return}if((t[(t[o>>2]|0)+24>>2]|0)!=(t[c>>2]|0)){s=n;return}kF(t[o>>2]|0,t[c>>2]|0)|0;s=n;return}default:{s=n;return}}}function kF(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0;r=s;s=s+16|0;n=r+8|0;f=r+4|0;u=r;t[f>>2]=e;t[u>>2]=i;i=t[u>>2]|0;do if(t[f>>2]|0){e=t[f>>2]|0;if(!i){t[n>>2]=e;break}if((t[e+4>>2]|0)!=3){t[n>>2]=t[f>>2];break}if((t[(t[u>>2]|0)+4>>2]|0)!=3){t[n>>2]=t[f>>2];break}e=t[f>>2]|0;if((t[(t[u>>2]|0)+8>>2]|0)!=(t[(t[f>>2]|0)+8>>2]|0)){t[n>>2]=e;break}else{Dy(e,t[(t[u>>2]|0)+40>>2]|0);iy(t[u>>2]|0);ry(t[u>>2]|0);t[n>>2]=t[f>>2];break}}else t[n>>2]=i;while(0);s=r;return t[n>>2]|0}function hF(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0;r=s;s=s+32|0;n=r+28|0;f=r+20|0;u=r+16|0;a=r+12|0;o=r+8|0;c=r+4|0;l=r;t[r+24>>2]=e;t[f>>2]=i;t[a>>2]=0;t[o>>2]=0;t[c>>2]=10;if((t[f>>2]|0)!=0?(t[(t[f>>2]|0)+4>>2]|0)!=18:0){e:while(1){if(!(t[f>>2]|0)){b=24;break}i:do if((t[(t[f>>2]|0)+4>>2]|0)==1){t[u>>2]=t[(t[f>>2]|0)+48>>2];while(1){if(!(t[u>>2]|0))break i;if(!(t[a>>2]|0)){t[a>>2]=gAi[t[135744>>2]&511]((t[c>>2]|0)+1<<2)|0;if(!(t[a>>2]|0)){b=10;break e}t[(t[a>>2]|0)+(t[o>>2]<<2)>>2]=0}t[l>>2]=0;while(1){if((t[l>>2]|0)>=(t[o>>2]|0))break;if((t[(t[u>>2]|0)+12>>2]|0)==(t[(t[(t[a>>2]|0)+(t[l>>2]<<2)>>2]|0)+12>>2]|0))break;if(Xl(t[(t[u>>2]|0)+12>>2]|0,t[(t[(t[a>>2]|0)+(t[l>>2]<<2)>>2]|0)+12>>2]|0)|0)break;t[l>>2]=(t[l>>2]|0)+1}if((t[l>>2]|0)>=(t[o>>2]|0)){if((t[o>>2]|0)>=(t[c>>2]|0)?(t[c>>2]=t[c>>2]<<1,t[a>>2]=MAi[t[135760>>2]&511](t[a>>2]|0,(t[c>>2]|0)+1<<2)|0,(t[a>>2]|0)==0):0){b=20;break e}i=t[u>>2]|0;e=t[o>>2]|0;t[o>>2]=e+1;t[(t[a>>2]|0)+(e<<2)>>2]=i;t[(t[a>>2]|0)+(t[o>>2]<<2)>>2]=0}t[u>>2]=t[t[u>>2]>>2]}}while(0);t[f>>2]=t[(t[f>>2]|0)+20>>2]}if((b|0)==10){LF(75736);t[n>>2]=0;k=t[n>>2]|0;s=r;return k|0}else if((b|0)==20){LF(75736);t[n>>2]=0;k=t[n>>2]|0;s=r;return k|0}else if((b|0)==24){t[n>>2]=t[a>>2];k=t[n>>2]|0;s=r;return k|0}}t[n>>2]=0;k=t[n>>2]|0;s=r;return k|0}function wF(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0;n=s;s=s+32|0;f=n+20|0;u=n+16|0;a=n+12|0;o=n+8|0;c=n+4|0;l=n;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;t[l>>2]=t[a>>2];if((t[a>>2]|0)!=0?(t[(t[a>>2]|0)+4>>2]|0)!=18:0){if((t[o>>2]|0)!=0?(Xl(t[o>>2]|0,75168)|0)!=0:0){if((t[u>>2]|0)==0?(t[(t[a>>2]|0)+4>>2]|0)==1:0){t[c>>2]=gAi[t[135744>>2]&511](24)|0;if(!(t[c>>2]|0)){LF(75760);t[f>>2]=0;b=t[f>>2]|0;s=n;return b|0}else{r=t[c>>2]|0;t[r+0>>2]=0;t[r+4>>2]=0;t[r+8>>2]=0;t[r+12>>2]=0;t[r+16>>2]=0;t[r+20>>2]=0;t[(t[c>>2]|0)+4>>2]=18;r=Yl(75176)|0;t[(t[c>>2]|0)+8>>2]=r;r=Yl(75168)|0;t[(t[c>>2]|0)+12>>2]=r;t[t[c>>2]>>2]=t[(t[a>>2]|0)+48>>2];t[(t[a>>2]|0)+48>>2]=t[c>>2];t[f>>2]=t[c>>2];b=t[f>>2]|0;s=n;return b|0}}if((t[u>>2]|0)==0?(t[u>>2]=t[(t[a>>2]|0)+32>>2],(t[u>>2]|0)==0):0){t[f>>2]=0;b=t[f>>2]|0;s=n;return b|0}r=t[u>>2]|0;if(!(t[(t[u>>2]|0)+52>>2]|0)){t[f>>2]=VF(r)|0;b=t[f>>2]|0;s=n;return b|0}else{t[f>>2]=t[r+52>>2];b=t[f>>2]|0;s=n;return b|0}}e:while(1){if(!(t[a>>2]|0)){k=43;break}if((t[(t[a>>2]|0)+4>>2]|0)==5){k=21;break}if((t[(t[a>>2]|0)+4>>2]|0)==6){k=21;break}if((t[(t[a>>2]|0)+4>>2]|0)==17){k=21;break}if((t[(t[a>>2]|0)+4>>2]|0)==1){t[c>>2]=t[(t[a>>2]|0)+48>>2];while(1){if(!(t[c>>2]|0))break;if(((t[o>>2]|0)==0?(t[(t[c>>2]|0)+12>>2]|0)==0:0)?(t[(t[c>>2]|0)+8>>2]|0)!=0:0){k=27;break e}if((((t[o>>2]|0)!=0?(t[(t[c>>2]|0)+12>>2]|0)!=0:0)?(t[(t[c>>2]|0)+8>>2]|0)!=0:0)?(Xl(t[(t[c>>2]|0)+12>>2]|0,t[o>>2]|0)|0)!=0:0){k=31;break e}t[c>>2]=t[t[c>>2]>>2]}if((t[l>>2]|0)!=(t[a>>2]|0)?(t[c>>2]=t[(t[a>>2]|0)+36>>2],(t[c>>2]|0)!=0):0){if(((t[o>>2]|0)==0?(t[(t[c>>2]|0)+12>>2]|0)==0:0)?(t[(t[c>>2]|0)+8>>2]|0)!=0:0){k=37;break}if((((t[o>>2]|0)!=0?(t[(t[c>>2]|0)+12>>2]|0)!=0:0)?(t[(t[c>>2]|0)+8>>2]|0)!=0:0)?(Xl(t[(t[c>>2]|0)+12>>2]|0,t[o>>2]|0)|0)!=0:0){k=41;break}}}t[a>>2]=t[(t[a>>2]|0)+20>>2]}if((k|0)==21){t[f>>2]=0;b=t[f>>2]|0;s=n;return b|0}else if((k|0)==27){t[f>>2]=t[c>>2];b=t[f>>2]|0;s=n;return b|0}else if((k|0)==31){t[f>>2]=t[c>>2];b=t[f>>2]|0;s=n;return b|0}else if((k|0)==37){t[f>>2]=t[c>>2];b=t[f>>2]|0;s=n;return b|0}else if((k|0)==41){t[f>>2]=t[c>>2];b=t[f>>2]|0;s=n;return b|0}else if((k|0)==43){t[f>>2]=0;b=t[f>>2]|0;s=n;return b|0}}t[f>>2]=0;b=t[f>>2]|0;s=n;return b|0}function dF(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0;r=s;s=s+32|0;n=r+20|0;f=r+16|0;u=r+12|0;a=r+8|0;o=r+4|0;c=r;t[f>>2]=e;t[u>>2]=i;if((t[f>>2]|0)!=0?!((t[u>>2]|0)==0?1:(t[(t[f>>2]|0)+4>>2]|0)!=1):0){t[a>>2]=t[(t[f>>2]|0)+44>>2];while(1){if(!(t[a>>2]|0))break;i=(Xl(t[(t[a>>2]|0)+8>>2]|0,t[u>>2]|0)|0)!=0;l=t[a>>2]|0;if(i){b=7;break}t[a>>2]=t[l+24>>2]}if((b|0)==7){t[n>>2]=l;k=t[n>>2]|0;s=r;return k|0}if(!(t[18946]|0)){t[n>>2]=0;k=t[n>>2]|0;s=r;return k|0}t[o>>2]=t[(t[f>>2]|0)+32>>2];if((t[o>>2]|0)!=0?(t[(t[o>>2]|0)+44>>2]|0)!=0:0){t[c>>2]=qM(t[(t[o>>2]|0)+44>>2]|0,t[(t[f>>2]|0)+8>>2]|0,t[u>>2]|0)|0;if((t[c>>2]|0)==0?(t[(t[o>>2]|0)+48>>2]|0)!=0:0)t[c>>2]=qM(t[(t[o>>2]|0)+48>>2]|0,t[(t[f>>2]|0)+8>>2]|0,t[u>>2]|0)|0;if((t[c>>2]|0)!=0?(t[(t[c>>2]|0)+48>>2]|0)!=0:0){t[n>>2]=t[c>>2];k=t[n>>2]|0;s=r;return k|0}}t[n>>2]=0;k=t[n>>2]|0;s=r;return k|0}t[n>>2]=0;k=t[n>>2]|0;s=r;return k|0}function vF(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0;r=s;s=s+16|0;n=r+12|0;f=r+8|0;u=r+4|0;a=r;t[f>>2]=e;t[u>>2]=i;t[a>>2]=BF(t[f>>2]|0,t[u>>2]|0,0,t[18946]|0)|0;if(!(t[a>>2]|0)){t[n>>2]=0;o=t[n>>2]|0;s=r;return o|0}else{t[n>>2]=YF(t[a>>2]|0)|0;o=t[n>>2]|0;s=r;return o|0}return 0}function mF(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0;r=s;s=s+16|0;n=r+12|0;f=r+8|0;u=r+4|0;a=r;t[f>>2]=e;t[u>>2]=i;t[a>>2]=BF(t[f>>2]|0,t[u>>2]|0,0,0)|0;if(!(t[a>>2]|0)){t[n>>2]=-1;o=t[n>>2]|0;s=r;return o|0}else{iy(t[a>>2]|0);vy(t[a>>2]|0);t[n>>2]=0;o=t[n>>2]|0;s=r;return o|0}return 0}function _F(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0;n=s;s=s+32|0;f=n+28|0;u=n+24|0;a=n+20|0;o=n+16|0;c=n+12|0;l=n+8|0;b=n+4|0;k=n;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;if(!((t[u>>2]|0)==0|(t[a>>2]|0)==0)?(t[(t[u>>2]|0)+4>>2]|0)==1:0){t[l>>2]=jg(t[a>>2]|0,c)|0;if(t[l>>2]|0){t[k>>2]=ql(t[a>>2]|0,t[c>>2]|0)|0;t[b>>2]=wF(t[(t[u>>2]|0)+32>>2]|0,t[u>>2]|0,t[k>>2]|0)|0;if(t[k>>2]|0)pAi[t[135736>>2]&511](t[k>>2]|0);if(t[b>>2]|0){t[f>>2]=nF(t[u>>2]|0,t[b>>2]|0,t[l>>2]|0,t[o>>2]|0)|0;h=t[f>>2]|0;s=n;return h|0}}t[f>>2]=nF(t[u>>2]|0,0,t[a>>2]|0,t[o>>2]|0)|0;h=t[f>>2]|0;s=n;return h|0}t[f>>2]=0;h=t[f>>2]|0;s=n;return h|0}function pF(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i+4|0;n=i;t[n>>2]=e;do if(t[n>>2]|0)if((t[(t[n>>2]|0)+4>>2]|0)==3){t[r>>2]=1;break}else{t[r>>2]=0;break}else t[r>>2]=0;while(0);s=i;return t[r>>2]|0}function EF(e){e=e|0;var i=0,r=0,n=0,f=0,a=0,o=0;i=s;s=s+16|0;r=i+8|0;n=i+4|0;f=i;t[n>>2]=e;if(!(t[n>>2]|0)){t[r>>2]=0;a=t[r>>2]|0;s=i;return a|0}if((t[(t[n>>2]|0)+4>>2]|0)!=3?(t[(t[n>>2]|0)+4>>2]|0)!=4:0){t[r>>2]=0;a=t[r>>2]|0;s=i;return a|0}if(!(t[(t[n>>2]|0)+40>>2]|0)){t[r>>2]=1;a=t[r>>2]|0;s=i;return a|0}t[f>>2]=t[(t[n>>2]|0)+40>>2];e:while(1){if(!(u[t[f>>2]>>0]|0)){o=16;break}do if((u[t[f>>2]>>0]|0|0)!=32){if(9<=(u[t[f>>2]>>0]|0|0)?(u[t[f>>2]>>0]|0|0)<=10:0)break;if((u[t[f>>2]>>0]|0|0)!=13){o=14;break e}}while(0);t[f>>2]=(t[f>>2]|0)+1}if((o|0)==14){t[r>>2]=0;a=t[r>>2]|0;s=i;return a|0}else if((o|0)==16){t[r>>2]=1;a=t[r>>2]|0;s=i;return a|0}return 0}function SF(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,l=0;n=s;s=s+16|0;f=n+12|0;u=n+8|0;a=n+4|0;o=n;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;if(!(t[u>>2]|0)){t[f>>2]=-1;c=t[f>>2]|0;s=n;return c|0}if((((t[(t[u>>2]|0)+4>>2]|0)!=3?(t[(t[u>>2]|0)+4>>2]|0)!=4:0)?(t[(t[u>>2]|0)+4>>2]|0)!=8:0)?(t[(t[u>>2]|0)+4>>2]|0)!=7:0){
	t[f>>2]=-1;c=t[f>>2]|0;s=n;return c|0}do if((t[(t[u>>2]|0)+40>>2]|0)==((t[u>>2]|0)+44|0))l=12;else{if(((t[(t[u>>2]|0)+32>>2]|0)!=0?(t[(t[(t[u>>2]|0)+32>>2]|0)+80>>2]|0)!=0:0)?(wz(t[(t[(t[u>>2]|0)+32>>2]|0)+80>>2]|0,t[(t[u>>2]|0)+40>>2]|0)|0)!=0:0){l=12;break}r=fs(t[(t[u>>2]|0)+40>>2]|0,t[a>>2]|0,t[o>>2]|0)|0;t[(t[u>>2]|0)+40>>2]=r}while(0);if((l|0)==12){l=ts(t[(t[u>>2]|0)+40>>2]|0,t[a>>2]|0,t[o>>2]|0)|0;t[(t[u>>2]|0)+40>>2]=l}t[(t[u>>2]|0)+44>>2]=0;if(!(t[(t[u>>2]|0)+40>>2]|0)){t[f>>2]=-1;c=t[f>>2]|0;s=n;return c|0}else{t[f>>2]=0;c=t[f>>2]|0;s=n;return c|0}return 0}function gF(){var e=0,i=0,r=0,f=0,u=0;e=s;s=s+16|0;i=e+4|0;r=e;t[r>>2]=gAi[t[135744>>2]&511](20)|0;if(!(t[r>>2]|0)){LF(75808);t[i>>2]=0;f=t[i>>2]|0;s=e;return f|0}t[(t[r>>2]|0)+4>>2]=0;t[(t[r>>2]|0)+8>>2]=t[33950];t[(t[r>>2]|0)+12>>2]=t[33948];u=gAi[t[135752>>2]&511](t[(t[r>>2]|0)+8>>2]|0)|0;t[t[r>>2]>>2]=u;if(!(t[t[r>>2]>>2]|0)){LF(75808);pAi[t[135736>>2]&511](t[r>>2]|0);t[i>>2]=0;f=t[i>>2]|0;s=e;return f|0}else{n[t[t[r>>2]>>2]>>0]=0;t[(t[r>>2]|0)+16>>2]=0;t[i>>2]=t[r>>2];f=t[i>>2]|0;s=e;return f|0}return 0}function yF(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if(!(t[r>>2]|0)){s=i;return}if((t[(t[r>>2]|0)+12>>2]|0)==3?(t[(t[r>>2]|0)+16>>2]|0)!=0:0)pAi[t[135736>>2]&511](t[(t[r>>2]|0)+16>>2]|0);else n=5;if(((n|0)==5?(t[t[r>>2]>>2]|0)!=0:0)?(t[(t[r>>2]|0)+12>>2]|0)!=2:0)pAi[t[135736>>2]&511](t[t[r>>2]>>2]|0);pAi[t[135736>>2]&511](t[r>>2]|0);s=i;return}function FF(e,i){e=e|0;i=i|0;var r=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0;r=s;s=s+32|0;f=r+20|0;u=r+16|0;a=r+12|0;o=r+8|0;c=r+4|0;l=r;t[u>>2]=e;t[a>>2]=i;t[c>>2]=0;if(!(t[u>>2]|0)){t[f>>2]=0;b=t[f>>2]|0;s=r;return b|0}if((t[(t[u>>2]|0)+12>>2]|0)==2){t[f>>2]=0;b=t[f>>2]|0;s=r;return b|0}if((t[a>>2]|0)>>>0<(t[(t[u>>2]|0)+8>>2]|0)>>>0){t[f>>2]=1;b=t[f>>2]|0;s=r;return b|0}i=t[(t[u>>2]|0)+12>>2]|0;e:do if((i|0)==4){if((t[(t[u>>2]|0)+4>>2]|0)>>>0<4096){t[o>>2]=t[a>>2];break}t[o>>2]=t[(t[u>>2]|0)+8>>2]<<1;while(1){if((t[a>>2]|0)>>>0<=(t[o>>2]|0)>>>0)break e;if((t[o>>2]|0)>>>0>2147483647)break;t[o>>2]=t[o>>2]<<1}LF(75824);t[f>>2]=0;b=t[f>>2]|0;s=r;return b|0}else if((i|0)==1)t[o>>2]=(t[a>>2]|0)+10;else if((i|0)==0|(i|0)==3){if(t[(t[u>>2]|0)+8>>2]|0)k=t[(t[u>>2]|0)+8>>2]<<1;else k=(t[a>>2]|0)+10|0;t[o>>2]=k;while(1){if((t[a>>2]|0)>>>0<=(t[o>>2]|0)>>>0)break e;if((t[o>>2]|0)>>>0>2147483647)break;t[o>>2]=t[o>>2]<<1}LF(75824);t[f>>2]=0;b=t[f>>2]|0;s=r;return b|0}else t[o>>2]=(t[a>>2]|0)+10;while(0);do if((t[(t[u>>2]|0)+12>>2]|0)==3?(t[(t[u>>2]|0)+16>>2]|0)!=0:0){t[l>>2]=(t[t[u>>2]>>2]|0)-(t[(t[u>>2]|0)+16>>2]|0);if((t[l>>2]|0)>>>0>(t[o>>2]|0)>>>0){GY(t[(t[u>>2]|0)+16>>2]|0,t[t[u>>2]>>2]|0,t[(t[u>>2]|0)+4>>2]|0)|0;t[t[u>>2]>>2]=t[(t[u>>2]|0)+16>>2];n[(t[t[u>>2]>>2]|0)+(t[(t[u>>2]|0)+4>>2]|0)>>0]=0;a=(t[u>>2]|0)+8|0;t[a>>2]=(t[a>>2]|0)+(t[l>>2]|0);break}t[c>>2]=MAi[t[135760>>2]&511](t[(t[u>>2]|0)+16>>2]|0,(t[l>>2]|0)+(t[o>>2]|0)|0)|0;if(t[c>>2]|0){t[(t[u>>2]|0)+16>>2]=t[c>>2];t[t[u>>2]>>2]=(t[c>>2]|0)+(t[l>>2]|0);break}LF(75824);t[f>>2]=0;b=t[f>>2]|0;s=r;return b|0}else h=32;while(0);do if((h|0)==32){do if(t[t[u>>2]>>2]|0){if(((t[(t[u>>2]|0)+8>>2]|0)-(t[(t[u>>2]|0)+4>>2]|0)|0)>>>0<100){t[c>>2]=MAi[t[135760>>2]&511](t[t[u>>2]>>2]|0,t[o>>2]|0)|0;break}t[c>>2]=gAi[t[135752>>2]&511](t[o>>2]|0)|0;if(t[c>>2]|0){YY(t[c>>2]|0,t[t[u>>2]>>2]|0,t[(t[u>>2]|0)+4>>2]|0)|0;pAi[t[135736>>2]&511](t[t[u>>2]>>2]|0);n[(t[c>>2]|0)+(t[(t[u>>2]|0)+4>>2]|0)>>0]=0}}else t[c>>2]=gAi[t[135752>>2]&511](t[o>>2]|0)|0;while(0);if(t[c>>2]|0){t[t[u>>2]>>2]=t[c>>2];break}LF(75824);t[f>>2]=0;b=t[f>>2]|0;s=r;return b|0}while(0);t[(t[u>>2]|0)+8>>2]=t[o>>2];t[f>>2]=1;b=t[f>>2]|0;s=r;return b|0}function OF(e,i,r){e=e|0;i=i|0;r=r|0;var f=0,u=0,a=0,o=0,c=0,l=0;f=s;s=s+32|0;u=f+16|0;a=f+12|0;o=f+8|0;c=f+4|0;l=f;t[a>>2]=e;t[o>>2]=i;t[c>>2]=r;do if((t[o>>2]|0)==0|(t[a>>2]|0)==0)t[u>>2]=-1;else{if((t[(t[a>>2]|0)+12>>2]|0)==2){t[u>>2]=-1;break}if((t[c>>2]|0)<-1){t[u>>2]=-1;break}if(!(t[c>>2]|0)){t[u>>2]=0;break}if((t[c>>2]|0)<0)t[c>>2]=rs(t[o>>2]|0)|0;if((t[c>>2]|0)<0){t[u>>2]=-1;break}if(!(t[c>>2]|0)){t[u>>2]=0;break}t[l>>2]=(t[(t[a>>2]|0)+4>>2]|0)+(t[c>>2]|0)+2;if((t[l>>2]|0)>>>0>(t[(t[a>>2]|0)+8>>2]|0)>>>0?(FF(t[a>>2]|0,t[l>>2]|0)|0)==0:0){LF(75824);t[u>>2]=2;break}GY((t[t[a>>2]>>2]|0)+(t[(t[a>>2]|0)+4>>2]|0)|0,t[o>>2]|0,t[c>>2]|0)|0;r=(t[a>>2]|0)+4|0;t[r>>2]=(t[r>>2]|0)+(t[c>>2]|0);n[(t[t[a>>2]>>2]|0)+(t[(t[a>>2]|0)+4>>2]|0)>>0]=0;t[u>>2]=0}while(0);s=f;return t[u>>2]|0}function AF(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0;r=s;s=s+16|0;n=r+8|0;f=r+4|0;u=r;t[f>>2]=e;t[u>>2]=i;do if(t[f>>2]|0){if((t[(t[f>>2]|0)+12>>2]|0)==2){t[n>>2]=-1;break}if(!(t[u>>2]|0)){t[n>>2]=-1;break}else{t[n>>2]=OF(t[f>>2]|0,t[u>>2]|0,-1)|0;break}}else t[n>>2]=-1;while(0);s=r;return t[n>>2]|0}function MF(e,i){e=e|0;i=i|0;var r=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0;r=s;s=s+16|0;f=r+12|0;u=r+8|0;a=r+4|0;o=r;t[u>>2]=e;t[a>>2]=i;if(!(t[u>>2]|0)){t[f>>2]=-1;c=t[f>>2]|0;s=r;return c|0}if((t[(t[u>>2]|0)+12>>2]|0)==2){t[f>>2]=-1;c=t[f>>2]|0;s=r;return c|0}if(!(t[a>>2]|0)){t[f>>2]=-1;c=t[f>>2]|0;s=r;return c|0}t[o>>2]=t[a>>2];while(1){l=t[(t[u>>2]|0)+4>>2]|0;if(!(n[t[o>>2]>>0]|0)){b=13;break}if((l+10|0)>>>0>=(t[(t[u>>2]|0)+8>>2]|0)>>>0?(FF(t[u>>2]|0,(t[(t[u>>2]|0)+4>>2]|0)+10|0)|0)==0:0){b=11;break}a=n[t[o>>2]>>0]|0;i=(t[u>>2]|0)+4|0;e=t[i>>2]|0;t[i>>2]=e+1;n[(t[t[u>>2]>>2]|0)+e>>0]=a;t[o>>2]=(t[o>>2]|0)+1}if((b|0)==11){LF(75824);t[f>>2]=2;c=t[f>>2]|0;s=r;return c|0}else if((b|0)==13){n[(t[t[u>>2]>>2]|0)+l>>0]=0;t[f>>2]=0;c=t[f>>2]|0;s=r;return c|0}return 0}function RF(e,i){e=e|0;i=i|0;var r=0,n=0,f=0;r=s;s=s+16|0;n=r+4|0;f=r;t[n>>2]=e;t[f>>2]=i;if(!(t[n>>2]|0)){s=r;return}if((t[(t[n>>2]|0)+12>>2]|0)==2){s=r;return}AF(t[n>>2]|0,t[f>>2]|0)|0;s=r;return}function NF(e,i){e=e|0;i=i|0;var r=0,n=0,f=0;r=s;s=s+16|0;n=r+4|0;f=r;t[n>>2]=e;t[f>>2]=i;if(!(t[n>>2]|0)){s=r;return}if((t[(t[n>>2]|0)+12>>2]|0)==2){s=r;return}MF(t[n>>2]|0,t[f>>2]|0)|0;s=r;return}function TF(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,a=0,o=0;r=s;s=s+16|0;n=r+12|0;f=r+8|0;a=r+4|0;o=r;t[n>>2]=e;t[f>>2]=i;if(!(t[n>>2]|0)){s=r;return}if((t[(t[n>>2]|0)+12>>2]|0)==2){s=r;return}if(!(es(t[f>>2]|0,34)|0)){MF(t[n>>2]|0,75840)|0;AF(t[n>>2]|0,t[f>>2]|0)|0;MF(t[n>>2]|0,75840)|0;s=r;return}i=(es(t[f>>2]|0,39)|0)!=0;e=t[n>>2]|0;if(!i){MF(e,75856)|0;AF(t[n>>2]|0,t[f>>2]|0)|0;MF(t[n>>2]|0,75856)|0;s=r;return}MF(e,75840)|0;e=t[f>>2]|0;t[a>>2]=e;t[o>>2]=e;while(1){if(!(u[t[a>>2]>>0]|0))break;if((u[t[a>>2]>>0]|0|0)!=34){t[a>>2]=(t[a>>2]|0)+1;continue}if((t[o>>2]|0)!=(t[a>>2]|0))OF(t[n>>2]|0,t[o>>2]|0,(t[a>>2]|0)-(t[o>>2]|0)|0)|0;OF(t[n>>2]|0,75848,6)|0;t[a>>2]=(t[a>>2]|0)+1;t[o>>2]=t[a>>2]}if((t[o>>2]|0)!=(t[a>>2]|0))OF(t[n>>2]|0,t[o>>2]|0,(t[a>>2]|0)-(t[o>>2]|0)|0)|0;MF(t[n>>2]|0,75840)|0;s=r;return}function LF(e){e=e|0;var i=0,r=0;i=s;s=s+16|0;r=i;t[r>>2]=e;dp(2,2,0,0,t[r>>2]|0);s=i;return}function DF(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0;n=s;s=s+16|0;f=n+12|0;u=n+8|0;a=n+4|0;o=n;t[f>>2]=e;t[u>>2]=i;t[a>>2]=r;t[o>>2]=0;r=t[f>>2]|0;if((r|0)==1302)t[o>>2]=76032;else if((r|0)==1300)t[o>>2]=75952;else if((r|0)==1301)t[o>>2]=75992;else if((r|0)==1303)t[o>>2]=76072;else t[o>>2]=76096;dp(2,t[f>>2]|0,t[u>>2]|0,t[o>>2]|0,t[a>>2]|0);s=n;return}function CF(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,l=0;n=s;s=s+32|0;f=n+16|0;u=n+12|0;a=n+8|0;o=n+4|0;c=n;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;do if(((t[a>>2]|0)!=0?!((t[o>>2]|0)==0?1:(t[(t[a>>2]|0)+4>>2]|0)!=2):0)?(t[(t[o>>2]|0)+4>>2]|0)==2:0){if((t[u>>2]|0)!=0?(t[(t[u>>2]|0)+4>>2]|0)!=2:0)break;r=t[(t[a>>2]|0)+20>>2]|0;i=t[(t[o>>2]|0)+8>>2]|0;if(!(t[(t[o>>2]|0)+36>>2]|0))t[c>>2]=xy(r,i,0)|0;else t[c>>2]=xy(r,i,t[(t[(t[o>>2]|0)+36>>2]|0)+8>>2]|0)|0;if((t[(t[o>>2]|0)+32>>2]|0)!=(t[(t[a>>2]|0)+32>>2]|0))Ny(t[o>>2]|0,t[(t[a>>2]|0)+32>>2]|0);t[(t[o>>2]|0)+20>>2]=t[(t[a>>2]|0)+20>>2];t[(t[o>>2]|0)+28>>2]=t[u>>2];if(t[u>>2]|0){t[(t[o>>2]|0)+24>>2]=t[(t[u>>2]|0)+24>>2];t[(t[u>>2]|0)+24>>2]=t[o>>2];if(t[(t[o>>2]|0)+24>>2]|0)t[(t[(t[o>>2]|0)+24>>2]|0)+28>>2]=t[o>>2]}else{t[(t[o>>2]|0)+24>>2]=t[a>>2];t[(t[a>>2]|0)+28>>2]=t[o>>2]}if((t[(t[o>>2]|0)+28>>2]|0)==0?(t[(t[o>>2]|0)+20>>2]|0)!=0:0)t[(t[(t[o>>2]|0)+20>>2]|0)+44>>2]=t[o>>2];if((t[c>>2]|0)!=0?(t[(t[c>>2]|0)+4>>2]|0)!=16:0)my(t[c>>2]|0)|0;t[f>>2]=t[o>>2];l=t[f>>2]|0;s=n;return l|0}while(0);t[f>>2]=0;l=t[f>>2]|0;s=n;return l|0}function PF(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;var u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0;u=s;s=s+48|0;a=u+36|0;o=u+32|0;c=u+28|0;l=u+24|0;b=u+20|0;k=u+16|0;h=u+12|0;w=u+8|0;d=u+4|0;v=u;t[o>>2]=e;t[c>>2]=i;t[l>>2]=r;t[b>>2]=n;t[k>>2]=f;t[w>>2]=0;if((t[o>>2]|0)!=0?(t[(t[o>>2]|0)+4>>2]|0)!=1:0){do if((t[k>>2]|0)==1){if((t[(t[o>>2]|0)+32>>2]|0)!=0?(wz(t[(t[(t[o>>2]|0)+32>>2]|0)+80>>2]|0,t[l>>2]|0)|0)!=0:0)break;pAi[t[135736>>2]&511](t[l>>2]|0)}while(0);t[a>>2]=0;m=t[a>>2]|0;s=u;return m|0}t[h>>2]=gAi[t[135744>>2]&511](48)|0;if(!(t[h>>2]|0)){do if((t[k>>2]|0)==1){if(((t[o>>2]|0)!=0?(t[(t[o>>2]|0)+32>>2]|0)!=0:0)?(wz(t[(t[(t[o>>2]|0)+32>>2]|0)+80>>2]|0,t[l>>2]|0)|0)!=0:0)break;pAi[t[135736>>2]&511](t[l>>2]|0)}while(0);LF(75320);t[a>>2]=0;m=t[a>>2]|0;s=u;return m|0}f=(t[h>>2]|0)+0|0;n=f+48|0;do{t[f>>2]=0;f=f+4|0}while((f|0)<(n|0));t[(t[h>>2]|0)+4>>2]=2;t[(t[h>>2]|0)+20>>2]=t[o>>2];if(t[o>>2]|0){t[w>>2]=t[(t[o>>2]|0)+32>>2];t[(t[h>>2]|0)+32>>2]=t[w>>2]}t[(t[h>>2]|0)+36>>2]=t[c>>2];do if(!(t[k>>2]|0)){if((t[w>>2]|0)!=0?(t[(t[w>>2]|0)+80>>2]|0)!=0:0){c=kz(t[(t[w>>2]|0)+80>>2]|0,t[l>>2]|0,-1)|0;t[(t[h>>2]|0)+8>>2]=c;break}c=Yl(t[l>>2]|0)|0;t[(t[h>>2]|0)+8>>2]=c}else t[(t[h>>2]|0)+8>>2]=t[l>>2];while(0);e:do if(t[b>>2]|0){if((ls(t[b>>2]|0)|0)==0?(DF(1303,t[w>>2]|0,0),(t[w>>2]|0)!=0):0){l=Yl(75792)|0;t[(t[w>>2]|0)+60>>2]=l}l=ay(t[w>>2]|0,t[b>>2]|0)|0;t[(t[h>>2]|0)+12>>2]=l;t[(t[h>>2]|0)+16>>2]=0;t[d>>2]=t[(t[h>>2]|0)+12>>2];while(1){if(!(t[d>>2]|0))break e;t[(t[d>>2]|0)+20>>2]=t[h>>2];if(!(t[(t[d>>2]|0)+24>>2]|0))t[(t[h>>2]|0)+16>>2]=t[d>>2];t[d>>2]=t[(t[d>>2]|0)+24>>2]}}while(0);do if(t[o>>2]|0){if(!(t[(t[o>>2]|0)+44>>2]|0)){t[(t[o>>2]|0)+44>>2]=t[h>>2];break}t[v>>2]=t[(t[o>>2]|0)+44>>2];while(1){if(!(t[(t[v>>2]|0)+24>>2]|0))break;t[v>>2]=t[(t[v>>2]|0)+24>>2]}t[(t[v>>2]|0)+24>>2]=t[h>>2];t[(t[h>>2]|0)+28>>2]=t[v>>2]}while(0);if((t[b>>2]|0)!=0&(t[o>>2]|0)!=0?(VM(t[(t[o>>2]|0)+32>>2]|0,t[o>>2]|0,t[h>>2]|0)|0)==1:0)zM(0,t[(t[o>>2]|0)+32>>2]|0,t[b>>2]|0,t[h>>2]|0)|0;if((t[18774]|0)!=0&(t[33968]|0)!=0)pAi[t[135872>>2]&511](t[h>>2]|0);t[a>>2]=t[h>>2];m=t[a>>2]|0;s=u;return m|0}function BF(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0;f=s;s=s+48|0;u=f+44|0;a=f+40|0;o=f+36|0;c=f+32|0;l=f+28|0;b=f+24|0;k=f+20|0;h=f+16|0;w=f+12|0;d=f+8|0;v=f+4|0;m=f;t[a>>2]=e;t[o>>2]=i;t[c>>2]=r;t[l>>2]=n;if((t[a>>2]|0)!=0?!((t[o>>2]|0)==0?1:(t[(t[a>>2]|0)+4>>2]|0)!=1):0){e:do if(t[(t[a>>2]|0)+44>>2]|0){t[b>>2]=t[(t[a>>2]|0)+44>>2];if(!(t[c>>2]|0)){while(1){if((t[(t[b>>2]|0)+36>>2]|0)==0?(Xl(t[(t[b>>2]|0)+8>>2]|0,t[o>>2]|0)|0)!=0:0)break;t[b>>2]=t[(t[b>>2]|0)+24>>2];if(!(t[b>>2]|0))break e}t[u>>2]=t[b>>2];_=t[u>>2]|0;s=f;return _|0}while(1){if((t[(t[b>>2]|0)+36>>2]|0)!=0?(Xl(t[(t[b>>2]|0)+8>>2]|0,t[o>>2]|0)|0)!=0:0){if((t[(t[(t[b>>2]|0)+36>>2]|0)+8>>2]|0)==(t[c>>2]|0))break;if(Xl(t[(t[(t[b>>2]|0)+36>>2]|0)+8>>2]|0,t[c>>2]|0)|0)break}t[b>>2]=t[(t[b>>2]|0)+24>>2];if(!(t[b>>2]|0))break e}t[u>>2]=t[b>>2];_=t[u>>2]|0;s=f;return _|0}while(0);if(!(t[l>>2]|0)){t[u>>2]=0;_=t[u>>2]|0;s=f;return _|0}if((t[(t[a>>2]|0)+32>>2]|0)!=0?(t[(t[(t[a>>2]|0)+32>>2]|0)+44>>2]|0)!=0:0){t[k>>2]=t[(t[a>>2]|0)+32>>2];t[h>>2]=0;t[d>>2]=0;do if((t[(t[a>>2]|0)+36>>2]|0)!=0?(t[(t[(t[a>>2]|0)+36>>2]|0)+12>>2]|0)!=0:0){t[d>>2]=Yl(t[(t[(t[a>>2]|0)+36>>2]|0)+12>>2]|0)|0;t[d>>2]=us(t[d>>2]|0,75864)|0;t[d>>2]=us(t[d>>2]|0,t[(t[a>>2]|0)+8>>2]|0)|0;if(t[d>>2]|0){t[w>>2]=t[d>>2];break}t[u>>2]=0;_=t[u>>2]|0;s=f;return _|0}else p=25;while(0);if((p|0)==25)t[w>>2]=t[(t[a>>2]|0)+8>>2];if(!(t[c>>2]|0)){t[h>>2]=QM(t[(t[k>>2]|0)+44>>2]|0,t[w>>2]|0,t[o>>2]|0,0)|0;if((t[h>>2]|0)==0?(t[(t[k>>2]|0)+48>>2]|0)!=0:0)t[h>>2]=QM(t[(t[k>>2]|0)+48>>2]|0,t[w>>2]|0,t[o>>2]|0,0)|0}else{t[v>>2]=hF(t[(t[a>>2]|0)+32>>2]|0,t[a>>2]|0)|0;if(!(t[v>>2]|0)){if(t[d>>2]|0)pAi[t[135736>>2]&511](t[d>>2]|0);t[u>>2]=0;_=t[u>>2]|0;s=f;return _|0}t[m>>2]=t[v>>2];while(1){if(!(t[t[m>>2]>>2]|0))break;if(Xl(t[(t[t[m>>2]>>2]|0)+8>>2]|0,t[c>>2]|0)|0){t[h>>2]=QM(t[(t[k>>2]|0)+44>>2]|0,t[w>>2]|0,t[o>>2]|0,t[(t[t[m>>2]>>2]|0)+12>>2]|0)|0;if(t[h>>2]|0)break;if((t[(t[k>>2]|0)+48>>2]|0)!=0?(t[h>>2]=QM(t[(t[k>>2]|0)+48>>2]|0,t[w>>2]|0,t[o>>2]|0,t[(t[t[m>>2]>>2]|0)+12>>2]|0)|0,(t[h>>2]|0)!=0):0)break}t[m>>2]=(t[m>>2]|0)+4}pAi[t[135736>>2]&511](t[v>>2]|0)}if(t[d>>2]|0)pAi[t[135736>>2]&511](t[d>>2]|0);if((t[h>>2]|0)!=0?(t[(t[h>>2]|0)+48>>2]|0)!=0:0){t[u>>2]=t[h>>2];_=t[u>>2]|0;s=f;return _|0}}t[u>>2]=0;_=t[u>>2]|0;s=f;return _|0}t[u>>2]=0;_=t[u>>2]|0;s=f;return _|0}function IF(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0;n=s;s=s+48|0;f=n+36|0;u=n+32|0;a=n+28|0;o=n+24|0;c=n+20|0;l=n+16|0;b=n+12|0;k=n+8|0;h=n+4|0;w=n;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;if(!(t[o>>2]|0)){t[f>>2]=0;d=t[f>>2]|0;s=n;return d|0}if((t[a>>2]|0)!=0?(t[(t[a>>2]|0)+4>>2]|0)!=1:0){t[f>>2]=0;d=t[f>>2]|0;s=n;return d|0}do if(!(t[a>>2]|0)){if(t[u>>2]|0){t[c>>2]=wy(t[u>>2]|0,t[(t[o>>2]|0)+8>>2]|0,0)|0;break}r=t[o>>2]|0;if(t[(t[o>>2]|0)+20>>2]|0){t[c>>2]=wy(t[(t[r+20>>2]|0)+32>>2]|0,t[(t[o>>2]|0)+8>>2]|0,0)|0;break}i=t[o>>2]|0;if(t[r+12>>2]|0){t[c>>2]=wy(t[(t[i+12>>2]|0)+32>>2]|0,t[(t[o>>2]|0)+8>>2]|0,0)|0;break}else{t[c>>2]=wy(0,t[i+8>>2]|0,0)|0;break}}else t[c>>2]=wy(t[(t[a>>2]|0)+32>>2]|0,t[(t[o>>2]|0)+8>>2]|0,0)|0;while(0);if(!(t[c>>2]|0)){t[f>>2]=0;d=t[f>>2]|0;s=n;return d|0}t[(t[c>>2]|0)+20>>2]=t[a>>2];do if((t[a>>2]|0)!=0?(t[(t[o>>2]|0)+36>>2]|0)!=0:0){t[l>>2]=wF(t[(t[a>>2]|0)+32>>2]|0,t[a>>2]|0,t[(t[(t[o>>2]|0)+36>>2]|0)+12>>2]|0)|0;if(t[l>>2]|0)if(Xl(t[(t[l>>2]|0)+8>>2]|0,t[(t[(t[o>>2]|0)+36>>2]|0)+8>>2]|0)|0){t[(t[c>>2]|0)+36>>2]=t[l>>2];break}else{u=GF(t[(t[a>>2]|0)+32>>2]|0,t[a>>2]|0,t[(t[o>>2]|0)+36>>2]|0)|0;t[(t[c>>2]|0)+36>>2]=u;break}t[l>>2]=wF(t[(t[o>>2]|0)+32>>2]|0,t[(t[o>>2]|0)+20>>2]|0,t[(t[(t[o>>2]|0)+36>>2]|0)+12>>2]|0)|0;if(t[l>>2]|0){t[b>>2]=t[a>>2];t[k>>2]=0;while(1){v=t[b>>2]|0;if(!(t[(t[b>>2]|0)+20>>2]|0))break;t[k>>2]=v;t[b>>2]=t[(t[b>>2]|0)+20>>2]}if((v|0)==(t[(t[a>>2]|0)+32>>2]|0))t[b>>2]=t[k>>2];u=Wg(t[b>>2]|0,t[(t[l>>2]|0)+8>>2]|0,t[(t[l>>2]|0)+12>>2]|0)|0;t[(t[c>>2]|0)+36>>2]=u}}else t[(t[c>>2]|0)+36>>2]=0;while(0);e:do if(t[(t[o>>2]|0)+12>>2]|0){l=xF(t[(t[o>>2]|0)+12>>2]|0,t[(t[c>>2]|0)+32>>2]|0,t[c>>2]|0)|0;t[(t[c>>2]|0)+12>>2]=l;t[(t[c>>2]|0)+16>>2]=0;t[h>>2]=t[(t[c>>2]|0)+12>>2];while(1){if(!(t[h>>2]|0))break e;if(!(t[(t[h>>2]|0)+24>>2]|0))t[(t[c>>2]|0)+16>>2]=t[h>>2];t[h>>2]=t[(t[h>>2]|0)+24>>2]}}while(0);if(((((((t[a>>2]|0)!=0&(t[o>>2]|0)!=0?(t[(t[a>>2]|0)+32>>2]|0)!=0:0)?(t[(t[o>>2]|0)+32>>2]|0)!=0:0)?(t[(t[(t[o>>2]|0)+32>>2]|0)+64>>2]|0)!=0:0)?(t[(t[o>>2]|0)+20>>2]|0)!=0:0)?(VM(t[(t[o>>2]|0)+32>>2]|0,t[(t[o>>2]|0)+20>>2]|0,t[o>>2]|0)|0)!=0:0)?(t[w>>2]=sy(t[(t[o>>2]|0)+32>>2]|0,t[(t[o>>2]|0)+12>>2]|0,1)|0,(t[w>>2]|0)!=0):0){zM(0,t[(t[a>>2]|0)+32>>2]|0,t[w>>2]|0,t[c>>2]|0)|0;pAi[t[135736>>2]&511](t[w>>2]|0)}t[f>>2]=t[c>>2];d=t[f>>2]|0;s=n;return d|0}function HF(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0;u=s;s=s+48|0;a=u+36|0;o=u+32|0;c=u+28|0;l=u+24|0;b=u+20|0;k=u+16|0;h=u+12|0;w=u+8|0;d=u+4|0;v=u;t[o>>2]=e;t[c>>2]=i;t[l>>2]=r;t[b>>2]=n;if(!(t[o>>2]|0)){t[a>>2]=0;m=t[a>>2]|0;s=u;return m|0}switch(t[(t[o>>2]|0)+4>>2]|0){case 18:{t[a>>2]=Vy(t[o>>2]|0)|0;m=t[a>>2]|0;s=u;return m|0}case 10:case 12:case 14:case 15:case 16:case 17:{t[a>>2]=0;m=t[a>>2]|0;s=u;return m|0}case 2:{t[a>>2]=IF(t[c>>2]|0,t[l>>2]|0,t[o>>2]|0)|0;m=t[a>>2]|0;s=u;return m|0}case 9:case 13:case 21:{t[a>>2]=Jy(t[o>>2]|0,t[b>>2]|0)|0;m=t[a>>2]|0;s=u;return m|0}default:{t[k>>2]=gAi[t[135744>>2]&511](60)|0;if(!(t[k>>2]|0)){LF(75936);t[a>>2]=0;m=t[a>>2]|0;s=u;return m|0}n=(t[k>>2]|0)+0|0;r=n+60|0;do{t[n>>2]=0;n=n+4|0}while((n|0)<(r|0));t[(t[k>>2]|0)+4>>2]=t[(t[o>>2]|0)+4>>2];t[(t[k>>2]|0)+32>>2]=t[c>>2];t[(t[k>>2]|0)+20>>2]=t[l>>2];do if((t[(t[o>>2]|0)+8>>2]|0)!=75104){if((t[(t[o>>2]|0)+8>>2]|0)==75112){t[(t[k>>2]|0)+8>>2]=75112;break}if((t[(t[o>>2]|0)+8>>2]|0)==75128){t[(t[k>>2]|0)+8>>2]=75128;break}if(t[(t[o>>2]|0)+8>>2]|0){if((t[c>>2]|0)!=0?(t[(t[c>>2]|0)+80>>2]|0)!=0:0){n=kz(t[(t[c>>2]|0)+80>>2]|0,t[(t[o>>2]|0)+8>>2]|0,-1)|0;t[(t[k>>2]|0)+8>>2]=n;break}n=Yl(t[(t[o>>2]|0)+8>>2]|0)|0;t[(t[k>>2]|0)+8>>2]=n}}else t[(t[k>>2]|0)+8>>2]=75104;while(0);if(((((t[(t[o>>2]|0)+4>>2]|0)!=1?(t[(t[o>>2]|0)+40>>2]|0)!=0:0)?(t[(t[o>>2]|0)+4>>2]|0)!=5:0)?(t[(t[o>>2]|0)+4>>2]|0)!=20:0)?(t[(t[o>>2]|0)+4>>2]|0)!=19:0){n=Yl(t[(t[o>>2]|0)+40>>2]|0)|0;t[(t[k>>2]|0)+40>>2]=n}else _=27;if((_|0)==27?(t[(t[o>>2]|0)+4>>2]|0)==1:0)f[(t[k>>2]|0)+56>>1]=f[(t[o>>2]|0)+56>>1]|0;if(t[l>>2]|0){if((t[18774]|0)!=0&(t[33968]|0)!=0)pAi[t[135872>>2]&511](t[k>>2]|0);t[h>>2]=Hy(t[l>>2]|0,t[k>>2]|0)|0;if((t[h>>2]|0)!=(t[k>>2]|0)){t[a>>2]=t[h>>2];m=t[a>>2]|0;s=u;return m|0}}do if(t[b>>2]|0){if(!((t[(t[o>>2]|0)+4>>2]|0)!=1?(t[(t[o>>2]|0)+4>>2]|0)!=19:0))_=37;if((_|0)==37?(t[(t[o>>2]|0)+48>>2]|0)!=0:0){h=Vy(t[(t[o>>2]|0)+48>>2]|0)|0;t[(t[k>>2]|0)+48>>2]=h}do if(t[(t[o>>2]|0)+36>>2]|0){t[w>>2]=wF(t[c>>2]|0,t[k>>2]|0,t[(t[(t[o>>2]|0)+36>>2]|0)+12>>2]|0)|0;if(t[w>>2]|0){t[(t[k>>2]|0)+36>>2]=t[w>>2];break}t[w>>2]=wF(t[(t[o>>2]|0)+32>>2]|0,t[o>>2]|0,t[(t[(t[o>>2]|0)+36>>2]|0)+12>>2]|0)|0;if(!(t[w>>2]|0)){h=GF(t[c>>2]|0,t[k>>2]|0,t[(t[o>>2]|0)+36>>2]|0)|0;t[(t[k>>2]|0)+36>>2]=h;break}t[d>>2]=t[k>>2];while(1){p=t[d>>2]|0;if(!(t[(t[d>>2]|0)+20>>2]|0))break;t[d>>2]=t[p+20>>2]}h=Wg(p,t[(t[w>>2]|0)+8>>2]|0,t[(t[w>>2]|0)+12>>2]|0)|0;t[(t[k>>2]|0)+36>>2]=h}while(0);if(!((t[(t[o>>2]|0)+4>>2]|0)!=1?(t[(t[o>>2]|0)+4>>2]|0)!=19:0))_=50;if((_|0)==50?(t[(t[o>>2]|0)+44>>2]|0)!=0:0){h=Yy(t[k>>2]|0,t[(t[o>>2]|0)+44>>2]|0)|0;t[(t[k>>2]|0)+44>>2]=h}if((t[(t[o>>2]|0)+4>>2]|0)==5){if((t[c>>2]|0)!=0?(t[(t[o>>2]|0)+32>>2]|0)==(t[c>>2]|0):0)t[(t[k>>2]|0)+12>>2]=t[(t[o>>2]|0)+12>>2];else{h=h_(t[c>>2]|0,t[(t[k>>2]|0)+8>>2]|0)|0;t[(t[k>>2]|0)+12>>2]=h}t[(t[k>>2]|0)+16>>2]=t[(t[k>>2]|0)+12>>2];break}if(((t[b>>2]|0)!=2?(t[(t[o>>2]|0)+12>>2]|0)!=0:0)?(h=xF(t[(t[o>>2]|0)+12>>2]|0,t[c>>2]|0,t[k>>2]|0)|0,t[(t[k>>2]|0)+12>>2]=h,(t[k>>2]|0)!=0):0){t[v>>2]=t[(t[k>>2]|0)+12>>2];if(!(t[v>>2]|0)){t[(t[k>>2]|0)+16>>2]=0;break}while(1){h=(t[(t[v>>2]|0)+24>>2]|0)!=0;t[(t[v>>2]|0)+20>>2]=t[k>>2];E=t[v>>2]|0;if(!h)break;t[v>>2]=t[E+24>>2]}t[(t[k>>2]|0)+16>>2]=E}}while(0);if((t[l>>2]|0)==0&(t[18774]|0)!=0&(t[33968]|0)!=0)pAi[t[135872>>2]&511](t[k>>2]|0);t[a>>2]=t[k>>2];m=t[a>>2]|0;s=u;return m|0}}return 0}function xF(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0;n=s;s=s+32|0;f=n+24|0;u=n+20|0;a=n+16|0;o=n+12|0;c=n+8|0;l=n+4|0;b=n;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;t[c>>2]=0;t[l>>2]=0;e:while(1){if(!(t[u>>2]|0)){k=19;break}do if((t[(t[u>>2]|0)+4>>2]|0)==14){if(!(t[a>>2]|0)){t[u>>2]=t[(t[u>>2]|0)+24>>2];continue e}if(t[(t[a>>2]|0)+44>>2]|0){t[b>>2]=t[(t[a>>2]|0)+44>>2];Hy(t[o>>2]|0,t[b>>2]|0)|0;break}t[b>>2]=Zy(t[u>>2]|0)|0;if(!(t[b>>2]|0)){k=8;break e}t[(t[b>>2]|0)+32>>2]=t[a>>2];t[(t[b>>2]|0)+20>>2]=t[o>>2];t[(t[a>>2]|0)+44>>2]=t[b>>2];Hy(t[o>>2]|0,t[b>>2]|0)|0}else t[b>>2]=HF(t[u>>2]|0,t[a>>2]|0,t[o>>2]|0,1)|0;while(0);if(!(t[b>>2]|0)){k=13;break}if(t[c>>2]|0){if((t[l>>2]|0)!=(t[b>>2]|0)){t[(t[l>>2]|0)+24>>2]=t[b>>2];t[(t[b>>2]|0)+28>>2]=t[l>>2];t[l>>2]=t[b>>2]}}else{t[(t[b>>2]|0)+28>>2]=0;r=t[b>>2]|0;t[l>>2]=r;t[c>>2]=r}t[u>>2]=t[(t[u>>2]|0)+24>>2]}if((k|0)==8){t[f>>2]=0;h=t[f>>2]|0;s=n;return h|0}else if((k|0)==13){t[f>>2]=0;h=t[f>>2]|0;s=n;return h|0}else if((k|0)==19){t[f>>2]=t[c>>2];h=t[f>>2]|0;s=n;return h|0}return 0}function UF(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0;r=s;s=s+16|0;n=r+12|0;f=r+8|0;u=r+4|0;a=r;t[f>>2]=e;t[u>>2]=i;if((t[f>>2]|0)!=0?(t[(t[f>>2]|0)+48>>2]|0)!=0:0){t[a>>2]=t[(t[f>>2]|0)+48>>2];t[n>>2]=rO(t[a>>2]|0,t[u>>2]|0)|0;o=t[n>>2]|0;s=r;return o|0}t[n>>2]=0;o=t[n>>2]|0;s=r;return o|0}function zF(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0;r=s;s=s+16|0;n=r+12|0;f=r+8|0;u=r+4|0;a=r;t[f>>2]=e;t[u>>2]=i;if((t[f>>2]|0)!=0?(t[(t[f>>2]|0)+60>>2]|0)!=0:0){t[a>>2]=t[(t[f>>2]|0)+60>>2];t[n>>2]=rO(t[a>>2]|0,t[u>>2]|0)|0;o=t[n>>2]|0;s=r;return o|0}t[n>>2]=0;o=t[n>>2]|0;s=r;return o|0}function jF(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,o=0,c=0,l=0;r=s;s=s+16|0;n=r+12|0;f=r+8|0;u=r+4|0;o=r;t[f>>2]=e;t[u>>2]=i;t[o>>2]=-1;if((t[u>>2]|0)>=5){t[n>>2]=-1;c=t[n>>2]|0;s=r;return c|0}if(!(t[f>>2]|0)){t[n>>2]=t[o>>2];c=t[n>>2]|0;s=r;return c|0}e:do if((((t[(t[f>>2]|0)+4>>2]|0)!=1?(t[(t[f>>2]|0)+4>>2]|0)!=3:0)?(t[(t[f>>2]|0)+4>>2]|0)!=8:0)?(t[(t[f>>2]|0)+4>>2]|0)!=7:0){do if(t[(t[f>>2]|0)+28>>2]|0){if((((t[(t[(t[f>>2]|0)+28>>2]|0)+4>>2]|0)!=1?(t[(t[(t[f>>2]|0)+28>>2]|0)+4>>2]|0)!=3:0)?(t[(t[(t[f>>2]|0)+28>>2]|0)+4>>2]|0)!=8:0)?(t[(t[(t[f>>2]|0)+28>>2]|0)+4>>2]|0)!=7:0)break;t[o>>2]=jF(t[(t[f>>2]|0)+28>>2]|0,(t[u>>2]|0)+1|0)|0;break e}while(0);if((t[(t[f>>2]|0)+20>>2]|0)!=0?(t[(t[(t[f>>2]|0)+20>>2]|0)+4>>2]|0)==1:0)t[o>>2]=jF(t[(t[f>>2]|0)+20>>2]|0,(t[u>>2]|0)+1|0)|0}else l=9;while(0);if((l|0)==9){do if((a[(t[f>>2]|0)+56>>1]|0|0)==65535){if((t[(t[f>>2]|0)+4>>2]|0)==3?(t[(t[f>>2]|0)+52>>2]|0)!=0:0){t[o>>2]=t[(t[f>>2]|0)+52>>2];break}if((t[(t[f>>2]|0)+4>>2]|0)==1?(t[(t[f>>2]|0)+12>>2]|0)!=0:0){t[o>>2]=jF(t[(t[f>>2]|0)+12>>2]|0,(t[u>>2]|0)+1|0)|0;break}l=t[f>>2]|0;if(t[(t[f>>2]|0)+24>>2]|0){t[o>>2]=jF(t[l+24>>2]|0,(t[u>>2]|0)+1|0)|0;break}if(t[l+28>>2]|0)t[o>>2]=jF(t[(t[f>>2]|0)+28>>2]|0,(t[u>>2]|0)+1|0)|0}while(0);if((t[o>>2]|0)==-1|(t[o>>2]|0)==65535)t[o>>2]=a[(t[f>>2]|0)+56>>1]}t[n>>2]=t[o>>2];c=t[n>>2]|0;s=r;return c|0}function VF(e){e=e|0;var i=0,r=0,n=0,f=0,u=0;i=s;s=s+16|0;r=i+8|0;n=i+4|0;f=i;t[n>>2]=e;if(!(t[n>>2]|0)){t[r>>2]=0;u=t[r>>2]|0;s=i;return u|0}if(t[(t[n>>2]|0)+52>>2]|0){t[r>>2]=t[(t[n>>2]|0)+52>>2];u=t[r>>2]|0;s=i;return u|0}t[f>>2]=gAi[t[135744>>2]&511](24)|0;if(!(t[f>>2]|0)){LF(75904);t[r>>2]=0;u=t[r>>2]|0;s=i;return u|0}else{e=t[f>>2]|0;t[e+0>>2]=0;t[e+4>>2]=0;t[e+8>>2]=0;t[e+12>>2]=0;t[e+16>>2]=0;t[e+20>>2]=0;t[(t[f>>2]|0)+4>>2]=18;e=Yl(75176)|0;t[(t[f>>2]|0)+8>>2]=e;e=Yl(75168)|0;t[(t[f>>2]|0)+12>>2]=e;t[(t[n>>2]|0)+52>>2]=t[f>>2];t[r>>2]=t[f>>2];u=t[r>>2]|0;s=i;return u|0}return 0}function qF(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0;f=s;s=s+32|0;u=f+20|0;a=f+12|0;o=f+8|0;c=f+4|0;l=f;t[f+16>>2]=e;t[a>>2]=i;t[o>>2]=r;t[c>>2]=n;e:while(1){if(t[a>>2]|0)b=(t[a>>2]|0)!=(t[o>>2]|0);else b=0;k=t[a>>2]|0;if(!b){h=19;break}if((t[k+4>>2]|0)==5){h=8;break}if((t[(t[a>>2]|0)+4>>2]|0)==6){h=8;break}if((t[(t[a>>2]|0)+4>>2]|0)==17){h=8;break}i:do if((t[(t[a>>2]|0)+4>>2]|0)==1){t[l>>2]=t[(t[a>>2]|0)+48>>2];while(1){if(!(t[l>>2]|0))break i;if((t[c>>2]|0)==0?(t[(t[l>>2]|0)+12>>2]|0)==0:0){h=13;break e}if(((t[c>>2]|0)!=0?(t[(t[l>>2]|0)+12>>2]|0)!=0:0)?(Xl(t[(t[l>>2]|0)+12>>2]|0,t[c>>2]|0)|0)!=0:0){h=16;break e}t[l>>2]=t[t[l>>2]>>2]}}while(0);t[a>>2]=t[(t[a>>2]|0)+20>>2]}if((h|0)==8){t[u>>2]=-1;w=t[u>>2]|0;s=f;return w|0}else if((h|0)==13){t[u>>2]=0;w=t[u>>2]|0;s=f;return w|0}else if((h|0)==16){t[u>>2]=0;w=t[u>>2]|0;s=f;return w|0}else if((h|0)==19)if((k|0)!=(t[o>>2]|0)){t[u>>2]=-1;w=t[u>>2]|0;s=f;return w|0}else{t[u>>2]=1;w=t[u>>2]|0;s=f;return w|0}return 0}function YF(e){e=e|0;var i=0,r=0,n=0,f=0,u=0;i=s;s=s+16|0;r=i+8|0;n=i+4|0;f=i;t[n>>2]=e;if(!(t[n>>2]|0)){t[r>>2]=0;u=t[r>>2]|0;s=i;return u|0}e=t[n>>2]|0;if((t[(t[n>>2]|0)+4>>2]|0)!=2)if((t[e+4>>2]|0)==16){t[r>>2]=Yl(t[(t[n>>2]|0)+48>>2]|0)|0;u=t[r>>2]|0;s=i;return u|0}else{t[r>>2]=0;u=t[r>>2]|0;s=i;return u|0}if(t[e+12>>2]|0){do if(!(t[(t[(t[n>>2]|0)+12>>2]|0)+24>>2]|0)){if((t[(t[(t[n>>2]|0)+12>>2]|0)+4>>2]|0)!=3?(t[(t[(t[n>>2]|0)+12>>2]|0)+4>>2]|0)!=4:0)break;t[r>>2]=Yl(t[(t[(t[n>>2]|0)+12>>2]|0)+40>>2]|0)|0;u=t[r>>2]|0;s=i;return u|0}while(0);t[f>>2]=sy(t[(t[n>>2]|0)+32>>2]|0,t[(t[n>>2]|0)+12>>2]|0,1)|0;if(t[f>>2]|0){t[r>>2]=t[f>>2];u=t[r>>2]|0;s=i;return u|0}}t[r>>2]=Yl(75312)|0;u=t[r>>2]|0;s=i;return u|0}function GF(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0;n=s;s=s+96|0;f=n;u=n+28|0;a=n+24|0;o=n+20|0;c=n+16|0;l=n+12|0;b=n+32|0;k=n+8|0;t[a>>2]=e;t[o>>2]=i;t[c>>2]=r;t[k>>2]=1;if((t[o>>2]|0)!=0?(t[(t[o>>2]|0)+4>>2]|0)==1:0){if((t[c>>2]|0)!=0?(t[(t[c>>2]|0)+4>>2]|0)==18:0){t[l>>2]=rF(t[a>>2]|0,t[o>>2]|0,t[(t[c>>2]|0)+8>>2]|0)|0;if(t[l>>2]|0){t[u>>2]=t[l>>2];h=t[u>>2]|0;s=n;return h|0}if(!(t[(t[c>>2]|0)+12>>2]|0))SY(b,50,75656,f)|0;else{t[f>>2]=t[(t[c>>2]|0)+12>>2];SY(b,50,75872,f)|0}t[l>>2]=wF(t[a>>2]|0,t[o>>2]|0,b)|0;while(1){if(!(t[l>>2]|0)){w=20;break}if((t[k>>2]|0)>1e3){w=15;break}if(!(t[(t[c>>2]|0)+12>>2]|0)){r=t[k>>2]|0;t[k>>2]=r+1;t[f>>2]=r;SY(b,50,75880,f)|0}else{r=t[(t[c>>2]|0)+12>>2]|0;i=t[k>>2]|0;t[k>>2]=i+1;t[f>>2]=r;t[f+4>>2]=i;SY(b,50,75896,f)|0}t[l>>2]=wF(t[a>>2]|0,t[o>>2]|0,b)|0}if((w|0)==15){t[u>>2]=0;h=t[u>>2]|0;s=n;return h|0}else if((w|0)==20){t[l>>2]=Wg(t[o>>2]|0,t[(t[c>>2]|0)+8>>2]|0,b)|0;t[u>>2]=t[l>>2];h=t[u>>2]|0;s=n;return h|0}}t[u>>2]=0;h=t[u>>2]|0;s=n;return h|0}t[u>>2]=0;h=t[u>>2]|0;s=n;return h|0}function WF(e){e=e|0;var i=0,r=0,n=0,f=0,u=0;i=s;s=s+16|0;r=i+8|0;n=i+4|0;f=i;t[n>>2]=e;t[n>>2]=(t[n>>2]|0)<=0?256:e;t[f>>2]=gAi[t[135744>>2]&511](20)|0;do if(t[f>>2]|0){t[(t[f>>2]|0)+12>>2]=0;t[(t[f>>2]|0)+4>>2]=t[n>>2];t[(t[f>>2]|0)+8>>2]=0;e=gAi[t[135744>>2]&511]((t[n>>2]|0)*24|0)|0;t[t[f>>2]>>2]=e;if(!(t[t[f>>2]>>2]|0)){pAi[t[135736>>2]&511](t[f>>2]|0);break}VY(t[t[f>>2]>>2]|0,0,(t[n>>2]|0)*24|0)|0;e=oz()|0;t[(t[f>>2]|0)+16>>2]=e;t[r>>2]=t[f>>2];u=t[r>>2]|0;s=i;return u|0}while(0);t[r>>2]=0;u=t[r>>2]|0;s=i;return u|0}function KF(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0;r=s;s=s+16|0;n=r+8|0;f=r+4|0;u=r;t[n>>2]=e;t[f>>2]=i;t[u>>2]=WF(t[n>>2]|0)|0;if(!(t[u>>2]|0)){a=t[u>>2]|0;s=r;return a|0}t[(t[u>>2]|0)+12>>2]=t[f>>2];sz(t[f>>2]|0)|0;a=t[u>>2]|0;s=r;return a|0}function XF(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0;r=s;s=s+32|0;n=r+24|0;f=r+20|0;u=r+16|0;a=r+12|0;o=r+8|0;c=r+4|0;l=r;t[n>>2]=e;t[f>>2]=i;t[c>>2]=0;if(!(t[n>>2]|0)){s=r;return}if(t[t[n>>2]>>2]|0){t[l>>2]=t[(t[n>>2]|0)+8>>2];t[u>>2]=0;while(1){if(!((t[l>>2]|0)>0?(t[u>>2]|0)<(t[(t[n>>2]|0)+4>>2]|0):0))break;t[a>>2]=(t[t[n>>2]>>2]|0)+((t[u>>2]|0)*24|0);e:do if(t[(t[a>>2]|0)+20>>2]|0){t[c>>2]=1;while(1){if(!(t[a>>2]|0))break e;t[o>>2]=t[t[a>>2]>>2];if((t[f>>2]|0)!=0?(t[(t[a>>2]|0)+16>>2]|0)!=0:0)EAi[t[f>>2]&511](t[(t[a>>2]|0)+16>>2]|0,t[(t[a>>2]|0)+4>>2]|0);if(!(t[(t[n>>2]|0)+12>>2]|0)){if(t[(t[a>>2]|0)+4>>2]|0)pAi[t[135736>>2]&511](t[(t[a>>2]|0)+4>>2]|0);if(t[(t[a>>2]|0)+8>>2]|0)pAi[t[135736>>2]&511](t[(t[a>>2]|0)+8>>2]|0);if(t[(t[a>>2]|0)+12>>2]|0)pAi[t[135736>>2]&511](t[(t[a>>2]|0)+12>>2]|0)}t[(t[a>>2]|0)+16>>2]=0;if(!(t[c>>2]|0))pAi[t[135736>>2]&511](t[a>>2]|0);t[l>>2]=(t[l>>2]|0)+-1;t[c>>2]=0;t[a>>2]=t[o>>2]}}while(0);t[u>>2]=(t[u>>2]|0)+1}pAi[t[135736>>2]&511](t[t[n>>2]>>2]|0)}if(t[(t[n>>2]|0)+12>>2]|0)bz(t[(t[n>>2]|0)+12>>2]|0);pAi[t[135736>>2]&511](t[n>>2]|0);s=r;return}function ZF(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0;n=s;s=s+16|0;f=n+8|0;u=n+4|0;a=n;t[f>>2]=e;t[u>>2]=i;t[a>>2]=r;r=JF(t[f>>2]|0,t[u>>2]|0,0,0,t[a>>2]|0)|0;s=n;return r|0}function JF(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;var u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0;u=s;s=s+48|0;a=u+36|0;o=u+32|0;c=u+28|0;l=u+24|0;b=u+20|0;k=u+16|0;h=u+12|0;w=u+8|0;d=u+4|0;v=u;t[o>>2]=e;t[c>>2]=i;t[l>>2]=r;t[b>>2]=n;t[k>>2]=f;t[w>>2]=0;if((t[o>>2]|0)==0|(t[c>>2]|0)==0){t[a>>2]=-1;m=t[a>>2]|0;s=u;return m|0}if(t[(t[o>>2]|0)+12>>2]|0){if((wz(t[(t[o>>2]|0)+12>>2]|0,t[c>>2]|0)|0)==0?(t[c>>2]=kz(t[(t[o>>2]|0)+12>>2]|0,t[c>>2]|0,-1)|0,(t[c>>2]|0)==0):0){t[a>>2]=-1;m=t[a>>2]|0;s=u;return m|0}if(((t[l>>2]|0)!=0?(wz(t[(t[o>>2]|0)+12>>2]|0,t[l>>2]|0)|0)==0:0)?(t[l>>2]=kz(t[(t[o>>2]|0)+12>>2]|0,t[l>>2]|0,-1)|0,(t[l>>2]|0)==0):0){t[a>>2]=-1;m=t[a>>2]|0;s=u;return m|0}if(((t[b>>2]|0)!=0?(wz(t[(t[o>>2]|0)+12>>2]|0,t[b>>2]|0)|0)==0:0)?(t[b>>2]=kz(t[(t[o>>2]|0)+12>>2]|0,t[b>>2]|0,-1)|0,(t[b>>2]|0)==0):0){t[a>>2]=-1;m=t[a>>2]|0;s=u;return m|0}}t[h>>2]=dO(t[o>>2]|0,t[c>>2]|0,t[l>>2]|0,t[b>>2]|0)|0;do if(t[(t[t[o>>2]>>2]|0)+((t[h>>2]|0)*24|0)+20>>2]|0){f=(t[(t[o>>2]|0)+12>>2]|0)!=0;t[v>>2]=(t[t[o>>2]>>2]|0)+((t[h>>2]|0)*24|0);if(f){while(1){_=(t[(t[v>>2]|0)+4>>2]|0)==(t[c>>2]|0);if(!(t[t[v>>2]>>2]|0))break;if((_?(t[(t[v>>2]|0)+8>>2]|0)==(t[l>>2]|0):0)?(t[(t[v>>2]|0)+12>>2]|0)==(t[b>>2]|0):0){p=22;break}t[w>>2]=(t[w>>2]|0)+1;t[v>>2]=t[t[v>>2]>>2]}if((p|0)==22){t[a>>2]=-1;m=t[a>>2]|0;s=u;return m|0}if(!_)break;if((t[(t[v>>2]|0)+8>>2]|0)!=(t[l>>2]|0))break;if((t[(t[v>>2]|0)+12>>2]|0)!=(t[b>>2]|0))break;t[a>>2]=-1;m=t[a>>2]|0;s=u;return m|0}else{while(1){f=(t[t[v>>2]>>2]|0)!=0;E=(Xl(t[(t[v>>2]|0)+4>>2]|0,t[c>>2]|0)|0)!=0;if(!f)break;if((E?(Xl(t[(t[v>>2]|0)+8>>2]|0,t[l>>2]|0)|0)!=0:0)?(Xl(t[(t[v>>2]|0)+12>>2]|0,t[b>>2]|0)|0)!=0:0){p=32;break}t[w>>2]=(t[w>>2]|0)+1;t[v>>2]=t[t[v>>2]>>2]}if((p|0)==32){t[a>>2]=-1;m=t[a>>2]|0;s=u;return m|0}if(!E)break;if(!(Xl(t[(t[v>>2]|0)+8>>2]|0,t[l>>2]|0)|0))break;if(!(Xl(t[(t[v>>2]|0)+12>>2]|0,t[b>>2]|0)|0))break;t[a>>2]=-1;m=t[a>>2]|0;s=u;return m|0}}else t[v>>2]=0;while(0);if(t[v>>2]|0){t[d>>2]=gAi[t[135744>>2]&511](24)|0;if(!(t[d>>2]|0)){t[a>>2]=-1;m=t[a>>2]|0;s=u;return m|0}}else t[d>>2]=(t[t[o>>2]>>2]|0)+((t[h>>2]|0)*24|0);h=t[c>>2]|0;if(t[(t[o>>2]|0)+12>>2]|0){t[(t[d>>2]|0)+4>>2]=h;t[(t[d>>2]|0)+8>>2]=t[l>>2];t[(t[d>>2]|0)+12>>2]=t[b>>2]}else{c=Yl(h)|0;t[(t[d>>2]|0)+4>>2]=c;c=Yl(t[l>>2]|0)|0;t[(t[d>>2]|0)+8>>2]=c;c=Yl(t[b>>2]|0)|0;t[(t[d>>2]|0)+12>>2]=c}t[(t[d>>2]|0)+16>>2]=t[k>>2];t[t[d>>2]>>2]=0;t[(t[d>>2]|0)+20>>2]=1;if(t[v>>2]|0)t[t[v>>2]>>2]=t[d>>2];d=(t[o>>2]|0)+8|0;t[d>>2]=(t[d>>2]|0)+1;if((t[w>>2]|0)>>>0>8)vO(t[o>>2]|0,t[(t[o>>2]|0)+4>>2]<<3)|0;t[a>>2]=0;m=t[a>>2]|0;s=u;return m|0}function QF(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,u=0,a=0,o=0,c=0;f=s;s=s+16|0;u=f+12|0;a=f+8|0;o=f+4|0;c=f;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;t[c>>2]=n;n=JF(t[u>>2]|0,t[a>>2]|0,t[o>>2]|0,0,t[c>>2]|0)|0;s=f;return n|0}function $F(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,u=0,a=0,o=0,c=0;f=s;s=s+16|0;u=f+12|0;a=f+8|0;o=f+4|0;c=f;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;t[c>>2]=n;n=eO(t[u>>2]|0,t[a>>2]|0,0,0,t[o>>2]|0,t[c>>2]|0)|0;s=f;return n|0}function eO(e,i,r,n,f,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;u=u|0;var a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0,S=0;a=s;s=s+48|0;o=a+36|0;c=a+32|0;l=a+28|0;b=a+24|0;k=a+20|0;h=a+16|0;w=a+12|0;d=a+8|0;v=a+4|0;m=a;t[c>>2]=e;t[l>>2]=i;t[b>>2]=r;t[k>>2]=n;t[h>>2]=f;t[w>>2]=u;if((t[c>>2]|0)==0|(t[l>>2]|0)==0){t[o>>2]=-1;_=t[o>>2]|0;s=a;return _|0}if(t[(t[c>>2]|0)+12>>2]|0){if((wz(t[(t[c>>2]|0)+12>>2]|0,t[l>>2]|0)|0)==0?(t[l>>2]=kz(t[(t[c>>2]|0)+12>>2]|0,t[l>>2]|0,-1)|0,(t[l>>2]|0)==0):0){t[o>>2]=-1;_=t[o>>2]|0;s=a;return _|0}if(((t[b>>2]|0)!=0?(wz(t[(t[c>>2]|0)+12>>2]|0,t[b>>2]|0)|0)==0:0)?(t[b>>2]=kz(t[(t[c>>2]|0)+12>>2]|0,t[b>>2]|0,-1)|0,(t[b>>2]|0)==0):0){t[o>>2]=-1;_=t[o>>2]|0;s=a;return _|0}if(((t[k>>2]|0)!=0?(wz(t[(t[c>>2]|0)+12>>2]|0,t[k>>2]|0)|0)==0:0)?(t[k>>2]=kz(t[(t[c>>2]|0)+12>>2]|0,t[k>>2]|0,-1)|0,(t[k>>2]|0)==0):0){t[o>>2]=-1;_=t[o>>2]|0;s=a;return _|0}}t[d>>2]=dO(t[c>>2]|0,t[l>>2]|0,t[b>>2]|0,t[k>>2]|0)|0;do if(t[(t[t[c>>2]>>2]|0)+((t[d>>2]|0)*24|0)+20>>2]|0){u=(t[(t[c>>2]|0)+12>>2]|0)!=0;t[m>>2]=(t[t[c>>2]>>2]|0)+((t[d>>2]|0)*24|0);if(u){while(1){p=(t[(t[m>>2]|0)+4>>2]|0)==(t[l>>2]|0);if(!(t[t[m>>2]>>2]|0))break;if((p?(t[(t[m>>2]|0)+8>>2]|0)==(t[b>>2]|0):0)?(t[(t[m>>2]|0)+12>>2]|0)==(t[k>>2]|0):0){E=22;break}t[m>>2]=t[t[m>>2]>>2]}if((E|0)==22){if(t[w>>2]|0)EAi[t[w>>2]&511](t[(t[m>>2]|0)+16>>2]|0,t[(t[m>>2]|0)+4>>2]|0);t[(t[m>>2]|0)+16>>2]=t[h>>2];t[o>>2]=0;_=t[o>>2]|0;s=a;return _|0}if(!p)break;if((t[(t[m>>2]|0)+8>>2]|0)!=(t[b>>2]|0))break;if((t[(t[m>>2]|0)+12>>2]|0)!=(t[k>>2]|0))break;if(t[w>>2]|0)EAi[t[w>>2]&511](t[(t[m>>2]|0)+16>>2]|0,t[(t[m>>2]|0)+4>>2]|0);t[(t[m>>2]|0)+16>>2]=t[h>>2];t[o>>2]=0;_=t[o>>2]|0;s=a;return _|0}else{while(1){u=(t[t[m>>2]>>2]|0)!=0;S=(Xl(t[(t[m>>2]|0)+4>>2]|0,t[l>>2]|0)|0)!=0;if(!u)break;if((S?(Xl(t[(t[m>>2]|0)+8>>2]|0,t[b>>2]|0)|0)!=0:0)?(Xl(t[(t[m>>2]|0)+12>>2]|0,t[k>>2]|0)|0)!=0:0){E=36;break}t[m>>2]=t[t[m>>2]>>2]}if((E|0)==36){if(t[w>>2]|0)EAi[t[w>>2]&511](t[(t[m>>2]|0)+16>>2]|0,t[(t[m>>2]|0)+4>>2]|0);t[(t[m>>2]|0)+16>>2]=t[h>>2];t[o>>2]=0;
	_=t[o>>2]|0;s=a;return _|0}if(!S)break;if(!(Xl(t[(t[m>>2]|0)+8>>2]|0,t[b>>2]|0)|0))break;if(!(Xl(t[(t[m>>2]|0)+12>>2]|0,t[k>>2]|0)|0))break;if(t[w>>2]|0)EAi[t[w>>2]&511](t[(t[m>>2]|0)+16>>2]|0,t[(t[m>>2]|0)+4>>2]|0);t[(t[m>>2]|0)+16>>2]=t[h>>2];t[o>>2]=0;_=t[o>>2]|0;s=a;return _|0}}else t[m>>2]=0;while(0);if(t[m>>2]|0){t[v>>2]=gAi[t[135744>>2]&511](24)|0;if(!(t[v>>2]|0)){t[o>>2]=-1;_=t[o>>2]|0;s=a;return _|0}}else t[v>>2]=(t[t[c>>2]>>2]|0)+((t[d>>2]|0)*24|0);d=t[l>>2]|0;if(t[(t[c>>2]|0)+12>>2]|0){t[(t[v>>2]|0)+4>>2]=d;t[(t[v>>2]|0)+8>>2]=t[b>>2];t[(t[v>>2]|0)+12>>2]=t[k>>2]}else{l=Yl(d)|0;t[(t[v>>2]|0)+4>>2]=l;l=Yl(t[b>>2]|0)|0;t[(t[v>>2]|0)+8>>2]=l;l=Yl(t[k>>2]|0)|0;t[(t[v>>2]|0)+12>>2]=l}t[(t[v>>2]|0)+16>>2]=t[h>>2];t[t[v>>2]>>2]=0;t[(t[v>>2]|0)+20>>2]=1;h=(t[c>>2]|0)+8|0;t[h>>2]=(t[h>>2]|0)+1;if(t[m>>2]|0)t[t[m>>2]>>2]=t[v>>2];t[o>>2]=0;_=t[o>>2]|0;s=a;return _|0}function iO(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;var u=0,a=0,o=0,c=0,l=0,b=0;u=s;s=s+32|0;a=u+16|0;o=u+12|0;c=u+8|0;l=u+4|0;b=u;t[a>>2]=e;t[o>>2]=i;t[c>>2]=r;t[l>>2]=n;t[b>>2]=f;f=eO(t[a>>2]|0,t[o>>2]|0,t[c>>2]|0,0,t[l>>2]|0,t[b>>2]|0)|0;s=u;return f|0}function rO(e,i){e=e|0;i=i|0;var r=0,n=0,f=0;r=s;s=s+16|0;n=r+4|0;f=r;t[n>>2]=e;t[f>>2]=i;i=nO(t[n>>2]|0,t[f>>2]|0,0,0)|0;s=r;return i|0}function nO(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0;f=s;s=s+32|0;u=f+24|0;a=f+20|0;o=f+16|0;c=f+12|0;l=f+8|0;b=f+4|0;k=f;t[a>>2]=e;t[o>>2]=i;t[c>>2]=r;t[l>>2]=n;if(!(t[a>>2]|0)){t[u>>2]=0;h=t[u>>2]|0;s=f;return h|0}if(!(t[o>>2]|0)){t[u>>2]=0;h=t[u>>2]|0;s=f;return h|0}t[b>>2]=dO(t[a>>2]|0,t[o>>2]|0,t[c>>2]|0,t[l>>2]|0)|0;if(!(t[(t[t[a>>2]>>2]|0)+((t[b>>2]|0)*24|0)+20>>2]|0)){t[u>>2]=0;h=t[u>>2]|0;s=f;return h|0}e:do if(t[(t[a>>2]|0)+12>>2]|0){t[k>>2]=(t[t[a>>2]>>2]|0)+((t[b>>2]|0)*24|0);while(1){if(!(t[k>>2]|0))break e;if(((t[(t[k>>2]|0)+4>>2]|0)==(t[o>>2]|0)?(t[(t[k>>2]|0)+8>>2]|0)==(t[c>>2]|0):0)?(t[(t[k>>2]|0)+12>>2]|0)==(t[l>>2]|0):0)break;t[k>>2]=t[t[k>>2]>>2]}t[u>>2]=t[(t[k>>2]|0)+16>>2];h=t[u>>2]|0;s=f;return h|0}while(0);t[k>>2]=(t[t[a>>2]>>2]|0)+((t[b>>2]|0)*24|0);while(1){if(!(t[k>>2]|0)){w=22;break}if(((Xl(t[(t[k>>2]|0)+4>>2]|0,t[o>>2]|0)|0)!=0?(Xl(t[(t[k>>2]|0)+8>>2]|0,t[c>>2]|0)|0)!=0:0)?(Xl(t[(t[k>>2]|0)+12>>2]|0,t[l>>2]|0)|0)!=0:0){w=20;break}t[k>>2]=t[t[k>>2]>>2]}if((w|0)==20){t[u>>2]=t[(t[k>>2]|0)+16>>2];h=t[u>>2]|0;s=f;return h|0}else if((w|0)==22){t[u>>2]=0;h=t[u>>2]|0;s=f;return h|0}return 0}function fO(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0;n=s;s=s+16|0;f=n+8|0;u=n+4|0;a=n;t[f>>2]=e;t[u>>2]=i;t[a>>2]=r;r=nO(t[f>>2]|0,t[u>>2]|0,t[a>>2]|0,0)|0;s=n;return r|0}function tO(e,i,r,n,f,u,a){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;u=u|0;a=a|0;var o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0;o=s;s=s+48|0;c=o+36|0;l=o+32|0;b=o+28|0;k=o+24|0;h=o+20|0;w=o+16|0;d=o+12|0;v=o+8|0;m=o+4|0;_=o;t[l>>2]=e;t[b>>2]=i;t[k>>2]=r;t[h>>2]=n;t[w>>2]=f;t[d>>2]=u;t[v>>2]=a;if(!(t[l>>2]|0)){t[c>>2]=0;p=t[c>>2]|0;s=o;return p|0}if(!(t[k>>2]|0)){t[c>>2]=0;p=t[c>>2]|0;s=o;return p|0}t[m>>2]=mO(t[l>>2]|0,t[b>>2]|0,t[k>>2]|0,t[h>>2]|0,t[w>>2]|0,t[d>>2]|0,t[v>>2]|0)|0;if(!(t[(t[t[l>>2]>>2]|0)+((t[m>>2]|0)*24|0)+20>>2]|0)){t[c>>2]=0;p=t[c>>2]|0;s=o;return p|0}t[_>>2]=(t[t[l>>2]>>2]|0)+((t[m>>2]|0)*24|0);while(1){if(!(t[_>>2]|0)){E=14;break}if(((Zl(t[b>>2]|0,t[k>>2]|0,t[(t[_>>2]|0)+4>>2]|0)|0)!=0?(Zl(t[h>>2]|0,t[w>>2]|0,t[(t[_>>2]|0)+8>>2]|0)|0)!=0:0)?(Zl(t[d>>2]|0,t[v>>2]|0,t[(t[_>>2]|0)+12>>2]|0)|0)!=0:0){E=12;break}t[_>>2]=t[t[_>>2]>>2]}if((E|0)==12){t[c>>2]=t[(t[_>>2]|0)+16>>2];p=t[c>>2]|0;s=o;return p|0}else if((E|0)==14){t[c>>2]=0;p=t[c>>2]|0;s=o;return p|0}return 0}function uO(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;var u=0,a=0,o=0,c=0,l=0,b=0;u=s;s=s+32|0;a=u+16|0;o=u+12|0;c=u+8|0;l=u+4|0;b=u;t[a>>2]=e;t[o>>2]=i;t[c>>2]=r;t[l>>2]=n;t[b>>2]=f;f=tO(t[a>>2]|0,t[o>>2]|0,t[c>>2]|0,t[l>>2]|0,t[b>>2]|0,0,0)|0;s=u;return f|0}function aO(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0;n=s;s=s+32|0;f=n+16|0;u=n+12|0;a=n+8|0;o=n;t[f>>2]=e;t[u>>2]=i;t[a>>2]=r;t[o+4>>2]=t[a>>2];t[o>>2]=t[u>>2];oO(t[f>>2]|0,229,o);s=n;return}function oO(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0;n=s;s=s+32|0;f=n+24|0;u=n+20|0;a=n+16|0;o=n+12|0;c=n+8|0;l=n+4|0;b=n;t[f>>2]=e;t[u>>2]=i;t[a>>2]=r;if((t[f>>2]|0)==0|(t[u>>2]|0)==0){s=n;return}if(!(t[t[f>>2]>>2]|0)){s=n;return}t[o>>2]=0;while(1){if((t[o>>2]|0)>=(t[(t[f>>2]|0)+4>>2]|0))break;e:do if(t[(t[t[f>>2]>>2]|0)+((t[o>>2]|0)*24|0)+20>>2]|0){t[l>>2]=(t[t[f>>2]>>2]|0)+((t[o>>2]|0)*24|0);while(1){if(!(t[l>>2]|0))break e;t[b>>2]=t[t[l>>2]>>2];t[c>>2]=t[(t[f>>2]|0)+8>>2];if((t[u>>2]|0)!=0?(t[(t[l>>2]|0)+16>>2]|0)!=0:0)mAi[t[u>>2]&511](t[(t[l>>2]|0)+16>>2]|0,t[a>>2]|0,t[(t[l>>2]|0)+4>>2]|0,t[(t[l>>2]|0)+8>>2]|0,t[(t[l>>2]|0)+12>>2]|0);if((t[c>>2]|0)==(t[(t[f>>2]|0)+8>>2]|0)){t[l>>2]=t[b>>2];continue}if((t[l>>2]|0)!=((t[t[f>>2]>>2]|0)+((t[o>>2]|0)*24|0)|0)){t[l>>2]=t[b>>2];continue}if(!(t[(t[t[f>>2]>>2]|0)+((t[o>>2]|0)*24|0)+20>>2]|0))t[l>>2]=0;if((t[(t[t[f>>2]>>2]|0)+((t[o>>2]|0)*24|0)>>2]|0)==(t[b>>2]|0))continue;t[l>>2]=(t[t[f>>2]>>2]|0)+((t[o>>2]|0)*24|0)}}while(0);t[o>>2]=(t[o>>2]|0)+1}s=n;return}function cO(e,i,r,n,f,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;u=u|0;var a=0,o=0,c=0,l=0,b=0,k=0,h=0;a=s;s=s+32|0;o=a+20|0;c=a+16|0;l=a+12|0;b=a+8|0;k=a+4|0;h=a;t[o>>2]=e;t[c>>2]=i;t[l>>2]=r;t[b>>2]=n;t[k>>2]=f;t[h>>2]=u;lO(t[o>>2]|0,t[c>>2]|0,t[l>>2]|0,t[b>>2]|0,t[k>>2]|0,t[h>>2]|0);s=a;return}function lO(e,i,r,n,f,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;u=u|0;var a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0;a=s;s=s+48|0;o=a+32|0;c=a+28|0;l=a+24|0;b=a+20|0;k=a+16|0;h=a+12|0;w=a+8|0;d=a+4|0;v=a;t[o>>2]=e;t[c>>2]=i;t[l>>2]=r;t[b>>2]=n;t[k>>2]=f;t[h>>2]=u;if((t[o>>2]|0)==0|(t[k>>2]|0)==0){s=a;return}if(!(t[t[o>>2]>>2]|0)){s=a;return}t[w>>2]=0;while(1){if((t[w>>2]|0)>=(t[(t[o>>2]|0)+4>>2]|0))break;e:do if(t[(t[t[o>>2]>>2]|0)+((t[w>>2]|0)*24|0)+20>>2]|0){t[d>>2]=(t[t[o>>2]>>2]|0)+((t[w>>2]|0)*24|0);while(1){if(!(t[d>>2]|0))break e;t[v>>2]=t[t[d>>2]>>2];if(!((t[c>>2]|0)!=0?(Xl(t[c>>2]|0,t[(t[d>>2]|0)+4>>2]|0)|0)==0:0))m=10;do if((m|0)==10){m=0;if((t[l>>2]|0)!=0?(Xl(t[l>>2]|0,t[(t[d>>2]|0)+8>>2]|0)|0)==0:0)break;if((t[b>>2]|0)!=0?(Xl(t[b>>2]|0,t[(t[d>>2]|0)+12>>2]|0)|0)==0:0)break;if(t[(t[d>>2]|0)+16>>2]|0)mAi[t[k>>2]&511](t[(t[d>>2]|0)+16>>2]|0,t[h>>2]|0,t[(t[d>>2]|0)+4>>2]|0,t[(t[d>>2]|0)+8>>2]|0,t[(t[d>>2]|0)+12>>2]|0)}while(0);t[d>>2]=t[v>>2]}}while(0);t[w>>2]=(t[w>>2]|0)+1}s=a;return}function sO(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0;r=s;s=s+32|0;n=r+24|0;f=r+20|0;u=r+16|0;a=r+12|0;o=r+8|0;c=r+4|0;l=r;t[f>>2]=e;t[u>>2]=i;if(!(t[f>>2]|0)){t[n>>2]=0;b=t[n>>2]|0;s=r;return b|0}if(!(t[u>>2]|0)){t[n>>2]=0;b=t[n>>2]|0;s=r;return b|0}t[l>>2]=WF(t[(t[f>>2]|0)+4>>2]|0)|0;if(!(t[l>>2]|0)){t[n>>2]=0;b=t[n>>2]|0;s=r;return b|0}e:do if(t[t[f>>2]>>2]|0){t[a>>2]=0;while(1){if((t[a>>2]|0)>=(t[(t[f>>2]|0)+4>>2]|0))break e;i:do if(t[(t[t[f>>2]>>2]|0)+((t[a>>2]|0)*24|0)+20>>2]|0){t[o>>2]=(t[t[f>>2]>>2]|0)+((t[a>>2]|0)*24|0);while(1){if(!(t[o>>2]|0))break i;t[c>>2]=t[t[o>>2]>>2];i=t[l>>2]|0;e=t[(t[o>>2]|0)+4>>2]|0;k=t[(t[o>>2]|0)+8>>2]|0;h=t[(t[o>>2]|0)+12>>2]|0;JF(i,e,k,h,MAi[t[u>>2]&511](t[(t[o>>2]|0)+16>>2]|0,t[(t[o>>2]|0)+4>>2]|0)|0)|0;t[o>>2]=t[c>>2]}}while(0);t[a>>2]=(t[a>>2]|0)+1}}while(0);t[(t[l>>2]|0)+8>>2]=t[(t[f>>2]|0)+8>>2];t[n>>2]=t[l>>2];b=t[n>>2]|0;s=r;return b|0}function bO(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i+4|0;n=i;t[n>>2]=e;if(!(t[n>>2]|0))t[r>>2]=-1;else t[r>>2]=t[(t[n>>2]|0)+8>>2];s=i;return t[r>>2]|0}function kO(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0;n=s;s=s+16|0;f=n+8|0;u=n+4|0;a=n;t[f>>2]=e;t[u>>2]=i;t[a>>2]=r;r=hO(t[f>>2]|0,t[u>>2]|0,0,0,t[a>>2]|0)|0;s=n;return r|0}function hO(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;var u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0;u=s;s=s+48|0;a=u+32|0;o=u+28|0;c=u+24|0;l=u+20|0;b=u+16|0;k=u+12|0;h=u+8|0;w=u+4|0;d=u;t[o>>2]=e;t[c>>2]=i;t[l>>2]=r;t[b>>2]=n;t[k>>2]=f;t[d>>2]=0;if((t[o>>2]|0)==0|(t[c>>2]|0)==0){t[a>>2]=-1;v=t[a>>2]|0;s=u;return v|0}t[h>>2]=dO(t[o>>2]|0,t[c>>2]|0,t[l>>2]|0,t[b>>2]|0)|0;if(!(t[(t[t[o>>2]>>2]|0)+((t[h>>2]|0)*24|0)+20>>2]|0)){t[a>>2]=-1;v=t[a>>2]|0;s=u;return v|0}t[w>>2]=(t[t[o>>2]>>2]|0)+((t[h>>2]|0)*24|0);while(1){if(!(t[w>>2]|0)){m=27;break}if(((Xl(t[(t[w>>2]|0)+4>>2]|0,t[c>>2]|0)|0)!=0?(Xl(t[(t[w>>2]|0)+8>>2]|0,t[l>>2]|0)|0)!=0:0)?(Xl(t[(t[w>>2]|0)+12>>2]|0,t[b>>2]|0)|0)!=0:0)break;t[d>>2]=t[w>>2];t[w>>2]=t[t[w>>2]>>2]}if((m|0)==27){t[a>>2]=-1;v=t[a>>2]|0;s=u;return v|0}if((t[k>>2]|0)!=0?(t[(t[w>>2]|0)+16>>2]|0)!=0:0)EAi[t[k>>2]&511](t[(t[w>>2]|0)+16>>2]|0,t[(t[w>>2]|0)+4>>2]|0);t[(t[w>>2]|0)+16>>2]=0;if(!(t[(t[o>>2]|0)+12>>2]|0)){if(t[(t[w>>2]|0)+4>>2]|0)pAi[t[135736>>2]&511](t[(t[w>>2]|0)+4>>2]|0);if(t[(t[w>>2]|0)+8>>2]|0)pAi[t[135736>>2]&511](t[(t[w>>2]|0)+8>>2]|0);if(t[(t[w>>2]|0)+12>>2]|0)pAi[t[135736>>2]&511](t[(t[w>>2]|0)+12>>2]|0)}k=t[t[w>>2]>>2]|0;do if(!(t[d>>2]|0)){m=t[w>>2]|0;if(!k){t[m+20>>2]=0;break}else{t[w>>2]=t[m>>2];m=(t[t[o>>2]>>2]|0)+((t[h>>2]|0)*24|0)|0;b=t[w>>2]|0;t[m+0>>2]=t[b+0>>2];t[m+4>>2]=t[b+4>>2];t[m+8>>2]=t[b+8>>2];t[m+12>>2]=t[b+12>>2];t[m+16>>2]=t[b+16>>2];t[m+20>>2]=t[b+20>>2];pAi[t[135736>>2]&511](t[w>>2]|0);break}}else{t[t[d>>2]>>2]=k;pAi[t[135736>>2]&511](t[w>>2]|0)}while(0);w=(t[o>>2]|0)+8|0;t[w>>2]=(t[w>>2]|0)+-1;t[a>>2]=0;v=t[a>>2]|0;s=u;return v|0}function wO(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,u=0,a=0,o=0,c=0;f=s;s=s+16|0;u=f+12|0;a=f+8|0;o=f+4|0;c=f;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;t[c>>2]=n;n=hO(t[u>>2]|0,t[a>>2]|0,t[o>>2]|0,0,t[c>>2]|0)|0;s=f;return n|0}function dO(e,i,r,f){e=e|0;i=i|0;r=r|0;f=f|0;var a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0;a=s;s=s+32|0;o=a+16|0;c=a+12|0;l=a+8|0;b=a+4|0;k=a;h=a+20|0;t[o>>2]=e;t[c>>2]=i;t[l>>2]=r;t[b>>2]=f;t[k>>2]=0;t[k>>2]=t[(t[o>>2]|0)+16>>2];e:do if(t[c>>2]|0){t[k>>2]=(t[k>>2]|0)+((u[t[c>>2]>>0]|0)*30|0);while(1){f=t[c>>2]|0;t[c>>2]=f+1;r=n[f>>0]|0;n[h>>0]=r;if(!(r<<24>>24))break e;t[k>>2]=t[k>>2]^(t[k>>2]<<5)+((t[k>>2]|0)>>>3)+(n[h>>0]|0)}}while(0);t[k>>2]=t[k>>2]^(t[k>>2]<<5)+((t[k>>2]|0)>>>3);e:do if(t[l>>2]|0)while(1){c=t[l>>2]|0;t[l>>2]=c+1;r=n[c>>0]|0;n[h>>0]=r;if(!(r<<24>>24))break e;t[k>>2]=t[k>>2]^(t[k>>2]<<5)+((t[k>>2]|0)>>>3)+(n[h>>0]|0)}while(0);t[k>>2]=t[k>>2]^(t[k>>2]<<5)+((t[k>>2]|0)>>>3);if(!(t[b>>2]|0)){w=t[k>>2]|0;d=t[o>>2]|0;v=d+4|0;m=t[v>>2]|0;_=(w>>>0)%(m>>>0)|0;s=a;return _|0}while(1){l=t[b>>2]|0;t[b>>2]=l+1;r=n[l>>0]|0;n[h>>0]=r;if(!(r<<24>>24))break;t[k>>2]=t[k>>2]^(t[k>>2]<<5)+((t[k>>2]|0)>>>3)+(n[h>>0]|0)}w=t[k>>2]|0;d=t[o>>2]|0;v=d+4|0;m=t[v>>2]|0;_=(w>>>0)%(m>>>0)|0;s=a;return _|0}function vO(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0;r=s;s=s+48|0;n=r+32|0;f=r+28|0;u=r+24|0;a=r+20|0;o=r+16|0;c=r+12|0;l=r+8|0;b=r+4|0;k=r;t[f>>2]=e;t[u>>2]=i;if(!(t[f>>2]|0)){t[n>>2]=-1;h=t[n>>2]|0;s=r;return h|0}if((t[u>>2]|0)<8){t[n>>2]=-1;h=t[n>>2]|0;s=r;return h|0}if((t[u>>2]|0)>16384){t[n>>2]=-1;h=t[n>>2]|0;s=r;return h|0}t[o>>2]=t[(t[f>>2]|0)+4>>2];t[k>>2]=t[t[f>>2]>>2];if(!(t[k>>2]|0)){t[n>>2]=-1;h=t[n>>2]|0;s=r;return h|0}i=gAi[t[135744>>2]&511]((t[u>>2]|0)*24|0)|0;t[t[f>>2]>>2]=i;if(!(t[t[f>>2]>>2]|0)){t[t[f>>2]>>2]=t[k>>2];t[n>>2]=-1;h=t[n>>2]|0;s=r;return h|0}VY(t[t[f>>2]>>2]|0,0,(t[u>>2]|0)*24|0)|0;t[(t[f>>2]|0)+4>>2]=t[u>>2];t[c>>2]=0;while(1){if((t[c>>2]|0)>=(t[o>>2]|0))break;if(t[(t[k>>2]|0)+((t[c>>2]|0)*24|0)+20>>2]|0){t[a>>2]=dO(t[f>>2]|0,t[(t[k>>2]|0)+((t[c>>2]|0)*24|0)+4>>2]|0,t[(t[k>>2]|0)+((t[c>>2]|0)*24|0)+8>>2]|0,t[(t[k>>2]|0)+((t[c>>2]|0)*24|0)+12>>2]|0)|0;u=(t[t[f>>2]>>2]|0)+((t[a>>2]|0)*24|0)|0;i=(t[k>>2]|0)+((t[c>>2]|0)*24|0)|0;t[u+0>>2]=t[i+0>>2];t[u+4>>2]=t[i+4>>2];t[u+8>>2]=t[i+8>>2];t[u+12>>2]=t[i+12>>2];t[u+16>>2]=t[i+16>>2];t[u+20>>2]=t[i+20>>2];t[(t[t[f>>2]>>2]|0)+((t[a>>2]|0)*24|0)>>2]=0}t[c>>2]=(t[c>>2]|0)+1}t[c>>2]=0;while(1){if((t[c>>2]|0)>=(t[o>>2]|0))break;t[l>>2]=t[(t[k>>2]|0)+((t[c>>2]|0)*24|0)>>2];while(1){if(!(t[l>>2]|0))break;t[b>>2]=t[t[l>>2]>>2];t[a>>2]=dO(t[f>>2]|0,t[(t[l>>2]|0)+4>>2]|0,t[(t[l>>2]|0)+8>>2]|0,t[(t[l>>2]|0)+12>>2]|0)|0;i=(t[t[f>>2]>>2]|0)+((t[a>>2]|0)*24|0)|0;if(!(t[(t[t[f>>2]>>2]|0)+((t[a>>2]|0)*24|0)+20>>2]|0)){u=t[l>>2]|0;t[i+0>>2]=t[u+0>>2];t[i+4>>2]=t[u+4>>2];t[i+8>>2]=t[u+8>>2];t[i+12>>2]=t[u+12>>2];t[i+16>>2]=t[u+16>>2];t[i+20>>2]=t[u+20>>2];t[(t[t[f>>2]>>2]|0)+((t[a>>2]|0)*24|0)>>2]=0;pAi[t[135736>>2]&511](t[l>>2]|0)}else{t[t[l>>2]>>2]=t[i>>2];t[(t[t[f>>2]>>2]|0)+((t[a>>2]|0)*24|0)>>2]=t[l>>2]}t[l>>2]=t[b>>2]}t[c>>2]=(t[c>>2]|0)+1}pAi[t[135736>>2]&511](t[k>>2]|0);t[n>>2]=0;h=t[n>>2]|0;s=r;return h|0}function mO(e,i,r,f,a,o,c){e=e|0;i=i|0;r=r|0;f=f|0;a=a|0;o=o|0;c=c|0;var l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0,S=0,g=0,y=0,F=0,O=0,A=0,M=0,R=0,N=0,T=0;l=s;s=s+48|0;b=l+28|0;k=l+24|0;h=l+20|0;w=l+16|0;d=l+12|0;v=l+8|0;m=l+4|0;_=l;p=l+32|0;t[b>>2]=e;t[k>>2]=i;t[h>>2]=r;t[w>>2]=f;t[d>>2]=a;t[v>>2]=o;t[m>>2]=c;t[_>>2]=0;t[_>>2]=t[(t[b>>2]|0)+16>>2];if(t[k>>2]|0)t[_>>2]=(t[_>>2]|0)+((u[t[k>>2]>>0]|0)*30|0);else t[_>>2]=(t[_>>2]|0)+((u[t[h>>2]>>0]|0)*30|0);if(t[k>>2]|0){while(1){c=t[k>>2]|0;t[k>>2]=c+1;o=n[c>>0]|0;n[p>>0]=o;E=t[_>>2]|0;S=(t[_>>2]<<5)+((t[_>>2]|0)>>>3)|0;if(!(o<<24>>24))break;t[_>>2]=E^S+(n[p>>0]|0)}t[_>>2]=E^S+58}e:do if(t[h>>2]|0)while(1){S=t[h>>2]|0;t[h>>2]=S+1;E=n[S>>0]|0;n[p>>0]=E;if(!(E<<24>>24))break e;t[_>>2]=t[_>>2]^(t[_>>2]<<5)+((t[_>>2]|0)>>>3)+(n[p>>0]|0)}while(0);t[_>>2]=t[_>>2]^(t[_>>2]<<5)+((t[_>>2]|0)>>>3);if(t[w>>2]|0){while(1){h=t[w>>2]|0;t[w>>2]=h+1;E=n[h>>0]|0;n[p>>0]=E;g=t[_>>2]|0;y=(t[_>>2]<<5)+((t[_>>2]|0)>>>3)|0;if(!(E<<24>>24))break;t[_>>2]=g^y+(n[p>>0]|0)}t[_>>2]=g^y+58}e:do if(t[d>>2]|0)while(1){y=t[d>>2]|0;t[d>>2]=y+1;g=n[y>>0]|0;n[p>>0]=g;if(!(g<<24>>24))break e;t[_>>2]=t[_>>2]^(t[_>>2]<<5)+((t[_>>2]|0)>>>3)+(n[p>>0]|0)}while(0);t[_>>2]=t[_>>2]^(t[_>>2]<<5)+((t[_>>2]|0)>>>3);if(t[v>>2]|0){while(1){d=t[v>>2]|0;t[v>>2]=d+1;g=n[d>>0]|0;n[p>>0]=g;F=t[_>>2]|0;O=(t[_>>2]<<5)+((t[_>>2]|0)>>>3)|0;if(!(g<<24>>24))break;t[_>>2]=F^O+(n[p>>0]|0)}t[_>>2]=F^O+58}if(!(t[m>>2]|0)){A=t[_>>2]|0;M=t[b>>2]|0;R=M+4|0;N=t[R>>2]|0;T=(A>>>0)%(N>>>0)|0;s=l;return T|0}while(1){O=t[m>>2]|0;t[m>>2]=O+1;F=n[O>>0]|0;n[p>>0]=F;if(!(F<<24>>24))break;t[_>>2]=t[_>>2]^(t[_>>2]<<5)+((t[_>>2]|0)>>>3)+(n[p>>0]|0)}A=t[_>>2]|0;M=t[b>>2]|0;R=M+4|0;N=t[R>>2]|0;T=(A>>>0)%(N>>>0)|0;s=l;return T|0}function _O(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;var u=0,a=0,o=0,c=0,l=0;u=s;s=s+32|0;a=u+20|0;o=u+16|0;c=u+12|0;l=u;t[a>>2]=e;t[o>>2]=i;t[c>>2]=r;t[u+8>>2]=n;t[u+4>>2]=f;t[l>>2]=t[o>>2];yAi[t[t[l>>2]>>2]&511](t[a>>2]|0,t[(t[l>>2]|0)+4>>2]|0,t[c>>2]|0);s=u;return}function pO(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0;n=s;s=s+16|0;f=n+12|0;u=n+8|0;a=n+4|0;o=n;t[f>>2]=e;t[u>>2]=i;t[a>>2]=r;do if(!(t[u>>2]|0)){if(!(t[(ii()|0)>>2]|0)){t[u>>2]=0;break}if((t[(ii()|0)>>2]|0)==13){t[u>>2]=1501;break}if((t[(ii()|0)>>2]|0)==11){t[u>>2]=1502;break}if((t[(ii()|0)>>2]|0)==9){t[u>>2]=1503;break}if((t[(ii()|0)>>2]|0)==74){t[u>>2]=1504;break}if((t[(ii()|0)>>2]|0)==16){t[u>>2]=1505;break}if((t[(ii()|0)>>2]|0)==125){t[u>>2]=1506;break}if((t[(ii()|0)>>2]|0)==10){t[u>>2]=1507;break}if((t[(ii()|0)>>2]|0)==35){t[u>>2]=1508;break}if((t[(ii()|0)>>2]|0)==33){t[u>>2]=1509;break}if((t[(ii()|0)>>2]|0)==17){t[u>>2]=1510;break}if((t[(ii()|0)>>2]|0)==14){t[u>>2]=1511;break}if((t[(ii()|0)>>2]|0)==27){t[u>>2]=1512;break}if((t[(ii()|0)>>2]|0)==115){t[u>>2]=1513;break}if((t[(ii()|0)>>2]|0)==4){t[u>>2]=1514;break}if((t[(ii()|0)>>2]|0)==22){t[u>>2]=1515;break}if((t[(ii()|0)>>2]|0)==5){t[u>>2]=1516;break}if((t[(ii()|0)>>2]|0)==21){t[u>>2]=1517;break}if((t[(ii()|0)>>2]|0)==24){t[u>>2]=1518;break}if((t[(ii()|0)>>2]|0)==31){t[u>>2]=1519;break}if((t[(ii()|0)>>2]|0)==90){t[u>>2]=1520;break}if((t[(ii()|0)>>2]|0)==36){t[u>>2]=1521;break}if((t[(ii()|0)>>2]|0)==23){t[u>>2]=1522;break}if((t[(ii()|0)>>2]|0)==19){t[u>>2]=1523;break}if((t[(ii()|0)>>2]|0)==2){t[u>>2]=1524;break}if((t[(ii()|0)>>2]|0)==8){t[u>>2]=1525;break}if((t[(ii()|0)>>2]|0)==37){t[u>>2]=1526;break}if((t[(ii()|0)>>2]|0)==12){t[u>>2]=1527;break}if((t[(ii()|0)>>2]|0)==28){t[u>>2]=1528;break}if((t[(ii()|0)>>2]|0)==38){t[u>>2]=1529;break}if((t[(ii()|0)>>2]|0)==20){t[u>>2]=1530;break}if((t[(ii()|0)>>2]|0)==39){t[u>>2]=1531;break}if((t[(ii()|0)>>2]|0)==95){t[u>>2]=1532;break}if((t[(ii()|0)>>2]|0)==25){t[u>>2]=1533;break}if((t[(ii()|0)>>2]|0)==6){t[u>>2]=1534;break}if((t[(ii()|0)>>2]|0)==1){t[u>>2]=1535;break}if((t[(ii()|0)>>2]|0)==32){t[u>>2]=1536;break}if((t[(ii()|0)>>2]|0)==34){t[u>>2]=1537;break}if((t[(ii()|0)>>2]|0)==30){t[u>>2]=1538;break}if((t[(ii()|0)>>2]|0)==29){t[u>>2]=1539;break}if((t[(ii()|0)>>2]|0)==3){t[u>>2]=1540;break}if((t[(ii()|0)>>2]|0)==110){t[u>>2]=1541;break}if((t[(ii()|0)>>2]|0)==18){t[u>>2]=1542;break}if((t[(ii()|0)>>2]|0)==88){t[u>>2]=1550;break}if((t[(ii()|0)>>2]|0)==106){t[u>>2]=1551;break}if((t[(ii()|0)>>2]|0)==111){t[u>>2]=1552;break}if((t[(ii()|0)>>2]|0)==110){t[u>>2]=1541;break}if((t[(ii()|0)>>2]|0)==101){t[u>>2]=1553;break}if((t[(ii()|0)>>2]|0)==98){t[u>>2]=1554;break}if((t[(ii()|0)>>2]|0)==115){t[u>>2]=1513;break}if((t[(ii()|0)>>2]|0)==114){t[u>>2]=1555;break}if((t[(ii()|0)>>2]|0)==97){t[u>>2]=1556;break}else{t[u>>2]=1500;break}}while(0);t[o>>2]=0;if((t[u>>2]|0)>=1500)t[o>>2]=(t[u>>2]|0)-1500;if((t[o>>2]|0)>>>0<57){c=t[f>>2]|0;l=t[u>>2]|0;b=t[o>>2]|0;k=76128+(b<<2)|0;h=t[k>>2]|0;w=t[a>>2]|0;dp(c,l,0,h,w);s=n;return}t[o>>2]=0;c=t[f>>2]|0;l=t[u>>2]|0;b=t[o>>2]|0;k=76128+(b<<2)|0;h=t[k>>2]|0;w=t[a>>2]|0;dp(c,l,0,h,w);s=n;return}function EO(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0;n=s;s=s+48|0;f=n;u=n+32|0;a=n+28|0;o=n+24|0;c=n+20|0;l=n+16|0;b=n+12|0;k=n+8|0;h=n+4|0;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;t[c>>2]=t[u>>2];t[l>>2]=0;t[b>>2]=0;t[k>>2]=0;t[h>>2]=2;if(((t[c>>2]|0)!=0?(t[(t[c>>2]|0)+212>>2]|0)!=0:0)?(t[(t[c>>2]|0)+172>>2]|0)==-1:0){s=n;return}if((t[c>>2]|0)!=0?(t[t[c>>2]>>2]|0)!=0:0){u=t[t[c>>2]>>2]|0;if(t[(t[c>>2]|0)+104>>2]|0){t[b>>2]=t[u+88>>2];t[h>>2]=2}else{t[b>>2]=t[u+84>>2];t[h>>2]=1}if((t[(t[t[c>>2]>>2]|0)+108>>2]|0)==-554844497)t[l>>2]=t[(t[t[c>>2]>>2]|0)+124>>2];t[k>>2]=t[(t[c>>2]|0)+4>>2]}u=t[l>>2]|0;l=t[b>>2]|0;b=t[k>>2]|0;k=t[c>>2]|0;c=t[h>>2]|0;h=t[o>>2]|0;r=t[a>>2]|0;t[f>>2]=t[o>>2];cp(u,l,b,k,0,8,1549,c,0,0,h,0,0,0,0,r,f);s=n;return}function SO(){var e=0,i=0;e=s;s=s+16|0;i=e;if(!(t[19090]|0)){s=e;return}t[i>>2]=(t[19092]|0)-1;while(1){if((t[i>>2]|0)<0)break;t[76376+(t[i>>2]<<4)>>2]=0;t[76380+(t[i>>2]<<4)>>2]=0;t[76384+(t[i>>2]<<4)>>2]=0;t[76388+(t[i>>2]<<4)>>2]=0;t[i>>2]=(t[i>>2]|0)+-1}t[19092]=0;t[19090]=0;s=e;return}function gO(){var e=0,i=0;e=s;s=s+16|0;i=e;if(!(t[19154]|0)){s=e;return}t[i>>2]=(t[19156]|0)-1;while(1){if((t[i>>2]|0)<0)break;t[76632+(t[i>>2]<<4)>>2]=0;t[76636+(t[i>>2]<<4)>>2]=0;t[76640+(t[i>>2]<<4)>>2]=0;t[76644+(t[i>>2]<<4)>>2]=0;t[i>>2]=(t[i>>2]|0)+-1}t[19156]=0;t[19154]=0;s=e;return}function yO(e){e=e|0;var i=0,r=0,n=0,f=0;i=s;s=s+96|0;r=i+80|0;n=i+76|0;f=i;t[n>>2]=e;do if(t[n>>2]|0){if((ri(t[n>>2]|0,f|0)|0)==-1){t[r>>2]=0;break}if((t[f+12>>2]&61440|0)==16384){t[r>>2]=2;break}else{t[r>>2]=1;break}}else t[r>>2]=0;while(0);s=i;return t[r>>2]|0}function FO(){return 0}function OO(e){e=e|0;var i=0;i=s;s=s+16|0;t[i>>2]=e;s=i;return 1}function AO(e){e=e|0;var i=0,r=0,n=0,f=0,u=0;i=s;s=s+16|0;r=i+8|0;n=i+4|0;f=i;t[r>>2]=e;t[f>>2]=cA(t[r>>2]|0)|0;if(t[f>>2]|0){u=t[f>>2]|0;s=i;return u|0}t[n>>2]=VA(t[r>>2]|0,0,0)|0;if(!(t[n>>2]|0)){u=t[f>>2]|0;s=i;return u|0}t[f>>2]=cA(t[n>>2]|0)|0;pAi[t[135736>>2]&511](t[n>>2]|0);u=t[f>>2]|0;s=i;return u|0}function MO(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,l=0;n=s;s=s+32|0;f=n+16|0;u=n+12|0;a=n+8|0;o=n+4|0;c=n;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;if((t[u>>2]|0)==0|(t[a>>2]|0)==0){t[f>>2]=-1;l=t[f>>2]|0;s=n;return l|0}t[c>>2]=Re(t[a>>2]|0,1,t[o>>2]|0,t[u>>2]|0)|0;if((t[c>>2]|0)<0)lA(0,76872);t[f>>2]=t[c>>2];l=t[f>>2]|0;s=n;return l|0}function RO(e){e=e|0;var i=0,r=0,n=0,f=0,u=0,a=0;i=s;s=s+16|0;r=i+12|0;n=i+8|0;f=i+4|0;u=i;t[n>>2]=e;if(!(t[n>>2]|0)){t[r>>2]=-1;a=t[r>>2]|0;s=i;return a|0}t[f>>2]=t[n>>2];if((t[f>>2]|0)!=(t[_>>2]|0)?(t[f>>2]|0)!=(t[v>>2]|0):0){if((t[f>>2]|0)==(t[m>>2]|0)){t[r>>2]=0;a=t[r>>2]|0;s=i;return a|0}e=(Qe(t[n>>2]|0)|0)==-1;t[u>>2]=e?-1:0;if((t[u>>2]|0)<0)lA(0,76896);t[r>>2]=t[u>>2];a=t[r>>2]|0;s=i;return a|0}t[u>>2]=Pe(t[f>>2]|0)|0;if((t[u>>2]|0)<0)lA(0,76880);t[r>>2]=0;a=t[r>>2]|0;s=i;return a|0}function NO(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,u=0,a=0,o=0,c=0,l=0,b=0;f=s;s=s+32|0;u=f+16|0;a=f+12|0;o=f+8|0;c=f+4|0;l=f;t[a>>2]=e;t[o>>2]=i;t[c>>2]=r;t[l>>2]=n;if((t[19092]|0)>=15){t[u>>2]=-1;b=t[u>>2]|0;s=f;return b|0}else{t[76376+(t[19092]<<4)>>2]=t[a>>2];t[76380+(t[19092]<<4)>>2]=t[o>>2];t[76384+(t[19092]<<4)>>2]=t[c>>2];t[76388+(t[19092]<<4)>>2]=t[l>>2];t[19090]=1;l=t[19092]|0;t[19092]=l+1;t[u>>2]=l;b=t[u>>2]|0;s=f;return b|0}return 0}function TO(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,u=0,a=0,o=0,c=0,l=0,b=0;f=s;s=s+32|0;u=f+16|0;a=f+12|0;o=f+8|0;c=f+4|0;l=f;t[a>>2]=e;t[o>>2]=i;t[c>>2]=r;t[l>>2]=n;if((t[19156]|0)>=15){t[u>>2]=-1;b=t[u>>2]|0;s=f;return b|0}else{t[76632+(t[19156]<<4)>>2]=t[a>>2];t[76636+(t[19156]<<4)>>2]=t[o>>2];t[76640+(t[19156]<<4)>>2]=t[c>>2];t[76644+(t[19156]<<4)>>2]=t[l>>2];t[19154]=1;l=t[19156]|0;t[19156]=l+1;t[u>>2]=l;b=t[u>>2]|0;s=f;return b|0}return 0}function LO(){var e=0;e=s;if(t[19090]|0){s=e;return}NO(230,231,232,233)|0;t[19090]=1;s=e;return}function DO(){var e=0;e=s;if(t[19154]|0){s=e;return}TO(230,234,235,233)|0;t[19154]=1;s=e;return}function CO(e){e=e|0;var i=0,r=0,n=0,f=0,u=0,a=0;i=s;s=s+16|0;r=i+8|0;n=i+4|0;f=i;t[n>>2]=e;t[f>>2]=gAi[t[135744>>2]&511](36)|0;if(!(t[f>>2]|0)){kA(76912);t[r>>2]=0;u=t[r>>2]|0;s=i;return u|0}e=(t[f>>2]|0)+0|0;a=e+36|0;do{t[e>>2]=0;e=e+4|0}while((e|0)<(a|0));e=vs(t[33950]<<1)|0;t[(t[f>>2]|0)+16>>2]=e;if(!(t[(t[f>>2]|0)+16>>2]|0)){pAi[t[135736>>2]&511](t[f>>2]|0);t[r>>2]=0;u=t[r>>2]|0;s=i;return u|0}Es(t[(t[f>>2]|0)+16>>2]|0,0)|0;e=j_(t[n>>2]|0)|0;t[(t[f>>2]|0)+12>>2]=e;if(t[(t[f>>2]|0)+12>>2]|0){e=vs(t[33950]<<1)|0;t[(t[f>>2]|0)+20>>2]=e}else t[(t[f>>2]|0)+20>>2]=0;t[(t[f>>2]|0)+4>>2]=0;t[(t[f>>2]|0)+8>>2]=0;t[t[f>>2]>>2]=0;t[(t[f>>2]|0)+24>>2]=-1;t[(t[f>>2]|0)+32>>2]=0;t[r>>2]=t[f>>2];u=t[r>>2]|0;s=i;return u|0}function PO(e){e=e|0;var i=0,r=0,n=0,f=0,u=0;i=s;s=s+16|0;r=i+8|0;n=i+4|0;f=i;t[n>>2]=e;t[f>>2]=gAi[t[135744>>2]&511](32)|0;if(!(t[f>>2]|0)){kA(76936);t[r>>2]=0;u=t[r>>2]|0;s=i;return u|0}e=t[f>>2]|0;t[e+0>>2]=0;t[e+4>>2]=0;t[e+8>>2]=0;t[e+12>>2]=0;t[e+16>>2]=0;t[e+20>>2]=0;t[e+24>>2]=0;t[e+28>>2]=0;e=ds()|0;t[(t[f>>2]|0)+16>>2]=e;if(!(t[(t[f>>2]|0)+16>>2]|0)){pAi[t[135736>>2]&511](t[f>>2]|0);t[r>>2]=0;u=t[r>>2]|0;s=i;return u|0}if((ps(t[(t[f>>2]|0)+16>>2]|0)|0)==1)Es(t[(t[f>>2]|0)+16>>2]|0,0)|0;t[(t[f>>2]|0)+12>>2]=t[n>>2];do if(t[n>>2]|0){e=vs(4e3)|0;t[(t[f>>2]|0)+20>>2]=e;if(t[(t[f>>2]|0)+20>>2]|0){G_(t[f>>2]|0,1)|0;break}pAi[t[135736>>2]&511](t[f>>2]|0);t[r>>2]=0;u=t[r>>2]|0;s=i;return u|0}else t[(t[f>>2]|0)+20>>2]=0;while(0);t[(t[f>>2]|0)+4>>2]=0;t[(t[f>>2]|0)+8>>2]=0;t[t[f>>2]>>2]=0;t[(t[f>>2]|0)+24>>2]=0;t[r>>2]=t[f>>2];u=t[r>>2]|0;s=i;return u|0}function BO(e){e=e|0;var i=0,r=0,n=0,f=0,u=0;i=s;s=s+16|0;r=i+8|0;n=i+4|0;f=i;t[n>>2]=e;t[f>>2]=gAi[t[135744>>2]&511](32)|0;if(!(t[f>>2]|0)){kA(76936);t[r>>2]=0;u=t[r>>2]|0;s=i;return u|0}e=t[f>>2]|0;t[e+0>>2]=0;t[e+4>>2]=0;t[e+8>>2]=0;t[e+12>>2]=0;t[e+16>>2]=0;t[e+20>>2]=0;t[e+24>>2]=0;t[e+28>>2]=0;e=ds()|0;t[(t[f>>2]|0)+16>>2]=e;if(!(t[(t[f>>2]|0)+16>>2]|0)){pAi[t[135736>>2]&511](t[f>>2]|0);t[r>>2]=0;u=t[r>>2]|0;s=i;return u|0}Es(t[(t[f>>2]|0)+16>>2]|0,3)|0;t[(t[f>>2]|0)+12>>2]=t[n>>2];do if(t[n>>2]|0){e=vs(4e3)|0;t[(t[f>>2]|0)+20>>2]=e;if(t[(t[f>>2]|0)+20>>2]|0){G_(t[f>>2]|0,1)|0;break}pAi[t[135736>>2]&511](t[f>>2]|0);t[r>>2]=0;u=t[r>>2]|0;s=i;return u|0}else t[(t[f>>2]|0)+20>>2]=0;while(0);t[(t[f>>2]|0)+4>>2]=0;t[(t[f>>2]|0)+8>>2]=0;t[t[f>>2]>>2]=0;t[(t[f>>2]|0)+24>>2]=0;t[r>>2]=t[f>>2];u=t[r>>2]|0;s=i;return u|0}function IO(e){e=e|0;var i=0,r=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if(!(t[r>>2]|0)){s=i;return}if(t[(t[r>>2]|0)+20>>2]|0){Ss(t[(t[r>>2]|0)+20>>2]|0);t[(t[r>>2]|0)+20>>2]=0}if(t[(t[r>>2]|0)+12>>2]|0)W_(t[(t[r>>2]|0)+12>>2]|0)|0;if(t[(t[r>>2]|0)+8>>2]|0)gAi[t[(t[r>>2]|0)+8>>2]&511](t[t[r>>2]>>2]|0)|0;if(t[(t[r>>2]|0)+16>>2]|0){Ss(t[(t[r>>2]|0)+16>>2]|0);t[(t[r>>2]|0)+16>>2]=0}pAi[t[135736>>2]&511](t[r>>2]|0);s=i;return}function HO(e){e=e|0;var i=0,r=0,n=0,f=0,u=0,a=0;i=s;s=s+16|0;r=i+12|0;n=i+8|0;f=i+4|0;u=i;t[n>>2]=e;t[u>>2]=0;if(!(t[n>>2]|0)){t[r>>2]=-1;a=t[r>>2]|0;s=i;return a|0}if(t[(t[n>>2]|0)+4>>2]|0)xO(t[n>>2]|0)|0;if(t[(t[n>>2]|0)+8>>2]|0)t[u>>2]=gAi[t[(t[n>>2]|0)+8>>2]&511](t[t[n>>2]>>2]|0)|0;t[f>>2]=t[(t[n>>2]|0)+24>>2];if(t[(t[n>>2]|0)+20>>2]|0){Ss(t[(t[n>>2]|0)+20>>2]|0);t[(t[n>>2]|0)+20>>2]=0}if(t[(t[n>>2]|0)+12>>2]|0)W_(t[(t[n>>2]|0)+12>>2]|0)|0;if(t[(t[n>>2]|0)+16>>2]|0){Ss(t[(t[n>>2]|0)+16>>2]|0);t[(t[n>>2]|0)+16>>2]=0}if(t[(t[n>>2]|0)+28>>2]|0)t[u>>2]=-1;pAi[t[135736>>2]&511](t[n>>2]|0);t[r>>2]=(t[u>>2]|0)==0?t[f>>2]|0:t[u>>2]|0;a=t[r>>2]|0;s=i;return a|0}function xO(e){e=e|0;var i=0,r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0;i=s;s=s+16|0;r=i+12|0;n=i+8|0;f=i+4|0;u=i;t[n>>2]=e;t[f>>2]=0;t[u>>2]=0;if((t[n>>2]|0)!=0?(t[(t[n>>2]|0)+28>>2]|0)==0:0){e:do if((t[(t[n>>2]|0)+20>>2]|0)!=0?(t[(t[n>>2]|0)+12>>2]|0)!=0:0){while(1){t[f>>2]=G_(t[n>>2]|0,0)|0;if((t[f>>2]|0)<0)break;if(!(t[f>>2]|0))break e}lA(1544,0);t[(t[n>>2]|0)+28>>2]=1544;t[r>>2]=-1;a=t[r>>2]|0;s=i;return a|0}while(0);if(((t[(t[n>>2]|0)+20>>2]|0)!=0?(t[(t[n>>2]|0)+12>>2]|0)!=0:0)?(t[(t[n>>2]|0)+4>>2]|0)!=0:0){f=t[(t[n>>2]|0)+4>>2]|0;e=t[t[n>>2]>>2]|0;o=Os(t[(t[n>>2]|0)+20>>2]|0)|0;c=Ts(t[(t[n>>2]|0)+20>>2]|0)|0;t[u>>2]=dAi[f&511](e,o,c)|0;if((t[u>>2]|0)>=0)ys(t[(t[n>>2]|0)+20>>2]|0,t[u>>2]|0)|0}else l=14;if(((l|0)==14?(t[(t[n>>2]|0)+4>>2]|0)!=0:0)?(l=t[(t[n>>2]|0)+4>>2]|0,c=t[t[n>>2]>>2]|0,o=Os(t[(t[n>>2]|0)+16>>2]|0)|0,e=Ts(t[(t[n>>2]|0)+16>>2]|0)|0,t[u>>2]=dAi[l&511](c,o,e)|0,(t[u>>2]|0)>=0):0)ys(t[(t[n>>2]|0)+16>>2]|0,t[u>>2]|0)|0;if((t[u>>2]|0)<0){lA(1545,0);t[(t[n>>2]|0)+28>>2]=1545;t[r>>2]=t[u>>2];a=t[r>>2]|0;s=i;return a|0}else{e=(t[n>>2]|0)+24|0;t[e>>2]=(t[e>>2]|0)+(t[u>>2]|0);t[r>>2]=t[u>>2];a=t[r>>2]|0;s=i;return a|0}}t[r>>2]=-1;a=t[r>>2]|0;s=i;return a|0}function UO(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0;r=s;s=s+32|0;n=r+20|0;f=r+16|0;u=r+12|0;a=r+8|0;o=r+4|0;c=r;t[f>>2]=e;t[u>>2]=i;t[o>>2]=0;t[c>>2]=0;if(!(t[19090]|0))LO();if(!(t[f>>2]|0)){t[n>>2]=0;l=t[n>>2]|0;s=r;return l|0}e:do if(!(t[c>>2]|0)){t[o>>2]=(t[19092]|0)-1;while(1){if((t[o>>2]|0)<0)break e;if(((t[76376+(t[o>>2]<<4)>>2]|0)!=0?(gAi[t[76376+(t[o>>2]<<4)>>2]&511](t[f>>2]|0)|0)!=0:0)?(t[c>>2]=gAi[t[76376+(t[o>>2]<<4)+4>>2]&511](t[f>>2]|0)|0,(t[c>>2]|0)!=0):0)break e;t[o>>2]=(t[o>>2]|0)+-1}}while(0);if(!(t[c>>2]|0)){t[n>>2]=0;l=t[n>>2]|0;s=r;return l|0}t[a>>2]=CO(t[u>>2]|0)|0;if(t[a>>2]|0){t[t[a>>2]>>2]=t[c>>2];t[(t[a>>2]|0)+4>>2]=t[76384+(t[o>>2]<<4)>>2];t[(t[a>>2]|0)+8>>2]=t[76388+(t[o>>2]<<4)>>2]}else gAi[t[76376+(t[o>>2]<<4)+12>>2]&511](t[c>>2]|0)|0;t[n>>2]=t[a>>2];l=t[n>>2]|0;s=r;return l|0}function zO(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0;r=s;s=s+16|0;n=r+8|0;f=r+4|0;u=r;t[f>>2]=e;t[u>>2]=i;if(t[33972]|0){t[n>>2]=MAi[t[135888>>2]&511](t[f>>2]|0,t[u>>2]|0)|0;a=t[n>>2]|0;s=r;return a|0}else{t[n>>2]=UO(t[f>>2]|0,t[u>>2]|0)|0;a=t[n>>2]|0;s=r;return a|0}return 0}function jO(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0;n=s;s=s+48|0;f=n+32|0;u=n+28|0;a=n+24|0;o=n+16|0;c=n+12|0;l=n+8|0;b=n+4|0;k=n;t[u>>2]=e;t[a>>2]=i;t[n+20>>2]=r;t[l>>2]=0;t[b>>2]=0;t[k>>2]=0;if(!(t[19154]|0))DO();if(!(t[u>>2]|0)){t[f>>2]=0;h=t[f>>2]|0;s=n;return h|0}t[c>>2]=IA(t[u>>2]|0)|0;if(t[c>>2]|0){if(!((t[t[c>>2]>>2]|0)!=0?(Xl(t[t[c>>2]>>2]|0,76960)|0)==0:0))t[k>>2]=VA(t[u>>2]|0,0,0)|0;xA(t[c>>2]|0)}if(t[k>>2]|0){t[l>>2]=(t[19156]|0)-1;while(1){if((t[l>>2]|0)<0)break;if(((t[76632+(t[l>>2]<<4)>>2]|0)!=0?(gAi[t[76632+(t[l>>2]<<4)>>2]&511](t[k>>2]|0)|0)!=0:0)?(t[b>>2]=gAi[t[76632+(t[l>>2]<<4)+4>>2]&511](t[k>>2]|0)|0,(t[b>>2]|0)!=0):0)break;t[l>>2]=(t[l>>2]|0)+-1}pAi[t[135736>>2]&511](t[k>>2]|0)}e:do if(!(t[b>>2]|0)){t[l>>2]=(t[19156]|0)-1;while(1){if((t[l>>2]|0)<0)break e;if(((t[76632+(t[l>>2]<<4)>>2]|0)!=0?(gAi[t[76632+(t[l>>2]<<4)>>2]&511](t[u>>2]|0)|0)!=0:0)?(t[b>>2]=gAi[t[76632+(t[l>>2]<<4)+4>>2]&511](t[u>>2]|0)|0,(t[b>>2]|0)!=0):0)break e;t[l>>2]=(t[l>>2]|0)+-1}}while(0);if(!(t[b>>2]|0)){t[f>>2]=0;h=t[f>>2]|0;s=n;return h|0}t[o>>2]=BO(t[a>>2]|0)|0;if(t[o>>2]|0){t[t[o>>2]>>2]=t[b>>2];t[(t[o>>2]|0)+4>>2]=t[76640+(t[l>>2]<<4)>>2];t[(t[o>>2]|0)+8>>2]=t[76644+(t[l>>2]<<4)>>2]}t[f>>2]=t[o>>2];h=t[f>>2]|0;s=n;return h|0}function VO(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0;n=s;s=s+16|0;f=n+12|0;u=n+8|0;a=n+4|0;o=n;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;if(t[33974]|0){t[f>>2]=dAi[t[135896>>2]&511](t[u>>2]|0,t[a>>2]|0,t[o>>2]|0)|0;c=t[f>>2]|0;s=n;return c|0}else{t[f>>2]=jO(t[u>>2]|0,t[a>>2]|0,t[o>>2]|0)|0;c=t[f>>2]|0;s=n;return c|0}return 0}function qO(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0;r=s;s=s+16|0;n=r+12|0;f=r+8|0;u=r+4|0;a=r;t[f>>2]=e;t[u>>2]=i;if(!(t[19154]|0))DO();if(!(t[f>>2]|0)){t[n>>2]=0;o=t[n>>2]|0;s=r;return o|0}t[a>>2]=BO(t[u>>2]|0)|0;if(t[a>>2]|0){t[t[a>>2]>>2]=t[f>>2];t[(t[a>>2]|0)+4>>2]=235;t[(t[a>>2]|0)+8>>2]=236}t[n>>2]=t[a>>2];o=t[n>>2]|0;s=r;return o|0}function YO(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0;r=s;s=s+16|0;n=r+12|0;f=r+8|0;u=r+4|0;a=r;t[f>>2]=e;t[u>>2]=i;if((t[f>>2]|0)<0){t[n>>2]=0;o=t[n>>2]|0;s=r;return o|0}t[a>>2]=CO(t[u>>2]|0)|0;if(t[a>>2]|0){t[t[a>>2]>>2]=t[f>>2];t[(t[a>>2]|0)+4>>2]=237;t[(t[a>>2]|0)+8>>2]=238}t[n>>2]=t[a>>2];o=t[n>>2]|0;s=r;return o|0}function GO(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0;n=s;s=s+32|0;f=n+20|0;u=n+16|0;a=n+12|0;o=n+8|0;c=n+4|0;l=n;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;if((t[a>>2]|0)<=0){t[f>>2]=0;b=t[f>>2]|0;s=n;return b|0}if(!(t[u>>2]|0)){t[f>>2]=0;b=t[f>>2]|0;s=n;return b|0}t[c>>2]=CO(t[o>>2]|0)|0;if((t[c>>2]|0)!=0?(t[t[c>>2]>>2]=t[u>>2],t[(t[c>>2]|0)+4>>2]=227,t[(t[c>>2]|0)+8>>2]=0,t[l>>2]=Ps(t[(t[c>>2]|0)+16>>2]|0,t[u>>2]|0,t[a>>2]|0)|0,(t[l>>2]|0)!=0):0){pAi[t[135736>>2]&511](t[c>>2]|0);t[f>>2]=0;b=t[f>>2]|0;s=n;return b|0}t[f>>2]=t[c>>2];b=t[f>>2]|0;s=n;return b|0}function WO(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,l=0;n=s;s=s+32|0;f=n+16|0;u=n+12|0;a=n+8|0;o=n+4|0;c=n;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;if((t[a>>2]|0)<=0){t[f>>2]=0;l=t[f>>2]|0;s=n;return l|0}if(!(t[u>>2]|0)){t[f>>2]=0;l=t[f>>2]|0;s=n;return l|0}t[c>>2]=gAi[t[135744>>2]&511](36)|0;if(!(t[c>>2]|0)){kA(76912);t[f>>2]=0;l=t[f>>2]|0;s=n;return l|0}r=(t[c>>2]|0)+0|0;i=r+36|0;do{t[r>>2]=0;r=r+4|0}while((r|0)<(i|0));r=_s(t[u>>2]|0,t[a>>2]|0)|0;t[(t[c>>2]|0)+16>>2]=r;if(!(t[(t[c>>2]|0)+16>>2]|0)){pAi[t[135736>>2]&511](t[c>>2]|0);t[f>>2]=0;l=t[f>>2]|0;s=n;return l|0}r=j_(t[o>>2]|0)|0;t[(t[c>>2]|0)+12>>2]=r;if(t[(t[c>>2]|0)+12>>2]|0){r=vs(t[33950]<<1)|0;t[(t[c>>2]|0)+20>>2]=r}else t[(t[c>>2]|0)+20>>2]=0;t[(t[c>>2]|0)+24>>2]=-1;t[t[c>>2]>>2]=t[u>>2];t[(t[c>>2]|0)+4>>2]=0;t[(t[c>>2]|0)+8>>2]=0;t[f>>2]=t[c>>2];l=t[f>>2]|0;s=n;return l|0}function KO(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0;r=s;s=s+16|0;n=r+12|0;f=r+8|0;u=r+4|0;a=r;t[f>>2]=e;t[u>>2]=i;if((t[f>>2]|0)<0){t[n>>2]=0;o=t[n>>2]|0;s=r;return o|0}t[a>>2]=BO(t[u>>2]|0)|0;if(t[a>>2]|0){t[t[a>>2]>>2]=t[f>>2];t[(t[a>>2]|0)+4>>2]=239;t[(t[a>>2]|0)+8>>2]=0}t[n>>2]=t[a>>2];o=t[n>>2]|0;s=r;return o|0}function XO(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0;f=s;s=s+32|0;u=f+20|0;a=f+16|0;o=f+12|0;c=f+8|0;l=f+4|0;b=f;t[a>>2]=e;t[o>>2]=i;t[c>>2]=r;t[l>>2]=n;if(!(t[a>>2]|0)){t[u>>2]=0;k=t[u>>2]|0;s=f;return k|0}t[b>>2]=CO(t[l>>2]|0)|0;if(t[b>>2]|0){t[t[b>>2]>>2]=t[c>>2];t[(t[b>>2]|0)+4>>2]=t[a>>2];t[(t[b>>2]|0)+8>>2]=t[o>>2]}t[u>>2]=t[b>>2];k=t[u>>2]|0;s=f;return k|0}function ZO(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0;n=s;s=s+32|0;f=n+24|0;u=n+20|0;a=n+16|0;o=n+12|0;c=n+8|0;l=n+4|0;b=n;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;t[c>>2]=0;if((t[a>>2]|0)<0){t[f>>2]=0;k=t[f>>2]|0;s=n;return k|0}if((t[u>>2]|0)!=0?(t[(t[u>>2]|0)+28>>2]|0)==0:0){do if(!(t[(t[u>>2]|0)+12>>2]|0)){t[c>>2]=t[a>>2];t[l>>2]=Ps(t[(t[u>>2]|0)+16>>2]|0,t[o>>2]|0,t[c>>2]|0)|0;if(t[l>>2]|0){t[f>>2]=-1;k=t[f>>2]|0;s=n;return k|0}}else{if(!(t[(t[u>>2]|0)+20>>2]|0)){r=ds()|0;t[(t[u>>2]|0)+20>>2]=r}t[l>>2]=Ps(t[(t[u>>2]|0)+20>>2]|0,t[o>>2]|0,t[a>>2]|0)|0;
	if(t[l>>2]|0){t[f>>2]=-1;k=t[f>>2]|0;s=n;return k|0}t[b>>2]=Ts(t[(t[u>>2]|0)+20>>2]|0)|0;t[c>>2]=Y_(t[u>>2]|0,1)|0;if((t[c>>2]|0)>=0){r=t[b>>2]|0;i=r-(Ts(t[(t[u>>2]|0)+20>>2]|0)|0)|0;r=(t[u>>2]|0)+32|0;t[r>>2]=(t[r>>2]|0)+i;break}lA(1544,0);t[(t[u>>2]|0)+28>>2]=1544;t[f>>2]=-1;k=t[f>>2]|0;s=n;return k|0}while(0);t[f>>2]=t[c>>2];k=t[f>>2]|0;s=n;return k|0}t[f>>2]=-1;k=t[f>>2]|0;s=n;return k|0}function JO(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0;r=s;s=s+32|0;n=r+24|0;f=r+20|0;u=r+16|0;a=r+12|0;o=r+8|0;c=r+4|0;l=r;t[f>>2]=e;t[u>>2]=i;t[a>>2]=0;t[o>>2]=0;t[c>>2]=0;if((t[f>>2]|0)!=0?(t[(t[f>>2]|0)+28>>2]|0)==0:0){if((t[u>>2]|0)<=4e3&(t[u>>2]|0)!=4)t[u>>2]=4e3;if((Ls(t[(t[f>>2]|0)+16>>2]|0)|0)>>>0<=0){lA(1548,0);t[(t[f>>2]|0)+28>>2]=1548;t[n>>2]=-1;b=t[n>>2]|0;s=r;return b|0}if((Fs(t[(t[f>>2]|0)+16>>2]|0,(t[u>>2]|0)+1|0)|0)<0){kA(76968);t[(t[f>>2]|0)+28>>2]=2;t[n>>2]=-1;b=t[n>>2]|0;s=r;return b|0}t[a>>2]=As(t[(t[f>>2]|0)+16>>2]|0)|0;if(!(t[(t[f>>2]|0)+4>>2]|0)){lA(1547,0);t[(t[f>>2]|0)+28>>2]=1547;t[n>>2]=-1;b=t[n>>2]|0;s=r;return b|0}t[o>>2]=dAi[t[(t[f>>2]|0)+4>>2]&511](t[t[f>>2]>>2]|0,t[a>>2]|0,t[u>>2]|0)|0;if((t[o>>2]|0)<=0)t[(t[f>>2]|0)+4>>2]=240;if((t[o>>2]|0)<0){t[n>>2]=-1;b=t[n>>2]|0;s=r;return b|0}t[u>>2]=t[o>>2];do if(t[(t[f>>2]|0)+12>>2]|0){if(!(t[(t[f>>2]|0)+20>>2]|0)){i=ds()|0;t[(t[f>>2]|0)+20>>2]=i}t[o>>2]=Ps(t[(t[f>>2]|0)+20>>2]|0,t[a>>2]|0,t[u>>2]|0)|0;if(t[o>>2]|0){t[n>>2]=-1;b=t[n>>2]|0;s=r;return b|0}t[l>>2]=Ts(t[(t[f>>2]|0)+20>>2]|0)|0;t[c>>2]=Y_(t[f>>2]|0,1)|0;if((t[c>>2]|0)>=0){i=t[l>>2]|0;e=i-(Ts(t[(t[f>>2]|0)+20>>2]|0)|0)|0;i=(t[f>>2]|0)+32|0;t[i>>2]=(t[i>>2]|0)+e;break}lA(1544,0);t[(t[f>>2]|0)+28>>2]=1544;t[n>>2]=-1;b=t[n>>2]|0;s=r;return b|0}else{t[c>>2]=t[u>>2];Ms(t[(t[f>>2]|0)+16>>2]|0,t[c>>2]|0)|0}while(0);t[n>>2]=t[c>>2];b=t[n>>2]|0;s=r;return b|0}t[n>>2]=-1;b=t[n>>2]|0;s=r;return b|0}function QO(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0;r=s;s=s+16|0;n=r+8|0;f=r+4|0;u=r;t[f>>2]=e;t[u>>2]=i;do if((t[f>>2]|0)!=0?(t[(t[f>>2]|0)+28>>2]|0)==0:0){i=t[f>>2]|0;if(t[(t[f>>2]|0)+4>>2]|0){t[n>>2]=JO(i,t[u>>2]|0)|0;break}if((ps(t[i+16>>2]|0)|0)==2){t[n>>2]=0;break}else{t[n>>2]=-1;break}}else a=3;while(0);if((a|0)==3)t[n>>2]=-1;s=r;return t[n>>2]|0}function $O(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0;n=s;s=s+32|0;f=n+28|0;u=n+24|0;a=n+20|0;o=n+16|0;c=n+12|0;l=n+8|0;b=n+4|0;k=n;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;t[c>>2]=0;t[b>>2]=0;if((t[u>>2]|0)!=0?(t[(t[u>>2]|0)+28>>2]|0)==0:0){if((t[a>>2]|0)<0){t[f>>2]=0;h=t[f>>2]|0;s=n;return h|0}if(t[(t[u>>2]|0)+28>>2]|0){t[f>>2]=-1;h=t[f>>2]|0;s=n;return h|0}while(1){r=t[a>>2]|0;t[k>>2]=r;t[k>>2]=(t[k>>2]|0)>16e3?16e3:r;r=t[u>>2]|0;if(t[(t[u>>2]|0)+12>>2]|0){if(!(t[r+20>>2]|0)){i=ds()|0;t[(t[u>>2]|0)+20>>2]=i}t[l>>2]=Ps(t[(t[u>>2]|0)+16>>2]|0,t[o>>2]|0,t[k>>2]|0)|0;if(t[l>>2]|0){w=12;break}if((Ts(t[(t[u>>2]|0)+16>>2]|0)|0)>>>0<4e3?(t[k>>2]|0)==(t[a>>2]|0):0){w=32;break}t[l>>2]=G_(t[u>>2]|0,0)|0;if((t[l>>2]|0)<0&(t[l>>2]|0)!=-3){w=16;break}t[c>>2]=Ts(t[(t[u>>2]|0)+20>>2]|0)|0}else{t[l>>2]=Ps(t[r+16>>2]|0,t[o>>2]|0,t[k>>2]|0)|0;if(t[l>>2]|0){w=19;break}t[c>>2]=Ts(t[(t[u>>2]|0)+16>>2]|0)|0}t[o>>2]=(t[o>>2]|0)+(t[k>>2]|0);t[a>>2]=(t[a>>2]|0)-(t[k>>2]|0);if((t[c>>2]|0)<4e3&(t[a>>2]|0)<=0){w=32;break}if(t[(t[u>>2]|0)+4>>2]|0){r=t[(t[u>>2]|0)+4>>2]|0;i=t[t[u>>2]>>2]|0;e=t[u>>2]|0;if(t[(t[u>>2]|0)+12>>2]|0){d=Os(t[e+20>>2]|0)|0;t[l>>2]=dAi[r&511](i,d,t[c>>2]|0)|0;if((t[l>>2]|0)>=0)ys(t[(t[u>>2]|0)+20>>2]|0,t[l>>2]|0)|0}else{d=Os(t[e+16>>2]|0)|0;t[l>>2]=dAi[r&511](i,d,t[c>>2]|0)|0;if((t[l>>2]|0)>=0)ys(t[(t[u>>2]|0)+16>>2]|0,t[l>>2]|0)|0}if((t[l>>2]|0)<0){w=29;break}d=(t[u>>2]|0)+24|0;t[d>>2]=(t[d>>2]|0)+(t[l>>2]|0)}t[b>>2]=(t[b>>2]|0)+(t[c>>2]|0);if((t[a>>2]|0)<=0){w=32;break}}if((w|0)==12){t[f>>2]=-1;h=t[f>>2]|0;s=n;return h|0}else if((w|0)==16){lA(1544,0);t[(t[u>>2]|0)+28>>2]=1544;t[f>>2]=-1;h=t[f>>2]|0;s=n;return h|0}else if((w|0)==19){t[f>>2]=-1;h=t[f>>2]|0;s=n;return h|0}else if((w|0)==29){lA(1546,0);t[(t[u>>2]|0)+28>>2]=1546;t[f>>2]=t[l>>2];h=t[f>>2]|0;s=n;return h|0}else if((w|0)==32){t[f>>2]=t[b>>2];h=t[f>>2]|0;s=n;return h|0}}t[f>>2]=-1;h=t[f>>2]|0;s=n;return h|0}function eA(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0;n=s;s=s+48|0;f=n+40|0;u=n+36|0;a=n+32|0;o=n+28|0;c=n+24|0;l=n+20|0;b=n+16|0;k=n+12|0;h=n+8|0;w=n+4|0;d=n;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;t[c>>2]=0;t[b>>2]=0;t[k>>2]=0;if((((t[u>>2]|0)!=0?!((t[a>>2]|0)==0?1:(t[(t[u>>2]|0)+28>>2]|0)!=0):0)?(t[(t[u>>2]|0)+16>>2]|0)!=0:0)?(ps(t[(t[u>>2]|0)+16>>2]|0)|0)!=2:0){t[w>>2]=HY(t[a>>2]|0)|0;if((t[w>>2]|0)<0){t[f>>2]=0;v=t[f>>2]|0;s=n;return v|0}if(t[(t[u>>2]|0)+28>>2]|0){t[f>>2]=-1;v=t[f>>2]|0;s=n;return v|0}if(!(t[o>>2]|0))t[o>>2]=241;while(1){t[k>>2]=t[b>>2];t[d>>2]=t[w>>2];t[h>>2]=(Ls(t[(t[u>>2]|0)+16>>2]|0)|0)-1;r=t[u>>2]|0;if((t[h>>2]|0)<40){if((Fs(t[r+16>>2]|0,100)|0)<0){m=14;break}t[k>>2]=-1}else{if(t[r+12>>2]|0){if(!(t[(t[u>>2]|0)+20>>2]|0)){r=ds()|0;t[(t[u>>2]|0)+20>>2]=r}r=t[o>>2]|0;i=As(t[(t[u>>2]|0)+16>>2]|0)|0;t[l>>2]=OAi[r&511](i,h,t[a>>2]|0,d)|0;if((t[l>>2]|0)<0|(t[h>>2]|0)==0){m=20;break}Ms(t[(t[u>>2]|0)+16>>2]|0,t[h>>2]|0)|0;if((Ts(t[(t[u>>2]|0)+16>>2]|0)|0)>>>0<4e3?(t[d>>2]|0)==(t[w>>2]|0):0){m=44;break}t[l>>2]=G_(t[u>>2]|0,0)|0;if((t[l>>2]|0)<0&(t[l>>2]|0)!=-3){m=24;break}t[c>>2]=Ts(t[(t[u>>2]|0)+20>>2]|0)|0}else{i=t[o>>2]|0;r=As(t[(t[u>>2]|0)+16>>2]|0)|0;t[l>>2]=OAi[i&511](r,h,t[a>>2]|0,d)|0;if((t[l>>2]|0)<0|(t[h>>2]|0)==0){m=27;break}Ms(t[(t[u>>2]|0)+16>>2]|0,t[h>>2]|0)|0;t[c>>2]=Ts(t[(t[u>>2]|0)+16>>2]|0)|0}t[a>>2]=(t[a>>2]|0)+(t[d>>2]|0);t[w>>2]=(t[w>>2]|0)-(t[d>>2]|0);if((t[c>>2]|0)<4e3&(t[w>>2]|0)<=0){m=44;break}r=t[u>>2]|0;if(!(t[(t[u>>2]|0)+4>>2]|0)){if((Ls(t[r+16>>2]|0)|0)>>>0<4e3)Fs(t[(t[u>>2]|0)+16>>2]|0,4e3)|0}else{i=t[(t[u>>2]|0)+4>>2]|0;e=t[t[u>>2]>>2]|0;_=t[u>>2]|0;if(t[r+12>>2]|0){r=Os(t[_+20>>2]|0)|0;t[l>>2]=dAi[i&511](e,r,t[c>>2]|0)|0;if((t[l>>2]|0)>=0)ys(t[(t[u>>2]|0)+20>>2]|0,t[l>>2]|0)|0}else{r=Os(t[_+16>>2]|0)|0;t[l>>2]=dAi[i&511](e,r,t[c>>2]|0)|0;if((t[l>>2]|0)>=0)ys(t[(t[u>>2]|0)+16>>2]|0,t[l>>2]|0)|0}if((t[l>>2]|0)<0){m=37;break}r=(t[u>>2]|0)+24|0;t[r>>2]=(t[r>>2]|0)+(t[l>>2]|0)}t[b>>2]=(t[b>>2]|0)+(t[c>>2]|0)}if((t[w>>2]|0)<=0){m=44;break}if((t[k>>2]|0)==(t[b>>2]|0)){m=44;break}}if((m|0)==14){t[f>>2]=-1;v=t[f>>2]|0;s=n;return v|0}else if((m|0)==20){t[f>>2]=-1;v=t[f>>2]|0;s=n;return v|0}else if((m|0)==24){lA(1544,0);t[(t[u>>2]|0)+28>>2]=1544;t[f>>2]=-1;v=t[f>>2]|0;s=n;return v|0}else if((m|0)==27){t[f>>2]=-1;v=t[f>>2]|0;s=n;return v|0}else if((m|0)==37){lA(1546,0);t[(t[u>>2]|0)+28>>2]=1546;t[f>>2]=t[l>>2];v=t[f>>2]|0;s=n;return v|0}else if((m|0)==44){t[f>>2]=t[b>>2];v=t[f>>2]|0;s=n;return v|0}}t[f>>2]=-1;v=t[f>>2]|0;s=n;return v|0}function iA(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0;r=s;s=s+16|0;n=r+12|0;f=r+8|0;u=r+4|0;a=r;t[f>>2]=e;t[u>>2]=i;do if((t[f>>2]|0)!=0?(t[(t[f>>2]|0)+28>>2]|0)==0:0){if(!(t[u>>2]|0)){t[n>>2]=-1;break}t[a>>2]=HY(t[u>>2]|0)|0;if((t[a>>2]|0)>0){t[n>>2]=$O(t[f>>2]|0,t[a>>2]|0,t[u>>2]|0)|0;break}else{t[n>>2]=t[a>>2];break}}else o=3;while(0);if((o|0)==3)t[n>>2]=-1;s=r;return t[n>>2]|0}function rA(e){e=e|0;var i=0,r=0,f=0,u=0,a=0,o=0,c=0;i=s;s=s+1040|0;r=i+12|0;f=i+8|0;u=i+4|0;a=i+16|0;o=i;t[f>>2]=e;t[u>>2]=0;if(!(t[19090]|0))LO();if(!(t[f>>2]|0)){t[r>>2]=0;c=t[r>>2]|0;s=i;return c|0}zY(a|0,t[f>>2]|0,1023)|0;n[a+1023>>0]=0;t[o>>2]=a+(HY(a|0)|0);while(1){if((t[o>>2]|0)>>>0<=a>>>0)break;if((n[t[o>>2]>>0]|0)==47)break;t[o>>2]=(t[o>>2]|0)+-1}if((n[t[o>>2]>>0]|0)!=47){if(Me(a|0,1024)|0){n[a+1023>>0]=0;t[u>>2]=gAi[t[135768>>2]&511](a)|0}}else{if((t[o>>2]|0)==(a|0))n[a+1>>0]=0;else n[t[o>>2]>>0]=0;t[u>>2]=gAi[t[135768>>2]&511](a)|0}t[r>>2]=t[u>>2];c=t[r>>2]|0;s=i;return c|0}function nA(e,i){e=e|0;i=i|0;var r=0,n=0;r=s;s=s+16|0;n=r;t[r+4>>2]=e;t[n>>2]=i;s=r;return t[n>>2]|0}function fA(e){e=e|0;var i=0,r=0;i=s;s=s+16|0;r=i;t[r>>2]=e;t[19248]=t[r>>2];s=i;return}function tA(){return t[19248]|0}function uA(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0;n=s;s=s+32|0;f=n+20|0;u=n+16|0;a=n+12|0;o=n+8|0;c=n+4|0;l=n;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;if((t[u>>2]|0)!=0?(pA(t[u>>2]|0)|0)==0:0){t[c>>2]=KA(t[u>>2]|0)|0;if(!(t[c>>2]|0)){kA(77e3);t[f>>2]=0;b=t[f>>2]|0;s=n;return b|0}else{t[l>>2]=dAi[t[76992>>2]&511](t[c>>2]|0,t[a>>2]|0,t[o>>2]|0)|0;pAi[t[135736>>2]&511](t[c>>2]|0);t[f>>2]=t[l>>2];b=t[f>>2]|0;s=n;return b|0}}t[f>>2]=dAi[t[76992>>2]&511](t[u>>2]|0,t[a>>2]|0,t[o>>2]|0)|0;b=t[f>>2]|0;s=n;return b|0}function aA(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0;n=s;s=s+32|0;f=n+20|0;u=n+16|0;a=n+12|0;o=n+8|0;c=n+4|0;l=n;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;t[c>>2]=0;t[l>>2]=0;t[l>>2]=EA(t[u>>2]|0,t[a>>2]|0,t[o>>2]|0)|0;if(!(t[l>>2]|0))t[l>>2]=t[u>>2];do if(t[l>>2]|0){if(($l(t[l>>2]|0,77032,6)|0)!=0?($l(t[l>>2]|0,77040,7)|0)!=0:0)break;lA(1543,t[l>>2]|0);if((t[l>>2]|0)!=(t[u>>2]|0))pAi[t[135736>>2]&511](t[l>>2]|0);t[f>>2]=0;b=t[f>>2]|0;s=n;return b|0}while(0);t[c>>2]=oA(t[l>>2]|0,t[a>>2]|0,t[o>>2]|0)|0;if((t[l>>2]|0)!=(t[u>>2]|0))pAi[t[135736>>2]&511](t[l>>2]|0);t[f>>2]=t[c>>2];b=t[f>>2]|0;s=n;return b|0}function oA(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0;n=s;s=s+32|0;f=n+24|0;u=n+20|0;a=n+16|0;o=n+12|0;c=n+8|0;l=n+4|0;b=n;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;t[c>>2]=0;t[l>>2]=0;if((t[o>>2]|0)!=0?(t[(t[o>>2]|0)+360>>2]&2048|0)!=0:0){t[b>>2]=t[(t[o>>2]|0)+360>>2];r=(t[o>>2]|0)+360|0;t[r>>2]=(t[r>>2]|0)-2048;t[c>>2]=aA(t[u>>2]|0,t[a>>2]|0,t[o>>2]|0)|0;t[(t[o>>2]|0)+360>>2]=t[b>>2];t[f>>2]=t[c>>2];k=t[f>>2]|0;s=n;return k|0}t[l>>2]=EA(t[u>>2]|0,t[a>>2]|0,t[o>>2]|0)|0;if(!(t[l>>2]|0))t[l>>2]=t[u>>2];if(!(t[l>>2]|0)){if(!(t[a>>2]|0))t[a>>2]=77048;EO(t[o>>2]|0,77056,t[a>>2]|0);t[f>>2]=0;k=t[f>>2]|0;s=n;return k|0}t[c>>2]=Ip(t[o>>2]|0,t[l>>2]|0)|0;if((t[l>>2]|0)!=0?(t[l>>2]|0)!=(t[u>>2]|0):0)pAi[t[135736>>2]&511](t[l>>2]|0);t[f>>2]=t[c>>2];k=t[f>>2]|0;s=n;return k|0}function cA(e){e=e|0;var i=0,r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0;i=s;s=s+16|0;r=i+12|0;n=i+8|0;f=i+4|0;u=i;t[n>>2]=e;t[f>>2]=t[n>>2];if(!(t[n>>2]|0)){t[r>>2]=0;a=t[r>>2]|0;s=i;return a|0}if(!(MY(t[n>>2]|0,77176)|0)){t[u>>2]=t[m>>2];t[r>>2]=t[u>>2];a=t[r>>2]|0;s=i;return a|0}e=($l(t[n>>2]|0,77096,17)|0)!=0;o=t[n>>2]|0;do if(e){c=($l(o,77120,8)|0)!=0;l=t[n>>2]|0;if(!c){t[f>>2]=l+7;break}if(!($l(l,77192,6)|0))t[f>>2]=(t[n>>2]|0)+5}else t[f>>2]=o+16;while(0);if(!(yO(t[f>>2]|0)|0)){t[r>>2]=0;a=t[r>>2]|0;s=i;return a|0}t[u>>2]=mi(t[f>>2]|0,77200)|0;if(!(t[u>>2]|0))lA(0,t[f>>2]|0);t[r>>2]=t[u>>2];a=t[r>>2]|0;s=i;return a|0}function lA(e,i){e=e|0;i=i|0;var r=0,n=0,f=0;r=s;s=s+16|0;n=r+4|0;f=r;t[n>>2]=e;t[f>>2]=i;pO(8,t[n>>2]|0,t[f>>2]|0);s=r;return}function sA(e){e=e|0;var i=0,r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0;i=s;s=s+16|0;r=i+12|0;n=i+8|0;f=i+4|0;u=i;t[n>>2]=e;t[f>>2]=0;if(!(MY(t[n>>2]|0,77176)|0)){t[u>>2]=t[_>>2];t[r>>2]=t[u>>2];a=t[r>>2]|0;s=i;return a|0}e=($l(t[n>>2]|0,77096,17)|0)!=0;o=t[n>>2]|0;do if(e){c=($l(o,77120,8)|0)!=0;l=t[n>>2]|0;if(c){t[f>>2]=l;break}else{t[f>>2]=l+7;break}}else t[f>>2]=o+16;while(0);if(!(t[f>>2]|0)){t[r>>2]=0;a=t[r>>2]|0;s=i;return a|0}t[u>>2]=mi(t[f>>2]|0,77184)|0;if(!(t[u>>2]|0))lA(0,t[f>>2]|0);t[r>>2]=t[u>>2];a=t[r>>2]|0;s=i;return a|0}function bA(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,l=0;n=s;s=s+32|0;f=n+16|0;u=n+12|0;a=n+8|0;o=n+4|0;c=n;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;if((t[u>>2]|0)==0|(t[a>>2]|0)==0){t[f>>2]=-1;l=t[f>>2]|0;s=n;return l|0}t[c>>2]=si(t[a>>2]|0,t[o>>2]|0,1,t[u>>2]|0)|0;if((t[c>>2]|0)==0?(We(t[u>>2]|0)|0)!=0:0){lA(0,77160);t[f>>2]=-1;l=t[f>>2]|0;s=n;return l|0}t[f>>2]=te(t[c>>2]|0,t[o>>2]|0)|0;l=t[f>>2]|0;s=n;return l|0}function kA(e){e=e|0;var i=0,r=0;i=s;s=s+16|0;r=i;t[r>>2]=e;dp(8,2,0,0,t[r>>2]|0);s=i;return}function hA(e){e=e|0;var i=0,r=0,n=0,f=0,u=0;i=s;s=s+16|0;r=i+8|0;n=i+4|0;f=i;t[n>>2]=e;if(!(t[n>>2]|0)){t[r>>2]=-1;u=t[r>>2]|0;s=i;return u|0}e=(Pe(t[n>>2]|0)|0)==-1;t[f>>2]=e?-1:0;if((t[f>>2]|0)<0)lA(0,76880);t[r>>2]=t[f>>2];u=t[r>>2]|0;s=i;return u|0}function wA(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0;n=s;s=s+16|0;f=n+12|0;u=n+8|0;a=n+4|0;o=n;t[f>>2]=e;t[u>>2]=i;t[a>>2]=r;t[o>>2]=ai(t[f>>2]|0,t[u>>2]|0,t[a>>2]|0)|0;if((t[o>>2]|0)>=0){c=t[o>>2]|0;s=n;return c|0}lA(0,77152);c=t[o>>2]|0;s=n;return c|0}function dA(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i+4|0;n=i;t[r>>2]=e;t[n>>2]=Ge(t[r>>2]|0)|0;if((t[n>>2]|0)<0)lA(0,77144);s=i;return t[n>>2]|0}function vA(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0;n=s;s=s+16|0;f=n+12|0;u=n+8|0;a=n+4|0;o=n;t[f>>2]=e;t[u>>2]=i;t[a>>2]=r;t[o>>2]=0;if((t[a>>2]|0)>0?(t[o>>2]=$e(t[f>>2]|0,t[u>>2]|0,t[a>>2]|0)|0,(t[o>>2]|0)<0):0)lA(0,77136);s=n;return t[o>>2]|0}function mA(e,i,r){e=e|0;i=i|0;r=r|0;var n=0;n=s;s=s+16|0;t[n+8>>2]=e;t[n+4>>2]=i;t[n>>2]=r;s=n;return 0}function _A(e,i,r,f){e=e|0;i=i|0;r=r|0;f=f|0;var a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0;a=s;s=s+32|0;o=a+28|0;c=a+24|0;l=a+20|0;b=a+16|0;k=a+12|0;h=a+8|0;w=a+4|0;d=a;t[o>>2]=e;t[c>>2]=i;t[l>>2]=r;t[b>>2]=f;t[k>>2]=t[o>>2];t[h>>2]=t[l>>2];t[w>>2]=(t[o>>2]|0)+(t[t[c>>2]>>2]|0);t[d>>2]=(t[l>>2]|0)+(t[t[b>>2]>>2]|0);e:while(1){if((t[l>>2]|0)>>>0>=(t[d>>2]|0)>>>0)break;if((t[o>>2]|0)>>>0>=(t[w>>2]|0)>>>0)break;do if((u[t[l>>2]>>0]|0|0)==60){if(((t[w>>2]|0)-(t[o>>2]|0)|0)<4)break e;f=t[o>>2]|0;t[o>>2]=f+1;n[f>>0]=38;f=t[o>>2]|0;t[o>>2]=f+1;n[f>>0]=108;f=t[o>>2]|0;t[o>>2]=f+1;n[f>>0]=116;f=t[o>>2]|0;t[o>>2]=f+1;n[f>>0]=59}else{if((u[t[l>>2]>>0]|0|0)==62){if(((t[w>>2]|0)-(t[o>>2]|0)|0)<4)break e;f=t[o>>2]|0;t[o>>2]=f+1;n[f>>0]=38;f=t[o>>2]|0;t[o>>2]=f+1;n[f>>0]=103;f=t[o>>2]|0;t[o>>2]=f+1;n[f>>0]=116;f=t[o>>2]|0;t[o>>2]=f+1;n[f>>0]=59;break}if((u[t[l>>2]>>0]|0|0)==38){if(((t[w>>2]|0)-(t[o>>2]|0)|0)<5)break e;f=t[o>>2]|0;t[o>>2]=f+1;n[f>>0]=38;f=t[o>>2]|0;t[o>>2]=f+1;n[f>>0]=97;f=t[o>>2]|0;t[o>>2]=f+1;n[f>>0]=109;f=t[o>>2]|0;t[o>>2]=f+1;n[f>>0]=112;f=t[o>>2]|0;t[o>>2]=f+1;n[f>>0]=59;break}if((u[t[l>>2]>>0]|0|0)!=13){f=n[t[l>>2]>>0]|0;r=t[o>>2]|0;t[o>>2]=r+1;n[r>>0]=f;break}if(((t[w>>2]|0)-(t[o>>2]|0)|0)<5)break e;f=t[o>>2]|0;t[o>>2]=f+1;n[f>>0]=38;f=t[o>>2]|0;t[o>>2]=f+1;n[f>>0]=35;f=t[o>>2]|0;t[o>>2]=f+1;n[f>>0]=49;f=t[o>>2]|0;t[o>>2]=f+1;n[f>>0]=51;f=t[o>>2]|0;t[o>>2]=f+1;n[f>>0]=59}while(0);t[l>>2]=(t[l>>2]|0)+1}t[t[c>>2]>>2]=(t[o>>2]|0)-(t[k>>2]|0);t[t[b>>2]>>2]=(t[l>>2]|0)-(t[h>>2]|0);s=a;return 0}function pA(e){e=e|0;var i=0,r=0,n=0,f=0,u=0,a=0,o=0,c=0;i=s;s=s+16|0;r=i+8|0;n=i+4|0;f=i;t[n>>2]=e;if(!(t[n>>2]|0)){t[r>>2]=0;u=t[r>>2]|0;s=i;return u|0}e=($l(t[n>>2]|0,77096,17)|0)!=0;a=t[n>>2]|0;do if(e){o=($l(a,77120,8)|0)!=0;c=t[n>>2]|0;if(o){t[f>>2]=c;break}else{t[f>>2]=c+7;break}}else t[f>>2]=a+16;while(0);t[r>>2]=yO(t[f>>2]|0)|0;u=t[r>>2]|0;s=i;return u|0}function EA(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0;n=s;s=s+32|0;f=n+20|0;u=n+16|0;a=n+12|0;o=n+8|0;c=n+4|0;l=n;t[f>>2]=e;t[u>>2]=i;t[a>>2]=r;t[o>>2]=0;t[c>>2]=sc()|0;if(!(t[c>>2]|0)){b=t[o>>2]|0;s=n;return b|0}if(pA(t[f>>2]|0)|0){b=t[o>>2]|0;s=n;return b|0}if(((t[a>>2]|0)!=0?(t[(t[a>>2]|0)+284>>2]|0)!=0:0)?(t[c>>2]|0)==3|(t[c>>2]|0)==2:0)t[o>>2]=hc(t[(t[a>>2]|0)+284>>2]|0,t[u>>2]|0,t[f>>2]|0)|0;if((t[o>>2]|0)==0?(t[c>>2]|0)==3|(t[c>>2]|0)==1:0)t[o>>2]=cc(t[u>>2]|0,t[f>>2]|0)|0;if((t[o>>2]|0)==0&(t[f>>2]|0)!=0)t[o>>2]=Yl(t[f>>2]|0)|0;if(!(t[o>>2]|0)){b=t[o>>2]|0;s=n;return b|0}if(pA(t[o>>2]|0)|0){b=t[o>>2]|0;s=n;return b|0}t[l>>2]=0;if(((t[a>>2]|0)!=0?(t[(t[a>>2]|0)+284>>2]|0)!=0:0)?(t[c>>2]|0)==3|(t[c>>2]|0)==2:0)t[l>>2]=wc(t[(t[a>>2]|0)+284>>2]|0,t[o>>2]|0)|0;if((t[l>>2]|0)==0?(t[c>>2]|0)==3|(t[c>>2]|0)==1:0)t[l>>2]=lc(t[o>>2]|0)|0;if(!(t[l>>2]|0)){b=t[o>>2]|0;s=n;return b|0}pAi[t[135736>>2]&511](t[o>>2]|0);t[o>>2]=t[l>>2];b=t[o>>2]|0;s=n;return b|0}function SA(){var e=0,i=0,r=0,n=0;e=s;s=s+16|0;i=e;r=t[33976]|0;n=t[33980]|0;t[i>>2]=t[19636];yAi[r&511](n,78496,i);s=e;return}function gA(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0;n=s;s=s+32|0;f=n;u=n+28|0;a=n+24|0;o=n+20|0;c=n+16|0;l=n+12|0;b=n+8|0;t[a>>2]=e;t[o>>2]=i;t[c>>2]=r;if(!(t[19638]|0))yA()|0;t[l>>2]=Xq(24+(t[a>>2]|0)|0)|0;if(!(t[l>>2]|0)){yAi[t[135904>>2]&511](t[33980]|0,78560,f);FA();t[u>>2]=0;k=t[u>>2]|0;s=n;return k|0}t[t[l>>2]>>2]=23205;t[(t[l>>2]|0)+12>>2]=t[a>>2];t[(t[l>>2]|0)+4>>2]=1;t[(t[l>>2]|0)+16>>2]=t[o>>2];t[(t[l>>2]|0)+20>>2]=t[c>>2];Zc(t[19650]|0);c=(t[19652]|0)+1|0;t[19652]=c;t[(t[l>>2]|0)+8>>2]=c;t[19654]=(t[19654]|0)+(t[a>>2]|0);t[19656]=(t[19656]|0)+1;if((t[19654]|0)>>>0>(t[19658]|0)>>>0)t[19658]=t[19654];Jc(t[19650]|0);if((t[19636]|0)==(t[(t[l>>2]|0)+8>>2]|0))SA();t[b>>2]=(t[l>>2]|0)+24;if((t[19660]|0)==(t[b>>2]|0)){l=t[33976]|0;c=t[33980]|0;o=t[a>>2]|0;t[f>>2]=t[19660];t[f+4>>2]=o;yAi[l&511](c,78648,f);SA()}t[u>>2]=t[b>>2];k=t[u>>2]|0;s=n;return k|0}function yA(){var e=0,i=0,r=0,n=0,f=0,u=0;e=s;s=s+16|0;i=e;r=e+8|0;n=e+4|0;if(t[19638]|0){t[r>>2]=-1;f=t[r>>2]|0;s=e;return f|0}t[19638]=1;t[19650]=Kc()|0;t[n>>2]=ti(78864)|0;if(t[n>>2]|0){u=t[n>>2]|0;t[i>>2]=78544;jq(u,78888,i)|0}t[n>>2]=ti(78896)|0;if(t[n>>2]|0){u=t[n>>2]|0;t[i>>2]=78640;jq(u,78912,i)|0}t[r>>2]=0;f=t[r>>2]|0;s=e;return f|0}function FA(){return}function OA(e){e=e|0;var i=0,r=0;i=s;s=s+16|0;r=i;t[r>>2]=e;e=gA(t[r>>2]|0,78672,0)|0;s=i;return e|0}function AA(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0;f=s;s=s+48|0;u=f;a=f+40|0;o=f+36|0;c=f+32|0;l=f+28|0;b=f+24|0;k=f+20|0;h=f+16|0;w=f+12|0;t[o>>2]=e;t[c>>2]=i;t[l>>2]=r;t[b>>2]=n;if(!(t[o>>2]|0)){t[a>>2]=gA(t[c>>2]|0,t[l>>2]|0,t[b>>2]|0)|0;d=t[a>>2]|0;s=f;return d|0}if(!(t[19638]|0))yA()|0;t[k>>2]=(t[o>>2]|0)+-24;t[w>>2]=t[(t[k>>2]|0)+8>>2];if((t[19636]|0)==(t[w>>2]|0))SA();n=t[k>>2]|0;do if((t[t[k>>2]>>2]|0)!=23205)BA(n);else{t[n>>2]=-23206;Zc(t[19650]|0);t[19654]=(t[19654]|0)-(t[(t[k>>2]|0)+12>>2]|0);t[19656]=(t[19656]|0)+-1;Jc(t[19650]|0);t[h>>2]=Jq(t[k>>2]|0,24+(t[c>>2]|0)|0)|0;if(!(t[h>>2]|0)){Zq(t[k>>2]|0);break}t[k>>2]=t[h>>2];if((t[19660]|0)==(t[o>>2]|0)){r=t[33976]|0;i=t[33980]|0;e=t[(t[k>>2]|0)+12>>2]|0;v=t[c>>2]|0;t[u>>2]=t[19660];t[u+4>>2]=e;t[u+8>>2]=v;yAi[r&511](i,78680,u);SA()}t[t[k>>2]>>2]=23205;t[(t[k>>2]|0)+8>>2]=t[w>>2];t[(t[k>>2]|0)+4>>2]=2;t[(t[k>>2]|0)+12>>2]=t[c>>2];t[(t[k>>2]|0)+16>>2]=t[l>>2];t[(t[k>>2]|0)+20>>2]=t[b>>2];Zc(t[19650]|0);t[19654]=(t[19654]|0)+(t[c>>2]|0);t[19656]=(t[19656]|0)+1;if((t[19654]|0)>>>0>(t[19658]|0)>>>0)t[19658]=t[19654];Jc(t[19650]|0);t[a>>2]=(t[k>>2]|0)+24;d=t[a>>2]|0;s=f;return d|0}while(0);t[a>>2]=0;d=t[a>>2]|0;s=f;return d|0}function MA(e,i){e=e|0;i=i|0;var r=0,n=0,f=0;r=s;s=s+16|0;n=r+4|0;f=r;t[n>>2]=e;t[f>>2]=i;i=AA(t[n>>2]|0,t[f>>2]|0,78672,0)|0;s=r;return i|0}function RA(e){e=e|0;var i=0,r=0,n=0,f=0,u=0,a=0;i=s;s=s+16|0;r=i;n=i+12|0;f=i+8|0;u=i+4|0;t[n>>2]=e;if(!(t[n>>2]|0)){s=i;return}do if((t[n>>2]|0)==(-1|0))yAi[t[135904>>2]&511](t[33980]|0,78712,r);else{if((t[19660]|0)==(t[n>>2]|0)){e=t[33976]|0;a=t[33980]|0;t[r>>2]=t[19660];yAi[e&511](a,78752,r);SA()}t[u>>2]=t[n>>2];t[f>>2]=(t[n>>2]|0)+-24;if((t[t[f>>2]>>2]|0)!=23205){BA(t[f>>2]|0);break}if((t[19636]|0)==(t[(t[f>>2]|0)+8>>2]|0))SA();t[t[f>>2]>>2]=-23206;VY(t[u>>2]|0,-1,t[(t[f>>2]|0)+12>>2]|0)|0;Zc(t[19650]|0);t[19654]=(t[19654]|0)-(t[(t[f>>2]|0)+12>>2]|0);t[19656]=(t[19656]|0)+-1;Jc(t[19650]|0);Zq(t[f>>2]|0);s=i;return}while(0);f=t[33976]|0;u=t[33980]|0;t[r>>2]=t[n>>2];yAi[f&511](u,78768,r);SA();s=i;return}function NA(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0;n=s;s=s+32|0;f=n;u=n+28|0;a=n+24|0;o=n+20|0;c=n+16|0;l=n+12|0;b=n+8|0;k=n+4|0;t[a>>2]=e;t[o>>2]=i;t[c>>2]=r;t[b>>2]=(HY(t[a>>2]|0)|0)+1;if(!(t[19638]|0))yA()|0;t[k>>2]=Xq(24+(t[b>>2]|0)|0)|0;if(!(t[k>>2]|0)){t[u>>2]=0;h=t[u>>2]|0;s=n;return h|0}t[t[k>>2]>>2]=23205;t[(t[k>>2]|0)+12>>2]=t[b>>2];t[(t[k>>2]|0)+4>>2]=3;t[(t[k>>2]|0)+16>>2]=t[o>>2];t[(t[k>>2]|0)+20>>2]=t[c>>2];Zc(t[19650]|0);c=(t[19652]|0)+1|0;t[19652]=c;t[(t[k>>2]|0)+8>>2]=c;t[19654]=(t[19654]|0)+(t[b>>2]|0);t[19656]=(t[19656]|0)+1;if((t[19654]|0)>>>0>(t[19658]|0)>>>0)t[19658]=t[19654];Jc(t[19650]|0);t[l>>2]=(t[k>>2]|0)+24;if((t[19636]|0)==(t[(t[k>>2]|0)+8>>2]|0))SA();WY(t[l>>2]|0,t[a>>2]|0)|0;if((t[19660]|0)==(t[l>>2]|0)){a=t[33976]|0;k=t[33980]|0;t[f>>2]=t[19660];yAi[a&511](k,78792,f);SA()}t[u>>2]=t[l>>2];h=t[u>>2]|0;s=n;return h|0}function TA(e){e=e|0;var i=0,r=0;i=s;s=s+16|0;r=i;t[r>>2]=e;e=NA(t[r>>2]|0,78672,0)|0;s=i;return e|0}function LA(){return t[19654]|0}function DA(e,i){e=e|0;i=i|0;var r=0,n=0,f=0;r=s;s=s+16|0;n=r;f=r+12|0;t[f>>2]=e;t[r+8>>2]=i;if(!(t[f>>2]|0)){s=r;return}i=t[f>>2]|0;f=t[19658]|0;t[n>>2]=t[19654];t[n+4>>2]=f;xe(i|0,78816,n|0)|0;s=r;return}function CA(){var e=0;e=s;if(!(t[19638]|0)){s=e;return}Xc(t[19650]|0);t[19650]=0;t[19638]=0;s=e;return}function PA(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,u=0,a=0,o=0,c=0,l=0;f=s;s=s+32|0;u=f+16|0;a=f+12|0;o=f+8|0;c=f+4|0;l=f;t[a>>2]=e;t[o>>2]=i;t[c>>2]=r;t[l>>2]=n;do if(t[a>>2]|0){if(!(t[o>>2]|0)){t[u>>2]=-1;break}if(!(t[c>>2]|0)){t[u>>2]=-1;break}if(!(t[l>>2]|0)){t[u>>2]=-1;break}else{t[33934]=t[a>>2];t[33936]=t[o>>2];t[33938]=t[o>>2];t[33940]=t[c>>2];t[33942]=t[l>>2];t[u>>2]=0;break}}else t[u>>2]=-1;while(0);s=f;return t[u>>2]|0}function BA(e){e=e|0;var i=0,r=0,n=0,f=0;i=s;s=s+16|0;r=i;n=i+4|0;t[n>>2]=e;e=t[33976]|0;f=t[33980]|0;t[r>>2]=t[n>>2];yAi[e&511](f,78920,r);s=i;return}function IA(e){e=e|0;var i=0,r=0,n=0,f=0,u=0,a=0;i=s;s=s+16|0;r=i+12|0;n=i+8|0;f=i+4|0;u=i;t[n>>2]=e;if(!(t[n>>2]|0)){t[r>>2]=0;a=t[r>>2]|0;s=i;return a|0}t[f>>2]=HA()|0;if((t[f>>2]|0)!=0?(t[u>>2]=ZA(t[f>>2]|0,t[n>>2]|0)|0,(t[u>>2]|0)!=0):0){xA(t[f>>2]|0);t[r>>2]=0;a=t[r>>2]|0;s=i;return a|0}t[r>>2]=t[f>>2];a=t[r>>2]|0;s=i;return a|0}function HA(){var e=0,i=0,r=0,n=0,f=0,u=0;e=s;s=s+16|0;i=e+4|0;r=e;t[r>>2]=gAi[t[135744>>2]&511](44)|0;if(!(t[r>>2]|0)){JA(78960);t[i>>2]=0;n=t[i>>2]|0;s=e;return n|0}else{f=(t[r>>2]|0)+0|0;u=f+44|0;do{t[f>>2]=0;f=f+4|0}while((f|0)<(u|0));t[i>>2]=t[r>>2];n=t[i>>2]|0;s=e;return n|0}return 0}function xA(e){e=e|0;var i=0,r=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if(!(t[r>>2]|0)){s=i;return}if(t[t[r>>2]>>2]|0)pAi[t[135736>>2]&511](t[t[r>>2]>>2]|0);if(t[(t[r>>2]|0)+12>>2]|0)pAi[t[135736>>2]&511](t[(t[r>>2]|0)+12>>2]|0);if(t[(t[r>>2]|0)+16>>2]|0)pAi[t[135736>>2]&511](t[(t[r>>2]|0)+16>>2]|0);if(t[(t[r>>2]|0)+24>>2]|0)pAi[t[135736>>2]&511](t[(t[r>>2]|0)+24>>2]|0);if(t[(t[r>>2]|0)+32>>2]|0)pAi[t[135736>>2]&511](t[(t[r>>2]|0)+32>>2]|0);if(t[(t[r>>2]|0)+4>>2]|0)pAi[t[135736>>2]&511](t[(t[r>>2]|0)+4>>2]|0);if(t[(t[r>>2]|0)+8>>2]|0)pAi[t[135736>>2]&511](t[(t[r>>2]|0)+8>>2]|0);if(t[(t[r>>2]|0)+28>>2]|0)pAi[t[135736>>2]&511](t[(t[r>>2]|0)+28>>2]|0);if(t[(t[r>>2]|0)+40>>2]|0)pAi[t[135736>>2]&511](t[(t[r>>2]|0)+40>>2]|0);pAi[t[135736>>2]&511](t[r>>2]|0);s=i;return}function UA(e,i){e=e|0;i=i|0;var r=0,n=0,f=0;r=s;s=s+16|0;n=r+4|0;f=r;t[n>>2]=e;t[f>>2]=i;i=ZA(t[n>>2]|0,t[f>>2]|0)|0;s=r;return i|0}function zA(e){e=e|0;var i=0,r=0,f=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0,S=0,g=0,y=0,F=0,O=0,A=0,M=0,R=0,N=0,T=0,L=0,D=0,C=0,P=0,B=0,I=0;i=s;s=s+112|0;r=i;f=i+100|0;a=i+96|0;o=i+92|0;c=i+88|0;l=i+84|0;b=i+80|0;k=i+76|0;h=i+72|0;w=i+68|0;d=i+64|0;v=i+60|0;m=i+56|0;_=i+52|0;p=i+48|0;E=i+44|0;S=i+40|0;g=i+36|0;y=i+32|0;F=i+28|0;O=i+24|0;A=i+20|0;M=i+16|0;R=i+12|0;N=i+8|0;T=i+4|0;t[a>>2]=e;t[o>>2]=0;if(!(t[a>>2]|0)){t[f>>2]=0;L=t[f>>2]|0;s=i;return L|0}t[k>>2]=80;t[o>>2]=gAi[t[135752>>2]&511]((t[k>>2]|0)+1|0)|0;if(!(t[o>>2]|0)){JA(78984);t[f>>2]=0;L=t[f>>2]|0;s=i;return L|0}t[b>>2]=0;e:do if(t[t[a>>2]>>2]|0){t[l>>2]=t[t[a>>2]>>2];while(1){D=(t[b>>2]|0)>=(t[k>>2]|0);if(!(n[t[l>>2]>>0]|0))break;if(D){t[c>>2]=QA(t[o>>2]|0,k)|0;if(!(t[c>>2]|0))break e;t[o>>2]=t[c>>2]}e=t[l>>2]|0;t[l>>2]=e+1;C=n[e>>0]|0;e=t[b>>2]|0;t[b>>2]=e+1;n[(t[o>>2]|0)+e>>0]=C}if(D){t[c>>2]=QA(t[o>>2]|0,k)|0;if(!(t[c>>2]|0))break;t[o>>2]=t[c>>2]}C=t[b>>2]|0;t[b>>2]=C+1;n[(t[o>>2]|0)+C>>0]=58;P=16}else P=16;while(0);e:do if((P|0)==16){D=t[a>>2]|0;i:do if(!(t[(t[a>>2]|0)+4>>2]|0)){r:do if((t[D+12>>2]|0)==0?(t[(t[a>>2]|0)+20>>2]|0)!=-1:0){if(!(t[(t[a>>2]|0)+8>>2]|0)){if(!(t[t[a>>2]>>2]|0))break;if(((t[b>>2]|0)+3|0)<(t[k>>2]|0))break;t[c>>2]=QA(t[o>>2]|0,k)|0;if(!(t[c>>2]|0))break e;t[o>>2]=t[c>>2];break}if(((t[b>>2]|0)+3|0)>=(t[k>>2]|0)){t[c>>2]=QA(t[o>>2]|0,k)|0;if(!(t[c>>2]|0))break e;t[o>>2]=t[c>>2]}C=t[b>>2]|0;t[b>>2]=C+1;n[(t[o>>2]|0)+C>>0]=47;C=t[b>>2]|0;t[b>>2]=C+1;n[(t[o>>2]|0)+C>>0]=47;t[l>>2]=t[(t[a>>2]|0)+8>>2];n:while(1){if(!(n[t[l>>2]>>0]|0))break r;if(((t[b>>2]|0)+3|0)>=(t[k>>2]|0)){t[c>>2]=QA(t[o>>2]|0,k)|0;if(!(t[c>>2]|0))break e;t[o>>2]=t[c>>2]}if(!((n[t[l>>2]>>0]|0)>=97?(n[t[l>>2]>>0]|0)<=122:0))P=113;do if((P|0)==113){P=0;if((n[t[l>>2]>>0]|0)>=65?(n[t[l>>2]>>0]|0)<=90:0)break;if((n[t[l>>2]>>0]|0)>=48?(n[t[l>>2]>>0]|0)<=57:0)break;if((n[t[l>>2]>>0]|0)!=45?(n[t[l>>2]>>0]|0)!=95:0){if((n[t[l>>2]>>0]|0)==46)break;if((n[t[l>>2]>>0]|0)==33)break;if((n[t[l>>2]>>0]|0)==126)break;if((n[t[l>>2]>>0]|0)==42)break;if((n[t[l>>2]>>0]|0)==39)break;if((n[t[l>>2]>>0]|0)==40)break;if((n[t[l>>2]>>0]|0)==41)break;if((n[t[l>>2]>>0]|0)==36)break;if((n[t[l>>2]>>0]|0)==44)break;if((n[t[l>>2]>>0]|0)==59)break;if((n[t[l>>2]>>0]|0)==58)break;if((n[t[l>>2]>>0]|0)==64)break;if((n[t[l>>2]>>0]|0)==38)break;if((n[t[l>>2]>>0]|0)==61)break;if((n[t[l>>2]>>0]|0)==43)break;C=t[l>>2]|0;t[l>>2]=C+1;t[p>>2]=u[C>>0];t[E>>2]=(t[p>>2]|0)/16|0;t[S>>2]=(t[p>>2]|0)%16|0;C=t[b>>2]|0;t[b>>2]=C+1;n[(t[o>>2]|0)+C>>0]=37;C=(t[E>>2]|0)+((t[E>>2]|0)>9?55:48)&255;e=t[b>>2]|0;t[b>>2]=e+1;n[(t[o>>2]|0)+e>>0]=C;C=(t[S>>2]|0)+((t[S>>2]|0)>9?55:48)&255;e=t[b>>2]|0;t[b>>2]=e+1;n[(t[o>>2]|0)+e>>0]=C;continue n}}while(0);C=t[l>>2]|0;t[l>>2]=C+1;e=n[C>>0]|0;C=t[b>>2]|0;t[b>>2]=C+1;n[(t[o>>2]|0)+C>>0]=e}}else P=53;while(0);if((P|0)==53){if(((t[b>>2]|0)+3|0)>=(t[k>>2]|0)){t[c>>2]=QA(t[o>>2]|0,k)|0;if(!(t[c>>2]|0))break e;t[o>>2]=t[c>>2]}e=t[b>>2]|0;t[b>>2]=e+1;n[(t[o>>2]|0)+e>>0]=47;e=t[b>>2]|0;t[b>>2]=e+1;n[(t[o>>2]|0)+e>>0]=47;if(t[(t[a>>2]|0)+16>>2]|0){t[l>>2]=t[(t[a>>2]|0)+16>>2];r:while(1){B=((t[b>>2]|0)+3|0)>=(t[k>>2]|0);if(!(n[t[l>>2]>>0]|0))break;if(B){t[c>>2]=QA(t[o>>2]|0,k)|0;if(!(t[c>>2]|0))break e;t[o>>2]=t[c>>2]}if(!((n[t[l>>2]>>0]|0)>=97?(n[t[l>>2]>>0]|0)<=122:0))P=64;do if((P|0)==64){P=0;if((n[t[l>>2]>>0]|0)>=65?(n[t[l>>2]>>0]|0)<=90:0)break;if((n[t[l>>2]>>0]|0)>=48?(n[t[l>>2]>>0]|0)<=57:0)break;if((n[t[l>>2]>>0]|0)!=45?(n[t[l>>2]>>0]|0)!=95:0){if((n[t[l>>2]>>0]|0)==46)break;if((n[t[l>>2]>>0]|0)==33)break;if((n[t[l>>2]>>0]|0)==126)break;if((n[t[l>>2]>>0]|0)==42)break;if((n[t[l>>2]>>0]|0)==39)break;if((n[t[l>>2]>>0]|0)==40)break;if((n[t[l>>2]>>0]|0)==41)break;if((n[t[l>>2]>>0]|0)==59)break;if((n[t[l>>2]>>0]|0)==58)break;if((n[t[l>>2]>>0]|0)==38)break;if((n[t[l>>2]>>0]|0)==61)break;if((n[t[l>>2]>>0]|0)==43)break;if((n[t[l>>2]>>0]|0)==36)break;if((n[t[l>>2]>>0]|0)==44)break;e=t[l>>2]|0;t[l>>2]=e+1;t[v>>2]=u[e>>0];t[m>>2]=(t[v>>2]|0)/16|0;t[_>>2]=(t[v>>2]|0)%16|0;e=t[b>>2]|0;t[b>>2]=e+1;n[(t[o>>2]|0)+e>>0]=37;e=(t[m>>2]|0)+((t[m>>2]|0)>9?55:48)&255;C=t[b>>2]|0;t[b>>2]=C+1;n[(t[o>>2]|0)+C>>0]=e;e=(t[_>>2]|0)+((t[_>>2]|0)>9?55:48)&255;C=t[b>>2]|0;t[b>>2]=C+1;n[(t[o>>2]|0)+C>>0]=e;continue r}}while(0);e=t[l>>2]|0;t[l>>2]=e+1;C=n[e>>0]|0;e=t[b>>2]|0;t[b>>2]=e+1;n[(t[o>>2]|0)+e>>0]=C}if(B){t[c>>2]=QA(t[o>>2]|0,k)|0;if(!(t[c>>2]|0))break e;t[o>>2]=t[c>>2]}C=t[b>>2]|0;t[b>>2]=C+1;n[(t[o>>2]|0)+C>>0]=64}if(t[(t[a>>2]|0)+12>>2]|0){t[l>>2]=t[(t[a>>2]|0)+12>>2];while(1){if(!(n[t[l>>2]>>0]|0))break;if((t[b>>2]|0)>=(t[k>>2]|0)){t[c>>2]=QA(t[o>>2]|0,k)|0;if(!(t[c>>2]|0))break e;t[o>>2]=t[c>>2]}C=t[l>>2]|0;t[l>>2]=C+1;e=n[C>>0]|0;C=t[b>>2]|0;t[b>>2]=C+1;n[(t[o>>2]|0)+C>>0]=e}if((t[(t[a>>2]|0)+20>>2]|0)>0){if(((t[b>>2]|0)+10|0)>=(t[k>>2]|0)){t[c>>2]=QA(t[o>>2]|0,k)|0;if(!(t[c>>2]|0))break e;t[o>>2]=t[c>>2]}e=(t[o>>2]|0)+(t[b>>2]|0)|0;C=(t[k>>2]|0)-(t[b>>2]|0)|0;t[r>>2]=t[(t[a>>2]|0)+20>>2];I=SY(e,C,79e3,r)|0;t[b>>2]=(t[b>>2]|0)+I}}}r:do if(t[(t[a>>2]|0)+24>>2]|0){t[l>>2]=t[(t[a>>2]|0)+24>>2];do if((t[t[a>>2]>>2]|0)!=0?(n[t[l>>2]>>0]|0)==47:0){if(!((n[(t[l>>2]|0)+1>>0]|0)>=97?(n[(t[l>>2]|0)+1>>0]|0)<=122:0)){if((n[(t[l>>2]|0)+1>>0]|0)<65)break;if((n[(t[l>>2]|0)+1>>0]|0)>90)break}if((n[(t[l>>2]|0)+2>>0]|0)==58?(Xl(t[t[a>>2]>>2]|0,79008)|0)!=0:0){if(((t[b>>2]|0)+3|0)>=(t[k>>2]|0)){t[c>>2]=QA(t[o>>2]|0,k)|0;if(!(t[c>>2]|0))break e;t[o>>2]=t[c>>2]}I=t[l>>2]|0;t[l>>2]=I+1;C=n[I>>0]|0;I=t[b>>2]|0;t[b>>2]=I+1;n[(t[o>>2]|0)+I>>0]=C;C=t[l>>2]|0;t[l>>2]=C+1;I=n[C>>0]|0;C=t[b>>2]|0;t[b>>2]=C+1;n[(t[o>>2]|0)+C>>0]=I;I=t[l>>2]|0;t[l>>2]=I+1;C=n[I>>0]|0;I=t[b>>2]|0;t[b>>2]=I+1;n[(t[o>>2]|0)+I>>0]=C}}while(0);n:while(1){if(!(n[t[l>>2]>>0]|0))break r;if(((t[b>>2]|0)+3|0)>=(t[k>>2]|0)){t[c>>2]=QA(t[o>>2]|0,k)|0;if(!(t[c>>2]|0))break e;t[o>>2]=t[c>>2]}if(!((n[t[l>>2]>>0]|0)>=97?(n[t[l>>2]>>0]|0)<=122:0))P=159;do if((P|0)==159){P=0;if((n[t[l>>2]>>0]|0)>=65?(n[t[l>>2]>>0]|0)<=90:0)break;if((n[t[l>>2]>>0]|0)>=48?(n[t[l>>2]>>0]|0)<=57:0)break;if(((n[t[l>>2]>>0]|0)!=45?(n[t[l>>2]>>0]|0)!=95:0)?(n[t[l>>2]>>0]|0)!=46:0){if((n[t[l>>2]>>0]|0)==33)break;if((n[t[l>>2]>>0]|0)==126)break;if((n[t[l>>2]>>0]|0)==42)break;if((n[t[l>>2]>>0]|0)==39)break;if((n[t[l>>2]>>0]|0)==40)break;if((n[t[l>>2]>>0]|0)==41)break;if((n[t[l>>2]>>0]|0)==47)break;if((n[t[l>>2]>>0]|0)==59)break;if((n[t[l>>2]>>0]|0)==64)break;if((n[t[l>>2]>>0]|0)==38)break;if((n[t[l>>2]>>0]|0)==61)break;if((n[t[l>>2]>>0]|0)==43)break;if((n[t[l>>2]>>0]|0)==36)break;if((n[t[l>>2]>>0]|0)==44)break;C=t[l>>2]|0;t[l>>2]=C+1;t[g>>2]=u[C>>0];t[y>>2]=(t[g>>2]|0)/16|0;t[F>>2]=(t[g>>2]|0)%16|0;C=t[b>>2]|0;t[b>>2]=C+1;n[(t[o>>2]|0)+C>>0]=37;C=(t[y>>2]|0)+((t[y>>2]|0)>9?55:48)&255;I=t[b>>2]|0;t[b>>2]=I+1;n[(t[o>>2]|0)+I>>0]=C;C=(t[F>>2]|0)+((t[F>>2]|0)>9?55:48)&255;I=t[b>>2]|0;t[b>>2]=I+1;n[(t[o>>2]|0)+I>>0]=C;continue n}}while(0);C=t[l>>2]|0;t[l>>2]=C+1;I=n[C>>0]|0;C=t[b>>2]|0;t[b>>2]=C+1;n[(t[o>>2]|0)+C>>0]=I}}while(0);if(t[(t[a>>2]|0)+40>>2]|0){if(((t[b>>2]|0)+1|0)>=(t[k>>2]|0)){t[c>>2]=QA(t[o>>2]|0,k)|0;if(!(t[c>>2]|0))break e;t[o>>2]=t[c>>2]}I=t[b>>2]|0;t[b>>2]=I+1;n[(t[o>>2]|0)+I>>0]=63;t[l>>2]=t[(t[a>>2]|0)+40>>2];while(1){if(!(n[t[l>>2]>>0]|0))break i;if(((t[b>>2]|0)+1|0)>=(t[k>>2]|0)){t[c>>2]=QA(t[o>>2]|0,k)|0;if(!(t[c>>2]|0))break e;t[o>>2]=t[c>>2]}I=t[l>>2]|0;t[l>>2]=I+1;C=n[I>>0]|0;I=t[b>>2]|0;t[b>>2]=I+1;n[(t[o>>2]|0)+I>>0]=C}}if(t[(t[a>>2]|0)+28>>2]|0){if(((t[b>>2]|0)+3|0)>=(t[k>>2]|0)){t[c>>2]=QA(t[o>>2]|0,k)|0;if(!(t[c>>2]|0))break e;t[o>>2]=t[c>>2]}C=t[b>>2]|0;t[b>>2]=C+1;n[(t[o>>2]|0)+C>>0]=63;t[l>>2]=t[(t[a>>2]|0)+28>>2];r:while(1){if(!(n[t[l>>2]>>0]|0))break i;if(((t[b>>2]|0)+3|0)>=(t[k>>2]|0)){t[c>>2]=QA(t[o>>2]|0,k)|0;if(!(t[c>>2]|0))break e;t[o>>2]=t[c>>2]}if(!((n[t[l>>2]>>0]|0)>=97?(n[t[l>>2]>>0]|0)<=122:0))P=203;do if((P|0)==203){P=0;if((n[t[l>>2]>>0]|0)>=65?(n[t[l>>2]>>0]|0)<=90:0)break;if((n[t[l>>2]>>0]|0)>=48?(n[t[l>>2]>>0]|0)<=57:0)break;if((n[t[l>>2]>>0]|0)!=45?(n[t[l>>2]>>0]|0)!=95:0){if((n[t[l>>2]>>0]|0)==46)break;if((n[t[l>>2]>>0]|0)==33)break;if((n[t[l>>2]>>0]|0)==126)break;if((n[t[l>>2]>>0]|0)==42)break;if((n[t[l>>2]>>0]|0)==39)break;if((n[t[l>>2]>>0]|0)==40)break;if((n[t[l>>2]>>0]|0)==41)break;if((n[t[l>>2]>>0]|0)==59)break;if((n[t[l>>2]>>0]|0)==47)break;if((n[t[l>>2]>>0]|0)==63)break;if((n[t[l>>2]>>0]|0)==58)break;if((n[t[l>>2]>>0]|0)==64)break;if((n[t[l>>2]>>0]|0)==38)break;if((n[t[l>>2]>>0]|0)==61)break;if((n[t[l>>2]>>0]|0)==43)break;if((n[t[l>>2]>>0]|0)==36)break;if((n[t[l>>2]>>0]|0)==44)break;if((n[t[l>>2]>>0]|0)==91)break;if((n[t[l>>2]>>0]|0)==93)break;C=t[l>>2]|0;t[l>>2]=C+1;t[O>>2]=u[C>>0];t[A>>2]=(t[O>>2]|0)/16|0;t[M>>2]=(t[O>>2]|0)%16|0;C=t[b>>2]|0;t[b>>2]=C+1;n[(t[o>>2]|0)+C>>0]=37;C=(t[A>>2]|0)+((t[A>>2]|0)>9?55:48)&255;I=t[b>>2]|0;t[b>>2]=I+1;n[(t[o>>2]|0)+I>>0]=C;C=(t[M>>2]|0)+((t[M>>2]|0)>9?55:48)&255;I=t[b>>2]|0;t[b>>2]=I+1;n[(t[o>>2]|0)+I>>0]=C;continue r}}while(0);C=t[l>>2]|0;t[l>>2]=C+1;I=n[C>>0]|0;C=t[b>>2]|0;t[b>>2]=C+1;n[(t[o>>2]|0)+C>>0]=I}}}else{t[l>>2]=t[D+4>>2];r:while(1){if(!(n[t[l>>2]>>0]|0))break i;if(((t[b>>2]|0)+3|0)>=(t[k>>2]|0)){t[c>>2]=QA(t[o>>2]|0,k)|0;if(!(t[c>>2]|0))break e;t[o>>2]=t[c>>2]}do if((((((((((n[t[l>>2]>>0]|0)!=59?(n[t[l>>2]>>0]|0)!=47:0)?(n[t[l>>2]>>0]|0)!=63:0)?(n[t[l>>2]>>0]|0)!=58:0)?(n[t[l>>2]>>0]|0)!=64:0)?(n[t[l>>2]>>0]|0)!=38:0)?(n[t[l>>2]>>0]|0)!=61:0)?(n[t[l>>2]>>0]|0)!=43:0)?(n[t[l>>2]>>0]|0)!=36:0)?(n[t[l>>2]>>0]|0)!=44:0){if((n[t[l>>2]>>0]|0)==91)break;if((n[t[l>>2]>>0]|0)==93)break;if((n[t[l>>2]>>0]|0)>=97?(n[t[l>>2]>>0]|0)<=122:0)break;if((n[t[l>>2]>>0]|0)>=65?(n[t[l>>2]>>0]|0)<=90:0)break;
	if((n[t[l>>2]>>0]|0)>=48?(n[t[l>>2]>>0]|0)<=57:0)break;if((n[t[l>>2]>>0]|0)==45)break;if((n[t[l>>2]>>0]|0)==95)break;if((n[t[l>>2]>>0]|0)==46)break;if((n[t[l>>2]>>0]|0)==33)break;if((n[t[l>>2]>>0]|0)==126)break;if((n[t[l>>2]>>0]|0)==42)break;if((n[t[l>>2]>>0]|0)==39)break;if((n[t[l>>2]>>0]|0)==40)break;if((n[t[l>>2]>>0]|0)==41)break;I=t[l>>2]|0;t[l>>2]=I+1;t[h>>2]=u[I>>0];t[w>>2]=(t[h>>2]|0)/16|0;t[d>>2]=(t[h>>2]|0)%16|0;I=t[b>>2]|0;t[b>>2]=I+1;n[(t[o>>2]|0)+I>>0]=37;I=(t[w>>2]|0)+((t[w>>2]|0)>9?55:48)&255;C=t[b>>2]|0;t[b>>2]=C+1;n[(t[o>>2]|0)+C>>0]=I;I=(t[d>>2]|0)+((t[d>>2]|0)>9?55:48)&255;C=t[b>>2]|0;t[b>>2]=C+1;n[(t[o>>2]|0)+C>>0]=I;continue r}while(0);I=t[l>>2]|0;t[l>>2]=I+1;C=n[I>>0]|0;I=t[b>>2]|0;t[b>>2]=I+1;n[(t[o>>2]|0)+I>>0]=C}}while(0);i:do if(t[(t[a>>2]|0)+32>>2]|0){if(((t[b>>2]|0)+3|0)>=(t[k>>2]|0)){t[c>>2]=QA(t[o>>2]|0,k)|0;if(!(t[c>>2]|0))break e;t[o>>2]=t[c>>2]}D=t[b>>2]|0;t[b>>2]=D+1;n[(t[o>>2]|0)+D>>0]=35;t[l>>2]=t[(t[a>>2]|0)+32>>2];r:while(1){if(!(n[t[l>>2]>>0]|0))break i;if(((t[b>>2]|0)+3|0)>=(t[k>>2]|0)){t[c>>2]=QA(t[o>>2]|0,k)|0;if(!(t[c>>2]|0))break e;t[o>>2]=t[c>>2]}if(!((n[t[l>>2]>>0]|0)>=97?(n[t[l>>2]>>0]|0)<=122:0))P=241;do if((P|0)==241){P=0;if((n[t[l>>2]>>0]|0)>=65?(n[t[l>>2]>>0]|0)<=90:0)break;if((n[t[l>>2]>>0]|0)>=48?(n[t[l>>2]>>0]|0)<=57:0)break;if(((((n[t[l>>2]>>0]|0)!=45?(n[t[l>>2]>>0]|0)!=95:0)?(n[t[l>>2]>>0]|0)!=46:0)?(n[t[l>>2]>>0]|0)!=33:0)?(n[t[l>>2]>>0]|0)!=126:0){if((n[t[l>>2]>>0]|0)==42)break;if((n[t[l>>2]>>0]|0)==39)break;if((n[t[l>>2]>>0]|0)==40)break;if((n[t[l>>2]>>0]|0)==41)break;if((n[t[l>>2]>>0]|0)==59)break;if((n[t[l>>2]>>0]|0)==47)break;if((n[t[l>>2]>>0]|0)==63)break;if((n[t[l>>2]>>0]|0)==58)break;if((n[t[l>>2]>>0]|0)==64)break;if((n[t[l>>2]>>0]|0)==38)break;if((n[t[l>>2]>>0]|0)==61)break;if((n[t[l>>2]>>0]|0)==43)break;if((n[t[l>>2]>>0]|0)==36)break;if((n[t[l>>2]>>0]|0)==44)break;if((n[t[l>>2]>>0]|0)==91)break;if((n[t[l>>2]>>0]|0)==93)break;D=t[l>>2]|0;t[l>>2]=D+1;t[R>>2]=u[D>>0];t[N>>2]=(t[R>>2]|0)/16|0;t[T>>2]=(t[R>>2]|0)%16|0;D=t[b>>2]|0;t[b>>2]=D+1;n[(t[o>>2]|0)+D>>0]=37;D=(t[N>>2]|0)+((t[N>>2]|0)>9?55:48)&255;C=t[b>>2]|0;t[b>>2]=C+1;n[(t[o>>2]|0)+C>>0]=D;D=(t[T>>2]|0)+((t[T>>2]|0)>9?55:48)&255;C=t[b>>2]|0;t[b>>2]=C+1;n[(t[o>>2]|0)+C>>0]=D;continue r}}while(0);D=t[l>>2]|0;t[l>>2]=D+1;C=n[D>>0]|0;D=t[b>>2]|0;t[b>>2]=D+1;n[(t[o>>2]|0)+D>>0]=C}}while(0);if((t[b>>2]|0)>=(t[k>>2]|0)){t[c>>2]=QA(t[o>>2]|0,k)|0;if(!(t[c>>2]|0))break;t[o>>2]=t[c>>2]}n[(t[o>>2]|0)+(t[b>>2]|0)>>0]=0;t[f>>2]=t[o>>2];L=t[f>>2]|0;s=i;return L|0}while(0);pAi[t[135736>>2]&511](t[o>>2]|0);t[f>>2]=0;L=t[f>>2]|0;s=i;return L|0}function jA(e){e=e|0;var i=0,r=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0;i=s;s=s+32|0;r=i+20|0;f=i+16|0;u=i+12|0;a=i+8|0;o=i+4|0;c=i;t[f>>2]=e;if(!(t[f>>2]|0)){t[r>>2]=-1;l=t[r>>2]|0;s=i;return l|0}t[u>>2]=t[f>>2];while(1){b=t[u>>2]|0;if((n[t[u>>2]>>0]|0)!=47)break;t[u>>2]=b+1}if(!(n[b>>0]|0)){t[r>>2]=0;l=t[r>>2]|0;s=i;return l|0}t[a>>2]=t[u>>2];e:while(1){if(!(n[t[u>>2]>>0]|0))break;if((n[t[u>>2]>>0]|0)==46?(n[(t[u>>2]|0)+1>>0]|0)==47:0){t[u>>2]=(t[u>>2]|0)+2;while(1){if((n[t[u>>2]>>0]|0)!=47)continue e;t[u>>2]=(t[u>>2]|0)+1}}if((n[t[u>>2]>>0]|0)==46?(n[(t[u>>2]|0)+1>>0]|0)==0:0)break;while(1){if((n[t[u>>2]>>0]|0)==47)break;if(!(n[t[u>>2]>>0]|0))break e;b=t[u>>2]|0;t[u>>2]=b+1;e=n[b>>0]|0;b=t[a>>2]|0;t[a>>2]=b+1;n[b>>0]=e}do{if((n[t[u>>2]>>0]|0)==47)k=(n[(t[u>>2]|0)+1>>0]|0)==47;else k=0;h=t[u>>2]|0;t[u>>2]=h+1}while(k);e=n[h>>0]|0;b=t[a>>2]|0;t[a>>2]=b+1;n[b>>0]=e}n[t[a>>2]>>0]=0;t[u>>2]=t[f>>2];while(1){w=t[u>>2]|0;if((n[t[u>>2]>>0]|0)!=47)break;t[u>>2]=w+1}if(!(n[w>>0]|0)){t[r>>2]=0;l=t[r>>2]|0;s=i;return l|0}e:while(1){t[o>>2]=t[u>>2];while(1){if((n[t[o>>2]>>0]|0)!=47)d=(n[t[o>>2]>>0]|0)!=0;else d=0;v=t[o>>2]|0;if(!d)break;t[o>>2]=v+1}if(!(n[v>>0]|0))break;t[o>>2]=(t[o>>2]|0)+1;if(!(((n[t[u>>2]>>0]|0)==46?(n[(t[u>>2]|0)+1>>0]|0)==46:0)?(t[o>>2]|0)==((t[u>>2]|0)+3|0):0))m=38;do if(((m|0)==38?(m=0,(n[t[o>>2]>>0]|0)==46):0)?(n[(t[o>>2]|0)+1>>0]|0)==46:0){if((n[(t[o>>2]|0)+2>>0]|0)!=47?(n[(t[o>>2]|0)+2>>0]|0)!=0:0)break;_=t[u>>2]|0;if(!(n[(t[o>>2]|0)+2>>0]|0)){m=44;break e}t[c>>2]=_;t[o>>2]=(t[o>>2]|0)+3;do{w=t[o>>2]|0;t[o>>2]=w+1;h=n[w>>0]|0;w=t[c>>2]|0;t[c>>2]=w+1;n[w>>0]=h}while((h<<24>>24|0)!=0);t[o>>2]=t[u>>2];do{if((t[o>>2]|0)>>>0<=(t[f>>2]|0)>>>0)break;h=(t[o>>2]|0)+-1|0;t[o>>2]=h}while((n[h>>0]|0)==47);if((t[o>>2]|0)==(t[f>>2]|0))continue e;t[u>>2]=t[o>>2];while(1){if((t[u>>2]|0)>>>0<=(t[f>>2]|0)>>>0)continue e;if((n[(t[u>>2]|0)+-1>>0]|0)==47)continue e;t[u>>2]=(t[u>>2]|0)+-1}}while(0);t[u>>2]=t[o>>2]}if((m|0)==44)n[_>>0]=0;n[t[a>>2]>>0]=0;if((n[t[f>>2]>>0]|0)==47){t[u>>2]=t[f>>2];while(1){if(((n[t[u>>2]>>0]|0)==47?(n[(t[u>>2]|0)+1>>0]|0)==46:0)?(n[(t[u>>2]|0)+2>>0]|0)==46:0)if((n[(t[u>>2]|0)+3>>0]|0)==47)p=1;else p=(n[(t[u>>2]|0)+3>>0]|0)==0;else p=0;E=t[u>>2]|0;if(!p)break;t[u>>2]=E+3}if((E|0)!=(t[f>>2]|0)){t[a>>2]=t[f>>2];while(1){if(!(n[t[u>>2]>>0]|0))break;f=t[u>>2]|0;t[u>>2]=f+1;E=n[f>>0]|0;f=t[a>>2]|0;t[a>>2]=f+1;n[f>>0]=E}n[t[a>>2]>>0]=0}}t[r>>2]=0;l=t[r>>2]|0;s=i;return l|0}function VA(e,i,r){e=e|0;i=i|0;r=r|0;var f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0;f=s;s=s+32|0;u=f+24|0;a=f+20|0;o=f+16|0;c=f+12|0;l=f+8|0;b=f+4|0;k=f;t[a>>2]=e;t[o>>2]=i;t[c>>2]=r;if(!(t[a>>2]|0)){t[u>>2]=0;h=t[u>>2]|0;s=f;return h|0}if((t[o>>2]|0)<=0)t[o>>2]=HY(t[a>>2]|0)|0;if((t[o>>2]|0)<0){t[u>>2]=0;h=t[u>>2]|0;s=f;return h|0}if(!(t[c>>2]|0)){t[l>>2]=gAi[t[135752>>2]&511]((t[o>>2]|0)+1|0)|0;if(!(t[l>>2]|0)){JA(79016);t[u>>2]=0;h=t[u>>2]|0;s=f;return h|0}}else t[l>>2]=t[c>>2];t[k>>2]=t[a>>2];t[b>>2]=t[l>>2];while(1){if((t[o>>2]|0)<=0)break;if((((t[o>>2]|0)>2?(n[t[k>>2]>>0]|0)==37:0)?($A(n[(t[k>>2]|0)+1>>0]|0)|0)!=0:0)?($A(n[(t[k>>2]|0)+2>>0]|0)|0)!=0:0){t[k>>2]=(t[k>>2]|0)+1;if((n[t[k>>2]>>0]|0)>=48?(n[t[k>>2]>>0]|0)<=57:0)n[t[b>>2]>>0]=(n[t[k>>2]>>0]|0)-48;else w=20;do if((w|0)==20){w=0;if((n[t[k>>2]>>0]|0)>=97?(n[t[k>>2]>>0]|0)<=102:0){n[t[b>>2]>>0]=(n[t[k>>2]>>0]|0)-97+10;break}if((n[t[k>>2]>>0]|0)>=65?(n[t[k>>2]>>0]|0)<=70:0)n[t[b>>2]>>0]=(n[t[k>>2]>>0]|0)-65+10}while(0);t[k>>2]=(t[k>>2]|0)+1;if((n[t[k>>2]>>0]|0)>=48?(n[t[k>>2]>>0]|0)<=57:0)n[t[b>>2]>>0]=(n[t[b>>2]>>0]<<4)+((n[t[k>>2]>>0]|0)-48);else w=29;do if((w|0)==29){w=0;if((n[t[k>>2]>>0]|0)>=97?(n[t[k>>2]>>0]|0)<=102:0){n[t[b>>2]>>0]=(n[t[b>>2]>>0]<<4)+((n[t[k>>2]>>0]|0)-97)+10;break}if((n[t[k>>2]>>0]|0)>=65?(n[t[k>>2]>>0]|0)<=70:0)n[t[b>>2]>>0]=(n[t[b>>2]>>0]<<4)+((n[t[k>>2]>>0]|0)-65)+10}while(0);t[k>>2]=(t[k>>2]|0)+1;t[o>>2]=(t[o>>2]|0)-3;t[b>>2]=(t[b>>2]|0)+1;continue}a=t[k>>2]|0;t[k>>2]=a+1;c=n[a>>0]|0;a=t[b>>2]|0;t[b>>2]=a+1;n[a>>0]=c;t[o>>2]=(t[o>>2]|0)+-1}n[t[b>>2]>>0]=0;t[u>>2]=t[l>>2];h=t[u>>2]|0;s=f;return h|0}function qA(e,i){e=e|0;i=i|0;var r=0,f=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0;r=s;s=s+48|0;f=r+28|0;a=r+24|0;o=r+20|0;c=r+16|0;l=r+33|0;b=r+12|0;k=r+8|0;h=r+4|0;w=r;d=r+32|0;t[a>>2]=e;t[o>>2]=i;if(!(t[a>>2]|0)){t[f>>2]=0;v=t[f>>2]|0;s=r;return v|0}i=t[a>>2]|0;if(!(u[t[a>>2]>>0]|0)){t[f>>2]=Yl(i)|0;v=t[f>>2]|0;s=r;return v|0}t[h>>2]=rs(i)|0;if((t[h>>2]|0)<=0){t[f>>2]=0;v=t[f>>2]|0;s=r;return v|0}t[h>>2]=(t[h>>2]|0)+20;t[c>>2]=gAi[t[135752>>2]&511](t[h>>2]|0)|0;if(!(t[c>>2]|0)){JA(79040);t[f>>2]=0;v=t[f>>2]|0;s=r;return v|0}t[k>>2]=t[a>>2];t[w>>2]=0;e:while(1){if(!(u[t[k>>2]>>0]|0)){m=40;break}if(((t[h>>2]|0)-(t[w>>2]|0)|0)<=3){t[b>>2]=QA(t[c>>2]|0,h)|0;if(!(t[b>>2]|0)){m=13;break}t[c>>2]=t[b>>2]}n[l>>0]=n[t[k>>2]>>0]|0;do if((u[l>>0]|0|0)!=64){if((u[l>>0]|0|0)>=97?(u[l>>0]|0|0)<=122:0)break;if((u[l>>0]|0|0)>=65?(u[l>>0]|0|0)<=90:0)break;if((u[l>>0]|0|0)>=48?(u[l>>0]|0|0)<=57:0)break;if((((((((u[l>>0]|0|0)!=45?(u[l>>0]|0|0)!=95:0)?(u[l>>0]|0|0)!=46:0)?(u[l>>0]|0|0)!=33:0)?(u[l>>0]|0|0)!=126:0)?(u[l>>0]|0|0)!=42:0)?(u[l>>0]|0|0)!=39:0)?(u[l>>0]|0|0)!=40:0){if((u[l>>0]|0|0)==41)break;if(es(t[o>>2]|0,n[l>>0]|0)|0)break;a=t[w>>2]|0;t[w>>2]=a+1;n[(t[c>>2]|0)+a>>0]=37;n[d>>0]=(u[l>>0]|0)>>4;a=u[d>>0]|0;if((u[d>>0]|0|0)<=9){i=t[w>>2]|0;t[w>>2]=i+1;n[(t[c>>2]|0)+i>>0]=48+a}else{i=t[w>>2]|0;t[w>>2]=i+1;n[(t[c>>2]|0)+i>>0]=65+a-10}n[d>>0]=(u[l>>0]|0)&15;a=u[d>>0]|0;if((u[d>>0]|0|0)<=9){i=t[w>>2]|0;t[w>>2]=i+1;n[(t[c>>2]|0)+i>>0]=48+a}else{i=t[w>>2]|0;t[w>>2]=i+1;n[(t[c>>2]|0)+i>>0]=65+a-10}t[k>>2]=(t[k>>2]|0)+1;continue e}}while(0);a=t[k>>2]|0;t[k>>2]=a+1;i=n[a>>0]|0;a=t[w>>2]|0;t[w>>2]=a+1;n[(t[c>>2]|0)+a>>0]=i}if((m|0)==13){JA(79040);pAi[t[135736>>2]&511](t[c>>2]|0);t[f>>2]=0;v=t[f>>2]|0;s=r;return v|0}else if((m|0)==40){n[(t[c>>2]|0)+(t[w>>2]|0)>>0]=0;t[f>>2]=t[c>>2];v=t[f>>2]|0;s=r;return v|0}return 0}function YA(e){e=e|0;var i=0,r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0;i=s;s=s+48|0;r=i;n=i+24|0;f=i+20|0;u=i+16|0;a=i+12|0;o=i+8|0;c=i+4|0;l=i+28|0;t[f>>2]=e;t[a>>2]=0;if(!(t[f>>2]|0)){t[n>>2]=0;b=t[n>>2]|0;s=i;return b|0}t[o>>2]=HA()|0;if((t[o>>2]|0)!=0?(t[(t[o>>2]|0)+36>>2]=1,t[c>>2]=UA(t[o>>2]|0,t[f>>2]|0)|0,(t[c>>2]|0)!=0):0){xA(t[o>>2]|0);t[n>>2]=0;b=t[n>>2]|0;s=i;return b|0}if(!(t[o>>2]|0)){t[n>>2]=0;b=t[n>>2]|0;s=i;return b|0}t[u>>2]=0;do if(t[t[o>>2]>>2]|0){t[a>>2]=qA(t[t[o>>2]>>2]|0,79064)|0;if(t[a>>2]|0){t[u>>2]=us(t[u>>2]|0,t[a>>2]|0)|0;t[u>>2]=us(t[u>>2]|0,79072)|0;pAi[t[135736>>2]&511](t[a>>2]|0);break}JA(79040);xA(t[o>>2]|0);t[n>>2]=0;b=t[n>>2]|0;s=i;return b|0}while(0);do if(t[(t[o>>2]|0)+8>>2]|0){t[a>>2]=qA(t[(t[o>>2]|0)+8>>2]|0,79080)|0;if(t[a>>2]|0){t[u>>2]=us(t[u>>2]|0,79088)|0;t[u>>2]=us(t[u>>2]|0,t[a>>2]|0)|0;pAi[t[135736>>2]&511](t[a>>2]|0);break}JA(79040);xA(t[o>>2]|0);t[n>>2]=0;b=t[n>>2]|0;s=i;return b|0}while(0);do if(t[(t[o>>2]|0)+16>>2]|0){t[a>>2]=qA(t[(t[o>>2]|0)+16>>2]|0,79096)|0;if(t[a>>2]|0){t[u>>2]=us(t[u>>2]|0,79088)|0;t[u>>2]=us(t[u>>2]|0,t[a>>2]|0)|0;t[u>>2]=us(t[u>>2]|0,79104)|0;pAi[t[135736>>2]&511](t[a>>2]|0);break}JA(79040);xA(t[o>>2]|0);t[n>>2]=0;b=t[n>>2]|0;s=i;return b|0}while(0);if(t[(t[o>>2]|0)+12>>2]|0){t[a>>2]=qA(t[(t[o>>2]|0)+12>>2]|0,79080)|0;if(!(t[a>>2]|0)){JA(79040);xA(t[o>>2]|0);t[n>>2]=0;b=t[n>>2]|0;s=i;return b|0}if(!(t[(t[o>>2]|0)+16>>2]|0))t[u>>2]=us(t[u>>2]|0,79088)|0;t[u>>2]=us(t[u>>2]|0,t[a>>2]|0)|0;pAi[t[135736>>2]&511](t[a>>2]|0)}if(t[(t[o>>2]|0)+20>>2]|0){t[r>>2]=t[(t[o>>2]|0)+20>>2];SY(l,10,79112,r)|0;t[u>>2]=us(t[u>>2]|0,79072)|0;t[u>>2]=us(t[u>>2]|0,l)|0}do if(t[(t[o>>2]|0)+24>>2]|0){t[a>>2]=qA(t[(t[o>>2]|0)+24>>2]|0,79120)|0;if(t[a>>2]|0){t[u>>2]=us(t[u>>2]|0,t[a>>2]|0)|0;pAi[t[135736>>2]&511](t[a>>2]|0);break}JA(79040);xA(t[o>>2]|0);t[n>>2]=0;b=t[n>>2]|0;s=i;return b|0}while(0);do if(!(t[(t[o>>2]|0)+40>>2]|0)){if(t[(t[o>>2]|0)+28>>2]|0){t[a>>2]=qA(t[(t[o>>2]|0)+28>>2]|0,79144)|0;if(t[a>>2]|0){t[u>>2]=us(t[u>>2]|0,79136)|0;t[u>>2]=us(t[u>>2]|0,t[a>>2]|0)|0;pAi[t[135736>>2]&511](t[a>>2]|0);break}JA(79040);xA(t[o>>2]|0);t[n>>2]=0;b=t[n>>2]|0;s=i;return b|0}}else{t[u>>2]=us(t[u>>2]|0,79136)|0;t[u>>2]=us(t[u>>2]|0,t[(t[o>>2]|0)+40>>2]|0)|0}while(0);do if(t[(t[o>>2]|0)+4>>2]|0){t[a>>2]=qA(t[(t[o>>2]|0)+4>>2]|0,79160)|0;if(t[a>>2]|0){t[u>>2]=us(t[u>>2]|0,t[a>>2]|0)|0;pAi[t[135736>>2]&511](t[a>>2]|0);break}JA(79040);xA(t[o>>2]|0);t[n>>2]=0;b=t[n>>2]|0;s=i;return b|0}while(0);do if(t[(t[o>>2]|0)+32>>2]|0){t[a>>2]=qA(t[(t[o>>2]|0)+32>>2]|0,79168)|0;if(t[a>>2]|0){t[u>>2]=us(t[u>>2]|0,79168)|0;t[u>>2]=us(t[u>>2]|0,t[a>>2]|0)|0;pAi[t[135736>>2]&511](t[a>>2]|0);break}JA(79040);xA(t[o>>2]|0);t[n>>2]=0;b=t[n>>2]|0;s=i;return b|0}while(0);xA(t[o>>2]|0);t[n>>2]=t[u>>2];b=t[n>>2]|0;s=i;return b|0}function GA(e,i){e=e|0;i=i|0;var r=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0;r=s;s=s+48|0;f=r+40|0;u=r+36|0;a=r+32|0;o=r+28|0;c=r+24|0;l=r+20|0;b=r+16|0;k=r+12|0;h=r+8|0;w=r+4|0;d=r;t[f>>2]=e;t[u>>2]=i;t[a>>2]=0;t[h>>2]=0;t[w>>2]=0;t[d>>2]=0;do if(t[f>>2]|0){if(!(n[t[f>>2]>>0]|0)){t[o>>2]=0;v=7;break}t[h>>2]=HA()|0;if(t[h>>2]|0){t[o>>2]=UA(t[h>>2]|0,t[f>>2]|0)|0;v=7}}else{t[o>>2]=-1;v=7}while(0);e:do if((v|0)==7?(t[o>>2]|0)==0:0){if((t[h>>2]|0)!=0?(t[t[h>>2]>>2]|0)!=0:0){t[a>>2]=Yl(t[f>>2]|0)|0;break}if(!(t[u>>2]|0))t[o>>2]=-1;else{t[w>>2]=HA()|0;if(!(t[w>>2]|0))break;t[o>>2]=UA(t[w>>2]|0,t[u>>2]|0)|0}i=t[h>>2]|0;if(t[o>>2]|0){if(!i)break;t[a>>2]=zA(t[h>>2]|0)|0;break}if(!i){if(t[(t[w>>2]|0)+32>>2]|0){pAi[t[135736>>2]&511](t[(t[w>>2]|0)+32>>2]|0);t[(t[w>>2]|0)+32>>2]=0}t[a>>2]=zA(t[w>>2]|0)|0;break}t[d>>2]=HA()|0;if(t[d>>2]|0){if((((t[t[h>>2]>>2]|0)==0?(t[(t[h>>2]|0)+24>>2]|0)==0:0)?(t[(t[h>>2]|0)+8>>2]|0)==0:0)?(t[(t[h>>2]|0)+12>>2]|0)==0:0){if(t[t[w>>2]>>2]|0){i=gAi[t[135768>>2]&511](t[t[w>>2]>>2]|0)|0;t[t[d>>2]>>2]=i}if(!(t[(t[w>>2]|0)+8>>2]|0)){if(t[(t[w>>2]|0)+12>>2]|0){i=gAi[t[135768>>2]&511](t[(t[w>>2]|0)+12>>2]|0)|0;t[(t[d>>2]|0)+12>>2]=i;if(t[(t[w>>2]|0)+16>>2]|0){i=gAi[t[135768>>2]&511](t[(t[w>>2]|0)+16>>2]|0)|0;t[(t[d>>2]|0)+16>>2]=i}t[(t[d>>2]|0)+20>>2]=t[(t[w>>2]|0)+20>>2]}}else{i=gAi[t[135768>>2]&511](t[(t[w>>2]|0)+8>>2]|0)|0;t[(t[d>>2]|0)+8>>2]=i}if(t[(t[w>>2]|0)+24>>2]|0){i=gAi[t[135768>>2]&511](t[(t[w>>2]|0)+24>>2]|0)|0;t[(t[d>>2]|0)+24>>2]=i}do if(t[(t[h>>2]|0)+40>>2]|0){i=gAi[t[135768>>2]&511](t[(t[h>>2]|0)+40>>2]|0)|0;t[(t[d>>2]|0)+40>>2]=i}else{if(t[(t[h>>2]|0)+28>>2]|0){i=gAi[t[135768>>2]&511](t[(t[h>>2]|0)+28>>2]|0)|0;t[(t[d>>2]|0)+28>>2]=i;break}if(t[(t[w>>2]|0)+40>>2]|0){i=gAi[t[135768>>2]&511](t[(t[w>>2]|0)+40>>2]|0)|0;t[(t[d>>2]|0)+40>>2]=i;break}if(!(t[(t[w>>2]|0)+28>>2]|0))break;i=gAi[t[135768>>2]&511](t[(t[w>>2]|0)+28>>2]|0)|0;t[(t[d>>2]|0)+28>>2]=i}while(0);if(t[(t[h>>2]|0)+32>>2]|0){i=gAi[t[135768>>2]&511](t[(t[h>>2]|0)+32>>2]|0)|0;t[(t[d>>2]|0)+32>>2]=i}}else v=47;i:do if((v|0)==47){if(t[t[h>>2]>>2]|0){t[a>>2]=zA(t[h>>2]|0)|0;break e}if(t[t[w>>2]>>2]|0){i=gAi[t[135768>>2]&511](t[t[w>>2]>>2]|0)|0;t[t[d>>2]>>2]=i}if(!(t[(t[h>>2]|0)+40>>2]|0)){if(t[(t[h>>2]|0)+28>>2]|0){i=gAi[t[135768>>2]&511](t[(t[h>>2]|0)+28>>2]|0)|0;t[(t[d>>2]|0)+28>>2]=i}}else{i=gAi[t[135768>>2]&511](t[(t[h>>2]|0)+40>>2]|0)|0;t[(t[d>>2]|0)+40>>2]=i}if(t[(t[h>>2]|0)+32>>2]|0){i=gAi[t[135768>>2]&511](t[(t[h>>2]|0)+32>>2]|0)|0;t[(t[d>>2]|0)+32>>2]=i}if((t[(t[h>>2]|0)+8>>2]|0)==0?(t[(t[h>>2]|0)+12>>2]|0)==0:0){if(!(t[(t[w>>2]|0)+8>>2]|0)){if(t[(t[w>>2]|0)+12>>2]|0){i=gAi[t[135768>>2]&511](t[(t[w>>2]|0)+12>>2]|0)|0;t[(t[d>>2]|0)+12>>2]=i;if(t[(t[w>>2]|0)+16>>2]|0){i=gAi[t[135768>>2]&511](t[(t[w>>2]|0)+16>>2]|0)|0;t[(t[d>>2]|0)+16>>2]=i}t[(t[d>>2]|0)+20>>2]=t[(t[w>>2]|0)+20>>2]}}else{i=gAi[t[135768>>2]&511](t[(t[w>>2]|0)+8>>2]|0)|0;t[(t[d>>2]|0)+8>>2]=i}do if(t[(t[h>>2]|0)+24>>2]|0){if((n[t[(t[h>>2]|0)+24>>2]>>0]|0)!=47)break;i=gAi[t[135768>>2]&511](t[(t[h>>2]|0)+24>>2]|0)|0;t[(t[d>>2]|0)+24>>2]=i;break i}while(0);t[c>>2]=2;if(t[(t[h>>2]|0)+24>>2]|0){i=HY(t[(t[h>>2]|0)+24>>2]|0)|0;t[c>>2]=(t[c>>2]|0)+i}if(t[(t[w>>2]|0)+24>>2]|0){i=HY(t[(t[w>>2]|0)+24>>2]|0)|0;t[c>>2]=(t[c>>2]|0)+i}i=gAi[t[135752>>2]&511](t[c>>2]|0)|0;t[(t[d>>2]|0)+24>>2]=i;if(!(t[(t[d>>2]|0)+24>>2]|0)){JA(79176);break e}n[t[(t[d>>2]|0)+24>>2]>>0]=0;t[b>>2]=0;t[k>>2]=0;r:do if(t[(t[w>>2]|0)+24>>2]|0)n:while(1){if(!(n[(t[(t[w>>2]|0)+24>>2]|0)+(t[b>>2]|0)>>0]|0))break r;while(1){if(n[(t[(t[w>>2]|0)+24>>2]|0)+(t[b>>2]|0)>>0]|0)m=(n[(t[(t[w>>2]|0)+24>>2]|0)+(t[b>>2]|0)>>0]|0)!=47;else m=0;_=t[b>>2]|0;if(!m)break;t[b>>2]=_+1}if(!(n[(t[(t[w>>2]|0)+24>>2]|0)+_>>0]|0))break r;t[b>>2]=(t[b>>2]|0)+1;while(1){if((t[k>>2]|0)>=(t[b>>2]|0))continue n;n[(t[(t[d>>2]|0)+24>>2]|0)+(t[k>>2]|0)>>0]=n[(t[(t[w>>2]|0)+24>>2]|0)+(t[k>>2]|0)>>0]|0;t[k>>2]=(t[k>>2]|0)+1}}while(0);n[(t[(t[d>>2]|0)+24>>2]|0)+(t[k>>2]|0)>>0]=0;r:do if(t[(t[h>>2]|0)+24>>2]|0){if(!(n[t[(t[h>>2]|0)+24>>2]>>0]|0))break;t[l>>2]=0;do if(!(t[k>>2]|0)){if(!(t[(t[w>>2]|0)+12>>2]|0))break;i=t[k>>2]|0;t[k>>2]=i+1;n[(t[(t[d>>2]|0)+24>>2]|0)+i>>0]=47}while(0);while(1){if(!(n[(t[(t[h>>2]|0)+24>>2]|0)+(t[l>>2]|0)>>0]|0))break r;i=t[l>>2]|0;t[l>>2]=i+1;e=n[(t[(t[h>>2]|0)+24>>2]|0)+i>>0]|0;i=t[k>>2]|0;t[k>>2]=i+1;n[(t[(t[d>>2]|0)+24>>2]|0)+i>>0]=e}}while(0);n[(t[(t[d>>2]|0)+24>>2]|0)+(t[k>>2]|0)>>0]=0;jA(t[(t[d>>2]|0)+24>>2]|0)|0;break}e=t[33942]|0;i=t[h>>2]|0;if(t[(t[h>>2]|0)+8>>2]|0){p=gAi[e&511](t[i+8>>2]|0)|0;t[(t[d>>2]|0)+8>>2]=p}else{p=gAi[e&511](t[i+12>>2]|0)|0;t[(t[d>>2]|0)+12>>2]=p;if(t[(t[h>>2]|0)+16>>2]|0){p=gAi[t[135768>>2]&511](t[(t[h>>2]|0)+16>>2]|0)|0;t[(t[d>>2]|0)+16>>2]=p}t[(t[d>>2]|0)+20>>2]=t[(t[h>>2]|0)+20>>2]}if(t[(t[h>>2]|0)+24>>2]|0){p=gAi[t[135768>>2]&511](t[(t[h>>2]|0)+24>>2]|0)|0;t[(t[d>>2]|0)+24>>2]=p}}while(0);t[a>>2]=zA(t[d>>2]|0)|0}}while(0);if(t[h>>2]|0)xA(t[h>>2]|0);if(t[w>>2]|0)xA(t[w>>2]|0);if(!(t[d>>2]|0)){E=t[a>>2]|0;s=r;return E|0}xA(t[d>>2]|0);E=t[a>>2]|0;s=r;return E|0}function WA(e,i){e=e|0;i=i|0;var r=0,f=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0,S=0,g=0,y=0,F=0;r=s;s=s+64|0;f=r+56|0;a=r+52|0;o=r+48|0;c=r+44|0;l=r+40|0;b=r+36|0;k=r+32|0;h=r+28|0;w=r+24|0;d=r+20|0;v=r+16|0;m=r+12|0;_=r+8|0;p=r+4|0;E=r;t[a>>2]=e;t[o>>2]=i;t[c>>2]=0;t[k>>2]=0;t[h>>2]=0;t[d>>2]=0;t[v>>2]=0;t[E>>2]=0;if((t[a>>2]|0)!=0?(u[t[a>>2]>>0]|0)!=0:0){t[d>>2]=HA()|0;if(!(t[d>>2]|0)){t[f>>2]=0;S=t[f>>2]|0;s=r;return S|0}if((u[t[a>>2]>>0]|0)!=46){t[l>>2]=UA(t[d>>2]|0,t[a>>2]|0)|0;if(!(t[l>>2]|0))g=9}else{i=Yl(t[a>>2]|0)|0;t[(t[d>>2]|0)+24>>2]=i;g=9}e:do if((g|0)==9){if((t[o>>2]|0)!=0?(u[t[o>>2]>>0]|0)!=0:0){t[v>>2]=HA()|0;if(!(t[v>>2]|0))break;if((u[t[o>>2]>>0]|0)!=46){t[l>>2]=UA(t[v>>2]|0,t[o>>2]|0)|0;if(t[l>>2]|0)break}else{i=Yl(t[o>>2]|0)|0;t[(t[v>>2]|0)+24>>2]=i}do if(t[t[d>>2]>>2]|0){if(((t[t[v>>2]>>2]|0)!=0?(Kl(t[t[v>>2]>>2]|0,t[t[d>>2]>>2]|0)|0)==0:0)?(Kl(t[(t[v>>2]|0)+12>>2]|0,t[(t[d>>2]|0)+12>>2]|0)|0)==0:0)break;t[c>>2]=Yl(t[a>>2]|0)|0;break e}while(0);if(Xl(t[(t[v>>2]|0)+24>>2]|0,t[(t[d>>2]|0)+24>>2]|0)|0){t[c>>2]=Yl(79160)|0;break}i=t[(t[d>>2]|0)+24>>2]|0;if(!(t[(t[v>>2]|0)+24>>2]|0)){t[c>>2]=Yl(i)|0;break}if(!i){t[(t[d>>2]|0)+24>>2]=79208;t[E>>2]=1}if(!(t[(t[v>>2]|0)+24>>2]|0)){if(!(t[(t[d>>2]|0)+24>>2]|0))break;t[_>>2]=t[(t[d>>2]|0)+24>>2];if((u[t[_>>2]>>0]|0)==47)t[_>>2]=(t[_>>2]|0)+1;t[c>>2]=qA(t[_>>2]|0,79216)|0;break}t[m>>2]=t[(t[v>>2]|0)+24>>2];if(!(t[(t[d>>2]|0)+24>>2]|0)){t[b>>2]=0;while(1){if(!(u[(t[m>>2]|0)+(t[b>>2]|0)>>0]|0))break;if((u[(t[m>>2]|0)+(t[b>>2]|0)>>0]|0)==47)t[h>>2]=(t[h>>2]|0)+1;t[b>>2]=(t[b>>2]|0)+1}t[_>>2]=0;t[w>>2]=1}else{do if((n[(t[(t[d>>2]|0)+24>>2]|0)+(t[k>>2]|0)>>0]|0)==46){if((n[(t[(t[d>>2]|0)+24>>2]|0)+((t[k>>2]|0)+1)>>0]|0)!=47)break;t[k>>2]=(t[k>>2]|0)+2}while(0);do if((u[t[m>>2]>>0]|0)==46){if((u[(t[m>>2]|0)+1>>0]|0)!=47){g=45;break}t[m>>2]=(t[m>>2]|0)+2}else g=45;while(0);do if((g|0)==45){if((u[t[m>>2]>>0]|0)!=47)break;if((n[(t[(t[d>>2]|0)+24>>2]|0)+(t[k>>2]|0)>>0]|0)==47)break;t[m>>2]=(t[m>>2]|0)+1}while(0);while(1){if((u[(t[m>>2]|0)+(t[k>>2]|0)>>0]|0)==(n[(t[(t[d>>2]|0)+24>>2]|0)+(t[k>>2]|0)>>0]|0))y=(u[(t[m>>2]|0)+(t[k>>2]|0)>>0]|0)!=0;else y=0;F=t[k>>2]|0;if(!y)break;t[k>>2]=F+1}if((u[(t[m>>2]|0)+F>>0]|0)==(n[(t[(t[d>>2]|0)+24>>2]|0)+(t[k>>2]|0)>>0]|0)){t[c>>2]=Yl(79160)|0;break}t[b>>2]=t[k>>2];i=t[b>>2]|0;do if((t[b>>2]|0)>0?(n[(t[(t[d>>2]|0)+24>>2]|0)+(t[b>>2]|0)>>0]|0)==47:0)t[b>>2]=i+-1;else{if(!((t[b>>2]|0)>1?(n[(t[(t[d>>2]|0)+24>>2]|0)+i>>0]|0)==0:0))break;if((n[(t[(t[d>>2]|0)+24>>2]|0)+((t[b>>2]|0)-1)>>0]|0)!=47)break;t[b>>2]=(t[b>>2]|0)-2}while(0);while(1){if((t[b>>2]|0)<=0)break;if((n[(t[(t[d>>2]|0)+24>>2]|0)+(t[b>>2]|0)>>0]|0)==47)break;t[b>>2]=(t[b>>2]|0)+-1}if(!(t[b>>2]|0))t[_>>2]=t[(t[d>>2]|0)+24>>2];else{t[b>>2]=(t[b>>2]|0)+1;t[_>>2]=(t[(t[d>>2]|0)+24>>2]|0)+(t[b>>2]|0)}i:do if((u[(t[m>>2]|0)+(t[k>>2]|0)>>0]|0)!=(n[(t[(t[d>>2]|0)+24>>2]|0)+(t[k>>2]|0)>>0]|0))while(1){if(!(u[(t[m>>2]|0)+(t[b>>2]|0)>>0]|0))break i;if((u[(t[m>>2]|0)+(t[b>>2]|0)>>0]|0)==47)t[h>>2]=(t[h>>2]|0)+1;t[b>>2]=(t[b>>2]|0)+1}while(0);t[w>>2]=(rs(t[_>>2]|0)|0)+1}if(!(t[h>>2]|0)){if(!(t[_>>2]|0))break;t[c>>2]=qA(t[_>>2]|0,79216)|0;break}t[c>>2]=gAi[t[135744>>2]&511]((t[w>>2]|0)+((t[h>>2]|0)*3|0)|0)|0;if(!(t[c>>2]|0)){JA(79224);break}t[p>>2]=t[c>>2];while(1){if((t[h>>2]|0)<=0)break;i=t[p>>2]|0;t[p>>2]=i+1;n[i>>0]=46;i=t[p>>2]|0;t[p>>2]=i+1;n[i>>0]=46;i=t[p>>2]|0;t[p>>2]=i+1;n[i>>0]=47;t[h>>2]=(t[h>>2]|0)+-1}i:do if(t[_>>2]|0){do if((t[w>>2]|0)>0?(t[p>>2]|0)>>>0>(t[c>>2]|0)>>>0:0){if((u[t[_>>2]>>0]|0)!=47)break;if((u[(t[p>>2]|0)+-1>>0]|0)!=47)break;YY(t[p>>2]|0,(t[_>>2]|0)+1|0,(t[w>>2]|0)-1|0)|0;n[(t[p>>2]|0)+((t[w>>2]|0)-2)>>0]=0;break i}while(0);YY(t[p>>2]|0,t[_>>2]|0,t[w>>2]|0)|0;n[(t[p>>2]|0)+((t[w>>2]|0)-1)>>0]=0}else n[(t[p>>2]|0)+((t[w>>2]|0)-1)>>0]=0;while(0);t[p>>2]=t[c>>2];t[c>>2]=qA(t[p>>2]|0,79216)|0;pAi[t[135736>>2]&511](t[p>>2]|0);break}t[c>>2]=Yl(t[a>>2]|0)|0}while(0);if(t[E>>2]|0)t[(t[d>>2]|0)+24>>2]=0;if(t[d>>2]|0)xA(t[d>>2]|0);if(t[v>>2]|0)xA(t[v>>2]|0);t[f>>2]=t[c>>2];S=t[f>>2]|0;s=r;return S|0}t[f>>2]=0;S=t[f>>2]|0;s=r;return S|0}function KA(e){e=e|0;var i=0,r=0,f=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0;i=s;s=s+48|0;r=i+28|0;f=i+24|0;a=i+20|0;o=i+16|0;c=i+12|0;l=i+8|0;b=i+4|0;k=i+32|0;h=i;t[f>>2]=e;if(!(t[f>>2]|0)){t[r>>2]=0;w=t[r>>2]|0;s=i;return w|0}if(((u[t[f>>2]>>0]|0|0)==47?(u[(t[f>>2]|0)+1>>0]|0|0)==47:0)?(u[(t[f>>2]|0)+2>>0]|0|0)!=47:0)t[f>>2]=(t[f>>2]|0)+1;e=IA(t[f>>2]|0)|0;t[a>>2]=e;if(e){xA(t[a>>2]|0);t[r>>2]=Yl(t[f>>2]|0)|0;w=t[r>>2]|0;s=i;return w|0}t[c>>2]=is(t[f>>2]|0,79248)|0;e:do if((t[c>>2]|0)!=0?(t[l>>2]=(t[c>>2]|0)-(t[f>>2]|0),!((t[l>>2]|0)<=0|(t[l>>2]|0)>20)):0){t[b>>2]=0;while(1){if((t[b>>2]|0)>=(t[l>>2]|0))break;n[k>>0]=n[(t[f>>2]|0)+(t[b>>2]|0)>>0]|0;if(!((u[k>>0]|0|0)>=97?(u[k>>0]|0|0)<=122:0)){if((u[k>>0]|0|0)<65)break e;if((u[k>>0]|0|0)>90)break e}t[b>>2]=(t[b>>2]|0)+1}t[h>>2]=qA(t[f>>2]|0,79256)|0;if((t[h>>2]|0)!=0?(t[a>>2]=IA(t[h>>2]|0)|0,(t[a>>2]|0)!=0):0){xA(t[a>>2]|0);t[r>>2]=t[h>>2];w=t[r>>2]|0;s=i;return w|0}}while(0);t[o>>2]=Yl(t[f>>2]|0)|0;t[r>>2]=t[o>>2];w=t[r>>2]|0;s=i;return w|0}function XA(e){e=e|0;var i=0,r=0,n=0,f=0,u=0,a=0,o=0,c=0;i=s;s=s+64|0;r=i+60|0;n=i+56|0;f=i+52|0;u=i+8|0;a=i+4|0;o=i;t[n>>2]=e;if(!(t[n>>2]|0)){t[r>>2]=0;c=t[r>>2]|0;s=i;return c|0}e=IA(t[n>>2]|0)|0;t[f>>2]=e;if(e){xA(t[f>>2]|0);t[r>>2]=Yl(t[n>>2]|0)|0;c=t[r>>2]|0;s=i;return c|0}t[o>>2]=KA(t[n>>2]|0)|0;if(!(t[o>>2]|0)){t[r>>2]=0;c=t[r>>2]|0;s=i;return c|0}else{n=u+0|0;f=n+44|0;do{t[n>>2]=0;n=n+4|0}while((n|0)<(f|0));t[u+24>>2]=t[o>>2];t[a>>2]=zA(u)|0;pAi[t[135736>>2]&511](t[o>>2]|0);t[r>>2]=t[a>>2];c=t[r>>2]|0;s=i;return c|0}return 0}function ZA(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0;r=s;s=s+16|0;n=r+12|0;f=r+8|0;u=r+4|0;a=r;t[f>>2]=e;t[u>>2]=i;if(!(t[u>>2]|0)){t[n>>2]=-1;o=t[n>>2]|0;s=r;return o|0}eM(t[f>>2]|0);t[a>>2]=iM(t[f>>2]|0,t[u>>2]|0)|0;if((t[a>>2]|0)!=0?(eM(t[f>>2]|0),t[a>>2]=rM(t[f>>2]|0,t[u>>2]|0)|0,(t[a>>2]|0)!=0):0){eM(t[f>>2]|0);t[n>>2]=t[a>>2];o=t[n>>2]|0;s=r;return o|0}t[n>>2]=0;o=t[n>>2]|0;s=r;return o|0}function JA(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i;n=i+4|0;t[n>>2]=e;if(t[n>>2]|0){e=t[n>>2]|0;t[r>>2]=t[n>>2];cp(0,0,0,0,0,30,2,3,0,0,e,0,0,0,0,79320,r);s=i;return}else{cp(0,0,0,0,0,30,2,3,0,0,0,0,0,0,0,79352,r);s=i;return}}function QA(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0;r=s;s=s+32|0;n=r+16|0;f=r+12|0;u=r+8|0;a=r+4|0;o=r;t[f>>2]=e;t[u>>2]=i;if((t[t[u>>2]>>2]|0)>1048576){JA(79272);t[n>>2]=0;c=t[n>>2]|0;s=r;return c|0}t[o>>2]=t[t[u>>2]>>2]<<1;t[a>>2]=MAi[t[135760>>2]&511](t[f>>2]|0,(t[o>>2]|0)+1|0)|0;if(!(t[a>>2]|0)){JA(78984);t[n>>2]=0;c=t[n>>2]|0;s=r;return c|0}else{t[t[u>>2]>>2]=t[o>>2];t[n>>2]=t[a>>2];c=t[n>>2]|0;s=r;return c|0}return 0}function $A(e){e=e|0;var i=0,r=0,f=0,u=0,a=0;i=s;s=s+16|0;r=i;f=i+4|0;n[f>>0]=e;if(!((n[f>>0]|0)>=48?(n[f>>0]|0)<=57:0))u=3;do if((u|0)==3){if((n[f>>0]|0)>=97?(n[f>>0]|0)<=102:0)break;if((n[f>>0]|0)>=65?(n[f>>0]|0)<=70:0)break;t[r>>2]=0;a=t[r>>2]|0;s=i;return a|0}while(0);t[r>>2]=1;a=t[r>>2]|0;s=i;return a|0}function eM(e){e=e|0;var i=0,r=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if(!(t[r>>2]|0)){s=i;return}if(t[t[r>>2]>>2]|0)pAi[t[135736>>2]&511](t[t[r>>2]>>2]|0);t[t[r>>2]>>2]=0;if(t[(t[r>>2]|0)+12>>2]|0)pAi[t[135736>>2]&511](t[(t[r>>2]|0)+12>>2]|0);t[(t[r>>2]|0)+12>>2]=0;if(t[(t[r>>2]|0)+16>>2]|0)pAi[t[135736>>2]&511](t[(t[r>>2]|0)+16>>2]|0);t[(t[r>>2]|0)+16>>2]=0;if(t[(t[r>>2]|0)+24>>2]|0)pAi[t[135736>>2]&511](t[(t[r>>2]|0)+24>>2]|0);t[(t[r>>2]|0)+24>>2]=0;if(t[(t[r>>2]|0)+32>>2]|0)pAi[t[135736>>2]&511](t[(t[r>>2]|0)+32>>2]|0);t[(t[r>>2]|0)+32>>2]=0;if(t[(t[r>>2]|0)+4>>2]|0)pAi[t[135736>>2]&511](t[(t[r>>2]|0)+4>>2]|0);t[(t[r>>2]|0)+4>>2]=0;if(t[(t[r>>2]|0)+8>>2]|0)pAi[t[135736>>2]&511](t[(t[r>>2]|0)+8>>2]|0);t[(t[r>>2]|0)+8>>2]=0;if(t[(t[r>>2]|0)+28>>2]|0)pAi[t[135736>>2]&511](t[(t[r>>2]|0)+28>>2]|0);t[(t[r>>2]|0)+28>>2]=0;if(t[(t[r>>2]|0)+40>>2]|0)pAi[t[135736>>2]&511](t[(t[r>>2]|0)+40>>2]|0);t[(t[r>>2]|0)+40>>2]=0;s=i;return}function iM(e,i){e=e|0;i=i|0;var r=0,f=0,u=0,a=0,o=0;r=s;s=s+16|0;f=r+12|0;u=r+8|0;a=r+4|0;o=r;t[u>>2]=e;t[a>>2]=i;t[o>>2]=nM(t[u>>2]|0,a)|0;do if(!(t[o>>2]|0)){if((n[t[a>>2]>>0]|0)!=58){t[f>>2]=1;break}t[a>>2]=(t[a>>2]|0)+1;t[o>>2]=fM(t[u>>2]|0,a)|0;if(t[o>>2]|0){t[f>>2]=t[o>>2];break}if((n[t[a>>2]>>0]|0)==63?(t[a>>2]=(t[a>>2]|0)+1,t[o>>2]=tM(t[u>>2]|0,a)|0,(t[o>>2]|0)!=0):0){t[f>>2]=t[o>>2];break}if((n[t[a>>2]>>0]|0)==35?(t[a>>2]=(t[a>>2]|0)+1,t[o>>2]=uM(t[u>>2]|0,a)|0,(t[o>>2]|0)!=0):0){t[f>>2]=t[o>>2];break}if(n[t[a>>2]>>0]|0){eM(t[u>>2]|0);t[f>>2]=1;break}else{t[f>>2]=0;break}}else t[f>>2]=t[o>>2];while(0);s=r;return t[f>>2]|0}function rM(e,i){e=e|0;i=i|0;var r=0,f=0,u=0,a=0,o=0,c=0,l=0;r=s;s=s+16|0;f=r+12|0;u=r+8|0;a=r+4|0;o=r;t[u>>2]=e;t[a>>2]=i;if((n[t[a>>2]>>0]|0)==47?(n[(t[a>>2]|0)+1>>0]|0)==47:0){t[a>>2]=(t[a>>2]|0)+2;t[o>>2]=aM(t[u>>2]|0,a)|0;if(t[o>>2]|0){t[f>>2]=t[o>>2];c=t[f>>2]|0;s=r;return c|0}t[o>>2]=oM(t[u>>2]|0,a)|0;if(t[o>>2]|0){t[f>>2]=t[o>>2];c=t[f>>2]|0;s=r;return c|0}}else l=7;e:do if((l|0)==7){if((n[t[a>>2]>>0]|0)==47){t[o>>2]=cM(t[u>>2]|0,a)|0;if(!(t[o>>2]|0))break;t[f>>2]=t[o>>2];c=t[f>>2]|0;s=r;return c|0}if(!((n[t[a>>2]>>0]|0)>=97?(n[t[a>>2]>>0]|0)<=122:0))l=12;i:do if((l|0)==12){if((n[t[a>>2]>>0]|0)>=65?(n[t[a>>2]>>0]|0)<=90:0)break;if((n[t[a>>2]>>0]|0)>=48?(n[t[a>>2]>>0]|0)<=57:0)break;if((((n[t[a>>2]>>0]|0)!=45?(n[t[a>>2]>>0]|0)!=46:0)?(n[t[a>>2]>>0]|0)!=95:0)?(n[t[a>>2]>>0]|0)!=126:0){r:do if((n[t[a>>2]>>0]|0)==37){if(!((n[(t[a>>2]|0)+1>>0]|0)>=48?(n[(t[a>>2]|0)+1>>0]|0)<=57:0))l=23;do if((l|0)==23){if((n[(t[a>>2]|0)+1>>0]|0)>=97?(n[(t[a>>2]|0)+1>>0]|0)<=102:0)break;if((n[(t[a>>2]|0)+1>>0]|0)<65)break r;if((n[(t[a>>2]|0)+1>>0]|0)>70)break r}while(0);if((n[(t[a>>2]|0)+2>>0]|0)>=48?(n[(t[a>>2]|0)+2>>0]|0)<=57:0)break i;if((n[(t[a>>2]|0)+2>>0]|0)>=97?(n[(t[a>>2]|0)+2>>0]|0)<=102:0)break i;if((n[(t[a>>2]|0)+2>>0]|0)>=65?(n[(t[a>>2]|0)+2>>0]|0)<=70:0)break i}while(0);if((((((((n[t[a>>2]>>0]|0)!=33?(n[t[a>>2]>>0]|0)!=36:0)?(n[t[a>>2]>>0]|0)!=38:0)?(n[t[a>>2]>>0]|0)!=40:0)?(n[t[a>>2]>>0]|0)!=41:0)?(n[t[a>>2]>>0]|0)!=42:0)?(n[t[a>>2]>>0]|0)!=43:0)?(n[t[a>>2]>>0]|0)!=44:0){if((n[t[a>>2]>>0]|0)==59)break;if((n[t[a>>2]>>0]|0)==61)break;if((n[t[a>>2]>>0]|0)==39)break;if((n[t[a>>2]>>0]|0)==58)break;if((n[t[a>>2]>>0]|0)==64)break;if(!(t[u>>2]|0))break e;if(t[(t[u>>2]|0)+24>>2]|0)pAi[t[135736>>2]&511](t[(t[u>>2]|0)+24>>2]|0);t[(t[u>>2]|0)+24>>2]=0;break e}}}while(0);t[o>>2]=lM(t[u>>2]|0,a)|0;if(t[o>>2]|0){t[f>>2]=t[o>>2];c=t[f>>2]|0;s=r;return c|0}}while(0);if((n[t[a>>2]>>0]|0)==63?(t[a>>2]=(t[a>>2]|0)+1,t[o>>2]=tM(t[u>>2]|0,a)|0,(t[o>>2]|0)!=0):0){t[f>>2]=t[o>>2];c=t[f>>2]|0;s=r;return c|0}if((n[t[a>>2]>>0]|0)==35?(t[a>>2]=(t[a>>2]|0)+1,t[o>>2]=uM(t[u>>2]|0,a)|0,(t[o>>2]|0)!=0):0){t[f>>2]=t[o>>2];c=t[f>>2]|0;s=r;return c|0}if(n[t[a>>2]>>0]|0){eM(t[u>>2]|0);t[f>>2]=1;c=t[f>>2]|0;s=r;return c|0}else{t[f>>2]=0;c=t[f>>2]|0;s=r;return c|0}return 0}function nM(e,i){e=e|0;i=i|0;var r=0,f=0,u=0,a=0,o=0,c=0,l=0;r=s;s=s+16|0;f=r+12|0;u=r+8|0;a=r+4|0;o=r;t[u>>2]=e;t[a>>2]=i;if(!(t[a>>2]|0)){t[f>>2]=-1;c=t[f>>2]|0;s=r;return c|0}t[o>>2]=t[t[a>>2]>>2];if(!((n[t[o>>2]>>0]|0)>=97?(n[t[o>>2]>>0]|0)<=122:0))l=5;do if((l|0)==5){if((n[t[o>>2]>>0]|0)>=65?(n[t[o>>2]>>0]|0)<=90:0)break;t[f>>2]=2;c=t[f>>2]|0;s=r;return c|0}while(0);t[o>>2]=(t[o>>2]|0)+1;e:while(1){if(!((n[t[o>>2]>>0]|0)>=97?(n[t[o>>2]>>0]|0)<=122:0))l=11;do if((l|0)==11){l=0;if((n[t[o>>2]>>0]|0)>=65?(n[t[o>>2]>>0]|0)<=90:0)break;if((n[t[o>>2]>>0]|0)>=48?(n[t[o>>2]>>0]|0)<=57:0)break;if(((n[t[o>>2]>>0]|0)!=43?(n[t[o>>2]>>0]|0)!=45:0)?(n[t[o>>2]>>0]|0)!=46:0)break e}while(0);t[o>>2]=(t[o>>2]|0)+1}if(t[u>>2]|0){if(t[t[u>>2]>>2]|0)pAi[t[135736>>2]&511](t[t[u>>2]>>2]|0);l=ql(t[t[a>>2]>>2]|0,(t[o>>2]|0)-(t[t[a>>2]>>2]|0)|0)|0;t[t[u>>2]>>2]=l}t[t[a>>2]>>2]=t[o>>2];t[f>>2]=0;c=t[f>>2]|0;s=r;return c|0}function fM(e,i){e=e|0;i=i|0;var r=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0;r=s;s=s+32|0;f=r+16|0;u=r+12|0;a=r+8|0;o=r+4|0;c=r;t[u>>2]=e;t[a>>2]=i;t[o>>2]=t[t[a>>2]>>2];if((n[t[o>>2]>>0]|0)==47?(n[(t[o>>2]|0)+1>>0]|0)==47:0){t[o>>2]=(t[o>>2]|0)+2;t[c>>2]=aM(t[u>>2]|0,o)|0;if(t[c>>2]|0){t[f>>2]=t[c>>2];l=t[f>>2]|0;s=r;return l|0}if(!(t[(t[u>>2]|0)+12>>2]|0))t[(t[u>>2]|0)+20>>2]=-1;t[c>>2]=oM(t[u>>2]|0,o)|0;if(t[c>>2]|0){t[f>>2]=t[c>>2];l=t[f>>2]|0;s=r;return l|0}else{t[t[a>>2]>>2]=t[o>>2];t[f>>2]=0;l=t[f>>2]|0;s=r;return l|0}}e:do if((n[t[o>>2]>>0]|0)==47){t[c>>2]=cM(t[u>>2]|0,o)|0;if(t[c>>2]|0){t[f>>2]=t[c>>2];l=t[f>>2]|0;s=r;return l|0}}else{if(!((n[t[o>>2]>>0]|0)>=97?(n[t[o>>2]>>0]|0)<=122:0))b=15;i:do if((b|0)==15){if((n[t[o>>2]>>0]|0)>=65?(n[t[o>>2]>>0]|0)<=90:0)break;if((n[t[o>>2]>>0]|0)>=48?(n[t[o>>2]>>0]|0)<=57:0)break;if((((n[t[o>>2]>>0]|0)!=45?(n[t[o>>2]>>0]|0)!=46:0)?(n[t[o>>2]>>0]|0)!=95:0)?(n[t[o>>2]>>0]|0)!=126:0){r:do if((n[t[o>>2]>>0]|0)==37){if(!((n[(t[o>>2]|0)+1>>0]|0)>=48?(n[(t[o>>2]|0)+1>>0]|0)<=57:0))b=26;do if((b|0)==26){if((n[(t[o>>2]|0)+1>>0]|0)>=97?(n[(t[o>>2]|0)+1>>0]|0)<=102:0)break;if((n[(t[o>>2]|0)+1>>0]|0)<65)break r;if((n[(t[o>>2]|0)+1>>0]|0)>70)break r}while(0);if((n[(t[o>>2]|0)+2>>0]|0)>=48?(n[(t[o>>2]|0)+2>>0]|0)<=57:0)break i;if((n[(t[o>>2]|0)+2>>0]|0)>=97?(n[(t[o>>2]|0)+2>>0]|0)<=102:0)break i;if((n[(t[o>>2]|0)+2>>0]|0)>=65?(n[(t[o>>2]|0)+2>>0]|0)<=70:0)break i}while(0);if((((((((n[t[o>>2]>>0]|0)!=33?(n[t[o>>2]>>0]|0)!=36:0)?(n[t[o>>2]>>0]|0)!=38:0)?(n[t[o>>2]>>0]|0)!=40:0)?(n[t[o>>2]>>0]|0)!=41:0)?(n[t[o>>2]>>0]|0)!=42:0)?(n[t[o>>2]>>0]|0)!=43:0)?(n[t[o>>2]>>0]|0)!=44:0){if((n[t[o>>2]>>0]|0)==59)break;if((n[t[o>>2]>>0]|0)==61)break;if((n[t[o>>2]>>0]|0)==39)break;if((n[t[o>>2]>>0]|0)==58)break;if((n[t[o>>2]>>0]|0)==64)break;if(!(t[u>>2]|0))break e;if(t[(t[u>>2]|0)+24>>2]|0)pAi[t[135736>>2]&511](t[(t[u>>2]|0)+24>>2]|0);t[(t[u>>2]|0)+24>>2]=0;break e}}}while(0);t[c>>2]=sM(t[u>>2]|0,o)|0;if(t[c>>2]|0){t[f>>2]=t[c>>2];l=t[f>>2]|0;s=r;return l|0}}while(0);t[t[a>>2]>>2]=t[o>>2];t[f>>2]=0;l=t[f>>2]|0;s=r;return l|0}function tM(e,i){e=e|0;i=i|0;var r=0,f=0,u=0,a=0,o=0,c=0,l=0;r=s;s=s+16|0;f=r+12|0;u=r+8|0;a=r+4|0;o=r;t[u>>2]=e;t[a>>2]=i;if(!(t[a>>2]|0)){t[f>>2]=-1;c=t[f>>2]|0;s=r;return c|0}t[o>>2]=t[t[a>>2]>>2];e:while(1){if(!((n[t[o>>2]>>0]|0)>=97?(n[t[o>>2]>>0]|0)<=122:0))l=6;i:do if((l|0)==6){l=0;if((n[t[o>>2]>>0]|0)>=65?(n[t[o>>2]>>0]|0)<=90:0)break;if((n[t[o>>2]>>0]|0)>=48?(n[t[o>>2]>>0]|0)<=57:0)break;if((((n[t[o>>2]>>0]|0)!=45?(n[t[o>>2]>>0]|0)!=46:0)?(n[t[o>>2]>>0]|0)!=95:0)?(n[t[o>>2]>>0]|0)!=126:0){r:do if((n[t[o>>2]>>0]|0)==37){if(!((n[(t[o>>2]|0)+1>>0]|0)>=48?(n[(t[o>>2]|0)+1>>0]|0)<=57:0))l=17;do if((l|0)==17){l=0;if((n[(t[o>>2]|0)+1>>0]|0)>=97?(n[(t[o>>2]|0)+1>>0]|0)<=102:0)break;if((n[(t[o>>2]|0)+1>>0]|0)<65)break r;if((n[(t[o>>2]|0)+1>>0]|0)>70)break r}while(0);if((n[(t[o>>2]|0)+2>>0]|0)>=48?(n[(t[o>>2]|0)+2>>0]|0)<=57:0)break i;if((n[(t[o>>2]|0)+2>>0]|0)>=97?(n[(t[o>>2]|0)+2>>0]|0)<=102:0)break i;if((n[(t[o>>2]|0)+2>>0]|0)>=65?(n[(t[o>>2]|0)+2>>0]|0)<=70:0)break i}while(0);if(((((((((n[t[o>>2]>>0]|0)!=33?(n[t[o>>2]>>0]|0)!=36:0)?(n[t[o>>2]>>0]|0)!=38:0)?(n[t[o>>2]>>0]|0)!=40:0)?(n[t[o>>2]>>0]|0)!=41:0)?(n[t[o>>2]>>0]|0)!=42:0)?(n[t[o>>2]>>0]|0)!=43:0)?(n[t[o>>2]>>0]|0)!=44:0)?(n[t[o>>2]>>0]|0)!=59:0){if((n[t[o>>2]>>0]|0)==61)break;if((n[t[o>>2]>>0]|0)==39)break;if((n[t[o>>2]>>0]|0)==58)break;if((n[t[o>>2]>>0]|0)==64)break;if((n[t[o>>2]>>0]|0)==47)break;if((n[t[o>>2]>>0]|0)==63)break;if(!(t[u>>2]|0))break e;if(!(t[(t[u>>2]|0)+36>>2]&1))break e;if((n[t[o>>2]>>0]|0)==123)break;if((n[t[o>>2]>>0]|0)==125)break;if((n[t[o>>2]>>0]|0)==124)break;if((n[t[o>>2]>>0]|0)==92)break;if((n[t[o>>2]>>0]|0)==94)break;if((n[t[o>>2]>>0]|0)==91)break;if((n[t[o>>2]>>0]|0)==93)break;if((n[t[o>>2]>>0]|0)!=96)break e}}}while(0);i=t[o>>2]|0;if((n[t[o>>2]>>0]|0)==37){t[o>>2]=i+3;continue}else{t[o>>2]=i+1;continue}}if(t[u>>2]|0){if(t[(t[u>>2]|0)+28>>2]|0)pAi[t[135736>>2]&511](t[(t[u>>2]|0)+28>>2]|0);
	l=t[t[a>>2]>>2]|0;i=(t[o>>2]|0)-(t[t[a>>2]>>2]|0)|0;if(t[(t[u>>2]|0)+36>>2]&2){e=ql(l,i)|0;t[(t[u>>2]|0)+28>>2]=e}else{e=VA(l,i,0)|0;t[(t[u>>2]|0)+28>>2]=e}if(t[(t[u>>2]|0)+40>>2]|0)pAi[t[135736>>2]&511](t[(t[u>>2]|0)+40>>2]|0);e=ql(t[t[a>>2]>>2]|0,(t[o>>2]|0)-(t[t[a>>2]>>2]|0)|0)|0;t[(t[u>>2]|0)+40>>2]=e}t[t[a>>2]>>2]=t[o>>2];t[f>>2]=0;c=t[f>>2]|0;s=r;return c|0}function uM(e,i){e=e|0;i=i|0;var r=0,f=0,u=0,a=0,o=0,c=0,l=0;r=s;s=s+16|0;f=r+12|0;u=r+8|0;a=r+4|0;o=r;t[u>>2]=e;t[a>>2]=i;if(!(t[a>>2]|0)){t[f>>2]=-1;c=t[f>>2]|0;s=r;return c|0}t[o>>2]=t[t[a>>2]>>2];e:while(1){if(!((n[t[o>>2]>>0]|0)>=97?(n[t[o>>2]>>0]|0)<=122:0))l=6;i:do if((l|0)==6){l=0;if((n[t[o>>2]>>0]|0)>=65?(n[t[o>>2]>>0]|0)<=90:0)break;if((n[t[o>>2]>>0]|0)>=48?(n[t[o>>2]>>0]|0)<=57:0)break;if((((n[t[o>>2]>>0]|0)!=45?(n[t[o>>2]>>0]|0)!=46:0)?(n[t[o>>2]>>0]|0)!=95:0)?(n[t[o>>2]>>0]|0)!=126:0){r:do if((n[t[o>>2]>>0]|0)==37){if(!((n[(t[o>>2]|0)+1>>0]|0)>=48?(n[(t[o>>2]|0)+1>>0]|0)<=57:0))l=17;do if((l|0)==17){l=0;if((n[(t[o>>2]|0)+1>>0]|0)>=97?(n[(t[o>>2]|0)+1>>0]|0)<=102:0)break;if((n[(t[o>>2]|0)+1>>0]|0)<65)break r;if((n[(t[o>>2]|0)+1>>0]|0)>70)break r}while(0);if((n[(t[o>>2]|0)+2>>0]|0)>=48?(n[(t[o>>2]|0)+2>>0]|0)<=57:0)break i;if((n[(t[o>>2]|0)+2>>0]|0)>=97?(n[(t[o>>2]|0)+2>>0]|0)<=102:0)break i;if((n[(t[o>>2]|0)+2>>0]|0)>=65?(n[(t[o>>2]|0)+2>>0]|0)<=70:0)break i}while(0);if(((((((((n[t[o>>2]>>0]|0)!=33?(n[t[o>>2]>>0]|0)!=36:0)?(n[t[o>>2]>>0]|0)!=38:0)?(n[t[o>>2]>>0]|0)!=40:0)?(n[t[o>>2]>>0]|0)!=41:0)?(n[t[o>>2]>>0]|0)!=42:0)?(n[t[o>>2]>>0]|0)!=43:0)?(n[t[o>>2]>>0]|0)!=44:0)?(n[t[o>>2]>>0]|0)!=59:0){if((n[t[o>>2]>>0]|0)==61)break;if((n[t[o>>2]>>0]|0)==39)break;if((n[t[o>>2]>>0]|0)==58)break;if((n[t[o>>2]>>0]|0)==64)break;if((n[t[o>>2]>>0]|0)==47)break;if((n[t[o>>2]>>0]|0)==63)break;if((n[t[o>>2]>>0]|0)==91)break;if((n[t[o>>2]>>0]|0)==93)break;if(!(t[u>>2]|0))break e;if(!(t[(t[u>>2]|0)+36>>2]&1))break e;if((n[t[o>>2]>>0]|0)==123)break;if((n[t[o>>2]>>0]|0)==125)break;if((n[t[o>>2]>>0]|0)==124)break;if((n[t[o>>2]>>0]|0)==92)break;if((n[t[o>>2]>>0]|0)==94)break;if((n[t[o>>2]>>0]|0)==91)break;if((n[t[o>>2]>>0]|0)==93)break;if((n[t[o>>2]>>0]|0)!=96)break e}}}while(0);i=t[o>>2]|0;if((n[t[o>>2]>>0]|0)==37){t[o>>2]=i+3;continue}else{t[o>>2]=i+1;continue}}do if(t[u>>2]|0){if(t[(t[u>>2]|0)+32>>2]|0)pAi[t[135736>>2]&511](t[(t[u>>2]|0)+32>>2]|0);l=t[t[a>>2]>>2]|0;i=(t[o>>2]|0)-(t[t[a>>2]>>2]|0)|0;if(t[(t[u>>2]|0)+36>>2]&2){e=ql(l,i)|0;t[(t[u>>2]|0)+32>>2]=e;break}else{e=VA(l,i,0)|0;t[(t[u>>2]|0)+32>>2]=e;break}}while(0);t[t[a>>2]>>2]=t[o>>2];t[f>>2]=0;c=t[f>>2]|0;s=r;return c|0}function aM(e,i){e=e|0;i=i|0;var r=0,f=0,u=0,a=0,o=0,c=0,l=0;r=s;s=s+32|0;f=r+16|0;u=r+12|0;a=r+8|0;o=r+4|0;c=r;t[u>>2]=e;t[a>>2]=i;t[o>>2]=t[t[a>>2]>>2];t[c>>2]=bM(t[u>>2]|0,o)|0;if((t[c>>2]|0)==0?(n[t[o>>2]>>0]|0)==64:0)t[o>>2]=(t[o>>2]|0)+1;else t[o>>2]=t[t[a>>2]>>2];t[c>>2]=kM(t[u>>2]|0,o)|0;if(t[c>>2]|0){t[f>>2]=t[c>>2];l=t[f>>2]|0;s=r;return l|0}if((n[t[o>>2]>>0]|0)==58?(t[o>>2]=(t[o>>2]|0)+1,t[c>>2]=hM(t[u>>2]|0,o)|0,(t[c>>2]|0)!=0):0){t[f>>2]=t[c>>2];l=t[f>>2]|0;s=r;return l|0}t[t[a>>2]>>2]=t[o>>2];t[f>>2]=0;l=t[f>>2]|0;s=r;return l|0}function oM(e,i){e=e|0;i=i|0;var r=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0;r=s;s=s+32|0;f=r+16|0;u=r+12|0;a=r+8|0;o=r+4|0;c=r;t[u>>2]=e;t[a>>2]=i;t[o>>2]=t[t[a>>2]>>2];while(1){if((n[t[o>>2]>>0]|0)!=47)break;t[o>>2]=(t[o>>2]|0)+1;t[c>>2]=wM(o,0,1)|0;if(t[c>>2]|0){l=4;break}}if((l|0)==4){t[f>>2]=t[c>>2];b=t[f>>2]|0;s=r;return b|0}do if(t[u>>2]|0){if(t[(t[u>>2]|0)+24>>2]|0)pAi[t[135736>>2]&511](t[(t[u>>2]|0)+24>>2]|0);c=t[u>>2]|0;if((t[t[a>>2]>>2]|0)==(t[o>>2]|0)){t[c+24>>2]=0;break}l=t[t[a>>2]>>2]|0;i=(t[o>>2]|0)-(t[t[a>>2]>>2]|0)|0;if(t[c+36>>2]&2){c=ql(l,i)|0;t[(t[u>>2]|0)+24>>2]=c;break}else{c=VA(l,i,0)|0;t[(t[u>>2]|0)+24>>2]=c;break}}while(0);t[t[a>>2]>>2]=t[o>>2];t[f>>2]=0;b=t[f>>2]|0;s=r;return b|0}function cM(e,i){e=e|0;i=i|0;var r=0,f=0,u=0,a=0,o=0,c=0,l=0;r=s;s=s+32|0;f=r+16|0;u=r+12|0;a=r+8|0;o=r+4|0;c=r;t[u>>2]=e;t[a>>2]=i;t[o>>2]=t[t[a>>2]>>2];if((n[t[o>>2]>>0]|0)!=47){t[f>>2]=1;l=t[f>>2]|0;s=r;return l|0}t[o>>2]=(t[o>>2]|0)+1;t[c>>2]=wM(o,0,0)|0;e:do if(!(t[c>>2]|0)){do{if((n[t[o>>2]>>0]|0)!=47)break e;t[o>>2]=(t[o>>2]|0)+1;t[c>>2]=wM(o,0,1)|0}while((t[c>>2]|0)==0);t[f>>2]=t[c>>2];l=t[f>>2]|0;s=r;return l|0}while(0);do if(t[u>>2]|0){if(t[(t[u>>2]|0)+24>>2]|0)pAi[t[135736>>2]&511](t[(t[u>>2]|0)+24>>2]|0);c=t[u>>2]|0;if((t[o>>2]|0)==(t[t[a>>2]>>2]|0)){t[c+24>>2]=0;break}i=t[t[a>>2]>>2]|0;e=(t[o>>2]|0)-(t[t[a>>2]>>2]|0)|0;if(t[c+36>>2]&2){c=ql(i,e)|0;t[(t[u>>2]|0)+24>>2]=c;break}else{c=VA(i,e,0)|0;t[(t[u>>2]|0)+24>>2]=c;break}}while(0);t[t[a>>2]>>2]=t[o>>2];t[f>>2]=0;l=t[f>>2]|0;s=r;return l|0}function lM(e,i){e=e|0;i=i|0;var r=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0;r=s;s=s+32|0;f=r+16|0;u=r+12|0;a=r+8|0;o=r+4|0;c=r;t[u>>2]=e;t[a>>2]=i;t[o>>2]=t[t[a>>2]>>2];t[c>>2]=wM(o,58,0)|0;if(t[c>>2]|0){t[f>>2]=t[c>>2];l=t[f>>2]|0;s=r;return l|0}while(1){if((n[t[o>>2]>>0]|0)!=47)break;t[o>>2]=(t[o>>2]|0)+1;t[c>>2]=wM(o,0,1)|0;if(t[c>>2]|0){b=5;break}}if((b|0)==5){t[f>>2]=t[c>>2];l=t[f>>2]|0;s=r;return l|0}do if(t[u>>2]|0){if(t[(t[u>>2]|0)+24>>2]|0)pAi[t[135736>>2]&511](t[(t[u>>2]|0)+24>>2]|0);c=t[u>>2]|0;if((t[o>>2]|0)==(t[t[a>>2]>>2]|0)){t[c+24>>2]=0;break}b=t[t[a>>2]>>2]|0;i=(t[o>>2]|0)-(t[t[a>>2]>>2]|0)|0;if(t[c+36>>2]&2){c=ql(b,i)|0;t[(t[u>>2]|0)+24>>2]=c;break}else{c=VA(b,i,0)|0;t[(t[u>>2]|0)+24>>2]=c;break}}while(0);t[t[a>>2]>>2]=t[o>>2];t[f>>2]=0;l=t[f>>2]|0;s=r;return l|0}function sM(e,i){e=e|0;i=i|0;var r=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0;r=s;s=s+32|0;f=r+16|0;u=r+12|0;a=r+8|0;o=r+4|0;c=r;t[u>>2]=e;t[a>>2]=i;t[o>>2]=t[t[a>>2]>>2];t[c>>2]=wM(o,0,0)|0;if(t[c>>2]|0){t[f>>2]=t[c>>2];l=t[f>>2]|0;s=r;return l|0}while(1){if((n[t[o>>2]>>0]|0)!=47)break;t[o>>2]=(t[o>>2]|0)+1;t[c>>2]=wM(o,0,1)|0;if(t[c>>2]|0){b=5;break}}if((b|0)==5){t[f>>2]=t[c>>2];l=t[f>>2]|0;s=r;return l|0}do if(t[u>>2]|0){if(t[(t[u>>2]|0)+24>>2]|0)pAi[t[135736>>2]&511](t[(t[u>>2]|0)+24>>2]|0);c=t[u>>2]|0;if((t[o>>2]|0)==(t[t[a>>2]>>2]|0)){t[c+24>>2]=0;break}b=t[t[a>>2]>>2]|0;i=(t[o>>2]|0)-(t[t[a>>2]>>2]|0)|0;if(t[c+36>>2]&2){c=ql(b,i)|0;t[(t[u>>2]|0)+24>>2]=c;break}else{c=VA(b,i,0)|0;t[(t[u>>2]|0)+24>>2]=c;break}}while(0);t[t[a>>2]>>2]=t[o>>2];t[f>>2]=0;l=t[f>>2]|0;s=r;return l|0}function bM(e,i){e=e|0;i=i|0;var r=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0;r=s;s=s+16|0;f=r+12|0;u=r+8|0;a=r+4|0;o=r;t[u>>2]=e;t[a>>2]=i;t[o>>2]=t[t[a>>2]>>2];while(1){if((n[t[o>>2]>>0]|0)>=97?(n[t[o>>2]>>0]|0)<=122:0)c=1;else l=4;e:do if((l|0)==4){l=0;if((n[t[o>>2]>>0]|0)>=65?(n[t[o>>2]>>0]|0)<=90:0){c=1;break}if((n[t[o>>2]>>0]|0)>=48?(n[t[o>>2]>>0]|0)<=57:0){c=1;break}if((((n[t[o>>2]>>0]|0)!=45?(n[t[o>>2]>>0]|0)!=46:0)?(n[t[o>>2]>>0]|0)!=95:0)?(n[t[o>>2]>>0]|0)!=126:0){i:do if((n[t[o>>2]>>0]|0)==37){if(!((n[(t[o>>2]|0)+1>>0]|0)>=48?(n[(t[o>>2]|0)+1>>0]|0)<=57:0))l=15;do if((l|0)==15){l=0;if((n[(t[o>>2]|0)+1>>0]|0)>=97?(n[(t[o>>2]|0)+1>>0]|0)<=102:0)break;if((n[(t[o>>2]|0)+1>>0]|0)<65)break i;if((n[(t[o>>2]|0)+1>>0]|0)>70)break i}while(0);if((n[(t[o>>2]|0)+2>>0]|0)>=48?(n[(t[o>>2]|0)+2>>0]|0)<=57:0){c=1;break e}if((n[(t[o>>2]|0)+2>>0]|0)>=97?(n[(t[o>>2]|0)+2>>0]|0)<=102:0){c=1;break e}if((n[(t[o>>2]|0)+2>>0]|0)>=65?(n[(t[o>>2]|0)+2>>0]|0)<=70:0){c=1;break e}}while(0);if((((((((((n[t[o>>2]>>0]|0)!=33?(n[t[o>>2]>>0]|0)!=36:0)?(n[t[o>>2]>>0]|0)!=38:0)?(n[t[o>>2]>>0]|0)!=40:0)?(n[t[o>>2]>>0]|0)!=41:0)?(n[t[o>>2]>>0]|0)!=42:0)?(n[t[o>>2]>>0]|0)!=43:0)?(n[t[o>>2]>>0]|0)!=44:0)?(n[t[o>>2]>>0]|0)!=59:0)?(n[t[o>>2]>>0]|0)!=61:0){if((n[t[o>>2]>>0]|0)==39){c=1;break}c=(n[t[o>>2]>>0]|0)==58}else c=1}else c=1}while(0);b=n[t[o>>2]>>0]|0;if(!c)break;i=t[o>>2]|0;if((b|0)==37){t[o>>2]=i+3;continue}else{t[o>>2]=i+1;continue}}if((b|0)!=64){t[f>>2]=1;k=t[f>>2]|0;s=r;return k|0}do if(t[u>>2]|0){if(t[(t[u>>2]|0)+16>>2]|0)pAi[t[135736>>2]&511](t[(t[u>>2]|0)+16>>2]|0);b=t[t[a>>2]>>2]|0;c=(t[o>>2]|0)-(t[t[a>>2]>>2]|0)|0;if(t[(t[u>>2]|0)+36>>2]&2){l=ql(b,c)|0;t[(t[u>>2]|0)+16>>2]=l;break}else{l=VA(b,c,0)|0;t[(t[u>>2]|0)+16>>2]=l;break}}while(0);t[t[a>>2]>>2]=t[o>>2];t[f>>2]=0;k=t[f>>2]|0;s=r;return k|0}function kM(e,i){e=e|0;i=i|0;var r=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0;r=s;s=s+32|0;f=r+16|0;u=r+12|0;a=r+8|0;o=r+4|0;c=r;t[u>>2]=e;t[a>>2]=i;t[o>>2]=t[t[a>>2]>>2];t[c>>2]=t[o>>2];i=t[o>>2]|0;e:do if((n[t[o>>2]>>0]|0)==91){t[o>>2]=i+1;while(1){if((n[t[o>>2]>>0]|0)!=93)l=(n[t[o>>2]>>0]|0)!=0;else l=0;b=t[o>>2]|0;if(!l)break;t[o>>2]=b+1}if((n[b>>0]|0)==93){t[o>>2]=(t[o>>2]|0)+1;break}t[f>>2]=1;k=t[f>>2]|0;s=r;return k|0}else{if((n[i>>0]|0)>=48?(n[t[o>>2]>>0]|0)<=57:0){if(((((((dM(o)|0)==0?(n[t[o>>2]>>0]|0)==46:0)?(t[o>>2]=(t[o>>2]|0)+1,(dM(o)|0)==0):0)?(n[t[o>>2]>>0]|0)==46:0)?(dM(o)|0)==0:0)?(n[t[o>>2]>>0]|0)==46:0)?(dM(o)|0)==0:0)break;t[o>>2]=t[t[a>>2]>>2]}while(1){if(!((n[t[o>>2]>>0]|0)>=97?(n[t[o>>2]>>0]|0)<=122:0))h=22;i:do if((h|0)==22){h=0;if((n[t[o>>2]>>0]|0)>=65?(n[t[o>>2]>>0]|0)<=90:0)break;if((n[t[o>>2]>>0]|0)>=48?(n[t[o>>2]>>0]|0)<=57:0)break;if((((n[t[o>>2]>>0]|0)!=45?(n[t[o>>2]>>0]|0)!=46:0)?(n[t[o>>2]>>0]|0)!=95:0)?(n[t[o>>2]>>0]|0)!=126:0){r:do if((n[t[o>>2]>>0]|0)==37){if(!((n[(t[o>>2]|0)+1>>0]|0)>=48?(n[(t[o>>2]|0)+1>>0]|0)<=57:0))h=33;do if((h|0)==33){h=0;if((n[(t[o>>2]|0)+1>>0]|0)>=97?(n[(t[o>>2]|0)+1>>0]|0)<=102:0)break;if((n[(t[o>>2]|0)+1>>0]|0)<65)break r;if((n[(t[o>>2]|0)+1>>0]|0)>70)break r}while(0);if((n[(t[o>>2]|0)+2>>0]|0)>=48?(n[(t[o>>2]|0)+2>>0]|0)<=57:0)break i;if((n[(t[o>>2]|0)+2>>0]|0)>=97?(n[(t[o>>2]|0)+2>>0]|0)<=102:0)break i;if((n[(t[o>>2]|0)+2>>0]|0)>=65?(n[(t[o>>2]|0)+2>>0]|0)<=70:0)break i}while(0);if(((((((n[t[o>>2]>>0]|0)!=33?(n[t[o>>2]>>0]|0)!=36:0)?(n[t[o>>2]>>0]|0)!=38:0)?(n[t[o>>2]>>0]|0)!=40:0)?(n[t[o>>2]>>0]|0)!=41:0)?(n[t[o>>2]>>0]|0)!=42:0)?(n[t[o>>2]>>0]|0)!=43:0){if((n[t[o>>2]>>0]|0)==44)break;if((n[t[o>>2]>>0]|0)==59)break;if((n[t[o>>2]>>0]|0)==61)break;if((n[t[o>>2]>>0]|0)!=39)break e}}}while(0);e=t[o>>2]|0;if((n[t[o>>2]>>0]|0)==37){t[o>>2]=e+3;continue}else{t[o>>2]=e+1;continue}}}while(0);do if(t[u>>2]|0){if(t[(t[u>>2]|0)+8>>2]|0)pAi[t[135736>>2]&511](t[(t[u>>2]|0)+8>>2]|0);t[(t[u>>2]|0)+8>>2]=0;if(t[(t[u>>2]|0)+12>>2]|0)pAi[t[135736>>2]&511](t[(t[u>>2]|0)+12>>2]|0);h=t[u>>2]|0;if((t[o>>2]|0)==(t[c>>2]|0)){t[h+12>>2]=0;break}i=t[c>>2]|0;b=(t[o>>2]|0)-(t[c>>2]|0)|0;if(t[h+36>>2]&2){h=ql(i,b)|0;t[(t[u>>2]|0)+12>>2]=h;break}else{h=VA(i,b,0)|0;t[(t[u>>2]|0)+12>>2]=h;break}}while(0);t[t[a>>2]>>2]=t[o>>2];t[f>>2]=0;k=t[f>>2]|0;s=r;return k|0}function hM(e,i){e=e|0;i=i|0;var r=0,f=0,u=0,a=0,o=0,c=0;r=s;s=s+16|0;f=r+12|0;u=r+8|0;a=r+4|0;o=r;t[u>>2]=e;t[a>>2]=i;t[o>>2]=t[t[a>>2]>>2];if((n[t[o>>2]>>0]|0)>=48?(n[t[o>>2]>>0]|0)<=57:0){if(t[u>>2]|0)t[(t[u>>2]|0)+20>>2]=0;while(1){if((n[t[o>>2]>>0]|0)<48)break;if((n[t[o>>2]>>0]|0)>57)break;if(t[u>>2]|0)t[(t[u>>2]|0)+20>>2]=((t[(t[u>>2]|0)+20>>2]|0)*10|0)+((n[t[o>>2]>>0]|0)-48);t[o>>2]=(t[o>>2]|0)+1}t[t[a>>2]>>2]=t[o>>2];t[f>>2]=0;c=t[f>>2]|0;s=r;return c|0}t[f>>2]=1;c=t[f>>2]|0;s=r;return c|0}function wM(e,i,r){e=e|0;i=i|0;r=r|0;var f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0;f=s;s=s+32|0;u=f+12|0;a=f+8|0;o=f+16|0;c=f+4|0;l=f;t[a>>2]=e;n[o>>0]=i;t[c>>2]=r;t[l>>2]=t[t[a>>2]>>2];if(!((n[t[l>>2]>>0]|0)>=97?(n[t[l>>2]>>0]|0)<=122:0))b=3;e:do if((b|0)==3){if((n[t[l>>2]>>0]|0)>=65?(n[t[l>>2]>>0]|0)<=90:0)break;if((n[t[l>>2]>>0]|0)>=48?(n[t[l>>2]>>0]|0)<=57:0)break;if((((n[t[l>>2]>>0]|0)!=45?(n[t[l>>2]>>0]|0)!=46:0)?(n[t[l>>2]>>0]|0)!=95:0)?(n[t[l>>2]>>0]|0)!=126:0){i:do if((n[t[l>>2]>>0]|0)==37){if(!((n[(t[l>>2]|0)+1>>0]|0)>=48?(n[(t[l>>2]|0)+1>>0]|0)<=57:0))b=14;do if((b|0)==14){if((n[(t[l>>2]|0)+1>>0]|0)>=97?(n[(t[l>>2]|0)+1>>0]|0)<=102:0)break;if((n[(t[l>>2]|0)+1>>0]|0)<65)break i;if((n[(t[l>>2]|0)+1>>0]|0)>70)break i}while(0);if((n[(t[l>>2]|0)+2>>0]|0)>=48?(n[(t[l>>2]|0)+2>>0]|0)<=57:0)break e;if((n[(t[l>>2]|0)+2>>0]|0)>=97?(n[(t[l>>2]|0)+2>>0]|0)<=102:0)break e;if((n[(t[l>>2]|0)+2>>0]|0)>=65?(n[(t[l>>2]|0)+2>>0]|0)<=70:0)break e}while(0);if(((((((((((n[t[l>>2]>>0]|0)!=33?(n[t[l>>2]>>0]|0)!=36:0)?(n[t[l>>2]>>0]|0)!=38:0)?(n[t[l>>2]>>0]|0)!=40:0)?(n[t[l>>2]>>0]|0)!=41:0)?(n[t[l>>2]>>0]|0)!=42:0)?(n[t[l>>2]>>0]|0)!=43:0)?(n[t[l>>2]>>0]|0)!=44:0)?(n[t[l>>2]>>0]|0)!=59:0)?(n[t[l>>2]>>0]|0)!=61:0)?(n[t[l>>2]>>0]|0)!=39:0){if((n[t[l>>2]>>0]|0)==58)break;if((n[t[l>>2]>>0]|0)==64)break;if(t[c>>2]|0){t[u>>2]=0;k=t[u>>2]|0;s=f;return k|0}else{t[u>>2]=1;k=t[u>>2]|0;s=f;return k|0}}}}while(0);while(1){if((n[t[l>>2]>>0]|0)>=97?(n[t[l>>2]>>0]|0)<=122:0)b=76;else b=42;e:do if((b|0)==42){b=0;if((n[t[l>>2]>>0]|0)>=65?(n[t[l>>2]>>0]|0)<=90:0){b=76;break}if((n[t[l>>2]>>0]|0)>=48?(n[t[l>>2]>>0]|0)<=57:0){b=76;break}if((((n[t[l>>2]>>0]|0)!=45?(n[t[l>>2]>>0]|0)!=46:0)?(n[t[l>>2]>>0]|0)!=95:0)?(n[t[l>>2]>>0]|0)!=126:0){i:do if((n[t[l>>2]>>0]|0)==37){if(!((n[(t[l>>2]|0)+1>>0]|0)>=48?(n[(t[l>>2]|0)+1>>0]|0)<=57:0))b=53;do if((b|0)==53){b=0;if((n[(t[l>>2]|0)+1>>0]|0)>=97?(n[(t[l>>2]|0)+1>>0]|0)<=102:0)break;if((n[(t[l>>2]|0)+1>>0]|0)<65)break i;if((n[(t[l>>2]|0)+1>>0]|0)>70)break i}while(0);if((n[(t[l>>2]|0)+2>>0]|0)>=48?(n[(t[l>>2]|0)+2>>0]|0)<=57:0){b=76;break e}if((n[(t[l>>2]|0)+2>>0]|0)>=97?(n[(t[l>>2]|0)+2>>0]|0)<=102:0){b=76;break e}if((n[(t[l>>2]|0)+2>>0]|0)>=65?(n[(t[l>>2]|0)+2>>0]|0)<=70:0){b=76;break e}}while(0);if(((((((((n[t[l>>2]>>0]|0)!=33?(n[t[l>>2]>>0]|0)!=36:0)?(n[t[l>>2]>>0]|0)!=38:0)?(n[t[l>>2]>>0]|0)!=40:0)?(n[t[l>>2]>>0]|0)!=41:0)?(n[t[l>>2]>>0]|0)!=42:0)?(n[t[l>>2]>>0]|0)!=43:0)?(n[t[l>>2]>>0]|0)!=44:0)?(n[t[l>>2]>>0]|0)!=59:0){if((n[t[l>>2]>>0]|0)==61){b=76;break}if((n[t[l>>2]>>0]|0)==39){b=76;break}if((n[t[l>>2]>>0]|0)==58){b=76;break}if((n[t[l>>2]>>0]|0)!=64)h=0;else b=76}else b=76}else b=76}while(0);if((b|0)==76){b=0;h=(n[t[l>>2]>>0]|0)!=(n[o>>0]|0)}w=t[l>>2]|0;if(!h)break;c=t[l>>2]|0;if((n[w>>0]|0)==37){t[l>>2]=c+3;continue}else{t[l>>2]=c+1;continue}}t[t[a>>2]>>2]=w;t[u>>2]=0;k=t[u>>2]|0;s=f;return k|0}function dM(e){e=e|0;var i=0,r=0,f=0,u=0,a=0,o=0;i=s;s=s+16|0;r=i+8|0;f=i+4|0;u=i;t[f>>2]=e;t[u>>2]=t[t[f>>2]>>2];if((n[t[u>>2]>>0]|0)>=48?(n[t[u>>2]>>0]|0)<=57:0){e:do if((n[(t[u>>2]|0)+1>>0]|0)>=48?(n[(t[u>>2]|0)+1>>0]|0)<=57:0){do if(((n[t[u>>2]>>0]|0)!=48?(n[(t[u>>2]|0)+1>>0]|0)>=48:0)?(n[(t[u>>2]|0)+1>>0]|0)<=57:0){if((n[(t[u>>2]|0)+2>>0]|0)>=48?(n[(t[u>>2]|0)+2>>0]|0)<=57:0)break;t[u>>2]=(t[u>>2]|0)+2;break e}while(0);if(((((n[t[u>>2]>>0]|0)==49?(n[(t[u>>2]|0)+1>>0]|0)>=48:0)?(n[(t[u>>2]|0)+1>>0]|0)<=57:0)?(n[(t[u>>2]|0)+2>>0]|0)>=48:0)?(n[(t[u>>2]|0)+2>>0]|0)<=57:0){t[u>>2]=(t[u>>2]|0)+3;break}if(((((n[t[u>>2]>>0]|0)==50?(n[(t[u>>2]|0)+1>>0]|0)>=48:0)?(n[(t[u>>2]|0)+1>>0]|0)<=52:0)?(n[(t[u>>2]|0)+2>>0]|0)>=48:0)?(n[(t[u>>2]|0)+2>>0]|0)<=57:0){t[u>>2]=(t[u>>2]|0)+3;break}if((((n[t[u>>2]>>0]|0)==50?(n[(t[u>>2]|0)+1>>0]|0)==53:0)?(n[(t[u>>2]|0)+2>>0]|0)>=48:0)?(n[(t[u>>2]|0)+1>>0]|0)<=53:0){t[u>>2]=(t[u>>2]|0)+3;break}t[r>>2]=1;a=t[r>>2]|0;s=i;return a|0}else o=6;while(0);if((o|0)==6)t[u>>2]=(t[u>>2]|0)+1;t[t[f>>2]>>2]=t[u>>2];t[r>>2]=0;a=t[r>>2]|0;s=i;return a|0}t[r>>2]=1;a=t[r>>2]|0;s=i;return a|0}function vM(e,i){e=e|0;i=i|0;var r=0,f=0,u=0,a=0,o=0,c=0;r=s;s=s+5024|0;f=r+8|0;u=r+4|0;a=r;o=r+16|0;t[u>>2]=e;t[a>>2]=i;if((t[u>>2]|0)==0|(t[a>>2]|0)==0){t[f>>2]=0;c=t[f>>2]|0;s=r;return c|0}if((t[(t[a>>2]|0)+4>>2]|0)!=15){t[f>>2]=0;c=t[f>>2]|0;s=r;return c|0}if((t[(t[a>>2]|0)+36>>2]|0)!=4){t[f>>2]=1;c=t[f>>2]|0;s=r;return c|0}if(t[(t[a>>2]|0)+52>>2]|0)if(ib(t[(t[a>>2]|0)+52>>2]|0)|0){t[f>>2]=1;c=t[f>>2]|0;s=r;return c|0}else{t[(t[u>>2]|0)+36>>2]=0;t[f>>2]=0;c=t[f>>2]|0;s=r;return c|0}i=rb()|0;t[(t[u>>2]|0)+56>>2]=i;i=t[u>>2]|0;if(!(t[(t[u>>2]|0)+56>>2]|0)){ER(i,t[a>>2]|0,1,79384,t[(t[a>>2]|0)+8>>2]|0,0,0);t[f>>2]=0;c=t[f>>2]|0;s=r;return c|0}e=ub(t[i+56>>2]|0)|0;t[(t[u>>2]|0)+60>>2]=e;SR(t[(t[a>>2]|0)+40>>2]|0,t[u>>2]|0,t[(t[a>>2]|0)+8>>2]|0)|0;ab(t[(t[u>>2]|0)+56>>2]|0,t[(t[u>>2]|0)+60>>2]|0)|0;e=_b(t[(t[u>>2]|0)+56>>2]|0)|0;t[(t[a>>2]|0)+52>>2]=e;if((ib(t[(t[a>>2]|0)+52>>2]|0)|0)!=1){n[o>>0]=0;mM(o,5e3,t[(t[a>>2]|0)+40>>2]|0,1);ER(t[u>>2]|0,t[a>>2]|0,505,79424,t[(t[a>>2]|0)+8>>2]|0,o,0);t[(t[u>>2]|0)+36>>2]=0;t[(t[u>>2]|0)+60>>2]=0;nb(t[(t[u>>2]|0)+56>>2]|0);t[(t[u>>2]|0)+56>>2]=0;t[f>>2]=0;c=t[f>>2]|0;s=r;return c|0}else{t[(t[u>>2]|0)+60>>2]=0;nb(t[(t[u>>2]|0)+56>>2]|0);t[(t[u>>2]|0)+56>>2]=0;t[f>>2]=1;c=t[f>>2]|0;s=r;return c|0}return 0}function mM(e,i,r,f){e=e|0;i=i|0;r=r|0;f=f|0;var u=0,a=0,o=0,c=0,l=0,b=0,k=0;u=s;s=s+32|0;a=u+16|0;o=u+12|0;c=u+8|0;l=u+4|0;b=u;t[a>>2]=e;t[o>>2]=i;t[c>>2]=r;t[l>>2]=f;if(!(t[c>>2]|0)){s=u;return}t[b>>2]=HY(t[a>>2]|0)|0;if(((t[o>>2]|0)-(t[b>>2]|0)|0)<50){if(((t[o>>2]|0)-(t[b>>2]|0)|0)<=4){s=u;return}if((n[(t[a>>2]|0)+((t[b>>2]|0)-1)>>0]|0)==46){s=u;return}xY(t[a>>2]|0,79624)|0;s=u;return}if(t[l>>2]|0)xY(t[a>>2]|0,79632)|0;f=t[t[c>>2]>>2]|0;do if((f|0)==4){if((t[t[(t[c>>2]|0)+12>>2]>>2]|0)!=4?(t[t[(t[c>>2]|0)+12>>2]>>2]|0)!=3:0)mM(t[a>>2]|0,t[o>>2]|0,t[(t[c>>2]|0)+12>>2]|0,0);else mM(t[a>>2]|0,t[o>>2]|0,t[(t[c>>2]|0)+12>>2]|0,1);t[b>>2]=HY(t[a>>2]|0)|0;if(((t[o>>2]|0)-(t[b>>2]|0)|0)>=50){xY(t[a>>2]|0,79664)|0;if(!((t[t[(t[c>>2]|0)+16>>2]>>2]|0)!=3?(t[(t[(t[c>>2]|0)+16>>2]|0)+4>>2]|0)==1:0))k=41;if((k|0)==41?(t[t[(t[c>>2]|0)+16>>2]>>2]|0)!=2:0){mM(t[a>>2]|0,t[o>>2]|0,t[(t[c>>2]|0)+16>>2]|0,1);break}mM(t[a>>2]|0,t[o>>2]|0,t[(t[c>>2]|0)+16>>2]|0,0);break}if(((t[o>>2]|0)-(t[b>>2]|0)|0)<=4){s=u;return}if((n[(t[a>>2]|0)+((t[b>>2]|0)-1)>>0]|0)==46){s=u;return}xY(t[a>>2]|0,79624)|0;s=u;return}else if((f|0)==1)xY(t[a>>2]|0,79640)|0;else if((f|0)==3){if((t[t[(t[c>>2]|0)+12>>2]>>2]|0)!=4?(t[t[(t[c>>2]|0)+12>>2]>>2]|0)!=3:0)mM(t[a>>2]|0,t[o>>2]|0,t[(t[c>>2]|0)+12>>2]|0,0);else mM(t[a>>2]|0,t[o>>2]|0,t[(t[c>>2]|0)+12>>2]|0,1);t[b>>2]=HY(t[a>>2]|0)|0;if(((t[o>>2]|0)-(t[b>>2]|0)|0)>=50){xY(t[a>>2]|0,79656)|0;if(!((t[t[(t[c>>2]|0)+16>>2]>>2]|0)!=4?(t[(t[(t[c>>2]|0)+16>>2]|0)+4>>2]|0)==1:0))k=28;if((k|0)==28?(t[t[(t[c>>2]|0)+16>>2]>>2]|0)!=2:0){mM(t[a>>2]|0,t[o>>2]|0,t[(t[c>>2]|0)+16>>2]|0,1);break}mM(t[a>>2]|0,t[o>>2]|0,t[(t[c>>2]|0)+16>>2]|0,0);break}if(((t[o>>2]|0)-(t[b>>2]|0)|0)<=4){s=u;return}if((n[(t[a>>2]|0)+((t[b>>2]|0)-1)>>0]|0)==46){s=u;return}xY(t[a>>2]|0,79624)|0;s=u;return}else if((f|0)==2){do if(t[(t[c>>2]|0)+24>>2]|0){r=(t[o>>2]|0)-(t[b>>2]|0)|0;i=(r|0)<((rs(t[(t[c>>2]|0)+24>>2]|0)|0)+10|0);r=t[a>>2]|0;if(!i){xY(r|0,t[(t[c>>2]|0)+24>>2]|0)|0;xY(t[a>>2]|0,79648)|0;break}xY(r|0,79624)|0;s=u;return}while(0);r=(t[o>>2]|0)-(t[b>>2]|0)|0;if((r|0)<((rs(t[(t[c>>2]|0)+8>>2]|0)|0)+10|0)){xY(t[a>>2]|0,79624)|0;s=u;return}else{if(!(t[(t[c>>2]|0)+8>>2]|0))break;xY(t[a>>2]|0,t[(t[c>>2]|0)+8>>2]|0)|0;break}}while(0);if(t[l>>2]|0)xY(t[a>>2]|0,79672)|0;l=t[(t[c>>2]|0)+4>>2]|0;if((l|0)==3){xY(t[a>>2]|0,79688)|0;s=u;return}else if((l|0)==4){xY(t[a>>2]|0,79696)|0;s=u;return}else if((l|0)==2){xY(t[a>>2]|0,79680)|0;s=u;return}else{s=u;return}}function _M(){var e=0,i=0,r=0,n=0,f=0,u=0;e=s;s=s+16|0;i=e+4|0;r=e;n=gAi[t[135744>>2]&511](64)|0;t[r>>2]=n;if(!n){gR(0,79472);t[i>>2]=0;f=t[i>>2]|0;s=e;return f|0}else{n=(t[r>>2]|0)+0|0;u=n+64|0;do{t[n>>2]=0;n=n+4|0}while((n|0)<(u|0));t[i>>2]=t[r>>2];f=t[i>>2]|0;s=e;return f|0}return 0}function pM(e){e=e|0;var i=0,r=0,n=0,f=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if(t[(t[r>>2]|0)+52>>2]|0)pAi[t[135736>>2]&511](t[(t[r>>2]|0)+52>>2]|0);if(!(t[(t[r>>2]|0)+24>>2]|0)){n=t[33934]|0;f=t[r>>2]|0;pAi[n&511](f);s=i;return}pAi[t[135736>>2]&511](t[(t[r>>2]|0)+24>>2]|0);n=t[33934]|0;f=t[r>>2]|0;pAi[n&511](f);s=i;return}function EM(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0;n=s;s=s+32|0;f=n+28|0;u=n+24|0;a=n+20|0;o=n+16|0;c=n+12|0;l=n+8|0;b=n+4|0;k=n;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;t[l>>2]=0;if(t[u>>2]|0)t[l>>2]=t[(t[u>>2]|0)+80>>2];u=t[o>>2]|0;if((u|0)==4|(u|0)==3|(u|0)==1){if(t[a>>2]|0)yR(0,1,79528,0)}else if((u|0)==2){if(!(t[a>>2]|0))yR(0,1,79488,0)}else{yR(0,1,79568,0);t[f>>2]=0;h=t[f>>2]|0;s=n;return h|0}t[c>>2]=gAi[t[135744>>2]&511](28)|0;if(!(t[c>>2]|0)){gR(0,79472);t[f>>2]=0;h=t[f>>2]|0;s=n;return h|0}u=t[c>>2]|0;t[u+0>>2]=0;t[u+4>>2]=0;t[u+8>>2]=0;t[u+12>>2]=0;t[u+16>>2]=0;t[u+20>>2]=0;t[u+24>>2]=0;t[t[c>>2]>>2]=t[o>>2];t[(t[c>>2]|0)+4>>2]=1;do if(t[a>>2]|0){t[k>>2]=jg(t[a>>2]|0,b)|0;o=(t[l>>2]|0)==0;if(!(t[k>>2]|0))if(o){u=Yl(t[a>>2]|0)|0;t[(t[c>>2]|0)+8>>2]=u;break}else{u=kz(t[l>>2]|0,t[a>>2]|0,-1)|0;t[(t[c>>2]|0)+8>>2]=u;break}else if(o){o=ql(t[a>>2]|0,t[b>>2]|0)|0;t[(t[c>>2]|0)+24>>2]=o;o=Yl(t[k>>2]|0)|0;t[(t[c>>2]|0)+8>>2]=o;break}else{o=kz(t[l>>2]|0,t[a>>2]|0,t[b>>2]|0)|0;t[(t[c>>2]|0)+24>>2]=o;o=kz(t[l>>2]|0,t[k>>2]|0,-1)|0;t[(t[c>>2]|0)+8>>2]=o;break}}while(0);t[f>>2]=t[c>>2];h=t[f>>2]|0;s=n;return h|0}function SM(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0;r=s;s=s+32|0;n=r+24|0;f=r+20|0;u=r+16|0;a=r+12|0;o=r+8|0;c=r+4|0;l=r;t[f>>2]=e;t[u>>2]=i;t[a>>2]=0;t[o>>2]=0;t[l>>2]=0;if(!(t[u>>2]|0)){t[n>>2]=0;b=t[n>>2]|0;s=r;return b|0}if(t[f>>2]|0)t[l>>2]=t[(t[f>>2]|0)+80>>2];t[a>>2]=gAi[t[135744>>2]&511](28)|0;if(!(t[a>>2]|0)){gR(0,79472);t[n>>2]=0;b=t[n>>2]|0;s=r;return b|0}i=t[a>>2]|0;t[i+0>>2]=0;t[i+4>>2]=0;t[i+8>>2]=0;t[i+12>>2]=0;t[i+16>>2]=0;t[i+20>>2]=0;t[i+24>>2]=0;t[t[a>>2]>>2]=t[t[u>>2]>>2];t[(t[a>>2]|0)+4>>2]=t[(t[u>>2]|0)+4>>2];do if(t[(t[u>>2]|0)+8>>2]|0)if(t[l>>2]|0){i=kz(t[l>>2]|0,t[(t[u>>2]|0)+8>>2]|0,-1)|0;t[(t[a>>2]|0)+8>>2]=i;break}else{i=Yl(t[(t[u>>2]|0)+8>>2]|0)|0;t[(t[a>>2]|0)+8>>2]=i;break}while(0);do if(t[(t[u>>2]|0)+24>>2]|0)if(t[l>>2]|0){i=kz(t[l>>2]|0,t[(t[u>>2]|0)+24>>2]|0,-1)|0;t[(t[a>>2]|0)+24>>2]=i;break}else{i=Yl(t[(t[u>>2]|0)+24>>2]|0)|0;t[(t[a>>2]|0)+24>>2]=i;break}while(0);if(t[(t[u>>2]|0)+12>>2]|0){i=SM(t[f>>2]|0,t[(t[u>>2]|0)+12>>2]|0)|0;t[(t[a>>2]|0)+12>>2]=i}if(t[(t[a>>2]|0)+12>>2]|0)t[(t[(t[a>>2]|0)+12>>2]|0)+20>>2]=t[a>>2];e:do if(t[(t[u>>2]|0)+16>>2]|0){t[o>>2]=t[a>>2];t[u>>2]=t[(t[u>>2]|0)+16>>2];while(1){if(!(t[u>>2]|0))break e;t[c>>2]=gAi[t[135744>>2]&511](28)|0;if(!(t[c>>2]|0))break;i=t[c>>2]|0;t[i+0>>2]=0;t[i+4>>2]=0;t[i+8>>2]=0;t[i+12>>2]=0;t[i+16>>2]=0;t[i+20>>2]=0;t[i+24>>2]=0;t[t[c>>2]>>2]=t[t[u>>2]>>2];t[(t[c>>2]|0)+4>>2]=t[(t[u>>2]|0)+4>>2];t[(t[o>>2]|0)+16>>2]=t[c>>2];do if(t[(t[u>>2]|0)+8>>2]|0)if(t[l>>2]|0){i=kz(t[l>>2]|0,t[(t[u>>2]|0)+8>>2]|0,-1)|0;t[(t[c>>2]|0)+8>>2]=i;break}else{i=Yl(t[(t[u>>2]|0)+8>>2]|0)|0;t[(t[c>>2]|0)+8>>2]=i;break}while(0);do if(t[(t[u>>2]|0)+24>>2]|0)if(t[l>>2]|0){i=kz(t[l>>2]|0,t[(t[u>>2]|0)+24>>2]|0,-1)|0;t[(t[c>>2]|0)+24>>2]=i;break}else{i=Yl(t[(t[u>>2]|0)+24>>2]|0)|0;t[(t[c>>2]|0)+24>>2]=i;break}while(0);if(t[(t[u>>2]|0)+12>>2]|0){i=SM(t[f>>2]|0,t[(t[u>>2]|0)+12>>2]|0)|0;t[(t[c>>2]|0)+12>>2]=i}if(t[(t[c>>2]|0)+12>>2]|0)t[(t[(t[c>>2]|0)+12>>2]|0)+20>>2]=t[a>>2];t[o>>2]=t[c>>2];t[u>>2]=t[(t[u>>2]|0)+16>>2]}gR(0,79472);t[n>>2]=t[a>>2];b=t[n>>2]|0;s=r;return b|0}while(0);t[n>>2]=t[a>>2];b=t[n>>2]|0;s=r;return b|0}function gM(e){e=e|0;var i=0,r=0;i=s;s=s+16|0;r=i;t[r>>2]=e;e=SM(0,t[r>>2]|0)|0;s=i;return e|0}function yM(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0;r=s;s=s+16|0;n=r+12|0;f=r+8|0;u=r+4|0;a=r;t[n>>2]=e;t[f>>2]=i;t[a>>2]=0;if(t[n>>2]|0)t[a>>2]=t[(t[n>>2]|0)+80>>2];while(1){if(!(t[f>>2]|0)){o=20;break}t[u>>2]=t[(t[f>>2]|0)+16>>2];if(((t[t[f>>2]>>2]|0)+-1|0)>>>0>=4)break;if(t[(t[f>>2]|0)+12>>2]|0)yM(t[n>>2]|0,t[(t[f>>2]|0)+12>>2]|0);i=(t[(t[f>>2]|0)+8>>2]|0)!=0;if(t[a>>2]|0){if(i?(wz(t[a>>2]|0,t[(t[f>>2]|0)+8>>2]|0)|0)==0:0)pAi[t[135736>>2]&511](t[(t[f>>2]|0)+8>>2]|0);if((t[(t[f>>2]|0)+24>>2]|0)!=0?(wz(t[a>>2]|0,t[(t[f>>2]|0)+24>>2]|0)|0)==0:0)pAi[t[135736>>2]&511](t[(t[f>>2]|0)+24>>2]|0)}else{if(i)pAi[t[135736>>2]&511](t[(t[f>>2]|0)+8>>2]|0);if(t[(t[f>>2]|0)+24>>2]|0)pAi[t[135736>>2]&511](t[(t[f>>2]|0)+24>>2]|0)}pAi[t[135736>>2]&511](t[f>>2]|0);t[f>>2]=t[u>>2]}if((o|0)==20){s=r;return}yR(0,1,79568,0);s=r;return}function FM(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;var u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0;u=s;s=s+48|0;a=u+44|0;o=u+40|0;c=u+36|0;l=u+32|0;b=u+28|0;k=u+24|0;h=u+20|0;w=u+16|0;d=u+12|0;v=u+8|0;m=u+4|0;_=u;t[o>>2]=e;t[c>>2]=i;t[l>>2]=r;t[b>>2]=n;t[k>>2]=f;t[d>>2]=0;if(!(t[c>>2]|0)){t[a>>2]=0;p=t[a>>2]|0;s=u;return p|0}if(!(t[l>>2]|0)){t[a>>2]=0;p=t[a>>2]|0;s=u;return p|0}f=t[b>>2]|0;if((f|0)==1){if(t[k>>2]|0){yR(t[o>>2]|0,1,79704,0);t[a>>2]=0;p=t[a>>2]|0;s=u;return p|0}}else if((f|0)==4){if(!(t[k>>2]|0)){yR(t[o>>2]|0,1,79848,0);t[a>>2]=0;p=t[a>>2]|0;s=u;return p|0}}else if((f|0)==3){if(!(t[k>>2]|0)){yR(t[o>>2]|0,1,79800,0);t[a>>2]=0;p=t[a>>2]|0;s=u;return p|0}}else if((f|0)==2){if(t[k>>2]|0){yR(t[o>>2]|0,1,79752,0);t[a>>2]=0;p=t[a>>2]|0;s=u;return p|0}}else{yR(t[o>>2]|0,1,79896,0);t[a>>2]=0;p=t[a>>2]|0;s=u;return p|0}t[m>>2]=zg(t[l>>2]|0,v)|0;if(t[m>>2]|0)t[l>>2]=t[m>>2];t[w>>2]=t[(t[c>>2]|0)+40>>2];if(!(t[w>>2]|0)){t[_>>2]=0;if(t[(t[c>>2]|0)+32>>2]|0)t[_>>2]=t[(t[(t[c>>2]|0)+32>>2]|0)+80>>2];t[w>>2]=KF(0,t[_>>2]|0)|0;t[(t[c>>2]|0)+40>>2]=t[w>>2]}if(!(t[w>>2]|0)){gR(t[o>>2]|0,79944);if(t[m>>2]|0)pAi[t[135736>>2]&511](t[m>>2]|0);if(t[v>>2]|0)pAi[t[135736>>2]&511](t[v>>2]|0);t[a>>2]=0;p=t[a>>2]|0;s=u;return p|0}if((((t[(t[c>>2]|0)+32>>2]|0)!=0?(t[(t[(t[c>>2]|0)+32>>2]|0)+44>>2]|0)!=0:0)?(t[h>>2]=fO(t[(t[(t[(t[c>>2]|0)+32>>2]|0)+44>>2]|0)+40>>2]|0,t[l>>2]|0,t[v>>2]|0)|0,(t[h>>2]|0)!=0):0)?(t[(t[h>>2]|0)+36>>2]|0)==0:0){t[d>>2]=t[(t[h>>2]|0)+44>>2];t[(t[h>>2]|0)+44>>2]=0;wO(t[(t[(t[(t[c>>2]|0)+32>>2]|0)+44>>2]|0)+40>>2]|0,t[l>>2]|0,t[v>>2]|0,0)|0;FR(t[h>>2]|0)}t[h>>2]=fO(t[w>>2]|0,t[l>>2]|0,t[v>>2]|0)|0;do if(!(t[h>>2]|0)){t[h>>2]=gAi[t[135744>>2]&511](56)|0;if(!(t[h>>2]|0)){gR(t[o>>2]|0,79472);if(t[m>>2]|0)pAi[t[135736>>2]&511](t[m>>2]|0);if(t[v>>2]|0)pAi[t[135736>>2]&511](t[v>>2]|0);t[a>>2]=0;p=t[a>>2]|0;s=u;return p|0}_=(t[h>>2]|0)+0|0;f=_+56|0;do{t[_>>2]=0;_=_+4|0}while((_|0)<(f|0));t[(t[h>>2]|0)+4>>2]=15;_=Yl(t[l>>2]|0)|0;t[(t[h>>2]|0)+8>>2]=_;if(!(t[(t[h>>2]|0)+8>>2]|0)){gR(t[o>>2]|0,79472);if(t[m>>2]|0)pAi[t[135736>>2]&511](t[m>>2]|0);if(t[v>>2]|0)pAi[t[135736>>2]&511](t[v>>2]|0);pAi[t[135736>>2]&511](t[h>>2]|0);t[a>>2]=0;p=t[a>>2]|0;s=u;return p|0}else{t[(t[h>>2]|0)+48>>2]=t[v>>2];if(!(QF(t[w>>2]|0,t[l>>2]|0,t[v>>2]|0,t[h>>2]|0)|0)){t[(t[h>>2]|0)+44>>2]=t[d>>2];break}ER(t[o>>2]|0,t[c>>2]|0,509,79992,t[l>>2]|0,0,0);FR(t[h>>2]|0);if(t[m>>2]|0)pAi[t[135736>>2]&511](t[m>>2]|0);t[a>>2]=0;p=t[a>>2]|0;s=u;return p|0}}else{if(!(t[(t[h>>2]|0)+36>>2]|0)){if(!(t[v>>2]|0))break;pAi[t[135736>>2]&511](t[v>>2]|0);t[v>>2]=0;break}ER(t[o>>2]|0,t[c>>2]|0,509,79992,t[l>>2]|0,0,0);if(t[m>>2]|0)pAi[t[135736>>2]&511](t[m>>2]|0);if(t[v>>2]|0)pAi[t[135736>>2]&511](t[v>>2]|0);t[a>>2]=0;p=t[a>>2]|0;s=u;return p|0}while(0);t[(t[h>>2]|0)+36>>2]=t[b>>2];do if(t[o>>2]|0){if((t[(t[o>>2]|0)+28>>2]|0)!=-1412623820?(t[(t[o>>2]|0)+28>>2]|0)!=-1412623819:0){E=63;break}t[(t[h>>2]|0)+40>>2]=t[k>>2];if(t[k>>2]|0)t[(t[k>>2]|0)+20>>2]=1}else E=63;while(0);if((E|0)==63){E=SM(t[(t[c>>2]|0)+32>>2]|0,t[k>>2]|0)|0;t[(t[h>>2]|0)+40>>2]=E}t[(t[h>>2]|0)+20>>2]=t[c>>2];t[(t[h>>2]|0)+32>>2]=t[(t[c>>2]|0)+32>>2];E=t[h>>2]|0;k=(t[c>>2]|0)+16|0;if(!(t[(t[c>>2]|0)+16>>2]|0)){t[k>>2]=E;t[(t[c>>2]|0)+12>>2]=E}else{t[(t[k>>2]|0)+24>>2]=E;t[(t[h>>2]|0)+28>>2]=t[(t[c>>2]|0)+16>>2];t[(t[c>>2]|0)+16>>2]=t[h>>2]}if(t[m>>2]|0)pAi[t[135736>>2]&511](t[m>>2]|0);t[a>>2]=t[h>>2];p=t[a>>2]|0;s=u;return p|0}function OM(e){e=e|0;var i=0,r=0;i=s;s=s+16|0;r=i;t[r>>2]=e;XF(t[r>>2]|0,242);s=i;return}function AM(e){e=e|0;var i=0,r=0;i=s;s=s+16|0;r=i;t[r>>2]=e;e=sO(t[r>>2]|0,243)|0;s=i;return e|0}function MM(e,i){e=e|0;i=i|0;var r=0,n=0,f=0;r=s;s=s+16|0;n=r+4|0;f=r;t[n>>2]=e;t[f>>2]=i;if((t[n>>2]|0)==0|(t[f>>2]|0)==0){s=r;return}i=t[(t[f>>2]|0)+36>>2]|0;if((i|0)==3){NF(t[n>>2]|0,80024);if(t[(t[f>>2]|0)+48>>2]|0){RF(t[n>>2]|0,t[(t[f>>2]|0)+48>>2]|0);NF(t[n>>2]|0,79648)}RF(t[n>>2]|0,t[(t[f>>2]|0)+8>>2]|0);NF(t[n>>2]|0,80064);AR(t[n>>2]|0,t[(t[f>>2]|0)+40>>2]|0,1);NF(t[n>>2]|0,80072);s=r;return}else if((i|0)==4){NF(t[n>>2]|0,80024);if(t[(t[f>>2]|0)+48>>2]|0){RF(t[n>>2]|0,t[(t[f>>2]|0)+48>>2]|0);NF(t[n>>2]|0,79648)}RF(t[n>>2]|0,t[(t[f>>2]|0)+8>>2]|0);NF(t[n>>2]|0,80064);AR(t[n>>2]|0,t[(t[f>>2]|0)+40>>2]|0,1);NF(t[n>>2]|0,80072);s=r;return}else if((i|0)==1){NF(t[n>>2]|0,80024);if(t[(t[f>>2]|0)+48>>2]|0){RF(t[n>>2]|0,t[(t[f>>2]|0)+48>>2]|0);NF(t[n>>2]|0,79648)}RF(t[n>>2]|0,t[(t[f>>2]|0)+8>>2]|0);NF(t[n>>2]|0,80040);s=r;return}else if((i|0)==2){NF(t[n>>2]|0,80024);if(t[(t[f>>2]|0)+48>>2]|0){RF(t[n>>2]|0,t[(t[f>>2]|0)+48>>2]|0);NF(t[n>>2]|0,79648)}RF(t[n>>2]|0,t[(t[f>>2]|0)+8>>2]|0);NF(t[n>>2]|0,80056);s=r;return}else{yR(0,1,80080,0);s=r;return}}function RM(e){e=e|0;var i=0,r=0,n=0,f=0,u=0;i=s;s=s+16|0;r=i+8|0;n=i+4|0;f=i;t[n>>2]=e;t[f>>2]=gAi[t[135744>>2]&511](8)|0;if(!(t[f>>2]|0)){gR(0,79472);t[r>>2]=0;u=t[r>>2]|0;s=i;return u|0}e=t[f>>2]|0;t[e+0>>2]=0;t[e+4>>2]=0;if(t[n>>2]|0){e=Yl(t[n>>2]|0)|0;t[(t[f>>2]|0)+4>>2]=e}t[r>>2]=t[f>>2];u=t[r>>2]|0;s=i;return u|0}function NM(e){e=e|0;var i=0,r=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if(!(t[r>>2]|0)){s=i;return}if(t[t[r>>2]>>2]|0)NM(t[t[r>>2]>>2]|0);if(t[(t[r>>2]|0)+4>>2]|0)pAi[t[135736>>2]&511](t[(t[r>>2]|0)+4>>2]|0);pAi[t[135736>>2]&511](t[r>>2]|0);s=i;return}function TM(e){e=e|0;var i=0,r=0,n=0,f=0,u=0;i=s;s=s+16|0;r=i+8|0;n=i+4|0;f=i;t[n>>2]=e;if(!(t[n>>2]|0)){t[r>>2]=0;u=t[r>>2]|0;s=i;return u|0}t[f>>2]=RM(t[(t[n>>2]|0)+4>>2]|0)|0;if(!(t[f>>2]|0)){t[r>>2]=0;u=t[r>>2]|0;s=i;return u|0}if(t[t[n>>2]>>2]|0){e=TM(t[t[n>>2]>>2]|0)|0;t[t[f>>2]>>2]=e}else t[t[f>>2]>>2]=0;t[r>>2]=t[f>>2];u=t[r>>2]|0;s=i;return u|0}function LM(e,i,r,n,f,u,a,o,c){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;u=u|0;a=a|0;o=o|0;c=c|0;var l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0,S=0,g=0,y=0,F=0,O=0,A=0;l=s;s=s+64|0;b=l+56|0;k=l+52|0;h=l+48|0;w=l+44|0;d=l+40|0;v=l+36|0;m=l+32|0;_=l+28|0;p=l+24|0;E=l+20|0;S=l+16|0;g=l+12|0;y=l+8|0;F=l+4|0;O=l;t[k>>2]=e;t[h>>2]=i;t[w>>2]=r;t[d>>2]=n;t[v>>2]=f;t[m>>2]=u;t[_>>2]=a;t[p>>2]=o;t[E>>2]=c;t[F>>2]=0;if(!(t[h>>2]|0)){NM(t[E>>2]|0);t[b>>2]=0;A=t[b>>2]|0;s=l;return A|0}if(!(t[d>>2]|0)){NM(t[E>>2]|0);t[b>>2]=0;A=t[b>>2]|0;s=l;return A|0}if(!(t[w>>2]|0)){NM(t[E>>2]|0);t[b>>2]=0;A=t[b>>2]|0;s=l;return A|0}if(t[(t[h>>2]|0)+32>>2]|0)t[F>>2]=t[(t[(t[h>>2]|0)+32>>2]|0)+80>>2];if(((t[m>>2]|0)+-1|0)>>>0>=10){yR(t[k>>2]|0,1,80136,0);NM(t[E>>2]|0);t[b>>2]=0;A=t[b>>2]|0;s=l;return A|0}if(((t[p>>2]|0)!=0?(MR(t[(t[h>>2]|0)+32>>2]|0,t[m>>2]|0,t[p>>2]|0)|0)==0:0)?(ER(t[k>>2]|0,t[h>>2]|0,500,80192,t[w>>2]|0,t[d>>2]|0,t[p>>2]|0),t[p>>2]=0,(t[k>>2]|0)!=0):0)t[(t[k>>2]|0)+36>>2]=0;if(((((t[(t[h>>2]|0)+32>>2]|0)!=0?(t[(t[(t[h>>2]|0)+32>>2]|0)+48>>2]|0)==(t[h>>2]|0):0)?(t[(t[(t[h>>2]|0)+32>>2]|0)+44>>2]|0)!=0:0)?(t[(t[(t[(t[h>>2]|0)+32>>2]|0)+44>>2]|0)+44>>2]|0)!=0:0)?(t[S>>2]=nO(t[(t[(t[(t[h>>2]|0)+32>>2]|0)+44>>2]|0)+44>>2]|0,t[d>>2]|0,t[v>>2]|0,t[w>>2]|0)|0,(t[S>>2]|0)!=0):0){NM(t[E>>2]|0);t[b>>2]=0;A=t[b>>2]|0;s=l;return A|0}t[g>>2]=t[(t[h>>2]|0)+44>>2];if(!(t[g>>2]|0)){t[g>>2]=KF(0,t[F>>2]|0)|0;t[(t[h>>2]|0)+44>>2]=t[g>>2]}if(!(t[g>>2]|0)){gR(t[k>>2]|0,80240);NM(t[E>>2]|0);t[b>>2]=0;A=t[b>>2]|0;s=l;return A|0}t[S>>2]=gAi[t[135744>>2]&511](64)|0;if(!(t[S>>2]|0)){gR(t[k>>2]|0,79472);NM(t[E>>2]|0);t[b>>2]=0;A=t[b>>2]|0;s=l;return A|0}c=(t[S>>2]|0)+0|0;o=c+64|0;do{t[c>>2]=0;c=c+4|0}while((c|0)<(o|0));t[(t[S>>2]|0)+4>>2]=16;t[(t[S>>2]|0)+40>>2]=t[m>>2];t[(t[S>>2]|0)+32>>2]=t[(t[h>>2]|0)+32>>2];if(t[F>>2]|0){c=kz(t[F>>2]|0,t[d>>2]|0,-1)|0;t[(t[S>>2]|0)+8>>2]=c;c=kz(t[F>>2]|0,t[v>>2]|0,-1)|0;t[(t[S>>2]|0)+56>>2]=c;c=kz(t[F>>2]|0,t[w>>2]|0,-1)|0;t[(t[S>>2]|0)+60>>2]=c}else{c=Yl(t[d>>2]|0)|0;t[(t[S>>2]|0)+8>>2]=c;c=Yl(t[v>>2]|0)|0;t[(t[S>>2]|0)+56>>2]=c;c=Yl(t[w>>2]|0)|0;t[(t[S>>2]|0)+60>>2]=c}t[(t[S>>2]|0)+44>>2]=t[_>>2];t[(t[S>>2]|0)+52>>2]=t[E>>2];do if(t[p>>2]|0)if(t[F>>2]|0){E=kz(t[F>>2]|0,t[p>>2]|0,-1)|0;t[(t[S>>2]|0)+48>>2]=E;break}else{E=Yl(t[p>>2]|0)|0;t[(t[S>>2]|0)+48>>2]=E;break}while(0);if((JF(t[g>>2]|0,t[(t[S>>2]|0)+8>>2]|0,t[(t[S>>2]|0)+56>>2]|0,t[(t[S>>2]|0)+60>>2]|0,t[S>>2]|0)|0)<0){RR(t[k>>2]|0,t[h>>2]|0,501,80288,t[d>>2]|0,t[w>>2]|0,0);NR(t[S>>2]|0);t[b>>2]=0;A=t[b>>2]|0;s=l;return A|0}t[y>>2]=TR(t[h>>2]|0,t[w>>2]|0,1)|0;e:do if(t[y>>2]|0){if(((t[m>>2]|0)==2?(LR(0,t[y>>2]|0,1)|0)!=0:0)?(ER(t[k>>2]|0,t[h>>2]|0,520,80336,t[w>>2]|0,t[d>>2]|0,0),(t[k>>2]|0)!=0):0)t[(t[k>>2]|0)+36>>2]=0;do if(!(Xl(t[(t[S>>2]|0)+8>>2]|0,80392)|0)){if((t[(t[S>>2]|0)+56>>2]|0)!=0?(Xl(t[(t[S>>2]|0)+56>>2]|0,80392)|0)!=0:0)break;t[O>>2]=t[(t[y>>2]|0)+44>>2];while(1){if(!(t[O>>2]|0))break;if(!(Xl(t[(t[O>>2]|0)+8>>2]|0,80392)|0)){if(!(t[(t[S>>2]|0)+56>>2]|0))break;if(!(Xl(t[(t[S>>2]|0)+56>>2]|0,80392)|0))break}if(!(t[(t[O>>2]|0)+36>>2]|0))break;
	t[O>>2]=t[(t[O>>2]|0)+36>>2]}if(t[O>>2]|0){t[(t[S>>2]|0)+36>>2]=t[(t[O>>2]|0)+36>>2];t[(t[O>>2]|0)+36>>2]=t[S>>2];break e}else{t[(t[S>>2]|0)+36>>2]=t[(t[y>>2]|0)+44>>2];t[(t[y>>2]|0)+44>>2]=t[S>>2];break e}}while(0);t[(t[S>>2]|0)+36>>2]=t[(t[y>>2]|0)+44>>2];t[(t[y>>2]|0)+44>>2]=t[S>>2]}while(0);t[(t[S>>2]|0)+20>>2]=t[h>>2];y=t[S>>2]|0;O=(t[h>>2]|0)+16|0;if(!(t[(t[h>>2]|0)+16>>2]|0)){t[O>>2]=y;t[(t[h>>2]|0)+12>>2]=y}else{t[(t[O>>2]|0)+24>>2]=y;t[(t[S>>2]|0)+28>>2]=t[(t[h>>2]|0)+16>>2];t[(t[h>>2]|0)+16>>2]=t[S>>2]}t[b>>2]=t[S>>2];A=t[b>>2]|0;s=l;return A|0}function DM(e){e=e|0;var i=0,r=0;i=s;s=s+16|0;r=i;t[r>>2]=e;XF(t[r>>2]|0,244);s=i;return}function CM(e){e=e|0;var i=0,r=0;i=s;s=s+16|0;r=i;t[r>>2]=e;e=sO(t[r>>2]|0,245)|0;s=i;return e|0}function PM(e,i){e=e|0;i=i|0;var r=0,n=0,f=0;r=s;s=s+16|0;n=r+4|0;f=r;t[n>>2]=e;t[f>>2]=i;if((t[n>>2]|0)==0|(t[f>>2]|0)==0){s=r;return}NF(t[n>>2]|0,80400);RF(t[n>>2]|0,t[(t[f>>2]|0)+60>>2]|0);NF(t[n>>2]|0,80064);if(t[(t[f>>2]|0)+56>>2]|0){RF(t[n>>2]|0,t[(t[f>>2]|0)+56>>2]|0);NF(t[n>>2]|0,79648)}RF(t[n>>2]|0,t[(t[f>>2]|0)+8>>2]|0);do switch(t[(t[f>>2]|0)+40>>2]|0){case 9:{NF(t[n>>2]|0,80504);CR(t[n>>2]|0,t[(t[f>>2]|0)+52>>2]|0);break}case 5:{NF(t[n>>2]|0,80448);break}case 6:{NF(t[n>>2]|0,80456);break}case 7:{NF(t[n>>2]|0,80472);break}case 2:{NF(t[n>>2]|0,80424);break}case 10:{NF(t[n>>2]|0,80512);CR(t[n>>2]|0,t[(t[f>>2]|0)+52>>2]|0);break}case 4:{NF(t[n>>2]|0,80440);break}case 8:{NF(t[n>>2]|0,80488);break}case 1:{NF(t[n>>2]|0,80416);break}case 3:{NF(t[n>>2]|0,80432);break}default:yR(0,1,80136,0)}while(0);i=t[(t[f>>2]|0)+44>>2]|0;if((i|0)==2)NF(t[n>>2]|0,80528);else if((i|0)==3)NF(t[n>>2]|0,80544);else if((i|0)==4)NF(t[n>>2]|0,80560);else if((i|0)!=1)yR(0,1,80568,0);if(t[(t[f>>2]|0)+48>>2]|0){NF(t[n>>2]|0,80064);TF(t[n>>2]|0,t[(t[f>>2]|0)+48>>2]|0)}NF(t[n>>2]|0,80072);s=r;return}function BM(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;var u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0;u=s;s=s+48|0;a=u+32|0;o=u+28|0;c=u+24|0;l=u+20|0;b=u+16|0;k=u+12|0;h=u+8|0;w=u+4|0;d=u;t[o>>2]=e;t[c>>2]=i;t[l>>2]=r;t[b>>2]=n;t[k>>2]=f;if(!(t[c>>2]|0)){t[a>>2]=0;v=t[a>>2]|0;s=u;return v|0}if(!(t[l>>2]|0)){t[a>>2]=0;v=t[a>>2]|0;s=u;return v|0}if((t[b>>2]|0)==0&(t[k>>2]|0)==0){t[a>>2]=0;v=t[a>>2]|0;s=u;return v|0}t[w>>2]=t[(t[c>>2]|0)+36>>2];if(!(t[w>>2]|0)){t[d>>2]=0;if(t[(t[c>>2]|0)+32>>2]|0)t[d>>2]=t[(t[(t[c>>2]|0)+32>>2]|0)+80>>2];f=KF(0,t[d>>2]|0)|0;t[w>>2]=f;t[(t[c>>2]|0)+36>>2]=f}if(!(t[w>>2]|0)){gR(t[o>>2]|0,80624);t[a>>2]=0;v=t[a>>2]|0;s=u;return v|0}t[h>>2]=gAi[t[135744>>2]&511](12)|0;if(!(t[h>>2]|0)){gR(t[o>>2]|0,79472);t[a>>2]=0;v=t[a>>2]|0;s=u;return v|0}o=t[h>>2]|0;t[o+0>>2]=0;t[o+4>>2]=0;t[o+8>>2]=0;o=Yl(t[l>>2]|0)|0;t[t[h>>2]>>2]=o;if(t[k>>2]|0){o=Yl(t[k>>2]|0)|0;t[(t[h>>2]|0)+8>>2]=o}if(t[b>>2]|0){o=Yl(t[b>>2]|0)|0;t[(t[h>>2]|0)+4>>2]=o}if(ZF(t[w>>2]|0,t[l>>2]|0,t[h>>2]|0)|0){yR(0,526,80672,t[l>>2]|0);PR(t[h>>2]|0);t[a>>2]=0;v=t[a>>2]|0;s=u;return v|0}else{t[a>>2]=t[h>>2];v=t[a>>2]|0;s=u;return v|0}return 0}function IM(e){e=e|0;var i=0,r=0;i=s;s=s+16|0;r=i;t[r>>2]=e;XF(t[r>>2]|0,246);s=i;return}function HM(e){e=e|0;var i=0,r=0;i=s;s=s+16|0;r=i;t[r>>2]=e;e=sO(t[r>>2]|0,247)|0;s=i;return e|0}function xM(e,i){e=e|0;i=i|0;var r=0,n=0,f=0;r=s;s=s+16|0;n=r+4|0;f=r;t[n>>2]=e;t[f>>2]=i;if((t[n>>2]|0)==0|(t[f>>2]|0)==0){s=r;return}NF(t[n>>2]|0,80712);RF(t[n>>2]|0,t[t[f>>2]>>2]|0);i=t[n>>2]|0;if(t[(t[f>>2]|0)+4>>2]|0){NF(i,80728);TF(t[n>>2]|0,t[(t[f>>2]|0)+4>>2]|0);if(t[(t[f>>2]|0)+8>>2]|0){NF(t[n>>2]|0,80064);TF(t[n>>2]|0,t[(t[f>>2]|0)+8>>2]|0)}}else{NF(i,80744);TF(t[n>>2]|0,t[(t[f>>2]|0)+8>>2]|0)}NF(t[n>>2]|0,80760);s=r;return}function UM(e,i){e=e|0;i=i|0;var r=0,n=0,f=0;r=s;s=s+16|0;n=r+4|0;f=r;t[n>>2]=e;t[f>>2]=i;if((t[n>>2]|0)==0|(t[f>>2]|0)==0){s=r;return}aO(t[f>>2]|0,248,t[n>>2]|0);s=r;return}function zM(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0;f=s;s=s+32|0;u=f+24|0;a=f+20|0;o=f+16|0;c=f+12|0;l=f+8|0;b=f+4|0;k=f;t[a>>2]=e;t[o>>2]=i;t[c>>2]=r;t[l>>2]=n;if(!(t[o>>2]|0)){t[u>>2]=0;h=t[u>>2]|0;s=f;return h|0}if(!(t[c>>2]|0)){t[u>>2]=0;h=t[u>>2]|0;s=f;return h|0}if(!(t[l>>2]|0)){t[u>>2]=0;h=t[u>>2]|0;s=f;return h|0}t[k>>2]=t[(t[o>>2]|0)+64>>2];if(!(t[k>>2]|0)){n=KF(0,t[(t[o>>2]|0)+80>>2]|0)|0;t[k>>2]=n;t[(t[o>>2]|0)+64>>2]=n}if(!(t[k>>2]|0)){gR(t[a>>2]|0,80768);t[u>>2]=0;h=t[u>>2]|0;s=f;return h|0}t[b>>2]=gAi[t[135744>>2]&511](24)|0;if(!(t[b>>2]|0)){gR(t[a>>2]|0,79472);t[u>>2]=0;h=t[u>>2]|0;s=f;return h|0}n=Yl(t[c>>2]|0)|0;t[(t[b>>2]|0)+4>>2]=n;t[(t[b>>2]|0)+20>>2]=t[o>>2];if((t[a>>2]|0)!=0?(t[(t[a>>2]|0)+44>>2]|0)!=0:0){if(t[(t[o>>2]|0)+80>>2]|0){n=kz(t[(t[o>>2]|0)+80>>2]|0,t[(t[l>>2]|0)+8>>2]|0,-1)|0;t[(t[b>>2]|0)+12>>2]=n}else{n=Yl(t[(t[l>>2]|0)+8>>2]|0)|0;t[(t[b>>2]|0)+12>>2]=n}t[(t[b>>2]|0)+8>>2]=0}else{t[(t[b>>2]|0)+8>>2]=t[l>>2];t[(t[b>>2]|0)+12>>2]=0}n=Qy(t[(t[l>>2]|0)+20>>2]|0)|0;t[(t[b>>2]|0)+16>>2]=n;if((ZF(t[k>>2]|0,t[c>>2]|0,t[b>>2]|0)|0)<0){ER(t[a>>2]|0,t[(t[l>>2]|0)+20>>2]|0,513,80808,t[c>>2]|0,0,0);HR(t[b>>2]|0);t[u>>2]=0;h=t[u>>2]|0;s=f;return h|0}if(t[l>>2]|0)t[(t[l>>2]|0)+40>>2]=2;t[u>>2]=t[b>>2];h=t[u>>2]|0;s=f;return h|0}function jM(e){e=e|0;var i=0,r=0;i=s;s=s+16|0;r=i;t[r>>2]=e;XF(t[r>>2]|0,249);s=i;return}function VM(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0;n=s;s=s+128|0;f=n+24|0;u=n+20|0;a=n+16|0;o=n+12|0;c=n+8|0;l=n+78|0;b=n+28|0;k=n+4|0;h=n;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;if((t[o>>2]|0)!=0?(t[(t[o>>2]|0)+8>>2]|0)!=0:0){if((((t[(t[o>>2]|0)+36>>2]|0)!=0?(t[(t[(t[o>>2]|0)+36>>2]|0)+12>>2]|0)!=0:0)?(MY(t[(t[o>>2]|0)+8>>2]|0,80832)|0)==0:0)?(MY(t[(t[(t[o>>2]|0)+36>>2]|0)+12>>2]|0,80840)|0)==0:0){t[f>>2]=1;w=t[f>>2]|0;s=n;return w|0}if(!(t[u>>2]|0)){t[f>>2]=0;w=t[f>>2]|0;s=n;return w|0}if(((t[(t[u>>2]|0)+44>>2]|0)==0?(t[(t[u>>2]|0)+48>>2]|0)==0:0)?(t[(t[u>>2]|0)+4>>2]|0)!=13:0){t[f>>2]=0;w=t[f>>2]|0;s=n;return w|0}if((t[(t[u>>2]|0)+4>>2]|0)==13){do if(!(Xl(80832,t[(t[o>>2]|0)+8>>2]|0)|0)){if(Xl(80848,t[(t[o>>2]|0)+8>>2]|0)|0){if(!(t[a>>2]|0))break;if(Xl(t[(t[a>>2]|0)+8>>2]|0,80856)|0)break}t[f>>2]=0;w=t[f>>2]|0;s=n;return w|0}while(0);t[f>>2]=1;w=t[f>>2]|0;s=n;return w|0}if(!(t[a>>2]|0)){t[f>>2]=0;w=t[f>>2]|0;s=n;return w|0}t[c>>2]=0;if((t[(t[a>>2]|0)+36>>2]|0)!=0?(t[(t[(t[a>>2]|0)+36>>2]|0)+12>>2]|0)!=0:0)d=Ug(t[(t[a>>2]|0)+8>>2]|0,t[(t[(t[a>>2]|0)+36>>2]|0)+12>>2]|0,l,50)|0;else d=t[(t[a>>2]|0)+8>>2]|0;t[k>>2]=d;if((t[(t[o>>2]|0)+36>>2]|0)!=0?(t[(t[(t[o>>2]|0)+36>>2]|0)+12>>2]|0)!=0:0)v=Ug(t[(t[o>>2]|0)+8>>2]|0,t[(t[(t[o>>2]|0)+36>>2]|0)+12>>2]|0,b,50)|0;else v=t[(t[o>>2]|0)+8>>2]|0;t[h>>2]=v;if(((t[k>>2]|0)!=0&(t[h>>2]|0)!=0?(t[c>>2]=qM(t[(t[u>>2]|0)+44>>2]|0,t[k>>2]|0,t[h>>2]|0)|0,(t[c>>2]|0)==0):0)?(t[(t[u>>2]|0)+48>>2]|0)!=0:0)t[c>>2]=qM(t[(t[u>>2]|0)+48>>2]|0,t[k>>2]|0,t[h>>2]|0)|0;if((t[h>>2]|0)!=(b|0)?(t[h>>2]|0)!=(t[(t[o>>2]|0)+8>>2]|0):0)pAi[t[135736>>2]&511](t[h>>2]|0);if((t[k>>2]|0)!=(l|0)?(t[k>>2]|0)!=(t[(t[a>>2]|0)+8>>2]|0):0)pAi[t[135736>>2]&511](t[k>>2]|0);if((t[c>>2]|0)!=0?(t[(t[c>>2]|0)+40>>2]|0)==2:0){t[f>>2]=1;w=t[f>>2]|0;s=n;return w|0}t[f>>2]=0;w=t[f>>2]|0;s=n;return w|0}t[f>>2]=0;w=t[f>>2]|0;s=n;return w|0}function qM(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0;n=s;s=s+32|0;f=n+28|0;u=n+24|0;a=n+20|0;o=n+16|0;c=n+12|0;l=n+8|0;b=n+4|0;k=n;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;t[b>>2]=0;t[k>>2]=0;if(!(t[u>>2]|0)){t[f>>2]=0;h=t[f>>2]|0;s=n;return h|0}if(!(t[(t[u>>2]|0)+44>>2]|0)){t[f>>2]=0;h=t[f>>2]|0;s=n;return h|0}t[c>>2]=t[(t[u>>2]|0)+44>>2];if(!(t[c>>2]|0)){t[f>>2]=0;h=t[f>>2]|0;s=n;return h|0}t[b>>2]=zg(t[o>>2]|0,k)|0;u=t[c>>2]|0;if(t[b>>2]|0){t[l>>2]=nO(u,t[b>>2]|0,t[k>>2]|0,t[a>>2]|0)|0;if(t[k>>2]|0)pAi[t[135736>>2]&511](t[k>>2]|0);if(t[b>>2]|0)pAi[t[135736>>2]&511](t[b>>2]|0)}else t[l>>2]=nO(u,t[o>>2]|0,0,t[a>>2]|0)|0;t[f>>2]=t[l>>2];h=t[f>>2]|0;s=n;return h|0}function YM(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0;r=s;s=s+32|0;n=r+20|0;f=r+16|0;u=r+12|0;a=r+8|0;o=r+4|0;c=r;t[f>>2]=e;t[u>>2]=i;if(!(t[f>>2]|0)){t[n>>2]=-1;l=t[n>>2]|0;s=r;return l|0}if(!(t[u>>2]|0)){t[n>>2]=-1;l=t[n>>2]|0;s=r;return l|0}t[a>>2]=t[(t[f>>2]|0)+64>>2];if(!(t[a>>2]|0)){t[n>>2]=-1;l=t[n>>2]|0;s=r;return l|0}t[c>>2]=sy(t[f>>2]|0,t[(t[u>>2]|0)+12>>2]|0,1)|0;if(!(t[c>>2]|0)){t[n>>2]=-1;l=t[n>>2]|0;s=r;return l|0}t[o>>2]=rO(t[a>>2]|0,t[c>>2]|0)|0;if((t[o>>2]|0)!=0?(t[(t[o>>2]|0)+8>>2]|0)==(t[u>>2]|0):0){kO(t[a>>2]|0,t[c>>2]|0,249)|0;pAi[t[135736>>2]&511](t[c>>2]|0);t[(t[u>>2]|0)+40>>2]=0;t[n>>2]=0;l=t[n>>2]|0;s=r;return l|0}pAi[t[135736>>2]&511](t[c>>2]|0);t[n>>2]=-1;l=t[n>>2]|0;s=r;return l|0}function GM(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0;r=s;s=s+32|0;n=r+16|0;f=r+12|0;u=r+8|0;a=r+4|0;o=r;t[f>>2]=e;t[u>>2]=i;do if(t[f>>2]|0){if(!(t[u>>2]|0)){t[n>>2]=0;break}t[a>>2]=t[(t[f>>2]|0)+64>>2];if(!(t[a>>2]|0)){t[n>>2]=0;break}t[o>>2]=rO(t[a>>2]|0,t[u>>2]|0)|0;if(!(t[o>>2]|0)){t[n>>2]=0;break}if(!(t[(t[o>>2]|0)+8>>2]|0)){t[n>>2]=t[f>>2];break}else{t[n>>2]=t[(t[o>>2]|0)+8>>2];break}}else t[n>>2]=0;while(0);s=r;return t[n>>2]|0}function WM(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0;f=s;s=s+32|0;u=f+28|0;a=f+24|0;o=f+20|0;c=f+16|0;l=f+12|0;b=f+8|0;k=f+4|0;h=f;t[a>>2]=e;t[o>>2]=i;t[c>>2]=r;t[l>>2]=n;if(!(t[o>>2]|0)){t[u>>2]=0;w=t[u>>2]|0;s=f;return w|0}if(!(t[c>>2]|0)){t[u>>2]=0;w=t[u>>2]|0;s=f;return w|0}if(!(t[l>>2]|0)){t[u>>2]=0;w=t[u>>2]|0;s=f;return w|0}t[k>>2]=t[(t[o>>2]|0)+68>>2];if(!(t[k>>2]|0)){n=KF(0,t[(t[o>>2]|0)+80>>2]|0)|0;t[k>>2]=n;t[(t[o>>2]|0)+68>>2]=n}if(!(t[k>>2]|0)){gR(t[a>>2]|0,80864);t[u>>2]=0;w=t[u>>2]|0;s=f;return w|0}t[b>>2]=gAi[t[135744>>2]&511](20)|0;if(!(t[b>>2]|0)){gR(t[a>>2]|0,79472);t[u>>2]=0;w=t[u>>2]|0;s=f;return w|0}n=Yl(t[c>>2]|0)|0;t[(t[b>>2]|0)+4>>2]=n;if((t[a>>2]|0)!=0?(t[(t[a>>2]|0)+44>>2]|0)!=0:0){a=Yl(t[(t[l>>2]|0)+8>>2]|0)|0;t[(t[b>>2]|0)+12>>2]=a;t[(t[b>>2]|0)+8>>2]=0}else{t[(t[b>>2]|0)+12>>2]=0;t[(t[b>>2]|0)+8>>2]=t[l>>2]}a=Qy(t[(t[l>>2]|0)+20>>2]|0)|0;t[(t[b>>2]|0)+16>>2]=a;a=rO(t[k>>2]|0,t[c>>2]|0)|0;t[h>>2]=a;do if(!a){l=Eq(250,251)|0;t[h>>2]=l;if(!l){yR(0,1,80904,0);break}if((ZF(t[k>>2]|0,t[c>>2]|0,t[h>>2]|0)|0)<0){Fq(t[h>>2]|0);yR(0,1,80952,0)}else d=22}else d=22;while(0);do if((d|0)==22){if(yq(t[h>>2]|0,t[b>>2]|0)|0){yR(0,1,80952,0);break}t[u>>2]=t[b>>2];w=t[u>>2]|0;s=f;return w|0}while(0);if(t[b>>2]|0){if(t[(t[b>>2]|0)+4>>2]|0)pAi[t[135736>>2]&511](t[(t[b>>2]|0)+4>>2]|0);if(t[(t[b>>2]|0)+12>>2]|0)pAi[t[135736>>2]&511](t[(t[b>>2]|0)+12>>2]|0);pAi[t[135736>>2]&511](t[b>>2]|0)}t[u>>2]=0;w=t[u>>2]|0;s=f;return w|0}function KM(e){e=e|0;var i=0,r=0;i=s;s=s+16|0;r=i;t[r>>2]=e;XF(t[r>>2]|0,252);s=i;return}function XM(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,l=0;n=s;s=s+32|0;f=n+16|0;u=n+12|0;a=n+8|0;o=n+4|0;c=n;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;if(!(t[o>>2]|0)){t[f>>2]=0;l=t[f>>2]|0;s=n;return l|0}if((t[u>>2]|0)==0?(t[u>>2]=t[(t[o>>2]|0)+32>>2],(t[u>>2]|0)==0):0){t[f>>2]=0;l=t[f>>2]|0;s=n;return l|0}if((t[(t[u>>2]|0)+44>>2]|0)==0?(t[(t[u>>2]|0)+48>>2]|0)==0:0){t[f>>2]=0;l=t[f>>2]|0;s=n;return l|0}if((t[(t[u>>2]|0)+4>>2]|0)==13){t[f>>2]=0;l=t[f>>2]|0;s=n;return l|0}if(!(t[a>>2]|0)){t[f>>2]=0;l=t[f>>2]|0;s=n;return l|0}t[c>>2]=qM(t[(t[u>>2]|0)+44>>2]|0,t[(t[a>>2]|0)+8>>2]|0,t[(t[o>>2]|0)+8>>2]|0)|0;if((t[c>>2]|0)==0?(t[(t[u>>2]|0)+48>>2]|0)!=0:0)t[c>>2]=qM(t[(t[u>>2]|0)+48>>2]|0,t[(t[a>>2]|0)+8>>2]|0,t[(t[o>>2]|0)+8>>2]|0)|0;do if(t[c>>2]|0){if((t[(t[c>>2]|0)+40>>2]|0)!=3?(t[(t[c>>2]|0)+40>>2]|0)!=4:0)break;t[f>>2]=1;l=t[f>>2]|0;s=n;return l|0}while(0);t[f>>2]=0;l=t[f>>2]|0;s=n;return l|0}function ZM(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0;r=s;s=s+32|0;n=r+24|0;f=r+20|0;u=r+16|0;a=r+12|0;o=r+8|0;c=r+4|0;l=r;t[f>>2]=e;t[u>>2]=i;t[c>>2]=0;t[l>>2]=0;if((t[f>>2]|0)==0|(t[u>>2]|0)==0){t[n>>2]=0;b=t[n>>2]|0;s=r;return b|0}if(!(t[(t[f>>2]|0)+40>>2]|0)){t[n>>2]=0;b=t[n>>2]|0;s=r;return b|0}t[a>>2]=t[(t[f>>2]|0)+40>>2];t[c>>2]=zg(t[u>>2]|0,l)|0;if(t[c>>2]|0)t[u>>2]=t[c>>2];t[o>>2]=fO(t[a>>2]|0,t[u>>2]|0,t[l>>2]|0)|0;if(t[l>>2]|0)pAi[t[135736>>2]&511](t[l>>2]|0);if(t[c>>2]|0)pAi[t[135736>>2]&511](t[c>>2]|0);t[n>>2]=t[o>>2];b=t[n>>2]|0;s=r;return b|0}function JM(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,l=0;n=s;s=s+32|0;f=n+16|0;u=n+12|0;a=n+8|0;o=n+4|0;c=n;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;if(!(t[u>>2]|0)){t[f>>2]=0;l=t[f>>2]|0;s=n;return l|0}if(!(t[(t[u>>2]|0)+40>>2]|0)){t[f>>2]=0;l=t[f>>2]|0;s=n;return l|0}else{t[c>>2]=t[(t[u>>2]|0)+40>>2];t[f>>2]=fO(t[c>>2]|0,t[a>>2]|0,t[o>>2]|0)|0;l=t[f>>2]|0;s=n;return l|0}return 0}function QM(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0;f=s;s=s+32|0;u=f+20|0;a=f+16|0;o=f+12|0;c=f+8|0;l=f+4|0;b=f;t[a>>2]=e;t[o>>2]=i;t[c>>2]=r;t[l>>2]=n;if(!(t[a>>2]|0)){t[u>>2]=0;k=t[u>>2]|0;s=f;return k|0}if(!(t[(t[a>>2]|0)+44>>2]|0)){t[u>>2]=0;k=t[u>>2]|0;s=f;return k|0}else{t[b>>2]=t[(t[a>>2]|0)+44>>2];t[u>>2]=nO(t[b>>2]|0,t[c>>2]|0,t[l>>2]|0,t[o>>2]|0)|0;k=t[u>>2]|0;s=f;return k|0}return 0}function $M(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0;r=s;s=s+16|0;n=r+12|0;f=r+8|0;u=r+4|0;a=r;t[f>>2]=e;t[u>>2]=i;do if(t[f>>2]|0)if(!(t[(t[f>>2]|0)+36>>2]|0)){t[n>>2]=0;break}else{t[a>>2]=t[(t[f>>2]|0)+36>>2];t[n>>2]=rO(t[a>>2]|0,t[u>>2]|0)|0;break}else t[n>>2]=0;while(0);s=r;return t[n>>2]|0}function eR(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,l=0;n=s;s=s+32|0;f=n+16|0;u=n+12|0;a=n+8|0;o=n+4|0;c=n;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;if((t[a>>2]|0)!=0?!((t[o>>2]|0)==0?1:(t[(t[a>>2]|0)+44>>2]|0)==0):0){t[c>>2]=$M(t[(t[a>>2]|0)+44>>2]|0,t[o>>2]|0)|0;if((t[c>>2]|0)==0?(t[(t[a>>2]|0)+48>>2]|0)!=0:0)t[c>>2]=$M(t[(t[a>>2]|0)+48>>2]|0,t[o>>2]|0)|0;if((t[c>>2]|0)==0&(t[u>>2]|0)!=0){ER(t[u>>2]|0,t[a>>2]|0,537,81e3,t[o>>2]|0,0,0);t[f>>2]=0;l=t[f>>2]|0;s=n;return l|0}else{t[f>>2]=1;l=t[f>>2]|0;s=n;return l|0}}t[f>>2]=-1;l=t[f>>2]|0;s=n;return l|0}function iR(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0;r=s;s=s+16|0;n=r+12|0;f=r+8|0;u=r+4|0;a=r;t[f>>2]=e;t[u>>2]=i;e:do if((t[f>>2]|0)!=0?(t[(t[f>>2]|0)+44>>2]|0)!=0:0){t[a>>2]=ZM(t[(t[f>>2]|0)+44>>2]|0,t[u>>2]|0)|0;if((t[a>>2]|0)==0?(t[(t[f>>2]|0)+48>>2]|0)!=0:0)t[a>>2]=ZM(t[(t[f>>2]|0)+48>>2]|0,t[u>>2]|0)|0;if(!(t[a>>2]|0)){t[n>>2]=-1;break}switch(t[(t[a>>2]|0)+36>>2]|0){case 4:{t[n>>2]=0;break e;break}case 0:{t[n>>2]=-1;break e;break}case 3:case 2:case 1:{t[n>>2]=1;break e;break}default:{t[n>>2]=1;break e}}}else o=3;while(0);if((o|0)==3)t[n>>2]=-1;s=r;return t[n>>2]|0}function rR(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0;n=s;s=s+16|0;f=n;t[n+12>>2]=e;t[n+8>>2]=i;t[n+4>>2]=r;t[f>>2]=1;s=n;return t[f>>2]|0}function nR(e,i,r,f,a){e=e|0;i=i|0;r=r|0;f=f|0;a=a|0;var o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0,S=0,g=0,y=0;o=s;s=s+112|0;c=o+44|0;l=o+40|0;b=o+36|0;k=o+32|0;h=o+28|0;w=o+24|0;d=o+20|0;v=o+16|0;m=o+12|0;_=o+8|0;p=o+4|0;E=o+48|0;S=o;t[l>>2]=e;t[b>>2]=i;t[k>>2]=r;t[h>>2]=f;t[w>>2]=a;t[_>>2]=0;t[p>>2]=0;if(!(t[b>>2]|0)){t[c>>2]=0;g=t[c>>2]|0;s=o;return g|0}if(!(t[k>>2]|0)){t[c>>2]=0;g=t[c>>2]|0;s=o;return g|0}if(!(t[h>>2]|0)){t[c>>2]=0;g=t[c>>2]|0;s=o;return g|0}if(!(t[w>>2]|0)){t[c>>2]=0;g=t[c>>2]|0;s=o;return g|0}if((t[(t[k>>2]|0)+36>>2]|0)!=0?(t[(t[(t[k>>2]|0)+36>>2]|0)+12>>2]|0)!=0:0){t[S>>2]=Ug(t[(t[k>>2]|0)+8>>2]|0,t[(t[(t[k>>2]|0)+36>>2]|0)+12>>2]|0,E,50)|0;if(!(t[S>>2]|0)){t[c>>2]=0;g=t[c>>2]|0;s=o;return g|0}t[_>>2]=qM(t[(t[b>>2]|0)+44>>2]|0,t[S>>2]|0,t[h>>2]|0)|0;if(((t[_>>2]|0)==0?(t[(t[b>>2]|0)+48>>2]|0)!=0:0)?(t[_>>2]=qM(t[(t[b>>2]|0)+48>>2]|0,t[S>>2]|0,t[h>>2]|0)|0,(t[_>>2]|0)!=0):0)t[p>>2]=1;if((t[S>>2]|0)!=(E|0)?(t[S>>2]|0)!=(t[(t[k>>2]|0)+8>>2]|0):0)pAi[t[135736>>2]&511](t[S>>2]|0)}if((t[_>>2]|0)==0?(t[(t[b>>2]|0)+44>>2]|0)!=0:0)t[_>>2]=qM(t[(t[b>>2]|0)+44>>2]|0,t[(t[k>>2]|0)+8>>2]|0,t[h>>2]|0)|0;if(((t[_>>2]|0)==0?(t[(t[b>>2]|0)+48>>2]|0)!=0:0)?(t[_>>2]=qM(t[(t[b>>2]|0)+48>>2]|0,t[(t[k>>2]|0)+8>>2]|0,t[h>>2]|0)|0,(t[_>>2]|0)!=0):0)t[p>>2]=1;if(!(t[_>>2]|0)){t[c>>2]=0;g=t[c>>2]|0;s=o;return g|0}if((t[(t[_>>2]|0)+40>>2]|0)==1){t[c>>2]=0;g=t[c>>2]|0;s=o;return g|0}t[d>>2]=Yl(t[w>>2]|0)|0;if(!(t[d>>2]|0)){t[c>>2]=0;g=t[c>>2]|0;s=o;return g|0}t[m>>2]=t[w>>2];t[v>>2]=t[d>>2];while(1){if((u[t[m>>2]>>0]|0|0)!=32)break;t[m>>2]=(t[m>>2]|0)+1}while(1){if(!(u[t[m>>2]>>0]|0))break;if((u[t[m>>2]>>0]|0|0)!=32){_=t[m>>2]|0;t[m>>2]=_+1;S=n[_>>0]|0;_=t[v>>2]|0;t[v>>2]=_+1;n[_>>0]=S;continue}while(1){y=t[m>>2]|0;if((u[t[m>>2]>>0]|0|0)!=32)break;t[m>>2]=y+1}if(!(u[y>>0]|0))continue;S=t[v>>2]|0;t[v>>2]=S+1;n[S>>0]=32}n[t[v>>2]>>0]=0;if(((t[p>>2]|0)==1?(t[(t[b>>2]|0)+40>>2]|0)!=0:0)?(Xl(t[w>>2]|0,t[d>>2]|0)|0)==0:0){ER(t[l>>2]|0,t[k>>2]|0,530,81032,t[h>>2]|0,t[(t[k>>2]|0)+8>>2]|0,0);t[(t[l>>2]|0)+36>>2]=0}t[c>>2]=t[d>>2];g=t[c>>2]|0;s=o;return g|0}function fR(e,i,r,f){e=e|0;i=i|0;r=r|0;f=f|0;var a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0;a=s;s=s+96|0;o=a+36|0;c=a+32|0;l=a+28|0;b=a+24|0;k=a+20|0;h=a+16|0;w=a+12|0;d=a+8|0;v=a+4|0;m=a+40|0;_=a;t[c>>2]=e;t[l>>2]=i;t[b>>2]=r;t[k>>2]=f;t[v>>2]=0;if(!(t[c>>2]|0)){t[o>>2]=0;p=t[o>>2]|0;s=a;return p|0}if(!(t[l>>2]|0)){t[o>>2]=0;p=t[o>>2]|0;s=a;return p|0}if(!(t[b>>2]|0)){t[o>>2]=0;p=t[o>>2]|0;s=a;return p|0}if(!(t[k>>2]|0)){t[o>>2]=0;p=t[o>>2]|0;s=a;return p|0}if((t[(t[l>>2]|0)+36>>2]|0)!=0?(t[(t[(t[l>>2]|0)+36>>2]|0)+12>>2]|0)!=0:0){t[_>>2]=Ug(t[(t[l>>2]|0)+8>>2]|0,t[(t[(t[l>>2]|0)+36>>2]|0)+12>>2]|0,m,50)|0;if(!(t[_>>2]|0)){t[o>>2]=0;p=t[o>>2]|0;s=a;return p|0}if((t[_>>2]|0)!=(m|0)?(t[_>>2]|0)!=(t[(t[l>>2]|0)+8>>2]|0):0)pAi[t[135736>>2]&511](t[_>>2]|0)}t[v>>2]=qM(t[(t[c>>2]|0)+44>>2]|0,t[(t[l>>2]|0)+8>>2]|0,t[b>>2]|0)|0;if((t[v>>2]|0)==0?(t[(t[c>>2]|0)+48>>2]|0)!=0:0)t[v>>2]=qM(t[(t[c>>2]|0)+48>>2]|0,t[(t[l>>2]|0)+8>>2]|0,t[b>>2]|0)|0;if(!(t[v>>2]|0)){t[o>>2]=0;p=t[o>>2]|0;s=a;return p|0}if((t[(t[v>>2]|0)+40>>2]|0)==1){t[o>>2]=0;p=t[o>>2]|0;s=a;return p|0}t[h>>2]=Yl(t[k>>2]|0)|0;if(!(t[h>>2]|0)){t[o>>2]=0;p=t[o>>2]|0;s=a;return p|0}t[d>>2]=t[k>>2];t[w>>2]=t[h>>2];while(1){if((u[t[d>>2]>>0]|0|0)!=32)break;t[d>>2]=(t[d>>2]|0)+1}while(1){if(!(u[t[d>>2]>>0]|0))break;if((u[t[d>>2]>>0]|0|0)!=32){k=t[d>>2]|0;t[d>>2]=k+1;v=n[k>>0]|0;k=t[w>>2]|0;t[w>>2]=k+1;n[k>>0]=v;continue}while(1){E=t[d>>2]|0;if((u[t[d>>2]>>0]|0|0)!=32)break;t[d>>2]=E+1}if(!(u[E>>0]|0))continue;v=t[w>>2]|0;t[w>>2]=v+1;n[v>>0]=32}n[t[w>>2]>>0]=0;t[o>>2]=t[h>>2];p=t[o>>2]|0;s=a;return p|0}function tR(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0;n=s;s=s+48|0;f=n+40|0;u=n+36|0;a=n+32|0;o=n+28|0;c=n+24|0;l=n+20|0;b=n+16|0;k=n+12|0;h=n+8|0;w=n+4|0;d=n;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;t[c>>2]=1;if(!(t[a>>2]|0)){t[f>>2]=0;v=t[f>>2]|0;s=n;return v|0}if((t[(t[a>>2]|0)+44>>2]|0)==0?(t[(t[a>>2]|0)+48>>2]|0)==0:0){t[f>>2]=0;v=t[f>>2]|0;s=n;return v|0}if(!(t[o>>2]|0)){t[f>>2]=1;v=t[f>>2]|0;s=n;return v|0}if(t[(t[o>>2]|0)+48>>2]|0){t[l>>2]=MR(t[a>>2]|0,t[(t[o>>2]|0)+40>>2]|0,t[(t[o>>2]|0)+48>>2]|0)|0;if(!(t[l>>2]|0))ER(t[u>>2]|0,t[o>>2]|0,500,81120,t[(t[o>>2]|0)+8>>2]|0,t[(t[o>>2]|0)+60>>2]|0,0);t[c>>2]=t[c>>2]&t[l>>2]}if(((t[(t[o>>2]|0)+40>>2]|0)==2?(t[(t[o>>2]|0)+44>>2]|0)!=3:0)?(t[(t[o>>2]|0)+44>>2]|0)!=2:0){ER(t[u>>2]|0,t[o>>2]|0,512,81184,t[(t[o>>2]|0)+8>>2]|0,t[(t[o>>2]|0)+60>>2]|0,0);t[c>>2]=0}do if((t[(t[o>>2]|0)+40>>2]|0)==2){t[k>>2]=ZM(t[(t[a>>2]|0)+44>>2]|0,t[(t[o>>2]|0)+60>>2]|0)|0;if(!(t[k>>2]|0)){t[b>>2]=0;if(t[(t[a>>2]|0)+44>>2]|0){t[h>>2]=t[(t[(t[a>>2]|0)+44>>2]|0)+44>>2];cO(t[h>>2]|0,0,0,t[(t[o>>2]|0)+60>>2]|0,253,b)}}else t[b>>2]=LR(0,t[k>>2]|0,0)|0;if((t[b>>2]|0)>1){WR(t[u>>2]|0,t[o>>2]|0,514,81256,t[(t[o>>2]|0)+60>>2]|0,t[b>>2]|0,t[(t[o>>2]|0)+8>>2]|0);break}if(t[(t[a>>2]|0)+48>>2]|0){t[w>>2]=0;t[k>>2]=ZM(t[(t[a>>2]|0)+48>>2]|0,t[(t[o>>2]|0)+60>>2]|0)|0;if(t[k>>2]|0)t[w>>2]=LR(0,t[k>>2]|0,0)|0;if((t[w>>2]|0)>1){WR(t[u>>2]|0,t[o>>2]|0,514,81328,t[(t[o>>2]|0)+60>>2]|0,t[w>>2]|0,t[(t[o>>2]|0)+8>>2]|0);break}if(((t[w>>2]|0)+(t[b>>2]|0)|0)>1)ER(t[u>>2]|0,t[o>>2]|0,514,81400,t[(t[o>>2]|0)+60>>2]|0,t[(t[o>>2]|0)+8>>2]|0,0)}}while(0);if((t[(t[o>>2]|0)+48>>2]|0)!=0?(t[(t[o>>2]|0)+52>>2]|0)!=0:0){t[d>>2]=t[(t[o>>2]|0)+52>>2];while(1){if(!(t[d>>2]|0))break;if(Xl(t[(t[d>>2]|0)+4>>2]|0,t[(t[o>>2]|0)+48>>2]|0)|0)break;t[d>>2]=t[t[d>>2]>>2]}if(!(t[d>>2]|0)){ER(t[u>>2]|0,t[o>>2]|0,502,81480,t[(t[o>>2]|0)+48>>2]|0,t[(t[o>>2]|0)+8>>2]|0,t[(t[o>>2]|0)+60>>2]|0);t[c>>2]=0}}t[f>>2]=t[c>>2];v=t[f>>2]|0;s=n;return v|0}function uR(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0;n=s;s=s+48|0;f=n+32|0;u=n+28|0;a=n+24|0;o=n+20|0;c=n+16|0;l=n+12|0;b=n+8|0;k=n+4|0;h=n;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;t[c>>2]=1;if(!(t[a>>2]|0)){t[f>>2]=0;w=t[f>>2]|0;s=n;return w|0}if((t[(t[a>>2]|0)+44>>2]|0)==0?(t[(t[a>>2]|0)+48>>2]|0)==0:0){t[f>>2]=0;w=t[f>>2]|0;s=n;return w|0}if(!(t[o>>2]|0)){t[f>>2]=1;w=t[f>>2]|0;s=n;return w|0}e:do if((t[(t[o>>2]|0)+36>>2]|0)==3){t[b>>2]=t[(t[o>>2]|0)+40>>2];while(1){if(!(t[b>>2]|0))break e;if((t[t[b>>2]>>2]|0)!=4)break e;if(!(t[(t[b>>2]|0)+12>>2]|0))break e;i:do if((t[t[(t[b>>2]|0)+12>>2]>>2]|0)==2){t[h>>2]=t[(t[(t[b>>2]|0)+12>>2]|0)+8>>2];t[k>>2]=t[(t[b>>2]|0)+16>>2];while(1){if(!(t[k>>2]|0))break i;d=t[k>>2]|0;if((t[t[k>>2]>>2]|0)==2)break;if(!(t[d+12>>2]|0))break i;if((t[t[(t[k>>2]|0)+12>>2]>>2]|0)!=2)break i;if((Xl(t[(t[(t[k>>2]|0)+12>>2]|0)+8>>2]|0,t[h>>2]|0)|0)!=0?(Xl(t[(t[(t[k>>2]|0)+12>>2]|0)+24>>2]|0,t[(t[(t[b>>2]|0)+12>>2]|0)+24>>2]|0)|0)!=0:0){r=t[u>>2]|0;i=t[o>>2]|0;e=t[(t[o>>2]|0)+8>>2]|0;if(!(t[(t[(t[b>>2]|0)+12>>2]|0)+24>>2]|0))ER(r,i,503,81672,e,t[h>>2]|0,0);else ER(r,i,503,81728,e,t[(t[(t[b>>2]|0)+12>>2]|0)+24>>2]|0,t[h>>2]|0);t[c>>2]=0}t[k>>2]=t[(t[k>>2]|0)+16>>2]}if((Xl(t[d+8>>2]|0,t[h>>2]|0)|0)!=0?(Xl(t[(t[k>>2]|0)+24>>2]|0,t[(t[(t[b>>2]|0)+12>>2]|0)+24>>2]|0)|0)!=0:0){e=t[u>>2]|0;i=t[o>>2]|0;r=t[(t[o>>2]|0)+8>>2]|0;if(!(t[(t[(t[b>>2]|0)+12>>2]|0)+24>>2]|0))ER(e,i,503,81560,r,t[h>>2]|0,0);else ER(e,i,503,81616,r,t[(t[(t[b>>2]|0)+12>>2]|0)+24>>2]|0,t[h>>2]|0);t[c>>2]=0}}while(0);t[b>>2]=t[(t[b>>2]|0)+16>>2]}}while(0);t[l>>2]=ZM(t[(t[a>>2]|0)+44>>2]|0,t[(t[o>>2]|0)+8>>2]|0)|0;do if((t[l>>2]|0)!=0?(t[l>>2]|0)!=(t[o>>2]|0):0){if((t[(t[l>>2]|0)+48>>2]|0)!=(t[(t[o>>2]|0)+48>>2]|0)?(Xl(t[(t[l>>2]|0)+48>>2]|0,t[(t[o>>2]|0)+48>>2]|0)|0)==0:0)break;if(t[(t[l>>2]|0)+36>>2]|0){ER(t[u>>2]|0,t[o>>2]|0,509,79992,t[(t[o>>2]|0)+8>>2]|0,0,0);t[c>>2]=0}}while(0);t[l>>2]=ZM(t[(t[a>>2]|0)+48>>2]|0,t[(t[o>>2]|0)+8>>2]|0)|0;do if((t[l>>2]|0)!=0?(t[l>>2]|0)!=(t[o>>2]|0):0){if((t[(t[l>>2]|0)+48>>2]|0)!=(t[(t[o>>2]|0)+48>>2]|0)?(Xl(t[(t[l>>2]|0)+48>>2]|0,t[(t[o>>2]|0)+48>>2]|0)|0)==0:0)break;if(t[(t[l>>2]|0)+36>>2]|0){ER(t[u>>2]|0,t[o>>2]|0,509,79992,t[(t[o>>2]|0)+8>>2]|0,0,0);t[c>>2]=0}}while(0);t[f>>2]=t[c>>2];w=t[f>>2]|0;s=n;return w|0}function aR(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;var u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0,S=0,g=0;u=s;s=s+112|0;a=u+48|0;o=u+44|0;c=u+40|0;l=u+36|0;b=u+32|0;k=u+28|0;h=u+24|0;w=u+20|0;d=u+16|0;v=u+52|0;m=u+12|0;_=u+8|0;p=u+4|0;E=u;t[o>>2]=e;t[c>>2]=i;t[l>>2]=r;t[b>>2]=n;t[k>>2]=f;t[h>>2]=0;t[d>>2]=1;if(!(t[c>>2]|0)){t[a>>2]=0;S=t[a>>2]|0;s=u;return S|0}if((t[(t[c>>2]|0)+44>>2]|0)==0?(t[(t[c>>2]|0)+48>>2]|0)==0:0){t[a>>2]=0;S=t[a>>2]|0;s=u;return S|0}if((t[l>>2]|0)!=0?(t[(t[l>>2]|0)+8>>2]|0)!=0:0){if((t[b>>2]|0)!=0?(t[(t[b>>2]|0)+8>>2]|0)!=0:0){if((t[(t[l>>2]|0)+36>>2]|0)!=0?(t[(t[(t[l>>2]|0)+36>>2]|0)+12>>2]|0)!=0:0){t[m>>2]=Ug(t[(t[l>>2]|0)+8>>2]|0,t[(t[(t[l>>2]|0)+36>>2]|0)+12>>2]|0,v,50)|0;if(!(t[m>>2]|0)){t[a>>2]=0;S=t[a>>2]|0;s=u;return S|0}f=t[(t[c>>2]|0)+44>>2]|0;n=t[m>>2]|0;r=t[(t[b>>2]|0)+8>>2]|0;if(t[(t[b>>2]|0)+36>>2]|0){t[h>>2]=QM(f,n,r,t[(t[(t[b>>2]|0)+36>>2]|0)+12>>2]|0)|0;if((t[h>>2]|0)==0?(t[(t[c>>2]|0)+48>>2]|0)!=0:0)t[h>>2]=QM(t[(t[c>>2]|0)+48>>2]|0,t[m>>2]|0,t[(t[b>>2]|0)+8>>2]|0,t[(t[(t[b>>2]|0)+36>>2]|0)+12>>2]|0)|0}else{t[h>>2]=qM(f,n,r)|0;if((t[h>>2]|0)==0?(t[(t[c>>2]|0)+48>>2]|0)!=0:0)t[h>>2]=qM(t[(t[c>>2]|0)+48>>2]|0,t[m>>2]|0,t[(t[b>>2]|0)+8>>2]|0)|0}if((t[m>>2]|0)!=(v|0)?(t[m>>2]|0)!=(t[(t[l>>2]|0)+8>>2]|0):0)pAi[t[135736>>2]&511](t[m>>2]|0)}do if(!(t[h>>2]|0)){m=t[(t[c>>2]|0)+44>>2]|0;v=t[(t[l>>2]|0)+8>>2]|0;r=t[(t[b>>2]|0)+8>>2]|0;if(t[(t[b>>2]|0)+36>>2]|0){t[h>>2]=QM(m,v,r,t[(t[(t[b>>2]|0)+36>>2]|0)+12>>2]|0)|0;if(t[h>>2]|0)break;if(!(t[(t[c>>2]|0)+48>>2]|0))break;t[h>>2]=QM(t[(t[c>>2]|0)+48>>2]|0,t[(t[l>>2]|0)+8>>2]|0,t[(t[b>>2]|0)+8>>2]|0,t[(t[(t[b>>2]|0)+36>>2]|0)+12>>2]|0)|0;break}else{t[h>>2]=qM(m,v,r)|0;if(t[h>>2]|0)break;if(!(t[(t[c>>2]|0)+48>>2]|0))break;t[h>>2]=qM(t[(t[c>>2]|0)+48>>2]|0,t[(t[l>>2]|0)+8>>2]|0,t[(t[b>>2]|0)+8>>2]|0)|0;break}}while(0);if(!(t[h>>2]|0)){ER(t[o>>2]|0,t[l>>2]|0,533,81784,t[(t[b>>2]|0)+8>>2]|0,t[(t[l>>2]|0)+8>>2]|0,0);t[a>>2]=0;S=t[a>>2]|0;s=u;return S|0}t[(t[b>>2]|0)+40>>2]=t[(t[h>>2]|0)+40>>2];t[w>>2]=MR(t[c>>2]|0,t[(t[h>>2]|0)+40>>2]|0,t[k>>2]|0)|0;if(!(t[w>>2]|0)){ER(t[o>>2]|0,t[l>>2]|0,502,81832,t[(t[b>>2]|0)+8>>2]|0,t[(t[l>>2]|0)+8>>2]|0,0);t[d>>2]=0}if((t[(t[h>>2]|0)+44>>2]|0)==4?(Xl(t[k>>2]|0,t[(t[h>>2]|0)+48>>2]|0)|0)==0:0){ER(t[o>>2]|0,t[l>>2]|0,500,81888,t[(t[b>>2]|0)+8>>2]|0,t[(t[l>>2]|0)+8>>2]|0,t[(t[h>>2]|0)+48>>2]|0);t[d>>2]=0}if((t[(t[h>>2]|0)+40>>2]|0)==2?(zM(t[o>>2]|0,t[c>>2]|0,t[k>>2]|0,t[b>>2]|0)|0)==0:0)t[d>>2]=0;if(!((t[(t[h>>2]|0)+40>>2]|0)!=3?(t[(t[h>>2]|0)+40>>2]|0)!=4:0))g=46;if((g|0)==46?(WM(t[o>>2]|0,t[c>>2]|0,t[k>>2]|0,t[b>>2]|0)|0)==0:0)t[d>>2]=0;if((t[(t[h>>2]|0)+40>>2]|0)==10){t[_>>2]=t[(t[h>>2]|0)+52>>2];t[p>>2]=$M(t[(t[c>>2]|0)+44>>2]|0,t[k>>2]|0)|0;if(!(t[p>>2]|0))t[p>>2]=$M(t[(t[c>>2]|0)+48>>2]|0,t[k>>2]|0)|0;if(!(t[p>>2]|0)){ER(t[o>>2]|0,t[l>>2]|0,537,81952,t[k>>2]|0,t[(t[b>>2]|0)+8>>2]|0,t[(t[l>>2]|0)+8>>2]|0);t[d>>2]=0}while(1){if(!(t[_>>2]|0))break;if(Xl(t[(t[_>>2]|0)+4>>2]|0,t[k>>2]|0)|0)break;t[_>>2]=t[t[_>>2]>>2]}if(!(t[_>>2]|0)){ER(t[o>>2]|0,t[l>>2]|0,527,82016,t[k>>2]|0,t[(t[b>>2]|0)+8>>2]|0,t[(t[l>>2]|0)+8>>2]|0);t[d>>2]=0}}if((t[(t[h>>2]|0)+40>>2]|0)==9){t[E>>2]=t[(t[h>>2]|0)+52>>2];while(1){if(!(t[E>>2]|0))break;if(Xl(t[(t[E>>2]|0)+4>>2]|0,t[k>>2]|0)|0)break;t[E>>2]=t[t[E>>2]>>2]}if(!(t[E>>2]|0)){ER(t[o>>2]|0,t[l>>2]|0,502,82096,t[k>>2]|0,t[(t[b>>2]|0)+8>>2]|0,t[(t[l>>2]|0)+8>>2]|0);t[d>>2]=0}}if((t[(t[h>>2]|0)+44>>2]|0)==4?(Xl(t[(t[h>>2]|0)+48>>2]|0,t[k>>2]|0)|0)==0:0){ER(t[o>>2]|0,t[l>>2]|0,502,82168,t[(t[b>>2]|0)+8>>2]|0,t[(t[l>>2]|0)+8>>2]|0,t[(t[h>>2]|0)+48>>2]|0);t[d>>2]=0}l=KR(t[o>>2]|0,t[c>>2]|0,t[(t[b>>2]|0)+8>>2]|0,t[(t[h>>2]|0)+40>>2]|0,t[k>>2]|0)|0;t[d>>2]=t[d>>2]&l;t[a>>2]=t[d>>2];S=t[a>>2]|0;s=u;return S|0}t[a>>2]=0;S=t[a>>2]|0;s=u;return S|0}t[a>>2]=0;S=t[a>>2]|0;s=u;return S|0}function oR(e,i,r,n,f,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;u=u|0;var a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0,S=0,g=0,y=0,F=0;a=s;s=s+112|0;o=a+52|0;c=a+48|0;l=a+44|0;b=a+40|0;k=a+36|0;h=a+32|0;w=a+28|0;d=a+24|0;v=a+20|0;m=a+16|0;_=a+56|0;p=a+12|0;E=a+8|0;S=a+4|0;g=a;t[c>>2]=e;t[l>>2]=i;t[b>>2]=r;t[k>>2]=n;t[h>>2]=f;t[w>>2]=u;t[d>>2]=0;t[m>>2]=1;if(!(t[l>>2]|0)){t[o>>2]=0;y=t[o>>2]|0;s=a;return y|0}if((t[(t[l>>2]|0)+44>>2]|0)==0?(t[(t[l>>2]|0)+48>>2]|0)==0:0){t[o>>2]=0;y=t[o>>2]|0;s=a;return y|0}if((t[b>>2]|0)!=0?(t[(t[b>>2]|0)+8>>2]|0)!=0:0){if((t[h>>2]|0)!=0?(t[(t[h>>2]|0)+8>>2]|0)!=0:0){if(t[k>>2]|0){t[p>>2]=Ug(t[(t[b>>2]|0)+8>>2]|0,t[k>>2]|0,_,50)|0;if(!(t[p>>2]|0)){gR(t[c>>2]|0,82216);t[o>>2]=0;y=t[o>>2]|0;s=a;return y|0}k=t[(t[l>>2]|0)+44>>2]|0;u=t[p>>2]|0;if(t[(t[h>>2]|0)+12>>2]|0){t[d>>2]=QM(k,u,t[(t[h>>2]|0)+12>>2]|0,80392)|0;if((t[d>>2]|0)==0?(t[(t[l>>2]|0)+48>>2]|0)!=0:0)t[d>>2]=QM(t[(t[l>>2]|0)+48>>2]|0,t[p>>2]|0,t[(t[h>>2]|0)+12>>2]|0,80392)|0}else{t[d>>2]=qM(k,u,80392)|0;if((t[d>>2]|0)==0?(t[(t[l>>2]|0)+48>>2]|0)!=0:0)t[d>>2]=qM(t[(t[l>>2]|0)+48>>2]|0,t[p>>2]|0,80392)|0}if((t[p>>2]|0)!=(_|0)?(t[p>>2]|0)!=(t[(t[b>>2]|0)+8>>2]|0):0)pAi[t[135736>>2]&511](t[p>>2]|0)}do if(!(t[d>>2]|0)){p=t[(t[l>>2]|0)+44>>2]|0;_=t[(t[b>>2]|0)+8>>2]|0;if(t[(t[h>>2]|0)+12>>2]|0){t[d>>2]=QM(p,_,t[(t[h>>2]|0)+12>>2]|0,80392)|0;if(t[d>>2]|0)break;if(!(t[(t[l>>2]|0)+48>>2]|0))break;t[d>>2]=QM(t[(t[l>>2]|0)+48>>2]|0,t[(t[b>>2]|0)+8>>2]|0,t[(t[h>>2]|0)+12>>2]|0,80392)|0;break}else{t[d>>2]=qM(p,_,80392)|0;if(t[d>>2]|0)break;if(!(t[(t[l>>2]|0)+48>>2]|0))break;t[d>>2]=qM(t[(t[l>>2]|0)+48>>2]|0,t[(t[b>>2]|0)+8>>2]|0,80392)|0;break}}while(0);if(!(t[d>>2]|0)){_=t[c>>2]|0;p=t[b>>2]|0;if(t[(t[h>>2]|0)+12>>2]|0)ER(_,p,533,82240,t[(t[h>>2]|0)+12>>2]|0,t[(t[b>>2]|0)+8>>2]|0,0);else ER(_,p,533,82296,t[(t[b>>2]|0)+8>>2]|0,0,0);t[o>>2]=0;y=t[o>>2]|0;s=a;return y|0}t[v>>2]=MR(t[l>>2]|0,t[(t[d>>2]|0)+40>>2]|0,t[w>>2]|0)|0;if(!(t[v>>2]|0)){v=t[c>>2]|0;p=t[b>>2]|0;if(t[(t[h>>2]|0)+12>>2]|0)ER(v,p,516,82352,t[(t[h>>2]|0)+12>>2]|0,t[(t[b>>2]|0)+8>>2]|0,0);else ER(v,p,516,82416,t[(t[b>>2]|0)+8>>2]|0,0,0);t[m>>2]=0}if((t[(t[d>>2]|0)+44>>2]|0)==4?(Xl(t[w>>2]|0,t[(t[d>>2]|0)+48>>2]|0)|0)==0:0){p=t[c>>2]|0;v=t[b>>2]|0;if(t[(t[h>>2]|0)+12>>2]|0)ER(p,v,500,82472,t[(t[h>>2]|0)+12>>2]|0,t[(t[b>>2]|0)+8>>2]|0,t[(t[d>>2]|0)+48>>2]|0);else ER(p,v,500,82544,t[(t[b>>2]|0)+8>>2]|0,t[(t[d>>2]|0)+48>>2]|0,0);t[m>>2]=0}if((t[(t[d>>2]|0)+40>>2]|0)==2?(zM(t[c>>2]|0,t[l>>2]|0,t[w>>2]|0,t[h>>2]|0)|0)==0:0)t[m>>2]=0;if(!((t[(t[d>>2]|0)+40>>2]|0)!=3?(t[(t[d>>2]|0)+40>>2]|0)!=4:0))F=54;if((F|0)==54?(WM(t[c>>2]|0,t[l>>2]|0,t[w>>2]|0,t[h>>2]|0)|0)==0:0)t[m>>2]=0;if((t[(t[d>>2]|0)+40>>2]|0)==10){t[E>>2]=t[(t[d>>2]|0)+52>>2];t[S>>2]=$M(t[(t[l>>2]|0)+44>>2]|0,t[w>>2]|0)|0;if(!(t[S>>2]|0))t[S>>2]=$M(t[(t[l>>2]|0)+48>>2]|0,t[w>>2]|0)|0;if(!(t[S>>2]|0)){S=t[c>>2]|0;F=t[b>>2]|0;v=t[w>>2]|0;if(t[(t[h>>2]|0)+12>>2]|0)ER(S,F,537,82608,v,t[(t[h>>2]|0)+12>>2]|0,t[(t[b>>2]|0)+8>>2]|0);else ER(S,F,537,82680,v,t[(t[b>>2]|0)+8>>2]|0,0);t[m>>2]=0}while(1){if(!(t[E>>2]|0))break;if(Xl(t[(t[E>>2]|0)+4>>2]|0,t[w>>2]|0)|0)break;t[E>>2]=t[t[E>>2]>>2]}if(!(t[E>>2]|0)){E=t[c>>2]|0;v=t[b>>2]|0;F=t[w>>2]|0;if(t[(t[h>>2]|0)+12>>2]|0)ER(E,v,527,82752,F,t[(t[h>>2]|0)+12>>2]|0,t[(t[b>>2]|0)+8>>2]|0);else ER(E,v,527,82832,F,t[(t[b>>2]|0)+8>>2]|0,0);t[m>>2]=0}}if((t[(t[d>>2]|0)+40>>2]|0)==9){t[g>>2]=t[(t[d>>2]|0)+52>>2];while(1){if(!(t[g>>2]|0))break;if(Xl(t[(t[g>>2]|0)+4>>2]|0,t[w>>2]|0)|0)break;t[g>>2]=t[t[g>>2]>>2]}if(!(t[g>>2]|0)){g=t[c>>2]|0;F=t[b>>2]|0;v=t[w>>2]|0;if(t[(t[h>>2]|0)+12>>2]|0)ER(g,F,502,82912,v,t[(t[h>>2]|0)+12>>2]|0,t[(t[b>>2]|0)+8>>2]|0);else ER(g,F,502,82992,v,t[(t[b>>2]|0)+8>>2]|0,0);t[m>>2]=0}}if((t[(t[d>>2]|0)+44>>2]|0)==4?(Xl(t[(t[d>>2]|0)+48>>2]|0,t[w>>2]|0)|0)==0:0){v=t[c>>2]|0;F=t[b>>2]|0;if(t[(t[h>>2]|0)+12>>2]|0)ER(v,F,508,83064,t[(t[h>>2]|0)+12>>2]|0,t[(t[b>>2]|0)+8>>2]|0,t[(t[d>>2]|0)+48>>2]|0);else ER(v,F,508,83120,t[(t[b>>2]|0)+8>>2]|0,t[(t[d>>2]|0)+48>>2]|0,0);t[m>>2]=0}b=t[c>>2]|0;c=t[l>>2]|0;if(t[(t[h>>2]|0)+12>>2]|0){l=KR(b,c,t[(t[h>>2]|0)+12>>2]|0,t[(t[d>>2]|0)+40>>2]|0,t[w>>2]|0)|0;t[m>>2]=t[m>>2]&l}else{l=KR(b,c,80392,t[(t[d>>2]|0)+40>>2]|0,t[w>>2]|0)|0;t[m>>2]=t[m>>2]&l}t[o>>2]=t[m>>2];y=t[o>>2]|0;s=a;return y|0}t[o>>2]=0;y=t[o>>2]|0;s=a;return y|0}t[o>>2]=0;y=t[o>>2]|0;s=a;return y|0}function cR(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0;f=s;s=s+48|0;u=f+36|0;a=f+32|0;o=f+28|0;c=f+24|0;l=f+20|0;b=f+16|0;k=f+12|0;h=f+8|0;w=f+4|0;d=f;t[a>>2]=e;t[o>>2]=i;t[c>>2]=r;t[l>>2]=n;t[b>>2]=1;t[h>>2]=0;if(!(t[a>>2]|0)){t[u>>2]=0;v=t[u>>2]|0;s=f;return v|0}do if(((t[(t[a>>2]|0)+44>>2]|0)>0?(t[(t[a>>2]|0)+40>>2]|0)!=0:0)?(t[w>>2]=t[(t[a>>2]|0)+40>>2],(t[t[w>>2]>>2]|0)!=0):0){t[d>>2]=t[t[w>>2]>>2];n=t[(t[d>>2]|0)+36>>2]|0;if((n|0)==4){if(!(t[(t[w>>2]|0)+8>>2]|0))break;t[b>>2]=Xs(t[(t[w>>2]|0)+8>>2]|0,t[l>>2]|0,0)|0;if((t[b>>2]|0)<0){ER(t[a>>2]|0,t[(t[w>>2]|0)+4>>2]|0,504,83352,t[(t[(t[w>>2]|0)+4>>2]|0)+8>>2]|0,t[l>>2]|0,0);t[b>>2]=0;break}else{t[b>>2]=1;break}}else if((n|0)==1){ER(t[a>>2]|0,t[(t[w>>2]|0)+4>>2]|0,528,83168,t[(t[(t[w>>2]|0)+4>>2]|0)+8>>2]|0,0,0);t[b>>2]=0;break}else if((n|0)==3){if((t[(t[d>>2]|0)+40>>2]|0)!=0?(t[t[(t[d>>2]|0)+40>>2]>>2]|0)==1:0){ER(t[a>>2]|0,t[(t[w>>2]|0)+4>>2]|0,529,83224,t[(t[(t[w>>2]|0)+4>>2]|0)+8>>2]|0,0,0);t[b>>2]=0;break}t[b>>2]=XR(t[a>>2]|0,t[(t[d>>2]|0)+40>>2]|0,t[l>>2]|0)|0;if((t[b>>2]|0)==1)break;ER(t[a>>2]|0,t[(t[w>>2]|0)+4>>2]|0,515,83288,t[l>>2]|0,t[(t[(t[w>>2]|0)+4>>2]|0)+8>>2]|0,0);break}else if(!n){t[b>>2]=0;break}else break}while(0);t[k>>2]=ZR(t[a>>2]|0,t[o>>2]|0,t[c>>2]|0,h)|0;JR(t[a>>2]|0,t[k>>2]|0,t[c>>2]|0)|0;t[u>>2]=t[b>>2];v=t[u>>2]|0;s=f;return v|0}function lR(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0;n=s;s=s+32|0;f=n+28|0;a=n+24|0;o=n+20|0;c=n+16|0;l=n+12|0;b=n+8|0;k=n+4|0;h=n;
	t[a>>2]=e;t[o>>2]=i;t[c>>2]=r;t[l>>2]=1;if(!(t[a>>2]|0)){t[f>>2]=0;w=t[f>>2]|0;s=n;return w|0}if((t[c>>2]|0)<=0){t[f>>2]=t[l>>2];w=t[f>>2]|0;s=n;return w|0}e:do if(((t[(t[a>>2]|0)+44>>2]|0)>0?(t[(t[a>>2]|0)+40>>2]|0)!=0:0)?(t[b>>2]=t[(t[a>>2]|0)+40>>2],(t[t[b>>2]>>2]|0)!=0):0){t[k>>2]=t[t[b>>2]>>2];r=t[(t[k>>2]|0)+36>>2]|0;if((r|0)==1){ER(t[a>>2]|0,t[(t[b>>2]|0)+4>>2]|0,528,83168,t[(t[(t[b>>2]|0)+4>>2]|0)+8>>2]|0,0,0);t[l>>2]=0;break}else if(!r){t[l>>2]=0;break}else if((r|0)==4){if((t[c>>2]|0)<=0)break;t[h>>2]=0;i:while(1){if((t[h>>2]|0)>=(t[c>>2]|0))break e;do if((u[(t[o>>2]|0)+(t[h>>2]|0)>>0]|0|0)!=32){if(9<=(u[(t[o>>2]|0)+(t[h>>2]|0)>>0]|0|0)?(u[(t[o>>2]|0)+(t[h>>2]|0)>>0]|0|0)<=10:0)break;if((u[(t[o>>2]|0)+(t[h>>2]|0)>>0]|0|0)!=13)break i}while(0);t[h>>2]=(t[h>>2]|0)+1}ER(t[a>>2]|0,t[(t[b>>2]|0)+4>>2]|0,504,83416,t[(t[(t[b>>2]|0)+4>>2]|0)+8>>2]|0,0,0);t[l>>2]=0;break}else break}while(0);t[f>>2]=t[l>>2];w=t[f>>2]|0;s=n;return w|0}function sR(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,u=0,a=0,o=0,c=0,l=0,b=0;f=s;s=s+32|0;u=f+28|0;a=f+24|0;o=f+8|0;c=f+4|0;l=f;t[a>>2]=e;t[f+20>>2]=i;t[f+16>>2]=r;t[f+12>>2]=n;t[o>>2]=1;if(!(t[a>>2]|0)){t[u>>2]=0;b=t[u>>2]|0;s=f;return b|0}if((t[(t[a>>2]|0)+44>>2]|0)>0?(t[(t[a>>2]|0)+40>>2]|0)!=0:0){t[c>>2]=t[(t[a>>2]|0)+40>>2];do if(((t[t[c>>2]>>2]|0)!=0?(t[l>>2]=t[t[c>>2]>>2],(t[(t[l>>2]|0)+36>>2]|0)==4):0)?(t[(t[c>>2]|0)+8>>2]|0)!=0:0){t[o>>2]=Xs(t[(t[c>>2]|0)+8>>2]|0,0,0)|0;if(!(t[o>>2]|0)){ER(t[a>>2]|0,t[(t[c>>2]|0)+4>>2]|0,504,83480,t[(t[(t[c>>2]|0)+4>>2]|0)+8>>2]|0,0,0);break}else{t[o>>2]=1;break}}while(0);QR(t[a>>2]|0)|0}t[u>>2]=t[o>>2];b=t[u>>2]|0;s=f;return b|0}function bR(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0,S=0,g=0,y=0,F=0,O=0,A=0,M=0,R=0,N=0,T=0,L=0,D=0,C=0;n=s;s=s+144|0;f=n+80|0;a=n+76|0;o=n+72|0;c=n+68|0;l=n+64|0;b=n+60|0;k=n+56|0;h=n+52|0;w=n+48|0;d=n+44|0;v=n+40|0;m=n+36|0;_=n+84|0;p=n+32|0;E=n+28|0;S=n+24|0;g=n+20|0;y=n+16|0;F=n+12|0;O=n+8|0;A=n+4|0;M=n;t[a>>2]=e;t[o>>2]=i;t[c>>2]=r;t[l>>2]=0;t[w>>2]=1;t[m>>2]=0;if(!(t[o>>2]|0)){t[f>>2]=0;R=t[f>>2]|0;s=n;return R|0}if((t[(t[o>>2]|0)+44>>2]|0)==0?(t[(t[o>>2]|0)+48>>2]|0)==0:0){t[f>>2]=0;R=t[f>>2]|0;s=n;return R|0}if(!(t[c>>2]|0)){t[f>>2]=0;R=t[f>>2]|0;s=n;return R|0}do switch(t[(t[c>>2]|0)+4>>2]|0){case 8:case 7:case 5:case 4:{t[f>>2]=1;R=t[f>>2]|0;s=n;return R|0}case 6:{ER(t[a>>2]|0,t[c>>2]|0,1,83680,0,0,0);t[f>>2]=0;R=t[f>>2]|0;s=n;return R|0}case 11:case 10:case 9:{ER(t[a>>2]|0,t[c>>2]|0,1,83744,0,0,0);t[f>>2]=0;R=t[f>>2]|0;s=n;return R|0}case 20:case 19:{t[f>>2]=1;R=t[f>>2]|0;s=n;return R|0}case 1:{t[l>>2]=ZR(t[a>>2]|0,t[o>>2]|0,t[c>>2]|0,m)|0;if(!(t[l>>2]|0)){t[f>>2]=0;R=t[f>>2]|0;s=n;return R|0}e:do if(!(t[(t[a>>2]|0)+44>>2]|0)){r=t[(t[l>>2]|0)+36>>2]|0;if(!r){ER(t[a>>2]|0,t[c>>2]|0,534,83832,t[(t[c>>2]|0)+8>>2]|0,0,0);t[f>>2]=0;R=t[f>>2]|0;s=n;return R|0}else if((r|0)==4){i:do if((t[m>>2]|0)==1?(t[(t[o>>2]|0)+40>>2]|0)==1:0){t[h>>2]=t[(t[c>>2]|0)+12>>2];while(1){if(!(t[h>>2]|0))break i;if((t[(t[h>>2]|0)+4>>2]|0)==3){t[E>>2]=t[(t[h>>2]|0)+40>>2];while(1){do if((u[t[E>>2]>>0]|0|0)==32)N=1;else{if(9<=(u[t[E>>2]>>0]|0|0)?(u[t[E>>2]>>0]|0|0)<=10:0){N=1;break}N=(u[t[E>>2]>>0]|0|0)==13}while(0);T=t[E>>2]|0;if(!N)break;t[E>>2]=T+1}if(!(u[T>>0]|0))break}t[h>>2]=t[(t[h>>2]|0)+24>>2]}ER(t[a>>2]|0,t[c>>2]|0,532,83904,t[(t[c>>2]|0)+8>>2]|0,0,0);t[w>>2]=0}while(0);t[h>>2]=t[(t[c>>2]|0)+12>>2];t[b>>2]=t[(t[l>>2]|0)+40>>2];t[d>>2]=eN(t[a>>2]|0,t[h>>2]|0,t[l>>2]|0,1,t[c>>2]|0)|0;if((t[d>>2]|0)>0)break;t[w>>2]=t[d>>2];break}else if((r|0)==3){if((t[(t[l>>2]|0)+40>>2]|0)!=0?(t[t[(t[l>>2]|0)+40>>2]>>2]|0)==1:0){t[w>>2]=$R(t[a>>2]|0,t[o>>2]|0,t[c>>2]|0)|0;if(t[w>>2]|0)break;ER(t[a>>2]|0,t[c>>2]|0,529,83224,t[(t[c>>2]|0)+8>>2]|0,0,0);break}t[h>>2]=t[(t[c>>2]|0)+12>>2];i:while(1){if(!(t[h>>2]|0))break e;do if((t[(t[h>>2]|0)+4>>2]|0)==1){t[v>>2]=t[(t[h>>2]|0)+8>>2];if((t[(t[h>>2]|0)+36>>2]|0)!=0?(t[(t[(t[h>>2]|0)+36>>2]|0)+12>>2]|0)!=0:0){t[p>>2]=Ug(t[(t[h>>2]|0)+8>>2]|0,t[(t[(t[h>>2]|0)+36>>2]|0)+12>>2]|0,_,50)|0;if(!(t[p>>2]|0))break i;t[b>>2]=t[(t[l>>2]|0)+40>>2];r:while(1){if(!(t[b>>2]|0))break;i=t[b>>2]|0;n:do if((t[t[b>>2]>>2]|0)==2){if(Xl(t[i+8>>2]|0,t[p>>2]|0)|0)break r}else{do if((t[i>>2]|0)==4){if(!(t[(t[b>>2]|0)+12>>2]|0))break;if((t[t[(t[b>>2]|0)+12>>2]>>2]|0)!=2)break;if(Xl(t[(t[(t[b>>2]|0)+12>>2]|0)+8>>2]|0,t[p>>2]|0)|0)break r;else break n}while(0);if((t[t[b>>2]>>2]|0)!=4){L=53;break r}if(!(t[(t[b>>2]|0)+12>>2]|0)){L=53;break r}if((t[t[(t[b>>2]|0)+12>>2]>>2]|0)!=1){L=53;break r}}while(0);t[b>>2]=t[(t[b>>2]|0)+16>>2]}if((L|0)==53){L=0;yR(0,519,83864,0)}if((t[p>>2]|0)!=(_|0)?(t[p>>2]|0)!=(t[(t[h>>2]|0)+8>>2]|0):0)pAi[t[135736>>2]&511](t[p>>2]|0);if(t[b>>2]|0)break}t[b>>2]=t[(t[l>>2]|0)+40>>2];r:while(1){if(!(t[b>>2]|0))break;i=t[b>>2]|0;n:do if((t[t[b>>2]>>2]|0)==2){if(Xl(t[i+8>>2]|0,t[v>>2]|0)|0)break r}else{do if((t[i>>2]|0)==4){if(!(t[(t[b>>2]|0)+12>>2]|0))break;if((t[t[(t[b>>2]|0)+12>>2]>>2]|0)!=2)break;if(Xl(t[(t[(t[b>>2]|0)+12>>2]|0)+8>>2]|0,t[v>>2]|0)|0)break r;else break n}while(0);if((t[t[b>>2]>>2]|0)!=4){L=70;break r}if(!(t[(t[b>>2]|0)+12>>2]|0)){L=70;break r}if((t[t[(t[b>>2]|0)+12>>2]>>2]|0)!=1){L=70;break r}}while(0);t[b>>2]=t[(t[b>>2]|0)+16>>2]}if((L|0)==70){L=0;yR(t[a>>2]|0,519,83864,0)}if(!(t[b>>2]|0)){ER(t[a>>2]|0,t[c>>2]|0,515,83288,t[v>>2]|0,t[(t[c>>2]|0)+8>>2]|0,0);t[w>>2]=0}}while(0);t[h>>2]=t[(t[h>>2]|0)+24>>2]}t[f>>2]=0;R=t[f>>2]|0;s=n;return R|0}else if((r|0)==1){if(!(t[(t[c>>2]|0)+12>>2]|0))break;ER(t[a>>2]|0,t[c>>2]|0,528,83168,t[(t[c>>2]|0)+8>>2]|0,0,0);t[w>>2]=0;break}else break}while(0);t[k>>2]=t[(t[l>>2]|0)+44>>2];while(1){if(!(t[k>>2]|0))break;e:do if((t[(t[k>>2]|0)+44>>2]|0)==2){t[S>>2]=-1;i:do if((t[(t[k>>2]|0)+56>>2]|0)==0?(Xl(t[(t[k>>2]|0)+8>>2]|0,80392)|0)!=0:0){t[g>>2]=t[(t[c>>2]|0)+48>>2];while(1){if(!(t[g>>2]|0))break i;if(!(t[(t[g>>2]|0)+12>>2]|0))break e;t[g>>2]=t[t[g>>2]>>2]}}else L=100;while(0);i:do if((L|0)==100){L=0;i=(Xl(t[(t[k>>2]|0)+56>>2]|0,80392)|0)!=0;e=t[c>>2]|0;if(i){t[y>>2]=t[e+48>>2];while(1){if(!(t[y>>2]|0))break i;if(Xl(t[(t[k>>2]|0)+8>>2]|0,t[(t[y>>2]|0)+12>>2]|0)|0)break e;t[y>>2]=t[t[y>>2]>>2]}}t[F>>2]=t[e+44>>2];while(1){if(!(t[F>>2]|0))break i;do if(Xl(t[(t[F>>2]|0)+8>>2]|0,t[(t[k>>2]|0)+8>>2]|0)|0){if(!(t[(t[k>>2]|0)+56>>2]|0))break e;t[O>>2]=t[(t[F>>2]|0)+36>>2];if(!(t[O>>2]|0))t[O>>2]=t[(t[c>>2]|0)+36>>2];if(!(t[O>>2]|0)){if((t[S>>2]|0)>=0)break;t[S>>2]=0;break}if(Xl(t[(t[O>>2]|0)+12>>2]|0,t[(t[k>>2]|0)+56>>2]|0)|0)break e;if((t[S>>2]|0)>=1)break;t[S>>2]=1}while(0);t[F>>2]=t[(t[F>>2]|0)+24>>2]}}while(0);if((t[S>>2]|0)==-1){e=t[a>>2]|0;i=t[c>>2]|0;D=t[(t[c>>2]|0)+8>>2]|0;C=t[k>>2]|0;if(!(t[(t[k>>2]|0)+56>>2]|0)){ER(e,i,518,83984,D,t[C+8>>2]|0,0);t[w>>2]=0;break}else{ER(e,i,518,84024,D,t[C+56>>2]|0,t[(t[k>>2]|0)+8>>2]|0);t[w>>2]=0;break}}if(!(t[S>>2]|0)){RR(t[a>>2]|0,t[c>>2]|0,524,84072,t[(t[c>>2]|0)+8>>2]|0,t[(t[k>>2]|0)+56>>2]|0,t[(t[k>>2]|0)+8>>2]|0);break}if((t[S>>2]|0)==1)RR(t[a>>2]|0,t[c>>2]|0,506,84128,t[(t[c>>2]|0)+8>>2]|0,t[(t[k>>2]|0)+56>>2]|0,t[(t[k>>2]|0)+8>>2]|0)}else if((t[(t[k>>2]|0)+44>>2]|0)==4){if((t[(t[k>>2]|0)+56>>2]|0)==0?(Xl(t[(t[k>>2]|0)+8>>2]|0,80392)|0)!=0:0){t[A>>2]=t[(t[c>>2]|0)+48>>2];while(1){if(!(t[A>>2]|0))break e;if(!(t[(t[A>>2]|0)+12>>2]|0))break;t[A>>2]=t[t[A>>2]>>2]}if(Xl(t[(t[k>>2]|0)+48>>2]|0,t[(t[A>>2]|0)+8>>2]|0)|0)break;ER(t[a>>2]|0,t[c>>2]|0,507,84192,t[(t[c>>2]|0)+8>>2]|0,0,0);t[w>>2]=0;break}if(Xl(t[(t[k>>2]|0)+56>>2]|0,80392)|0){t[M>>2]=t[(t[c>>2]|0)+48>>2];while(1){if(!(t[M>>2]|0))break e;if(Xl(t[(t[k>>2]|0)+8>>2]|0,t[(t[M>>2]|0)+12>>2]|0)|0)break;t[M>>2]=t[t[M>>2]>>2]}if(!(Xl(t[(t[k>>2]|0)+48>>2]|0,t[(t[M>>2]|0)+8>>2]|0)|0)){ER(t[a>>2]|0,t[c>>2]|0,508,84264,t[(t[c>>2]|0)+8>>2]|0,t[(t[M>>2]|0)+12>>2]|0,0);t[w>>2]=0}}}while(0);t[k>>2]=t[(t[k>>2]|0)+36>>2]}t[f>>2]=t[w>>2];R=t[f>>2]|0;s=n;return R|0}case 3:{if(t[(t[c>>2]|0)+12>>2]|0){ER(t[a>>2]|0,t[c>>2]|0,1,83584,0,0,0);t[f>>2]=0;R=t[f>>2]|0;s=n;return R|0}if(t[(t[c>>2]|0)+36>>2]|0){ER(t[a>>2]|0,t[c>>2]|0,1,83616,0,0,0);t[f>>2]=0;R=t[f>>2]|0;s=n;return R|0}if(!(t[(t[c>>2]|0)+40>>2]|0)){ER(t[a>>2]|0,t[c>>2]|0,1,83648,0,0,0);t[f>>2]=0;R=t[f>>2]|0;s=n;return R|0}else{t[f>>2]=1;R=t[f>>2]|0;s=n;return R|0}break}case 2:{ER(t[a>>2]|0,t[c>>2]|0,1,83552,0,0,0);t[f>>2]=0;R=t[f>>2]|0;s=n;return R|0}case 13:{ER(t[a>>2]|0,t[c>>2]|0,1,83776,0,0,0);t[f>>2]=0;R=t[f>>2]|0;s=n;return R|0}case 12:{ER(t[a>>2]|0,t[c>>2]|0,1,83712,0,0,0);t[f>>2]=0;R=t[f>>2]|0;s=n;return R|0}default:{ER(t[a>>2]|0,t[c>>2]|0,1,83808,0,0,0);t[f>>2]=0;R=t[f>>2]|0;s=n;return R|0}}while(0);return 0}function kR(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0;r=s;s=s+80|0;n=r+20|0;f=r+16|0;u=r+12|0;a=r+8|0;o=r+4|0;c=r+24|0;l=r;t[f>>2]=e;t[u>>2]=i;if(!(t[u>>2]|0)){t[n>>2]=0;b=t[n>>2]|0;s=r;return b|0}t[a>>2]=eF(t[u>>2]|0)|0;if((t[a>>2]|0)!=0?(t[(t[a>>2]|0)+8>>2]|0)!=0:0){do if(((t[(t[u>>2]|0)+44>>2]|0)!=0?(t[(t[(t[u>>2]|0)+44>>2]|0)+8>>2]|0)!=0:0)?(Xl(t[(t[(t[u>>2]|0)+44>>2]|0)+8>>2]|0,t[(t[a>>2]|0)+8>>2]|0)|0)==0:0){if((t[(t[a>>2]|0)+36>>2]|0)!=0?(t[(t[(t[a>>2]|0)+36>>2]|0)+12>>2]|0)!=0:0){t[l>>2]=Ug(t[(t[a>>2]|0)+8>>2]|0,t[(t[(t[a>>2]|0)+36>>2]|0)+12>>2]|0,c,50)|0;if(!(t[l>>2]|0)){gR(t[f>>2]|0,0);t[n>>2]=0;b=t[n>>2]|0;s=r;return b|0}t[o>>2]=Xl(t[(t[(t[u>>2]|0)+44>>2]|0)+8>>2]|0,t[l>>2]|0)|0;if((t[l>>2]|0)!=(c|0)?(t[l>>2]|0)!=(t[(t[a>>2]|0)+8>>2]|0):0)pAi[t[135736>>2]&511](t[l>>2]|0);if((t[o>>2]|0)==1)break}if((Xl(t[(t[(t[u>>2]|0)+44>>2]|0)+8>>2]|0,84352)|0)!=0?(Xl(t[(t[a>>2]|0)+8>>2]|0,84360)|0)!=0:0)break;ER(t[f>>2]|0,t[a>>2]|0,531,84368,t[(t[a>>2]|0)+8>>2]|0,t[(t[(t[u>>2]|0)+44>>2]|0)+8>>2]|0,0);t[n>>2]=0;b=t[n>>2]|0;s=r;return b|0}while(0);t[n>>2]=1;b=t[n>>2]|0;s=r;return b|0}yR(t[f>>2]|0,525,84328,0);t[n>>2]=0;b=t[n>>2]|0;s=r;return b|0}function hR(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0;n=s;s=s+48|0;f=n+32|0;u=n+28|0;a=n+24|0;o=n+20|0;c=n+16|0;l=n+12|0;b=n+8|0;k=n+4|0;h=n;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;t[h>>2]=1;if(!(t[o>>2]|0)){t[f>>2]=0;w=t[f>>2]|0;s=n;return w|0}if(((t[(t[o>>2]|0)+4>>2]|0)!=19?(t[(t[o>>2]|0)+4>>2]|0)!=20:0)?(t[(t[o>>2]|0)+4>>2]|0)!=18:0){if(!(t[a>>2]|0)){t[f>>2]=0;w=t[f>>2]|0;s=n;return w|0}if((t[(t[a>>2]|0)+44>>2]|0)==0?(t[(t[a>>2]|0)+48>>2]|0)==0:0){t[f>>2]=0;w=t[f>>2]|0;s=n;return w|0}if((t[(t[o>>2]|0)+4>>2]|0)==5){t[f>>2]=1;w=t[f>>2]|0;s=n;return w|0}r=bR(t[u>>2]|0,t[a>>2]|0,t[o>>2]|0)|0;t[h>>2]=t[h>>2]&r;e:do if((t[(t[o>>2]|0)+4>>2]|0)==1){t[l>>2]=t[(t[o>>2]|0)+44>>2];while(1){if(!(t[l>>2]|0))break;t[k>>2]=sy(t[a>>2]|0,t[(t[l>>2]|0)+12>>2]|0,0)|0;r=aR(t[u>>2]|0,t[a>>2]|0,t[o>>2]|0,t[l>>2]|0,t[k>>2]|0)|0;t[h>>2]=t[h>>2]&r;if(t[k>>2]|0)pAi[t[135736>>2]&511](t[k>>2]|0);t[l>>2]=t[(t[l>>2]|0)+24>>2]}t[b>>2]=t[(t[o>>2]|0)+48>>2];while(1){if(!(t[b>>2]|0))break e;r=t[u>>2]|0;i=t[a>>2]|0;e=t[o>>2]|0;if(!(t[(t[o>>2]|0)+36>>2]|0)){d=oR(r,i,e,0,t[b>>2]|0,t[(t[b>>2]|0)+8>>2]|0)|0;t[h>>2]=t[h>>2]&d}else{d=oR(r,i,e,t[(t[(t[o>>2]|0)+36>>2]|0)+12>>2]|0,t[b>>2]|0,t[(t[b>>2]|0)+8>>2]|0)|0;t[h>>2]=t[h>>2]&d}t[b>>2]=t[t[b>>2]>>2]}}while(0);t[c>>2]=t[(t[o>>2]|0)+12>>2];while(1){if(!(t[c>>2]|0))break;o=hR(t[u>>2]|0,t[a>>2]|0,t[c>>2]|0)|0;t[h>>2]=t[h>>2]&o;t[c>>2]=t[(t[c>>2]|0)+24>>2]}t[f>>2]=t[h>>2];w=t[f>>2]|0;s=n;return w|0}t[f>>2]=1;w=t[f>>2]|0;s=n;return w|0}function wR(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0;r=s;s=s+32|0;n=r+16|0;f=r+12|0;u=r+8|0;a=r+4|0;o=r;t[f>>2]=e;t[u>>2]=i;if(!(t[f>>2]|0)){t[n>>2]=0;c=t[n>>2]|0;s=r;return c|0}i=t[f>>2]|0;if(!(t[u>>2]|0)){yR(i,521,84416,0);t[n>>2]=0;c=t[n>>2]|0;s=r;return c|0}else{t[o>>2]=t[i+28>>2];t[(t[f>>2]|0)+28>>2]=0;t[a>>2]=t[(t[u>>2]|0)+68>>2];t[(t[f>>2]|0)+32>>2]=t[u>>2];t[(t[f>>2]|0)+36>>2]=1;aO(t[a>>2]|0,254,t[f>>2]|0);t[(t[f>>2]|0)+28>>2]=t[o>>2];t[n>>2]=t[(t[f>>2]|0)+36>>2];c=t[n>>2]|0;s=r;return c|0}return 0}function dR(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0;n=s;s=s+32|0;f=n+28|0;u=n+24|0;a=n+20|0;o=n+16|0;c=n+12|0;l=n+8|0;b=n+4|0;k=n;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;if(!(t[o>>2]|0)){t[f>>2]=0;h=t[f>>2]|0;s=n;return h|0}if(!(t[a>>2]|0)){t[f>>2]=0;h=t[f>>2]|0;s=n;return h|0}t[l>>2]=t[(t[a>>2]|0)+48>>2];t[b>>2]=t[(t[a>>2]|0)+44>>2];t[(t[a>>2]|0)+48>>2]=t[o>>2];t[(t[a>>2]|0)+44>>2]=0;t[c>>2]=kR(t[u>>2]|0,t[a>>2]|0)|0;if(!(t[c>>2]|0)){t[(t[a>>2]|0)+48>>2]=t[l>>2];t[(t[a>>2]|0)+44>>2]=t[b>>2];t[f>>2]=t[c>>2];h=t[f>>2]|0;s=n;return h|0}if(t[(t[a>>2]|0)+64>>2]|0){jM(t[(t[a>>2]|0)+64>>2]|0);t[(t[a>>2]|0)+64>>2]=0}if(t[(t[a>>2]|0)+68>>2]|0){KM(t[(t[a>>2]|0)+68>>2]|0);t[(t[a>>2]|0)+68>>2]=0}t[k>>2]=eF(t[a>>2]|0)|0;t[c>>2]=hR(t[u>>2]|0,t[a>>2]|0,t[k>>2]|0)|0;k=wR(t[u>>2]|0,t[a>>2]|0)|0;t[c>>2]=t[c>>2]&k;t[(t[a>>2]|0)+48>>2]=t[l>>2];t[(t[a>>2]|0)+44>>2]=t[b>>2];t[f>>2]=t[c>>2];h=t[f>>2]|0;s=n;return h|0}function vR(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0;r=s;s=s+32|0;n=r+20|0;f=r+16|0;u=r+12|0;a=r+8|0;o=r+4|0;c=r;t[f>>2]=e;t[u>>2]=i;if((t[u>>2]|0)==0|(t[f>>2]|0)==0){t[n>>2]=0;l=t[n>>2]|0;s=r;return l|0}if((t[(t[u>>2]|0)+44>>2]|0)==0?(t[(t[u>>2]|0)+48>>2]|0)==0:0){t[n>>2]=0;l=t[n>>2]|0;s=r;return l|0}t[(t[f>>2]|0)+32>>2]=t[u>>2];t[(t[f>>2]|0)+36>>2]=1;t[a>>2]=t[(t[u>>2]|0)+44>>2];if((t[a>>2]|0)!=0?(t[(t[a>>2]|0)+44>>2]|0)!=0:0){t[o>>2]=t[(t[a>>2]|0)+44>>2];aO(t[o>>2]|0,255,t[f>>2]|0)}if((t[a>>2]|0)!=0?(t[(t[a>>2]|0)+48>>2]|0)!=0:0){t[c>>2]=t[(t[a>>2]|0)+48>>2];aO(t[c>>2]|0,256,t[f>>2]|0)}t[a>>2]=t[(t[u>>2]|0)+48>>2];if((t[a>>2]|0)!=0?(t[(t[a>>2]|0)+44>>2]|0)!=0:0){t[o>>2]=t[(t[a>>2]|0)+44>>2];aO(t[o>>2]|0,255,t[f>>2]|0)}if((t[a>>2]|0)!=0?(t[(t[a>>2]|0)+48>>2]|0)!=0:0){t[c>>2]=t[(t[a>>2]|0)+48>>2];aO(t[c>>2]|0,256,t[f>>2]|0)}t[n>>2]=t[(t[f>>2]|0)+36>>2];l=t[n>>2]|0;s=r;return l|0}function mR(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0;r=s;s=s+32|0;n=r+20|0;f=r+16|0;u=r+12|0;a=r+8|0;o=r+4|0;c=r;t[f>>2]=e;t[u>>2]=i;if(!(t[u>>2]|0)){t[n>>2]=0;l=t[n>>2]|0;s=r;return l|0}if((t[(t[u>>2]|0)+44>>2]|0)==0?(t[(t[u>>2]|0)+48>>2]|0)==0:0){yR(t[f>>2]|0,522,84456,0);t[n>>2]=0;l=t[n>>2]|0;s=r;return l|0}do if(t[(t[u>>2]|0)+44>>2]|0){if((t[(t[(t[u>>2]|0)+44>>2]|0)+56>>2]|0)==0?(t[(t[(t[u>>2]|0)+44>>2]|0)+52>>2]|0)==0:0)break;if(!(t[(t[u>>2]|0)+48>>2]|0)){if(t[(t[(t[u>>2]|0)+44>>2]|0)+56>>2]|0){t[c>>2]=GA(t[(t[(t[u>>2]|0)+44>>2]|0)+56>>2]|0,t[(t[u>>2]|0)+72>>2]|0)|0;if(!(t[c>>2]|0)){yR(t[f>>2]|0,517,84472,t[(t[(t[u>>2]|0)+44>>2]|0)+56>>2]|0);t[n>>2]=0;l=t[n>>2]|0;s=r;return l|0}}else t[c>>2]=0;i=aS(t[(t[(t[u>>2]|0)+44>>2]|0)+52>>2]|0,t[c>>2]|0)|0;t[(t[u>>2]|0)+48>>2]=i;if(t[c>>2]|0)pAi[t[135736>>2]&511](t[c>>2]|0);if(!(t[(t[u>>2]|0)+48>>2]|0)){i=t[f>>2]|0;e=t[(t[u>>2]|0)+44>>2]|0;if(t[(t[(t[u>>2]|0)+44>>2]|0)+56>>2]|0)yR(i,517,84520,t[e+56>>2]|0);else yR(i,517,84520,t[e+52>>2]|0);t[n>>2]=0;l=t[n>>2]|0;s=r;return l|0}}}while(0);if(t[(t[u>>2]|0)+64>>2]|0){jM(t[(t[u>>2]|0)+64>>2]|0);t[(t[u>>2]|0)+64>>2]=0}if(t[(t[u>>2]|0)+68>>2]|0){KM(t[(t[u>>2]|0)+68>>2]|0);t[(t[u>>2]|0)+68>>2]=0}t[a>>2]=vR(t[f>>2]|0,t[u>>2]|0)|0;if(kR(t[f>>2]|0,t[u>>2]|0)|0){t[o>>2]=eF(t[u>>2]|0)|0;c=hR(t[f>>2]|0,t[u>>2]|0,t[o>>2]|0)|0;t[a>>2]=t[a>>2]&c;c=wR(t[f>>2]|0,t[u>>2]|0)|0;t[a>>2]=t[a>>2]&c;t[n>>2]=t[a>>2];l=t[n>>2]|0;s=r;return l|0}else{t[n>>2]=0;l=t[n>>2]|0;s=r;return l|0}return 0}function _R(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0;f=s;s=s+32|0;u=f+20|0;a=f+16|0;o=f+12|0;c=f+8|0;l=f+4|0;b=f;t[a>>2]=e;t[o>>2]=i;t[c>>2]=r;t[l>>2]=n;if((t[a>>2]|0)==0|(t[o>>2]|0)==0|(t[c>>2]|0)==0){t[u>>2]=-1;k=t[u>>2]|0;s=f;return k|0}if((t[t[c>>2]>>2]|0)>=(t[l>>2]|0)){t[u>>2]=t[t[c>>2]>>2];k=t[u>>2]|0;s=f;return k|0}n=t[t[a>>2]>>2]|0;do if((n|0)==4){_R(t[(t[a>>2]|0)+12>>2]|0,t[o>>2]|0,t[c>>2]|0,t[l>>2]|0)|0;_R(t[(t[a>>2]|0)+16>>2]|0,t[o>>2]|0,t[c>>2]|0,t[l>>2]|0)|0}else if((n|0)==2){t[b>>2]=0;while(1){h=t[(t[a>>2]|0)+8>>2]|0;if((t[b>>2]|0)>=(t[t[c>>2]>>2]|0)){w=17;break}if(Xl(h,t[(t[o>>2]|0)+(t[b>>2]<<2)>>2]|0)|0)break;t[b>>2]=(t[b>>2]|0)+1}if((w|0)==17){r=t[c>>2]|0;i=t[r>>2]|0;t[r>>2]=i+1;t[(t[o>>2]|0)+(i<<2)>>2]=h;break}t[u>>2]=t[t[c>>2]>>2];k=t[u>>2]|0;s=f;return k|0}else if((n|0)==1){t[b>>2]=0;while(1){if((t[b>>2]|0)>=(t[t[c>>2]>>2]|0)){w=11;break}if(Xl(79640,t[(t[o>>2]|0)+(t[b>>2]<<2)>>2]|0)|0)break;t[b>>2]=(t[b>>2]|0)+1}if((w|0)==11){i=t[c>>2]|0;r=t[i>>2]|0;t[i>>2]=r+1;t[(t[o>>2]|0)+(r<<2)>>2]=79640;break}t[u>>2]=t[t[c>>2]>>2];k=t[u>>2]|0;s=f;return k|0}else if((n|0)==3){_R(t[(t[a>>2]|0)+12>>2]|0,t[o>>2]|0,t[c>>2]|0,t[l>>2]|0)|0;_R(t[(t[a>>2]|0)+16>>2]|0,t[o>>2]|0,t[c>>2]|0,t[l>>2]|0)|0}while(0);t[u>>2]=t[t[c>>2]>>2];k=t[u>>2]|0;s=f;return k|0}function pR(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0,S=0,g=0,y=0,F=0,O=0,A=0,M=0,R=0;f=s;s=s+1168|0;u=f+1160|0;a=f+1156|0;o=f+1152|0;c=f+1148|0;l=f+1144|0;b=f+1080|0;k=f+1072|0;h=f+48|0;w=f+44|0;d=f+40|0;v=f+36|0;m=f+32|0;_=f+28|0;p=f+24|0;E=f+20|0;S=f+16|0;g=f+12|0;y=f+8|0;F=f+4|0;O=f;t[a>>2]=e;t[o>>2]=i;t[c>>2]=r;t[l>>2]=n;t[k>>2]=0;VY(h|0,0,1024)|0;t[w>>2]=0;if((t[a>>2]|0)==0&(t[o>>2]|0)==0){t[u>>2]=-1;A=t[u>>2]|0;s=f;return A|0}if(!(t[c>>2]|0)){t[u>>2]=-1;A=t[u>>2]|0;s=f;return A|0}if((t[l>>2]|0)<=0){t[u>>2]=-1;A=t[u>>2]|0;s=f;return A|0}n=b+0|0;r=n+64|0;do{t[n>>2]=0;n=n+4|0}while((n|0)<(r|0));t[b+4>>2]=257;t[k>>2]=0;t[m>>2]=(t[a>>2]|0)!=0?t[a>>2]|0:t[o>>2]|0;t[_>>2]=t[(t[m>>2]|0)+20>>2];t[F>>2]=ZM(t[(t[(t[_>>2]|0)+32>>2]|0)+44>>2]|0,t[(t[_>>2]|0)+8>>2]|0)|0;if((t[F>>2]|0)==0?(t[(t[(t[_>>2]|0)+32>>2]|0)+48>>2]|0)!=0:0)t[F>>2]=ZM(t[(t[(t[_>>2]|0)+32>>2]|0)+48>>2]|0,t[(t[_>>2]|0)+8>>2]|0)|0;if(!(t[F>>2]|0)){t[u>>2]=-1;A=t[u>>2]|0;s=f;return A|0}if(t[a>>2]|0)M=t[(t[a>>2]|0)+24>>2]|0;else M=0;t[E>>2]=M;if(t[o>>2]|0)R=t[(t[o>>2]|0)+28>>2]|0;else R=0;t[S>>2]=R;t[g>>2]=t[(t[_>>2]|0)+12>>2];t[y>>2]=t[(t[_>>2]|0)+16>>2];t[p>>2]=Sy(t[(t[m>>2]|0)+32>>2]|0,0,84568,0)|0;if(!(t[p>>2]|0)){t[u>>2]=-1;A=t[u>>2]|0;s=f;return A|0}t[(t[p>>2]|0)+20>>2]=t[_>>2];t[(t[p>>2]|0)+28>>2]=t[a>>2];t[(t[p>>2]|0)+24>>2]=t[o>>2];t[v>>2]=t[(t[p>>2]|0)+8>>2];m=t[p>>2]|0;if(t[a>>2]|0)t[(t[a>>2]|0)+24>>2]=m;else t[(t[_>>2]|0)+12>>2]=m;m=t[p>>2]|0;if(t[o>>2]|0)t[(t[o>>2]|0)+28>>2]=m;else t[(t[_>>2]|0)+16>>2]=m;t[w>>2]=_R(t[(t[F>>2]|0)+40>>2]|0,h,w,256)|0;t[d>>2]=0;while(1){if((t[d>>2]|0)>=(t[w>>2]|0))break;t[(t[p>>2]|0)+8>>2]=t[h+(t[d>>2]<<2)>>2];if(bR(b,t[(t[_>>2]|0)+32>>2]|0,t[_>>2]|0)|0){t[O>>2]=0;while(1){if((t[O>>2]|0)>=(t[k>>2]|0))break;if(Xl(t[h+(t[d>>2]<<2)>>2]|0,t[(t[c>>2]|0)+(t[O>>2]<<2)>>2]|0)|0)break;t[O>>2]=(t[O>>2]|0)+1}F=t[h+(t[d>>2]<<2)>>2]|0;m=t[k>>2]|0;t[k>>2]=m+1;t[(t[c>>2]|0)+(m<<2)>>2]=F;if((t[k>>2]|0)>=(t[l>>2]|0))break}t[d>>2]=(t[d>>2]|0)+1}if(t[a>>2]|0)t[(t[a>>2]|0)+24>>2]=t[E>>2];if(t[o>>2]|0)t[(t[o>>2]|0)+28>>2]=t[S>>2];t[(t[_>>2]|0)+12>>2]=t[g>>2];t[(t[_>>2]|0)+16>>2]=t[y>>2];t[(t[p>>2]|0)+8>>2]=t[v>>2];ry(t[p>>2]|0);t[u>>2]=t[k>>2];A=t[u>>2]|0;s=f;return A|0}function ER(e,i,r,n,f,u,a){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;u=u|0;a=a|0;var o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0,S=0;o=s;s=s+64|0;c=o;l=o+56|0;b=o+52|0;k=o+48|0;h=o+44|0;w=o+40|0;d=o+36|0;v=o+32|0;m=o+28|0;_=o+24|0;p=o+20|0;E=o+16|0;S=o+12|0;t[l>>2]=e;t[b>>2]=i;t[k>>2]=r;t[h>>2]=n;t[w>>2]=f;t[d>>2]=u;t[v>>2]=a;t[m>>2]=0;t[_>>2]=0;t[p>>2]=0;t[E>>2]=0;do if(t[l>>2]|0){t[_>>2]=t[(t[l>>2]|0)+4>>2];t[E>>2]=t[t[l>>2]>>2];if((t[(t[l>>2]|0)+28>>2]|0)!=-1412623820?(t[(t[l>>2]|0)+28>>2]|0)!=-1412623819:0)break;t[S>>2]=(t[l>>2]|0)-(t[t[l>>2]>>2]|0);if((t[S>>2]|0)>0&(t[S>>2]|0)<250)t[p>>2]=t[t[l>>2]>>2]}while(0);l=t[m>>2]|0;m=t[_>>2]|0;_=t[E>>2]|0;E=t[p>>2]|0;p=t[b>>2]|0;b=t[k>>2]|0;k=t[w>>2]|0;S=t[w>>2]|0;a=t[v>>2]|0;u=t[h>>2]|0;h=t[d>>2]|0;d=t[v>>2]|0;t[c>>2]=t[w>>2];t[c+4>>2]=h;t[c+8>>2]=d;cp(l,m,_,E,p,23,b,2,0,0,k,S,a,0,0,u,c);s=o;return}function SR(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0;n=s;s=s+112|0;f=n+44|0;u=n+40|0;a=n+36|0;o=n+32|0;c=n+28|0;l=n+48|0;b=n+24|0;k=n+20|0;h=n+16|0;w=n+12|0;d=n+8|0;v=n+4|0;m=n;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;if(!(t[u>>2]|0)){ER(t[a>>2]|0,0,1,85712,t[o>>2]|0,0,0);t[f>>2]=0;_=t[f>>2]|0;s=n;return _|0}r=t[t[u>>2]>>2]|0;do if((r|0)==2){t[c>>2]=t[(t[a>>2]|0)+60>>2];t[b>>2]=Ug(t[(t[u>>2]|0)+8>>2]|0,t[(t[u>>2]|0)+24>>2]|0,l,50)|0;if(!(t[b>>2]|0)){gR(t[a>>2]|0,85800);t[f>>2]=0;_=t[f>>2]|0;s=n;return _|0}i=t[(t[u>>2]|0)+4>>2]|0;if((i|0)==4){e=ob(t[(t[a>>2]|0)+56>>2]|0,t[(t[a>>2]|0)+60>>2]|0,0,t[b>>2]|0,0)|0;t[(t[a>>2]|0)+60>>2]=e;ob(t[(t[a>>2]|0)+56>>2]|0,t[(t[a>>2]|0)+60>>2]|0,t[(t[a>>2]|0)+60>>2]|0,t[b>>2]|0,0)|0}else if((i|0)==1){e=ob(t[(t[a>>2]|0)+56>>2]|0,t[(t[a>>2]|0)+60>>2]|0,0,t[b>>2]|0,0)|0;t[(t[a>>2]|0)+60>>2]=e}else if((i|0)==2){e=ob(t[(t[a>>2]|0)+56>>2]|0,t[(t[a>>2]|0)+60>>2]|0,0,t[b>>2]|0,0)|0;t[(t[a>>2]|0)+60>>2]=e;hb(t[(t[a>>2]|0)+56>>2]|0,t[c>>2]|0,t[(t[a>>2]|0)+60>>2]|0)|0}else if((i|0)==3){i=hb(t[(t[a>>2]|0)+56>>2]|0,t[(t[a>>2]|0)+60>>2]|0,0)|0;t[(t[a>>2]|0)+60>>2]=i;ob(t[(t[a>>2]|0)+56>>2]|0,t[(t[a>>2]|0)+60>>2]|0,t[(t[a>>2]|0)+60>>2]|0,t[b>>2]|0,0)|0}if((t[b>>2]|0)!=(l|0)?(t[b>>2]|0)!=(t[(t[u>>2]|0)+8>>2]|0):0)pAi[t[135736>>2]&511](t[b>>2]|0)}else if((r|0)==4){t[m>>2]=t[(t[u>>2]|0)+4>>2];if((t[m>>2]|0)==4|(t[m>>2]|0)==3){i=hb(t[(t[a>>2]|0)+56>>2]|0,t[(t[a>>2]|0)+60>>2]|0,0)|0;t[(t[a>>2]|0)+60>>2]=i}t[d>>2]=t[(t[a>>2]|0)+60>>2];t[v>>2]=kb(t[(t[a>>2]|0)+56>>2]|0)|0;do{t[(t[a>>2]|0)+60>>2]=t[d>>2];SR(t[(t[u>>2]|0)+12>>2]|0,t[a>>2]|0,t[o>>2]|0)|0;hb(t[(t[a>>2]|0)+56>>2]|0,t[(t[a>>2]|0)+60>>2]|0,t[v>>2]|0)|0;t[u>>2]=t[(t[u>>2]|0)+16>>2];if((t[t[u>>2]>>2]|0)!=4)break}while((t[(t[u>>2]|0)+4>>2]|0)==1);t[(t[a>>2]|0)+60>>2]=t[d>>2];SR(t[u>>2]|0,t[a>>2]|0,t[o>>2]|0)|0;hb(t[(t[a>>2]|0)+56>>2]|0,t[(t[a>>2]|0)+60>>2]|0,t[v>>2]|0)|0;i=hb(t[(t[a>>2]|0)+56>>2]|0,t[v>>2]|0,0)|0;t[(t[a>>2]|0)+60>>2]=i;i=t[m>>2]|0;if((i|0)==3){hb(t[(t[a>>2]|0)+56>>2]|0,t[d>>2]|0,t[(t[a>>2]|0)+60>>2]|0)|0;hb(t[(t[a>>2]|0)+56>>2]|0,t[v>>2]|0,t[d>>2]|0)|0;break}else if((i|0)==4){hb(t[(t[a>>2]|0)+56>>2]|0,t[v>>2]|0,t[d>>2]|0)|0;break}else if((i|0)==2){hb(t[(t[a>>2]|0)+56>>2]|0,t[d>>2]|0,t[(t[a>>2]|0)+60>>2]|0)|0;break}else break}else if((r|0)==1){ER(t[a>>2]|0,0,1,85760,t[o>>2]|0,0,0);t[f>>2]=0;_=t[f>>2]|0;s=n;return _|0}else if((r|0)==3){t[k>>2]=t[(t[a>>2]|0)+60>>2];t[w>>2]=t[(t[u>>2]|0)+4>>2];if((t[w>>2]|0)!=1){i=hb(t[(t[a>>2]|0)+56>>2]|0,t[k>>2]|0,0)|0;t[(t[a>>2]|0)+60>>2]=i;t[k>>2]=t[(t[a>>2]|0)+60>>2]}do{SR(t[(t[u>>2]|0)+12>>2]|0,t[a>>2]|0,t[o>>2]|0)|0;t[u>>2]=t[(t[u>>2]|0)+16>>2];if((t[t[u>>2]>>2]|0)!=3)break}while((t[(t[u>>2]|0)+4>>2]|0)==1);SR(t[u>>2]|0,t[a>>2]|0,t[o>>2]|0)|0;t[h>>2]=t[(t[a>>2]|0)+60>>2];i=hb(t[(t[a>>2]|0)+56>>2]|0,t[h>>2]|0,0)|0;t[(t[a>>2]|0)+60>>2]=i;i=t[w>>2]|0;if((i|0)==3){hb(t[(t[a>>2]|0)+56>>2]|0,t[k>>2]|0,t[(t[a>>2]|0)+60>>2]|0)|0;hb(t[(t[a>>2]|0)+56>>2]|0,t[h>>2]|0,t[k>>2]|0)|0;break}else if((i|0)==2){hb(t[(t[a>>2]|0)+56>>2]|0,t[k>>2]|0,t[(t[a>>2]|0)+60>>2]|0)|0;break}else if((i|0)==4){hb(t[(t[a>>2]|0)+56>>2]|0,t[h>>2]|0,t[k>>2]|0)|0;break}else break}else{yR(t[a>>2]|0,1,85824,t[o>>2]|0);t[f>>2]=0;_=t[f>>2]|0;s=n;return _|0}while(0);t[f>>2]=1;_=t[f>>2]|0;s=n;return _|0}function gR(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0;r=s;s=s+32|0;n=r;f=r+24|0;u=r+20|0;a=r+16|0;o=r+12|0;c=r+8|0;l=r+4|0;t[f>>2]=e;t[u>>2]=i;t[a>>2]=0;t[o>>2]=0;t[c>>2]=0;do if(t[f>>2]|0){t[a>>2]=t[(t[f>>2]|0)+4>>2];t[c>>2]=t[t[f>>2]>>2];if((t[(t[f>>2]|0)+28>>2]|0)!=-1412623820?(t[(t[f>>2]|0)+28>>2]|0)!=-1412623819:0)break;t[l>>2]=(t[f>>2]|0)-(t[t[f>>2]>>2]|0);if((t[l>>2]|0)>0&(t[l>>2]|0)<250)t[o>>2]=t[t[f>>2]>>2]}while(0);f=t[a>>2]|0;a=t[c>>2]|0;c=t[o>>2]|0;if(t[u>>2]|0){o=t[u>>2]|0;t[n>>2]=t[u>>2];cp(0,f,a,c,0,23,2,3,0,0,o,0,0,0,0,85648,n);s=r;return}else{cp(0,f,a,c,0,23,2,3,0,0,0,0,0,0,0,85680,n);s=r;return}}function yR(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0;f=s;s=s+48|0;u=f;a=f+32|0;o=f+28|0;c=f+24|0;l=f+20|0;b=f+16|0;k=f+12|0;h=f+8|0;w=f+4|0;t[a>>2]=e;t[o>>2]=i;t[c>>2]=r;t[l>>2]=n;t[b>>2]=0;t[k>>2]=0;t[h>>2]=0;do if(t[a>>2]|0){t[b>>2]=t[(t[a>>2]|0)+4>>2];t[h>>2]=t[t[a>>2]>>2];if((t[(t[a>>2]|0)+28>>2]|0)!=-1412623820?(t[(t[a>>2]|0)+28>>2]|0)!=-1412623819:0)break;t[w>>2]=(t[a>>2]|0)-(t[t[a>>2]>>2]|0);if((t[w>>2]|0)>0&(t[w>>2]|0)<250)t[k>>2]=t[t[a>>2]>>2]}while(0);a=t[b>>2]|0;b=t[h>>2]|0;h=t[k>>2]|0;k=t[o>>2]|0;if(t[l>>2]|0){o=t[l>>2]|0;w=t[c>>2]|0;t[u>>2]=t[l>>2];cp(0,a,b,h,0,23,k,2,0,0,o,0,0,0,0,w,u);s=f;return}else{t[u>>2]=t[c>>2];cp(0,a,b,h,0,23,k,2,0,0,0,0,0,0,0,85640,u);s=f;return}}function FR(e){e=e|0;var i=0,r=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if(!(t[r>>2]|0)){s=i;return}iy(t[r>>2]|0);yM(t[(t[r>>2]|0)+32>>2]|0,t[(t[r>>2]|0)+40>>2]|0);if(t[(t[r>>2]|0)+8>>2]|0)pAi[t[135736>>2]&511](t[(t[r>>2]|0)+8>>2]|0);if(t[(t[r>>2]|0)+48>>2]|0)pAi[t[135736>>2]&511](t[(t[r>>2]|0)+48>>2]|0);if(t[(t[r>>2]|0)+52>>2]|0)fb(t[(t[r>>2]|0)+52>>2]|0);pAi[t[135736>>2]&511](t[r>>2]|0);s=i;return}function OR(e){e=e|0;var i=0,r=0,n=0,f=0,u=0,a=0;i=s;s=s+16|0;r=i+8|0;n=i+4|0;f=i;t[n>>2]=e;t[f>>2]=gAi[t[135744>>2]&511](56)|0;if(!(t[f>>2]|0)){gR(0,79472);t[r>>2]=0;u=t[r>>2]|0;s=i;return u|0}e=(t[f>>2]|0)+0|0;a=e+56|0;do{t[e>>2]=0;e=e+4|0}while((e|0)<(a|0));t[(t[f>>2]|0)+4>>2]=15;t[(t[f>>2]|0)+36>>2]=t[(t[n>>2]|0)+36>>2];if(t[(t[n>>2]|0)+8>>2]|0){e=Yl(t[(t[n>>2]|0)+8>>2]|0)|0;t[(t[f>>2]|0)+8>>2]=e}else t[(t[f>>2]|0)+8>>2]=0;if(t[(t[n>>2]|0)+48>>2]|0){e=Yl(t[(t[n>>2]|0)+48>>2]|0)|0;t[(t[f>>2]|0)+48>>2]=e}else t[(t[f>>2]|0)+48>>2]=0;e=gM(t[(t[n>>2]|0)+40>>2]|0)|0;t[(t[f>>2]|0)+40>>2]=e;t[(t[f>>2]|0)+44>>2]=0;t[r>>2]=t[f>>2];u=t[r>>2]|0;s=i;return u|0}function AR(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0;n=s;s=s+16|0;f=n+8|0;u=n+4|0;a=n;t[f>>2]=e;t[u>>2]=i;t[a>>2]=r;if(!(t[u>>2]|0)){s=n;return}if(t[a>>2]|0)NF(t[f>>2]|0,79632);r=t[t[u>>2]>>2]|0;e:do if((r|0)==1)NF(t[f>>2]|0,79640);else if((r|0)==4){if((t[t[(t[u>>2]|0)+12>>2]>>2]|0)!=4?(t[t[(t[u>>2]|0)+12>>2]>>2]|0)!=3:0)AR(t[f>>2]|0,t[(t[u>>2]|0)+12>>2]|0,0);else AR(t[f>>2]|0,t[(t[u>>2]|0)+12>>2]|0,1);NF(t[f>>2]|0,79664);do if((t[t[(t[u>>2]|0)+16>>2]>>2]|0)!=3){if((t[t[(t[u>>2]|0)+16>>2]>>2]|0)==4?(t[(t[(t[u>>2]|0)+16>>2]|0)+4>>2]|0)!=1:0)break;AR(t[f>>2]|0,t[(t[u>>2]|0)+16>>2]|0,0);break e}while(0);AR(t[f>>2]|0,t[(t[u>>2]|0)+16>>2]|0,1)}else if((r|0)==2){if(t[(t[u>>2]|0)+24>>2]|0){RF(t[f>>2]|0,t[(t[u>>2]|0)+24>>2]|0);NF(t[f>>2]|0,79648)}RF(t[f>>2]|0,t[(t[u>>2]|0)+8>>2]|0)}else if((r|0)==3){if((t[t[(t[u>>2]|0)+12>>2]>>2]|0)!=4?(t[t[(t[u>>2]|0)+12>>2]>>2]|0)!=3:0)AR(t[f>>2]|0,t[(t[u>>2]|0)+12>>2]|0,0);else AR(t[f>>2]|0,t[(t[u>>2]|0)+12>>2]|0,1);NF(t[f>>2]|0,79656);do if((t[t[(t[u>>2]|0)+16>>2]>>2]|0)!=4){if((t[t[(t[u>>2]|0)+16>>2]>>2]|0)==3?(t[(t[(t[u>>2]|0)+16>>2]|0)+4>>2]|0)!=1:0)break;AR(t[f>>2]|0,t[(t[u>>2]|0)+16>>2]|0,0);break e}while(0);AR(t[f>>2]|0,t[(t[u>>2]|0)+16>>2]|0,1)}else yR(0,1,79568,0);while(0);if(t[a>>2]|0)NF(t[f>>2]|0,79672);a=t[(t[u>>2]|0)+4>>2]|0;if((a|0)==2){NF(t[f>>2]|0,79680);s=n;return}else if((a|0)==3){NF(t[f>>2]|0,79688);s=n;return}else if((a|0)==4){NF(t[f>>2]|0,79696);s=n;return}else{s=n;return}}function MR(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0;n=s;s=s+16|0;f=n+12|0;u=n+8|0;a=n+4|0;o=n;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;switch(t[a>>2]|0){case 10:case 2:case 3:case 5:{t[f>>2]=jR(t[u>>2]|0,t[o>>2]|0)|0;break}case 7:{t[f>>2]=qR(t[u>>2]|0,t[o>>2]|0)|0;break}case 4:case 6:{t[f>>2]=VR(t[u>>2]|0,t[o>>2]|0)|0;break}case 9:case 8:{t[f>>2]=YR(t[u>>2]|0,t[o>>2]|0)|0;break}default:t[f>>2]=1}s=n;return t[f>>2]|0}function RR(e,i,r,n,f,u,a){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;u=u|0;a=a|0;var o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0,S=0;o=s;s=s+64|0;c=o;l=o+56|0;b=o+52|0;k=o+48|0;h=o+44|0;w=o+40|0;d=o+36|0;v=o+32|0;m=o+28|0;_=o+24|0;p=o+20|0;E=o+16|0;S=o+12|0;t[l>>2]=e;t[b>>2]=i;t[k>>2]=r;t[h>>2]=n;t[w>>2]=f;t[d>>2]=u;t[v>>2]=a;t[m>>2]=0;t[_>>2]=0;t[p>>2]=0;t[E>>2]=0;do if(t[l>>2]|0){t[_>>2]=t[(t[l>>2]|0)+8>>2];t[E>>2]=t[t[l>>2]>>2];if((t[(t[l>>2]|0)+28>>2]|0)!=-1412623820?(t[(t[l>>2]|0)+28>>2]|0)!=-1412623819:0)break;t[S>>2]=(t[l>>2]|0)-(t[t[l>>2]>>2]|0);if((t[S>>2]|0)>0&(t[S>>2]|0)<250)t[p>>2]=t[t[l>>2]>>2]}while(0);l=t[m>>2]|0;m=t[_>>2]|0;_=t[E>>2]|0;E=t[p>>2]|0;p=t[b>>2]|0;b=t[k>>2]|0;k=t[w>>2]|0;S=t[w>>2]|0;a=t[v>>2]|0;u=t[h>>2]|0;h=t[d>>2]|0;d=t[v>>2]|0;t[c>>2]=t[w>>2];t[c+4>>2]=h;t[c+8>>2]=d;cp(l,m,_,E,p,23,b,1,0,0,k,S,a,0,0,u,c);s=o;return}function NR(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i+4|0;n=i;t[r>>2]=e;if(!(t[r>>2]|0)){s=i;return}if(t[(t[r>>2]|0)+32>>2]|0)t[n>>2]=t[(t[(t[r>>2]|0)+32>>2]|0)+80>>2];else t[n>>2]=0;iy(t[r>>2]|0);if(t[(t[r>>2]|0)+52>>2]|0)NM(t[(t[r>>2]|0)+52>>2]|0);e=(t[(t[r>>2]|0)+60>>2]|0)!=0;if(t[n>>2]|0){if(e?(wz(t[n>>2]|0,t[(t[r>>2]|0)+60>>2]|0)|0)==0:0)pAi[t[135736>>2]&511](t[(t[r>>2]|0)+60>>2]|0);if((t[(t[r>>2]|0)+8>>2]|0)!=0?(wz(t[n>>2]|0,t[(t[r>>2]|0)+8>>2]|0)|0)==0:0)pAi[t[135736>>2]&511](t[(t[r>>2]|0)+8>>2]|0);if((t[(t[r>>2]|0)+56>>2]|0)!=0?(wz(t[n>>2]|0,t[(t[r>>2]|0)+56>>2]|0)|0)==0:0)pAi[t[135736>>2]&511](t[(t[r>>2]|0)+56>>2]|0);if((t[(t[r>>2]|0)+48>>2]|0)!=0?(wz(t[n>>2]|0,t[(t[r>>2]|0)+48>>2]|0)|0)==0:0)pAi[t[135736>>2]&511](t[(t[r>>2]|0)+48>>2]|0)}else{if(e)pAi[t[135736>>2]&511](t[(t[r>>2]|0)+60>>2]|0);if(t[(t[r>>2]|0)+8>>2]|0)pAi[t[135736>>2]&511](t[(t[r>>2]|0)+8>>2]|0);if(t[(t[r>>2]|0)+48>>2]|0)pAi[t[135736>>2]&511](t[(t[r>>2]|0)+48>>2]|0);if(t[(t[r>>2]|0)+56>>2]|0)pAi[t[135736>>2]&511](t[(t[r>>2]|0)+56>>2]|0)}pAi[t[135736>>2]&511](t[r>>2]|0);s=i;return}function TR(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0;n=s;s=s+48|0;f=n+32|0;u=n+28|0;a=n+24|0;o=n+20|0;c=n+16|0;l=n+12|0;b=n+8|0;k=n+4|0;h=n;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;t[b>>2]=0;t[k>>2]=0;if(!(t[u>>2]|0)){t[f>>2]=0;w=t[f>>2]|0;s=n;return w|0}if(!(t[(t[u>>2]|0)+40>>2]|0)){t[h>>2]=0;if(t[(t[u>>2]|0)+32>>2]|0)t[h>>2]=t[(t[(t[u>>2]|0)+32>>2]|0)+80>>2];if(!(t[o>>2]|0)){t[f>>2]=0;w=t[f>>2]|0;s=n;return w|0}t[c>>2]=t[(t[u>>2]|0)+40>>2];if(!(t[c>>2]|0)){t[c>>2]=KF(0,t[h>>2]|0)|0;t[(t[u>>2]|0)+40>>2]=t[c>>2]}if(!(t[c>>2]|0)){gR(0,85552);t[f>>2]=0;w=t[f>>2]|0;s=n;return w|0}}t[c>>2]=t[(t[u>>2]|0)+40>>2];t[b>>2]=zg(t[a>>2]|0,k)|0;if(t[b>>2]|0)t[a>>2]=t[b>>2];t[l>>2]=fO(t[c>>2]|0,t[a>>2]|0,t[k>>2]|0)|0;do if((t[l>>2]|0)==0&(t[o>>2]|0)!=0){t[l>>2]=gAi[t[135744>>2]&511](56)|0;if(t[l>>2]|0){u=(t[l>>2]|0)+0|0;h=u+56|0;do{t[u>>2]=0;u=u+4|0}while((u|0)<(h|0));t[(t[l>>2]|0)+4>>2]=15;u=Yl(t[a>>2]|0)|0;t[(t[l>>2]|0)+8>>2]=u;u=Yl(t[k>>2]|0)|0;t[(t[l>>2]|0)+48>>2]=u;t[(t[l>>2]|0)+36>>2]=0;QF(t[c>>2]|0,t[a>>2]|0,t[k>>2]|0,t[l>>2]|0)|0;break}gR(0,79472);t[f>>2]=0;w=t[f>>2]|0;s=n;return w|0}while(0);if(t[k>>2]|0)pAi[t[135736>>2]&511](t[k>>2]|0);if(t[b>>2]|0)pAi[t[135736>>2]&511](t[b>>2]|0);t[f>>2]=t[l>>2];w=t[f>>2]|0;s=n;return w|0}function LR(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0;n=s;s=s+32|0;f=n+20|0;u=n+16|0;a=n+12|0;o=n+8|0;c=n+4|0;l=n;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;t[l>>2]=0;if(!(t[a>>2]|0)){t[f>>2]=0;b=t[f>>2]|0;s=n;return b|0}t[c>>2]=t[(t[a>>2]|0)+44>>2];while(1){if(!(t[c>>2]|0))break;if((t[(t[c>>2]|0)+40>>2]|0)==2?(t[l>>2]=(t[l>>2]|0)+1,(t[l>>2]|0)>1&(t[o>>2]|0)!=0):0)ER(t[u>>2]|0,t[a>>2]|0,520,85584,t[(t[a>>2]|0)+8>>2]|0,t[(t[c>>2]|0)+8>>2]|0,0);t[c>>2]=t[(t[c>>2]|0)+36>>2]}t[f>>2]=t[l>>2];b=t[f>>2]|0;s=n;return b|0}function DR(e){e=e|0;var i=0,r=0,n=0,f=0,u=0,a=0;i=s;s=s+16|0;r=i+8|0;n=i+4|0;f=i;t[n>>2]=e;t[f>>2]=gAi[t[135744>>2]&511](64)|0;if(!(t[f>>2]|0)){gR(0,79472);t[r>>2]=0;u=t[r>>2]|0;s=i;return u|0}e=(t[f>>2]|0)+0|0;a=e+64|0;do{t[e>>2]=0;e=e+4|0}while((e|0)<(a|0));t[(t[f>>2]|0)+4>>2]=16;t[(t[f>>2]|0)+40>>2]=t[(t[n>>2]|0)+40>>2];t[(t[f>>2]|0)+44>>2]=t[(t[n>>2]|0)+44>>2];e=TM(t[(t[n>>2]|0)+52>>2]|0)|0;t[(t[f>>2]|0)+52>>2]=e;if(t[(t[n>>2]|0)+60>>2]|0){e=Yl(t[(t[n>>2]|0)+60>>2]|0)|0;t[(t[f>>2]|0)+60>>2]=e}if(t[(t[n>>2]|0)+8>>2]|0){e=Yl(t[(t[n>>2]|0)+8>>2]|0)|0;t[(t[f>>2]|0)+8>>2]=e}if(t[(t[n>>2]|0)+56>>2]|0){e=Yl(t[(t[n>>2]|0)+56>>2]|0)|0;t[(t[f>>2]|0)+56>>2]=e}if(t[(t[n>>2]|0)+48>>2]|0){e=Yl(t[(t[n>>2]|0)+48>>2]|0)|0;t[(t[f>>2]|0)+48>>2]=e}t[r>>2]=t[f>>2];u=t[r>>2]|0;s=i;return u|0}function CR(e,i){e=e|0;i=i|0;var r=0,n=0,f=0;r=s;s=s+16|0;n=r+4|0;f=r;t[n>>2]=e;t[f>>2]=i;if((t[n>>2]|0)==0|(t[f>>2]|0)==0){s=r;return}RF(t[n>>2]|0,t[(t[f>>2]|0)+4>>2]|0);i=t[n>>2]|0;if(!(t[t[f>>2]>>2]|0)){NF(i,79672);s=r;return}else{NF(i,79664);CR(t[n>>2]|0,t[t[f>>2]>>2]|0);s=r;return}}function PR(e){e=e|0;var i=0,r=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if(!(t[r>>2]|0)){s=i;return}if(t[t[r>>2]>>2]|0)pAi[t[135736>>2]&511](t[t[r>>2]>>2]|0);if(t[(t[r>>2]|0)+4>>2]|0)pAi[t[135736>>2]&511](t[(t[r>>2]|0)+4>>2]|0);
	if(t[(t[r>>2]|0)+8>>2]|0)pAi[t[135736>>2]&511](t[(t[r>>2]|0)+8>>2]|0);pAi[t[135736>>2]&511](t[r>>2]|0);s=i;return}function BR(e){e=e|0;var i=0,r=0,n=0,f=0,u=0;i=s;s=s+16|0;r=i+8|0;n=i+4|0;f=i;t[n>>2]=e;t[f>>2]=gAi[t[135744>>2]&511](12)|0;if(!(t[f>>2]|0)){gR(0,79472);t[r>>2]=0;u=t[r>>2]|0;s=i;return u|0}if(t[t[n>>2]>>2]|0){e=Yl(t[t[n>>2]>>2]|0)|0;t[t[f>>2]>>2]=e}else t[t[f>>2]>>2]=0;if(t[(t[n>>2]|0)+4>>2]|0){e=Yl(t[(t[n>>2]|0)+4>>2]|0)|0;t[(t[f>>2]|0)+4>>2]=e}else t[(t[f>>2]|0)+4>>2]=0;if(t[(t[n>>2]|0)+8>>2]|0){e=Yl(t[(t[n>>2]|0)+8>>2]|0)|0;t[(t[f>>2]|0)+8>>2]=e}else t[(t[f>>2]|0)+8>>2]=0;t[r>>2]=t[f>>2];u=t[r>>2]|0;s=i;return u|0}function IR(e,i){e=e|0;i=i|0;var r=0,n=0,f=0;r=s;s=s+16|0;n=r+4|0;f=r;t[n>>2]=e;t[f>>2]=i;xM(t[f>>2]|0,t[n>>2]|0);s=r;return}function HR(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i+4|0;n=i;t[r>>2]=e;t[n>>2]=0;if(!(t[r>>2]|0)){s=i;return}if(t[(t[r>>2]|0)+20>>2]|0)t[n>>2]=t[(t[(t[r>>2]|0)+20>>2]|0)+80>>2];do if((t[(t[r>>2]|0)+4>>2]|0)!=0?(t[(t[r>>2]|0)+4>>2]|0)!=0:0){if((t[n>>2]|0)!=0?(wz(t[n>>2]|0,t[(t[r>>2]|0)+4>>2]|0)|0)!=0:0)break;pAi[t[135736>>2]&511](t[(t[r>>2]|0)+4>>2]|0)}while(0);do if((t[(t[r>>2]|0)+12>>2]|0)!=0?(t[(t[r>>2]|0)+12>>2]|0)!=0:0){if((t[n>>2]|0)!=0?(wz(t[n>>2]|0,t[(t[r>>2]|0)+12>>2]|0)|0)!=0:0)break;pAi[t[135736>>2]&511](t[(t[r>>2]|0)+12>>2]|0)}while(0);pAi[t[135736>>2]&511](t[r>>2]|0);s=i;return}function xR(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i+4|0;n=i;t[r>>2]=e;t[n>>2]=Aq(t[r>>2]|0)|0;if(!(t[n>>2]|0)){s=i;return}if(t[(t[n>>2]|0)+4>>2]|0)pAi[t[135736>>2]&511](t[(t[n>>2]|0)+4>>2]|0);if(t[(t[n>>2]|0)+12>>2]|0)pAi[t[135736>>2]&511](t[(t[n>>2]|0)+12>>2]|0);pAi[t[135736>>2]&511](t[n>>2]|0);s=i;return}function UR(e,i){e=e|0;i=i|0;var r=0;r=s;s=s+16|0;t[r+4>>2]=e;t[r>>2]=i;s=r;return 0}function zR(e){e=e|0;var i=0,r=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if(!(t[r>>2]|0)){s=i;return}Fq(t[r>>2]|0);s=i;return}function jR(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0;r=s;s=s+32|0;n=r+20|0;f=r+16|0;u=r+12|0;a=r+8|0;o=r+4|0;c=r;t[f>>2]=e;t[u>>2]=i;if(!(t[u>>2]|0)){t[n>>2]=0;l=t[n>>2]|0;s=r;return l|0}t[a>>2]=t[u>>2];t[o>>2]=Mp(0,t[a>>2]|0,c)|0;t[a>>2]=(t[a>>2]|0)+(t[c>>2]|0);if(!(tN(t[f>>2]|0,t[o>>2]|0)|0)){t[n>>2]=0;l=t[n>>2]|0;s=r;return l|0}t[o>>2]=Mp(0,t[a>>2]|0,c)|0;t[a>>2]=(t[a>>2]|0)+(t[c>>2]|0);while(1){if(!(uN(t[f>>2]|0,t[o>>2]|0)|0))break;t[o>>2]=Mp(0,t[a>>2]|0,c)|0;t[a>>2]=(t[a>>2]|0)+(t[c>>2]|0)}if(t[o>>2]|0){t[n>>2]=0;l=t[n>>2]|0;s=r;return l|0}else{t[n>>2]=1;l=t[n>>2]|0;s=r;return l|0}return 0}function VR(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0;r=s;s=s+32|0;n=r+20|0;f=r+16|0;u=r+12|0;a=r+8|0;o=r+4|0;c=r;t[f>>2]=e;t[u>>2]=i;if(!(t[u>>2]|0)){t[n>>2]=0;l=t[n>>2]|0;s=r;return l|0}t[a>>2]=t[u>>2];t[o>>2]=Mp(0,t[a>>2]|0,c)|0;t[a>>2]=(t[a>>2]|0)+(t[c>>2]|0);if(!(tN(t[f>>2]|0,t[o>>2]|0)|0)){t[n>>2]=0;l=t[n>>2]|0;s=r;return l|0}t[o>>2]=Mp(0,t[a>>2]|0,c)|0;t[a>>2]=(t[a>>2]|0)+(t[c>>2]|0);while(1){if(!(uN(t[f>>2]|0,t[o>>2]|0)|0))break;t[o>>2]=Mp(0,t[a>>2]|0,c)|0;t[a>>2]=(t[a>>2]|0)+(t[c>>2]|0)}e:while(1){if((t[o>>2]|0)!=32)break;while(1){if((t[o>>2]|0)!=32)break;t[o>>2]=Mp(0,t[a>>2]|0,c)|0;t[a>>2]=(t[a>>2]|0)+(t[c>>2]|0)}if(!(tN(t[f>>2]|0,t[o>>2]|0)|0)){b=12;break}t[o>>2]=Mp(0,t[a>>2]|0,c)|0;t[a>>2]=(t[a>>2]|0)+(t[c>>2]|0);while(1){if(!(uN(t[f>>2]|0,t[o>>2]|0)|0))continue e;t[o>>2]=Mp(0,t[a>>2]|0,c)|0;t[a>>2]=(t[a>>2]|0)+(t[c>>2]|0)}}if((b|0)==12){t[n>>2]=0;l=t[n>>2]|0;s=r;return l|0}if(t[o>>2]|0){t[n>>2]=0;l=t[n>>2]|0;s=r;return l|0}else{t[n>>2]=1;l=t[n>>2]|0;s=r;return l|0}return 0}function qR(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0;r=s;s=s+32|0;n=r+20|0;f=r+16|0;u=r+12|0;a=r+8|0;o=r+4|0;c=r;t[f>>2]=e;t[u>>2]=i;if(!(t[u>>2]|0)){t[n>>2]=0;l=t[n>>2]|0;s=r;return l|0}t[a>>2]=t[u>>2];t[o>>2]=Mp(0,t[a>>2]|0,c)|0;t[a>>2]=(t[a>>2]|0)+(t[c>>2]|0);if(!(uN(t[f>>2]|0,t[o>>2]|0)|0)){t[n>>2]=0;l=t[n>>2]|0;s=r;return l|0}t[o>>2]=Mp(0,t[a>>2]|0,c)|0;t[a>>2]=(t[a>>2]|0)+(t[c>>2]|0);while(1){if(!(uN(t[f>>2]|0,t[o>>2]|0)|0))break;t[o>>2]=Mp(0,t[a>>2]|0,c)|0;t[a>>2]=(t[a>>2]|0)+(t[c>>2]|0)}if(t[o>>2]|0){t[n>>2]=0;l=t[n>>2]|0;s=r;return l|0}else{t[n>>2]=1;l=t[n>>2]|0;s=r;return l|0}return 0}function YR(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0;r=s;s=s+32|0;n=r+20|0;f=r+16|0;u=r+12|0;a=r+8|0;o=r+4|0;c=r;t[f>>2]=e;t[u>>2]=i;if(!(t[u>>2]|0)){t[n>>2]=0;l=t[n>>2]|0;s=r;return l|0}t[a>>2]=t[u>>2];t[o>>2]=Mp(0,t[a>>2]|0,c)|0;t[a>>2]=(t[a>>2]|0)+(t[c>>2]|0);while(1){if((t[o>>2]|0)<256){if((t[o>>2]|0)!=32?!(9<=(t[o>>2]|0)&(t[o>>2]|0)<=10):0)b=(t[o>>2]|0)==13;else b=1;k=b&1}else k=0;if(!k)break;t[o>>2]=Mp(0,t[a>>2]|0,c)|0;t[a>>2]=(t[a>>2]|0)+(t[c>>2]|0)}if(!(uN(t[f>>2]|0,t[o>>2]|0)|0)){t[n>>2]=0;l=t[n>>2]|0;s=r;return l|0}while(1){if(!(uN(t[f>>2]|0,t[o>>2]|0)|0))break;t[o>>2]=Mp(0,t[a>>2]|0,c)|0;t[a>>2]=(t[a>>2]|0)+(t[c>>2]|0)}e:while(1){if((t[o>>2]|0)!=32){h=25;break}while(1){if((t[o>>2]|0)!=32)break;t[o>>2]=Mp(0,t[a>>2]|0,c)|0;t[a>>2]=(t[a>>2]|0)+(t[c>>2]|0)}if(!(t[o>>2]|0)){h=19;break}if(!(uN(t[f>>2]|0,t[o>>2]|0)|0)){h=21;break}t[o>>2]=Mp(0,t[a>>2]|0,c)|0;t[a>>2]=(t[a>>2]|0)+(t[c>>2]|0);while(1){if(!(uN(t[f>>2]|0,t[o>>2]|0)|0))continue e;t[o>>2]=Mp(0,t[a>>2]|0,c)|0;t[a>>2]=(t[a>>2]|0)+(t[c>>2]|0)}}if((h|0)==19){t[n>>2]=1;l=t[n>>2]|0;s=r;return l|0}else if((h|0)==21){t[n>>2]=0;l=t[n>>2]|0;s=r;return l|0}else if((h|0)==25)if(t[o>>2]|0){t[n>>2]=0;l=t[n>>2]|0;s=r;return l|0}else{t[n>>2]=1;l=t[n>>2]|0;s=r;return l|0}return 0}function GR(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0;n=s;s=s+16|0;f=n+8|0;u=n+4|0;t[f>>2]=e;t[u>>2]=i;t[n>>2]=r;if((t[(t[f>>2]|0)+40>>2]|0)!=2){s=n;return}f=t[u>>2]|0;t[f>>2]=(t[f>>2]|0)+1;s=n;return}function WR(e,i,r,n,f,u,a){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;u=u|0;a=a|0;var o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0,S=0;o=s;s=s+64|0;c=o;l=o+56|0;b=o+52|0;k=o+48|0;h=o+44|0;w=o+40|0;d=o+36|0;v=o+32|0;m=o+28|0;_=o+24|0;p=o+20|0;E=o+16|0;S=o+12|0;t[l>>2]=e;t[b>>2]=i;t[k>>2]=r;t[h>>2]=n;t[w>>2]=f;t[d>>2]=u;t[v>>2]=a;t[m>>2]=0;t[_>>2]=0;t[p>>2]=0;t[E>>2]=0;do if(t[l>>2]|0){t[_>>2]=t[(t[l>>2]|0)+4>>2];t[E>>2]=t[t[l>>2]>>2];if((t[(t[l>>2]|0)+28>>2]|0)!=-1412623820?(t[(t[l>>2]|0)+28>>2]|0)!=-1412623819:0)break;t[S>>2]=(t[l>>2]|0)-(t[t[l>>2]>>2]|0);if((t[S>>2]|0)>0&(t[S>>2]|0)<250)t[p>>2]=t[t[l>>2]>>2]}while(0);l=t[m>>2]|0;m=t[_>>2]|0;_=t[E>>2]|0;E=t[p>>2]|0;p=t[b>>2]|0;b=t[k>>2]|0;k=t[w>>2]|0;S=t[v>>2]|0;a=t[d>>2]|0;u=t[h>>2]|0;h=t[d>>2]|0;d=t[v>>2]|0;t[c>>2]=t[w>>2];t[c+4>>2]=h;t[c+8>>2]=d;cp(l,m,_,E,p,23,b,2,0,0,k,S,0,a,0,u,c);s=o;return}function KR(e,i,r,f,a){e=e|0;i=i|0;r=r|0;f=f|0;a=a|0;var o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0,S=0,g=0,y=0,F=0,O=0,A=0;o=s;s=s+64|0;c=o+48|0;l=o+44|0;b=o+40|0;k=o+36|0;h=o+32|0;w=o+28|0;d=o+24|0;v=o+20|0;m=o+16|0;_=o+12|0;p=o+8|0;E=o+52|0;S=o+4|0;g=o;t[l>>2]=e;t[b>>2]=i;t[k>>2]=r;t[h>>2]=f;t[w>>2]=a;t[d>>2]=1;a=t[h>>2]|0;do if((a|0)==5){t[v>>2]=h_(t[b>>2]|0,t[w>>2]|0)|0;if((t[v>>2]|0)==0?(t[(t[b>>2]|0)+40>>2]|0)==1:0){t[(t[b>>2]|0)+40>>2]=0;t[v>>2]=h_(t[b>>2]|0,t[w>>2]|0)|0}if(!(t[v>>2]|0)){ER(t[l>>2]|0,t[b>>2]|0,535,85248,t[k>>2]|0,t[w>>2]|0,0);t[d>>2]=0;break}if((t[(t[v>>2]|0)+48>>2]|0)!=3){ER(t[l>>2]|0,t[b>>2]|0,511,85304,t[k>>2]|0,t[w>>2]|0,0);t[d>>2]=0}}else if((a|0)==10){t[g>>2]=$M(t[(t[b>>2]|0)+44>>2]|0,t[w>>2]|0)|0;if((t[g>>2]|0)==0?(t[(t[b>>2]|0)+48>>2]|0)!=0:0)t[g>>2]=$M(t[(t[b>>2]|0)+48>>2]|0,t[w>>2]|0)|0;if(!(t[g>>2]|0)){ER(t[l>>2]|0,t[b>>2]|0,537,85488,t[k>>2]|0,t[w>>2]|0,0);t[d>>2]=0}}else if((a|0)==6){t[_>>2]=0;t[m>>2]=Yl(t[w>>2]|0)|0;if(!(t[m>>2]|0)){t[c>>2]=0;y=t[c>>2]|0;s=o;return y|0}t[p>>2]=t[m>>2];e:while(1){if(!(u[t[p>>2]>>0]|0))break;t[_>>2]=t[p>>2];while(1){if(u[t[p>>2]>>0]|0){do if((u[t[p>>2]>>0]|0|0)==32)F=1;else{if(9<=(u[t[p>>2]>>0]|0|0)?(u[t[p>>2]>>0]|0|0)<=10:0){F=1;break}F=(u[t[p>>2]>>0]|0|0)==13}while(0);O=F^1}else O=0;A=t[p>>2]|0;if(!O)break;t[p>>2]=A+1}n[E>>0]=n[A>>0]|0;n[t[p>>2]>>0]=0;t[S>>2]=h_(t[b>>2]|0,t[_>>2]|0)|0;if(t[S>>2]|0){if((t[(t[S>>2]|0)+48>>2]|0)!=3){ER(t[l>>2]|0,t[b>>2]|0,511,85424,t[k>>2]|0,t[_>>2]|0,0);t[d>>2]=0}}else{ER(t[l>>2]|0,t[b>>2]|0,535,85368,t[k>>2]|0,t[_>>2]|0,0);t[d>>2]=0}if(!(u[E>>0]|0))break;n[t[p>>2]>>0]=n[E>>0]|0;while(1){do if((u[t[p>>2]>>0]|0|0)!=32){if(9<=(u[t[p>>2]>>0]|0|0)?(u[t[p>>2]>>0]|0|0)<=10:0)break;if((u[t[p>>2]>>0]|0|0)!=13)continue e}while(0);t[p>>2]=(t[p>>2]|0)+1}}pAi[t[135736>>2]&511](t[m>>2]|0)}while(0);t[c>>2]=t[d>>2];y=t[c>>2]|0;s=o;return y|0}function XR(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0;n=s;s=s+32|0;f=n+20|0;u=n+16|0;a=n+12|0;o=n+8|0;c=n+4|0;l=n;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;t[c>>2]=jg(t[o>>2]|0,l)|0;e:do if(!(t[c>>2]|0)){i:while(1){if(!(t[a>>2]|0))break e;r=t[a>>2]|0;do if((t[t[a>>2]>>2]|0)==2){if((t[r+24>>2]|0)==0?(Xl(t[(t[a>>2]|0)+8>>2]|0,t[o>>2]|0)|0)!=0:0){b=6;break i}}else{if(((t[r>>2]|0)==4?(t[(t[a>>2]|0)+12>>2]|0)!=0:0)?(t[t[(t[a>>2]|0)+12>>2]>>2]|0)==2:0){if(t[(t[(t[a>>2]|0)+12>>2]|0)+24>>2]|0)break;if(Xl(t[(t[(t[a>>2]|0)+12>>2]|0)+8>>2]|0,t[o>>2]|0)|0){b=12;break i}else break}if((t[t[a>>2]>>2]|0)!=4){b=16;break i}if(!(t[(t[a>>2]|0)+12>>2]|0)){b=16;break i}if((t[t[(t[a>>2]|0)+12>>2]>>2]|0)!=1){b=16;break i}}while(0);t[a>>2]=t[(t[a>>2]|0)+16>>2]}if((b|0)==6){t[f>>2]=1;k=t[f>>2]|0;s=n;return k|0}else if((b|0)==12){t[f>>2]=1;k=t[f>>2]|0;s=n;return k|0}else if((b|0)==16){yR(0,519,83864,0);break}}else{i:while(1){if(!(t[a>>2]|0))break e;r=t[a>>2]|0;do if((t[t[a>>2]>>2]|0)==2){if(((t[r+24>>2]|0)!=0?(Jl(t[(t[a>>2]|0)+24>>2]|0,t[o>>2]|0,t[l>>2]|0)|0)==0:0)?(Xl(t[(t[a>>2]|0)+8>>2]|0,t[c>>2]|0)|0)!=0:0){b=23;break i}}else{if(((t[r>>2]|0)==4?(t[(t[a>>2]|0)+12>>2]|0)!=0:0)?(t[t[(t[a>>2]|0)+12>>2]>>2]|0)==2:0){if(!(t[(t[(t[a>>2]|0)+12>>2]|0)+24>>2]|0))break;if(Jl(t[(t[(t[a>>2]|0)+12>>2]|0)+24>>2]|0,t[o>>2]|0,t[l>>2]|0)|0)break;if(Xl(t[(t[(t[a>>2]|0)+12>>2]|0)+8>>2]|0,t[c>>2]|0)|0){b=30;break i}else break}if((t[t[a>>2]>>2]|0)!=4){b=34;break i}if(!(t[(t[a>>2]|0)+12>>2]|0)){b=34;break i}if((t[t[(t[a>>2]|0)+12>>2]>>2]|0)!=1){b=34;break i}}while(0);t[a>>2]=t[(t[a>>2]|0)+16>>2]}if((b|0)==23){t[f>>2]=1;k=t[f>>2]|0;s=n;return k|0}else if((b|0)==30){t[f>>2]=1;k=t[f>>2]|0;s=n;return k|0}else if((b|0)==34){yR(t[u>>2]|0,519,83864,0);break}}while(0);t[f>>2]=0;k=t[f>>2]|0;s=n;return k|0}function ZR(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0;f=s;s=s+32|0;u=f+24|0;a=f+20|0;o=f+16|0;c=f+12|0;l=f+8|0;b=f+4|0;k=f;t[a>>2]=e;t[o>>2]=i;t[c>>2]=r;t[l>>2]=n;t[b>>2]=0;t[k>>2]=0;if(!((t[a>>2]|0)==0|(t[o>>2]|0)==0|(t[c>>2]|0)==0)?(t[(t[c>>2]|0)+8>>2]|0)!=0:0){if(t[l>>2]|0)t[t[l>>2]>>2]=0;if((t[(t[c>>2]|0)+36>>2]|0)!=0?(t[(t[(t[c>>2]|0)+36>>2]|0)+12>>2]|0)!=0:0)t[k>>2]=t[(t[(t[c>>2]|0)+36>>2]|0)+12>>2];if((((t[k>>2]|0)!=0?(t[b>>2]=JM(t[(t[o>>2]|0)+44>>2]|0,t[(t[c>>2]|0)+8>>2]|0,t[k>>2]|0)|0,(t[b>>2]|0)==0):0)?(t[(t[o>>2]|0)+48>>2]|0)!=0:0)?(t[b>>2]=JM(t[(t[o>>2]|0)+48>>2]|0,t[(t[c>>2]|0)+8>>2]|0,t[k>>2]|0)|0,(t[b>>2]|0)!=0&(t[l>>2]|0)!=0):0)t[t[l>>2]>>2]=1;if((((t[b>>2]|0)==0?(t[b>>2]=ZM(t[(t[o>>2]|0)+44>>2]|0,t[(t[c>>2]|0)+8>>2]|0)|0,(t[b>>2]|0)==0):0)?(t[(t[o>>2]|0)+48>>2]|0)!=0:0)?(t[b>>2]=ZM(t[(t[o>>2]|0)+48>>2]|0,t[(t[c>>2]|0)+8>>2]|0)|0,(t[b>>2]|0)!=0&(t[l>>2]|0)!=0):0)t[t[l>>2]>>2]=1;if(!(t[b>>2]|0))ER(t[a>>2]|0,t[c>>2]|0,534,83832,t[(t[c>>2]|0)+8>>2]|0,0,0);t[u>>2]=t[b>>2];h=t[u>>2]|0;s=f;return h|0}t[u>>2]=0;h=t[u>>2]|0;s=f;return h|0}function JR(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0;n=s;s=s+32|0;f=n+16|0;u=n+12|0;a=n+8|0;o=n+4|0;c=n;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;if(!((t[(t[u>>2]|0)+48>>2]|0)!=0?(t[(t[u>>2]|0)+52>>2]|0)!=0:0))l=3;if((l|0)==3?(t[(t[u>>2]|0)+48>>2]=10,l=gAi[t[135744>>2]&511]((t[(t[u>>2]|0)+48>>2]|0)*12|0)|0,t[(t[u>>2]|0)+52>>2]=l,(t[(t[u>>2]|0)+52>>2]|0)==0):0){gR(t[u>>2]|0,79472);t[f>>2]=-1;b=t[f>>2]|0;s=n;return b|0}do if((t[(t[u>>2]|0)+44>>2]|0)>=(t[(t[u>>2]|0)+48>>2]|0)){t[c>>2]=MAi[t[135760>>2]&511](t[(t[u>>2]|0)+52>>2]|0,(t[(t[u>>2]|0)+48>>2]<<1)*12|0)|0;l=t[u>>2]|0;if(t[c>>2]|0){r=l+48|0;t[r>>2]=t[r>>2]<<1;t[(t[u>>2]|0)+52>>2]=t[c>>2];break}gR(l,85184);t[f>>2]=-1;b=t[f>>2]|0;s=n;return b|0}while(0);t[(t[u>>2]|0)+40>>2]=(t[(t[u>>2]|0)+52>>2]|0)+((t[(t[u>>2]|0)+44>>2]|0)*12|0);t[(t[(t[u>>2]|0)+52>>2]|0)+((t[(t[u>>2]|0)+44>>2]|0)*12|0)>>2]=t[a>>2];t[(t[(t[u>>2]|0)+52>>2]|0)+((t[(t[u>>2]|0)+44>>2]|0)*12|0)+4>>2]=t[o>>2];do if((t[a>>2]|0)!=0?(t[(t[a>>2]|0)+36>>2]|0)==4:0){if(!(t[(t[a>>2]|0)+52>>2]|0))vM(t[u>>2]|0,t[a>>2]|0)|0;if(t[(t[a>>2]|0)+52>>2]|0){c=Ws(t[(t[a>>2]|0)+52>>2]|0,0,0)|0;t[(t[(t[u>>2]|0)+52>>2]|0)+((t[(t[u>>2]|0)+44>>2]|0)*12|0)+8>>2]=c;break}else{t[(t[(t[u>>2]|0)+52>>2]|0)+((t[(t[u>>2]|0)+44>>2]|0)*12|0)+8>>2]=0;ER(t[u>>2]|0,t[a>>2]|0,1,85200,t[(t[o>>2]|0)+8>>2]|0,0,0);break}}while(0);o=(t[u>>2]|0)+44|0;u=t[o>>2]|0;t[o>>2]=u+1;t[f>>2]=u;b=t[f>>2]|0;s=n;return b|0}function QR(e){e=e|0;var i=0,r=0,n=0,f=0,u=0;i=s;s=s+16|0;r=i+8|0;n=i+4|0;f=i;t[n>>2]=e;if((t[(t[n>>2]|0)+44>>2]|0)<1){t[r>>2]=-1;u=t[r>>2]|0;s=i;return u|0}e=(t[n>>2]|0)+44|0;t[e>>2]=(t[e>>2]|0)+-1;t[f>>2]=t[(t[(t[n>>2]|0)+52>>2]|0)+((t[(t[n>>2]|0)+44>>2]|0)*12|0)>>2];t[(t[(t[n>>2]|0)+52>>2]|0)+((t[(t[n>>2]|0)+44>>2]|0)*12|0)>>2]=0;t[(t[(t[n>>2]|0)+52>>2]|0)+((t[(t[n>>2]|0)+44>>2]|0)*12|0)+4>>2]=0;if((t[f>>2]|0)!=0?(t[(t[f>>2]|0)+36>>2]|0)==4:0)Ks(t[(t[(t[n>>2]|0)+52>>2]|0)+((t[(t[n>>2]|0)+44>>2]|0)*12|0)+8>>2]|0);t[(t[(t[n>>2]|0)+52>>2]|0)+((t[(t[n>>2]|0)+44>>2]|0)*12|0)+8>>2]=0;f=t[n>>2]|0;if((t[(t[n>>2]|0)+44>>2]|0)>=1)t[(t[n>>2]|0)+40>>2]=(t[(t[n>>2]|0)+52>>2]|0)+(((t[f+44>>2]|0)-1|0)*12|0);else t[f+40>>2]=0;t[r>>2]=t[(t[n>>2]|0)+44>>2];u=t[r>>2]|0;s=i;return u|0}function $R(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0;n=s;s=s+32|0;f=n+24|0;u=n+20|0;a=n+16|0;o=n+12|0;c=n+8|0;l=n+4|0;b=n;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;t[c>>2]=1;if(!((t[u>>2]|0)==0|(t[a>>2]|0)==0|(t[o>>2]|0)==0)?(t[(t[o>>2]|0)+4>>2]|0)==1:0){t[b>>2]=t[(t[o>>2]|0)+12>>2];t[l>>2]=t[b>>2];e:while(1){if(!(t[l>>2]|0))break;switch(t[(t[l>>2]|0)+4>>2]|0){case 4:case 3:case 7:case 8:break;case 5:{if((t[(t[l>>2]|0)+12>>2]|0)!=0?(t[(t[(t[l>>2]|0)+12>>2]|0)+12>>2]|0)!=0:0){aN(t[u>>2]|0,t[l>>2]|0)|0;t[l>>2]=t[(t[(t[l>>2]|0)+12>>2]|0)+12>>2];continue e}break}default:{k=10;break e}}t[l>>2]=t[(t[l>>2]|0)+24>>2];while(1){if(t[l>>2]|0)continue e;t[l>>2]=oN(t[u>>2]|0)|0;if(!(t[l>>2]|0))continue e;t[l>>2]=t[(t[l>>2]|0)+24>>2]}}if((k|0)==10)t[c>>2]=0;t[(t[u>>2]|0)+20>>2]=0;t[(t[u>>2]|0)+16>>2]=0;if(t[(t[u>>2]|0)+24>>2]|0){pAi[t[135736>>2]&511](t[(t[u>>2]|0)+24>>2]|0);t[(t[u>>2]|0)+24>>2]=0}t[f>>2]=t[c>>2];h=t[f>>2]|0;s=n;return h|0}t[f>>2]=0;h=t[f>>2]|0;s=n;return h|0}function eN(e,i,r,f,u){e=e|0;i=i|0;r=r|0;f=f|0;u=u|0;var a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0,S=0,g=0,y=0,F=0;a=s;s=s+10112|0;o=a+44|0;c=a+40|0;l=a+36|0;b=a+32|0;k=a+28|0;h=a+24|0;w=a+20|0;d=a+16|0;v=a+12|0;m=a+8|0;_=a+4|0;p=a+10048|0;E=a;S=a+5048|0;g=a+48|0;t[c>>2]=e;t[l>>2]=i;t[b>>2]=r;t[k>>2]=f;t[h>>2]=u;t[w>>2]=1;if((t[b>>2]|0)==0|(t[h>>2]|0)==0|(t[c>>2]|0)==0){t[o>>2]=-1;y=t[o>>2]|0;s=a;return y|0}t[v>>2]=t[(t[b>>2]|0)+40>>2];t[m>>2]=t[(t[b>>2]|0)+8>>2];if(!(t[(t[b>>2]|0)+52>>2]|0))t[w>>2]=vM(t[c>>2]|0,t[b>>2]|0)|0;if(!(t[(t[b>>2]|0)+52>>2]|0)){t[o>>2]=-1;y=t[o>>2]|0;s=a;return y|0}if(!(ib(t[(t[b>>2]|0)+52>>2]|0)|0)){t[o>>2]=-1;y=t[o>>2]|0;s=a;return y|0}t[(t[c>>2]|0)+20>>2]=0;t[(t[c>>2]|0)+16>>2]=0;t[(t[c>>2]|0)+24>>2]=0;t[_>>2]=Ws(t[(t[b>>2]|0)+52>>2]|0,0,0)|0;if(t[_>>2]|0){t[d>>2]=t[l>>2];e:while(1){if(!(t[d>>2]|0)){F=31;break}b=t[(t[d>>2]|0)+4>>2]|0;do if((b|0)==3){if(!(EF(t[d>>2]|0)|0)){F=17;break e}}else if((b|0)==1){if((t[(t[d>>2]|0)+36>>2]|0)!=0?(t[(t[(t[d>>2]|0)+36>>2]|0)+12>>2]|0)!=0:0){t[E>>2]=Ug(t[(t[d>>2]|0)+8>>2]|0,t[(t[(t[d>>2]|0)+36>>2]|0)+12>>2]|0,p,50)|0;if(!(t[E>>2]|0)){F=22;break e}t[w>>2]=Xs(t[_>>2]|0,t[E>>2]|0,0)|0;if((t[E>>2]|0)==(p|0))break;if((t[E>>2]|0)==(t[(t[d>>2]|0)+8>>2]|0))break;pAi[t[135736>>2]&511](t[E>>2]|0);break}t[w>>2]=Xs(t[_>>2]|0,t[(t[d>>2]|0)+8>>2]|0,0)|0}else if((b|0)==4){F=18;break e}else if(((b|0)==5?(t[(t[d>>2]|0)+12>>2]|0)!=0:0)?(t[(t[(t[d>>2]|0)+12>>2]|0)+12>>2]|0)!=0:0){aN(t[c>>2]|0,t[d>>2]|0)|0;t[d>>2]=t[(t[(t[d>>2]|0)+12>>2]|0)+12>>2];continue e}while(0);t[d>>2]=t[(t[d>>2]|0)+24>>2];while(1){if(t[d>>2]|0)continue e;t[d>>2]=oN(t[c>>2]|0)|0;if(!(t[d>>2]|0))continue e;t[d>>2]=t[(t[d>>2]|0)+24>>2]}}if((F|0)==17)t[w>>2]=0;else if((F|0)==18)t[w>>2]=0;else if((F|0)==22)t[w>>2]=-1;else if((F|0)==31)t[w>>2]=Xs(t[_>>2]|0,0,0)|0;Ks(t[_>>2]|0)}if((t[k>>2]|0)!=0&(t[w>>2]|0)!=1&(t[w>>2]|0)!=-3){do if(t[c>>2]|0){n[S>>0]=0;mM(S,5e3,t[v>>2]|0,1);n[g>>0]=0;cN(g,5e3,t[l>>2]|0,1);k=t[c>>2]|0;_=t[h>>2]|0;if(t[m>>2]|0){ER(k,_,504,84936,t[m>>2]|0,S,g);break}else{ER(k,_,504,85008,S,g,0);break}}else{_=t[c>>2]|0;k=t[h>>2]|0;if(t[m>>2]|0){ER(_,k,504,85072,t[m>>2]|0,0,0);break}else{ER(_,k,504,85120,0,0,0);break}}while(0);t[w>>2]=0}if((t[w>>2]|0)==-3)t[w>>2]=1;t[(t[c>>2]|0)+20>>2]=0;t[(t[c>>2]|0)+16>>2]=0;if(t[(t[c>>2]|0)+24>>2]|0){pAi[t[135736>>2]&511](t[(t[c>>2]|0)+24>>2]|0);t[(t[c>>2]|0)+24>>2]=0}t[o>>2]=t[w>>2];y=t[o>>2]|0;s=a;return y|0}function iN(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0;n=s;s=s+32|0;f=n+16|0;u=n+12|0;a=n+8|0;o=n;t[f>>2]=e;t[u>>2]=i;t[a>>2]=r;if(!(t[f>>2]|0)){s=n;return}t[o>>2]=t[u>>2];t[o+4>>2]=t[a>>2];Mq(t[f>>2]|0,258,o);s=n;return}function rN(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,l=0;n=s;s=s+32|0;f=n+24|0;u=n+20|0;a=n+12|0;o=n+8|0;c=n+4|0;l=n;t[f>>2]=e;t[u>>2]=i;t[n+16>>2]=r;t[c>>2]=0;if(!(t[f>>2]|0)){s=n;return}r=t[(t[f>>2]|0)+40>>2]|0;e:do if((r|0)==5|(r|0)==6|(r|0)==10){if(((t[(t[f>>2]|0)+48>>2]|0)!=0?(t[a>>2]=KR(t[u>>2]|0,t[(t[u>>2]|0)+32>>2]|0,t[(t[f>>2]|0)+8>>2]|0,t[(t[f>>2]|0)+40>>2]|0,t[(t[f>>2]|0)+48>>2]|0)|0,(t[a>>2]|0)==0):0)?(t[(t[u>>2]|0)+36>>2]|0)==1:0)t[(t[u>>2]|0)+36>>2]=0;if(t[(t[f>>2]|0)+52>>2]|0){t[l>>2]=t[(t[f>>2]|0)+52>>2];while(1){if(!(t[l>>2]|0))break e;t[a>>2]=KR(t[u>>2]|0,t[(t[u>>2]|0)+32>>2]|0,t[(t[f>>2]|0)+8>>2]|0,t[(t[f>>2]|0)+40>>2]|0,t[(t[l>>2]|0)+4>>2]|0)|0;if((t[a>>2]|0)==0?(t[(t[u>>2]|0)+36>>2]|0)==1:0)t[(t[u>>2]|0)+36>>2]=0;t[l>>2]=t[t[l>>2]>>2]}}}while(0);if((t[(t[f>>2]|0)+40>>2]|0)!=10){s=n;return}t[o>>2]=t[(t[f>>2]|0)+32>>2];if(!(t[(t[f>>2]|0)+60>>2]|0)){yR(t[u>>2]|0,1,84584,t[(t[f>>2]|0)+8>>2]|0);s=n;return}if(t[o>>2]|0)t[c>>2]=ZM(t[(t[o>>2]|0)+44>>2]|0,t[(t[f>>2]|0)+60>>2]|0)|0;if((t[c>>2]|0)==0&(t[o>>2]|0)!=0)t[c>>2]=ZM(t[(t[o>>2]|0)+48>>2]|0,t[(t[f>>2]|0)+60>>2]|0)|0;if(((t[c>>2]|0)==0?(t[(t[f>>2]|0)+20>>2]|0)!=0:0)?(t[(t[(t[f>>2]|0)+20>>2]|0)+4>>2]|0)==14:0)t[c>>2]=ZM(t[(t[f>>2]|0)+20>>2]|0,t[(t[f>>2]|0)+60>>2]|0)|0;if(!(t[c>>2]|0)){ER(t[u>>2]|0,0,534,84640,t[(t[f>>2]|0)+8>>2]|0,t[(t[f>>2]|0)+60>>2]|0,0);s=n;return}if((t[(t[c>>2]|0)+36>>2]|0)!=1){s=n;return}ER(t[u>>2]|0,0,510,84696,t[(t[f>>2]|0)+8>>2]|0,t[(t[f>>2]|0)+60>>2]|0,0);t[(t[u>>2]|0)+36>>2]=0;s=n;return}function nN(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0;n=s;s=s+32|0;f=n+16|0;u=n+12|0;a=n+4|0;o=n;t[f>>2]=e;t[u>>2]=i;t[n+8>>2]=r;if(!(t[f>>2]|0)){s=n;return}if((t[(t[f>>2]|0)+48>>2]|0)!=3){s=n;return}t[a>>2]=t[(t[f>>2]|0)+40>>2];if(!(t[a>>2]|0)){s=n;return}t[o>>2]=eR(t[u>>2]|0,t[(t[f>>2]|0)+32>>2]|0,t[a>>2]|0)|0;if((t[o>>2]|0)==1){s=n;return}t[(t[u>>2]|0)+36>>2]=0;s=n;return}function fN(e,i,r){e=e|0;i=i|0;r=r|0;r=s;s=s+16|0;t[r+4>>2]=e;t[r>>2]=i;s=r;return}function tN(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0;r=s;s=s+16|0;n=r+8|0;f=r+4|0;u=r;t[f>>2]=e;t[u>>2]=i;e:do if((t[f>>2]|0)!=0?(t[(t[f>>2]|0)+92>>2]&4|0)!=0:0){i=t[u>>2]|0;if((t[u>>2]|0)<256){if(((!(65<=(i|0)&(t[u>>2]|0)<=90)?!(97<=(t[u>>2]|0)&(t[u>>2]|0)<=122):0)?!(192<=(t[u>>2]|0)&(t[u>>2]|0)<=214):0)?!(216<=(t[u>>2]|0)&(t[u>>2]|0)<=246|248<=(t[u>>2]|0)):0)a=24}else if(!(dj(i,199744)|0))a=24;do if((a|0)==24){i=t[u>>2]|0;if((t[u>>2]|0)<256)if((i|0)==95|(t[u>>2]|0)==58)break;else break e;if(!(19968<=(i|0)&(t[u>>2]|0)<=40869|(t[u>>2]|0)==12295)?!(12321<=(t[u>>2]|0)&(t[u>>2]|0)<=12329|(t[u>>2]|0)==95|(t[u>>2]|0)==58):0)break e}while(0);t[n>>2]=1;o=t[n>>2]|0;s=r;return o|0}else a=3;while(0);do if((a|0)==3){if(((((((((((((!((t[u>>2]|0)>=97&(t[u>>2]|0)<=122)?!((t[u>>2]|0)>=65&(t[u>>2]|0)<=90|(t[u>>2]|0)==95|(t[u>>2]|0)==58):0)?!((t[u>>2]|0)>=192&(t[u>>2]|0)<=214):0)?!((t[u>>2]|0)>=216&(t[u>>2]|0)<=246):0)?!((t[u>>2]|0)>=248&(t[u>>2]|0)<=767):0)?!((t[u>>2]|0)>=880&(t[u>>2]|0)<=893):0)?!((t[u>>2]|0)>=895&(t[u>>2]|0)<=8191):0)?!((t[u>>2]|0)>=8204&(t[u>>2]|0)<=8205):0)?!((t[u>>2]|0)>=8304&(t[u>>2]|0)<=8591):0)?!((t[u>>2]|0)>=11264&(t[u>>2]|0)<=12271):0)?!((t[u>>2]|0)>=12289&(t[u>>2]|0)<=55295):0)?!((t[u>>2]|0)>=63744&(t[u>>2]|0)<=64975):0)?!((t[u>>2]|0)>=65008&(t[u>>2]|0)<=65533):0)?!((t[u>>2]|0)>=65536&(t[u>>2]|0)<=983039):0)break;t[n>>2]=1;o=t[n>>2]|0;s=r;return o|0}while(0);t[n>>2]=0;o=t[n>>2]|0;s=r;return o|0}function uN(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0;r=s;s=s+16|0;n=r+8|0;f=r+4|0;u=r;t[f>>2]=e;t[u>>2]=i;e:do if((t[f>>2]|0)!=0?(t[(t[f>>2]|0)+92>>2]&4|0)!=0:0){i=t[u>>2]|0;if((t[u>>2]|0)<256){if(((!(65<=(i|0)&(t[u>>2]|0)<=90)?!(97<=(t[u>>2]|0)&(t[u>>2]|0)<=122):0)?!(192<=(t[u>>2]|0)&(t[u>>2]|0)<=214):0)?!(216<=(t[u>>2]|0)&(t[u>>2]|0)<=246|248<=(t[u>>2]|0)):0)a=27}else if(!(dj(i,199744)|0))a=27;do if((a|0)==27){if((t[u>>2]|0)>=256){if(19968<=(t[u>>2]|0)&(t[u>>2]|0)<=40869|(t[u>>2]|0)==12295)break;if(12321<=(t[u>>2]|0)&(t[u>>2]|0)<=12329)break}i=t[u>>2]|0;if((t[u>>2]|0)<256){if(48<=(i|0)&(t[u>>2]|0)<=57|(t[u>>2]|0)==46|(t[u>>2]|0)==45|(t[u>>2]|0)==95|(t[u>>2]|0)==58)break}else{e=(dj(i,200216)|0)!=0;if(e|(t[u>>2]|0)==46|(t[u>>2]|0)==45|(t[u>>2]|0)==95|(t[u>>2]|0)==58)break}if((t[u>>2]|0)>=256?(dj(t[u>>2]|0,200144)|0)!=0:0)break;e=t[u>>2]|0;if((t[u>>2]|0)<256)if((e|0)==183)break;else break e;else if(dj(e,200272)|0)break;else break e}while(0);t[n>>2]=1;o=t[n>>2]|0;s=r;return o|0}else a=3;while(0);do if((a|0)==3){if((((((((((((((((!((t[u>>2]|0)>=97&(t[u>>2]|0)<=122)?!((t[u>>2]|0)>=65&(t[u>>2]|0)<=90):0)?!((t[u>>2]|0)>=48&(t[u>>2]|0)<=57|(t[u>>2]|0)==95|(t[u>>2]|0)==58|(t[u>>2]|0)==45|(t[u>>2]|0)==46|(t[u>>2]|0)==183):0)?!((t[u>>2]|0)>=192&(t[u>>2]|0)<=214):0)?!((t[u>>2]|0)>=216&(t[u>>2]|0)<=246):0)?!((t[u>>2]|0)>=248&(t[u>>2]|0)<=767):0)?!((t[u>>2]|0)>=768&(t[u>>2]|0)<=879):0)?!((t[u>>2]|0)>=880&(t[u>>2]|0)<=893):0)?!((t[u>>2]|0)>=895&(t[u>>2]|0)<=8191):0)?!((t[u>>2]|0)>=8204&(t[u>>2]|0)<=8205):0)?!((t[u>>2]|0)>=8255&(t[u>>2]|0)<=8256):0)?!((t[u>>2]|0)>=8304&(t[u>>2]|0)<=8591):0)?!((t[u>>2]|0)>=11264&(t[u>>2]|0)<=12271):0)?!((t[u>>2]|0)>=12289&(t[u>>2]|0)<=55295):0)?!((t[u>>2]|0)>=63744&(t[u>>2]|0)<=64975):0)?!((t[u>>2]|0)>=65008&(t[u>>2]|0)<=65533):0)?!((t[u>>2]|0)>=65536&(t[u>>2]|0)<=983039):0)break;t[n>>2]=1;o=t[n>>2]|0;s=r;return o|0}while(0);t[n>>2]=0;o=t[n>>2]|0;s=r;return o|0}function aN(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0;r=s;s=s+16|0;n=r+12|0;f=r+8|0;u=r+4|0;a=r;t[f>>2]=e;t[u>>2]=i;if((t[(t[f>>2]|0)+20>>2]|0)<=0?(t[(t[f>>2]|0)+20>>2]=4,i=gAi[t[135744>>2]&511](t[(t[f>>2]|0)+20>>2]<<2)|0,t[(t[f>>2]|0)+24>>2]=i,(t[(t[f>>2]|0)+24>>2]|0)==0):0){gR(t[f>>2]|0,79472);t[(t[f>>2]|0)+20>>2]=0;t[n>>2]=0;o=t[n>>2]|0;s=r;return o|0}do if((t[(t[f>>2]|0)+16>>2]|0)>=(t[(t[f>>2]|0)+20>>2]|0)){t[a>>2]=MAi[t[135760>>2]&511](t[(t[f>>2]|0)+24>>2]|0,t[(t[f>>2]|0)+20>>2]<<1<<2)|0;i=t[f>>2]|0;if(t[a>>2]|0){e=i+20|0;t[e>>2]=t[e>>2]<<1;t[(t[f>>2]|0)+24>>2]=t[a>>2];break}gR(i,85184);t[n>>2]=0;o=t[n>>2]|0;s=r;return o|0}while(0);t[(t[(t[f>>2]|0)+24>>2]|0)+(t[(t[f>>2]|0)+16>>2]<<2)>>2]=t[u>>2];t[(t[f>>2]|0)+12>>2]=t[u>>2];u=(t[f>>2]|0)+16|0;f=t[u>>2]|0;t[u>>2]=f+1;t[n>>2]=f;o=t[n>>2]|0;s=r;return o|0}function oN(e){e=e|0;var i=0,r=0,n=0,f=0,u=0;i=s;s=s+16|0;r=i+8|0;n=i+4|0;f=i;t[n>>2]=e;if((t[(t[n>>2]|0)+16>>2]|0)<=0){t[r>>2]=0;u=t[r>>2]|0;s=i;return u|0}e=(t[n>>2]|0)+16|0;t[e>>2]=(t[e>>2]|0)+-1;e=t[n>>2]|0;if((t[(t[n>>2]|0)+16>>2]|0)>0)t[(t[n>>2]|0)+12>>2]=t[(t[(t[n>>2]|0)+24>>2]|0)+((t[e+16>>2]|0)-1<<2)>>2];else t[e+12>>2]=0;t[f>>2]=t[(t[(t[n>>2]|0)+24>>2]|0)+(t[(t[n>>2]|0)+16>>2]<<2)>>2];t[(t[(t[n>>2]|0)+24>>2]|0)+(t[(t[n>>2]|0)+16>>2]<<2)>>2]=0;t[r>>2]=t[f>>2];u=t[r>>2]|0;s=i;return u|0}function cN(e,i,r,f){e=e|0;i=i|0;r=r|0;f=f|0;var u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0;u=s;s=s+32|0;a=u+20|0;o=u+16|0;c=u+12|0;l=u+8|0;b=u+4|0;k=u;t[a>>2]=e;t[o>>2]=i;t[c>>2]=r;t[l>>2]=f;if(!(t[c>>2]|0)){s=u;return}if(t[l>>2]|0)xY(t[a>>2]|0,79632)|0;t[b>>2]=t[c>>2];e:while(1){if(!(t[b>>2]|0)){h=30;break}t[k>>2]=HY(t[a>>2]|0)|0;if(((t[o>>2]|0)-(t[k>>2]|0)|0)<50){h=7;break}switch(t[(t[b>>2]|0)+4>>2]|0){case 3:{if(!(EF(t[b>>2]|0)|0))h=25;break}case 1:{if((t[(t[b>>2]|0)+36>>2]|0)!=0?(t[(t[(t[b>>2]|0)+36>>2]|0)+12>>2]|0)!=0:0){c=(t[o>>2]|0)-(t[k>>2]|0)|0;if((c|0)<((rs(t[(t[(t[b>>2]|0)+36>>2]|0)+12>>2]|0)|0)+10|0)){h=14;break e}xY(t[a>>2]|0,t[(t[(t[b>>2]|0)+36>>2]|0)+12>>2]|0)|0;xY(t[a>>2]|0,79648)|0}if(((t[o>>2]|0)-(t[k>>2]|0)|0)<((rs(t[(t[b>>2]|0)+8>>2]|0)|0)+10|0)){h=19;break e}xY(t[a>>2]|0,t[(t[b>>2]|0)+8>>2]|0)|0;if(t[(t[b>>2]|0)+24>>2]|0)xY(t[a>>2]|0,80064)|0;break}case 18:case 12:case 11:case 10:case 13:case 21:case 9:case 2:{xY(t[a>>2]|0,85176)|0;if(t[(t[b>>2]|0)+24>>2]|0)xY(t[a>>2]|0,80064)|0;break}case 5:case 4:{h=25;break}default:{}}if((h|0)==25?(h=0,xY(t[a>>2]|0,85168)|0,(t[(t[b>>2]|0)+24>>2]|0)!=0):0)xY(t[a>>2]|0,80064)|0;t[b>>2]=t[(t[b>>2]|0)+24>>2]}if((h|0)==7){if(((t[o>>2]|0)-(t[k>>2]|0)|0)<=4){s=u;return}if((n[(t[a>>2]|0)+((t[k>>2]|0)-1)>>0]|0)==46){s=u;return}xY(t[a>>2]|0,79624)|0;s=u;return}else if((h|0)==14){if(((t[o>>2]|0)-(t[k>>2]|0)|0)<=4){s=u;return}if((n[(t[a>>2]|0)+((t[k>>2]|0)-1)>>0]|0)==46){s=u;return}xY(t[a>>2]|0,79624)|0;s=u;return}else if((h|0)==19){if(((t[o>>2]|0)-(t[k>>2]|0)|0)<=4){s=u;return}if((n[(t[a>>2]|0)+((t[k>>2]|0)-1)>>0]|0)==46){s=u;return}xY(t[a>>2]|0,79624)|0;s=u;return}else if((h|0)==30){if(!(t[l>>2]|0)){s=u;return}xY(t[a>>2]|0,79672)|0;s=u;return}}function lN(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0;r=s;s=s+16|0;n=r+8|0;f=r+4|0;u=r;t[n>>2]=e;t[f>>2]=i;t[u>>2]=t[f>>2];sN(t[n>>2]|0,t[t[u>>2]>>2]|0,t[(t[u>>2]|0)+4>>2]|0);s=r;return 1}function sN(e,i,r){e=e|0;i=i|0;r=r|0;var f=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0,S=0,g=0,y=0,F=0,O=0;f=s;s=s+48|0;a=f+40|0;o=f+36|0;c=f+32|0;l=f+28|0;b=f+24|0;k=f+20|0;h=f+16|0;w=f+12|0;d=f+45|0;v=f+8|0;m=f+4|0;_=f;p=f+44|0;t[a>>2]=e;t[o>>2]=i;t[c>>2]=r;if(!(t[a>>2]|0)){s=f;return}if((t[(t[a>>2]|0)+8>>2]|0)==0?(t[(t[a>>2]|0)+12>>2]|0)==0:0){s=f;return}t[b>>2]=t[(t[a>>2]|0)+8>>2];if(!(t[b>>2]|0)){t[h>>2]=0;t[k>>2]=Yl(t[c>>2]|0)|0;if(!(t[k>>2]|0)){t[(t[o>>2]|0)+36>>2]=0;s=f;return}t[w>>2]=t[k>>2];e:while(1){if(!(u[t[w>>2]>>0]|0))break;t[h>>2]=t[w>>2];while(1){if(u[t[w>>2]>>0]|0){do if((u[t[w>>2]>>0]|0|0)==32)E=1;else{if(9<=(u[t[w>>2]>>0]|0|0)?(u[t[w>>2]>>0]|0|0)<=10:0){E=1;break}E=(u[t[w>>2]>>0]|0|0)==13}while(0);S=E^1}else S=0;g=t[w>>2]|0;if(!S)break;t[w>>2]=g+1}n[d>>0]=n[g>>0]|0;n[t[w>>2]>>0]=0;t[l>>2]=GM(t[(t[o>>2]|0)+32>>2]|0,t[h>>2]|0)|0;if(!(t[l>>2]|0)){WR(t[o>>2]|0,0,536,84752,t[(t[a>>2]|0)+12>>2]|0,t[(t[a>>2]|0)+16>>2]|0,t[h>>2]|0);t[(t[o>>2]|0)+36>>2]=0}if(!(u[d>>0]|0))break;n[t[w>>2]>>0]=n[d>>0]|0;while(1){do if((u[t[w>>2]>>0]|0|0)!=32){if(9<=(u[t[w>>2]>>0]|0|0)?(u[t[w>>2]>>0]|0|0)<=10:0)break;if((u[t[w>>2]>>0]|0|0)!=13)continue e}while(0);t[w>>2]=(t[w>>2]|0)+1}}pAi[t[135736>>2]&511](t[k>>2]|0);s=f;return}if((t[(t[b>>2]|0)+40>>2]|0)==3){t[l>>2]=GM(t[(t[o>>2]|0)+32>>2]|0,t[c>>2]|0)|0;if(t[l>>2]|0){s=f;return}ER(t[o>>2]|0,t[(t[b>>2]|0)+20>>2]|0,536,84808,t[(t[b>>2]|0)+8>>2]|0,t[c>>2]|0,0);t[(t[o>>2]|0)+36>>2]=0;s=f;return}if((t[(t[b>>2]|0)+40>>2]|0)!=4){s=f;return}t[m>>2]=0;t[v>>2]=Yl(t[c>>2]|0)|0;if(!(t[v>>2]|0)){gR(t[o>>2]|0,84864);t[(t[o>>2]|0)+36>>2]=0;s=f;return}t[_>>2]=t[v>>2];e:while(1){if(!(u[t[_>>2]>>0]|0))break;t[m>>2]=t[_>>2];while(1){if(u[t[_>>2]>>0]|0){do if((u[t[_>>2]>>0]|0|0)==32)y=1;else{if(9<=(u[t[_>>2]>>0]|0|0)?(u[t[_>>2]>>0]|0|0)<=10:0){y=1;break}y=(u[t[_>>2]>>0]|0|0)==13}while(0);F=y^1}else F=0;O=t[_>>2]|0;if(!F)break;t[_>>2]=O+1}n[p>>0]=n[O>>0]|0;n[t[_>>2]>>0]=0;t[l>>2]=GM(t[(t[o>>2]|0)+32>>2]|0,t[m>>2]|0)|0;if(!(t[l>>2]|0)){ER(t[o>>2]|0,t[(t[b>>2]|0)+20>>2]|0,536,84880,t[(t[b>>2]|0)+8>>2]|0,t[m>>2]|0,0);t[(t[o>>2]|0)+36>>2]=0}if(!(u[p>>0]|0))break;n[t[_>>2]>>0]=n[p>>0]|0;while(1){do if((u[t[_>>2]>>0]|0|0)!=32){if(9<=(u[t[_>>2]>>0]|0|0)?(u[t[_>>2]>>0]|0|0)<=10:0)break;if((u[t[_>>2]>>0]|0|0)!=13)continue e}while(0);t[_>>2]=(t[_>>2]|0)+1}}pAi[t[135736>>2]&511](t[v>>2]|0);s=f;return}function bN(){var e=0,i=0,r=0,n=0,f=0;e=s;s=s+16|0;i=e+4|0;r=e;t[r>>2]=0;if(t[21466]|0){s=e;return}t[i>>2]=0;while(1){if((t[i>>2]|0)>=100)break;t[85872+(t[i>>2]<<2)>>2]=0;t[i>>2]=(t[i>>2]|0)+1}t[i>>2]=0;e:while(1){if(!((t[i>>2]|0)<99?(t[86272+(t[r>>2]<<2)>>2]|0)!=0:0))break;n=86272+(t[r>>2]<<2)|0;f=t[i>>2]|0;t[i>>2]=f+1;t[85872+(f<<2)>>2]=n;while(1){n=(t[86272+(t[r>>2]<<2)>>2]|0)!=0;t[r>>2]=(t[r>>2]|0)+1;if(!n)continue e}}t[21466]=1;s=e;return}function kN(e){e=e|0;var i=0,r=0,n=0,f=0,u=0,a=0,o=0;i=s;s=s+16|0;r=i+8|0;n=i+4|0;f=i;t[n>>2]=e;t[f>>2]=0;while(1){if((t[f>>2]|0)>>>0>=92){u=6;break}e=(Ql(t[n>>2]|0,t[87848+((t[f>>2]|0)*36|0)>>2]|0)|0)!=0;a=t[f>>2]|0;if(!e){u=4;break}t[f>>2]=a+1}if((u|0)==4){t[r>>2]=87848+(a*36|0);o=t[r>>2]|0;s=i;return o|0}else if((u|0)==6){t[r>>2]=0;o=t[r>>2]|0;s=i;return o|0}return 0}function hN(e){e=e|0;var i=0,r=0,n=0,f=0,u=0,a=0,o=0;i=s;s=s+16|0;r=i+8|0;n=i+4|0;f=i;t[n>>2]=e;t[f>>2]=0;while(1){if((t[f>>2]|0)>>>0>=253){u=6;break}e=(Xl(t[n>>2]|0,t[91164+((t[f>>2]|0)*12|0)>>2]|0)|0)!=0;a=t[f>>2]|0;if(e){u=4;break}t[f>>2]=a+1}if((u|0)==4){t[r>>2]=91160+(a*12|0);o=t[r>>2]|0;s=i;return o|0}else if((u|0)==6){t[r>>2]=0;o=t[r>>2]|0;s=i;return o|0}return 0}function wN(e){e=e|0;var i=0,r=0,n=0,f=0,u=0,a=0,o=0;i=s;s=s+16|0;r=i+8|0;n=i+4|0;f=i;t[n>>2]=e;t[f>>2]=0;while(1){if((t[f>>2]|0)>>>0>=253)break;u=t[f>>2]|0;if((t[91160+((t[f>>2]|0)*12|0)>>2]|0)>>>0>=(t[n>>2]|0)>>>0){a=4;break}t[f>>2]=u+1}if((a|0)==4?(t[91160+(u*12|0)>>2]|0)>>>0<=(t[n>>2]|0)>>>0:0){t[r>>2]=91160+((t[f>>2]|0)*12|0);o=t[r>>2]|0;s=i;return o|0}t[r>>2]=0;o=t[r>>2]|0;s=i;return o|0}function dN(e,i,r,f){e=e|0;i=i|0;r=r|0;f=f|0;var a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0,S=0,g=0,y=0,F=0,O=0,A=0,M=0;a=s;s=s+96|0;o=a;c=a+64|0;l=a+60|0;b=a+56|0;k=a+52|0;h=a+48|0;w=a+44|0;d=a+40|0;v=a+36|0;m=a+32|0;_=a+28|0;p=a+24|0;E=a+20|0;S=a+16|0;g=a+12|0;y=a+8|0;F=a+4|0;O=a+72|0;t[l>>2]=e;t[b>>2]=i;t[k>>2]=r;t[h>>2]=f;t[w>>2]=t[k>>2];t[v>>2]=t[l>>2];t[m>>2]=t[k>>2];if((t[l>>2]|0)==0|(t[b>>2]|0)==0|(t[h>>2]|0)==0){t[c>>2]=-1;A=t[c>>2]|0;s=a;return A|0}if(!(t[k>>2]|0)){t[t[b>>2]>>2]=0;t[t[h>>2]>>2]=0;t[c>>2]=0;A=t[c>>2]|0;s=a;return A|0}t[_>>2]=(t[k>>2]|0)+(t[t[h>>2]>>2]|0);t[d>>2]=(t[l>>2]|0)+(t[t[b>>2]>>2]|0);e:while(1){if((t[k>>2]|0)>>>0>=(t[_>>2]|0)>>>0){M=32;break}f=t[k>>2]|0;t[k>>2]=f+1;t[E>>2]=u[f>>0];f=t[E>>2]|0;do if((t[E>>2]|0)>>>0<128){t[p>>2]=f;t[S>>2]=0}else{if(f>>>0<192){M=10;break e}r=t[E>>2]|0;if((t[E>>2]|0)>>>0<224){t[p>>2]=r&31;t[S>>2]=1;break}i=t[E>>2]|0;if(r>>>0<240){t[p>>2]=i&15;t[S>>2]=2;break}if(i>>>0>=248){M=17;break e}t[p>>2]=t[E>>2]&7;t[S>>2]=3}while(0);if(((t[_>>2]|0)-(t[k>>2]|0)|0)<(t[S>>2]|0)){M=32;break}while(1){if(!(t[S>>2]|0))break;if((t[k>>2]|0)>>>0>=(t[_>>2]|0)>>>0)break;f=t[k>>2]|0;t[k>>2]=f+1;i=u[f>>0]|0;t[E>>2]=i;if((i&192|0)!=128)break;t[p>>2]=t[p>>2]<<6;t[p>>2]=t[p>>2]|t[E>>2]&63;t[S>>2]=(t[S>>2]|0)+-1}if((t[p>>2]|0)>>>0<128){if(((t[l>>2]|0)+1|0)>>>0>=(t[d>>2]|0)>>>0){M=32;break}i=t[p>>2]&255;f=t[l>>2]|0;t[l>>2]=f+1;n[f>>0]=i}else{t[y>>2]=wN(t[p>>2]|0)|0;if(!(t[y>>2]|0)){t[o>>2]=t[p>>2];SY(O,16,94200,o)|0;t[F>>2]=O}else t[F>>2]=t[(t[y>>2]|0)+4>>2];t[g>>2]=HY(t[F>>2]|0)|0;if(((t[l>>2]|0)+2+(t[g>>2]|0)|0)>>>0>=(t[d>>2]|0)>>>0){M=32;break}i=t[l>>2]|0;t[l>>2]=i+1;n[i>>0]=38;YY(t[l>>2]|0,t[F>>2]|0,t[g>>2]|0)|0;t[l>>2]=(t[l>>2]|0)+(t[g>>2]|0);i=t[l>>2]|0;t[l>>2]=i+1;n[i>>0]=59}t[w>>2]=t[k>>2]}if((M|0)==10){t[t[b>>2]>>2]=(t[l>>2]|0)-(t[v>>2]|0);t[t[h>>2]>>2]=(t[w>>2]|0)-(t[m>>2]|0);t[c>>2]=-2;A=t[c>>2]|0;s=a;return A|0}else if((M|0)==17){t[t[b>>2]>>2]=(t[l>>2]|0)-(t[v>>2]|0);t[t[h>>2]>>2]=(t[w>>2]|0)-(t[m>>2]|0);t[c>>2]=-2;A=t[c>>2]|0;s=a;return A|0}else if((M|0)==32){t[t[b>>2]>>2]=(t[l>>2]|0)-(t[v>>2]|0);t[t[h>>2]>>2]=(t[w>>2]|0)-(t[m>>2]|0);t[c>>2]=0;A=t[c>>2]|0;s=a;return A|0}return 0}function vN(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0;r=s;s=s+16|0;n=r+12|0;f=r+8|0;u=r+4|0;a=r;t[f>>2]=e;t[u>>2]=i;t[a>>2]=gAi[t[135744>>2]&511](96)|0;if(!(t[a>>2]|0)){CN(0,94208);t[n>>2]=0;o=t[n>>2]|0;s=r;return o|0}i=(t[a>>2]|0)+0|0;e=i+96|0;do{t[i>>2]=0;i=i+4|0}while((i|0)<(e|0));
	t[(t[a>>2]|0)+4>>2]=13;t[(t[a>>2]|0)+56>>2]=0;t[(t[a>>2]|0)+44>>2]=0;t[(t[a>>2]|0)+32>>2]=t[a>>2];t[(t[a>>2]|0)+8>>2]=0;t[(t[a>>2]|0)+12>>2]=0;t[(t[a>>2]|0)+48>>2]=0;t[(t[a>>2]|0)+52>>2]=0;t[(t[a>>2]|0)+60>>2]=0;t[(t[a>>2]|0)+40>>2]=1;t[(t[a>>2]|0)+36>>2]=0;t[(t[a>>2]|0)+64>>2]=0;t[(t[a>>2]|0)+68>>2]=0;t[t[a>>2]>>2]=0;t[(t[a>>2]|0)+76>>2]=1;t[(t[a>>2]|0)+92>>2]=160;if((t[u>>2]|0)!=0|(t[f>>2]|0)!=0)$g(t[a>>2]|0,94240,t[u>>2]|0,t[f>>2]|0)|0;t[n>>2]=t[a>>2];o=t[n>>2]|0;s=r;return o|0}function mN(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,a=0,o=0,c=0,l=0;r=s;s=s+32|0;n=r+16|0;f=r+12|0;a=r+8|0;o=r+4|0;c=r;t[f>>2]=e;t[a>>2]=i;t[c>>2]=0;if(t[a>>2]|0)t[t[a>>2]>>2]=0;if((t[f>>2]|0)!=0?(t[(t[f>>2]|0)+36>>2]|0)!=0:0){do if((u[t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==38){Op(t[f>>2]|0);t[o>>2]=PN(t[f>>2]|0)|0;i=t[f>>2]|0;if(!(t[o>>2]|0)){BN(i,68,94336,0,0);break}if((t[i+292>>2]|0)==0?((t[(t[(t[f>>2]|0)+36>>2]|0)+20>>2]|0)-(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)|0)<250:0)yp(t[(t[f>>2]|0)+36>>2]|0,250)|0;if((u[t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)!=59){BN(t[f>>2]|0,23,94368,0,0);if(!(t[a>>2]|0))break;t[t[a>>2]>>2]=t[o>>2];break}if(t[a>>2]|0)t[t[a>>2]>>2]=t[o>>2];t[c>>2]=hN(t[o>>2]|0)|0;if(t[c>>2]|0)Op(t[f>>2]|0)}while(0);t[n>>2]=t[c>>2];l=t[n>>2]|0;s=r;return l|0}t[n>>2]=0;l=t[n>>2]|0;s=r;return l|0}function _N(e){e=e|0;var i=0,r=0,n=0,f=0,a=0,o=0;i=s;s=s+16|0;r=i+8|0;n=i+4|0;f=i;t[n>>2]=e;t[f>>2]=0;if((t[n>>2]|0)!=0?(t[(t[n>>2]|0)+36>>2]|0)!=0:0){do if((u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==38?(u[(t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]|0)+1>>0]|0|0)==35:0){if((u[(t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]|0)+2>>0]|0|0)!=120?(u[(t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]|0)+2>>0]|0|0)!=88:0){a=23;break}e=(t[n>>2]|0)+200|0;t[e>>2]=(t[e>>2]|0)+3;e=(t[(t[n>>2]|0)+36>>2]|0)+16|0;t[e>>2]=(t[e>>2]|0)+3;e=(t[(t[n>>2]|0)+36>>2]|0)+32|0;t[e>>2]=(t[e>>2]|0)+3;e:while(1){if((u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==59)break;if((u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)>=48?(u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)<=57:0)t[f>>2]=(t[f>>2]<<4)+((u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0)-48);else a=13;do if((a|0)==13){a=0;if((u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)>=97?(u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)<=102:0){t[f>>2]=(t[f>>2]<<4)+((u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0)-97)+10;break}if((u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)<65){a=19;break e}if((u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)>70){a=19;break e}t[f>>2]=(t[f>>2]<<4)+((u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0)-65)+10}while(0);Op(t[n>>2]|0)}if((a|0)==19)BN(t[n>>2]|0,6,94448,0,0);if((u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==59)Op(t[n>>2]|0)}else a=23;while(0);do if((a|0)==23){if((u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==38?(u[(t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]|0)+1>>0]|0|0)==35:0){e=(t[n>>2]|0)+200|0;t[e>>2]=(t[e>>2]|0)+2;e=(t[(t[n>>2]|0)+36>>2]|0)+16|0;t[e>>2]=(t[e>>2]|0)+2;e=(t[(t[n>>2]|0)+36>>2]|0)+32|0;t[e>>2]=(t[e>>2]|0)+2;while(1){if((u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==59)break;if((u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)<48){a=30;break}if((u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)>57){a=30;break}t[f>>2]=((t[f>>2]|0)*10|0)+((u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0)-48);Op(t[n>>2]|0)}if((a|0)==30)BN(t[n>>2]|0,7,94448,0,0);if((u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)!=59)break;Op(t[n>>2]|0);break}BN(t[n>>2]|0,8,94488,0,0)}while(0);e=t[f>>2]|0;if((t[f>>2]|0)<256)if(9<=(e|0)&(t[f>>2]|0)<=10|(t[f>>2]|0)==13|32<=(t[f>>2]|0))a=39;else a=40;else if((!(256<=(e|0)&(t[f>>2]|0)<=55295)?!(57344<=(t[f>>2]|0)&(t[f>>2]|0)<=65533):0)?!(65536<=(t[f>>2]|0)&(t[f>>2]|0)<=1114111):0)a=40;else a=39;if((a|0)==39){t[r>>2]=t[f>>2];o=t[r>>2]|0;s=i;return o|0}else if((a|0)==40){IN(t[n>>2]|0,9,94528,t[f>>2]|0);t[r>>2]=0;o=t[r>>2]|0;s=i;return o|0}}BN(t[n>>2]|0,1,94408,0,0);t[r>>2]=0;o=t[r>>2]|0;s=i;return o|0}function pN(e){e=e|0;var i=0,r=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if(!(t[r>>2]|0)){s=i;return}zN(t[r>>2]|0);s=i;return}function EN(e){e=e|0;var i=0,r=0,f=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0;i=s;s=s+32|0;r=i+12|0;f=i+8|0;a=i+16|0;o=i+4|0;c=i;t[f>>2]=e;rS();fj();if((t[f>>2]|0)!=0?(t[(t[f>>2]|0)+36>>2]|0)!=0:0){t[(t[f>>2]|0)+32>>2]=1;t[(t[f>>2]|0)+280>>2]=1;if((t[(t[f>>2]|0)+292>>2]|0)==0?((t[(t[(t[f>>2]|0)+36>>2]|0)+20>>2]|0)-(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)|0)<250:0)yp(t[(t[f>>2]|0)+36>>2]|0,250)|0;if((t[t[f>>2]>>2]|0)!=0?(t[(t[t[f>>2]>>2]|0)+44>>2]|0)!=0:0)EAi[t[(t[t[f>>2]>>2]|0)+44>>2]&511](t[(t[f>>2]|0)+4>>2]|0,136080);if((t[(t[f>>2]|0)+24>>2]|0)==0?((t[(t[(t[f>>2]|0)+36>>2]|0)+20>>2]|0)-(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)|0)>=4:0){if(t[(t[f>>2]|0)+176>>2]|0)l=-1;else l=u[t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]>>0]|0;n[a>>0]=l;n[a+1>>0]=n[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+1>>0]|0;n[a+2>>0]=n[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+2>>0]|0;n[a+3>>0]=n[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+3>>0]|0;t[o>>2]=L_(a,4)|0;if(t[o>>2]|0)Tp(t[f>>2]|0,t[o>>2]|0)|0}jN(t[f>>2]|0)|0;if(!(u[t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]>>0]|0))BN(t[f>>2]|0,4,94672,0,0);if(((t[t[f>>2]>>2]|0)!=0?(t[(t[t[f>>2]>>2]|0)+48>>2]|0)!=0:0)?(t[(t[f>>2]|0)+212>>2]|0)==0:0)pAi[t[(t[t[f>>2]>>2]|0)+48>>2]&511](t[(t[f>>2]|0)+4>>2]|0);while(1){if((((u[t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==60?(u[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+1>>0]|0|0)==33:0)?(u[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+2>>0]|0|0)==45:0)?(u[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+3>>0]|0|0)==45:0)b=1;else if((u[t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==60)b=(u[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+1>>0]|0|0)==63;else b=0;k=t[f>>2]|0;if(!b)break;VN(k);qN(t[f>>2]|0);jN(t[f>>2]|0)|0}if(((((((((u[t[(t[k+36>>2]|0)+16>>2]>>0]|0|0)==60?(u[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+1>>0]|0|0)==33:0)?(Pq(u[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+2>>0]|0)|0)==68:0)?(Pq(u[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+3>>0]|0)|0)==79:0)?(Pq(u[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+4>>0]|0)|0)==67:0)?(Pq(u[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+5>>0]|0)|0)==84:0)?(Pq(u[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+6>>0]|0)|0)==89:0)?(Pq(u[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+7>>0]|0)|0)==80:0)?(Pq(u[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+8>>0]|0)|0)==69:0)YN(t[f>>2]|0);jN(t[f>>2]|0)|0;while(1){if((((u[t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==60?(u[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+1>>0]|0|0)==33:0)?(u[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+2>>0]|0|0)==45:0)?(u[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+3>>0]|0|0)==45:0)h=1;else if((u[t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==60)h=(u[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+1>>0]|0|0)==63;else h=0;w=t[f>>2]|0;if(!h)break;VN(w);qN(t[f>>2]|0);jN(t[f>>2]|0)|0}zN(w);if(!(u[t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]>>0]|0))UN(t[f>>2]|0);if((t[t[f>>2]>>2]|0)!=0?(t[(t[t[f>>2]>>2]|0)+52>>2]|0)!=0:0)pAi[t[(t[t[f>>2]>>2]|0)+52>>2]&511](t[(t[f>>2]|0)+4>>2]|0);if(((t[(t[f>>2]|0)+360>>2]&4|0)==0?(t[(t[f>>2]|0)+8>>2]|0)!=0:0)?(t[c>>2]=Qg(t[(t[f>>2]|0)+8>>2]|0)|0,(t[c>>2]|0)==0):0){c=$g(t[(t[f>>2]|0)+8>>2]|0,94240,94296,94248)|0;t[(t[(t[f>>2]|0)+8>>2]|0)+44>>2]=c}if(t[(t[f>>2]|0)+12>>2]|0){t[r>>2]=0;d=t[r>>2]|0;s=i;return d|0}else{t[r>>2]=-1;d=t[r>>2]|0;s=i;return d|0}}BN(t[f>>2]|0,1,94632,0,0);t[r>>2]=1;d=t[r>>2]|0;s=i;return d|0}function SN(e){e=e|0;var i=0,r=0;i=s;s=s+16|0;r=i;t[r>>2]=e;Up(t[r>>2]|0);s=i;return}function gN(){var e=0,i=0,r=0,n=0,f=0;e=s;s=s+16|0;i=e+4|0;r=e;t[r>>2]=gAi[t[135744>>2]&511](472)|0;do if(t[r>>2]|0){VY(t[r>>2]|0,0,472)|0;n=(GN(t[r>>2]|0)|0)<0;f=t[r>>2]|0;if(n){SN(f);t[i>>2]=0;break}else{t[i>>2]=f;break}}else{CN(0,94696);t[i>>2]=0}while(0);s=e;return t[i>>2]|0}function yN(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0;r=s;s=s+32|0;n=r+20|0;f=r+16|0;u=r+12|0;a=r+8|0;o=r+4|0;c=r;t[f>>2]=e;t[u>>2]=i;do if(t[f>>2]|0){if((t[u>>2]|0)<=0){t[n>>2]=0;break}t[a>>2]=gN()|0;if(!(t[a>>2]|0)){t[n>>2]=0;break}t[c>>2]=GO(t[f>>2]|0,t[u>>2]|0,0)|0;if(!(t[c>>2]|0)){t[n>>2]=0;break}t[o>>2]=Cp(t[a>>2]|0)|0;if(!(t[o>>2]|0)){Up(t[a>>2]|0);t[n>>2]=0;break}else{t[(t[o>>2]|0)+4>>2]=0;t[t[o>>2]>>2]=t[c>>2];zs(t[(t[c>>2]|0)+16>>2]|0,t[o>>2]|0)|0;eE(t[a>>2]|0,t[o>>2]|0)|0;t[n>>2]=t[a>>2];break}}else t[n>>2]=0;while(0);s=r;return t[n>>2]|0}function FN(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0;f=s;s=s+48|0;u=f+44|0;a=f+40|0;o=f+36|0;c=f+32|0;l=f+28|0;b=f+24|0;k=f+20|0;h=f+16|0;w=f+12|0;d=f+8|0;v=f+4|0;m=f;t[a>>2]=e;t[o>>2]=i;t[c>>2]=r;t[l>>2]=n;if((t[a>>2]|0)!=0?(t[(t[a>>2]|0)+36>>2]|0)!=0:0){do if((((t[c>>2]|0)>0&(t[o>>2]|0)!=0?(t[(t[a>>2]|0)+36>>2]|0)!=0:0)?(t[t[(t[a>>2]|0)+36>>2]>>2]|0)!=0:0)?(t[(t[a>>2]|0)+172>>2]|0)!=-1:0){t[b>>2]=js(t[(t[t[(t[a>>2]|0)+36>>2]>>2]|0)+16>>2]|0,t[(t[a>>2]|0)+36>>2]|0)|0;t[k>>2]=(t[(t[(t[a>>2]|0)+36>>2]|0)+16>>2]|0)-(t[(t[(t[a>>2]|0)+36>>2]|0)+12>>2]|0);t[h>>2]=ZO(t[t[(t[a>>2]|0)+36>>2]>>2]|0,t[c>>2]|0,t[o>>2]|0)|0;n=t[a>>2]|0;if((t[h>>2]|0)>=0){Vs(t[(t[t[n+36>>2]>>2]|0)+16>>2]|0,t[(t[a>>2]|0)+36>>2]|0,t[b>>2]|0,t[k>>2]|0)|0;break}t[n+84>>2]=-1;t[(t[a>>2]|0)+212>>2]=1;t[u>>2]=-1;_=t[u>>2]|0;s=f;return _|0}else p=11;while(0);do if(((((((p|0)==11?(t[(t[a>>2]|0)+172>>2]|0)!=-1:0)?(t[(t[a>>2]|0)+36>>2]|0)!=0:0)?(t[t[(t[a>>2]|0)+36>>2]>>2]|0)!=0:0)?(t[w>>2]=t[t[(t[a>>2]|0)+36>>2]>>2],(t[(t[w>>2]|0)+12>>2]|0)!=0):0)?(t[(t[w>>2]|0)+16>>2]|0)!=0:0)?(t[(t[w>>2]|0)+20>>2]|0)!=0:0){t[v>>2]=js(t[(t[w>>2]|0)+16>>2]|0,t[(t[a>>2]|0)+36>>2]|0)|0;t[m>>2]=(t[(t[(t[a>>2]|0)+36>>2]|0)+16>>2]|0)-(t[(t[(t[a>>2]|0)+36>>2]|0)+12>>2]|0);t[d>>2]=Y_(t[w>>2]|0,t[l>>2]|0)|0;if((t[d>>2]|0)>=0){Vs(t[(t[w>>2]|0)+16>>2]|0,t[(t[a>>2]|0)+36>>2]|0,t[v>>2]|0,t[m>>2]|0)|0;break}BN(t[a>>2]|0,81,94760,0,0);t[u>>2]=81;_=t[u>>2]|0;s=f;return _|0}while(0);WN(t[a>>2]|0,t[l>>2]|0)|0;if(t[l>>2]|0){if(((t[(t[a>>2]|0)+172>>2]|0)!=-1?(t[(t[a>>2]|0)+172>>2]|0)!=14:0)?(t[(t[a>>2]|0)+172>>2]|0)!=1:0){t[(t[a>>2]|0)+84>>2]=5;t[(t[a>>2]|0)+12>>2]=0}if(((t[(t[a>>2]|0)+172>>2]|0)!=-1?(t[t[a>>2]>>2]|0)!=0:0)?(t[(t[t[a>>2]>>2]|0)+52>>2]|0)!=0:0)pAi[t[(t[t[a>>2]>>2]|0)+52>>2]&511](t[(t[a>>2]|0)+4>>2]|0);t[(t[a>>2]|0)+172>>2]=-1}t[u>>2]=t[(t[a>>2]|0)+84>>2];_=t[u>>2]|0;s=f;return _|0}BN(t[a>>2]|0,1,94728,0,0);t[u>>2]=1;_=t[u>>2]|0;s=f;return _|0}function ON(e,i,r,n,f,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;u=u|0;var a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0;a=s;s=s+48|0;o=a+44|0;c=a+40|0;l=a+36|0;b=a+32|0;k=a+28|0;h=a+24|0;w=a+20|0;d=a+16|0;v=a+12|0;m=a+8|0;_=a+4|0;p=a;t[c>>2]=e;t[l>>2]=i;t[b>>2]=r;t[k>>2]=n;t[h>>2]=f;t[w>>2]=u;rS();t[m>>2]=CO(t[w>>2]|0)|0;if(!(t[m>>2]|0)){t[o>>2]=0;E=t[o>>2]|0;s=a;return E|0}t[d>>2]=gN()|0;if(!(t[d>>2]|0)){IO(t[m>>2]|0);t[o>>2]=0;E=t[o>>2]|0;s=a;return E|0}if(!((t[w>>2]|0)!=1?(t[(t[m>>2]|0)+12>>2]|0)==0:0))t[(t[d>>2]|0)+256>>2]=1;do if(t[c>>2]|0){if((t[t[d>>2]>>2]|0)!=136096)pAi[t[135736>>2]&511](t[t[d>>2]>>2]|0);w=gAi[t[135744>>2]&511](128)|0;t[t[d>>2]>>2]=w;if(!(t[t[d>>2]>>2]|0)){pAi[t[135736>>2]&511](t[m>>2]|0);pAi[t[135736>>2]&511](t[d>>2]|0);t[o>>2]=0;E=t[o>>2]|0;s=a;return E|0}else{w=(t[t[d>>2]>>2]|0)+0|0;u=(t[c>>2]|0)+0|0;f=w+128|0;do{t[w>>2]=t[u>>2];w=w+4|0;u=u+4|0}while((w|0)<(f|0));if(!(t[l>>2]|0))break;t[(t[d>>2]|0)+4>>2]=t[l>>2];break}}while(0);if(!(t[h>>2]|0))t[(t[d>>2]|0)+180>>2]=0;else{l=rA(t[h>>2]|0)|0;t[(t[d>>2]|0)+180>>2]=l}t[v>>2]=KN(t[d>>2]|0)|0;if(!(t[v>>2]|0)){Up(t[d>>2]|0);pAi[t[135736>>2]&511](t[m>>2]|0);t[o>>2]=0;E=t[o>>2]|0;s=a;return E|0}if(!(t[h>>2]|0))t[(t[v>>2]|0)+4>>2]=0;else{l=KA(t[h>>2]|0)|0;t[(t[v>>2]|0)+4>>2]=l}t[t[v>>2]>>2]=t[m>>2];zs(t[(t[m>>2]|0)+16>>2]|0,t[v>>2]|0)|0;eE(t[d>>2]|0,t[v>>2]|0)|0;if(((t[k>>2]|0)>0&(t[b>>2]|0)!=0?(t[(t[d>>2]|0)+36>>2]|0)!=0:0)?(t[t[(t[d>>2]|0)+36>>2]>>2]|0)!=0:0){t[_>>2]=js(t[(t[t[(t[d>>2]|0)+36>>2]>>2]|0)+16>>2]|0,t[(t[d>>2]|0)+36>>2]|0)|0;t[p>>2]=(t[(t[(t[d>>2]|0)+36>>2]|0)+16>>2]|0)-(t[(t[(t[d>>2]|0)+36>>2]|0)+12>>2]|0);ZO(t[t[(t[d>>2]|0)+36>>2]>>2]|0,t[k>>2]|0,t[b>>2]|0)|0;Vs(t[(t[t[(t[d>>2]|0)+36>>2]>>2]|0)+16>>2]|0,t[(t[d>>2]|0)+36>>2]|0,t[_>>2]|0,t[p>>2]|0)|0}t[(t[d>>2]|0)+292>>2]=1;t[o>>2]=t[d>>2];E=t[o>>2]|0;s=a;return E|0}function AN(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0;r=s;s=s+48|0;n=r;f=r+36|0;u=r+32|0;a=r+28|0;o=r+24|0;c=r+20|0;l=r+16|0;b=r+12|0;k=r+8|0;h=r+4|0;t[u>>2]=e;t[a>>2]=i;t[k>>2]=94776;if(!(t[u>>2]|0)){t[f>>2]=0;w=t[f>>2]|0;s=r;return w|0}t[o>>2]=gN()|0;if(!(t[o>>2]|0)){t[f>>2]=0;w=t[f>>2]|0;s=r;return w|0}t[l>>2]=KA(t[u>>2]|0)|0;if(!(t[l>>2]|0)){if(t[34014]|0)yAi[t[135968+88>>2]&511](0,94792,n);Up(t[o>>2]|0);t[f>>2]=0;w=t[f>>2]|0;s=r;return w|0}t[c>>2]=uA(t[l>>2]|0,0,t[o>>2]|0)|0;pAi[t[135736>>2]&511](t[l>>2]|0);l=t[o>>2]|0;if(!(t[c>>2]|0)){Up(l);t[f>>2]=0;w=t[f>>2]|0;s=r;return w|0}eE(l,t[c>>2]|0)|0;if(((t[a>>2]|0)!=0?(t[h>>2]=HY(t[a>>2]|0)|0,(t[h>>2]|0)>>>0<1e3):0)?(c=t[33938]|0,l=rs(t[k>>2]|0)|0,t[b>>2]=gAi[c&511](l+(t[h>>2]|0)+1|0)|0,(t[b>>2]|0)!=0):0){WY(t[b>>2]|0,t[k>>2]|0)|0;xY(t[b>>2]|0,t[a>>2]|0)|0;XN(t[o>>2]|0,t[b>>2]|0);pAi[t[135736>>2]&511](t[b>>2]|0)}t[f>>2]=t[o>>2];w=t[f>>2]|0;s=r;return w|0}function MN(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0;f=s;s=s+32|0;u=f+28|0;a=f+24|0;o=f+20|0;c=f+16|0;l=f+12|0;b=f+8|0;k=f+4|0;h=f;t[a>>2]=e;t[o>>2]=i;t[c>>2]=r;t[l>>2]=n;t[h>>2]=0;rS();t[k>>2]=AN(t[a>>2]|0,t[o>>2]|0)|0;if(!(t[k>>2]|0)){t[u>>2]=0;w=t[u>>2]|0;s=f;return w|0}if(t[c>>2]|0){t[h>>2]=t[t[k>>2]>>2];t[t[k>>2]>>2]=t[c>>2];t[(t[k>>2]|0)+4>>2]=t[l>>2]}EN(t[k>>2]|0)|0;t[b>>2]=t[(t[k>>2]|0)+8>>2];if(t[c>>2]|0){t[t[k>>2]>>2]=t[h>>2];t[(t[k>>2]|0)+4>>2]=0}SN(t[k>>2]|0);t[u>>2]=t[b>>2];w=t[u>>2]|0;s=f;return w|0}function RN(e,i){e=e|0;i=i|0;var r=0,n=0,f=0;r=s;s=s+16|0;n=r+4|0;f=r;t[n>>2]=e;t[f>>2]=i;i=MN(t[n>>2]|0,t[f>>2]|0,0,0)|0;s=r;return i|0}function NN(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0;r=s;s=s+16|0;n=r+8|0;f=r+4|0;u=r;t[f>>2]=e;t[u>>2]=i;if(!(t[f>>2]|0)){t[n>>2]=-1;a=t[n>>2]|0;s=r;return a|0}if(t[u>>2]&64){t[(t[t[f>>2]>>2]|0)+84>>2]=0;t[(t[f>>2]|0)+116>>2]=0;t[u>>2]=(t[u>>2]|0)-64;i=(t[f>>2]|0)+360|0;t[i>>2]=t[i>>2]|64}if(t[u>>2]&32){t[(t[t[f>>2]>>2]|0)+88>>2]=0;t[(t[f>>2]|0)+112>>2]=0;t[(t[t[f>>2]>>2]|0)+92>>2]=0;t[u>>2]=(t[u>>2]|0)-32;i=(t[f>>2]|0)+360|0;t[i>>2]=t[i>>2]|32}i=(t[f>>2]|0)+268|0;if(t[u>>2]&128){t[i>>2]=1;t[u>>2]=(t[u>>2]|0)-128;e=(t[f>>2]|0)+360|0;t[e>>2]=t[e>>2]|128}else t[i>>2]=0;i=(t[f>>2]|0)+208|0;if(t[u>>2]&256){t[i>>2]=0;t[(t[t[f>>2]>>2]|0)+72>>2]=65;t[u>>2]=(t[u>>2]|0)-256;e=(t[f>>2]|0)+360|0;t[e>>2]=t[e>>2]|256}else t[i>>2]=1;i=(t[f>>2]|0)+288|0;if(t[u>>2]&1){t[i>>2]=1;t[u>>2]=(t[u>>2]|0)-1}else t[i>>2]=0;if(t[u>>2]&65536){i=(t[f>>2]|0)+360|0;t[i>>2]=t[i>>2]|65536;t[u>>2]=(t[u>>2]|0)-65536}if(t[u>>2]&524288){i=(t[f>>2]|0)+360|0;t[i>>2]=t[i>>2]|524288;t[u>>2]=(t[u>>2]|0)-524288}if(t[u>>2]&4){i=(t[f>>2]|0)+360|0;t[i>>2]=t[i>>2]|4;t[u>>2]=(t[u>>2]|0)-4}if(t[u>>2]&2097152){i=(t[f>>2]|0)+360|0;t[i>>2]=t[i>>2]|2097152;t[u>>2]=(t[u>>2]|0)-2097152}if(t[u>>2]&8192){i=(t[f>>2]|0)+360|0;t[i>>2]=t[i>>2]|8192;t[u>>2]=(t[u>>2]|0)-8192}t[(t[f>>2]|0)+364>>2]=0;t[n>>2]=t[u>>2];a=t[n>>2]|0;s=r;return a|0}function TN(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,l=0;n=s;s=s+32|0;f=n+16|0;u=n+12|0;a=n+8|0;o=n+4|0;c=n;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;rS();t[c>>2]=AN(t[u>>2]|0,t[a>>2]|0)|0;if(!(t[c>>2]|0)){t[f>>2]=0;l=t[f>>2]|0;s=n;return l|0}else{t[f>>2]=ZN(t[c>>2]|0,0,0,t[o>>2]|0,0)|0;l=t[f>>2]|0;s=n;return l|0}return 0}function LN(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;var u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0;u=s;s=s+32|0;a=u+24|0;o=u+20|0;c=u+16|0;l=u+12|0;b=u+8|0;k=u+4|0;h=u;t[o>>2]=e;t[c>>2]=i;t[l>>2]=r;t[b>>2]=n;t[k>>2]=f;rS();t[h>>2]=lS(t[o>>2]|0,t[c>>2]|0)|0;if(!(t[h>>2]|0)){t[a>>2]=0;w=t[a>>2]|0;s=u;return w|0}fj();if(t[t[h>>2]>>2]|0){c=(t[t[h>>2]>>2]|0)+0|0;o=136096|0;f=c+112|0;do{t[c>>2]=t[o>>2];c=c+4|0;o=o+4|0}while((c|0)<(f|0))}t[a>>2]=ZN(t[h>>2]|0,t[l>>2]|0,t[b>>2]|0,t[k>>2]|0,0)|0;w=t[a>>2]|0;s=u;return w|0}function DN(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0;r=s;s=s+32|0;n=r+20|0;f=r+16|0;u=r+12|0;a=r+8|0;o=r+4|0;c=r;t[f>>2]=e;t[u>>2]=i;t[c>>2]=0;if(!(t[21466]|0))bN();t[o>>2]=0;while(1){if((t[o>>2]|0)>=100)break;t[c>>2]=t[85872+(t[o>>2]<<2)>>2];if(!(t[c>>2]|0)){l=6;break}if(Xl(t[t[c>>2]>>2]|0,t[f>>2]|0)|0)break;t[o>>2]=(t[o>>2]|0)+1}if((l|0)==6){t[n>>2]=0;b=t[n>>2]|0;s=r;return b|0}t[a>>2]=((t[c>>2]|0)-86272|0)/4|0;t[a>>2]=(t[a>>2]|0)+1;while(1){if(!(t[86272+(t[a>>2]<<2)>>2]|0)){l=14;break}if(Xl(t[86272+(t[a>>2]<<2)>>2]|0,t[u>>2]|0)|0){l=12;break}t[a>>2]=(t[a>>2]|0)+1}if((l|0)==12){t[n>>2]=1;b=t[n>>2]|0;s=r;return b|0}else if((l|0)==14){t[n>>2]=0;b=t[n>>2]|0;s=r;return b|0}return 0}function CN(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0;r=s;s=s+16|0;n=r;f=r+8|0;u=r+4|0;t[f>>2]=e;t[u>>2]=i;if(((t[f>>2]|0)!=0?(t[(t[f>>2]|0)+212>>2]|0)!=0:0)?(t[(t[f>>2]|0)+172>>2]|0)==-1:0){s=r;return}if(t[f>>2]|0){t[(t[f>>2]|0)+84>>2]=2;t[(t[f>>2]|0)+172>>2]=-1;t[(t[f>>2]|0)+212>>2]=1}i=t[f>>2]|0;if(t[u>>2]|0){f=t[u>>2]|0;t[n>>2]=t[u>>2];cp(0,0,0,i,0,1,2,3,0,0,f,0,0,0,0,98040,n);s=r;return}else{cp(0,0,0,i,0,1,2,3,0,0,0,0,0,0,0,98072,n);s=r;return}}function PN(e){e=e|0;var i=0,r=0,n=0,f=0,a=0,o=0,c=0,l=0,b=0,k=0;i=s;s=s+32|0;r=i+16|0;n=i+12|0;f=i+8|0;a=i+4|0;o=i;t[n>>2]=e;t[o>>2]=0;if((t[(t[n>>2]|0)+292>>2]|0)==0?((t[(t[(t[n>>2]|0)+36>>2]|0)+20>>2]|0)-(t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]|0)|0)<250:0)yp(t[(t[n>>2]|0)+36>>2]|0,250)|0;t[f>>2]=t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2];if((u[t[f>>2]>>0]|0|0)>=97?(u[t[f>>2]>>0]|0|0)<=122:0)c=10;else c=6;do if((c|0)==6){if((u[t[f>>2]>>0]|0|0)>=65?(u[t[f>>2]>>0]|0|0)<=90:0){c=10;break}if(!((u[t[f>>2]>>0]|0|0)!=95?(u[t[f>>2]>>0]|0|0)!=58:0))c=10}while(0);if((c|0)==10){t[f>>2]=(t[f>>2]|0)+1;while(1){if((u[t[f>>2]>>0]|0|0)>=97?(u[t[f>>2]>>0]|0|0)<=122:0)l=1;else c=13;do if((c|0)==13){c=0;if((u[t[f>>2]>>0]|0|0)>=65?(u[t[f>>2]>>0]|0|0)<=90:0){l=1;break}if((u[t[f>>2]>>0]|0|0)>=48?(u[t[f>>2]>>0]|0|0)<=57:0){l=1;break}if(((u[t[f>>2]>>0]|0|0)!=95?(u[t[f>>2]>>0]|0|0)!=45:0)?(u[t[f>>2]>>0]|0|0)!=58:0)l=(u[t[f>>2]>>0]|0|0)==46;else l=1}while(0);b=t[f>>2]|0;if(!l)break;t[f>>2]=b+1}if((u[b>>0]|0|0)>0?(u[t[f>>2]>>0]|0|0)<128:0){t[o>>2]=(t[f>>2]|0)-(t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]|0);t[a>>2]=kz(t[(t[n>>2]|0)+296>>2]|0,t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]|0,t[o>>2]|0)|0;t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]=t[f>>2];f=(t[n>>2]|0)+200|0;t[f>>2]=(t[f>>2]|0)+(t[o>>2]|0);f=(t[(t[n>>2]|0)+36>>2]|0)+32|0;t[f>>2]=(t[f>>2]|0)+(t[o>>2]|0);t[r>>2]=t[a>>2];k=t[r>>2]|0;s=i;return k|0}}t[r>>2]=JN(t[n>>2]|0)|0;k=t[r>>2]|0;s=i;return k|0}function BN(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;var u=0,a=0,o=0,c=0,l=0,b=0,k=0;u=s;s=s+32|0;a=u;o=u+24|0;c=u+20|0;l=u+16|0;b=u+12|0;k=u+8|0;t[o>>2]=e;t[c>>2]=i;t[l>>2]=r;t[b>>2]=n;t[k>>2]=f;if(((t[o>>2]|0)!=0?(t[(t[o>>2]|0)+212>>2]|0)!=0:0)?(t[(t[o>>2]|0)+172>>2]|0)==-1:0){s=u;return}if(t[o>>2]|0)t[(t[o>>2]|0)+84>>2]=t[c>>2];f=t[o>>2]|0;n=t[c>>2]|0;c=t[b>>2]|0;r=t[k>>2]|0;i=t[l>>2]|0;l=t[k>>2]|0;t[a>>2]=t[b>>2];t[a+4>>2]=l;cp(0,0,0,f,0,5,n,2,0,0,c,r,0,0,0,i,a);if(!(t[o>>2]|0)){s=u;return}t[(t[o>>2]|0)+12>>2]=0;s=u;return}function IN(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,u=0,a=0,o=0,c=0,l=0;f=s;s=s+32|0;u=f;a=f+16|0;o=f+12|0;c=f+8|0;l=f+4|0;t[a>>2]=e;t[o>>2]=i;t[c>>2]=r;t[l>>2]=n;if(((t[a>>2]|0)!=0?(t[(t[a>>2]|0)+212>>2]|0)!=0:0)?(t[(t[a>>2]|0)+172>>2]|0)==-1:0){s=f;return}if(t[a>>2]|0)t[(t[a>>2]|0)+84>>2]=t[o>>2];n=t[a>>2]|0;r=t[o>>2]|0;o=t[l>>2]|0;i=t[c>>2]|0;t[u>>2]=t[l>>2];cp(0,0,0,n,0,5,r,2,0,0,0,0,0,o,0,i,u);if(!(t[a>>2]|0)){s=f;return}t[(t[a>>2]|0)+12>>2]=0;s=f;return}function HN(e){e=e|0;var i=0,r=0,n=0,f=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0;i=s;s=s+64|0;r=i+52|0;n=i+48|0;f=i+44|0;a=i+40|0;o=i+36|0;c=i+32|0;l=i+28|0;b=i+24|0;k=i+20|0;h=i+16|0;w=i+12|0;d=i+8|0;v=i+4|0;m=i;t[n>>2]=e;t[l>>2]=0;t[k>>2]=0;t[w>>2]=0;if((t[n>>2]|0)!=0?(t[(t[n>>2]|0)+36>>2]|0)!=0:0){if((t[(t[n>>2]|0)+172>>2]|0)==-1){t[r>>2]=-1;_=t[r>>2]|0;s=i;return _|0}if((u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)!=60){t[r>>2]=-1;_=t[r>>2]|0;s=i;return _|0}Op(t[n>>2]|0);t[c>>2]=t[(t[n>>2]|0)+300>>2];t[b>>2]=t[(t[n>>2]|0)+304>>2];if((t[(t[n>>2]|0)+292>>2]|0)==0?((t[(t[(t[n>>2]|0)+36>>2]|0)+20>>2]|0)-(t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]|0)|0)<250:0)yp(t[(t[n>>2]|0)+36>>2]|0,250)|0;t[f>>2]=QN(t[n>>2]|0)|0;if(!(t[f>>2]|0)){BN(t[n>>2]|0,68,97520,0,0);while(1){if(!(9<=(u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)?(u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)<=10:0))p=15;if(((p|0)==15?(p=0,(u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)!=13):0)?32>(u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0):0)break;if((u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==62)break;if((t[(t[n>>2]|0)+172>>2]|0)==-1)break;Op(t[n>>2]|0)}t[r>>2]=-1;_=t[r>>2]|0;s=i;return _|0}if(Xl(t[f>>2]|0,96200)|0)t[k>>2]=1;$N(t[n>>2]|0,t[f>>2]|0);eT(t[n>>2]|0,t[f>>2]|0);if((t[(t[n>>2]|0)+188>>2]|0)>0?(Xl(t[f>>2]|0,94240)|0)!=0:0){BN(t[n>>2]|0,800,97656,t[f>>2]|0,0);t[w>>2]=1;e=(t[n>>2]|0)+248|0;t[e>>2]=(t[e>>2]|0)+1}if((t[(t[n>>2]|0)+188>>2]|0)!=1?(Xl(t[f>>2]|0,95656)|0)!=0:0){BN(t[n>>2]|0,800,97704,t[f>>2]|0,0);t[w>>2]=1;e=(t[n>>2]|0)+248|0;t[e>>2]=(t[e>>2]|0)+1}e:do if(Xl(t[f>>2]|0,95648)|0){t[d>>2]=0;while(1){if((t[d>>2]|0)>=(t[(t[n>>2]|0)+188>>2]|0))break e;if(Xl(t[(t[(t[n>>2]|0)+196>>2]|0)+(t[d>>2]<<2)>>2]|0,95648)|0){BN(t[n>>2]|0,800,97752,t[f>>2]|0,0);t[w>>2]=1;e=(t[n>>2]|0)+248|0;t[e>>2]=(t[e>>2]|0)+1}t[d>>2]=(t[d>>2]|0)+1}}while(0);jN(t[n>>2]|0)|0;while(1){if(!(9<=(u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)?(u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)<=10:0))p=38;if(((p|0)==38?(p=0,(u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)!=13):0)?32>(u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0):0)break;if((u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==62)break;if((u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==47?(u[(t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]|0)+1>>0]|0|0)==62:0)break;t[v>>2]=t[(t[n>>2]|0)+200>>2];if((t[(t[n>>2]|0)+292>>2]|0)==0?((t[(t[(t[n>>2]|0)+36>>2]|0)+20>>2]|0)-(t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]|0)|0)<250:0)yp(t[(t[n>>2]|0)+36>>2]|0,250)|0;t[a>>2]=iT(t[n>>2]|0,o)|0;e:do if(t[a>>2]|0){t[h>>2]=0;while(1){if((t[h>>2]|0)>=(t[l>>2]|0))break;if(Xl(t[(t[c>>2]|0)+(t[h>>2]<<2)>>2]|0,t[a>>2]|0)|0){p=50;break}t[h>>2]=(t[h>>2]|0)+2}if((p|0)==50){p=0;BN(t[n>>2]|0,42,97800,t[a>>2]|0,0);if(!(t[o>>2]|0))break;pAi[t[135736>>2]&511](t[o>>2]|0);break}do if(!(t[c>>2]|0)){t[b>>2]=22;t[c>>2]=gAi[t[135744>>2]&511](t[b>>2]<<2)|0;if(t[c>>2]|0){t[(t[n>>2]|0)+300>>2]=t[c>>2];t[(t[n>>2]|0)+304>>2]=t[b>>2];break}CN(t[n>>2]|0,0);if(!(t[o>>2]|0))break e;pAi[t[135736>>2]&511](t[o>>2]|0);break e}else{if(((t[l>>2]|0)+4|0)<=(t[b>>2]|0))break;t[b>>2]=t[b>>2]<<1;t[m>>2]=MAi[t[135760>>2]&511](t[c>>2]|0,t[b>>2]<<2)|0;if(t[m>>2]|0){t[c>>2]=t[m>>2];t[(t[n>>2]|0)+300>>2]=t[c>>2];t[(t[n>>2]|0)+304>>2]=t[b>>2];break}CN(t[n>>2]|0,0);if(!(t[o>>2]|0))break e;pAi[t[135736>>2]&511](t[o>>2]|0);break e}while(0);d=t[a>>2]|0;e=t[l>>2]|0;t[l>>2]=e+1;t[(t[c>>2]|0)+(e<<2)>>2]=d;d=t[o>>2]|0;e=t[l>>2]|0;t[l>>2]=e+1;t[(t[c>>2]|0)+(e<<2)>>2]=d;t[(t[c>>2]|0)+(t[l>>2]<<2)>>2]=0;t[(t[c>>2]|0)+((t[l>>2]|0)+1<<2)>>2]=0}else{if(t[o>>2]|0)pAi[t[135736>>2]&511](t[o>>2]|0);while(1){if(!(9<=(u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)?(u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)<=10:0))p=68;do if((p|0)==68){p=0;if((u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==13)break;if(32>(u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0))break e}while(0);if((u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==32)break e;if(9<=(u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)?(u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)<=10:0)break e;if((u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==13)break e;if((u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==62)break e;if((u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==47?(u[(t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]|0)+1>>0]|0|0)==62:0)break e;Op(t[n>>2]|0)}}while(0);jN(t[n>>2]|0)|0;if((t[v>>2]|0)==(t[(t[n>>2]|0)+200>>2]|0)){p=79;break}}if((p|0)==79)BN(t[n>>2]|0,1,97824,0,0);if((t[k>>2]|0)!=0&(t[l>>2]|0)!=0)rT(t[n>>2]|0,t[c>>2]|0);do if(((t[w>>2]|0)==0?(nT(t[n>>2]|0,t[f>>2]|0)|0,(t[t[n>>2]>>2]|0)!=0):0)?(t[(t[t[n>>2]>>2]|0)+56>>2]|0)!=0:0){k=t[(t[t[n>>2]>>2]|0)+56>>2]|0;p=t[(t[n>>2]|0)+4>>2]|0;v=t[f>>2]|0;if(t[l>>2]|0){yAi[k&511](p,v,t[c>>2]|0);break}else{yAi[k&511](p,v,0);break}}while(0);e:do if(t[c>>2]|0){t[h>>2]=1;while(1){if((t[h>>2]|0)>=(t[l>>2]|0))break e;if(t[(t[c>>2]|0)+(t[h>>2]<<2)>>2]|0)pAi[t[135736>>2]&511](t[(t[c>>2]|0)+(t[h>>2]<<2)>>2]|0);t[h>>2]=(t[h>>2]|0)+2}}while(0);t[r>>2]=t[w>>2];_=t[r>>2]|0;s=i;return _|0}BN(t[n>>2]|0,1,97616,0,0);t[r>>2]=-1;_=t[r>>2]|0;s=i;return _|0}function xN(e){e=e|0;var i=0,r=0,n=0,f=0,u=0;i=s;s=s+16|0;r=i+8|0;n=i+4|0;f=i;t[n>>2]=e;if((t[(t[n>>2]|0)+188>>2]|0)<=0){t[r>>2]=0;u=t[r>>2]|0;s=i;return u|0}e=(t[n>>2]|0)+188|0;t[e>>2]=(t[e>>2]|0)+-1;if((t[(t[n>>2]|0)+188>>2]|0)<0){t[r>>2]=0;u=t[r>>2]|0;s=i;return u|0}e=t[n>>2]|0;if((t[(t[n>>2]|0)+188>>2]|0)>0)t[(t[n>>2]|0)+184>>2]=t[(t[(t[n>>2]|0)+196>>2]|0)+((t[e+188>>2]|0)-1<<2)>>2];else t[e+184>>2]=0;t[f>>2]=t[(t[(t[n>>2]|0)+196>>2]|0)+(t[(t[n>>2]|0)+188>>2]<<2)>>2];t[(t[(t[n>>2]|0)+196>>2]|0)+(t[(t[n>>2]|0)+188>>2]<<2)>>2]=0;t[r>>2]=t[f>>2];u=t[r>>2]|0;s=i;return u|0}function UN(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i+4|0;n=i;t[r>>2]=e;if(!(t[(t[r>>2]|0)+188>>2]|0)){s=i;return}t[n>>2]=(t[(t[r>>2]|0)+188>>2]|0)-1;while(1){if((t[n>>2]|0)<0)break;if((t[t[r>>2]>>2]|0)!=0?(t[(t[t[r>>2]>>2]|0)+60>>2]|0)!=0:0)EAi[t[(t[t[r>>2]>>2]|0)+60>>2]&511](t[(t[r>>2]|0)+4>>2]|0,t[(t[r>>2]|0)+184>>2]|0);xN(t[r>>2]|0)|0;t[n>>2]=(t[n>>2]|0)+-1}s=i;return}function zN(e){e=e|0;var i=0,r=0,n=0,f=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0;i=s;s=s+32|0;r=i+16|0;n=i+12|0;f=i+8|0;a=i+4|0;o=i;t[r>>2]=e;t[n>>2]=Yl(t[(t[r>>2]|0)+184>>2]|0)|0;t[f>>2]=t[(t[r>>2]|0)+188>>2];e:while(1){t[o>>2]=t[(t[r>>2]|0)+200>>2];if((t[(t[r>>2]|0)+292>>2]|0)==0?((t[(t[(t[r>>2]|0)+36>>2]|0)+20>>2]|0)-(t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)|0)<250:0)yp(t[(t[r>>2]|0)+36>>2]|0,250)|0;if((t[(t[r>>2]|0)+172>>2]|0)==-1)break;if((u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==60?(u[(t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)+1>>0]|0|0)==47:0){if(!(gi(t[r>>2]|0)|0))continue;if((t[n>>2]|0)==0?(t[(t[r>>2]|0)+188>>2]|0)!=0:0)continue;if(t[n>>2]|0)pAi[t[135736>>2]&511](t[n>>2]|0);t[n>>2]=Yl(t[(t[r>>2]|0)+184>>2]|0)|0;t[f>>2]=t[(t[r>>2]|0)+188>>2];continue}i:do if((u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==60){if(!(65<=(u[(t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)+1>>0]|0|0)?(u[(t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)+1>>0]|0|0)<=90:0))c=17;do if((c|0)==17){c=0;if(97<=(u[(t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)+1>>0]|0|0)?(u[(t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)+1>>0]|0|0)<=122:0)break;if((u[(t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)+1>>0]|0|0)!=95?(u[(t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)+1>>0]|0|0)!=58:0)break i}while(0);t[a>>2]=yi(t[r>>2]|0)|0;e=t[r>>2]|0;if(t[a>>2]|0){if(!(t[e+184>>2]|0))break;if((DN(t[a>>2]|0,t[(t[r>>2]|0)+184>>2]|0)|0)!=1)break;$N(t[r>>2]|0,t[a>>2]|0);continue e}BN(e,68,97520,0,0);while(1){if(9<=(u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)?(u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)<=10:0)c=27;else if((u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)!=13?32>(u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0):0)l=0;else c=27;if((c|0)==27){c=0;l=(u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)!=62}b=t[r>>2]|0;if(!l)break;Op(b)}Mi(b);if(t[n>>2]|0)pAi[t[135736>>2]&511](t[n>>2]|0);t[n>>2]=Yl(t[(t[r>>2]|0)+184>>2]|0)|0;t[f>>2]=t[(t[r>>2]|0)+188>>2];continue e}while(0);if(((t[(t[r>>2]|0)+188>>2]|0)>0?(t[f>>2]|0)>=(t[(t[r>>2]|0)+188>>2]|0):0)?(Xl(t[n>>2]|0,t[(t[r>>2]|0)+184>>2]|0)|0)==0:0){Mi(t[r>>2]|0);if(t[n>>2]|0)pAi[t[135736>>2]&511](t[n>>2]|0);t[n>>2]=Yl(t[(t[r>>2]|0)+184>>2]|0)|0;t[f>>2]=t[(t[r>>2]|0)+188>>2];continue}do if(u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0){if((Xl(t[n>>2]|0,94992)|0)==0?(Xl(t[n>>2]|0,95e3)|0)==0:0){c=46;break}Fi(t[r>>2]|0)}else c=46;while(0);if((c|0)==46){c=0;if(((((((((u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==60?(u[(t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)+1>>0]|0|0)==33:0)?(Pq(u[(t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)+2>>0]|0)|0)==68:0)?(Pq(u[(t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)+3>>0]|0)|0)==79:0)?(Pq(u[(t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)+4>>0]|0)|0)==67:0)?(Pq(u[(t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)+5>>0]|0)|0)==84:0)?(Pq(u[(t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)+6>>0]|0)|0)==89:0)?(Pq(u[(t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)+7>>0]|0)|0)==80:0)?(Pq(u[(t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)+8>>0]|0)|0)==69:0){BN(t[r>>2]|0,800,95008,95040,0);YN(t[r>>2]|0)}if((((u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==60?(u[(t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)+1>>0]|0|0)==33:0)?(u[(t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)+2>>0]|0|0)==45:0)?(u[(t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)+3>>0]|0|0)==45:0)VN(t[r>>2]|0);else c=61;do if((c|0)==61){c=0;if((u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==60?(u[(t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)+1>>0]|0|0)==63:0){qN(t[r>>2]|0);break}e=t[r>>2]|0;if((u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==60){Ri(e);if(t[n>>2]|0)pAi[t[135736>>2]&511](t[n>>2]|0);t[n>>2]=Yl(t[(t[r>>2]|0)+184>>2]|0)|0;t[f>>2]=t[(t[r>>2]|0)+188>>2];break}k=t[r>>2]|0;if((u[t[(t[e+36>>2]|0)+16>>2]>>0]|0|0)==38){Oi(k);break}h=t[r>>2]|0;if(!(u[t[(t[k+36>>2]|0)+16>>2]>>0]|0)){c=71;break e}Ai(h)}while(0);if((t[o>>2]|0)==(t[(t[r>>2]|0)+200>>2]|0)){c=74;break}}if(t[(t[r>>2]|0)+292>>2]|0)continue;if(((t[(t[(t[r>>2]|0)+36>>2]|0)+20>>2]|0)-(t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)|0)>=250)continue;yp(t[(t[r>>2]|0)+36>>2]|0,250)|0}if((c|0)==71)UN(h);else if((c|0)==74?(t[(t[r>>2]|0)+52>>2]|0)!=0:0)BN(t[r>>2]|0,1,95064,0,0);if(!(t[n>>2]|0)){s=i;return}pAi[t[135736>>2]&511](t[n>>2]|0);s=i;return}function jN(e){e=e|0;var i=0,r=0,n=0,f=0;i=s;s=s+16|0;r=i+4|0;n=i;t[r>>2]=e;t[n>>2]=0;e:while(1){do if((u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)!=32){if(9<=(u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)?(u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)<=10:0)break;if((u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)!=13)break e}while(0);if((u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==0?(yp(t[(t[r>>2]|0)+36>>2]|0,250)|0)<=0:0)aE(t[r>>2]|0)|0;else{e=t[(t[r>>2]|0)+36>>2]|0;if((u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==10){f=e+28|0;t[f>>2]=(t[f>>2]|0)+1;t[(t[(t[r>>2]|0)+36>>2]|0)+32>>2]=1}else{f=e+32|0;t[f>>2]=(t[f>>2]|0)+1}f=(t[(t[r>>2]|0)+36>>2]|0)+16|0;t[f>>2]=(t[f>>2]|0)+1;f=(t[r>>2]|0)+200|0;t[f>>2]=(t[f>>2]|0)+1;if(!(u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0))yp(t[(t[r>>2]|0)+36>>2]|0,250)|0}t[n>>2]=(t[n>>2]|0)+1}s=i;return t[n>>2]|0}function VN(e){e=e|0;var i=0,r=0,f=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0;i=s;s=s+48|0;r=i+44|0;f=i+40|0;a=i+36|0;o=i+32|0;c=i+28|0;l=i+24|0;b=i+20|0;k=i+16|0;h=i+12|0;w=i+8|0;d=i+4|0;v=i;t[r>>2]=e;t[f>>2]=0;t[o>>2]=100;if(t[(t[r>>2]|0)+176>>2]|0)m=-1;else m=u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0;if((m|0)!=60){s=i;return}if((u[(t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)+1>>0]|0|0)!=33){s=i;return}if((u[(t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)+2>>0]|0|0)!=45){s=i;return}if((u[(t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)+3>>0]|0|0)!=45){s=i;return}t[d>>2]=t[(t[r>>2]|0)+172>>2];t[(t[r>>2]|0)+172>>2]=5;if(((t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)-(t[(t[(t[r>>2]|0)+36>>2]|0)+12>>2]|0)|0)>500?((t[(t[(t[r>>2]|0)+36>>2]|0)+20>>2]|0)-(t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)|0)<500:0)Fp(t[(t[r>>2]|0)+36>>2]|0);m=(t[r>>2]|0)+200|0;t[m>>2]=(t[m>>2]|0)+4;m=(t[(t[r>>2]|0)+36>>2]|0)+16|0;t[m>>2]=(t[m>>2]|0)+4;m=(t[(t[r>>2]|0)+36>>2]|0)+32|0;t[m>>2]=(t[m>>2]|0)+4;t[f>>2]=gAi[t[135752>>2]&511](t[o>>2]|0)|0;m=t[r>>2]|0;if(!(t[f>>2]|0)){CN(m,97424);t[(t[r>>2]|0)+172>>2]=t[d>>2];s=i;return}t[c>>2]=Ni(m,l)|0;m=t[(t[r>>2]|0)+36>>2]|0;if((u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==10){e=m+28|0;t[e>>2]=(t[e>>2]|0)+1;t[(t[(t[r>>2]|0)+36>>2]|0)+32>>2]=1}else{e=m+32|0;t[e>>2]=(t[e>>2]|0)+1}t[(t[r>>2]|0)+176>>2]=0;e=(t[(t[r>>2]|0)+36>>2]|0)+16|0;t[e>>2]=(t[e>>2]|0)+(t[l>>2]|0);e=(t[r>>2]|0)+200|0;t[e>>2]=(t[e>>2]|0)+1;t[b>>2]=Ni(t[r>>2]|0,k)|0;e=t[(t[r>>2]|0)+36>>2]|0;if((u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==10){m=e+28|0;t[m>>2]=(t[m>>2]|0)+1;t[(t[(t[r>>2]|0)+36>>2]|0)+32>>2]=1}else{m=e+32|0;t[m>>2]=(t[m>>2]|0)+1}t[(t[r>>2]|0)+176>>2]=0;m=(t[(t[r>>2]|0)+36>>2]|0)+16|0;t[m>>2]=(t[m>>2]|0)+(t[k>>2]|0);m=(t[r>>2]|0)+200|0;t[m>>2]=(t[m>>2]|0)+1;t[h>>2]=Ni(t[r>>2]|0,w)|0;t[a>>2]=0;while(1){m=t[h>>2]|0;if((t[h>>2]|0)<256)if(9<=(m|0)&(t[h>>2]|0)<=10|(t[h>>2]|0)==13|32<=(t[h>>2]|0))_=24;else p=0;else if((!(256<=(m|0)&(t[h>>2]|0)<=55295)?!(57344<=(t[h>>2]|0)&(t[h>>2]|0)<=65533):0)?!(65536<=(t[h>>2]|0)&(t[h>>2]|0)<=1114111):0)p=0;else _=24;
	if((_|0)==24){_=0;if((t[h>>2]|0)!=62|(t[b>>2]|0)!=45)p=1;else p=(t[c>>2]|0)!=45}E=t[a>>2]|0;if(!p)break;if((E+5|0)>=(t[o>>2]|0)){t[o>>2]=t[o>>2]<<1;t[v>>2]=MAi[t[135760>>2]&511](t[f>>2]|0,t[o>>2]|0)|0;if(!(t[v>>2]|0)){_=29;break}t[f>>2]=t[v>>2]}if((t[l>>2]|0)==1){m=t[c>>2]&255;e=t[a>>2]|0;t[a>>2]=e+1;n[(t[f>>2]|0)+e>>0]=m}else{m=Np(t[l>>2]|0,(t[f>>2]|0)+(t[a>>2]|0)|0,t[c>>2]|0)|0;t[a>>2]=(t[a>>2]|0)+m}t[c>>2]=t[b>>2];t[l>>2]=t[k>>2];t[b>>2]=t[h>>2];t[k>>2]=t[w>>2];m=t[(t[r>>2]|0)+36>>2]|0;if((u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==10){e=m+28|0;t[e>>2]=(t[e>>2]|0)+1;t[(t[(t[r>>2]|0)+36>>2]|0)+32>>2]=1}else{e=m+32|0;t[e>>2]=(t[e>>2]|0)+1}t[(t[r>>2]|0)+176>>2]=0;e=(t[(t[r>>2]|0)+36>>2]|0)+16|0;t[e>>2]=(t[e>>2]|0)+(t[w>>2]|0);e=(t[r>>2]|0)+200|0;t[e>>2]=(t[e>>2]|0)+1;t[h>>2]=Ni(t[r>>2]|0,w)|0;if(t[h>>2]|0)continue;if(((t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)-(t[(t[(t[r>>2]|0)+36>>2]|0)+12>>2]|0)|0)>500?((t[(t[(t[r>>2]|0)+36>>2]|0)+20>>2]|0)-(t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)|0)<500:0)Fp(t[(t[r>>2]|0)+36>>2]|0);if((t[(t[r>>2]|0)+292>>2]|0)==0?((t[(t[(t[r>>2]|0)+36>>2]|0)+20>>2]|0)-(t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)|0)<250:0)yp(t[(t[r>>2]|0)+36>>2]|0,250)|0;t[h>>2]=Ni(t[r>>2]|0,w)|0}if((_|0)==29){pAi[t[135736>>2]&511](t[f>>2]|0);CN(t[r>>2]|0,97456);t[(t[r>>2]|0)+172>>2]=t[d>>2];s=i;return}n[(t[f>>2]|0)+E>>0]=0;E=t[h>>2]|0;if((t[h>>2]|0)<256)if(9<=(E|0)&(t[h>>2]|0)<=10|(t[h>>2]|0)==13|32<=(t[h>>2]|0))_=51;else _=50;else if((!(256<=(E|0)&(t[h>>2]|0)<=55295)?!(57344<=(t[h>>2]|0)&(t[h>>2]|0)<=65533):0)?!(65536<=(t[h>>2]|0)&(t[h>>2]|0)<=1114111):0)_=50;else _=51;if((_|0)==50){BN(t[r>>2]|0,45,97480,t[f>>2]|0,0);pAi[t[135736>>2]&511](t[f>>2]|0)}else if((_|0)==51){Op(t[r>>2]|0);if(((t[t[r>>2]>>2]|0)!=0?(t[(t[t[r>>2]>>2]|0)+80>>2]|0)!=0:0)?(t[(t[r>>2]|0)+212>>2]|0)==0:0)EAi[t[(t[t[r>>2]>>2]|0)+80>>2]&511](t[(t[r>>2]|0)+4>>2]|0,t[f>>2]|0);pAi[t[135736>>2]&511](t[f>>2]|0)}t[(t[r>>2]|0)+172>>2]=t[d>>2];s=i;return}function qN(e){e=e|0;var i=0,r=0,f=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0;i=s;s=s+48|0;r=i+36|0;f=i+32|0;a=i+28|0;o=i+24|0;c=i+20|0;l=i+16|0;b=i+12|0;k=i+8|0;h=i+4|0;w=i;t[r>>2]=e;t[f>>2]=0;t[a>>2]=0;t[o>>2]=100;t[h>>2]=0;if(t[(t[r>>2]|0)+176>>2]|0)d=-1;else d=u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0;if((d|0)!=60){s=i;return}if((u[(t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)+1>>0]|0|0)!=63){s=i;return}t[k>>2]=t[(t[r>>2]|0)+172>>2];t[(t[r>>2]|0)+172>>2]=2;d=(t[r>>2]|0)+200|0;t[d>>2]=(t[d>>2]|0)+2;d=(t[(t[r>>2]|0)+36>>2]|0)+16|0;t[d>>2]=(t[d>>2]|0)+2;d=(t[(t[r>>2]|0)+36>>2]|0)+32|0;t[d>>2]=(t[d>>2]|0)+2;if(((t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)-(t[(t[(t[r>>2]|0)+36>>2]|0)+12>>2]|0)|0)>500?((t[(t[(t[r>>2]|0)+36>>2]|0)+20>>2]|0)-(t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)|0)<500:0)Fp(t[(t[r>>2]|0)+36>>2]|0);t[b>>2]=PN(t[r>>2]|0)|0;d=t[r>>2]|0;if(t[b>>2]|0){if(t[d+176>>2]|0)v=-1;else v=u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0;if((v|0)==62){v=(t[r>>2]|0)+200|0;t[v>>2]=(t[v>>2]|0)+1;v=(t[(t[r>>2]|0)+36>>2]|0)+16|0;t[v>>2]=(t[v>>2]|0)+1;v=(t[(t[r>>2]|0)+36>>2]|0)+32|0;t[v>>2]=(t[v>>2]|0)+1;if(((t[t[r>>2]>>2]|0)!=0?(t[(t[r>>2]|0)+212>>2]|0)==0:0)?(t[(t[t[r>>2]>>2]|0)+76>>2]|0)!=0:0)yAi[t[(t[t[r>>2]>>2]|0)+76>>2]&511](t[(t[r>>2]|0)+4>>2]|0,t[b>>2]|0,0);t[(t[r>>2]|0)+172>>2]=t[k>>2];s=i;return}t[f>>2]=gAi[t[135752>>2]&511](t[o>>2]|0)|0;v=t[r>>2]|0;if(!(t[f>>2]|0)){CN(v,0);t[(t[r>>2]|0)+172>>2]=t[k>>2];s=i;return}t[c>>2]=u[t[(t[v+36>>2]|0)+16>>2]>>0];if((t[c>>2]|0)<256){if((t[c>>2]|0)!=32?!(9<=(t[c>>2]|0)&(t[c>>2]|0)<=10|(t[c>>2]|0)==13):0)m=22}else m=22;if((m|0)==22)BN(t[r>>2]|0,65,97328,t[b>>2]|0,0);jN(t[r>>2]|0)|0;t[c>>2]=Ni(t[r>>2]|0,l)|0;while(1){v=t[c>>2]|0;if((t[c>>2]|0)<256)if(9<=(v|0)&(t[c>>2]|0)<=10|(t[c>>2]|0)==13|32<=(t[c>>2]|0))m=29;else _=0;else if((!(256<=(v|0)&(t[c>>2]|0)<=55295)?!(57344<=(t[c>>2]|0)&(t[c>>2]|0)<=65533):0)?!(65536<=(t[c>>2]|0)&(t[c>>2]|0)<=1114111):0)_=0;else m=29;if((m|0)==29){m=0;_=(t[c>>2]|0)!=62}p=t[a>>2]|0;if(!_)break;if((p+5|0)>=(t[o>>2]|0)){t[o>>2]=t[o>>2]<<1;t[w>>2]=MAi[t[135760>>2]&511](t[f>>2]|0,t[o>>2]|0)|0;if(!(t[w>>2]|0)){m=33;break}t[f>>2]=t[w>>2]}t[h>>2]=(t[h>>2]|0)+1;if((t[h>>2]|0)>50){if((t[(t[r>>2]|0)+292>>2]|0)==0?((t[(t[(t[r>>2]|0)+36>>2]|0)+20>>2]|0)-(t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)|0)<250:0)yp(t[(t[r>>2]|0)+36>>2]|0,250)|0;t[h>>2]=0}if((t[l>>2]|0)==1){v=t[c>>2]&255;e=t[a>>2]|0;t[a>>2]=e+1;n[(t[f>>2]|0)+e>>0]=v}else{v=Np(t[l>>2]|0,(t[f>>2]|0)+(t[a>>2]|0)|0,t[c>>2]|0)|0;t[a>>2]=(t[a>>2]|0)+v}v=t[(t[r>>2]|0)+36>>2]|0;if((u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==10){e=v+28|0;t[e>>2]=(t[e>>2]|0)+1;t[(t[(t[r>>2]|0)+36>>2]|0)+32>>2]=1}else{e=v+32|0;t[e>>2]=(t[e>>2]|0)+1}t[(t[r>>2]|0)+176>>2]=0;e=(t[(t[r>>2]|0)+36>>2]|0)+16|0;t[e>>2]=(t[e>>2]|0)+(t[l>>2]|0);e=(t[r>>2]|0)+200|0;t[e>>2]=(t[e>>2]|0)+1;t[c>>2]=Ni(t[r>>2]|0,l)|0;if(t[c>>2]|0)continue;do if(((t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)-(t[(t[(t[r>>2]|0)+36>>2]|0)+12>>2]|0)|0)>500){if(((t[(t[(t[r>>2]|0)+36>>2]|0)+20>>2]|0)-(t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)|0)>=500)break;Fp(t[(t[r>>2]|0)+36>>2]|0)}while(0);do if(!(t[(t[r>>2]|0)+292>>2]|0)){if(((t[(t[(t[r>>2]|0)+36>>2]|0)+20>>2]|0)-(t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]|0)|0)>=250)break;yp(t[(t[r>>2]|0)+36>>2]|0,250)|0}while(0);t[c>>2]=Ni(t[r>>2]|0,l)|0}if((m|0)==33){CN(t[r>>2]|0,0);pAi[t[135736>>2]&511](t[f>>2]|0);t[(t[r>>2]|0)+172>>2]=t[k>>2];s=i;return}n[(t[f>>2]|0)+p>>0]=0;p=t[r>>2]|0;if((t[c>>2]|0)==62){c=p+200|0;t[c>>2]=(t[c>>2]|0)+1;c=(t[(t[r>>2]|0)+36>>2]|0)+16|0;t[c>>2]=(t[c>>2]|0)+1;c=(t[(t[r>>2]|0)+36>>2]|0)+32|0;t[c>>2]=(t[c>>2]|0)+1;if(((t[t[r>>2]>>2]|0)!=0?(t[(t[r>>2]|0)+212>>2]|0)==0:0)?(t[(t[t[r>>2]>>2]|0)+76>>2]|0)!=0:0)yAi[t[(t[t[r>>2]>>2]|0)+76>>2]&511](t[(t[r>>2]|0)+4>>2]|0,t[b>>2]|0,t[f>>2]|0)}else BN(p,47,97360,t[b>>2]|0,0);pAi[t[135736>>2]&511](t[f>>2]|0)}else BN(d,46,97392,0,0);t[(t[r>>2]|0)+172>>2]=t[k>>2];s=i;return}function YN(e){e=e|0;var i=0,r=0,n=0,f=0,a=0;i=s;s=s+16|0;r=i+12|0;n=i+8|0;f=i+4|0;a=i;t[r>>2]=e;t[f>>2]=0;t[a>>2]=0;e=(t[r>>2]|0)+200|0;t[e>>2]=(t[e>>2]|0)+9;e=(t[(t[r>>2]|0)+36>>2]|0)+16|0;t[e>>2]=(t[e>>2]|0)+9;e=(t[(t[r>>2]|0)+36>>2]|0)+32|0;t[e>>2]=(t[e>>2]|0)+9;jN(t[r>>2]|0)|0;t[n>>2]=PN(t[r>>2]|0)|0;if(!(t[n>>2]|0))BN(t[r>>2]|0,68,96976,0,0);jN(t[r>>2]|0)|0;t[a>>2]=Ti(t[r>>2]|0,f)|0;jN(t[r>>2]|0)|0;if((u[t[(t[(t[r>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)!=62)BN(t[r>>2]|0,61,97024,0,0);Op(t[r>>2]|0);if(((t[t[r>>2]>>2]|0)!=0?(t[t[t[r>>2]>>2]>>2]|0)!=0:0)?(t[(t[r>>2]|0)+212>>2]|0)==0:0)NAi[t[t[t[r>>2]>>2]>>2]&511](t[(t[r>>2]|0)+4>>2]|0,t[n>>2]|0,t[f>>2]|0,t[a>>2]|0);if(t[a>>2]|0)pAi[t[135736>>2]&511](t[a>>2]|0);if(!(t[f>>2]|0)){s=i;return}pAi[t[135736>>2]&511](t[f>>2]|0);s=i;return}function GN(e){e=e|0;var i=0,r=0,n=0,f=0,u=0,a=0,o=0;i=s;s=s+16|0;r=i+8|0;n=i+4|0;f=i;t[n>>2]=e;if(!(t[n>>2]|0)){t[r>>2]=-1;u=t[r>>2]|0;s=i;return u|0}VY(t[n>>2]|0,0,472)|0;e=lz()|0;t[(t[n>>2]|0)+296>>2]=e;if(!(t[(t[n>>2]|0)+296>>2]|0)){CN(0,96936);t[r>>2]=-1;u=t[r>>2]|0;s=i;return u|0}t[f>>2]=gAi[t[135744>>2]&511](128)|0;if(!(t[f>>2]|0)){CN(0,96936);t[r>>2]=-1;u=t[r>>2]|0;s=i;return u|0}e=(t[f>>2]|0)+0|0;a=e+128|0;do{t[e>>2]=0;e=e+4|0}while((e|0)<(a|0));o=gAi[t[135744>>2]&511](20)|0;t[(t[n>>2]|0)+48>>2]=o;if(!(t[(t[n>>2]|0)+48>>2]|0)){CN(0,96936);t[(t[n>>2]|0)+40>>2]=0;t[(t[n>>2]|0)+44>>2]=0;t[(t[n>>2]|0)+36>>2]=0;t[r>>2]=-1;u=t[r>>2]|0;s=i;return u|0}t[(t[n>>2]|0)+40>>2]=0;t[(t[n>>2]|0)+44>>2]=5;t[(t[n>>2]|0)+36>>2]=0;t[(t[n>>2]|0)+20>>2]=0;t[(t[n>>2]|0)+24>>2]=0;t[(t[n>>2]|0)+28>>2]=-1;t[(t[n>>2]|0)+172>>2]=0;o=gAi[t[135744>>2]&511](40)|0;t[(t[n>>2]|0)+64>>2]=o;if(!(t[(t[n>>2]|0)+64>>2]|0)){CN(0,96936);t[(t[n>>2]|0)+56>>2]=0;t[(t[n>>2]|0)+60>>2]=0;t[(t[n>>2]|0)+52>>2]=0;t[(t[n>>2]|0)+40>>2]=0;t[(t[n>>2]|0)+44>>2]=0;t[(t[n>>2]|0)+36>>2]=0;t[r>>2]=-1;u=t[r>>2]|0;s=i;return u|0}t[(t[n>>2]|0)+56>>2]=0;t[(t[n>>2]|0)+60>>2]=10;t[(t[n>>2]|0)+52>>2]=0;o=gAi[t[135744>>2]&511](40)|0;t[(t[n>>2]|0)+196>>2]=o;if(!(t[(t[n>>2]|0)+196>>2]|0)){CN(0,96936);t[(t[n>>2]|0)+188>>2]=0;t[(t[n>>2]|0)+192>>2]=0;t[(t[n>>2]|0)+184>>2]=0;t[(t[n>>2]|0)+56>>2]=0;t[(t[n>>2]|0)+60>>2]=0;t[(t[n>>2]|0)+52>>2]=0;t[(t[n>>2]|0)+40>>2]=0;t[(t[n>>2]|0)+44>>2]=0;t[(t[n>>2]|0)+36>>2]=0;t[r>>2]=-1;u=t[r>>2]|0;s=i;return u|0}t[(t[n>>2]|0)+188>>2]=0;t[(t[n>>2]|0)+192>>2]=10;t[(t[n>>2]|0)+184>>2]=0;t[(t[n>>2]|0)+460>>2]=0;t[(t[n>>2]|0)+452>>2]=0;t[(t[n>>2]|0)+456>>2]=0;if(!(t[f>>2]|0))t[t[n>>2]>>2]=136096;else{t[t[n>>2]>>2]=t[f>>2];e=(t[f>>2]|0)+0|0;f=136096|0;a=e+112|0;do{t[e>>2]=t[f>>2];e=e+4|0;f=f+4|0}while((e|0)<(a|0))}t[(t[n>>2]|0)+4>>2]=t[n>>2];t[(t[n>>2]|0)+8>>2]=0;t[(t[n>>2]|0)+12>>2]=1;t[(t[n>>2]|0)+16>>2]=0;t[(t[n>>2]|0)+280>>2]=t[33962];t[(t[n>>2]|0)+32>>2]=1;t[(t[n>>2]|0)+136>>2]=-1412623820;t[(t[n>>2]|0)+108>>2]=t[n>>2];t[(t[n>>2]|0)+112>>2]=224;t[(t[n>>2]|0)+116>>2]=225;t[(t[n>>2]|0)+68>>2]=0;t[(t[n>>2]|0)+104>>2]=0;t[(t[n>>2]|0)+200>>2]=0;t[(t[n>>2]|0)+204>>2]=0;t[(t[n>>2]|0)+284>>2]=0;xp((t[n>>2]|0)+72|0);t[r>>2]=0;u=t[r>>2]|0;s=i;return u|0}function WN(e,i){e=e|0;i=i|0;var r=0,f=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0,S=0,g=0,y=0,F=0;r=s;s=s+80|0;f=r+60|0;a=r+56|0;o=r+52|0;c=r+48|0;l=r+44|0;b=r+69|0;k=r+68|0;h=r+24|0;w=r+20|0;d=r+16|0;v=r+12|0;m=r+8|0;_=r+66|0;p=r+4|0;E=r+64|0;S=r;t[f>>2]=e;t[a>>2]=i;t[o>>2]=0;t[l>>2]=0;e:while(1){t[c>>2]=t[(t[f>>2]|0)+36>>2];if(!(t[c>>2]|0))break;i=t[c>>2]|0;if(!(t[t[c>>2]>>2]|0))t[l>>2]=(t[i+24>>2]|0)-((t[(t[c>>2]|0)+16>>2]|0)-(t[(t[c>>2]|0)+12>>2]|0));else{e=Ts(t[(t[i>>2]|0)+16>>2]|0)|0;t[l>>2]=e-((t[(t[c>>2]|0)+16>>2]|0)-(t[(t[c>>2]|0)+12>>2]|0))}if(((((t[l>>2]|0)==0&(t[a>>2]|0)!=0?(UN(t[f>>2]|0),(t[(t[f>>2]|0)+188>>2]|0)==0):0)?(t[(t[f>>2]|0)+172>>2]|0)!=-1:0)?(t[(t[f>>2]|0)+172>>2]=-1,(t[t[f>>2]>>2]|0)!=0):0)?(t[(t[t[f>>2]>>2]|0)+52>>2]|0)!=0:0)pAi[t[(t[t[f>>2]>>2]|0)+52>>2]&511](t[(t[f>>2]|0)+4>>2]|0);if((t[l>>2]|0)<1)break;n[b>>0]=n[t[(t[c>>2]|0)+16>>2]>>0]|0;e=t[f>>2]|0;if(!(u[b>>0]|0)){i=e+200|0;t[i>>2]=(t[i>>2]|0)+1;i=(t[(t[f>>2]|0)+36>>2]|0)+16|0;t[i>>2]=(t[i>>2]|0)+1;i=(t[(t[f>>2]|0)+36>>2]|0)+32|0;t[i>>2]=(t[i>>2]|0)+1;continue}do switch(t[e+172>>2]|0){case 1:{jN(t[f>>2]|0)|0;i=t[c>>2]|0;if(!(t[t[c>>2]>>2]|0))t[l>>2]=(t[i+24>>2]|0)-((t[(t[c>>2]|0)+16>>2]|0)-(t[(t[c>>2]|0)+12>>2]|0));else{g=Ts(t[(t[i>>2]|0)+16>>2]|0)|0;t[l>>2]=g-((t[(t[c>>2]|0)+16>>2]|0)-(t[(t[c>>2]|0)+12>>2]|0))}if((t[l>>2]|0)<1)break e;if((t[l>>2]|0)<2){if(!(t[a>>2]|0))break e;n[k>>0]=32}else n[k>>0]=n[(t[(t[c>>2]|0)+16>>2]|0)+1>>0]|0;n[b>>0]=n[t[(t[c>>2]|0)+16>>2]>>0]|0;if((((u[b>>0]|0)==60?(u[k>>0]|0)==33:0)?(u[(t[(t[c>>2]|0)+16>>2]|0)+2>>0]|0)==45:0)?(u[(t[(t[c>>2]|0)+16>>2]|0)+3>>0]|0)==45:0){if((t[a>>2]|0)==0?(Li(t[f>>2]|0,45,45,62,1,1)|0)<0:0)break e;VN(t[f>>2]|0);t[(t[f>>2]|0)+172>>2]=1;continue e}if((u[b>>0]|0)==60?(u[k>>0]|0)==63:0){if((t[a>>2]|0)==0?(Li(t[f>>2]|0,62,0,0,0,1)|0)<0:0)break e;qN(t[f>>2]|0);t[(t[f>>2]|0)+172>>2]=1;continue e}do if(((((((u[b>>0]|0)==60?(u[k>>0]|0)==33:0)?(Pq(u[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+2>>0]|0)|0)==68:0)?(Pq(u[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+3>>0]|0)|0)==79:0)?(Pq(u[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+4>>0]|0)|0)==67:0)?(Pq(u[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+5>>0]|0)|0)==84:0)?(Pq(u[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+6>>0]|0)|0)==89:0){if((Pq(u[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+7>>0]|0)|0)!=80)break;if((Pq(u[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+8>>0]|0)|0)!=69)break;if((t[a>>2]|0)==0?(Li(t[f>>2]|0,62,0,0,0,1)|0)<0:0)break e;YN(t[f>>2]|0);t[(t[f>>2]|0)+172>>2]=4;continue e}while(0);if((u[b>>0]|0)==60?(u[k>>0]|0)==33&(t[l>>2]|0)<9:0)break e;t[(t[f>>2]|0)+172>>2]=6;continue e;break}case 9:{if((t[l>>2]|0)<2)break e;if((t[a>>2]|0)==0?(Li(t[f>>2]|0,62,0,0,0,1)|0)<0:0)break e;gi(t[f>>2]|0)|0;g=(t[f>>2]|0)+172|0;if(!(t[(t[f>>2]|0)+188>>2]|0))t[g>>2]=14;else t[g>>2]=7;t[(t[f>>2]|0)+204>>2]=0;continue e;break}case 8:{BN(t[f>>2]|0,1,95104,0,0);t[(t[f>>2]|0)+172>>2]=7;t[(t[f>>2]|0)+204>>2]=0;continue e;break}case 3:{BN(t[f>>2]|0,1,95144,0,0);t[(t[f>>2]|0)+172>>2]=7;t[(t[f>>2]|0)+204>>2]=0;continue e;break}case 7:{if(t[(t[f>>2]|0)+176>>2]|0){n[_+0>>0]=0;n[_+1>>0]=0;n[_>>0]=t[(t[f>>2]|0)+176>>2];Ci(t[f>>2]|0)|0;if((t[t[f>>2]>>2]|0)!=0?(t[(t[t[f>>2]>>2]|0)+68>>2]|0)!=0:0)yAi[t[(t[t[f>>2]>>2]|0)+68>>2]&511](t[(t[f>>2]|0)+4>>2]|0,_,1);t[(t[f>>2]|0)+176>>2]=0;t[(t[f>>2]|0)+204>>2]=0}if(((t[l>>2]|0)==1&(t[a>>2]|0)!=0?(n[b>>0]=n[t[(t[c>>2]|0)+16>>2]>>0]|0,(u[b>>0]|0)!=60):0)?(u[b>>0]|0)!=38:0){i:do if(t[t[f>>2]>>2]|0){do if((u[b>>0]|0)!=32){if(9<=(u[b>>0]|0)?(u[b>>0]|0)<=10:0)break;if((u[b>>0]|0)!=13){Ci(t[f>>2]|0)|0;if(!(t[(t[t[f>>2]>>2]|0)+68>>2]|0))break i;yAi[t[(t[t[f>>2]>>2]|0)+68>>2]&511](t[(t[f>>2]|0)+4>>2]|0,b,1);break i}}while(0);g=t[t[f>>2]>>2]|0;if(t[(t[f>>2]|0)+208>>2]|0){if(!(t[g+68>>2]|0))break;yAi[t[(t[t[f>>2]>>2]|0)+68>>2]&511](t[(t[f>>2]|0)+4>>2]|0,b,1);break}else{if(!(t[g+72>>2]|0))break;yAi[t[(t[t[f>>2]>>2]|0)+72>>2]&511](t[(t[f>>2]|0)+4>>2]|0,b,1);break}}while(0);t[(t[f>>2]|0)+176>>2]=0;t[(t[f>>2]|0)+204>>2]=0;g=(t[c>>2]|0)+16|0;t[g>>2]=(t[g>>2]|0)+1;continue e}if((t[l>>2]|0)<2)break e;n[b>>0]=n[t[(t[c>>2]|0)+16>>2]>>0]|0;n[k>>0]=n[(t[(t[c>>2]|0)+16>>2]|0)+1>>0]|0;t[m>>2]=t[(t[f>>2]|0)+200>>2];i:do if((Xl(t[(t[f>>2]|0)+184>>2]|0,94992)|0)==0?(Xl(t[(t[f>>2]|0)+184>>2]|0,95e3)|0)==0:0){do if((((((u[b>>0]|0)==60?(u[k>>0]|0)==33:0)?(Pq(u[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+2>>0]|0)|0)==68:0)?(Pq(u[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+3>>0]|0)|0)==79:0)?(Pq(u[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+4>>0]|0)|0)==67:0)?(Pq(u[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+5>>0]|0)|0)==84:0){if((Pq(u[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+6>>0]|0)|0)!=89)break;if((Pq(u[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+7>>0]|0)|0)!=80)break;if((Pq(u[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+8>>0]|0)|0)!=69)break;if((t[a>>2]|0)==0?(Li(t[f>>2]|0,62,0,0,0,1)|0)<0:0)break e;BN(t[f>>2]|0,800,95008,95040,0);YN(t[f>>2]|0);break i}while(0);if((((u[b>>0]|0)==60?(u[k>>0]|0)==33:0)?(u[(t[(t[c>>2]|0)+16>>2]|0)+2>>0]|0)==45:0)?(u[(t[(t[c>>2]|0)+16>>2]|0)+3>>0]|0)==45:0){if((t[a>>2]|0)==0?(Li(t[f>>2]|0,45,45,62,1,1)|0)<0:0)break e;VN(t[f>>2]|0);t[(t[f>>2]|0)+172>>2]=7;break}if((u[b>>0]|0)==60?(u[k>>0]|0)==63:0){if((t[a>>2]|0)==0?(Li(t[f>>2]|0,62,0,0,0,1)|0)<0:0)break e;qN(t[f>>2]|0);t[(t[f>>2]|0)+172>>2]=7;break}if((u[b>>0]|0)==60?(u[k>>0]|0)==33&(t[l>>2]|0)<4:0)break e;if((u[b>>0]|0)==60?(u[k>>0]|0)==47:0){t[(t[f>>2]|0)+172>>2]=9;t[(t[f>>2]|0)+204>>2]=0;continue e}if((u[b>>0]|0)==60){t[(t[f>>2]|0)+172>>2]=6;t[(t[f>>2]|0)+204>>2]=0;continue e}g=(t[a>>2]|0)!=0;if((u[b>>0]|0)==38){if(!g?(Pi(t[f>>2]|0,95048,4)|0)<0:0)break e;Oi(t[f>>2]|0);break}else{if(!g?(Pi(t[f>>2]|0,95056,2)|0)<0:0)break e;t[(t[f>>2]|0)+204>>2]=0;Ai(t[f>>2]|0);break}}else y=187;while(0);if((y|0)==187){y=0;if(!(t[a>>2]|0)){t[p>>2]=Li(t[f>>2]|0,60,47,0,0,0)|0;if((t[p>>2]|0)<0)break e;n[E>>0]=n[(t[(t[c>>2]|0)+16>>2]|0)+((t[p>>2]|0)+2)>>0]|0;if(!(u[E>>0]|0))break e}Fi(t[f>>2]|0);if((u[b>>0]|0)==60?(u[k>>0]|0)==47:0){t[(t[f>>2]|0)+172>>2]=9;t[(t[f>>2]|0)+204>>2]=0;continue e}}if((t[m>>2]|0)!=(t[(t[f>>2]|0)+200>>2]|0))continue e;if(t[(t[f>>2]|0)+52>>2]|0)BN(t[f>>2]|0,1,95064,0,0);Op(t[f>>2]|0);continue e;break}case 6:{if((t[l>>2]|0)<1)break e;if((t[l>>2]|0)<2){if(!(t[a>>2]|0))break e;n[k>>0]=32}else n[k>>0]=n[(t[(t[c>>2]|0)+16>>2]|0)+1>>0]|0;n[b>>0]=n[t[(t[c>>2]|0)+16>>2]>>0]|0;if((u[b>>0]|0)!=60){t[(t[f>>2]|0)+172>>2]=7;continue e}if((u[k>>0]|0)==47){t[(t[f>>2]|0)+172>>2]=9;t[(t[f>>2]|0)+204>>2]=0;continue e}if((t[a>>2]|0)==0?(Li(t[f>>2]|0,62,0,0,0,1)|0)<0:0)break e;if(t[(t[f>>2]|0)+68>>2]|0){t[h+4>>2]=(t[(t[(t[f>>2]|0)+36>>2]|0)+36>>2]|0)+((t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)-(t[(t[(t[f>>2]|0)+36>>2]|0)+12>>2]|0));t[h+8>>2]=t[(t[(t[f>>2]|0)+36>>2]|0)+28>>2]}t[d>>2]=HN(t[f>>2]|0)|0;t[w>>2]=t[(t[f>>2]|0)+184>>2];if((t[d>>2]|0)==-1|(t[w>>2]|0)==0){if((u[t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]>>0]|0)!=62)continue e;Op(t[f>>2]|0);continue e}t[v>>2]=kN(t[w>>2]|0)|0;if(!(t[v>>2]|0))BN(t[f>>2]|0,801,94576,t[w>>2]|0,0);if((u[t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]>>0]|0)==47?(u[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+1>>0]|0)==62:0){g=(t[f>>2]|0)+200|0;t[g>>2]=(t[g>>2]|0)+2;g=(t[(t[f>>2]|0)+36>>2]|0)+16|0;t[g>>2]=(t[g>>2]|0)+2;g=(t[(t[f>>2]|0)+36>>2]|0)+32|0;t[g>>2]=(t[g>>2]|0)+2;do if(t[t[f>>2]>>2]|0){if(!(t[(t[t[f>>2]>>2]|0)+60>>2]|0))break;EAi[t[(t[t[f>>2]>>2]|0)+60>>2]&511](t[(t[f>>2]|0)+4>>2]|0,t[w>>2]|0)}while(0);xN(t[f>>2]|0)|0;t[(t[f>>2]|0)+172>>2]=7;continue e}g=t[f>>2]|0;if((u[t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]>>0]|0)!=62){BN(g,73,94592,t[w>>2]|0,0);if(Xl(t[w>>2]|0,t[(t[f>>2]|0)+184>>2]|0)|0){nE(t[f>>2]|0)|0;xN(t[f>>2]|0)|0}if(t[(t[f>>2]|0)+68>>2]|0)Di(t[f>>2]|0,h)|0;t[(t[f>>2]|0)+172>>2]=7;continue e}Op(g);if((t[v>>2]|0)!=0?(n[(t[v>>2]|0)+7>>0]|0)!=0:0){do if(t[t[f>>2]>>2]|0){if(!(t[(t[t[f>>2]>>2]|0)+60>>2]|0))break;EAi[t[(t[t[f>>2]>>2]|0)+60>>2]&511](t[(t[f>>2]|0)+4>>2]|0,t[w>>2]|0)}while(0);xN(t[f>>2]|0)|0}if(t[(t[f>>2]|0)+68>>2]|0)Di(t[f>>2]|0,h)|0;t[(t[f>>2]|0)+172>>2]=7;continue e;break}case 0:{n[b>>0]=n[t[(t[c>>2]|0)+16>>2]>>0]|0;do if((u[b>>0]|0)!=32){if(9<=(u[b>>0]|0)?(u[b>>0]|0)<=10:0){y=20;break}if((u[b>>0]|0)==13)y=20}else y=20;while(0);do if((y|0)==20){y=0;jN(t[f>>2]|0)|0;g=t[c>>2]|0;if(!(t[t[c>>2]>>2]|0)){t[l>>2]=(t[g+24>>2]|0)-((t[(t[c>>2]|0)+16>>2]|0)-(t[(t[c>>2]|0)+12>>2]|0));break}else{i=Ts(t[(t[g>>2]|0)+16>>2]|0)|0;t[l>>2]=i-((t[(t[c>>2]|0)+16>>2]|0)-(t[(t[c>>2]|0)+12>>2]|0));break}}while(0);if((t[t[f>>2]>>2]|0)!=0?(t[(t[t[f>>2]>>2]|0)+44>>2]|0)!=0:0)EAi[t[(t[t[f>>2]>>2]|0)+44>>2]&511](t[(t[f>>2]|0)+4>>2]|0,136080);if(((t[t[f>>2]>>2]|0)!=0?(t[(t[t[f>>2]>>2]|0)+48>>2]|0)!=0:0)?(t[(t[f>>2]|0)+212>>2]|0)==0:0)pAi[t[(t[t[f>>2]>>2]|0)+48>>2]&511](t[(t[f>>2]|0)+4>>2]|0);n[b>>0]=n[t[(t[c>>2]|0)+16>>2]>>0]|0;n[k>>0]=n[(t[(t[c>>2]|0)+16>>2]|0)+1>>0]|0;if(((((((((u[b>>0]|0)==60?(u[k>>0]|0)==33:0)?(Pq(u[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+2>>0]|0)|0)==68:0)?(Pq(u[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+3>>0]|0)|0)==79:0)?(Pq(u[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+4>>0]|0)|0)==67:0)?(Pq(u[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+5>>0]|0)|0)==84:0)?(Pq(u[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+6>>0]|0)|0)==89:0)?(Pq(u[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+7>>0]|0)|0)==80:0)?(Pq(u[(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)+8>>0]|0)|0)==69:0){if((t[a>>2]|0)==0?(Li(t[f>>2]|0,62,0,0,0,1)|0)<0:0)break e;YN(t[f>>2]|0);t[(t[f>>2]|0)+172>>2]=4;continue e}t[(t[f>>2]|0)+172>>2]=1;continue e;break}case 14:{i=t[c>>2]|0;if(!(t[t[c>>2]>>2]|0))t[l>>2]=(t[i+24>>2]|0)-((t[(t[c>>2]|0)+16>>2]|0)-(t[(t[c>>2]|0)+12>>2]|0));else{g=Ts(t[(t[i>>2]|0)+16>>2]|0)|0;t[l>>2]=g-((t[(t[c>>2]|0)+16>>2]|0)-(t[(t[c>>2]|0)+12>>2]|0))}if((t[l>>2]|0)<1)break e;n[b>>0]=n[t[(t[c>>2]|0)+16>>2]>>0]|0;if((u[b>>0]|0)==32){y=105;break e}if(9<=(u[b>>0]|0)?(u[b>>0]|0)<=10:0){y=105;break e}if((u[b>>0]|0)==13){y=105;break e}if((t[l>>2]|0)<2)break e;n[k>>0]=n[(t[(t[c>>2]|0)+16>>2]|0)+1>>0]|0;if((((u[b>>0]|0)==60?(u[k>>0]|0)==33:0)?(u[(t[(t[c>>2]|0)+16>>2]|0)+2>>0]|0)==45:0)?(u[(t[(t[c>>2]|0)+16>>2]|0)+3>>0]|0)==45:0){if((t[a>>2]|0)==0?(Li(t[f>>2]|0,45,45,62,1,1)|0)<0:0)break e;VN(t[f>>2]|0);t[(t[f>>2]|0)+172>>2]=14;continue e}if((u[b>>0]|0)!=60){y=119;break e}if((u[k>>0]|0)!=63){y=119;break e}if((t[a>>2]|0)==0?(Li(t[f>>2]|0,62,0,0,0,1)|0)<0:0)break e;qN(t[f>>2]|0);t[(t[f>>2]|0)+172>>2]=14;continue e;break}case 4:{jN(t[f>>2]|0)|0;g=t[c>>2]|0;if(!(t[t[c>>2]>>2]|0))t[l>>2]=(t[g+24>>2]|0)-((t[(t[c>>2]|0)+16>>2]|0)-(t[(t[c>>2]|0)+12>>2]|0));else{i=Ts(t[(t[g>>2]|0)+16>>2]|0)|0;t[l>>2]=i-((t[(t[c>>2]|0)+16>>2]|0)-(t[(t[c>>2]|0)+12>>2]|0))}if((t[l>>2]|0)<2)break e;n[b>>0]=n[t[(t[c>>2]|0)+16>>2]>>0]|0;n[k>>0]=n[(t[(t[c>>2]|0)+16>>2]|0)+1>>0]|0;if((((u[b>>0]|0)==60?(u[k>>0]|0)==33:0)?(u[(t[(t[c>>2]|0)+16>>2]|0)+2>>0]|0)==45:0)?(u[(t[(t[c>>2]|0)+16>>2]|0)+3>>0]|0)==45:0){if((t[a>>2]|0)==0?(Li(t[f>>2]|0,45,45,62,1,1)|0)<0:0)break e;VN(t[f>>2]|0);t[(t[f>>2]|0)+172>>2]=4;continue e}if((u[b>>0]|0)==60?(u[k>>0]|0)==63:0){if((t[a>>2]|0)==0?(Li(t[f>>2]|0,62,0,0,0,1)|0)<0:0)break e;qN(t[f>>2]|0);t[(t[f>>2]|0)+172>>2]=4;continue e}if((u[b>>0]|0)==60?(u[k>>0]|0)==33&(t[l>>2]|0)<4:0)break e;t[(t[f>>2]|0)+172>>2]=6;continue e;break}case 5:{BN(t[f>>2]|0,1,95184,0,0);t[(t[f>>2]|0)+172>>2]=7;t[(t[f>>2]|0)+204>>2]=0;continue e;break}case 2:{BN(t[f>>2]|0,1,95224,0,0);t[(t[f>>2]|0)+172>>2]=7;t[(t[f>>2]|0)+204>>2]=0;continue e;break}case 10:{BN(t[f>>2]|0,1,95264,0,0);t[(t[f>>2]|0)+172>>2]=7;t[(t[f>>2]|0)+204>>2]=0;continue e;break}case 11:{BN(t[f>>2]|0,1,95312,0,0);t[(t[f>>2]|0)+172>>2]=7;t[(t[f>>2]|0)+204>>2]=0;continue e;break}case 12:{BN(t[f>>2]|0,1,95360,0,0);t[(t[f>>2]|0)+172>>2]=6;t[(t[f>>2]|0)+204>>2]=0;continue e;break}case 13:{BN(t[f>>2]|0,1,95408,0,0);t[(t[f>>2]|0)+172>>2]=7;t[(t[f>>2]|0)+204>>2]=0;continue e;break}case 15:{BN(t[f>>2]|0,1,95472,0,0);t[(t[f>>2]|0)+172>>2]=7;t[(t[f>>2]|0)+204>>2]=0;continue e;break}case 16:{BN(t[f>>2]|0,1,95528,0,0);t[(t[f>>2]|0)+172>>2]=7;t[(t[f>>2]|0)+204>>2]=0;continue e;break}case-1:{break e;break}default:continue e}while(0)}do if((y|0)==105)Ai(t[f>>2]|0);else if((y|0)==119){if((u[b>>0]|0)==60?(u[k>>0]|0)==33&(t[l>>2]|0)<4:0)break;t[(t[f>>2]|0)+84>>2]=5;t[(t[f>>2]|0)+12>>2]=0;t[(t[f>>2]|0)+172>>2]=-1;if((t[t[f>>2]>>2]|0)!=0?(t[(t[t[f>>2]>>2]|0)+52>>2]|0)!=0:0)pAi[t[(t[t[f>>2]>>2]|0)+52>>2]&511](t[(t[f>>2]|0)+4>>2]|0)}while(0);if(((((t[l>>2]|0)==0&(t[a>>2]|0)!=0?(UN(t[f>>2]|0),(t[(t[f>>2]|0)+188>>2]|0)==0):0)?(t[(t[f>>2]|0)+172>>2]|0)!=-1:0)?(t[(t[f>>2]|0)+172>>2]=-1,(t[t[f>>2]>>2]|0)!=0):0)?(t[(t[t[f>>2]>>2]|0)+52>>2]|0)!=0:0)pAi[t[(t[t[f>>2]>>2]|0)+52>>2]&511](t[(t[f>>2]|0)+4>>2]|0);if(t[(t[f>>2]|0)+360>>2]&4){F=t[o>>2]|0;s=r;return F|0}if(!(t[(t[f>>2]|0)+8>>2]|0)){F=t[o>>2]|0;s=r;return F|0}if(((t[a>>2]|0)==0?(t[(t[f>>2]|0)+172>>2]|0)!=-1:0)?(t[(t[f>>2]|0)+172>>2]|0)!=14:0){F=t[o>>2]|0;s=r;return F|0}t[S>>2]=Qg(t[(t[f>>2]|0)+8>>2]|0)|0;if(t[S>>2]|0){F=t[o>>2]|0;s=r;return F|0}S=$g(t[(t[f>>2]|0)+8>>2]|0,94240,94296,94248)|0;t[(t[(t[f>>2]|0)+8>>2]|0)+44>>2]=S;F=t[o>>2]|0;s=r;return F|0}function KN(e){e=e|0;var i=0,r=0,n=0,f=0,u=0;i=s;s=s+16|0;r=i+8|0;n=i+4|0;f=i;t[n>>2]=e;t[f>>2]=gAi[t[135744>>2]&511](60)|0;if(!(t[f>>2]|0)){CN(t[n>>2]|0,94952);t[r>>2]=0;u=t[r>>2]|0;s=i;return u|0}else{n=(t[f>>2]|0)+0|0;e=n+60|0;do{t[n>>2]=0;n=n+4|0}while((n|0)<(e|0));t[(t[f>>2]|0)+4>>2]=0;t[(t[f>>2]|0)+8>>2]=0;t[(t[f>>2]|0)+12>>2]=0;t[(t[f>>2]|0)+16>>2]=0;t[t[f>>2]>>2]=0;t[(t[f>>2]|0)+28>>2]=1;t[(t[f>>2]|0)+32>>2]=1;t[t[f>>2]>>2]=0;t[(t[f>>2]|0)+40>>2]=0;t[(t[f>>2]|0)+48>>2]=0;t[(t[f>>2]|0)+36>>2]=0;t[(t[f>>2]|0)+24>>2]=0;t[r>>2]=t[f>>2];u=t[r>>2]|0;s=i;return u|0}return 0}function XN(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,a=0;r=s;s=s+16|0;n=r+8|0;f=r+4|0;a=r;t[n>>2]=e;t[f>>2]=i;if(!(t[f>>2]|0)){s=r;return}t[a>>2]=ns(t[f>>2]|0,94816)|0;if(t[a>>2]|0)t[a>>2]=(t[a>>2]|0)+7;e:do if(t[a>>2]|0){do if((u[t[a>>2]>>0]|0|0)!=32){if(9<=(u[t[a>>2]>>0]|0|0)?(u[t[a>>2]>>0]|0|0)<=10:0)break;if((u[t[a>>2]>>0]|0|0)!=13)break e}while(0);t[a>>2]=ns(t[f>>2]|0,94824)|0}while(0);if(!(t[a>>2]|0)){s=r;return}if((u[t[a>>2]>>0]|0|0)!=61){s=r;return}t[a>>2]=(t[a>>2]|0)+1;Bi(t[n>>2]|0,t[a>>2]|0);s=r;return}function ZN(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;var u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0;u=s;s=s+32|0;a=u+24|0;o=u+20|0;c=u+16|0;l=u+12|0;b=u+8|0;k=u+4|0;h=u;t[a>>2]=e;t[o>>2]=i;t[c>>2]=r;t[l>>2]=n;t[b>>2]=f;NN(t[a>>2]|0,t[l>>2]|0)|0;t[(t[a>>2]|0)+32>>2]=1;if((t[c>>2]|0)!=0?(t[h>>2]=V_(t[c>>2]|0)|0,(t[h>>2]|0)!=0):0){Lp(t[a>>2]|0,t[h>>2]|0)|0;if(t[(t[(t[a>>2]|0)+36>>2]|0)+44>>2]|0)pAi[t[135736>>2]&511](t[(t[(t[a>>2]|0)+36>>2]|0)+44>>2]|0);h=Yl(t[c>>2]|0)|0;t[(t[(t[a>>2]|0)+36>>2]|0)+44>>2]=h}if(((t[o>>2]|0)!=0?(t[(t[a>>2]|0)+36>>2]|0)!=0:0)?(t[(t[(t[a>>2]|0)+36>>2]|0)+4>>2]|0)==0:0){h=Yl(t[o>>2]|0)|0;t[(t[(t[a>>2]|0)+36>>2]|0)+4>>2]=h}EN(t[a>>2]|0)|0;t[k>>2]=t[(t[a>>2]|0)+8>>2];t[(t[a>>2]|0)+8>>2]=0;if(t[b>>2]|0){w=t[k>>2]|0;s=u;return w|0}if(((t[k>>2]|0)!=0?(t[(t[a>>2]|0)+364>>2]|0)!=0:0)?(t[(t[k>>2]|0)+80>>2]|0)==(t[(t[a>>2]|0)+296>>2]|0):0)t[(t[a>>2]|0)+296>>2]=0;Up(t[a>>2]|0);w=t[k>>2]|0;s=u;return w|0}function JN(e){e=e|0;var i=0,r=0,n=0,f=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0;i=s;s=s+32|0;r=i+20|0;n=i+16|0;f=i+12|0;a=i+8|0;o=i+4|0;c=i;t[n>>2]=e;t[f>>2]=0;t[c>>2]=0;if((t[(t[n>>2]|0)+292>>2]|0)==0?((t[(t[(t[n>>2]|0)+36>>2]|0)+20>>2]|0)-(t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]|0)|0)<250:0)yp(t[(t[n>>2]|0)+36>>2]|0,250)|0;t[o>>2]=Ni(t[n>>2]|0,a)|0;e:do if(!((t[o>>2]|0)==32|(t[o>>2]|0)==62|(t[o>>2]|0)==47)){e=t[o>>2]|0;if((t[o>>2]|0)<256){if(((!(65<=(e|0)&(t[o>>2]|0)<=90)?!(97<=(t[o>>2]|0)&(t[o>>2]|0)<=122):0)?!(192<=(t[o>>2]|0)&(t[o>>2]|0)<=214):0)?!(216<=(t[o>>2]|0)&(t[o>>2]|0)<=246|248<=(t[o>>2]|0)):0)l=11}else if(!(dj(e,199744)|0))l=11;do if((l|0)==11){e=t[o>>2]|0;if((t[o>>2]|0)<256)if((e|0)!=95&(t[o>>2]|0)!=58)break e;else break;if(!(19968<=(e|0)&(t[o>>2]|0)<=40869|(t[o>>2]|0)==12295)?(12321<=(t[o>>2]|0)&(t[o>>2]|0)<=12329^1)&(t[o>>2]|0)!=95&(t[o>>2]|0)!=58:0)break e}while(0);i:while(1){if(!((t[o>>2]|0)!=32&(t[o>>2]|0)!=62&(t[o>>2]|0)!=47))break;e=t[o>>2]|0;if((t[o>>2]|0)<256){if(((!(65<=(e|0)&(t[o>>2]|0)<=90)?!(97<=(t[o>>2]|0)&(t[o>>2]|0)<=122):0)?!(192<=(t[o>>2]|0)&(t[o>>2]|0)<=214):0)?!(216<=(t[o>>2]|0)&(t[o>>2]|0)<=246|248<=(t[o>>2]|0)):0)l=23}else if(!(dj(e,199744)|0))l=23;do if((l|0)==23){l=0;if((t[o>>2]|0)>=256){if(19968<=(t[o>>2]|0)&(t[o>>2]|0)<=40869|(t[o>>2]|0)==12295)break;if(12321<=(t[o>>2]|0)&(t[o>>2]|0)<=12329)break}e=t[o>>2]|0;if((t[o>>2]|0)<256){if(48<=(e|0)&(t[o>>2]|0)<=57|(t[o>>2]|0)==46|(t[o>>2]|0)==45|(t[o>>2]|0)==95|(t[o>>2]|0)==58)break}else{b=(dj(e,200216)|0)!=0;if(b|(t[o>>2]|0)==46|(t[o>>2]|0)==45|(t[o>>2]|0)==95|(t[o>>2]|0)==58)break}if((t[o>>2]|0)>=256?(dj(t[o>>2]|0,200144)|0)!=0:0)break;b=t[o>>2]|0;if((t[o>>2]|0)<256)k=(b|0)==183&1;else k=dj(b,200272)|0;if(!k)break i}while(0);b=t[c>>2]|0;t[c>>2]=b+1;if(((b|0)>100?(t[c>>2]=0,(t[(t[n>>2]|0)+292>>2]|0)==0):0)?((t[(t[(t[n>>2]|0)+36>>2]|0)+20>>2]|0)-(t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]|0)|0)<250:0)yp(t[(t[n>>2]|0)+36>>2]|0,250)|0;t[f>>2]=(t[f>>2]|0)+(t[a>>2]|0);b=t[(t[n>>2]|0)+36>>2]|0;if((u[t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==10){e=b+28|0;t[e>>2]=(t[e>>2]|0)+1;t[(t[(t[n>>2]|0)+36>>2]|0)+32>>2]=1}else{e=b+32|0;t[e>>2]=(t[e>>2]|0)+1}t[(t[n>>2]|0)+176>>2]=0;e=(t[(t[n>>2]|0)+36>>2]|0)+16|0;t[e>>2]=(t[e>>2]|0)+(t[a>>2]|0);e=(t[n>>2]|0)+200|0;t[e>>2]=(t[e>>2]|0)+1;t[o>>2]=Ni(t[n>>2]|0,a)|0}t[r>>2]=kz(t[(t[n>>2]|0)+296>>2]|0,(t[(t[(t[n>>2]|0)+36>>2]|0)+16>>2]|0)+(0-(t[f>>2]|0))|0,t[f>>2]|0)|0;h=t[r>>2]|0;s=i;return h|0}while(0);t[r>>2]=0;h=t[r>>2]|0;s=i;return h|0}function QN(e){e=e|0;var i=0,r=0,f=0,a=0,o=0,c=0,l=0,b=0,k=0;i=s;s=s+112|0;r=i+8|0;f=i+4|0;a=i;o=i+12|0;t[f>>2]=e;t[a>>2]=0;if(!(65<=(u[t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)?(u[t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)<=90:0))c=3;do if((c|0)==3){if(97<=(u[t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)?(u[t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)<=122:0)break;if(((u[t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)!=95?(u[t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)!=58:0)?(u[t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)!=46:0){t[r>>2]=0;l=t[r>>2]|0;s=i;return l|0}}while(0);while(1){do if((t[a>>2]|0)<100){if(65<=(u[t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)?(u[t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)<=90:0){b=1;break}if(97<=(u[t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)?(u[t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)<=122:0){b=1;break}if(48<=(u[t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)?(u[t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)<=57:0){b=1;break}if(((u[t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)!=58?(u[t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)!=45:0)?(u[t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)!=95:0)b=(u[t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==46;else b=1}else b=0;while(0);k=t[f>>2]|0;if(!b)break;if((u[t[(t[k+36>>2]|0)+16>>2]>>0]|0|0)>=65?(u[t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)<=90:0)n[o+(t[a>>2]|0)>>0]=(u[t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]>>0]|0)+32;else n[o+(t[a>>2]|0)>>0]=u[t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]>>0]|0;t[a>>2]=(t[a>>2]|0)+1;Op(t[f>>2]|0)}t[r>>2]=kz(t[k+296>>2]|0,o,t[a>>2]|0)|0;l=t[r>>2]|0;s=i;return l|0}function $N(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0;r=s;s=s+16|0;n=r+4|0;f=r;t[n>>2]=e;t[f>>2]=i;while(1){if(!(t[f>>2]|0))break;if(!(t[(t[n>>2]|0)+184>>2]|0))break;if(!(DN(t[f>>2]|0,t[(t[n>>2]|0)+184>>2]|0)|0))break;if((t[t[n>>2]>>2]|0)!=0?(t[(t[t[n>>2]>>2]|0)+60>>2]|0)!=0:0)EAi[t[(t[t[n>>2]>>2]|0)+60>>2]&511](t[(t[n>>2]|0)+4>>2]|0,t[(t[n>>2]|0)+184>>2]|0);xN(t[n>>2]|0)|0}if(!(t[f>>2]|0)){UN(t[n>>2]|0);s=r;return}while(1){if(t[f>>2]|0){u=20;break}if(!(t[(t[n>>2]|0)+184>>2]|0)){u=20;break}if(((Xl(t[(t[n>>2]|0)+184>>2]|0,95656)|0)==0?(Xl(t[(t[n>>2]|0)+184>>2]|0,95648)|0)==0:0)?(Xl(t[(t[n>>2]|0)+184>>2]|0,94240)|0)==0:0){u=20;break}if((t[t[n>>2]>>2]|0)!=0?(t[(t[t[n>>2]>>2]|0)+60>>2]|0)!=0:0)EAi[t[(t[t[n>>2]>>2]|0)+60>>2]&511](t[(t[n>>2]|0)+4>>2]|0,t[(t[n>>2]|0)+184>>2]|0);xN(t[n>>2]|0)|0}if((u|0)==20){s=r;return}}function eT(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0;r=s;s=s+16|0;n=r+8|0;f=r+4|0;u=r;t[n>>2]=e;t[f>>2]=i;if(!((t[23702]|0)!=0?(t[(t[n>>2]|0)+360>>2]&8192|0)==0:0)){s=r;return}if(Xl(t[f>>2]|0,94240)|0){s=r;return}if(((t[(t[n>>2]|0)+188>>2]|0)<=0?(nT(t[n>>2]|0,94240)|0,(t[t[n>>2]>>2]|0)!=0):0)?(t[(t[t[n>>2]>>2]|0)+56>>2]|0)!=0:0)yAi[t[(t[t[n>>2]>>2]|0)+56>>2]&511](t[(t[n>>2]|0)+4>>2]|0,94240,0);if(Xl(t[f>>2]|0,95648)|0){s=r;return}if(Xl(t[f>>2]|0,95656)|0){s=r;return}do if((t[(t[n>>2]|0)+188>>2]|0)<=1){if((((((Xl(t[f>>2]|0,94992)|0)==0?(Xl(t[f>>2]|0,95e3)|0)==0:0)?(Xl(t[f>>2]|0,96200)|0)==0:0)?(Xl(t[f>>2]|0,96208)|0)==0:0)?(Xl(t[f>>2]|0,96216)|0)==0:0)?(Xl(t[f>>2]|0,96224)|0)==0:0)break;if((t[(t[n>>2]|0)+32>>2]|0)>=3){s=r;return}nT(t[n>>2]|0,95656)|0;if(!(t[t[n>>2]>>2]|0)){s=r;return}if(!(t[(t[t[n>>2]>>2]|0)+56>>2]|0)){s=r;return}yAi[t[(t[t[n>>2]>>2]|0)+56>>2]&511](t[(t[n>>2]|0)+4>>2]|0,95656,0);s=r;return}while(0);if(Xl(t[f>>2]|0,96232)|0){s=r;return}if(Xl(t[f>>2]|0,96248)|0){s=r;return}if(Xl(t[f>>2]|0,96256)|0){s=r;return}if((t[(t[n>>2]|0)+32>>2]|0)>=10){s=r;return}t[u>>2]=0;while(1){if((t[u>>2]|0)>=(t[(t[n>>2]|0)+188>>2]|0)){a=29;break}if(Xl(t[(t[(t[n>>2]|0)+196>>2]|0)+(t[u>>2]<<2)>>2]|0,95648)|0){a=32;break}if(Xl(t[(t[(t[n>>2]|0)+196>>2]|0)+(t[u>>2]<<2)>>2]|0,95656)|0){a=32;break}t[u>>2]=(t[u>>2]|0)+1}if((a|0)==29){nT(t[n>>2]|0,95648)|0;if(!(t[t[n>>2]>>2]|0)){s=r;return}if(!(t[(t[t[n>>2]>>2]|0)+56>>2]|0)){s=r;return}yAi[t[(t[t[n>>2]>>2]|0)+56>>2]&511](t[(t[n>>2]|0)+4>>2]|0,95648,0);s=r;return}else if((a|0)==32){s=r;return}}function iT(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,a=0,o=0,c=0,l=0;r=s;s=s+32|0;n=r+16|0;f=r+12|0;a=r+8|0;o=r+4|0;c=r;t[f>>2]=e;t[a>>2]=i;t[c>>2]=0;t[t[a>>2]>>2]=0;t[o>>2]=QN(t[f>>2]|0)|0;i=t[f>>2]|0;if(!(t[o>>2]|0)){BN(i,68,97912,0,0);t[n>>2]=0;l=t[n>>2]|0;s=r;return l|0}jN(i)|0;if((u[t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==61){Op(t[f>>2]|0);jN(t[f>>2]|0)|0;t[c>>2]=Ii(t[f>>2]|0)|0}t[t[a>>2]>>2]=t[c>>2];t[n>>2]=t[o>>2];l=t[n>>2]|0;s=r;return l|0}function rT(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0;r=s;s=s+32|0;n=r+24|0;f=r+20|0;u=r+16|0;a=r+12|0;o=r+8|0;c=r+4|0;l=r;t[n>>2]=e;t[f>>2]=i;t[c>>2]=0;t[l>>2]=0;if((t[n>>2]|0)==0|(t[f>>2]|0)==0){s=r;return}t[u>>2]=0;i=t[u>>2]|0;t[u>>2]=i+1;t[a>>2]=t[(t[f>>2]|0)+(i<<2)>>2];while(1){if(!(t[a>>2]|0))break;i=t[u>>2]|0;t[u>>2]=i+1;t[o>>2]=t[(t[f>>2]|0)+(i<<2)>>2];if(((t[o>>2]|0)!=0?(Ql(t[a>>2]|0,97872)|0)==0:0)?(Ql(t[o>>2]|0,97888)|0)==0:0)t[c>>2]=1;else b=8;do if((b|0)==8){b=0;if((t[o>>2]|0)!=0?(Ql(t[a>>2]|0,94816)|0)==0:0){Bi(t[n>>2]|0,t[o>>2]|0);break}if((t[o>>2]|0)!=0?(Ql(t[a>>2]|0,97904)|0)==0:0)t[l>>2]=t[o>>2]}while(0);i=t[u>>2]|0;t[u>>2]=i+1;t[a>>2]=t[(t[f>>2]|0)+(i<<2)>>2]}if(!((t[c>>2]|0)!=0&(t[l>>2]|0)!=0)){s=r;return}XN(t[n>>2]|0,t[l>>2]|0);s=r;return}function nT(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0;r=s;s=s+16|0;n=r+8|0;f=r+4|0;u=r;t[f>>2]=e;t[u>>2]=i;if((t[(t[f>>2]|0)+32>>2]|0)<3?(Xl(t[u>>2]|0,95656)|0)!=0:0)t[(t[f>>2]|0)+32>>2]=3;if((t[(t[f>>2]|0)+32>>2]|0)<10?(Xl(t[u>>2]|0,95648)|0)!=0:0)t[(t[f>>2]|0)+32>>2]=10;if((t[(t[f>>2]|0)+188>>2]|0)>=(t[(t[f>>2]|0)+192>>2]|0)?(i=(t[f>>2]|0)+192|0,t[i>>2]=t[i>>2]<<1,i=MAi[t[135760>>2]&511](t[(t[f>>2]|0)+196>>2]|0,t[(t[f>>2]|0)+192>>2]<<2)|0,t[(t[f>>2]|0)+196>>2]=i,(t[(t[f>>2]|0)+196>>2]|0)==0):0){CN(t[f>>2]|0,0);t[n>>2]=0;a=t[n>>2]|0;s=r;return a|0}t[(t[(t[f>>2]|0)+196>>2]|0)+(t[(t[f>>2]|0)+188>>2]<<2)>>2]=t[u>>2];t[(t[f>>2]|0)+184>>2]=t[u>>2];u=(t[f>>2]|0)+188|0;
	f=t[u>>2]|0;t[u>>2]=f+1;t[n>>2]=f;a=t[n>>2]|0;s=r;return a|0}function fT(e){e=e|0;var i=0,r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0,S=0,g=0,y=0,F=0,O=0;i=s;s=s+80|0;r=i+64|0;n=i+60|0;f=i+56|0;u=i+52|0;a=i+48|0;o=i+44|0;c=i+40|0;l=i+36|0;b=i+32|0;k=i+28|0;h=i+24|0;w=i+20|0;d=i+16|0;v=i+12|0;m=i+8|0;_=i+4|0;p=i;t[n>>2]=e;t[f>>2]=t[(t[(t[n>>2]|0)+108>>2]|0)+56>>2];e:while(1){if(!(t[f>>2]|0)){E=48;break}i:do if(((t[(t[f>>2]|0)+20>>2]|0)==24?(t[(t[f>>2]|0)+32>>2]|0)!=0:0)?(t[(t[(t[f>>2]|0)+32>>2]|0)+4>>2]|0)!=0:0){t[d>>2]=0;t[b>>2]=t[(t[(t[(t[f>>2]|0)+16>>2]|0)+4>>2]|0)+32>>2];t[u>>2]=t[(t[(t[n>>2]|0)+108>>2]|0)+52>>2];while(1){if(!(t[u>>2]|0))break;if((t[(t[(t[(t[(t[f>>2]|0)+16>>2]|0)+4>>2]|0)+36>>2]|0)+4>>2]|0)==(t[(t[u>>2]|0)+4>>2]|0))break;t[u>>2]=t[t[u>>2]>>2]}if((t[u>>2]|0)!=0?(t[(t[u>>2]|0)+20>>2]|0)!=0:0)S=(t[(t[(t[u>>2]|0)+20>>2]|0)+4>>2]|0)!=0;else S=0;t[k>>2]=S?1:0;t[a>>2]=0;while(1){if((t[a>>2]|0)>=(t[(t[(t[f>>2]|0)+32>>2]|0)+4>>2]|0))break i;t[l>>2]=0;t[d>>2]=t[(t[t[(t[f>>2]|0)+32>>2]>>2]|0)+(t[a>>2]<<2)>>2];r:do if(t[u>>2]|0){t[h>>2]=t[(t[d>>2]|0)+4>>2];t[o>>2]=0;while(1){if((t[o>>2]|0)>=(t[(t[u>>2]|0)+12>>2]|0))break;t[w>>2]=t[(t[(t[(t[u>>2]|0)+8>>2]|0)+(t[o>>2]<<2)>>2]|0)+4>>2];t[c>>2]=0;while(1){if((t[c>>2]|0)>=(t[b>>2]|0))break;t[l>>2]=Od(t[(t[(t[w>>2]|0)+(t[c>>2]<<2)>>2]|0)+4>>2]|0,t[(t[(t[h>>2]|0)+(t[c>>2]<<2)>>2]|0)+4>>2]|0)|0;if(!(t[l>>2]|0))break;if((t[l>>2]|0)==-1){E=22;break e}t[c>>2]=(t[c>>2]|0)+1}if((t[l>>2]|0)==1)break;t[o>>2]=(t[o>>2]|0)+1}if((t[l>>2]|0)==0&(t[k>>2]|0)!=0){t[o>>2]=0;while(1){if((t[o>>2]|0)>=(t[(t[(t[u>>2]|0)+20>>2]|0)+4>>2]|0))break r;t[w>>2]=t[(t[(t[t[(t[u>>2]|0)+20>>2]>>2]|0)+(t[o>>2]<<2)>>2]|0)+4>>2];t[c>>2]=0;while(1){if((t[c>>2]|0)>=(t[b>>2]|0))break;t[l>>2]=Od(t[(t[(t[w>>2]|0)+(t[c>>2]<<2)>>2]|0)+4>>2]|0,t[(t[(t[h>>2]|0)+(t[c>>2]<<2)>>2]|0)+4>>2]|0)|0;if(!(t[l>>2]|0))break;if((t[l>>2]|0)==-1){E=33;break e}t[c>>2]=(t[c>>2]|0)+1}if((t[l>>2]|0)==1)break;t[o>>2]=(t[o>>2]|0)+1}t[v>>2]=0;t[m>>2]=0;e=t[n>>2]|0;g=t[d>>2]|0;y=t[(t[(t[f>>2]|0)+16>>2]|0)+4>>2]|0;F=UL(t[n>>2]|0,v,t[(t[d>>2]|0)+4>>2]|0,t[b>>2]|0)|0;YL(e,1877,g,y,142400,F,Rd(m,t[(t[(t[f>>2]|0)+16>>2]|0)+4>>2]|0)|0);if(t[v>>2]|0){pAi[t[135736>>2]&511](t[v>>2]|0);t[v>>2]=0}if(t[m>>2]|0){pAi[t[135736>>2]&511](t[m>>2]|0);t[m>>2]=0}}}while(0);if(!(t[l>>2]|0)){t[_>>2]=0;t[p>>2]=0;F=t[n>>2]|0;y=t[d>>2]|0;g=t[(t[(t[f>>2]|0)+16>>2]|0)+4>>2]|0;e=UL(t[n>>2]|0,_,t[(t[d>>2]|0)+4>>2]|0,t[b>>2]|0)|0;YL(F,1877,y,g,142464,e,Rd(p,t[(t[(t[f>>2]|0)+16>>2]|0)+4>>2]|0)|0);if(t[_>>2]|0){pAi[t[135736>>2]&511](t[_>>2]|0);t[_>>2]=0}if(t[p>>2]|0){pAi[t[135736>>2]&511](t[p>>2]|0);t[p>>2]=0}}t[a>>2]=(t[a>>2]|0)+1}}while(0);t[f>>2]=t[(t[f>>2]|0)+8>>2]}if((E|0)==22){t[r>>2]=-1;O=t[r>>2]|0;s=i;return O|0}else if((E|0)==33){t[r>>2]=-1;O=t[r>>2]|0;s=i;return O|0}else if((E|0)==48){t[r>>2]=0;O=t[r>>2]|0;s=i;return O|0}return 0}function tT(e){e=e|0;var i=0,r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0,S=0,g=0,y=0,F=0;i=s;s=s+80|0;r=i+64|0;n=i+60|0;f=i+56|0;u=i+52|0;a=i+48|0;o=i+44|0;c=i+40|0;l=i+36|0;b=i+32|0;k=i+28|0;h=i+24|0;w=i+20|0;d=i+16|0;v=i+12|0;m=i+8|0;_=i+4|0;p=i;t[n>>2]=e;t[a>>2]=0;t[c>>2]=0;t[v>>2]=0;t[f>>2]=t[(t[(t[n>>2]|0)+108>>2]|0)+52>>2];if(!(t[f>>2]|0)){t[r>>2]=0;E=t[r>>2]|0;s=i;return E|0}t[u>>2]=(t[(t[(t[n>>2]|0)+100>>2]|0)+((t[(t[n>>2]|0)+96>>2]|0)-1<<2)>>2]|0)+52;e:while(1){if(!(t[f>>2]|0)){S=87;break}if(!(t[(t[f>>2]|0)+12>>2]|0)){if((t[(t[f>>2]|0)+20>>2]|0)!=0?(t[(t[(t[f>>2]|0)+20>>2]|0)+4>>2]|0)!=0:0)S=8}else S=8;i:do if((S|0)==8){S=0;r:do if(!(t[(t[n>>2]|0)+188>>2]|0)){t[k>>2]=t[(t[n>>2]|0)+112>>2];while(1){g=t[k>>2]|0;if((t[(t[k>>2]|0)+4>>2]|0)==(t[(t[f>>2]|0)+4>>2]|0))break;t[k>>2]=t[g>>2];if(!(t[k>>2]|0))break r}if((t[g+8>>2]|0)==-1)break i;if((t[(t[k>>2]|0)+8>>2]|0)>=(t[(t[n>>2]|0)+96>>2]|0))break i}while(0);if(t[u>>2]|0)t[a>>2]=t[t[u>>2]>>2];while(1){if(!(t[a>>2]|0))break;if((t[(t[a>>2]|0)+4>>2]|0)==(t[(t[f>>2]|0)+4>>2]|0))break;t[a>>2]=t[t[a>>2]>>2]}if(!(t[a>>2]|0)){t[a>>2]=GL(t[(t[f>>2]|0)+4>>2]|0)|0;if(!(t[a>>2]|0))break e;do if(t[(t[f>>2]|0)+12>>2]|0){if(!(t[(t[n>>2]|0)+192>>2]|0)){t[(t[a>>2]|0)+8>>2]=t[(t[f>>2]|0)+8>>2];t[(t[f>>2]|0)+8>>2]=0;t[(t[a>>2]|0)+16>>2]=t[(t[f>>2]|0)+16>>2];t[(t[f>>2]|0)+16>>2]=0;t[(t[a>>2]|0)+12>>2]=t[(t[f>>2]|0)+12>>2];t[(t[f>>2]|0)+12>>2]=0;break}e=gAi[t[135744>>2]&511](t[(t[f>>2]|0)+12>>2]<<2)|0;t[(t[a>>2]|0)+8>>2]=e;if(!(t[(t[a>>2]|0)+8>>2]|0)){S=76;break e}t[(t[a>>2]|0)+16>>2]=t[(t[f>>2]|0)+12>>2];t[(t[a>>2]|0)+12>>2]=t[(t[f>>2]|0)+12>>2];YY(t[(t[a>>2]|0)+8>>2]|0,t[(t[f>>2]|0)+8>>2]|0,t[(t[f>>2]|0)+12>>2]<<2|0)|0}while(0);if(t[(t[f>>2]|0)+20>>2]|0){if(t[(t[a>>2]|0)+20>>2]|0)Wk(t[(t[a>>2]|0)+20>>2]|0);t[(t[a>>2]|0)+20>>2]=t[(t[f>>2]|0)+20>>2];t[(t[f>>2]|0)+20>>2]=0}if(!(t[u>>2]|0))break;if(!(t[t[u>>2]>>2]|0)){t[t[u>>2]>>2]=t[a>>2];break}else{t[t[a>>2]>>2]=t[t[u>>2]>>2];t[t[u>>2]>>2]=t[a>>2];break}}t[_>>2]=t[(t[a>>2]|0)+12>>2];if((t[(t[a>>2]|0)+20>>2]|0)!=0?(t[(t[(t[a>>2]|0)+20>>2]|0)+4>>2]|0)!=0:0){t[p>>2]=t[(t[(t[a>>2]|0)+20>>2]|0)+4>>2];t[l>>2]=t[t[(t[a>>2]|0)+20>>2]>>2]}else{t[l>>2]=0;t[p>>2]=0}t[b>>2]=t[(t[a>>2]|0)+8>>2];t[m>>2]=t[(t[(t[f>>2]|0)+4>>2]|0)+32>>2];t[h>>2]=0;while(1){if((t[h>>2]|0)>=(t[(t[f>>2]|0)+12>>2]|0))break i;t[o>>2]=t[(t[(t[f>>2]|0)+8>>2]|0)+(t[h>>2]<<2)>>2];do if(t[o>>2]|0){if(t[p>>2]|0){t[w>>2]=0;r:while(1){if((t[w>>2]|0)>=(t[p>>2]|0))break;n:do if((t[m>>2]|0)==1){t[v>>2]=Od(t[(t[t[(t[o>>2]|0)+4>>2]>>2]|0)+4>>2]|0,t[(t[t[(t[(t[l>>2]|0)+(t[w>>2]<<2)>>2]|0)+4>>2]>>2]|0)+4>>2]|0)|0;if((t[v>>2]|0)==-1)break e;if(t[v>>2]|0)break;t[w>>2]=(t[w>>2]|0)+1;continue r}else{t[c>>2]=t[(t[l>>2]|0)+(t[w>>2]<<2)>>2];t[d>>2]=0;while(1){if((t[d>>2]|0)>=(t[m>>2]|0))break n;t[v>>2]=Od(t[(t[(t[(t[o>>2]|0)+4>>2]|0)+(t[d>>2]<<2)>>2]|0)+4>>2]|0,t[(t[(t[(t[c>>2]|0)+4>>2]|0)+(t[d>>2]<<2)>>2]|0)+4>>2]|0)|0;if((t[v>>2]|0)==-1)break e;if(!(t[v>>2]|0))break n;t[d>>2]=(t[d>>2]|0)+1}}while(0);if((t[v>>2]|0)==1)break;t[w>>2]=(t[w>>2]|0)+1}if(!((t[_>>2]|0)!=0?(t[w>>2]|0)==(t[p>>2]|0):0))break}else if(!(t[_>>2]|0))break;t[w>>2]=0;r:while(1){if((t[w>>2]|0)>=(t[_>>2]|0))break;t[c>>2]=t[(t[b>>2]|0)+(t[w>>2]<<2)>>2];n:do if((t[m>>2]|0)==1){t[v>>2]=Od(t[(t[t[(t[o>>2]|0)+4>>2]>>2]|0)+4>>2]|0,t[(t[t[(t[c>>2]|0)+4>>2]>>2]|0)+4>>2]|0)|0;if((t[v>>2]|0)==-1)break e;if(!(t[v>>2]|0)){t[w>>2]=(t[w>>2]|0)+1;continue r}}else{t[d>>2]=0;while(1){if((t[d>>2]|0)>=(t[m>>2]|0))break n;t[v>>2]=Od(t[(t[(t[(t[o>>2]|0)+4>>2]|0)+(t[d>>2]<<2)>>2]|0)+4>>2]|0,t[(t[(t[(t[c>>2]|0)+4>>2]|0)+(t[d>>2]<<2)>>2]|0)+4>>2]|0)|0;if((t[v>>2]|0)==-1)break e;if(!(t[v>>2]|0))break n;t[d>>2]=(t[d>>2]|0)+1}}while(0);if((t[v>>2]|0)==1)break;t[w>>2]=(t[w>>2]|0)+1}if((t[w>>2]|0)!=(t[_>>2]|0)){t[_>>2]=(t[_>>2]|0)+-1;e=(t[a>>2]|0)+12|0;t[e>>2]=(t[e>>2]|0)+-1;t[(t[b>>2]|0)+(t[w>>2]<<2)>>2]=t[(t[b>>2]|0)+(t[_>>2]<<2)>>2];if((t[(t[a>>2]|0)+12>>2]|0)!=(t[_>>2]|0))t[(t[b>>2]|0)+(t[_>>2]<<2)>>2]=t[(t[b>>2]|0)+(t[(t[a>>2]|0)+12>>2]<<2)>>2];if((t[(t[a>>2]|0)+20>>2]|0)==0?(e=hh()|0,t[(t[a>>2]|0)+20>>2]=e,(t[(t[a>>2]|0)+20>>2]|0)==0):0)break e;Cd(t[(t[a>>2]|0)+20>>2]|0,t[c>>2]|0)|0;break}if(t[(t[a>>2]|0)+8>>2]|0){if((t[(t[a>>2]|0)+12>>2]|0)>=(t[(t[a>>2]|0)+16>>2]|0)?(e=(t[a>>2]|0)+16|0,t[e>>2]=t[e>>2]<<1,e=MAi[t[135760>>2]&511](t[(t[a>>2]|0)+8>>2]|0,t[(t[a>>2]|0)+16>>2]<<2)|0,t[(t[a>>2]|0)+8>>2]=e,(t[(t[a>>2]|0)+8>>2]|0)==0):0){S=68;break e}}else{e=gAi[t[135744>>2]&511](40)|0;t[(t[a>>2]|0)+8>>2]=e;if(!(t[(t[a>>2]|0)+8>>2]|0)){S=64;break e}t[(t[a>>2]|0)+16>>2]=1}t[b>>2]=t[(t[a>>2]|0)+8>>2];e=t[o>>2]|0;y=(t[a>>2]|0)+12|0;F=t[y>>2]|0;t[y>>2]=F+1;t[(t[b>>2]|0)+(F<<2)>>2]=e}while(0);t[h>>2]=(t[h>>2]|0)+1}}while(0);t[f>>2]=t[t[f>>2]>>2]}if((S|0)==64)kh(0,142168,0);else if((S|0)==68)kh(0,142208,0);else if((S|0)==76){kh(0,142256,0);_d(t[a>>2]|0)}else if((S|0)==87){t[r>>2]=0;E=t[r>>2]|0;s=i;return E|0}t[r>>2]=-1;E=t[r>>2]|0;s=i;return E|0}function uT(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0;r=s;s=s+16|0;n=r+12|0;f=r+8|0;u=r+4|0;a=r;t[f>>2]=e;t[u>>2]=i;t[a>>2]=Zk()|0;if(!(t[a>>2]|0)){t[n>>2]=0;o=t[n>>2]|0;s=r;return o|0}t[(t[a>>2]|0)+80>>2]=t[u>>2];sz(t[u>>2]|0)|0;if(t[f>>2]|0){i=kz(t[u>>2]|0,t[f>>2]|0,-1)|0;t[(t[a>>2]|0)+44>>2]=i}t[n>>2]=t[a>>2];o=t[n>>2]|0;s=r;return o|0}function aT(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0;r=s;s=s+16|0;n=r+8|0;f=r+4|0;u=r;t[n>>2]=e;t[f>>2]=i;t[u>>2]=gAi[t[135744>>2]&511](12)|0;if(!(t[u>>2]|0)){kh(t[f>>2]|0,141168,0);s=r;return}t[(t[u>>2]|0)+8>>2]=-1;t[(t[u>>2]|0)+4>>2]=t[n>>2];t[t[u>>2]>>2]=0;if(!(t[(t[f>>2]|0)+112>>2]|0))t[(t[f>>2]|0)+112>>2]=t[u>>2];else{t[t[u>>2]>>2]=t[(t[f>>2]|0)+112>>2];t[(t[f>>2]|0)+112>>2]=t[u>>2]}if(t[(t[f>>2]|0)+184>>2]|0){s=r;return}if((t[t[n>>2]>>2]|0)!=24){s=r;return}t[(t[f>>2]|0)+184>>2]=1;s=r;return}function oT(e){e=e|0;var i=0,r=0,n=0,f=0,u=0,a=0;i=s;s=s+32|0;r=i+16|0;n=i+12|0;f=i+8|0;u=i+4|0;a=i;t[r>>2]=e;while(1){if(!(t[r>>2]|0))break;t[n>>2]=t[(t[r>>2]|0)+8>>2];if(t[(t[r>>2]|0)+24>>2]|0){t[f>>2]=0;while(1){if((t[f>>2]|0)>=(t[(t[r>>2]|0)+28>>2]|0))break;if(t[(t[(t[r>>2]|0)+24>>2]|0)+(t[f>>2]<<2)>>2]|0)pAi[t[135736>>2]&511](t[(t[(t[r>>2]|0)+24>>2]|0)+(t[f>>2]<<2)>>2]|0);t[f>>2]=(t[f>>2]|0)+1}pAi[t[135736>>2]&511](t[(t[r>>2]|0)+24>>2]|0)}if(t[(t[r>>2]|0)+32>>2]|0){e:do if((t[(t[r>>2]|0)+20>>2]|0)==24){t[u>>2]=0;while(1){if((t[u>>2]|0)>=(t[(t[(t[r>>2]|0)+32>>2]|0)+4>>2]|0))break e;t[a>>2]=t[(t[t[(t[r>>2]|0)+32>>2]>>2]|0)+(t[u>>2]<<2)>>2];pAi[t[135736>>2]&511](t[(t[a>>2]|0)+4>>2]|0);pAi[t[135736>>2]&511](t[a>>2]|0);t[u>>2]=(t[u>>2]|0)+1}}while(0);Wk(t[(t[r>>2]|0)+32>>2]|0)}pAi[t[135736>>2]&511](t[r>>2]|0);t[r>>2]=t[n>>2]}s=i;return}function cT(e){e=e|0;var i=0,r=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if(t[t[r>>2]>>2]|0){pAi[t[135736>>2]&511](t[t[r>>2]>>2]|0);t[t[r>>2]>>2]=0}t[(t[r>>2]|0)+4>>2]=0;t[(t[r>>2]|0)+8>>2]=0;s=i;return}function lT(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i+4|0;n=i;t[n>>2]=e;do switch(t[n>>2]|0){case 18:{t[r>>2]=143832;break}case 17:{t[r>>2]=143776;break}case 24:{t[r>>2]=144e3;break}case 6:{t[r>>2]=143856;break}case 8:{t[r>>2]=143904;break}case 22:{t[r>>2]=143944;break}case 23:{t[r>>2]=143976;break}case 16:{t[r>>2]=143800;break}case 26:{t[r>>2]=143736;break}case 14:{t[r>>2]=143712;break}case 1:{t[r>>2]=143688;break}case 2e3:{t[r>>2]=144048;break}case 7:{t[r>>2]=143880;break}case 2001:{t[r>>2]=144088;break}case 4:{t[r>>2]=143688;break}case 25:{t[r>>2]=143928;break}case 5:{t[r>>2]=143664;break}case 2:{t[r>>2]=144032;break}case 15:{t[r>>2]=143752;break}default:t[r>>2]=144136}while(0);s=i;return t[r>>2]|0}function sT(e,i,r,n,f,u,a){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;u=u|0;a=a|0;var o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0;o=s;s=s+32|0;c=o+24|0;l=o+20|0;b=o+16|0;k=o+12|0;h=o+8|0;w=o+4|0;d=o;t[c>>2]=e;t[l>>2]=i;t[b>>2]=r;t[k>>2]=n;t[h>>2]=f;t[w>>2]=u;t[d>>2]=a;Ld(t[c>>2]|0,2,t[l>>2]|0,t[b>>2]|0,0,t[k>>2]|0,t[h>>2]|0,t[w>>2]|0,t[d>>2]|0,0);s=o;return}function bT(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0;n=s;s=s+48|0;f=n+32|0;u=n+28|0;a=n+24|0;o=n+20|0;c=n+16|0;l=n+12|0;b=n+8|0;k=n+4|0;h=n;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;t[b>>2]=0;t[h>>2]=0;if(t[t[a>>2]>>2]|0)pAi[t[135736>>2]&511](t[t[a>>2]>>2]|0);t[t[a>>2]>>2]=0;e:while(1){t[l>>2]=Ed(t[(t[o>>2]|0)+64>>2]|0)|0;t[c>>2]=t[(t[o>>2]|0)+68>>2];while(1){if(!(t[c>>2]|0))break;if((t[t[c>>2]>>2]|0)==1007){t[h>>2]=1;t[k>>2]=WL(t[(t[c>>2]|0)+32>>2]|0,t[l>>2]|0,b)|0;if((t[k>>2]|0)==-1)break e;if(!(t[t[a>>2]>>2]|0)){r=Yl(142568)|0;t[t[a>>2]>>2]=r}else{r=us(t[t[a>>2]>>2]|0,157648)|0;t[t[a>>2]>>2]=r}r=us(t[t[a>>2]>>2]|0,t[b>>2]|0)|0;t[t[a>>2]>>2]=r;r=us(t[t[a>>2]>>2]|0,142568)|0;t[t[a>>2]>>2]=r;if(t[b>>2]|0){pAi[t[135736>>2]&511](t[b>>2]|0);t[b>>2]=0}}t[c>>2]=t[(t[c>>2]|0)+4>>2]}if(t[h>>2]|0){w=20;break}t[o>>2]=t[(t[o>>2]|0)+64>>2];if(!(t[o>>2]|0)){w=20;break}if((t[t[o>>2]>>2]|0)==1){w=20;break}}if((w|0)==20){t[f>>2]=t[t[a>>2]>>2];d=t[f>>2]|0;s=n;return d|0}rh(t[u>>2]|0,157568,157600);if(t[t[a>>2]>>2]|0)pAi[t[135736>>2]&511](t[t[a>>2]>>2]|0);t[t[a>>2]>>2]=0;t[f>>2]=0;d=t[f>>2]|0;s=n;return d|0}function kT(e){e=e|0;var i=0,r=0,n=0,f=0;i=s;s=s+16|0;r=i+4|0;n=i;t[n>>2]=e;do switch(t[t[n>>2]>>2]|0){case 14:{t[r>>2]=t[(t[n>>2]|0)+52>>2];break}case 2e3:{t[r>>2]=t[(t[n>>2]|0)+16>>2];break}case 15:{t[r>>2]=t[(t[n>>2]|0)+56>>2];break}case 18:{t[r>>2]=t[(t[n>>2]|0)+16>>2];break}case 26:{if(t[(t[n>>2]|0)+12>>2]|0)t[r>>2]=kT(t[(t[n>>2]|0)+12>>2]|0)|0;else f=13;break}case 24:case 22:case 23:{t[r>>2]=t[(t[n>>2]|0)+20>>2];break}case 1:{t[r>>2]=142520;break}case 16:{t[r>>2]=t[(t[n>>2]|0)+52>>2];break}case 5:case 4:{t[r>>2]=t[(t[n>>2]|0)+112>>2];break}case 17:{t[r>>2]=t[(t[n>>2]|0)+20>>2];break}default:f=13}while(0);if((f|0)==13)t[r>>2]=0;s=i;return t[r>>2]|0}function hT(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i+4|0;n=i;t[n>>2]=e;e:do switch(t[t[n>>2]>>2]|0){case 17:{t[r>>2]=t[(t[n>>2]|0)+16>>2];break}case 18:{t[r>>2]=t[(t[n>>2]|0)+4>>2];break}case 14:{t[r>>2]=t[(t[n>>2]|0)+8>>2];break}case 16:{t[r>>2]=t[(t[n>>2]|0)+8>>2];break}case 5:case 4:case 1:{t[r>>2]=t[(t[n>>2]|0)+8>>2];break}case 2e3:{t[r>>2]=t[(t[n>>2]|0)+12>>2];break}case 26:{if(t[(t[n>>2]|0)+12>>2]|0){t[r>>2]=hT(t[(t[n>>2]|0)+12>>2]|0)|0;break e}else{t[r>>2]=0;break e}break}case 15:{t[r>>2]=t[(t[n>>2]|0)+8>>2];break}case 24:case 22:case 23:{t[r>>2]=t[(t[n>>2]|0)+16>>2];break}default:t[r>>2]=0}while(0);s=i;return t[r>>2]|0}function wT(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0;r=s;s=s+32|0;n=r+24|0;f=r+20|0;u=r+16|0;a=r+12|0;o=r+8|0;c=r+4|0;l=r;t[f>>2]=e;t[u>>2]=i;if(!(t[u>>2]|0)){t[n>>2]=0;b=t[n>>2]|0;s=r;return b|0}t[o>>2]=KL(t[u>>2]|0)|0;t[a>>2]=Vg(t[o>>2]|0,1)|0;do if(!(t[a>>2]|0)){if((t[(t[u>>2]|0)+40>>2]|0)!=2){t[l>>2]=TD(t[o>>2]|0)|0;if(t[l>>2]|0){pAi[t[135736>>2]&511](t[o>>2]|0);t[o>>2]=t[l>>2]}t[c>>2]=zM(0,t[(t[u>>2]|0)+32>>2]|0,t[o>>2]|0,t[u>>2]|0)|0;if(!(t[c>>2]|0)){t[a>>2]=3037;i=t[f>>2]|0;e=t[u>>2]|0;k=ED(23)|0;Ud(i,3037,0,e,k,0,0,161408,t[o>>2]|0,0);break}else{t[(t[u>>2]|0)+40>>2]=2;break}}}else if((t[a>>2]|0)>0){t[a>>2]=3037;k=t[f>>2]|0;e=t[u>>2]|0;i=ED(23)|0;Ud(k,3037,0,e,i,0,0,161456,t[o>>2]|0,0)}while(0);if(t[o>>2]|0)pAi[t[135736>>2]&511](t[o>>2]|0);t[n>>2]=t[a>>2];b=t[n>>2]|0;s=r;return b|0}function dT(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;var u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0;u=s;s=s+32|0;a=u+24|0;o=u+20|0;c=u+16|0;l=u+12|0;b=u+8|0;k=u+4|0;h=u;t[o>>2]=e;t[c>>2]=i;t[l>>2]=r;t[b>>2]=n;t[k>>2]=f;t[h>>2]=0;if((t[o>>2]|0)==0|(t[k>>2]|0)==0|(t[l>>2]|0)==0){t[a>>2]=-1;w=t[a>>2]|0;s=u;return w|0}if((t[t[k>>2]>>2]|0)!=1){rh(t[o>>2]|0,162480,162512);t[a>>2]=-1;w=t[a>>2]|0;s=u;return w|0}switch(t[(t[k>>2]|0)+88>>2]|0){case 17:case 16:case 29:case 21:case 22:break;default:{rh(t[o>>2]|0,162480,162552);t[a>>2]=-1;w=t[a>>2]|0;s=u;return w|0}}t[h>>2]=LD(t[k>>2]|0,t[b>>2]|0,0,t[l>>2]|0)|0;if((t[h>>2]|0)<0){rh(t[o>>2]|0,162480,162624);t[a>>2]=-1;w=t[a>>2]|0;s=u;return w|0}if((t[h>>2]|0)>0){if(t[(t[k>>2]|0)+48>>2]&64)t[h>>2]=1825;else t[h>>2]=1824;Ud(t[o>>2]|0,t[h>>2]|0,t[c>>2]|0,t[l>>2]|0,t[k>>2]|0,0,t[b>>2]|0,0,0,0)}t[a>>2]=t[h>>2];w=t[a>>2]|0;s=u;return w|0}function vT(e,i,r,n,f,u,a,o,c,l,b,k){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;u=u|0;a=a|0;o=o|0;c=c|0;l=l|0;b=b|0;k=k|0;var h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0,S=0,g=0,y=0,F=0,O=0,A=0,M=0,R=0,N=0;h=s;s=s+80|0;w=h;d=h+76|0;v=h+72|0;m=h+68|0;_=h+64|0;p=h+60|0;E=h+56|0;S=h+52|0;g=h+48|0;y=h+44|0;F=h+40|0;O=h+36|0;A=h+32|0;M=h+28|0;R=h+24|0;N=h+20|0;t[d>>2]=e;t[v>>2]=i;t[m>>2]=r;t[_>>2]=n;t[p>>2]=f;t[E>>2]=u;t[S>>2]=a;t[g>>2]=o;t[y>>2]=c;t[F>>2]=l;t[O>>2]=b;t[A>>2]=k;t[M>>2]=0;t[R>>2]=0;t[N>>2]=0;if(t[d>>2]|0){k=(t[d>>2]|0)+20|0;t[k>>2]=(t[k>>2]|0)+1;t[(t[d>>2]|0)+16>>2]=t[m>>2];t[M>>2]=t[(t[d>>2]|0)+8>>2];t[N>>2]=t[(t[d>>2]|0)+4>>2];t[R>>2]=t[(t[d>>2]|0)+24>>2]}k=t[R>>2]|0;R=t[M>>2]|0;M=t[N>>2]|0;N=t[d>>2]|0;d=t[v>>2]|0;v=t[m>>2]|0;m=t[_>>2]|0;_=t[p>>2]|0;p=t[E>>2]|0;E=t[S>>2]|0;S=t[y>>2]|0;y=t[F>>2]|0;F=t[O>>2]|0;O=t[A>>2]|0;t[w>>2]=t[g>>2];t[w+4>>2]=S;t[w+8>>2]=y;t[w+12>>2]=F;t[w+16>>2]=O;cp(k,R,M,N,d,16,v,2,0,0,m,_,p,0,0,E,w);s=h;return}function mT(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0;r=s;s=s+16|0;n=r+12|0;f=r+8|0;u=r+4|0;a=r;t[f>>2]=e;t[u>>2]=i;t[a>>2]=gAi[t[135744>>2]&511](8)|0;if(!(t[a>>2]|0)){Qh(t[f>>2]|0,168864,t[u>>2]|0);t[n>>2]=0;o=t[n>>2]|0;s=r;return o|0}else{f=t[a>>2]|0;t[f+0>>2]=0;t[f+4>>2]=0;t[(t[a>>2]|0)+4>>2]=t[u>>2];t[n>>2]=t[a>>2];o=t[n>>2]|0;s=r;return o|0}return 0}function _T(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,u=0,a=0,o=0,c=0,l=0;f=s;s=s+32|0;u=f+20|0;a=f+16|0;o=f+8|0;c=f+4|0;l=f;t[u>>2]=e;t[a>>2]=i;t[f+12>>2]=r;t[o>>2]=n;t[c>>2]=0;t[l>>2]=0;bw(c,t[u>>2]|0,t[(t[o>>2]|0)+20>>2]|0)|0;n=t[u>>2]|0;u=t[a>>2]|0;a=t[o>>2]|0;r=t[c>>2]|0;kw(n,u,a,163216,r,XL(l,t[(t[o>>2]|0)+36>>2]|0,t[(t[o>>2]|0)+8>>2]|0)|0,0,0);if(t[c>>2]|0){pAi[t[135736>>2]&511](t[c>>2]|0);t[c>>2]=0}if(!(t[l>>2]|0)){s=f;return}pAi[t[135736>>2]&511](t[l>>2]|0);t[l>>2]=0;s=f;return}function pT(e,i,r,n,f,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;u=u|0;var a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0;a=s;s=s+32|0;o=a+28|0;c=a+24|0;l=a+20|0;b=a+16|0;k=a+12|0;h=a+8|0;w=a+4|0;d=a;t[c>>2]=e;t[l>>2]=i;t[b>>2]=r;t[k>>2]=n;t[h>>2]=f;t[w>>2]=u;if((t[c>>2]|0)==0|(t[h>>2]|0)==0){if(t[w>>2]|0)t[t[w>>2]>>2]=0;t[o>>2]=-1;v=t[o>>2]|0;s=a;return v|0}if((t[t[h>>2]>>2]|0)!=1){if(t[w>>2]|0)t[t[w>>2]>>2]=0;pw(t[c>>2]|0,t[b>>2]|0,3069,168672,t[(t[h>>2]|0)+8>>2]|0,0);t[o>>2]=-1;v=t[o>>2]|0;s=a;return v|0}t[d>>2]=Bd(t[b>>2]|0,t[k>>2]|0)|0;if(t[d>>2]|0){t[o>>2]=Id(t[c>>2]|0,t[l>>2]|0,t[d>>2]|0,t[h>>2]|0,t[w>>2]|0)|0;v=t[o>>2]|0;s=a;return v|0}if(t[w>>2]|0)t[t[w>>2]>>2]=0;t[o>>2]=0;v=t[o>>2]|0;s=a;return v|0}function ET(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0;n=s;s=s+32|0;f=n+16|0;u=n+12|0;a=n+8|0;o=n+4|0;c=n;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;if((t[u>>2]|0)==0|(t[o>>2]|0)==0){t[f>>2]=0;l=t[f>>2]|0;s=n;return l|0}t[c>>2]=t[(t[u>>2]|0)+44>>2];while(1){if(!(t[c>>2]|0)){b=10;break}if(((t[(t[c>>2]|0)+36>>2]|0)!=0?(Xl(t[(t[c>>2]|0)+8>>2]|0,t[o>>2]|0)|0)!=0:0)?(Xl(t[(t[(t[c>>2]|0)+36>>2]|0)+8>>2]|0,t[a>>2]|0)|0)!=0:0){b=8;break}t[c>>2]=t[(t[c>>2]|0)+24>>2]}if((b|0)==8){t[f>>2]=t[c>>2];l=t[f>>2]|0;s=n;return l|0}else if((b|0)==10){t[f>>2]=0;l=t[f>>2]|0;s=n;return l|0}return 0}function ST(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0;n=s;s=s+32|0;f=n+24|0;u=n+20|0;a=n+16|0;o=n+12|0;c=n+8|0;l=n+4|0;b=n;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;if(t[a>>2]|0){if(!(t[o>>2]|0)){t[f>>2]=t[a>>2];k=t[f>>2]|0;s=n;return k|0}t[b>>2]=0;t[c>>2]=oF(t[(t[o>>2]|0)+32>>2]|0,t[o>>2]|0)|0;r=t[a>>2]|0;if(!(t[c>>2]|0))t[l>>2]=GA(r,t[(t[(t[o>>2]|0)+32>>2]|0)+72>>2]|0)|0;else{t[l>>2]=GA(r,t[c>>2]|0)|0;pAi[t[135736>>2]&511](t[c>>2]|0)}if(t[l>>2]|0){t[b>>2]=kz(t[u>>2]|0,t[l>>2]|0,-1)|0;pAi[t[135736>>2]&511](t[l>>2]|0);t[f>>2]=t[b>>2];k=t[f>>2]|0;s=n;return k|0}}t[f>>2]=0;k=t[f>>2]|0;s=n;return k|0}function gT(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0;n=s;s=s+32|0;f=n+20|0;u=n+16|0;a=n+12|0;o=n+8|0;c=n+4|0;l=n;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;t[l>>2]=0;if(!(t[o>>2]|0)){t[f>>2]=0;b=t[f>>2]|0;s=n;return b|0}if(t[(t[o>>2]|0)+32>>2]|0){rh(t[u>>2]|0,168128,168152);t[f>>2]=-1;b=t[f>>2]|0;s=n;return b|0}r=t[u>>2]|0;if(!(t[(t[o>>2]|0)+20>>2]|0)){rh(r,168128,168176);t[f>>2]=-1;b=t[f>>2]|0;s=n;return b|0}if(!(t[r+28>>2]|0)){rh(t[u>>2]|0,168128,155336);t[f>>2]=-1;b=t[f>>2]|0;s=n;return b|0}t[c>>2]=uT(t[(t[o>>2]|0)+8>>2]|0,t[(t[u>>2]|0)+80>>2]|0)|0;if(!(t[c>>2]|0)){t[f>>2]=-1;b=t[f>>2]|0;s=n;return b|0}t[(t[c>>2]|0)+28>>2]=t[(t[u>>2]|0)+28>>2];t[(t[c>>2]|0)+36>>2]=t[a>>2];Dk(t[c>>2]|0,t[(t[u>>2]|0)+8>>2]|0,t[(t[u>>2]|0)+12>>2]|0,t[(t[u>>2]|0)+4>>2]|0);Pk(t[c>>2]|0,t[(t[u>>2]|0)+24>>2]|0,t[(t[u>>2]|0)+4>>2]|0);t[(t[c>>2]|0)+40>>2]=t[(t[u>>2]|0)+40>>2];t[l>>2]=sh(t[c>>2]|0,t[a>>2]|0,t[o>>2]|0)|0;if(t[l>>2]|0)t[(t[u>>2]|0)+16>>2]=t[l>>2];o=(t[u>>2]|0)+20|0;t[o>>2]=(t[o>>2]|0)+(t[(t[c>>2]|0)+20>>2]|0);t[(t[u>>2]|0)+40>>2]=t[(t[c>>2]|0)+40>>2];t[(t[c>>2]|0)+28>>2]=0;Rk(t[c>>2]|0);t[f>>2]=t[l>>2];b=t[f>>2]|0;s=n;return b|0}function yT(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0;f=s;s=s+48|0;u=f+40|0;a=f+36|0;o=f+32|0;c=f+28|0;l=f+24|0;b=f+20|0;k=f+16|0;h=f+12|0;w=f+8|0;d=f+4|0;v=f;t[a>>2]=e;t[o>>2]=i;t[c>>2]=r;t[l>>2]=n;t[b>>2]=0;t[k>>2]=0;t[h>>2]=0;t[w>>2]=0;t[d>>2]=0;t[v>>2]=0;if((t[a>>2]|0)==0|(t[o>>2]|0)==0|(t[c>>2]|0)==0){t[u>>2]=-1;m=t[u>>2]|0;s=f;return m|0}t[h>>2]=ZL(t[a>>2]|0,t[o>>2]|0,t[c>>2]|0,k,t[l>>2]|0)|0;if(t[h>>2]|0){t[u>>2]=t[h>>2];m=t[u>>2]|0;s=f;return m|0}t[h>>2]=lh(t[a>>2]|0,t[l>>2]|0,t[k>>2]|0,0,0,0,t[c>>2]|0,t[(t[a>>2]|0)+112>>2]|0,0,v)|0;if(t[h>>2]|0){t[u>>2]=t[h>>2];m=t[u>>2]|0;s=f;return m|0}e:do if((t[v>>2]|0)!=0?(t[(t[v>>2]|0)+20>>2]|0)!=0:0){n=t[(t[a>>2]|0)+112>>2]|0;do if(t[(t[v>>2]|0)+12>>2]|0){if(!n){th(t[a>>2]|0,3050,t[c>>2]|0,0,167648,t[k>>2]|0,0);break}if(Xl(t[(t[v>>2]|0)+12>>2]|0,t[(t[a>>2]|0)+112>>2]|0)|0)break e;iL(t[a>>2]|0,3050,0,t[c>>2]|0,167792,t[(t[v>>2]|0)+12>>2]|0,t[k>>2]|0,t[(t[a>>2]|0)+112>>2]|0)}else{if(!n)break e;t[w>>2]=1;if((t[(t[v>>2]|0)+32>>2]|0)!=0?(t[(t[v>>2]|0)+12>>2]|0)!=0:0){th(t[a>>2]|0,3050,t[c>>2]|0,0,167912,t[k>>2]|0,0);break}t[(t[v>>2]|0)+16>>2]=t[(t[a>>2]|0)+112>>2];break e}while(0);t[u>>2]=t[(t[a>>2]|0)+16>>2];m=t[u>>2]|0;s=f;return m|0}else _=9;while(0);do if((_|0)==9)if((t[l>>2]|0)==2){t[h>>2]=3050;th(t[a>>2]|0,t[h>>2]|0,t[c>>2]|0,0,167544,t[k>>2]|0,0);break}else{t[h>>2]=3081;th(t[a>>2]|0,t[h>>2]|0,t[c>>2]|0,0,167592,t[k>>2]|0,0);break}while(0);if(((t[v>>2]|0)!=0?(t[(t[v>>2]|0)+32>>2]|0)==0:0)?(t[(t[v>>2]|0)+20>>2]|0)!=0:0){do if(t[w>>2]|0)if(!(t[(t[o>>2]|0)+24>>2]&512)){k=(t[o>>2]|0)+24|0;t[k>>2]=t[k>>2]|512;break}else{t[d>>2]=1;break}while(0);gT(t[a>>2]|0,t[o>>2]|0,t[v>>2]|0)|0;if(!((t[w>>2]|0)==0|(t[d>>2]|0)!=0)){d=(t[o>>2]|0)+24|0;t[d>>2]=t[d>>2]^512}}t[b>>2]=t[(t[c>>2]|0)+12>>2];if((t[l>>2]|0)!=3){if((((t[b>>2]|0)!=0?(t[(t[b>>2]|0)+36>>2]|0)!=0:0)?(Xl(t[(t[b>>2]|0)+8>>2]|0,160992)|0)!=0:0)?(Xl(t[(t[(t[b>>2]|0)+36>>2]|0)+8>>2]|0,t[38526]|0)|0)!=0:0)t[b>>2]=t[(t[b>>2]|0)+24>>2]}else{t[(t[a>>2]|0)+116>>2]=t[v>>2];t[(t[a>>2]|0)+100>>2]=1;e:while(1){if(!((((t[b>>2]|0)!=0?(t[(t[b>>2]|0)+36>>2]|0)!=0:0)?(Xl(t[(t[b>>2]|0)+8>>2]|0,160992)|0)!=0:0)?(Xl(t[(t[(t[b>>2]|0)+36>>2]|0)+8>>2]|0,t[38526]|0)|0)!=0:0))_=37;do if((_|0)==37){_=0;if((((t[b>>2]|0)!=0?(t[(t[b>>2]|0)+36>>2]|0)!=0:0)?(Xl(t[(t[b>>2]|0)+8>>2]|0,161024)|0)!=0:0)?(Xl(t[(t[(t[b>>2]|0)+36>>2]|0)+8>>2]|0,t[38526]|0)|0)!=0:0)break;if((((t[b>>2]|0)!=0?(t[(t[b>>2]|0)+36>>2]|0)!=0:0)?(Xl(t[(t[b>>2]|0)+8>>2]|0,161008)|0)!=0:0)?(Xl(t[(t[(t[b>>2]|0)+36>>2]|0)+8>>2]|0,t[38526]|0)|0)!=0:0)break;if((((t[b>>2]|0)!=0?(t[(t[b>>2]|0)+36>>2]|0)!=0:0)?(Xl(t[(t[b>>2]|0)+8>>2]|0,161080)|0)!=0:0)?(Xl(t[(t[(t[b>>2]|0)+36>>2]|0)+8>>2]|0,t[38526]|0)|0)!=0:0)break;if(!(t[b>>2]|0))break e;if(!(t[(t[b>>2]|0)+36>>2]|0))break e;if(!(Xl(t[(t[b>>2]|0)+8>>2]|0,161064)|0))break e;if(!(Xl(t[(t[(t[b>>2]|0)+36>>2]|0)+8>>2]|0,t[38526]|0)|0))break e}while(0);if(!((((t[b>>2]|0)!=0?(t[(t[b>>2]|0)+36>>2]|0)!=0:0)?(Xl(t[(t[b>>2]|0)+8>>2]|0,160992)|0)!=0:0)?(Xl(t[(t[(t[b>>2]|0)+36>>2]|0)+8>>2]|0,t[38526]|0)|0)!=0:0))_=57;do if((_|0)==57){_=0;if((((t[b>>2]|0)!=0?(t[(t[b>>2]|0)+36>>2]|0)!=0:0)?(Xl(t[(t[b>>2]|0)+8>>2]|0,161024)|0)!=0:0)?(Xl(t[(t[(t[b>>2]|0)+36>>2]|0)+8>>2]|0,t[38526]|0)|0)!=0:0){Wd(t[a>>2]|0,t[o>>2]|0,t[b>>2]|0,1)|0;break}if((((t[b>>2]|0)!=0?(t[(t[b>>2]|0)+36>>2]|0)!=0:0)?(Xl(t[(t[b>>2]|0)+8>>2]|0,161008)|0)!=0:0)?(Xl(t[(t[(t[b>>2]|0)+36>>2]|0)+8>>2]|0,t[38526]|0)|0)!=0:0){Gd(t[a>>2]|0,t[o>>2]|0,t[b>>2]|0,1)|0;break}if((((t[b>>2]|0)!=0?(t[(t[b>>2]|0)+36>>2]|0)!=0:0)?(Xl(t[(t[b>>2]|0)+8>>2]|0,161080)|0)!=0:0)?(Xl(t[(t[(t[b>>2]|0)+36>>2]|0)+8>>2]|0,t[38526]|0)|0)!=0:0){Jd(t[a>>2]|0,t[o>>2]|0,t[b>>2]|0)|0;break}if((((t[b>>2]|0)!=0?(t[(t[b>>2]|0)+36>>2]|0)!=0:0)?(Xl(t[(t[b>>2]|0)+8>>2]|0,161064)|0)!=0:0)?(Xl(t[(t[(t[b>>2]|0)+36>>2]|0)+8>>2]|0,t[38526]|0)|0)!=0:0)Zd(t[a>>2]|0,t[o>>2]|0,t[b>>2]|0)|0}while(0);t[b>>2]=t[(t[b>>2]|0)+24>>2]}t[(t[a>>2]|0)+116>>2]=0;t[(t[a>>2]|0)+100>>2]=0}do if(t[b>>2]|0){t[h>>2]=3033;o=t[a>>2]|0;_=t[h>>2]|0;v=t[c>>2]|0;d=t[b>>2]|0;if((t[l>>2]|0)==3){$d(o,_,0,v,d,0,168056);break}else{$d(o,_,0,v,d,0,161392);break}}while(0);t[u>>2]=t[h>>2];m=t[u>>2]|0;s=f;return m|0}function FT(e,i,r,n,f,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;u=u|0;var a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0;a=s;s=s+32|0;o=a+24|0;c=a+20|0;l=a+16|0;b=a+12|0;k=a+8|0;h=a+4|0;w=a;t[o>>2]=e;t[c>>2]=i;t[l>>2]=r;t[b>>2]=n;t[k>>2]=f;t[h>>2]=u;t[w>>2]=0;sw(w,0,t[l>>2]|0,t[b>>2]|0)|0;l=t[o>>2]|0;o=t[b>>2]|0;b=t[c>>2]|0;c=t[w>>2]|0;if(t[h>>2]|0)pw(l,o,b,161256,c,t[h>>2]|0);else pw(l,o,b,163272,c,t[k>>2]|0);if(!(t[w>>2]|0)){s=a;return}pAi[t[135736>>2]&511](t[w>>2]|0);t[w>>2]=0;s=a;return}function OT(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0;n=s;s=s+32|0;f=n+16|0;u=n+12|0;a=n+8|0;o=n+4|0;c=n;t[f>>2]=e;t[u>>2]=i;t[a>>2]=r;t[o>>2]=0;t[c>>2]=0;t[o>>2]=sF(t[a>>2]|0)|0;do if(!(Xl(t[o>>2]|0,165504)|0)){if(Xl(t[o>>2]|0,165512)|0){t[c>>2]=0;break}if(Xl(t[o>>2]|0,161736)|0){t[c>>2]=1;break}if(Xl(t[o>>2]|0,165520)|0){t[c>>2]=0;break}else{r=t[f>>2]|0;i=t[u>>2]|0;e=t[a>>2]|0;l=ED(15)|0;Ud(r,1714,i,e,l,0,t[o>>2]|0,0,0,0);break}}else t[c>>2]=1;while(0);if(!(t[o>>2]|0)){b=t[c>>2]|0;s=n;return b|0}pAi[t[135736>>2]&511](t[o>>2]|0);b=t[c>>2]|0;s=n;return b|0}function AT(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0;f=s;s=s+32|0;u=f+28|0;a=f+24|0;o=f+20|0;c=f+16|0;l=f+12|0;b=f+8|0;k=f+4|0;h=f;t[a>>2]=e;t[o>>2]=i;t[c>>2]=r;t[l>>2]=n;t[k>>2]=0;if((t[a>>2]|0)==0|(t[o>>2]|0)==0|(t[c>>2]|0)==0|(t[l>>2]|0)==0){t[u>>2]=-1;w=t[u>>2]|0;s=f;return w|0}t[t[l>>2]>>2]=0;t[b>>2]=t[(t[a>>2]|0)+84>>2];t[(t[b>>2]|0)+52>>2]=4;t[h>>2]=t[(t[c>>2]|0)+44>>2];while(1){if(!(t[h>>2]|0))break;n=t[h>>2]|0;if(!(t[(t[h>>2]|0)+36>>2]|0)){if(!(Xl(t[n+8>>2]|0,161384)|0))_T(t[a>>2]|0,3035,0,t[h>>2]|0)}else if(Xl(t[(t[n+36>>2]|0)+8>>2]|0,t[38526]|0)|0)_T(t[a>>2]|0,3035,0,t[h>>2]|0);t[h>>2]=t[(t[h>>2]|0)+24>>2]}Pd(t[a>>2]|0,t[c>>2]|0,161384)|0;t[k>>2]=t[(t[c>>2]|0)+12>>2];if((((t[k>>2]|0)!=0?(t[(t[k>>2]|0)+36>>2]|0)!=0:0)?(Xl(t[(t[k>>2]|0)+8>>2]|0,160992)|0)!=0:0)?(Xl(t[(t[(t[k>>2]|0)+36>>2]|0)+8>>2]|0,t[38526]|0)|0)!=0:0){h=t[b>>2]|0;JL(h,jd(t[a>>2]|0,t[k>>2]|0,1)|0)|0;t[k>>2]=t[(t[k>>2]|0)+24>>2]}if(!(t[k>>2]|0))$d(t[a>>2]|0,3034,0,t[c>>2]|0,0,0,167392);if(!(t[k>>2]|0))$d(t[a>>2]|0,3034,0,t[c>>2]|0,0,0,167392);if((((t[k>>2]|0)!=0?(t[(t[k>>2]|0)+36>>2]|0)!=0:0)?(Xl(t[(t[k>>2]|0)+8>>2]|0,165456)|0)!=0:0)?(Xl(t[(t[(t[k>>2]|0)+36>>2]|0)+8>>2]|0,t[38526]|0)|0)!=0:0){DT(t[a>>2]|0,t[o>>2]|0,t[k>>2]|0,9)|0;t[t[l>>2]>>2]=1;t[k>>2]=t[(t[k>>2]|0)+24>>2]}else d=25;if(((((d|0)==25?(t[k>>2]|0)!=0:0)?(t[(t[k>>2]|0)+36>>2]|0)!=0:0)?(Xl(t[(t[k>>2]|0)+8>>2]|0,165440)|0)!=0:0)?(Xl(t[(t[(t[k>>2]|0)+36>>2]|0)+8>>2]|0,t[38526]|0)|0)!=0:0){QL(t[a>>2]|0,t[o>>2]|0,t[k>>2]|0,9)|0;t[t[l>>2]>>2]=1;t[k>>2]=t[(t[k>>2]|0)+24>>2]}if(t[k>>2]|0)$d(t[a>>2]|0,3033,0,t[c>>2]|0,t[k>>2]|0,0,167392);t[u>>2]=0;w=t[u>>2]|0;s=f;return w|0}function MT(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0;f=s;s=s+32|0;u=f+28|0;a=f+24|0;o=f+20|0;c=f+16|0;l=f+12|0;b=f+8|0;k=f+4|0;h=f;t[a>>2]=e;t[o>>2]=i;t[c>>2]=r;t[l>>2]=n;t[k>>2]=0;if((t[a>>2]|0)==0|(t[o>>2]|0)==0|(t[c>>2]|0)==0|(t[l>>2]|0)==0){t[u>>2]=-1;w=t[u>>2]|0;s=f;return w|0}t[t[l>>2]>>2]=0;t[b>>2]=t[(t[a>>2]|0)+84>>2];t[h>>2]=t[(t[c>>2]|0)+44>>2];while(1){if(!(t[h>>2]|0))break;n=t[h>>2]|0;if(!(t[(t[h>>2]|0)+36>>2]|0)){if((Xl(t[n+8>>2]|0,161384)|0)==0?(Xl(t[(t[h>>2]|0)+8>>2]|0,167064)|0)==0:0)_T(t[a>>2]|0,3035,0,t[h>>2]|0)}else if(Xl(t[(t[n+36>>2]|0)+8>>2]|0,t[38526]|0)|0)_T(t[a>>2]|0,3035,0,t[h>>2]|0);t[h>>2]=t[(t[h>>2]|0)+24>>2]}Pd(t[a>>2]|0,t[c>>2]|0,161384)|0;if((WT(t[a>>2]|0,t[c>>2]|0,167064,0)|0)!=0?(t[(t[b>>2]|0)+48>>2]&1|0)==0:0){h=(t[b>>2]|0)+48|0;t[h>>2]=t[h>>2]|1}t[k>>2]=t[(t[c>>2]|0)+12>>2];if((((t[k>>2]|0)!=0?(t[(t[k>>2]|0)+36>>2]|0)!=0:0)?(Xl(t[(t[k>>2]|0)+8>>2]|0,160992)|0)!=0:0)?(Xl(t[(t[(t[k>>2]|0)+36>>2]|0)+8>>2]|0,t[38526]|0)|0)!=0:0){h=t[b>>2]|0;JL(h,jd(t[a>>2]|0,t[k>>2]|0,1)|0)|0;t[k>>2]=t[(t[k>>2]|0)+24>>2]}if(!(t[k>>2]|0))$d(t[a>>2]|0,3034,0,t[c>>2]|0,0,0,167392);if(!(t[k>>2]|0))$d(t[a>>2]|0,3034,0,t[c>>2]|0,0,0,167392);if((((t[k>>2]|0)!=0?(t[(t[k>>2]|0)+36>>2]|0)!=0:0)?(Xl(t[(t[k>>2]|0)+8>>2]|0,165456)|0)!=0:0)?(Xl(t[(t[(t[k>>2]|0)+36>>2]|0)+8>>2]|0,t[38526]|0)|0)!=0:0){DT(t[a>>2]|0,t[o>>2]|0,t[k>>2]|0,10)|0;t[t[l>>2]>>2]=1;t[k>>2]=t[(t[k>>2]|0)+24>>2]}else d=29;if(((((d|0)==29?(t[k>>2]|0)!=0:0)?(t[(t[k>>2]|0)+36>>2]|0)!=0:0)?(Xl(t[(t[k>>2]|0)+8>>2]|0,165440)|0)!=0:0)?(Xl(t[(t[(t[k>>2]|0)+36>>2]|0)+8>>2]|0,t[38526]|0)|0)!=0:0){QL(t[a>>2]|0,t[o>>2]|0,t[k>>2]|0,10)|0;t[t[l>>2]>>2]=1;t[k>>2]=t[(t[k>>2]|0)+24>>2]}if(t[k>>2]|0)$d(t[a>>2]|0,3033,0,t[c>>2]|0,t[k>>2]|0,0,167392);t[u>>2]=0;w=t[u>>2]|0;s=f;return w|0}function RT(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;var u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0,S=0,g=0,y=0,F=0,O=0,A=0,M=0,R=0,N=0,T=0;u=s;s=s+80|0;a=u+76|0;o=u+72|0;c=u+68|0;l=u+64|0;b=u+60|0;k=u+56|0;h=u+52|0;w=u+48|0;d=u+44|0;v=u+40|0;m=u+36|0;_=u+32|0;p=u+28|0;E=u+24|0;S=u+20|0;g=u+16|0;y=u+12|0;F=u+8|0;O=u+4|0;A=u;t[o>>2]=e;t[c>>2]=i;t[l>>2]=r;t[b>>2]=n;t[k>>2]=f;t[w>>2]=0;t[d>>2]=0;t[m>>2]=1;t[_>>2]=1;t[E>>2]=0;if((t[o>>2]|0)==0|(t[c>>2]|0)==0|(t[l>>2]|0)==0){t[a>>2]=0;M=t[a>>2]|0;s=u;return M|0}t[h>>2]=Rv(t[o>>2]|0,t[c>>2]|0,t[b>>2]|0,t[l>>2]|0)|0;if(!(t[h>>2]|0)){t[a>>2]=0;M=t[a>>2]|0;s=u;return M|0}e:do if(t[k>>2]|0){f=t[o>>2]|0;n=t[l>>2]|0;if((t[b>>2]|0)==8){t[m>>2]=BT(f,n,0,1,1,161728)|0;t[_>>2]=IT(t[o>>2]|0,t[l>>2]|0,1,1,1,161736)|0}else{t[m>>2]=BT(f,n,0,-1,1,161744)|0;t[_>>2]=IT(t[o>>2]|0,t[l>>2]|0,0,1073741824,1,161768)|0}HT(t[o>>2]|0,0,t[l>>2]|0,t[m>>2]|0,t[_>>2]|0)|0;t[w>>2]=Mv(t[o>>2]|0,t[l>>2]|0,t[m>>2]|0,t[_>>2]|0)|0;if(!(t[w>>2]|0)){t[a>>2]=0;M=t[a>>2]|0;s=u;return M|0}t[(t[w>>2]|0)+12>>2]=t[h>>2];t[v>>2]=t[(t[l>>2]|0)+44>>2];while(1){if(!(t[v>>2]|0))break e;n=t[v>>2]|0;if(!(t[(t[v>>2]|0)+36>>2]|0)){if(((Xl(t[n+8>>2]|0,161384)|0)==0?(Xl(t[(t[v>>2]|0)+8>>2]|0,161808)|0)==0:0)?(Xl(t[(t[v>>2]|0)+8>>2]|0,161824)|0)==0:0)_T(t[o>>2]|0,3035,0,t[v>>2]|0)}else if(Xl(t[(t[n+36>>2]|0)+8>>2]|0,t[38526]|0)|0)_T(t[o>>2]|0,3035,0,t[v>>2]|0);t[v>>2]=t[(t[v>>2]|0)+24>>2]}}else{t[v>>2]=t[(t[l>>2]|0)+44>>2];while(1){if(!(t[v>>2]|0))break e;n=t[v>>2]|0;if(!(t[(t[v>>2]|0)+36>>2]|0)){if(!(Xl(t[n+8>>2]|0,161384)|0))_T(t[o>>2]|0,3035,0,t[v>>2]|0)}else if(Xl(t[(t[n+36>>2]|0)+8>>2]|0,t[38526]|0)|0)_T(t[o>>2]|0,3035,0,t[v>>2]|0);t[v>>2]=t[(t[v>>2]|0)+24>>2]}}while(0);Pd(t[o>>2]|0,t[l>>2]|0,161384)|0;t[d>>2]=t[(t[l>>2]|0)+12>>2];if((((t[d>>2]|0)!=0?(t[(t[d>>2]|0)+36>>2]|0)!=0:0)?(Xl(t[(t[d>>2]|0)+8>>2]|0,160992)|0)!=0:0)?(Xl(t[(t[(t[d>>2]|0)+36>>2]|0)+8>>2]|0,t[38526]|0)|0)!=0:0){v=jd(t[o>>2]|0,t[d>>2]|0,1)|0;t[(t[h>>2]|0)+4>>2]=v;t[d>>2]=t[(t[d>>2]|0)+24>>2]}if((t[b>>2]|0)==8){t[g>>2]=0;while(1){if(!(t[d>>2]|0))break;if(!(t[(t[d>>2]|0)+36>>2]|0))break;if(!(Xl(t[(t[d>>2]|0)+8>>2]|0,161040)|0))break;if(!(Xl(t[(t[(t[d>>2]|0)+36>>2]|0)+8>>2]|0,t[38526]|0)|0))break;t[S>>2]=Kd(t[o>>2]|0,t[c>>2]|0,t[d>>2]|0,p,0)|0;if(t[S>>2]|0){if(t[p>>2]|0)t[E>>2]=(t[E>>2]|0)+1;if((t[(t[S>>2]|0)+16>>2]|0)>1){sv(t[o>>2]|0,3091,0,t[d>>2]|0,161840,0);t[(t[S>>2]|0)+16>>2]=1}if((t[(t[S>>2]|0)+20>>2]|0)>1){sv(t[o>>2]|0,3091,0,t[d>>2]|0,161888,0);t[(t[S>>2]|0)+20>>2]=1}b=t[S>>2]|0;if(!(t[g>>2]|0))t[(t[h>>2]|0)+12>>2]=b;else t[(t[g>>2]|0)+8>>2]=b;t[g>>2]=t[S>>2]}t[d>>2]=t[(t[d>>2]|0)+24>>2]}if(t[d>>2]|0)$d(t[o>>2]|0,3033,0,t[l>>2]|0,t[d>>2]|0,0,161936)}else{t[y>>2]=0;t[F>>2]=0;while(1){if((((t[d>>2]|0)!=0?(t[(t[d>>2]|0)+36>>2]|0)!=0:0)?(Xl(t[(t[d>>2]|0)+8>>2]|0,161040)|0)!=0:0)?(Xl(t[(t[(t[d>>2]|0)+36>>2]|0)+8>>2]|0,t[38526]|0)|0)!=0:0)R=1;else N=59;do if((N|0)==59){N=0;if((((t[d>>2]|0)!=0?(t[(t[d>>2]|0)+36>>2]|0)!=0:0)?(Xl(t[(t[d>>2]|0)+8>>2]|0,161080)|0)!=0:0)?(Xl(t[(t[(t[d>>2]|0)+36>>2]|0)+8>>2]|0,t[38526]|0)|0)!=0:0){R=1;break}if((((t[d>>2]|0)!=0?(t[(t[d>>2]|0)+36>>2]|0)!=0:0)?(Xl(t[(t[d>>2]|0)+8>>2]|0,161976)|0)!=0:0)?(Xl(t[(t[(t[d>>2]|0)+36>>2]|0)+8>>2]|0,t[38526]|0)|0)!=0:0){R=1;break}if((((t[d>>2]|0)!=0?(t[(t[d>>2]|0)+36>>2]|0)!=0:0)?(Xl(t[(t[d>>2]|0)+8>>2]|0,161656)|0)!=0:0)?(Xl(t[(t[(t[d>>2]|0)+36>>2]|0)+8>>2]|0,t[38526]|0)|0)!=0:0){R=1;break}if(((t[d>>2]|0)!=0?(t[(t[d>>2]|0)+36>>2]|0)!=0:0)?(Xl(t[(t[d>>2]|0)+8>>2]|0,161664)|0)!=0:0)R=(Xl(t[(t[(t[d>>2]|0)+36>>2]|0)+8>>2]|0,t[38526]|0)|0)!=0;else R=0}while(0);T=(t[d>>2]|0)!=0;if(!R)break;if(((T?(t[(t[d>>2]|0)+36>>2]|0)!=0:0)?(Xl(t[(t[d>>2]|0)+8>>2]|0,161040)|0)!=0:0)?(Xl(t[(t[(t[d>>2]|0)+36>>2]|0)+8>>2]|0,t[38526]|0)|0)!=0:0){
	t[y>>2]=Kd(t[o>>2]|0,t[c>>2]|0,t[d>>2]|0,p,0)|0;if((t[y>>2]|0)!=0&(t[p>>2]|0)!=0)t[E>>2]=(t[E>>2]|0)+1}else N=82;do if((N|0)==82){N=0;if((((t[d>>2]|0)!=0?(t[(t[d>>2]|0)+36>>2]|0)!=0:0)?(Xl(t[(t[d>>2]|0)+8>>2]|0,161080)|0)!=0:0)?(Xl(t[(t[(t[d>>2]|0)+36>>2]|0)+8>>2]|0,t[38526]|0)|0)!=0:0){t[y>>2]=NT(t[o>>2]|0,t[c>>2]|0,t[d>>2]|0)|0;if(t[y>>2]|0)t[E>>2]=(t[E>>2]|0)+1;if(!(t[(t[o>>2]|0)+100>>2]|0))break;if(!(t[(t[o>>2]|0)+120>>2]|0))break;if(!((t[y>>2]|0)!=0?(t[t[(t[(t[o>>2]|0)+120>>2]|0)+4>>2]>>2]|0)==17:0))break;if(!(t[(t[y>>2]|0)+12>>2]|0))break;if((t[(t[(t[y>>2]|0)+12>>2]|0)+12>>2]|0)!=(t[(t[(t[o>>2]|0)+120>>2]|0)+16>>2]|0))break;if((t[(t[(t[y>>2]|0)+12>>2]|0)+16>>2]|0)!=(t[(t[(t[o>>2]|0)+120>>2]|0)+20>>2]|0))break;do if(t[(t[o>>2]|0)+124>>2]|0){t[O>>2]=0;S=t[o>>2]|0;g=t[d>>2]|0;th(S,3081,g,0,161984,uh(O,t[(t[(t[o>>2]|0)+120>>2]|0)+20>>2]|0,t[(t[(t[o>>2]|0)+120>>2]|0)+16>>2]|0)|0,0);if(t[O>>2]|0){pAi[t[135736>>2]&511](t[O>>2]|0);t[O>>2]=0}t[y>>2]=0}else{if((t[(t[y>>2]|0)+16>>2]|0)==1?(t[(t[y>>2]|0)+20>>2]|0)==1:0)break;t[A>>2]=0;g=t[o>>2]|0;S=t[d>>2]|0;th(g,3081,S,0,162096,uh(A,t[(t[(t[o>>2]|0)+120>>2]|0)+20>>2]|0,t[(t[(t[o>>2]|0)+120>>2]|0)+16>>2]|0)|0,0);if(t[A>>2]|0){pAi[t[135736>>2]&511](t[A>>2]|0);t[A>>2]=0}t[y>>2]=0}while(0);t[(t[(t[o>>2]|0)+120>>2]|0)+8>>2]=t[y>>2];S=(t[o>>2]|0)+124|0;t[S>>2]=(t[S>>2]|0)+1;break}if((((t[d>>2]|0)!=0?(t[(t[d>>2]|0)+36>>2]|0)!=0:0)?(Xl(t[(t[d>>2]|0)+8>>2]|0,161976)|0)!=0:0)?(Xl(t[(t[(t[d>>2]|0)+36>>2]|0)+8>>2]|0,t[38526]|0)|0)!=0:0){t[y>>2]=$L(t[o>>2]|0,t[c>>2]|0,t[d>>2]|0)|0;break}if((((t[d>>2]|0)!=0?(t[(t[d>>2]|0)+36>>2]|0)!=0:0)?(Xl(t[(t[d>>2]|0)+8>>2]|0,161656)|0)!=0:0)?(Xl(t[(t[(t[d>>2]|0)+36>>2]|0)+8>>2]|0,t[38526]|0)|0)!=0:0){t[y>>2]=RT(t[o>>2]|0,t[c>>2]|0,t[d>>2]|0,7,1)|0;break}if((((t[d>>2]|0)!=0?(t[(t[d>>2]|0)+36>>2]|0)!=0:0)?(Xl(t[(t[d>>2]|0)+8>>2]|0,161664)|0)!=0:0)?(Xl(t[(t[(t[d>>2]|0)+36>>2]|0)+8>>2]|0,t[38526]|0)|0)!=0:0)t[y>>2]=RT(t[o>>2]|0,t[c>>2]|0,t[d>>2]|0,6,1)|0}while(0);if(t[y>>2]|0){S=t[y>>2]|0;if(!(t[F>>2]|0))t[(t[h>>2]|0)+12>>2]=S;else t[(t[F>>2]|0)+8>>2]=S;t[F>>2]=t[y>>2]}t[d>>2]=t[(t[d>>2]|0)+24>>2]}if(T)$d(t[o>>2]|0,3033,0,t[l>>2]|0,t[d>>2]|0,0,162240)}if((t[_>>2]|0)==0&(t[m>>2]|0)==0){t[a>>2]=0;M=t[a>>2]|0;s=u;return M|0}if(t[E>>2]|0)qT((t[(t[o>>2]|0)+28>>2]|0)+20|0,10,t[h>>2]|0)|0;if(t[k>>2]|0){t[a>>2]=t[w>>2];M=t[a>>2]|0;s=u;return M|0}else{t[a>>2]=t[h>>2];M=t[a>>2]|0;s=u;return M|0}return 0}function NT(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0;n=s;s=s+48|0;f=n+40|0;u=n+36|0;a=n+32|0;o=n+28|0;c=n+24|0;l=n+20|0;b=n+16|0;k=n+12|0;h=n+8|0;w=n+4|0;d=n;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;t[l>>2]=0;t[k>>2]=0;t[h>>2]=0;if((t[u>>2]|0)==0|(t[a>>2]|0)==0|(t[o>>2]|0)==0){t[f>>2]=0;v=t[f>>2]|0;s=n;return v|0}t[b>>2]=Bd(t[o>>2]|0,160064)|0;r=t[u>>2]|0;if(!(t[b>>2]|0)){FT(r,3036,0,t[o>>2]|0,160064,0);t[f>>2]=0;v=t[f>>2]|0;s=n;return v|0}if(xT(r,t[a>>2]|0,0,t[b>>2]|0,h,k)|0){t[f>>2]=0;v=t[f>>2]|0;s=n;return v|0}UT(t[u>>2]|0,t[a>>2]|0,t[o>>2]|0,t[b>>2]|0,t[h>>2]|0)|0;t[w>>2]=BT(t[u>>2]|0,t[o>>2]|0,0,-1,1,161744)|0;t[d>>2]=IT(t[u>>2]|0,t[o>>2]|0,0,1073741824,1,161768)|0;t[b>>2]=t[(t[o>>2]|0)+44>>2];while(1){if(!(t[b>>2]|0))break;a=t[b>>2]|0;if(!(t[(t[b>>2]|0)+36>>2]|0)){if((((Xl(t[a+8>>2]|0,160064)|0)==0?(Xl(t[(t[b>>2]|0)+8>>2]|0,161384)|0)==0:0)?(Xl(t[(t[b>>2]|0)+8>>2]|0,161824)|0)==0:0)?(Xl(t[(t[b>>2]|0)+8>>2]|0,161808)|0)==0:0)_T(t[u>>2]|0,3035,0,t[b>>2]|0)}else if(Xl(t[(t[a+36>>2]|0)+8>>2]|0,t[38526]|0)|0)_T(t[u>>2]|0,3035,0,t[b>>2]|0);t[b>>2]=t[(t[b>>2]|0)+24>>2]}Pd(t[u>>2]|0,t[o>>2]|0,161384)|0;t[c>>2]=Mv(t[u>>2]|0,t[o>>2]|0,t[w>>2]|0,t[d>>2]|0)|0;if(!(t[c>>2]|0)){t[f>>2]=0;v=t[f>>2]|0;s=n;return v|0}b=VT(t[u>>2]|0,17,t[k>>2]|0,t[h>>2]|0)|0;t[(t[c>>2]|0)+12>>2]=b;HT(t[u>>2]|0,t[c>>2]|0,t[o>>2]|0,t[w>>2]|0,t[d>>2]|0)|0;t[l>>2]=t[(t[o>>2]|0)+12>>2];if((((t[l>>2]|0)!=0?(t[(t[l>>2]|0)+36>>2]|0)!=0:0)?(Xl(t[(t[l>>2]|0)+8>>2]|0,160992)|0)!=0:0)?(Xl(t[(t[(t[l>>2]|0)+36>>2]|0)+8>>2]|0,t[38526]|0)|0)!=0:0){b=jd(t[u>>2]|0,t[l>>2]|0,1)|0;t[(t[c>>2]|0)+4>>2]=b;t[l>>2]=t[(t[l>>2]|0)+24>>2]}if(t[l>>2]|0)$d(t[u>>2]|0,3033,0,t[o>>2]|0,t[l>>2]|0,0,161392);if((t[w>>2]|0)==0&(t[d>>2]|0)==0){t[f>>2]=0;v=t[f>>2]|0;s=n;return v|0}else{t[f>>2]=t[c>>2];v=t[f>>2]|0;s=n;return v|0}return 0}function TT(e,i,r,n,f,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;u=u|0;var a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0;a=s;s=s+32|0;o=a+28|0;c=a+24|0;l=a+20|0;b=a+16|0;k=a+12|0;h=a+8|0;w=a+4|0;d=a;t[c>>2]=e;t[l>>2]=i;t[b>>2]=r;t[k>>2]=n;t[h>>2]=f;t[w>>2]=u;while(1){if(!((((t[t[b>>2]>>2]|0)!=0?(t[(t[t[b>>2]>>2]|0)+36>>2]|0)!=0:0)?(Xl(t[(t[t[b>>2]>>2]|0)+8>>2]|0,161048)|0)!=0:0)?(Xl(t[(t[(t[t[b>>2]>>2]|0)+36>>2]|0)+8>>2]|0,t[38526]|0)|0)!=0:0)){if(!(t[t[b>>2]>>2]|0)){v=24;break}if(!(t[(t[t[b>>2]>>2]|0)+36>>2]|0)){v=24;break}if(!(Xl(t[(t[t[b>>2]>>2]|0)+8>>2]|0,161064)|0)){v=24;break}if(!(Xl(t[(t[(t[t[b>>2]>>2]|0)+36>>2]|0)+8>>2]|0,t[38526]|0)|0)){v=24;break}}if((((t[t[b>>2]>>2]|0)!=0?(t[(t[t[b>>2]>>2]|0)+36>>2]|0)!=0:0)?(Xl(t[(t[t[b>>2]>>2]|0)+8>>2]|0,161048)|0)!=0:0)?(Xl(t[(t[(t[t[b>>2]>>2]|0)+36>>2]|0)+8>>2]|0,t[38526]|0)|0)!=0:0)t[d>>2]=eD(t[c>>2]|0,t[l>>2]|0,t[t[b>>2]>>2]|0,t[t[k>>2]>>2]|0,t[h>>2]|0)|0;else v=15;if((v|0)==15?(v=0,t[d>>2]=iD(t[c>>2]|0,t[l>>2]|0,t[t[b>>2]>>2]|0)|0,(t[d>>2]|0)!=0&(t[w>>2]|0)!=0):0)t[t[w>>2]>>2]=1;if(t[d>>2]|0){if((t[t[k>>2]>>2]|0)==0?(u=hh()|0,t[t[k>>2]>>2]=u,(t[t[k>>2]>>2]|0)==0):0){v=20;break}if((rL(t[t[k>>2]>>2]|0,2,t[d>>2]|0)|0)==-1){v=22;break}}t[t[b>>2]>>2]=t[(t[t[b>>2]>>2]|0)+24>>2]}if((v|0)==20){t[o>>2]=-1;m=t[o>>2]|0;s=a;return m|0}else if((v|0)==22){t[o>>2]=-1;m=t[o>>2]|0;s=a;return m|0}else if((v|0)==24){t[o>>2]=0;m=t[o>>2]|0;s=a;return m|0}return 0}function LT(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0;n=s;s=s+32|0;f=n+24|0;u=n+20|0;a=n+16|0;o=n+12|0;c=n+8|0;l=n+4|0;b=n;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;t[l>>2]=0;if((t[u>>2]|0)==0|(t[a>>2]|0)==0|(t[o>>2]|0)==0){t[f>>2]=0;k=t[f>>2]|0;s=n;return k|0}t[c>>2]=nL(t[u>>2]|0,t[a>>2]|0,21,t[o>>2]|0)|0;if(!(t[c>>2]|0)){t[f>>2]=0;k=t[f>>2]|0;s=n;return k|0}t[b>>2]=t[(t[o>>2]|0)+44>>2];while(1){if(!(t[b>>2]|0))break;r=t[b>>2]|0;if(!(t[(t[b>>2]|0)+36>>2]|0)){if(((Xl(t[r+8>>2]|0,161384)|0)==0?(Xl(t[(t[b>>2]|0)+8>>2]|0,162304)|0)==0:0)?(Xl(t[(t[b>>2]|0)+8>>2]|0,162320)|0)==0:0)_T(t[u>>2]|0,3035,0,t[b>>2]|0)}else if(Xl(t[(t[r+36>>2]|0)+8>>2]|0,t[38526]|0)|0)_T(t[u>>2]|0,3035,0,t[b>>2]|0);t[b>>2]=t[(t[b>>2]|0)+24>>2]}Pd(t[u>>2]|0,t[o>>2]|0,161384)|0;if(rD(t[u>>2]|0,t[a>>2]|0,t[c>>2]|0,t[o>>2]|0)|0){t[f>>2]=0;k=t[f>>2]|0;s=n;return k|0}t[l>>2]=t[(t[o>>2]|0)+12>>2];if((((t[l>>2]|0)!=0?(t[(t[l>>2]|0)+36>>2]|0)!=0:0)?(Xl(t[(t[l>>2]|0)+8>>2]|0,160992)|0)!=0:0)?(Xl(t[(t[(t[l>>2]|0)+36>>2]|0)+8>>2]|0,t[38526]|0)|0)!=0:0){a=jd(t[u>>2]|0,t[l>>2]|0,1)|0;t[(t[c>>2]|0)+8>>2]=a;t[l>>2]=t[(t[l>>2]|0)+24>>2]}if(t[l>>2]|0)$d(t[u>>2]|0,3033,0,t[o>>2]|0,t[l>>2]|0,0,161392);t[f>>2]=t[c>>2];k=t[f>>2]|0;s=n;return k|0}function DT(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0,S=0;f=s;s=s+64|0;u=f+52|0;a=f+48|0;o=f+44|0;c=f+40|0;l=f+36|0;b=f+32|0;k=f+28|0;h=f+24|0;w=f+20|0;d=f+16|0;v=f+12|0;m=f+8|0;_=f+4|0;p=f;t[a>>2]=e;t[o>>2]=i;t[c>>2]=r;t[l>>2]=n;t[k>>2]=0;if((t[a>>2]|0)==0|(t[o>>2]|0)==0|(t[c>>2]|0)==0){t[u>>2]=0;E=t[u>>2]|0;s=f;return E|0}t[b>>2]=t[(t[a>>2]|0)+84>>2];n=(t[b>>2]|0)+48|0;t[n>>2]=t[n>>2]|4;t[h>>2]=t[(t[c>>2]|0)+44>>2];while(1){if(!(t[h>>2]|0))break;n=t[h>>2]|0;if(!(t[(t[h>>2]|0)+36>>2]|0)){if((Xl(t[n+8>>2]|0,161384)|0)==0?(Xl(t[(t[h>>2]|0)+8>>2]|0,151424)|0)==0:0)_T(t[a>>2]|0,3035,0,t[h>>2]|0)}else if(Xl(t[(t[n+36>>2]|0)+8>>2]|0,t[38526]|0)|0)_T(t[a>>2]|0,3035,0,t[h>>2]|0);t[h>>2]=t[(t[h>>2]|0)+24>>2]}Pd(t[a>>2]|0,t[c>>2]|0,161384)|0;do if(!(GT(t[a>>2]|0,t[o>>2]|0,0,t[c>>2]|0,151424,(t[b>>2]|0)+60|0,(t[b>>2]|0)+56|0)|0)){if((t[(t[b>>2]|0)+56>>2]|0)==0?(t[t[b>>2]>>2]|0)==5:0){FT(t[a>>2]|0,3036,0,t[c>>2]|0,151424,0);break}if((t[(t[a>>2]|0)+100>>2]|0)!=0?(t[(t[b>>2]|0)+48>>2]&8|0)!=0:0){if(!(t[(t[b>>2]|0)+56>>2]|0)){FT(t[a>>2]|0,3036,0,t[c>>2]|0,151424,0);break}if((Xl(t[(t[b>>2]|0)+56>>2]|0,t[(t[b>>2]|0)+8>>2]|0)|0)!=0?(Xl(t[(t[b>>2]|0)+60>>2]|0,t[(t[b>>2]|0)+112>>2]|0)|0)!=0:0)break;t[w>>2]=0;t[d>>2]=0;h=t[a>>2]|0;n=t[c>>2]|0;r=uh(w,t[(t[b>>2]|0)+60>>2]|0,t[(t[b>>2]|0)+56>>2]|0)|0;iL(h,3081,0,n,166112,r,uh(d,t[(t[b>>2]|0)+112>>2]|0,t[(t[b>>2]|0)+8>>2]|0)|0,0);if(t[w>>2]|0){pAi[t[135736>>2]&511](t[w>>2]|0);t[w>>2]=0}if(t[d>>2]|0){pAi[t[135736>>2]&511](t[d>>2]|0);t[d>>2]=0}t[(t[b>>2]|0)+56>>2]=0;t[(t[b>>2]|0)+60>>2]=0}}while(0);t[k>>2]=t[(t[c>>2]|0)+12>>2];if((((t[k>>2]|0)!=0?(t[(t[k>>2]|0)+36>>2]|0)!=0:0)?(Xl(t[(t[k>>2]|0)+8>>2]|0,160992)|0)!=0:0)?(Xl(t[(t[(t[k>>2]|0)+36>>2]|0)+8>>2]|0,t[38526]|0)|0)!=0:0){d=t[b>>2]|0;JL(d,jd(t[a>>2]|0,t[k>>2]|0,1)|0)|0;t[k>>2]=t[(t[k>>2]|0)+24>>2]}do if((t[l>>2]|0)==4){if((((t[k>>2]|0)!=0?(t[(t[k>>2]|0)+36>>2]|0)!=0:0)?(Xl(t[(t[k>>2]|0)+8>>2]|0,161024)|0)!=0:0)?(Xl(t[(t[(t[k>>2]|0)+36>>2]|0)+8>>2]|0,t[38526]|0)|0)!=0:0){d=t[a>>2]|0;if(t[(t[b>>2]|0)+56>>2]|0)$d(d,3005,0,t[c>>2]|0,t[k>>2]|0,166232,0);else{w=Wd(d,t[o>>2]|0,t[k>>2]|0,0)|0;t[(t[b>>2]|0)+64>>2]=w}t[k>>2]=t[(t[k>>2]|0)+24>>2];break}if(!(t[(t[b>>2]|0)+56>>2]|0))$d(t[a>>2]|0,3005,0,t[c>>2]|0,t[k>>2]|0,166304,0)}else{if((t[l>>2]|0)!=10){if(!((t[l>>2]|0)==9&(t[k>>2]|0)!=0))break;if(!(t[(t[k>>2]|0)+36>>2]|0))break;if(!(Xl(t[(t[k>>2]|0)+8>>2]|0,161024)|0))break;if(!(Xl(t[(t[(t[k>>2]|0)+36>>2]|0)+8>>2]|0,t[38526]|0)|0))break;w=Wd(t[a>>2]|0,t[o>>2]|0,t[k>>2]|0,0)|0;t[(t[b>>2]|0)+104>>2]=w;if(t[(t[b>>2]|0)+104>>2]|0){t[k>>2]=t[(t[k>>2]|0)+24>>2];break}t[u>>2]=0;E=t[u>>2]|0;s=f;return E|0}if((((t[k>>2]|0)!=0?(t[(t[k>>2]|0)+36>>2]|0)!=0:0)?(Xl(t[(t[k>>2]|0)+8>>2]|0,161648)|0)!=0:0)?(Xl(t[(t[(t[k>>2]|0)+36>>2]|0)+8>>2]|0,t[38526]|0)|0)!=0:0){w=RT(t[a>>2]|0,t[o>>2]|0,t[k>>2]|0,8,1)|0;t[(t[b>>2]|0)+28>>2]=w;t[k>>2]=t[(t[k>>2]|0)+24>>2];break}if((((t[k>>2]|0)!=0?(t[(t[k>>2]|0)+36>>2]|0)!=0:0)?(Xl(t[(t[k>>2]|0)+8>>2]|0,161656)|0)!=0:0)?(Xl(t[(t[(t[k>>2]|0)+36>>2]|0)+8>>2]|0,t[38526]|0)|0)!=0:0){w=RT(t[a>>2]|0,t[o>>2]|0,t[k>>2]|0,7,1)|0;t[(t[b>>2]|0)+28>>2]=w;t[k>>2]=t[(t[k>>2]|0)+24>>2];break}if((((t[k>>2]|0)!=0?(t[(t[k>>2]|0)+36>>2]|0)!=0:0)?(Xl(t[(t[k>>2]|0)+8>>2]|0,161664)|0)!=0:0)?(Xl(t[(t[(t[k>>2]|0)+36>>2]|0)+8>>2]|0,t[38526]|0)|0)!=0:0){w=RT(t[a>>2]|0,t[o>>2]|0,t[k>>2]|0,6,1)|0;t[(t[b>>2]|0)+28>>2]=w;t[k>>2]=t[(t[k>>2]|0)+24>>2];break}if((((t[k>>2]|0)!=0?(t[(t[k>>2]|0)+36>>2]|0)!=0:0)?(Xl(t[(t[k>>2]|0)+8>>2]|0,161080)|0)!=0:0)?(Xl(t[(t[(t[k>>2]|0)+36>>2]|0)+8>>2]|0,t[38526]|0)|0)!=0:0){w=NT(t[a>>2]|0,t[o>>2]|0,t[k>>2]|0)|0;t[(t[b>>2]|0)+28>>2]=w;t[k>>2]=t[(t[k>>2]|0)+24>>2]}}while(0);e:do if((t[l>>2]|0)==4|(t[l>>2]|0)==9){t[m>>2]=0;i:while(1){if(!((((t[k>>2]|0)!=0?(t[(t[k>>2]|0)+36>>2]|0)!=0:0)?(Xl(t[(t[k>>2]|0)+8>>2]|0,157848)|0)!=0:0)?(Xl(t[(t[(t[k>>2]|0)+36>>2]|0)+8>>2]|0,t[38526]|0)|0)!=0:0))S=77;r:do if((S|0)==77){S=0;if((((t[k>>2]|0)!=0?(t[(t[k>>2]|0)+36>>2]|0)!=0:0)?(Xl(t[(t[k>>2]|0)+8>>2]|0,157832)|0)!=0:0)?(Xl(t[(t[(t[k>>2]|0)+36>>2]|0)+8>>2]|0,t[38526]|0)|0)!=0:0)break;if((((t[k>>2]|0)!=0?(t[(t[k>>2]|0)+36>>2]|0)!=0:0)?(Xl(t[(t[k>>2]|0)+8>>2]|0,157816)|0)!=0:0)?(Xl(t[(t[(t[k>>2]|0)+36>>2]|0)+8>>2]|0,t[38526]|0)|0)!=0:0)break;if((((t[k>>2]|0)!=0?(t[(t[k>>2]|0)+36>>2]|0)!=0:0)?(Xl(t[(t[k>>2]|0)+8>>2]|0,157800)|0)!=0:0)?(Xl(t[(t[(t[k>>2]|0)+36>>2]|0)+8>>2]|0,t[38526]|0)|0)!=0:0)break;if((((t[k>>2]|0)!=0?(t[(t[k>>2]|0)+36>>2]|0)!=0:0)?(Xl(t[(t[k>>2]|0)+8>>2]|0,157936)|0)!=0:0)?(Xl(t[(t[(t[k>>2]|0)+36>>2]|0)+8>>2]|0,t[38526]|0)|0)!=0:0)break;if((((t[k>>2]|0)!=0?(t[(t[k>>2]|0)+36>>2]|0)!=0:0)?(Xl(t[(t[k>>2]|0)+8>>2]|0,157952)|0)!=0:0)?(Xl(t[(t[(t[k>>2]|0)+36>>2]|0)+8>>2]|0,t[38526]|0)|0)!=0:0)break;if((((t[k>>2]|0)!=0?(t[(t[k>>2]|0)+36>>2]|0)!=0:0)?(Xl(t[(t[k>>2]|0)+8>>2]|0,157792)|0)!=0:0)?(Xl(t[(t[(t[k>>2]|0)+36>>2]|0)+8>>2]|0,t[38526]|0)|0)!=0:0)break;if((((t[k>>2]|0)!=0?(t[(t[k>>2]|0)+36>>2]|0)!=0:0)?(Xl(t[(t[k>>2]|0)+8>>2]|0,157880)|0)!=0:0)?(Xl(t[(t[(t[k>>2]|0)+36>>2]|0)+8>>2]|0,t[38526]|0)|0)!=0:0)break;if((((t[k>>2]|0)!=0?(t[(t[k>>2]|0)+36>>2]|0)!=0:0)?(Xl(t[(t[k>>2]|0)+8>>2]|0,157864)|0)!=0:0)?(Xl(t[(t[(t[k>>2]|0)+36>>2]|0)+8>>2]|0,t[38526]|0)|0)!=0:0)break;do if((t[k>>2]|0)!=0?(t[(t[k>>2]|0)+36>>2]|0)!=0:0){if(!(Xl(t[(t[k>>2]|0)+8>>2]|0,157896)|0))break;if(Xl(t[(t[(t[k>>2]|0)+36>>2]|0)+8>>2]|0,t[38526]|0)|0)break r}while(0);do if(t[k>>2]|0){if(!(t[(t[k>>2]|0)+36>>2]|0))break;if(!(Xl(t[(t[k>>2]|0)+8>>2]|0,157904)|0))break;if(Xl(t[(t[(t[k>>2]|0)+36>>2]|0)+8>>2]|0,t[38526]|0)|0)break r}while(0);if(!(t[k>>2]|0))break i;if(!(t[(t[k>>2]|0)+36>>2]|0))break i;if(!(Xl(t[(t[k>>2]|0)+8>>2]|0,157920)|0))break i;if(!(Xl(t[(t[(t[k>>2]|0)+36>>2]|0)+8>>2]|0,t[38526]|0)|0))break i}while(0);t[v>>2]=nD(t[a>>2]|0,t[o>>2]|0,t[k>>2]|0)|0;if(t[v>>2]|0){w=t[v>>2]|0;if(!(t[m>>2]|0))t[(t[b>>2]|0)+68>>2]=w;else t[(t[m>>2]|0)+4>>2]=w;t[m>>2]=t[v>>2];t[(t[m>>2]|0)+4>>2]=0}t[k>>2]=t[(t[k>>2]|0)+24>>2]}if(t[(t[b>>2]|0)+68>>2]|0){t[p>>2]=0;t[v>>2]=t[(t[b>>2]|0)+68>>2];while(1){t[_>>2]=gAi[t[135744>>2]&511](8)|0;if(!(t[_>>2]|0))break;t[(t[_>>2]|0)+4>>2]=t[v>>2];t[t[_>>2]>>2]=0;w=t[_>>2]|0;if(!(t[p>>2]|0))t[(t[b>>2]|0)+96>>2]=w;else t[t[p>>2]>>2]=w;t[p>>2]=t[_>>2];t[v>>2]=t[(t[v>>2]|0)+4>>2];if(!(t[v>>2]|0))break e}Qh(t[a>>2]|0,166376,0);pAi[t[135736>>2]&511](t[_>>2]|0);t[u>>2]=0;E=t[u>>2]|0;s=f;return E|0}}while(0);if((t[t[b>>2]>>2]|0)==5){if((TT(t[a>>2]|0,t[o>>2]|0,k,(t[b>>2]|0)+116|0,12,0)|0)==-1){t[u>>2]=0;E=t[u>>2]|0;s=f;return E|0}if((((t[k>>2]|0)!=0?(t[(t[k>>2]|0)+36>>2]|0)!=0:0)?(Xl(t[(t[k>>2]|0)+8>>2]|0,163328)|0)!=0:0)?(Xl(t[(t[(t[k>>2]|0)+36>>2]|0)+8>>2]|0,t[38526]|0)|0)!=0:0){_=LT(t[a>>2]|0,t[o>>2]|0,t[k>>2]|0)|0;t[(t[b>>2]|0)+84>>2]=_;t[k>>2]=t[(t[k>>2]|0)+24>>2]}}do if(t[k>>2]|0){if((t[l>>2]|0)==10){$d(t[a>>2]|0,3033,0,t[c>>2]|0,t[k>>2]|0,0,166400);break}_=t[a>>2]|0;b=t[c>>2]|0;o=t[k>>2]|0;if((t[l>>2]|0)==9){$d(_,3033,0,b,o,0,166504);break}else{$d(_,3033,0,b,o,0,166752);break}}while(0);t[u>>2]=0;E=t[u>>2]|0;s=f;return E|0}function CT(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0;n=s;s=s+32|0;f=n+24|0;u=n+20|0;a=n+16|0;o=n+12|0;c=n+8|0;l=n+4|0;b=n;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;t[l>>2]=0;if((t[u>>2]|0)==0|(t[a>>2]|0)==0|(t[o>>2]|0)==0){t[f>>2]=0;k=t[f>>2]|0;s=n;return k|0}t[c>>2]=t[(t[u>>2]|0)+84>>2];r=(t[c>>2]|0)+48|0;t[r>>2]=t[r>>2]|64;r=ED(46)|0;t[(t[c>>2]|0)+64>>2]=r;t[b>>2]=t[(t[o>>2]|0)+44>>2];while(1){if(!(t[b>>2]|0))break;r=t[b>>2]|0;if(!(t[(t[b>>2]|0)+36>>2]|0)){if((Xl(t[r+8>>2]|0,161384)|0)==0?(Xl(t[(t[b>>2]|0)+8>>2]|0,160400)|0)==0:0)_T(t[u>>2]|0,3035,0,t[b>>2]|0)}else if(Xl(t[(t[r+36>>2]|0)+8>>2]|0,t[38526]|0)|0)_T(t[u>>2]|0,3035,0,t[b>>2]|0);t[b>>2]=t[(t[b>>2]|0)+24>>2]}Pd(t[u>>2]|0,t[o>>2]|0,161384)|0;GT(t[u>>2]|0,t[a>>2]|0,0,t[o>>2]|0,160400,(t[c>>2]|0)+60|0,(t[c>>2]|0)+56|0)|0;t[l>>2]=t[(t[o>>2]|0)+12>>2];if((((t[l>>2]|0)!=0?(t[(t[l>>2]|0)+36>>2]|0)!=0:0)?(Xl(t[(t[l>>2]|0)+8>>2]|0,160992)|0)!=0:0)?(Xl(t[(t[(t[l>>2]|0)+36>>2]|0)+8>>2]|0,t[38526]|0)|0)!=0:0){b=t[c>>2]|0;JL(b,jd(t[u>>2]|0,t[l>>2]|0,1)|0)|0;t[l>>2]=t[(t[l>>2]|0)+24>>2]}if((((t[l>>2]|0)!=0?(t[(t[l>>2]|0)+36>>2]|0)!=0:0)?(Xl(t[(t[l>>2]|0)+8>>2]|0,161024)|0)!=0:0)?(Xl(t[(t[(t[l>>2]|0)+36>>2]|0)+8>>2]|0,t[38526]|0)|0)!=0:0){b=t[u>>2]|0;if(t[(t[c>>2]|0)+56>>2]|0)sv(b,3e3,0,t[o>>2]|0,165952,0);else{r=Wd(b,t[a>>2]|0,t[l>>2]|0,0)|0;t[(t[c>>2]|0)+28>>2]=r}t[l>>2]=t[(t[l>>2]|0)+24>>2]}else h=25;if((h|0)==25?(t[(t[c>>2]|0)+56>>2]|0)==0:0)sv(t[u>>2]|0,3e3,0,t[o>>2]|0,166032,0);if(t[l>>2]|0)$d(t[u>>2]|0,3033,0,t[o>>2]|0,t[l>>2]|0,0,164200);if(((t[(t[c>>2]|0)+56>>2]|0)==0?(t[(t[c>>2]|0)+28>>2]|0)==0:0)?(Bd(t[o>>2]|0,160400)|0)==0:0)sv(t[u>>2]|0,3e3,0,t[o>>2]|0,166032,0);t[f>>2]=0;k=t[f>>2]|0;s=n;return k|0}function PT(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0,S=0,g=0,y=0,F=0,O=0,A=0,M=0,R=0;n=s;s=s+80|0;f=n+64|0;a=n+60|0;o=n+56|0;c=n+52|0;l=n+48|0;b=n+44|0;k=n+40|0;h=n+36|0;w=n+32|0;d=n+28|0;v=n+24|0;m=n+20|0;_=n+16|0;p=n+12|0;E=n+8|0;S=n+4|0;g=n;t[a>>2]=e;t[o>>2]=i;t[c>>2]=r;t[b>>2]=0;t[h>>2]=0;if((t[a>>2]|0)==0|(t[o>>2]|0)==0|(t[c>>2]|0)==0){t[f>>2]=-1;y=t[f>>2]|0;s=n;return y|0}t[l>>2]=t[(t[a>>2]|0)+84>>2];r=(t[l>>2]|0)+48|0;t[r>>2]=t[r>>2]|128;r=ED(46)|0;t[(t[l>>2]|0)+64>>2]=r;t[k>>2]=t[(t[c>>2]|0)+44>>2];while(1){if(!(t[k>>2]|0))break;r=t[k>>2]|0;if(!(t[(t[k>>2]|0)+36>>2]|0)){if((Xl(t[r+8>>2]|0,161384)|0)==0?(Xl(t[(t[k>>2]|0)+8>>2]|0,160512)|0)==0:0)_T(t[a>>2]|0,3035,0,t[k>>2]|0)}else if(Xl(t[(t[r+36>>2]|0)+8>>2]|0,t[38526]|0)|0)_T(t[a>>2]|0,3035,0,t[k>>2]|0);t[k>>2]=t[(t[k>>2]|0)+24>>2]}Pd(t[a>>2]|0,t[c>>2]|0,161384)|0;t[k>>2]=Bd(t[c>>2]|0,160512)|0;e:do if(t[k>>2]|0){t[p>>2]=0;t[h>>2]=Hd(t[a>>2]|0,t[k>>2]|0)|0;t[(t[l>>2]|0)+56>>2]=t[h>>2];while(1){do if((u[t[h>>2]>>0]|0|0)==32)F=1;else{if(9<=(u[t[h>>2]>>0]|0|0)?(u[t[h>>2]>>0]|0|0)<=10:0){F=1;break}F=(u[t[h>>2]>>0]|0|0)==13}while(0);r=t[h>>2]|0;if(F){t[h>>2]=r+1;continue}t[w>>2]=r;while(1){if(u[t[w>>2]>>0]|0){do if((u[t[w>>2]>>0]|0|0)==32)O=1;else{if(9<=(u[t[w>>2]>>0]|0|0)?(u[t[w>>2]>>0]|0|0)<=10:0){O=1;break}O=(u[t[w>>2]>>0]|0|0)==13}while(0);A=O^1}else A=0;M=t[w>>2]|0;if(!A)break;t[w>>2]=M+1}if((M|0)==(t[h>>2]|0))break e;t[d>>2]=ql(t[h>>2]|0,(t[w>>2]|0)-(t[h>>2]|0)|0)|0;if(!(fD(t[a>>2]|0,t[o>>2]|0,0,t[k>>2]|0,t[d>>2]|0,m,v)|0)){t[_>>2]=gAi[t[135744>>2]&511](8)|0;if(!(t[_>>2]|0)){R=32;break}t[(t[_>>2]|0)+4>>2]=0;t[t[_>>2]>>2]=0;r=t[_>>2]|0;if(!(t[p>>2]|0))t[(t[l>>2]|0)+92>>2]=r;else t[t[p>>2]>>2]=r;t[p>>2]=t[_>>2];t[E>>2]=VT(t[a>>2]|0,4,t[v>>2]|0,t[m>>2]|0)|0;if(!(t[E>>2]|0))break;t[(t[_>>2]|0)+4>>2]=t[E>>2]}if(t[d>>2]|0){pAi[t[135736>>2]&511](t[d>>2]|0);t[d>>2]=0}t[h>>2]=t[w>>2];if(!(u[t[h>>2]>>0]|0))break e}if((R|0)==32){Qh(t[a>>2]|0,165784,0);t[f>>2]=-1;y=t[f>>2]|0;s=n;return y|0}if(t[d>>2]|0){pAi[t[135736>>2]&511](t[d>>2]|0);t[d>>2]=0}t[f>>2]=-1;y=t[f>>2]|0;s=n;return y|0}while(0);t[b>>2]=t[(t[c>>2]|0)+12>>2];if((((t[b>>2]|0)!=0?(t[(t[b>>2]|0)+36>>2]|0)!=0:0)?(Xl(t[(t[b>>2]|0)+8>>2]|0,160992)|0)!=0:0)?(Xl(t[(t[(t[b>>2]|0)+36>>2]|0)+8>>2]|0,t[38526]|0)|0)!=0:0){d=t[l>>2]|0;JL(d,jd(t[a>>2]|0,t[b>>2]|0,1)|0)|0;t[b>>2]=t[(t[b>>2]|0)+24>>2]}e:do if((((t[b>>2]|0)!=0?(t[(t[b>>2]|0)+36>>2]|0)!=0:0)?(Xl(t[(t[b>>2]|0)+8>>2]|0,161024)|0)!=0:0)?(Xl(t[(t[(t[b>>2]|0)+36>>2]|0)+8>>2]|0,t[38526]|0)|0)!=0:0){t[g>>2]=0;while(1){if(!(t[b>>2]|0))break e;if(!(t[(t[b>>2]|0)+36>>2]|0))break e;if(!(Xl(t[(t[b>>2]|0)+8>>2]|0,161024)|0))break e;if(!(Xl(t[(t[(t[b>>2]|0)+36>>2]|0)+8>>2]|0,t[38526]|0)|0))break e;t[S>>2]=Wd(t[a>>2]|0,t[o>>2]|0,t[b>>2]|0,0)|0;if(t[S>>2]|0){d=t[S>>2]|0;if(!(t[g>>2]|0)){t[(t[l>>2]|0)+28>>2]=d;t[g>>2]=t[S>>2]}else{t[(t[g>>2]|0)+4>>2]=d;t[g>>2]=t[S>>2]}t[(t[g>>2]|0)+4>>2]=0}t[b>>2]=t[(t[b>>2]|0)+24>>2]}}while(0);if(t[b>>2]|0)$d(t[a>>2]|0,3033,0,t[c>>2]|0,t[b>>2]|0,0,165832);if((t[k>>2]|0)==0?(t[(t[l>>2]|0)+28>>2]|0)==0:0)sv(t[a>>2]|0,3007,0,t[c>>2]|0,165864,0);t[f>>2]=0;y=t[f>>2]|0;s=n;return y|0}function BT(e,i,r,n,f,a){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;a=a|0;var o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0,S=0,g=0,y=0,F=0;o=s;s=s+48|0;c=o+40|0;l=o+36|0;b=o+32|0;k=o+28|0;h=o+24|0;w=o+20|0;d=o+16|0;v=o+12|0;m=o+8|0;_=o+4|0;p=o;t[l>>2]=e;t[b>>2]=i;t[k>>2]=r;t[h>>2]=n;t[w>>2]=f;t[d>>2]=a;t[_>>2]=0;t[p>>2]=Bd(t[b>>2]|0,161824)|0;if(!(t[p>>2]|0)){t[c>>2]=t[w>>2];E=t[c>>2]|0;s=o;return E|0}t[v>>2]=Hd(t[l>>2]|0,t[p>>2]|0)|0;t[m>>2]=t[v>>2];while(1){do if((u[t[m>>2]>>0]|0|0)==32)S=1;else{if(9<=(u[t[m>>2]>>0]|0|0)?(u[t[m>>2]>>0]|0|0)<=10:0){S=1;break}S=(u[t[m>>2]>>0]|0|0)==13}while(0);g=t[m>>2]|0;if(!S)break;t[m>>2]=g+1}if(!(u[g>>0]|0)){Ud(t[l>>2]|0,3037,0,t[p>>2]|0,0,t[d>>2]|0,t[v>>2]|0,0,0,0);t[c>>2]=t[w>>2];E=t[c>>2]|0;s=o;return E|0}while(1){if((u[t[m>>2]>>0]|0|0)<48)break;if((u[t[m>>2]>>0]|0|0)>57)break;t[_>>2]=((t[_>>2]|0)*10|0)+((u[t[m>>2]>>0]|0)-48);t[m>>2]=(t[m>>2]|0)+1}while(1){do if((u[t[m>>2]>>0]|0|0)==32)y=1;else{if(9<=(u[t[m>>2]>>0]|0|0)?(u[t[m>>2]>>0]|0|0)<=10:0){y=1;break}y=(u[t[m>>2]>>0]|0|0)==13}while(0);F=t[m>>2]|0;if(!y)break;t[m>>2]=F+1}do if((u[F>>0]|0|0)==0?(t[_>>2]|0)>=(t[k>>2]|0):0){if((t[h>>2]|0)!=-1?(t[_>>2]|0)>(t[h>>2]|0):0)break;t[c>>2]=t[_>>2];E=t[c>>2]|0;s=o;return E|0}while(0);Ud(t[l>>2]|0,3037,0,t[p>>2]|0,0,t[d>>2]|0,t[v>>2]|0,0,0,0);t[c>>2]=t[w>>2];E=t[c>>2]|0;s=o;return E|0}function IT(e,i,r,n,f,a){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;a=a|0;var o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0,S=0,g=0,y=0,F=0;o=s;s=s+48|0;c=o+40|0;l=o+36|0;b=o+32|0;k=o+28|0;h=o+24|0;w=o+20|0;d=o+16|0;v=o+12|0;m=o+8|0;_=o+4|0;p=o;t[l>>2]=e;t[b>>2]=i;t[k>>2]=r;t[h>>2]=n;t[w>>2]=f;t[d>>2]=a;t[_>>2]=0;t[p>>2]=Bd(t[b>>2]|0,161808)|0;if(!(t[p>>2]|0)){t[c>>2]=t[w>>2];E=t[c>>2]|0;s=o;return E|0}t[v>>2]=Hd(t[l>>2]|0,t[p>>2]|0)|0;if(Xl(t[v>>2]|0,163200)|0)if((t[h>>2]|0)!=1073741824){Ud(t[l>>2]|0,3037,0,t[p>>2]|0,0,t[d>>2]|0,t[v>>2]|0,0,0,0);t[c>>2]=t[w>>2];E=t[c>>2]|0;s=o;return E|0}else{t[c>>2]=1073741824;E=t[c>>2]|0;s=o;return E|0}t[m>>2]=t[v>>2];while(1){do if((u[t[m>>2]>>0]|0|0)==32)S=1;else{if(9<=(u[t[m>>2]>>0]|0|0)?(u[t[m>>2]>>0]|0|0)<=10:0){S=1;break}S=(u[t[m>>2]>>0]|0|0)==13}while(0);g=t[m>>2]|0;if(!S)break;t[m>>2]=g+1}if(!(u[g>>0]|0)){Ud(t[l>>2]|0,3037,0,t[p>>2]|0,0,t[d>>2]|0,t[v>>2]|0,0,0,0);t[c>>2]=t[w>>2];E=t[c>>2]|0;s=o;return E|0}while(1){if((u[t[m>>2]>>0]|0|0)<48)break;if((u[t[m>>2]>>0]|0|0)>57)break;t[_>>2]=((t[_>>2]|0)*10|0)+((u[t[m>>2]>>0]|0)-48);t[m>>2]=(t[m>>2]|0)+1}while(1){do if((u[t[m>>2]>>0]|0|0)==32)y=1;else{if(9<=(u[t[m>>2]>>0]|0|0)?(u[t[m>>2]>>0]|0|0)<=10:0){y=1;break}y=(u[t[m>>2]>>0]|0|0)==13}while(0);F=t[m>>2]|0;if(!y)break;t[m>>2]=F+1}do if((u[F>>0]|0|0)==0?(t[_>>2]|0)>=(t[k>>2]|0):0){if((t[h>>2]|0)!=-1?(t[_>>2]|0)>(t[h>>2]|0):0)break;t[c>>2]=t[_>>2];E=t[c>>2]|0;s=o;return E|0}while(0);Ud(t[l>>2]|0,3037,0,t[p>>2]|0,0,t[d>>2]|0,t[v>>2]|0,0,0,0);t[c>>2]=t[w>>2];E=t[c>>2]|0;s=o;return E|0}function HT(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;var u=0,a=0,o=0,c=0,l=0,b=0,k=0;u=s;s=s+32|0;a=u+20|0;o=u+16|0;c=u+8|0;l=u+4|0;b=u;t[o>>2]=e;t[u+12>>2]=i;t[c>>2]=r;t[l>>2]=n;t[b>>2]=f;if((t[b>>2]|0)==0&(t[l>>2]|0)==0){t[a>>2]=0;k=t[a>>2]|0;s=u;return k|0}if((t[b>>2]|0)!=1073741824){if((t[b>>2]|0)<1){f=t[o>>2]|0;jT(f,3044,0,0,Bd(t[c>>2]|0,161808)|0,163048);t[a>>2]=3044;k=t[a>>2]|0;s=u;return k|0}if((t[l>>2]|0)>(t[b>>2]|0)){b=t[o>>2]|0;jT(b,3043,0,0,Bd(t[c>>2]|0,161824)|0,163096);t[a>>2]=3043;k=t[a>>2]|0;s=u;return k|0}}t[a>>2]=0;k=t[a>>2]|0;s=u;return k|0}function xT(e,i,r,n,f,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;u=u|0;var a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0;a=s;s=s+32|0;o=a+24|0;c=a+20|0;l=a+16|0;b=a+12|0;k=a+8|0;h=a+4|0;w=a;t[o>>2]=e;t[c>>2]=i;t[l>>2]=r;t[b>>2]=n;t[k>>2]=f;t[h>>2]=u;t[w>>2]=Hd(t[o>>2]|0,t[b>>2]|0)|0;u=fD(t[o>>2]|0,t[c>>2]|0,t[l>>2]|0,t[b>>2]|0,t[w>>2]|0,t[k>>2]|0,t[h>>2]|0)|0;s=a;return u|0}function UT(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;var u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0;u=s;s=s+32|0;a=u+28|0;o=u+24|0;c=u+16|0;l=u+12|0;b=u+8|0;k=u+4|0;h=u;t[o>>2]=e;t[u+20>>2]=i;t[c>>2]=r;t[l>>2]=n;t[b>>2]=f;if(Xl(t[(t[o>>2]|0)+112>>2]|0,t[b>>2]|0)|0){t[a>>2]=0;w=t[a>>2]|0;s=u;return w|0}if(Xl(t[38526]|0,t[b>>2]|0)|0){t[a>>2]=0;w=t[a>>2]|0;s=u;return w|0}e:do if(t[(t[(t[(t[o>>2]|0)+28>>2]|0)+16>>2]|0)+24>>2]|0){t[k>>2]=t[(t[(t[(t[o>>2]|0)+28>>2]|0)+16>>2]|0)+24>>2];while(1){if(!((t[(t[k>>2]|0)+4>>2]|0)!=0?(t[(t[k>>2]|0)+4>>2]|0)!=1:0))d=9;if((d|0)==9?(d=0,(Xl(t[b>>2]|0,t[(t[k>>2]|0)+8>>2]|0)|0)!=0):0)break;t[k>>2]=t[t[k>>2]>>2];if(!(t[k>>2]|0))break e}t[a>>2]=0;w=t[a>>2]|0;s=u;return w|0}while(0);if(t[l>>2]|0)v=t[l>>2]|0;else v=t[c>>2]|0;t[h>>2]=v;v=t[o>>2]|0;o=t[h>>2]|0;if(!(t[b>>2]|0))th(v,3004,o,0,162704,0,0);else th(v,3004,o,0,162824,t[b>>2]|0,0);t[a>>2]=3004;w=t[a>>2]|0;s=u;return w|0}function zT(e,i,r,n,f,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;u=u|0;var a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0;a=s;s=s+32|0;o=a+24|0;c=a+20|0;l=a+16|0;b=a+12|0;k=a+8|0;h=a+4|0;w=a;t[o>>2]=e;t[c>>2]=i;t[l>>2]=r;t[b>>2]=n;t[k>>2]=f;t[h>>2]=u;t[w>>2]=0;sw(w,0,t[l>>2]|0,t[(t[b>>2]|0)+20>>2]|0)|0;vT(t[o>>2]|0,t[b>>2]|0,t[c>>2]|0,0,0,0,164296,t[w>>2]|0,t[k>>2]|0,t[h>>2]|0,0,0);if(!(t[w>>2]|0)){s=a;return}pAi[t[135736>>2]&511](t[w>>2]|0);t[w>>2]=0;s=a;return}function jT(e,i,r,n,f,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;u=u|0;var a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0;a=s;s=s+32|0;o=a+24|0;c=a+20|0;l=a+16|0;b=a+12|0;k=a+8|0;h=a+4|0;w=a;t[o>>2]=e;t[c>>2]=i;t[l>>2]=r;t[b>>2]=n;t[k>>2]=f;t[h>>2]=u;t[w>>2]=0;do if(t[l>>2]|0){u=t[l>>2]|0;if(!(t[t[l>>2]>>2]|0)){sw(u,0,t[b>>2]|0,t[(t[k>>2]|0)+20>>2]|0)|0;t[w>>2]=t[t[l>>2]>>2];break}else{t[w>>2]=t[u>>2];break}}else sw(w,0,t[b>>2]|0,t[(t[k>>2]|0)+20>>2]|0)|0;while(0);b=t[o>>2]|0;if(!(t[k>>2]|0))vT(b,0,t[c>>2]|0,0,0,0,163160,t[w>>2]|0,163192,t[h>>2]|0,0,0);else vT(b,t[k>>2]|0,t[c>>2]|0,0,0,0,163160,t[w>>2]|0,t[(t[k>>2]|0)+8>>2]|0,t[h>>2]|0,0,0);if(!((t[l>>2]|0)==0&(t[w>>2]|0)!=0)){s=a;return}pAi[t[135736>>2]&511](t[w>>2]|0);t[w>>2]=0;s=a;return}function VT(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0;f=s;s=s+32|0;u=f+20|0;a=f+16|0;o=f+12|0;c=f+8|0;l=f+4|0;b=f;t[a>>2]=e;t[o>>2]=i;t[c>>2]=r;t[l>>2]=n;t[b>>2]=gAi[t[135744>>2]&511](24)|0;if(!(t[b>>2]|0)){Qh(t[a>>2]|0,162672,0);t[u>>2]=0;k=t[u>>2]|0;s=f;return k|0}else{t[(t[b>>2]|0)+20>>2]=0;t[t[b>>2]>>2]=2e3;t[(t[b>>2]|0)+12>>2]=t[c>>2];t[(t[b>>2]|0)+16>>2]=t[l>>2];t[(t[b>>2]|0)+4>>2]=0;t[(t[b>>2]|0)+8>>2]=t[o>>2];qT((t[(t[(t[a>>2]|0)+28>>2]|0)+16>>2]|0)+48|0,10,t[b>>2]|0)|0;t[u>>2]=t[b>>2];k=t[u>>2]|0;s=f;return k|0}return 0}function qT(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0;n=s;s=s+16|0;f=n+12|0;u=n+8|0;a=n+4|0;o=n;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;if((t[t[u>>2]>>2]|0)==0?(r=hh()|0,t[t[u>>2]>>2]=r,(t[t[u>>2]>>2]|0)==0):0){t[f>>2]=-1;c=t[f>>2]|0;s=n;return c|0}rL(t[t[u>>2]>>2]|0,t[a>>2]|0,t[o>>2]|0)|0;t[f>>2]=0;c=t[f>>2]|0;s=n;return c|0}function YT(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;var u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0;u=s;s=s+32|0;a=u+24|0;o=u+20|0;c=u+16|0;l=u+12|0;b=u+8|0;k=u+4|0;h=u;t[o>>2]=e;t[c>>2]=i;t[l>>2]=r;t[b>>2]=n;t[k>>2]=f;t[h>>2]=0;if((t[o>>2]|0)==0|(t[c>>2]|0)==0){t[a>>2]=0;w=t[a>>2]|0;s=u;return w|0}t[h>>2]=gAi[t[135744>>2]&511](104)|0;if(!(t[h>>2]|0)){Qh(t[o>>2]|0,165528,0);t[a>>2]=0;w=t[a>>2]|0;s=u;return w|0}f=(t[h>>2]|0)+0|0;n=f+104|0;do{t[f>>2]=0;f=f+4|0}while((f|0)<(n|0));t[t[h>>2]>>2]=14;t[(t[h>>2]|0)+8>>2]=t[c>>2];t[(t[h>>2]|0)+52>>2]=t[l>>2];t[(t[h>>2]|0)+36>>2]=t[b>>2];b=t[(t[(t[o>>2]|0)+28>>2]|0)+16>>2]|0;if(t[k>>2]|0)qT(b+44|0,5,t[h>>2]|0)|0;else qT(b+48|0,10,t[h>>2]|0)|0;qT((t[(t[o>>2]|0)+28>>2]|0)+20|0,10,t[h>>2]|0)|0;t[a>>2]=t[h>>2];w=t[a>>2]|0;s=u;return w|0}function GT(e,i,r,n,f,u,a){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;u=u|0;a=a|0;var o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0;o=s;s=s+48|0;c=o+32|0;l=o+28|0;b=o+24|0;k=o+20|0;h=o+16|0;w=o+12|0;d=o+8|0;v=o+4|0;m=o;t[l>>2]=e;t[b>>2]=i;t[k>>2]=r;t[h>>2]=n;t[w>>2]=f;t[d>>2]=u;t[v>>2]=a;t[m>>2]=Bd(t[h>>2]|0,t[w>>2]|0)|0;if(!(t[m>>2]|0)){t[t[v>>2]>>2]=0;t[t[d>>2]>>2]=0;t[c>>2]=0;_=t[c>>2]|0;s=o;return _|0}else{t[c>>2]=xT(t[l>>2]|0,t[b>>2]|0,t[k>>2]|0,t[m>>2]|0,t[d>>2]|0,t[v>>2]|0)|0;_=t[c>>2]|0;s=o;return _|0}return 0}function WT(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0;f=s;s=s+32|0;u=f+20|0;a=f+16|0;o=f+12|0;c=f+8|0;l=f+4|0;b=f;t[a>>2]=e;t[o>>2]=i;t[c>>2]=r;t[l>>2]=n;t[b>>2]=Sw(t[a>>2]|0,t[o>>2]|0,t[c>>2]|0)|0;if(!(t[b>>2]|0)){t[u>>2]=t[l>>2];k=t[u>>2]|0;s=f;return k|0}do if(!(Xl(t[b>>2]|0,165504)|0)){if(Xl(t[b>>2]|0,165512)|0){t[l>>2]=0;break}if(Xl(t[b>>2]|0,161736)|0){t[l>>2]=1;break}if(Xl(t[b>>2]|0,165520)|0){t[l>>2]=0;break}else{n=t[a>>2]|0;r=Bd(t[o>>2]|0,t[c>>2]|0)|0;i=ED(15)|0;Ud(n,1714,0,r,i,0,t[b>>2]|0,0,0,0);break}}else t[l>>2]=1;while(0);t[u>>2]=t[l>>2];k=t[u>>2]|0;s=f;return k|0}function KT(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;var u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0;u=s;s=s+48|0;a=u+44|0;o=u+40|0;c=u+36|0;l=u+32|0;b=u+28|0;k=u+24|0;h=u+20|0;w=u+16|0;d=u+12|0;v=u+8|0;m=u+4|0;_=u;t[o>>2]=e;t[c>>2]=i;t[l>>2]=r;t[b>>2]=n;t[k>>2]=f;t[h>>2]=0;t[w>>2]=0;t[v>>2]=0;t[m>>2]=0;t[_>>2]=0;t[d>>2]=t[(t[l>>2]|0)+44>>2];while(1){if(!(t[d>>2]|0))break;f=t[d>>2]|0;do if(!(t[(t[d>>2]|0)+36>>2]|0)){if((Xl(t[f+8>>2]|0,161384)|0)==0?(Xl(t[(t[d>>2]|0)+8>>2]|0,161352)|0)==0:0){if((t[b>>2]|0)==24?(Xl(t[(t[d>>2]|0)+8>>2]|0,160144)|0)!=0:0)break;_T(t[o>>2]|0,3035,0,t[d>>2]|0)}}else if(Xl(t[(t[f+36>>2]|0)+8>>2]|0,t[38526]|0)|0)_T(t[o>>2]|0,3035,0,t[d>>2]|0);while(0);t[d>>2]=t[(t[d>>2]|0)+24>>2]}t[d>>2]=Bd(t[l>>2]|0,161352)|0;f=t[o>>2]|0;if(!(t[d>>2]|0)){FT(f,3036,0,t[l>>2]|0,161352,0);t[a>>2]=0;p=t[a>>2]|0;s=u;return p|0}n=t[d>>2]|0;if(Id(f,0,n,ED(22)|0,v)|0){t[a>>2]=0;p=t[a>>2]|0;s=u;return p|0}t[h>>2]=tD(t[o>>2]|0,t[c>>2]|0,t[v>>2]|0,t[k>>2]|0,t[b>>2]|0,t[l>>2]|0)|0;if(!(t[h>>2]|0)){t[a>>2]=0;p=t[a>>2]|0;s=u;return p|0}Pd(t[o>>2]|0,t[l>>2]|0,161384)|0;do if((t[b>>2]|0)==24){t[d>>2]=Bd(t[l>>2]|0,160144)|0;k=t[o>>2]|0;if(!(t[d>>2]|0)){FT(k,3036,0,t[l>>2]|0,160144,0);break}v=VT(k,23,0,0)|0;t[(t[h>>2]|0)+36>>2]=v;if(t[(t[h>>2]|0)+36>>2]|0){xT(t[o>>2]|0,t[c>>2]|0,0,t[d>>2]|0,(t[(t[h>>2]|0)+36>>2]|0)+16|0,(t[(t[h>>2]|0)+36>>2]|0)+12|0)|0;UT(t[o>>2]|0,t[c>>2]|0,t[l>>2]|0,t[d>>2]|0,t[(t[(t[h>>2]|0)+36>>2]|0)+16>>2]|0)|0;break}t[a>>2]=0;p=t[a>>2]|0;s=u;return p|0}while(0);t[w>>2]=t[(t[l>>2]|0)+12>>2];if((((t[w>>2]|0)!=0?(t[(t[w>>2]|0)+36>>2]|0)!=0:0)?(Xl(t[(t[w>>2]|0)+8>>2]|0,160992)|0)!=0:0)?(Xl(t[(t[(t[w>>2]|0)+36>>2]|0)+8>>2]|0,t[38526]|0)|0)!=0:0){d=jd(t[o>>2]|0,t[w>>2]|0,1)|0;t[(t[h>>2]|0)+4>>2]=d;t[w>>2]=t[(t[w>>2]|0)+24>>2]}if(!(t[w>>2]|0))$d(t[o>>2]|0,3034,0,t[l>>2]|0,t[w>>2]|0,164808,164840);e:do if((((t[w>>2]|0)!=0?(t[(t[w>>2]|0)+36>>2]|0)!=0:0)?(Xl(t[(t[w>>2]|0)+8>>2]|0,164880)|0)!=0:0)?(Xl(t[(t[(t[w>>2]|0)+36>>2]|0)+8>>2]|0,t[38526]|0)|0)!=0:0){d=uD(t[o>>2]|0,t[h>>2]|0,t[w>>2]|0,0)|0;t[(t[h>>2]|0)+24>>2]=d;t[w>>2]=t[(t[w>>2]|0)+24>>2];if((((t[w>>2]|0)!=0?(t[(t[w>>2]|0)+36>>2]|0)!=0:0)?(Xl(t[(t[w>>2]|0)+8>>2]|0,164896)|0)!=0:0)?(Xl(t[(t[(t[w>>2]|0)+36>>2]|0)+8>>2]|0,t[38526]|0)|0)!=0:0)while(1){t[m>>2]=uD(t[o>>2]|0,t[h>>2]|0,t[w>>2]|0,1)|0;if(t[m>>2]|0){t[(t[m>>2]|0)+8>>2]=t[(t[h>>2]|0)+32>>2];d=(t[h>>2]|0)+32|0;t[d>>2]=(t[d>>2]|0)+1;d=t[m>>2]|0;if(t[_>>2]|0)t[t[_>>2]>>2]=d;else t[(t[h>>2]|0)+28>>2]=d;t[_>>2]=t[m>>2]}t[w>>2]=t[(t[w>>2]|0)+24>>2];if(!(t[w>>2]|0))break e;if(!(t[(t[w>>2]|0)+36>>2]|0))break e;if(!(Xl(t[(t[w>>2]|0)+8>>2]|0,164896)|0))break e;if(!(Xl(t[(t[(t[w>>2]|0)+36>>2]|0)+8>>2]|0,t[38526]|0)|0))break e}$d(t[o>>2]|0,3033,0,t[l>>2]|0,t[w>>2]|0,0,164840)}while(0);if(t[w>>2]|0)$d(t[o>>2]|0,3033,0,t[l>>2]|0,t[w>>2]|0,0,164840);t[a>>2]=t[h>>2];p=t[a>>2]|0;s=u;return p|0}function XT(e,i,r,n,f,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;u=u|0;var a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0;a=s;s=s+32|0;o=a+28|0;c=a+24|0;l=a+20|0;b=a+16|0;k=a+12|0;h=a+8|0;w=a+4|0;d=a;t[c>>2]=e;t[l>>2]=i;t[b>>2]=r;t[k>>2]=n;t[h>>2]=f;t[w>>2]=u;t[d>>2]=0;if((t[c>>2]|0)==0|(t[l>>2]|0)==0){t[o>>2]=0;v=t[o>>2]|0;s=a;return v|0}t[d>>2]=gAi[t[135744>>2]&511](76)|0;if(!(t[d>>2]|0)){Qh(t[c>>2]|0,164272,0);t[o>>2]=0;v=t[o>>2]|0;s=a;return v|0}l=(t[d>>2]|0)+0|0;u=l+76|0;do{t[l>>2]=0;l=l+4|0}while((l|0)<(u|0));t[t[d>>2]>>2]=15;t[(t[d>>2]|0)+52>>2]=t[h>>2];t[(t[d>>2]|0)+8>>2]=t[b>>2];t[(t[d>>2]|0)+56>>2]=t[k>>2];k=t[(t[(t[c>>2]|0)+28>>2]|0)+16>>2]|0;if(t[w>>2]|0)qT(k+44|0,5,t[d>>2]|0)|0;else qT(k+48|0,10,t[d>>2]|0)|0;qT((t[(t[c>>2]|0)+28>>2]|0)+20|0,10,t[d>>2]|0)|0;t[o>>2]=t[d>>2];v=t[o>>2]|0;s=a;return v|0}function ZT(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;var u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0;u=s;s=s+32|0;a=u+24|0;o=u+20|0;c=u+12|0;l=u+8|0;b=u+4|0;k=u;t[o>>2]=e;t[u+16>>2]=i;t[c>>2]=r;t[l>>2]=n;t[b>>2]=f;t[k>>2]=0;if((t[o>>2]|0)==0|(t[c>>2]|0)==0){t[a>>2]=0;h=t[a>>2]|0;s=u;return h|0}t[k>>2]=gAi[t[135744>>2]&511](60)|0;if(!(t[k>>2]|0)){Qh(t[o>>2]|0,164360,0);t[a>>2]=0;h=t[a>>2]|0;s=u;return h|0}f=(t[k>>2]|0)+0|0;n=f+60|0;do{t[f>>2]=0;f=f+4|0}while((f|0)<(n|0));t[t[k>>2]>>2]=16;t[(t[k>>2]|0)+8>>2]=t[c>>2];t[(t[k>>2]|0)+52>>2]=t[l>>2];t[(t[k>>2]|0)+32>>2]=t[b>>2];b=(t[k>>2]|0)+36|0;t[b>>2]=t[b>>2]|2;do if(t[(t[o>>2]|0)+100>>2]|0){b=_L(t[o>>2]|0,t[(t[o>>2]|0)+116>>2]|0,t[k>>2]|0,t[c>>2]|0,t[l>>2]|0)|0;t[(t[o>>2]|0)+120>>2]=b;if(t[(t[o>>2]|0)+120>>2]|0){t[(t[o>>2]|0)+124>>2]=0;break}pAi[t[135736>>2]&511](t[k>>2]|0);t[a>>2]=0;h=t[a>>2]|0;s=u;return h|0}while(0);qT((t[(t[(t[o>>2]|0)+28>>2]|0)+16>>2]|0)+44|0,5,t[k>>2]|0)|0;qT((t[(t[o>>2]|0)+28>>2]|0)+20|0,10,t[k>>2]|0)|0;
	t[a>>2]=t[k>>2];h=t[a>>2]|0;s=u;return h|0}function JT(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;var u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0;u=s;s=s+32|0;a=u+24|0;o=u+20|0;c=u+16|0;l=u+12|0;b=u+8|0;k=u+4|0;h=u;t[o>>2]=e;t[c>>2]=i;t[l>>2]=r;t[b>>2]=n;t[k>>2]=f;t[h>>2]=0;if((t[o>>2]|0)==0|(t[c>>2]|0)==0|(t[l>>2]|0)==0){t[a>>2]=0;w=t[a>>2]|0;s=u;return w|0}t[h>>2]=gAi[t[135744>>2]&511](32)|0;if(!(t[h>>2]|0)){Qh(t[o>>2]|0,163256,0);t[a>>2]=0;w=t[a>>2]|0;s=u;return w|0}c=t[h>>2]|0;t[c+0>>2]=0;t[c+4>>2]=0;t[c+8>>2]=0;t[c+12>>2]=0;t[c+16>>2]=0;t[c+20>>2]=0;t[c+24>>2]=0;t[c+28>>2]=0;t[(t[h>>2]|0)+16>>2]=t[l>>2];t[t[h>>2]>>2]=17;t[(t[h>>2]|0)+24>>2]=t[k>>2];t[(t[h>>2]|0)+20>>2]=t[b>>2];do if(t[(t[o>>2]|0)+100>>2]|0){k=_L(t[o>>2]|0,t[(t[o>>2]|0)+116>>2]|0,t[h>>2]|0,t[l>>2]|0,t[b>>2]|0)|0;t[(t[o>>2]|0)+120>>2]=k;if(t[(t[o>>2]|0)+120>>2]|0){t[(t[o>>2]|0)+124>>2]=0;break}pAi[t[135736>>2]&511](t[h>>2]|0);t[a>>2]=0;w=t[a>>2]|0;s=u;return w|0}while(0);qT((t[(t[(t[o>>2]|0)+28>>2]|0)+16>>2]|0)+44|0,5,t[h>>2]|0)|0;qT((t[(t[o>>2]|0)+28>>2]|0)+20|0,10,t[h>>2]|0)|0;t[a>>2]=t[h>>2];w=t[a>>2]|0;s=u;return w|0}function QT(e,i,r,n,f,u,a){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;u=u|0;a=a|0;var o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0;o=s;s=s+32|0;c=o+24|0;l=o+20|0;b=o+16|0;k=o+12|0;h=o+8|0;w=o+4|0;d=o;t[c>>2]=e;t[l>>2]=i;t[b>>2]=r;t[k>>2]=n;t[h>>2]=f;t[w>>2]=u;t[d>>2]=a;a=t[c>>2]|0;if(t[b>>2]|0){pw(a,t[b>>2]|0,t[k>>2]|0,t[h>>2]|0,t[w>>2]|0,t[d>>2]|0);s=o;return}else{pw(a,t[l>>2]|0,t[k>>2]|0,t[h>>2]|0,t[w>>2]|0,t[d>>2]|0);s=o;return}}function $T(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;var u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0;u=s;s=s+32|0;a=u+24|0;o=u+20|0;c=u+16|0;l=u+12|0;b=u+8|0;k=u;t[o>>2]=e;t[c>>2]=i;t[l>>2]=r;t[b>>2]=n;t[u+4>>2]=f;t[k>>2]=0;if((t[o>>2]|0)==0|(t[c>>2]|0)==0|(t[l>>2]|0)==0){t[a>>2]=0;h=t[a>>2]|0;s=u;return h|0}t[k>>2]=gAi[t[135744>>2]&511](20)|0;if(!(t[k>>2]|0)){Qh(t[o>>2]|0,161632,0);t[a>>2]=0;h=t[a>>2]|0;s=u;return h|0}else{c=t[k>>2]|0;t[c+0>>2]=0;t[c+4>>2]=0;t[c+8>>2]=0;t[c+12>>2]=0;t[c+16>>2]=0;t[t[k>>2]>>2]=18;t[(t[k>>2]|0)+4>>2]=t[l>>2];t[(t[k>>2]|0)+16>>2]=t[b>>2];qT((t[(t[(t[o>>2]|0)+28>>2]|0)+16>>2]|0)+44|0,5,t[k>>2]|0)|0;t[a>>2]=t[k>>2];h=t[a>>2]|0;s=u;return h|0}return 0}function eL(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0;n=s;s=s+32|0;f=n+20|0;u=n+16|0;a=n+12|0;o=n+8|0;c=n+4|0;l=n;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;t[c>>2]=0;if((t[a>>2]|0)==0|(t[u>>2]|0)==0){t[f>>2]=0;b=t[f>>2]|0;s=n;return b|0}do if(t[u>>2]|0){if((Xl(t[o>>2]|0,t[(t[u>>2]|0)+4>>2]|0)|0)!=0?(t[c>>2]=rO(t[(t[u>>2]|0)+56>>2]|0,t[a>>2]|0)|0,(t[c>>2]|0)!=0):0)break;if((bO(t[(t[u>>2]|0)+48>>2]|0)|0)>1){r=t[(t[u>>2]|0)+48>>2]|0;if(!(t[o>>2]|0))t[l>>2]=rO(r,145792)|0;else t[l>>2]=rO(r,t[o>>2]|0)|0;if(t[l>>2]|0)t[c>>2]=rO(t[(t[(t[l>>2]|0)+52>>2]|0)+56>>2]|0,t[a>>2]|0)|0}}while(0);t[f>>2]=t[c>>2];b=t[f>>2]|0;s=n;return b|0}function iL(e,i,r,n,f,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;u=u|0;a=a|0;o=o|0;var c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0;c=s;s=s+48|0;l=c+36|0;b=c+32|0;k=c+28|0;h=c+24|0;w=c+20|0;d=c+16|0;v=c+12|0;m=c+8|0;_=c+4|0;p=c;t[l>>2]=e;t[b>>2]=i;t[k>>2]=r;t[h>>2]=n;t[w>>2]=f;t[d>>2]=u;t[v>>2]=a;t[m>>2]=o;t[_>>2]=0;t[p>>2]=0;sw(_,0,t[k>>2]|0,t[h>>2]|0)|0;t[p>>2]=Yl(147824)|0;t[p>>2]=us(t[p>>2]|0,t[w>>2]|0)|0;t[p>>2]=us(t[p>>2]|0,142704)|0;if((t[h>>2]|0)==0&(t[k>>2]|0)!=0)t[h>>2]=lw(t[k>>2]|0)|0;vT(t[l>>2]|0,t[h>>2]|0,t[b>>2]|0,0,0,0,t[p>>2]|0,t[_>>2]|0,t[d>>2]|0,t[v>>2]|0,t[m>>2]|0,0);if(t[_>>2]|0){pAi[t[135736>>2]&511](t[_>>2]|0);t[_>>2]=0}if(!(t[p>>2]|0)){s=c;return}pAi[t[135736>>2]&511](t[p>>2]|0);t[p>>2]=0;s=c;return}function rL(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0;n=s;s=s+16|0;f=n+12|0;u=n+8|0;a=n+4|0;o=n;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;do if(t[t[u>>2]>>2]|0){if((t[(t[u>>2]|0)+8>>2]|0)<=(t[(t[u>>2]|0)+4>>2]|0)?(r=(t[u>>2]|0)+8|0,t[r>>2]=t[r>>2]<<1,r=MAi[t[135760>>2]&511](t[t[u>>2]>>2]|0,t[(t[u>>2]|0)+8>>2]<<2)|0,t[t[u>>2]>>2]=r,(t[t[u>>2]>>2]|0)==0):0){Qh(0,142376,0);t[(t[u>>2]|0)+8>>2]=0;t[f>>2]=-1;c=t[f>>2]|0;s=n;return c|0}}else{if((t[a>>2]|0)<=0)t[a>>2]=1;r=gAi[t[135744>>2]&511](t[a>>2]<<2)|0;t[t[u>>2]>>2]=r;if(t[t[u>>2]>>2]|0){t[(t[u>>2]|0)+8>>2]=t[a>>2];break}Qh(0,142344,0);t[f>>2]=-1;c=t[f>>2]|0;s=n;return c|0}while(0);a=t[o>>2]|0;o=(t[u>>2]|0)+4|0;r=t[o>>2]|0;t[o>>2]=r+1;t[(t[t[u>>2]>>2]|0)+(r<<2)>>2]=a;t[f>>2]=0;c=t[f>>2]|0;s=n;return c|0}function nL(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0;f=s;s=s+32|0;u=f+20|0;a=f+16|0;o=f+12|0;c=f+8|0;l=f+4|0;b=f;t[a>>2]=e;t[o>>2]=i;t[c>>2]=r;t[l>>2]=n;t[b>>2]=0;if((t[a>>2]|0)==0|(t[o>>2]|0)==0){t[u>>2]=0;k=t[u>>2]|0;s=f;return k|0}t[b>>2]=gAi[t[135744>>2]&511](44)|0;if(!(t[b>>2]|0)){Qh(t[a>>2]|0,153064,0);t[u>>2]=0;k=t[u>>2]|0;s=f;return k|0}else{o=(t[b>>2]|0)+0|0;n=o+44|0;do{t[o>>2]=0;o=o+4|0}while((o|0)<(n|0));t[t[b>>2]>>2]=t[c>>2];t[(t[b>>2]|0)+12>>2]=t[l>>2];qT((t[(t[(t[a>>2]|0)+28>>2]|0)+16>>2]|0)+48|0,10,t[b>>2]|0)|0;t[u>>2]=t[b>>2];k=t[u>>2]|0;s=f;return k|0}return 0}function fL(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0;n=s;s=s+32|0;f=n+24|0;u=n+20|0;a=n+16|0;o=n+12|0;c=n+8|0;l=n+4|0;b=n;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;if((t[o>>2]|0)==0|(t[a>>2]|0)==0){t[f>>2]=-1;k=t[f>>2]|0;s=n;return k|0}t[(t[a>>2]|0)+28>>2]=t[(t[o>>2]|0)+28>>2];t[c>>2]=t[(t[o>>2]|0)+32>>2];t[b>>2]=0;while(1){if(!(t[c>>2]|0))break;t[l>>2]=aD(t[u>>2]|0)|0;if(!(t[l>>2]|0)){h=6;break}t[(t[l>>2]|0)+4>>2]=t[(t[c>>2]|0)+4>>2];r=t[l>>2]|0;if(!(t[b>>2]|0))t[(t[a>>2]|0)+32>>2]=r;else t[t[b>>2]>>2]=r;t[b>>2]=t[l>>2];t[c>>2]=t[t[c>>2]>>2]}if((h|0)==6){t[f>>2]=-1;k=t[f>>2]|0;s=n;return k|0}if(t[(t[a>>2]|0)+36>>2]|0)Gk(t[(t[a>>2]|0)+36>>2]|0);do if(t[(t[o>>2]|0)+36>>2]|0){h=aD(t[u>>2]|0)|0;t[(t[a>>2]|0)+36>>2]=h;if(t[(t[a>>2]|0)+36>>2]|0){t[(t[(t[a>>2]|0)+36>>2]|0)+4>>2]=t[(t[(t[o>>2]|0)+36>>2]|0)+4>>2];break}t[f>>2]=-1;k=t[f>>2]|0;s=n;return k|0}else t[(t[a>>2]|0)+36>>2]=0;while(0);t[f>>2]=0;k=t[f>>2]|0;s=n;return k|0}function tL(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0;n=s;s=s+48|0;f=n+40|0;u=n+36|0;a=n+32|0;o=n+28|0;c=n+24|0;l=n+20|0;b=n+16|0;k=n+12|0;h=n+8|0;w=n+4|0;d=n;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;do if(((t[(t[a>>2]|0)+28>>2]|0)==(t[(t[o>>2]|0)+28>>2]|0)?((t[(t[a>>2]|0)+32>>2]|0)==0|0)==((t[(t[o>>2]|0)+32>>2]|0)==0|0):0)?((t[(t[a>>2]|0)+36>>2]|0)==0|0)==((t[(t[o>>2]|0)+36>>2]|0)==0|0):0){if((t[(t[a>>2]|0)+36>>2]|0)!=0?(t[(t[(t[a>>2]|0)+36>>2]|0)+4>>2]|0)!=(t[(t[(t[o>>2]|0)+36>>2]|0)+4>>2]|0):0)break;if(!(t[(t[a>>2]|0)+32>>2]|0)){t[f>>2]=0;v=t[f>>2]|0;s=n;return v|0}t[h>>2]=0;t[c>>2]=t[(t[a>>2]|0)+32>>2];while(1){if(!(t[c>>2]|0))break;t[h>>2]=0;t[l>>2]=t[(t[o>>2]|0)+32>>2];while(1){if(!(t[l>>2]|0))break;if((t[(t[c>>2]|0)+4>>2]|0)==(t[(t[l>>2]|0)+4>>2]|0)){m=12;break}t[l>>2]=t[t[l>>2]>>2]}if((m|0)==12){m=0;t[h>>2]=1}if(!(t[h>>2]|0))break;t[c>>2]=t[t[c>>2]>>2]}if(t[h>>2]|0){t[f>>2]=0;v=t[f>>2]|0;s=n;return v|0}}while(0);if((t[(t[a>>2]|0)+28>>2]|0)!=(t[(t[o>>2]|0)+28>>2]|0)?(t[(t[a>>2]|0)+28>>2]|0)!=0:0)if((fL(t[u>>2]|0,t[a>>2]|0,t[o>>2]|0)|0)==-1){t[f>>2]=-1;v=t[f>>2]|0;s=n;return v|0}else{t[f>>2]=0;v=t[f>>2]|0;s=n;return v|0}if(!((t[(t[a>>2]|0)+36>>2]|0)!=0?(t[(t[o>>2]|0)+32>>2]|0)!=0:0))m=26;do if((m|0)==26){if((t[(t[o>>2]|0)+36>>2]|0)!=0?(t[(t[a>>2]|0)+32>>2]|0)!=0:0)break;if((t[(t[a>>2]|0)+32>>2]|0)!=0?(t[(t[o>>2]|0)+32>>2]|0)!=0:0){t[c>>2]=t[(t[a>>2]|0)+32>>2];t[b>>2]=0;while(1){if(!(t[c>>2]|0))break;t[d>>2]=0;t[l>>2]=t[(t[o>>2]|0)+32>>2];while(1){if(!(t[l>>2]|0))break;if((t[(t[c>>2]|0)+4>>2]|0)==(t[(t[l>>2]|0)+4>>2]|0)){m=57;break}t[l>>2]=t[t[l>>2]>>2]}if((m|0)==57){m=0;t[d>>2]=1}if(t[d>>2]|0){t[b>>2]=t[c>>2];t[c>>2]=t[t[c>>2]>>2];continue}h=t[t[c>>2]>>2]|0;if(!(t[b>>2]|0))t[(t[a>>2]|0)+32>>2]=h;else t[t[b>>2]>>2]=h;t[k>>2]=t[t[c>>2]>>2];pAi[t[135736>>2]&511](t[c>>2]|0);t[c>>2]=t[k>>2]}t[f>>2]=0;v=t[f>>2]|0;s=n;return v|0}if(((((t[(t[a>>2]|0)+36>>2]|0)!=0?(t[(t[o>>2]|0)+36>>2]|0)!=0:0)?(t[(t[(t[a>>2]|0)+36>>2]|0)+4>>2]|0)!=(t[(t[(t[o>>2]|0)+36>>2]|0)+4>>2]|0):0)?(t[(t[(t[a>>2]|0)+36>>2]|0)+4>>2]|0)!=0:0)?(t[(t[(t[o>>2]|0)+36>>2]|0)+4>>2]|0)!=0:0){pw(t[u>>2]|0,t[(t[a>>2]|0)+12>>2]|0,1793,153008,0,0);t[f>>2]=1793;v=t[f>>2]|0;s=n;return v|0}if((((t[(t[a>>2]|0)+36>>2]|0)!=0?(t[(t[o>>2]|0)+36>>2]|0)!=0:0)?(t[(t[(t[a>>2]|0)+36>>2]|0)+4>>2]|0)!=(t[(t[(t[o>>2]|0)+36>>2]|0)+4>>2]|0):0)?(t[(t[(t[a>>2]|0)+36>>2]|0)+4>>2]|0)==0:0)t[(t[(t[a>>2]|0)+36>>2]|0)+4>>2]=t[(t[(t[o>>2]|0)+36>>2]|0)+4>>2];t[f>>2]=0;v=t[f>>2]|0;s=n;return v|0}while(0);if(!(t[(t[a>>2]|0)+32>>2]|0)){t[w>>2]=t[(t[(t[a>>2]|0)+36>>2]|0)+4>>2];if((fL(t[u>>2]|0,t[a>>2]|0,t[o>>2]|0)|0)==-1){t[f>>2]=-1;v=t[f>>2]|0;s=n;return v|0}}else t[w>>2]=t[(t[(t[o>>2]|0)+36>>2]|0)+4>>2];t[b>>2]=0;t[c>>2]=t[(t[a>>2]|0)+32>>2];while(1){if(!(t[c>>2]|0))break;if(!(t[(t[c>>2]|0)+4>>2]|0)){m=35;break}t[b>>2]=t[c>>2];t[c>>2]=t[t[c>>2]>>2]}if((m|0)==35){m=t[t[c>>2]>>2]|0;if(!(t[b>>2]|0))t[(t[a>>2]|0)+32>>2]=m;else t[t[b>>2]>>2]=m;pAi[t[135736>>2]&511](t[c>>2]|0)}e:do if(t[w>>2]|0){t[b>>2]=0;t[c>>2]=t[(t[a>>2]|0)+32>>2];while(1){if(!(t[c>>2]|0))break e;if((t[(t[c>>2]|0)+4>>2]|0)==(t[w>>2]|0))break;t[b>>2]=t[c>>2];t[c>>2]=t[t[c>>2]>>2]}m=t[t[c>>2]>>2]|0;if(!(t[b>>2]|0))t[(t[a>>2]|0)+32>>2]=m;else t[t[b>>2]>>2]=m;pAi[t[135736>>2]&511](t[c>>2]|0)}while(0);t[f>>2]=0;v=t[f>>2]|0;s=n;return v|0}function uL(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,l=0;n=s;s=s+32|0;f=n+16|0;u=n+12|0;a=n+8|0;o=n+4|0;c=n;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;do if(t[t[u>>2]>>2]|0){if((t[(t[u>>2]|0)+8>>2]|0)<=(t[(t[u>>2]|0)+4>>2]|0)?(r=(t[u>>2]|0)+8|0,t[r>>2]=t[r>>2]<<1,r=MAi[t[135760>>2]&511](t[t[u>>2]>>2]|0,t[(t[u>>2]|0)+8>>2]<<2)|0,t[t[u>>2]>>2]=r,(t[t[u>>2]>>2]|0)==0):0){Qh(0,142376,0);t[(t[u>>2]|0)+8>>2]=0;t[f>>2]=-1;l=t[f>>2]|0;s=n;return l|0}}else{r=gAi[t[135744>>2]&511](80)|0;t[t[u>>2]>>2]=r;if(t[t[u>>2]>>2]|0){t[(t[u>>2]|0)+8>>2]=20;break}Qh(0,142344,0);t[f>>2]=-1;l=t[f>>2]|0;s=n;return l|0}while(0);if((t[o>>2]|0)>=(t[(t[u>>2]|0)+4>>2]|0)){r=t[a>>2]|0;i=(t[u>>2]|0)+4|0;e=t[i>>2]|0;t[i>>2]=e+1;t[(t[t[u>>2]>>2]|0)+(e<<2)>>2]=r}else{t[c>>2]=t[(t[u>>2]|0)+4>>2];while(1){if((t[c>>2]|0)<=(t[o>>2]|0))break;t[(t[t[u>>2]>>2]|0)+(t[c>>2]<<2)>>2]=t[(t[t[u>>2]>>2]|0)+((t[c>>2]|0)-1<<2)>>2];t[c>>2]=(t[c>>2]|0)+-1}t[(t[t[u>>2]>>2]|0)+(t[o>>2]<<2)>>2]=t[a>>2];a=(t[u>>2]|0)+4|0;t[a>>2]=(t[a>>2]|0)+1}t[f>>2]=0;l=t[f>>2]|0;s=n;return l|0}function aL(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0;r=s;s=s+16|0;n=r+8|0;f=r+4|0;u=r;t[f>>2]=e;t[u>>2]=i;do if(t[f>>2]|0)if(t[(t[f>>2]|0)+48>>2]&t[u>>2]){t[n>>2]=1;break}else{t[n>>2]=0;break}else t[n>>2]=0;while(0);s=r;return t[n>>2]|0}function oL(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;var u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0;u=s;s=s+32|0;a=u+24|0;o=u+20|0;c=u+16|0;l=u+12|0;b=u+8|0;k=u+4|0;h=u;t[a>>2]=e;t[o>>2]=i;t[c>>2]=r;t[l>>2]=n;t[b>>2]=f;t[k>>2]=0;t[h>>2]=0;sw(k,0,t[c>>2]|0,t[(t[c>>2]|0)+36>>2]|0)|0;f=t[a>>2]|0;a=t[(t[c>>2]|0)+36>>2]|0;c=t[o>>2]|0;o=t[k>>2]|0;n=fh(t[t[b>>2]>>2]|0)|0;vT(f,a,c,0,0,0,149488,o,n,sw(h,0,t[l>>2]|0,0)|0,0,0);if(t[k>>2]|0){pAi[t[135736>>2]&511](t[k>>2]|0);t[k>>2]=0}if(!(t[h>>2]|0)){s=u;return}pAi[t[135736>>2]&511](t[h>>2]|0);t[h>>2]=0;s=u;return}function cL(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,u=0,a=0,o=0,c=0,l=0;f=s;s=s+32|0;u=f+16|0;a=f+12|0;o=f+8|0;c=f+4|0;l=f;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;t[c>>2]=n;t[l>>2]=0;sw(l,0,t[o>>2]|0,t[(t[o>>2]|0)+36>>2]|0)|0;n=t[u>>2]|0;u=t[(t[o>>2]|0)+36>>2]|0;o=t[a>>2]|0;a=t[l>>2]|0;pw(n,u,o,149448,a,fh(t[t[c>>2]>>2]|0)|0);if(!(t[l>>2]|0)){s=f;return}pAi[t[135736>>2]&511](t[l>>2]|0);t[l>>2]=0;s=f;return}function lL(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0;f=s;s=s+32|0;u=f+20|0;a=f+16|0;o=f+12|0;c=f+8|0;l=f+4|0;b=f;t[a>>2]=e;t[o>>2]=i;t[c>>2]=r;t[l>>2]=n;if((t[o>>2]|0)==(t[c>>2]|0)){t[u>>2]=0;k=t[u>>2]|0;s=f;return k|0}if(((t[t[o>>2]>>2]|0)!=1?(t[(t[o>>2]|0)+48>>2]&4194304|0)==0:0)?(wv(t[o>>2]|0,t[a>>2]|0)|0)==-1:0){t[u>>2]=-1;k=t[u>>2]|0;s=f;return k|0}if(((t[t[c>>2]>>2]|0)!=1?(t[(t[c>>2]|0)+48>>2]&4194304|0)==0:0)?(wv(t[c>>2]|0,t[a>>2]|0)|0)==-1:0){t[u>>2]=-1;k=t[u>>2]|0;s=f;return k|0}if((t[l>>2]&1|0)==0?(aL(t[(t[o>>2]|0)+64>>2]|0,1024)|0)==0:0){if((t[(t[o>>2]|0)+64>>2]|0)==(t[c>>2]|0)){t[u>>2]=0;k=t[u>>2]|0;s=f;return k|0}if(!((t[t[(t[o>>2]|0)+64>>2]>>2]|0)==1?(t[(t[(t[o>>2]|0)+64>>2]|0)+88>>2]|0)==45:0))h=18;if((h|0)==18?(lL(t[a>>2]|0,t[(t[o>>2]|0)+64>>2]|0,t[c>>2]|0,t[l>>2]|0)|0)==0:0){t[u>>2]=0;k=t[u>>2]|0;s=f;return k|0}do if((t[t[c>>2]>>2]|0)==1?(t[(t[c>>2]|0)+88>>2]|0)==46:0){if((t[(t[o>>2]|0)+48>>2]&64|0)==0?(t[(t[o>>2]|0)+48>>2]&128|0)==0:0)break;t[u>>2]=0;k=t[u>>2]|0;s=f;return k|0}while(0);e:do if(t[(t[c>>2]|0)+48>>2]&128){t[b>>2]=t[(t[c>>2]|0)+92>>2];while(1){if(!(t[b>>2]|0))break e;if(((t[t[(t[b>>2]|0)+4>>2]>>2]|0)!=1?(t[(t[(t[b>>2]|0)+4>>2]|0)+48>>2]&4194304|0)==0:0)?(wv(t[(t[b>>2]|0)+4>>2]|0,t[a>>2]|0)|0)==-1:0){h=31;break}if(!(lL(t[a>>2]|0,t[o>>2]|0,t[(t[b>>2]|0)+4>>2]|0,t[l>>2]|0)|0)){h=33;break}t[b>>2]=t[t[b>>2]>>2]}if((h|0)==31){t[u>>2]=-1;k=t[u>>2]|0;s=f;return k|0}else if((h|0)==33){t[u>>2]=0;k=t[u>>2]|0;s=f;return k|0}}while(0);t[u>>2]=3032;k=t[u>>2]|0;s=f;return k|0}t[u>>2]=3031;k=t[u>>2]|0;s=f;return k|0}function sL(e){e=e|0;var i=0,r=0,n=0,f=0;i=s;s=s+16|0;r=i+4|0;n=i;t[n>>2]=e;do if(!(t[(t[n>>2]|0)+92>>2]|0)){e=Ik(0)|0;t[(t[n>>2]|0)+92>>2]=e;e=t[n>>2]|0;if(t[(t[n>>2]|0)+92>>2]|0){Ck(t[e+92>>2]|0,t[(t[n>>2]|0)+8>>2]|0,t[(t[n>>2]|0)+12>>2]|0,t[(t[n>>2]|0)+4>>2]|0);Bk(t[(t[n>>2]|0)+92>>2]|0,t[(t[n>>2]|0)+24>>2]|0,t[(t[n>>2]|0)+4>>2]|0);break}pw(e,0,3069,148224,0,0);t[r>>2]=-1;f=t[r>>2]|0;s=i;return f|0}while(0);t[r>>2]=0;f=t[r>>2]|0;s=i;return f|0}function bL(e,i,r,n,f,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;u=u|0;var a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0;a=s;s=s+32|0;o=a+24|0;c=a+20|0;l=a+16|0;b=a+12|0;k=a+8|0;h=a+4|0;w=a;t[o>>2]=e;t[c>>2]=i;t[l>>2]=r;t[b>>2]=n;t[k>>2]=f;t[h>>2]=u;t[w>>2]=0;t[w>>2]=Yl(142568)|0;u=t[w>>2]|0;t[w>>2]=us(u,fh(t[t[c>>2]>>2]|0)|0)|0;t[w>>2]=us(t[w>>2]|0,147720)|0;if(!(t[b>>2]|0))t[w>>2]=us(t[w>>2]|0,147736)|0;u=t[w>>2]|0;if((t[b>>2]|0)==1)t[w>>2]=us(u,147752)|0;else t[w>>2]=us(u,147768)|0;if(t[k>>2]|0)t[w>>2]=us(t[w>>2]|0,147784)|0;t[w>>2]=us(t[w>>2]|0,143656)|0;k=t[w>>2]|0;t[w>>2]=us(k,fh(t[t[l>>2]>>2]|0)|0)|0;l=t[w>>2]|0;if(t[h>>2]|0)t[w>>2]=us(l,147800)|0;else t[w>>2]=us(l,142568)|0;sv(t[o>>2]|0,1717,t[c>>2]|0,0,t[w>>2]|0,0);if(!(t[w>>2]|0)){s=a;return}pAi[t[135736>>2]&511](t[w>>2]|0);s=a;return}function kL(e){e=e|0;var i=0,r=0;i=s;s=s+16|0;r=i;t[r>>2]=e;dp(16,2,0,0,t[r>>2]|0);s=i;return}function hL(e,i,r,n,f,u,a,o,c,l){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;u=u|0;a=a|0;o=o|0;c=c|0;l=l|0;var b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0,S=0,g=0,y=0;b=s;s=s+48|0;k=b+44|0;h=b+40|0;w=b+36|0;d=b+32|0;v=b+28|0;m=b+24|0;_=b+20|0;p=b+16|0;E=b+12|0;S=b+8|0;g=b+4|0;y=b;t[k>>2]=e;t[h>>2]=i;t[w>>2]=r;t[d>>2]=n;t[v>>2]=f;t[m>>2]=u;t[_>>2]=a;t[p>>2]=o;t[E>>2]=c;t[S>>2]=l;t[g>>2]=0;t[y>>2]=0;sw(y,0,t[d>>2]|0,0)|0;t[y>>2]=us(t[y>>2]|0,144448)|0;d=t[y>>2]|0;t[y>>2]=us(d,sw(g,0,t[v>>2]|0,0)|0)|0;if(t[g>>2]|0){pAi[t[135736>>2]&511](t[g>>2]|0);t[g>>2]=0}t[y>>2]=us(t[y>>2]|0,152080)|0;t[y>>2]=us(t[y>>2]|0,t[m>>2]|0)|0;t[y>>2]=us(t[y>>2]|0,142704)|0;kw(t[k>>2]|0,t[h>>2]|0,t[w>>2]|0,t[y>>2]|0,t[_>>2]|0,t[p>>2]|0,t[E>>2]|0,t[S>>2]|0);pAi[t[135736>>2]&511](t[y>>2]|0);s=b;return}function wL(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,u=0,a=0,o=0,c=0,l=0,b=0;f=s;s=s+32|0;u=f+16|0;a=f+12|0;o=f+8|0;c=f+4|0;l=f;t[a>>2]=e;t[o>>2]=i;t[c>>2]=r;t[l>>2]=n;t[t[o>>2]>>2]=0;t[t[c>>2]>>2]=0;if(t[l>>2]|0)t[t[l>>2]>>2]=0;n=t[a>>2]|0;if(t[(t[a>>2]|0)+28>>2]|0){t[t[c>>2]>>2]=t[n+28>>2];if(t[l>>2]|0)t[t[l>>2]>>2]=t[(t[a>>2]|0)+32>>2];if(t[(t[a>>2]|0)+16>>2]&1)t[t[o>>2]>>2]=1;t[u>>2]=1;b=t[u>>2]|0;s=f;return b|0}if((t[n+12>>2]|0)!=0?(t[(t[(t[a>>2]|0)+12>>2]|0)+44>>2]|0)!=0:0){t[t[c>>2]>>2]=t[(t[(t[a>>2]|0)+12>>2]|0)+44>>2];if(t[l>>2]|0)t[t[l>>2]>>2]=t[(t[(t[a>>2]|0)+12>>2]|0)+68>>2];if(t[(t[(t[a>>2]|0)+12>>2]|0)+60>>2]&512)t[t[o>>2]>>2]=1;t[u>>2]=1;b=t[u>>2]|0;s=f;return b|0}t[u>>2]=0;b=t[u>>2]|0;s=f;return b|0}function dL(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0;r=s;s=s+16|0;n=r+12|0;f=r+8|0;u=r+4|0;a=r;t[f>>2]=e;t[u>>2]=i;if(!(t[f>>2]|0)){t[n>>2]=-1;o=t[n>>2]|0;s=r;return o|0}if(t[(t[f>>2]|0)+28>>2]|0){t[n>>2]=0;o=t[n>>2]|0;s=r;return o|0}i=t[f>>2]|0;e:do if(!(t[(t[f>>2]|0)+32>>2]|0)){if((t[i+36>>2]|0)!=0&(t[u>>2]|0)!=0?(Xl(t[(t[(t[f>>2]|0)+36>>2]|0)+4>>2]|0,t[u>>2]|0)|0)==0:0){t[n>>2]=0;o=t[n>>2]|0;s=r;return o|0}}else{t[a>>2]=t[i+32>>2];while(1){if(!(t[a>>2]|0))break e;if(Xl(t[(t[a>>2]|0)+4>>2]|0,t[u>>2]|0)|0)break;t[a>>2]=t[t[a>>2]>>2]}t[n>>2]=0;o=t[n>>2]|0;s=r;return o|0}while(0);t[n>>2]=1;o=t[n>>2]|0;s=r;return o|0}function vL(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0;r=s;s=s+32|0;n=r+24|0;f=r+20|0;u=r+16|0;a=r+12|0;o=r+8|0;c=r+4|0;l=r;t[f>>2]=e;t[u>>2]=i;if(t[(t[u>>2]|0)+28>>2]|0){t[n>>2]=0;b=t[n>>2]|0;s=r;return b|0}if(((t[(t[f>>2]|0)+36>>2]|0)!=0?(t[(t[u>>2]|0)+36>>2]|0)!=0:0)?(t[(t[(t[f>>2]|0)+36>>2]|0)+4>>2]|0)==(t[(t[(t[u>>2]|0)+36>>2]|0)+4>>2]|0):0){t[n>>2]=0;b=t[n>>2]|0;s=r;return b|0}do if(t[(t[f>>2]|0)+32>>2]|0){if(!(t[(t[u>>2]|0)+32>>2]|0)){if(!(t[(t[u>>2]|0)+36>>2]|0))break;t[l>>2]=t[(t[f>>2]|0)+32>>2];while(1){if(!(t[l>>2]|0)){k=27;break}if((t[(t[l>>2]|0)+4>>2]|0)==(t[(t[(t[u>>2]|0)+36>>2]|0)+4>>2]|0)){k=25;break}t[l>>2]=t[t[l>>2]>>2]}if((k|0)==25){t[n>>2]=1;b=t[n>>2]|0;s=r;return b|0}else if((k|0)==27){t[n>>2]=0;b=t[n>>2]|0;s=r;return b|0}}t[c>>2]=0;t[a>>2]=t[(t[f>>2]|0)+32>>2];while(1){if(!(t[a>>2]|0))break;t[c>>2]=0;t[o>>2]=t[(t[u>>2]|0)+32>>2];while(1){if(!(t[o>>2]|0))break;if((t[(t[a>>2]|0)+4>>2]|0)==(t[(t[o>>2]|0)+4>>2]|0)){k=14;break}t[o>>2]=t[t[o>>2]>>2]}if((k|0)==14){k=0;t[c>>2]=1}if(!(t[c>>2]|0)){k=17;break}t[a>>2]=t[t[a>>2]>>2]}if((k|0)==17){t[n>>2]=1;b=t[n>>2]|0;s=r;return b|0}if(t[c>>2]|0){t[n>>2]=0;b=t[n>>2]|0;s=r;return b|0}}while(0);t[n>>2]=1;b=t[n>>2]|0;s=r;return b|0}function mL(e){e=e|0;var i=0,r=0,n=0,f=0,u=0;i=s;s=s+16|0;r=i+4|0;n=i;t[n>>2]=e;if(((t[n>>2]|0)!=0?(t[(t[n>>2]|0)+16>>2]|0)!=0:0)?(t[(t[n>>2]|0)+12>>2]|0)!=0:0){if(!(((t[t[(t[n>>2]|0)+12>>2]>>2]|0)!=6?(t[t[(t[n>>2]|0)+12>>2]>>2]|0)!=7:0)?(t[t[(t[n>>2]|0)+12>>2]>>2]|0)!=8:0))f=8;if((f|0)==8?(oD(t[n>>2]|0)|0)==0:0){t[r>>2]=1;u=t[r>>2]|0;s=i;return u|0}t[r>>2]=0;u=t[r>>2]|0;s=i;return u|0}t[r>>2]=1;u=t[r>>2]|0;s=i;return u|0}function _L(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;var u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0;u=s;s=s+32|0;a=u+24|0;o=u+20|0;c=u+16|0;l=u+12|0;b=u+8|0;k=u+4|0;h=u;t[o>>2]=e;t[c>>2]=i;t[l>>2]=r;t[b>>2]=n;t[k>>2]=f;t[h>>2]=gAi[t[135744>>2]&511](28)|0;if(!(t[h>>2]|0)){Qh(t[o>>2]|0,153320,0);t[a>>2]=0;w=t[a>>2]|0;s=u;return w|0}f=t[h>>2]|0;t[f+0>>2]=0;t[f+4>>2]=0;t[f+8>>2]=0;t[f+12>>2]=0;t[f+16>>2]=0;t[f+20>>2]=0;t[f+24>>2]=0;t[(t[h>>2]|0)+4>>2]=t[l>>2];t[(t[h>>2]|0)+24>>2]=t[c>>2];t[(t[h>>2]|0)+16>>2]=t[b>>2];t[(t[h>>2]|0)+20>>2]=t[k>>2];k=t[h>>2]|0;b=t[(t[o>>2]|0)+28>>2]|0;if(!(t[(t[(t[o>>2]|0)+28>>2]|0)+28>>2]|0))t[b+28>>2]=k;else t[t[b+32>>2]>>2]=k;t[(t[(t[o>>2]|0)+28>>2]|0)+32>>2]=t[h>>2];t[a>>2]=t[h>>2];w=t[a>>2]|0;s=u;return w|0}function pL(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0;n=s;s=s+48|0;f=n+44|0;u=n+40|0;a=n+36|0;o=n+32|0;c=n+28|0;l=n+24|0;b=n+20|0;k=n+16|0;h=n+12|0;w=n+8|0;d=n+4|0;v=n;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;do if(((t[(t[a>>2]|0)+28>>2]|0)==(t[(t[o>>2]|0)+28>>2]|0)?((t[(t[a>>2]|0)+32>>2]|0)==0|0)==((t[(t[o>>2]|0)+32>>2]|0)==0|0):0)?((t[(t[a>>2]|0)+36>>2]|0)==0|0)==((t[(t[o>>2]|0)+36>>2]|0)==0|0):0){if((t[(t[a>>2]|0)+36>>2]|0)!=0?(t[(t[(t[a>>2]|0)+36>>2]|0)+4>>2]|0)!=(t[(t[(t[o>>2]|0)+36>>2]|0)+4>>2]|0):0)break;if(!(t[(t[a>>2]|0)+32>>2]|0)){t[f>>2]=0;m=t[f>>2]|0;s=n;return m|0}t[k>>2]=0;t[c>>2]=t[(t[a>>2]|0)+32>>2];while(1){if(!(t[c>>2]|0))break;t[k>>2]=0;t[l>>2]=t[(t[o>>2]|0)+32>>2];while(1){if(!(t[l>>2]|0))break;if((t[(t[c>>2]|0)+4>>2]|0)==(t[(t[l>>2]|0)+4>>2]|0)){_=12;break}t[l>>2]=t[t[l>>2]>>2]}if((_|0)==12){_=0;t[k>>2]=1}if(!(t[k>>2]|0))break;t[c>>2]=t[t[c>>2]>>2]}if(t[k>>2]|0){t[f>>2]=0;m=t[f>>2]|0;s=n;return m|0}}while(0);k=t[a>>2]|0;if((t[(t[a>>2]|0)+28>>2]|0)!=(t[(t[o>>2]|0)+28>>2]|0)){if(!(t[k+28>>2]|0)){t[(t[a>>2]|0)+28>>2]=1;if(t[(t[a>>2]|0)+32>>2]|0){Gk(t[(t[a>>2]|0)+32>>2]|0);t[(t[a>>2]|0)+32>>2]=0}if(t[(t[a>>2]|0)+36>>2]|0){pAi[t[135736>>2]&511](t[(t[a>>2]|0)+36>>2]|0);t[(t[a>>2]|0)+36>>2]=0}}t[f>>2]=0;m=t[f>>2]|0;s=n;return m|0}if((t[k+32>>2]|0)!=0?(t[(t[o>>2]|0)+32>>2]|0)!=0:0){t[c>>2]=t[(t[o>>2]|0)+32>>2];t[w>>2]=t[(t[a>>2]|0)+32>>2];while(1){if(!(t[c>>2]|0)){_=40;break}t[h>>2]=0;t[l>>2]=t[w>>2];while(1){if(!(t[l>>2]|0))break;if((t[(t[c>>2]|0)+4>>2]|0)==(t[(t[l>>2]|0)+4>>2]|0)){_=33;break}t[l>>2]=t[t[l>>2]>>2]}if((_|0)==33){_=0;t[h>>2]=1}if(!(t[h>>2]|0)){t[b>>2]=aD(t[u>>2]|0)|0;if(!(t[b>>2]|0)){_=37;break}t[(t[b>>2]|0)+4>>2]=t[(t[c>>2]|0)+4>>2];t[t[b>>2]>>2]=t[(t[a>>2]|0)+32>>2];t[(t[a>>2]|0)+32>>2]=t[b>>2]}t[c>>2]=t[t[c>>2]>>2]}if((_|0)==37){t[f>>2]=-1;m=t[f>>2]|0;s=n;return m|0}else if((_|0)==40){t[f>>2]=0;m=t[f>>2]|0;s=n;return m|0}}if(((t[(t[a>>2]|0)+36>>2]|0)!=0?(t[(t[o>>2]|0)+36>>2]|0)!=0:0)?(t[(t[(t[a>>2]|0)+36>>2]|0)+4>>2]|0)!=(t[(t[(t[o>>2]|0)+36>>2]|0)+4>>2]|0):0){t[(t[(t[a>>2]|0)+36>>2]|0)+4>>2]=0;t[f>>2]=0;m=t[f>>2]|0;s=n;return m|0}if(!(((t[(t[a>>2]|0)+36>>2]|0)!=0?(t[(t[(t[a>>2]|0)+36>>2]|0)+4>>2]|0)!=0:0)?(t[(t[o>>2]|0)+32>>2]|0)!=0:0))_=48;do if((_|0)==48){if(((t[(t[o>>2]|0)+36>>2]|0)!=0?(t[(t[(t[o>>2]|0)+36>>2]|0)+4>>2]|0)!=0:0)?(t[(t[a>>2]|0)+32>>2]|0)!=0:0)break;if(!(((t[(t[a>>2]|0)+36>>2]|0)!=0?(t[(t[(t[a>>2]|0)+36>>2]|0)+4>>2]|0)==0:0)?(t[(t[o>>2]|0)+32>>2]|0)!=0:0))_=87;do if((_|0)==87){if(((t[(t[o>>2]|0)+36>>2]|0)!=0?(t[(t[(t[o>>2]|0)+36>>2]|0)+4>>2]|0)==0:0)?(t[(t[a>>2]|0)+32>>2]|0)!=0:0)break;t[f>>2]=0;m=t[f>>2]|0;s=n;return m|0}while(0);if(t[(t[a>>2]|0)+32>>2]|0)t[c>>2]=t[(t[a>>2]|0)+32>>2];else t[c>>2]=t[(t[o>>2]|0)+32>>2];while(1){if(!(t[c>>2]|0))break;if(!(t[(t[c>>2]|0)+4>>2]|0)){_=95;break}t[c>>2]=t[t[c>>2]>>2]}if((_|0)==95){t[(t[a>>2]|0)+28>>2]=1;if(t[(t[a>>2]|0)+32>>2]|0){Gk(t[(t[a>>2]|0)+32>>2]|0);t[(t[a>>2]|0)+32>>2]=0}if(t[(t[a>>2]|0)+36>>2]|0){pAi[t[135736>>2]&511](t[(t[a>>2]|0)+36>>2]|0);t[(t[a>>2]|0)+36>>2]=0}t[f>>2]=0;m=t[f>>2]|0;s=n;return m|0}do if(!(t[(t[a>>2]|0)+36>>2]|0)){if(t[(t[a>>2]|0)+32>>2]|0){Gk(t[(t[a>>2]|0)+32>>2]|0);t[(t[a>>2]|0)+32>>2]=0}b=aD(t[u>>2]|0)|0;t[(t[a>>2]|0)+36>>2]=b;if(t[(t[a>>2]|0)+36>>2]|0){t[(t[(t[a>>2]|0)+36>>2]|0)+4>>2]=0;break}t[f>>2]=-1;m=t[f>>2]|0;s=n;return m|0}while(0);t[f>>2]=0;m=t[f>>2]|0;s=n;return m|0}while(0);t[v>>2]=0;if(t[(t[a>>2]|0)+32>>2]|0){t[c>>2]=t[(t[a>>2]|0)+32>>2];t[l>>2]=t[(t[o>>2]|0)+36>>2]}else{t[c>>2]=t[(t[o>>2]|0)+32>>2];t[l>>2]=t[(t[a>>2]|0)+36>>2]}t[d>>2]=0;while(1){if(!(t[c>>2]|0))break;if(t[(t[c>>2]|0)+4>>2]|0){if((t[(t[c>>2]|0)+4>>2]|0)==(t[(t[l>>2]|0)+4>>2]|0))t[d>>2]=1}else t[v>>2]=1;if((t[d>>2]|0)!=0&(t[v>>2]|0)!=0)break;t[c>>2]=t[t[c>>2]>>2]}do if((t[d>>2]|0)!=0&(t[v>>2]|0)!=0){t[(t[a>>2]|0)+28>>2]=1;if(t[(t[a>>2]|0)+32>>2]|0){Gk(t[(t[a>>2]|0)+32>>2]|0);t[(t[a>>2]|0)+32>>2]=0}if(t[(t[a>>2]|0)+36>>2]|0){pAi[t[135736>>2]&511](t[(t[a>>2]|0)+36>>2]|0);t[(t[a>>2]|0)+36>>2]=0}}else{if(!((t[d>>2]|0)==0|(t[v>>2]|0)!=0)){if(t[(t[a>>2]|0)+32>>2]|0){Gk(t[(t[a>>2]|0)+32>>2]|0);t[(t[a>>2]|0)+32>>2]=0}if((t[(t[a>>2]|0)+36>>2]|0)==0?(c=aD(t[u>>2]|0)|0,t[(t[a>>2]|0)+36>>2]=c,(t[(t[a>>2]|0)+36>>2]|0)==0):0){t[f>>2]=-1;m=t[f>>2]|0;s=n;return m|0}t[(t[(t[a>>2]|0)+36>>2]|0)+4>>2]=0;break}if((t[d>>2]|0)==0&(t[v>>2]|0)!=0){pw(t[u>>2]|0,t[(t[a>>2]|0)+12>>2]|0,1794,152712,0,0);t[f>>2]=1794;m=t[f>>2]|0;s=n;return m|0}if(!((t[d>>2]|0)!=0|(t[v>>2]|0)!=0)?(t[(t[a>>2]|0)+36>>2]|0)==0:0){if(t[(t[a>>2]|0)+32>>2]|0){Gk(t[(t[a>>2]|0)+32>>2]|0);t[(t[a>>2]|0)+32>>2]=0}c=aD(t[u>>2]|0)|0;t[(t[a>>2]|0)+36>>2]=c;if(t[(t[a>>2]|0)+36>>2]|0){t[(t[(t[a>>2]|0)+36>>2]|0)+4>>2]=t[(t[(t[o>>2]|0)+36>>2]|0)+4>>2];break}t[f>>2]=-1;m=t[f>>2]|0;s=n;return m|0}}while(0);t[f>>2]=0;m=t[f>>2]|0;s=n;return m|0}function EL(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0;r=s;s=s+48|0;n=r+40|0;f=r+36|0;u=r+32|0;a=r+28|0;o=r+24|0;c=r+20|0;l=r+16|0;b=r+12|0;k=r+8|0;h=r+4|0;w=r;t[f>>2]=e;t[u>>2]=i;do if(t[(t[u>>2]|0)+64>>2]|0){if((t[t[(t[u>>2]|0)+64>>2]>>2]|0)!=4){if((t[t[(t[u>>2]|0)+64>>2]>>2]|0)!=1)break;if((t[(t[(t[u>>2]|0)+64>>2]|0)+88>>2]|0)==45)break}if(!(t[(t[u>>2]|0)+48>>2]&2)){th(t[f>>2]|0,3076,0,t[u>>2]|0,152344,0,0);t[n>>2]=3076;d=t[n>>2]|0;s=r;return d|0}}while(0);e:do if((t[(t[u>>2]|0)+116>>2]|0)!=0?(t[(t[(t[u>>2]|0)+116>>2]|0)+4>>2]|0)>1:0){t[a>>2]=t[(t[u>>2]|0)+116>>2];t[k>>2]=0;t[l>>2]=(t[(t[a>>2]|0)+4>>2]|0)-1;i:while(1){if((t[l>>2]|0)<0)break e;t[o>>2]=t[(t[t[a>>2]>>2]|0)+(t[l>>2]<<2)>>2];r:do if((t[l>>2]|0)>0){t[b>>2]=(t[l>>2]|0)-1;while(1){if((t[b>>2]|0)<0){v=20;break r}t[c>>2]=t[(t[t[a>>2]>>2]|0)+(t[b>>2]<<2)>>2];if((t[(t[(t[o>>2]|0)+12>>2]|0)+8>>2]|0)==(t[(t[(t[c>>2]|0)+12>>2]|0)+8>>2]|0)?(t[(t[(t[o>>2]|0)+12>>2]|0)+56>>2]|0)==(t[(t[(t[c>>2]|0)+12>>2]|0)+56>>2]|0):0)break;t[b>>2]=(t[b>>2]|0)+-1}t[h>>2]=0;i=t[f>>2]|0;e=t[u>>2]|0;th(i,3087,0,e,152424,Nd(h,t[o>>2]|0)|0,0);if(t[h>>2]|0){pAi[t[135736>>2]&511](t[h>>2]|0);t[h>>2]=0}if((yv(t[a>>2]|0,t[l>>2]|0)|0)==-1)break i}else v=20;while(0);if(((v|0)==20?(v=0,(t[(t[(t[o>>2]|0)+12>>2]|0)+48>>2]|0)!=0):0)?(gv(t[(t[(t[o>>2]|0)+12>>2]|0)+48>>2]|0,23)|0)!=0:0){if(t[k>>2]|0){t[w>>2]=0;e=t[f>>2]|0;i=t[u>>2]|0;th(e,3087,0,i,152440,Nd(w,t[o>>2]|0)|0,0);if(t[w>>2]|0){pAi[t[135736>>2]&511](t[w>>2]|0);t[w>>2]=0}if((yv(t[a>>2]|0,t[l>>2]|0)|0)==-1)break}t[k>>2]=1}t[l>>2]=(t[l>>2]|0)+-1}t[n>>2]=-1;d=t[n>>2]|0;s=r;return d|0}while(0);t[n>>2]=0;d=t[n>>2]|0;s=r;return d|0}function SL(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0;r=s;s=s+16|0;n=r+12|0;f=r+8|0;u=r+4|0;a=r;t[f>>2]=e;t[u>>2]=i;t[a>>2]=t[(t[u>>2]|0)+64>>2];if((t[t[a>>2]>>2]|0)!=5?(t[(t[a>>2]|0)+88>>2]|0)!=45:0){if((t[(t[u>>2]|0)+104>>2]|0)!=(t[a>>2]|0)){sv(t[f>>2]|0,3063,t[u>>2]|0,0,152296,0);t[n>>2]=3063;o=t[n>>2]|0;s=r;return o|0}if(t[(t[a>>2]|0)+48>>2]&512){sv(t[f>>2]|0,3063,t[u>>2]|0,0,152088,0);t[n>>2]=3063;o=t[n>>2]|0;s=r;return o|0}}else c=3;do if((c|0)==3){if(t[(t[a>>2]|0)+48>>2]&512){sv(t[f>>2]|0,3063,t[u>>2]|0,0,152088,0);t[n>>2]=3063;o=t[n>>2]|0;s=r;return o|0}if((t[(t[u>>2]|0)+104>>2]|0)!=0?(t[(t[u>>2]|0)+104>>2]|0)==(t[(t[a>>2]|0)+104>>2]|0):0)break;if((t[(t[u>>2]|0)+52>>2]|0)==1?(t[(t[a>>2]|0)+52>>2]|0)==1:0)break;if(!(t[(t[u>>2]|0)+28>>2]|0)){sv(t[f>>2]|0,3063,t[u>>2]|0,0,152152,0);t[n>>2]=3063;o=t[n>>2]|0;s=r;return o|0}if((t[(t[a>>2]|0)+52>>2]|0)!=1){if((t[(t[u>>2]|0)+52>>2]|0)==(t[(t[a>>2]|0)+52>>2]|0)){if((t[(t[u>>2]|0)+52>>2]|0)==3)break;if((t[(t[u>>2]|0)+52>>2]|0)==2)break}sv(t[f>>2]|0,3063,t[u>>2]|0,0,152200,0);t[n>>2]=3063;o=t[n>>2]|0;s=r;return o|0}}while(0);t[n>>2]=0;o=t[n>>2]|0;s=r;return o|0}function gL(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0;r=s;s=s+32|0;n=r+24|0;f=r+20|0;u=r+16|0;a=r+12|0;o=r+8|0;c=r+4|0;l=r;t[f>>2]=e;t[u>>2]=i;t[a>>2]=t[(t[u>>2]|0)+64>>2];if((t[t[a>>2]>>2]|0)!=5?(t[(t[a>>2]|0)+88>>2]|0)!=45:0){th(t[f>>2]|0,1787,t[(t[u>>2]|0)+36>>2]|0,t[u>>2]|0,150744,0,0);t[n>>2]=t[(t[f>>2]|0)+16>>2];b=t[n>>2]|0;s=r;return b|0}i=t[f>>2]|0;if(t[(t[a>>2]|0)+48>>2]&1024){th(i,1787,t[(t[u>>2]|0)+36>>2]|0,t[u>>2]|0,150784,0,0);t[n>>2]=t[(t[f>>2]|0)+16>>2];b=t[n>>2]|0;s=r;return b|0}if((Fv(i,0,t[u>>2]|0,t[a>>2]|0,t[(t[u>>2]|0)+116>>2]|0,t[(t[a>>2]|0)+116>>2]|0,t[(t[u>>2]|0)+84>>2]|0,t[(t[a>>2]|0)+84>>2]|0)|0)==-1){t[n>>2]=-1;b=t[n>>2]|0;s=r;return b|0}do if((t[(t[a>>2]|0)+88>>2]|0)!=45){if((t[(t[u>>2]|0)+52>>2]|0)!=4?(t[(t[u>>2]|0)+52>>2]|0)!=6:0){if((t[(t[u>>2]|0)+52>>2]|0)==1){if((t[(t[a>>2]|0)+52>>2]|0)==1)break;if(!((t[(t[a>>2]|0)+52>>2]|0)!=2?(t[(t[a>>2]|0)+52>>2]|0)!=3:0))k=28;if((k|0)==28?(mL(t[(t[a>>2]|0)+28>>2]|0)|0)!=0:0)break;sv(t[f>>2]|0,1787,t[u>>2]|0,0,151040,0);t[n>>2]=t[(t[f>>2]|0)+16>>2];b=t[n>>2]|0;s=r;return b|0}if((t[(t[u>>2]|0)+52>>2]|0)!=2?(t[(t[u>>2]|0)+52>>2]|0)!=3:0){sv(t[f>>2]|0,1787,t[u>>2]|0,0,151256,0);t[n>>2]=t[(t[f>>2]|0)+16>>2];b=t[n>>2]|0;s=r;return b|0}if((t[(t[u>>2]|0)+52>>2]|0)!=3)break;if((t[(t[a>>2]|0)+52>>2]|0)==3)break;sv(t[f>>2]|0,1787,t[u>>2]|0,0,151160,0);t[n>>2]=t[(t[f>>2]|0)+16>>2];b=t[n>>2]|0;s=r;return b|0}if((t[(t[a>>2]|0)+52>>2]|0)!=4?(t[(t[a>>2]|0)+52>>2]|0)!=6:0){if((t[(t[a>>2]|0)+52>>2]|0)==3?(mL(t[(t[a>>2]|0)+28>>2]|0)|0)!=0:0)break;sv(t[f>>2]|0,1787,t[u>>2]|0,0,150936,0);t[n>>2]=t[(t[f>>2]|0)+16>>2];b=t[n>>2]|0;s=r;return b|0}t[o>>2]=lL(t[f>>2]|0,t[(t[u>>2]|0)+104>>2]|0,t[(t[a>>2]|0)+104>>2]|0,0)|0;if(t[o>>2]|0){t[c>>2]=0;t[l>>2]=0;if((t[o>>2]|0)==-1){t[n>>2]=-1;b=t[n>>2]|0;s=r;return b|0}i=t[f>>2]|0;e=t[u>>2]|0;h=Nd(c,t[(t[u>>2]|0)+104>>2]|0)|0;th(i,1787,0,e,150848,h,Nd(l,t[(t[a>>2]|0)+104>>2]|0)|0);if(t[c>>2]|0){pAi[t[135736>>2]&511](t[c>>2]|0);t[c>>2]=0}if(t[l>>2]|0){pAi[t[135736>>2]&511](t[l>>2]|0);t[l>>2]=0}t[n>>2]=t[(t[f>>2]|0)+16>>2];b=t[n>>2]|0;s=r;return b|0}}while(0);t[n>>2]=0;b=t[n>>2]|0;s=r;return b|0}function yL(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0;r=s;s=s+16|0;n=r+12|0;f=r+8|0;u=r+4|0;a=r;t[f>>2]=e;t[u>>2]=i;if(!(t[(t[u>>2]|0)+80>>2]|0)){t[n>>2]=0;o=t[n>>2]|0;s=r;return o|0}i=t[u>>2]|0;if((t[(t[u>>2]|0)+80>>2]|0)==(t[f>>2]|0)){t[n>>2]=i;o=t[n>>2]|0;s=r;return o|0}if(t[(t[i+80>>2]|0)+48>>2]&512){t[n>>2]=0;o=t[n>>2]|0;s=r;return o|0}else{i=(t[(t[u>>2]|0)+80>>2]|0)+48|0;t[i>>2]=t[i>>2]|512;t[a>>2]=yL(t[f>>2]|0,t[(t[u>>2]|0)+80>>2]|0)|0;f=(t[(t[u>>2]|0)+80>>2]|0)+48|0;t[f>>2]=t[f>>2]^512;t[n>>2]=t[a>>2];o=t[n>>2]|0;s=r;return o|0}return 0}function FL(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,u=0,a=0,o=0,c=0,l=0,b=0;f=s;s=s+32|0;u=f+16|0;a=f+12|0;o=f+8|0;c=f+4|0;l=f;t[a>>2]=e;t[o>>2]=i;t[c>>2]=r;t[l>>2]=n;do if((t[t[o>>2]>>2]|0)!=4){if((t[t[o>>2]>>2]|0)==1?(t[(t[o>>2]|0)+88>>2]|0)!=45:0)break;t[u>>2]=cD(t[a>>2]|0,t[o>>2]|0,t[c>>2]|0,t[l>>2]|0)|0;b=t[u>>2]|0;s=f;return b|0}while(0);t[u>>2]=lL(t[a>>2]|0,t[o>>2]|0,t[c>>2]|0,t[l>>2]|0)|0;b=t[u>>2]|0;s=f;return b|0}function OL(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;var u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0;u=s;s=s+32|0;a=u+24|0;o=u+20|0;c=u+16|0;l=u+12|0;b=u+8|0;k=u+4|0;h=u;t[o>>2]=e;t[c>>2]=i;t[l>>2]=r;t[b>>2]=n;t[k>>2]=f;t[h>>2]=0;if(!((t[t[l>>2]>>2]|0)!=5?(t[(t[l>>2]|0)+88>>2]|0)!=45:0))w=3;do if(((w|0)==3?(t[(t[l>>2]|0)+52>>2]|0)!=4:0)?(t[(t[l>>2]|0)+52>>2]|0)!=6:0){if((t[(t[l>>2]|0)+52>>2]|0)==3?(mL(t[(t[l>>2]|0)+28>>2]|0)|0)!=0:0)break;sv(t[o>>2]|0,3059,t[l>>2]|0,t[(t[l>>2]|0)+36>>2]|0,159240,0);t[a>>2]=3059;d=t[a>>2]|0;s=u;return d|0}while(0);do if((t[t[l>>2]>>2]|0)==4)w=11;else{if((t[t[l>>2]>>2]|0)==1?(t[(t[l>>2]|0)+88>>2]|0)!=45:0){w=11;break}if((t[(t[l>>2]|0)+52>>2]|0)!=4?(t[(t[l>>2]|0)+52>>2]|0)!=6:0){t[a>>2]=t[h>>2];d=t[a>>2]|0;s=u;return d|0}t[h>>2]=nh(t[o>>2]|0,t[c>>2]|0,t[(t[l>>2]|0)+104>>2]|0,t[b>>2]|0,t[k>>2]|0,1,1,0)|0}while(0);if((w|0)==11)t[h>>2]=nh(t[o>>2]|0,t[c>>2]|0,t[l>>2]|0,t[b>>2]|0,t[k>>2]|0,1,1,0)|0;if((t[h>>2]|0)<0)rh(t[o>>2]|0,159384,141832);t[a>>2]=t[h>>2];d=t[a>>2]|0;s=u;return d|0}function AL(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,l=0;n=s;s=s+32|0;f=n+16|0;u=n+12|0;a=n+8|0;o=n+4|0;c=n;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;t[c>>2]=0;if((t[u>>2]|0)==0|(t[a>>2]|0)==0|(t[o>>2]|0)==0){t[f>>2]=-1;l=t[f>>2]|0;s=n;return l|0}t[c>>2]=lD(t[u>>2]|0,t[a>>2]|0)|0;if(!(t[c>>2]|0))t[c>>2]=sD(t[u>>2]|0,t[a>>2]|0)|0;if(!(t[c>>2]|0)){t[f>>2]=-1;l=t[f>>2]|0;s=n;return l|0}if((Cd(t[(t[c>>2]|0)+4>>2]|0,t[o>>2]|0)|0)==-1){t[f>>2]=-1;l=t[f>>2]|0;s=n;return l|0}else{t[f>>2]=0;l=t[f>>2]|0;s=n;return l|0}return 0}function ML(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0;r=s;s=s+48|0;n=r+32|0;f=r+28|0;u=r+24|0;a=r+20|0;o=r+16|0;c=r+12|0;l=r+8|0;b=r+4|0;k=r;t[f>>2]=e;t[u>>2]=i;t[a>>2]=0;if(!(t[(t[(t[u>>2]|0)+12>>2]|0)+48>>2]&131072)){t[o>>2]=t[(t[u>>2]|0)+12>>2];if(t[(t[o>>2]|0)+48>>2]&16){t[n>>2]=0;h=t[n>>2]|0;s=r;return h|0}do if((t[(t[u>>2]|0)+20>>2]|0)==1){t[c>>2]=t[(t[f>>2]|0)+76>>2];i=cb(t[(t[f>>2]|0)+64>>2]|0,t[c>>2]|0,0,t[(t[o>>2]|0)+8>>2]|0,t[(t[o>>2]|0)+52>>2]|0,t[o>>2]|0)|0;t[(t[f>>2]|0)+76>>2]=i}else{if((t[(t[u>>2]|0)+20>>2]|0)>=1073741824?(t[(t[u>>2]|0)+16>>2]|0)<2:0){t[c>>2]=t[(t[f>>2]|0)+76>>2];i=cb(t[(t[f>>2]|0)+64>>2]|0,t[c>>2]|0,0,t[(t[o>>2]|0)+8>>2]|0,t[(t[o>>2]|0)+52>>2]|0,t[o>>2]|0)|0;t[(t[f>>2]|0)+76>>2]=i;i=cb(t[(t[f>>2]|0)+64>>2]|0,t[(t[f>>2]|0)+76>>2]|0,t[(t[f>>2]|0)+76>>2]|0,t[(t[o>>2]|0)+8>>2]|0,t[(t[o>>2]|0)+52>>2]|0,t[o>>2]|0)|0;t[(t[f>>2]|0)+76>>2]=i;
	break}if((t[(t[u>>2]|0)+20>>2]|0)==1073741824)w=1073741824;else w=(t[(t[u>>2]|0)+20>>2]|0)-1|0;t[b>>2]=w;if((t[(t[u>>2]|0)+16>>2]|0)<1)d=0;else d=(t[(t[u>>2]|0)+16>>2]|0)-1|0;t[k>>2]=d;t[c>>2]=hb(t[(t[f>>2]|0)+64>>2]|0,t[(t[f>>2]|0)+76>>2]|0,0)|0;t[l>>2]=db(t[(t[f>>2]|0)+64>>2]|0,t[k>>2]|0,t[b>>2]|0)|0;i=cb(t[(t[f>>2]|0)+64>>2]|0,t[c>>2]|0,0,t[(t[o>>2]|0)+8>>2]|0,t[(t[o>>2]|0)+52>>2]|0,t[o>>2]|0)|0;t[(t[f>>2]|0)+76>>2]=i;vb(t[(t[f>>2]|0)+64>>2]|0,t[(t[f>>2]|0)+76>>2]|0,t[c>>2]|0,t[l>>2]|0)|0;i=mb(t[(t[f>>2]|0)+64>>2]|0,t[(t[f>>2]|0)+76>>2]|0,0,t[l>>2]|0)|0;t[(t[f>>2]|0)+76>>2]=i}while(0);if(!(t[(t[u>>2]|0)+16>>2]|0)){hb(t[(t[f>>2]|0)+64>>2]|0,t[c>>2]|0,t[(t[f>>2]|0)+76>>2]|0)|0;t[a>>2]=1}}else t[a>>2]=RL(t[f>>2]|0,t[u>>2]|0,-1,0)|0;t[n>>2]=t[a>>2];h=t[n>>2]|0;s=r;return h|0}function RL(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0,S=0,g=0,y=0;f=s;s=s+64|0;u=f+56|0;a=f+52|0;o=f+48|0;c=f+44|0;l=f+40|0;b=f+36|0;k=f+32|0;h=f+28|0;w=f+24|0;d=f+20|0;v=f+16|0;m=f+12|0;_=f+8|0;p=f+4|0;E=f;t[a>>2]=e;t[o>>2]=i;t[c>>2]=r;t[l>>2]=n;t[m>>2]=0;t[h>>2]=t[(t[o>>2]|0)+12>>2];t[b>>2]=t[(t[a>>2]|0)+76>>2];if(!(t[l>>2]|0))t[l>>2]=kb(t[(t[a>>2]|0)+64>>2]|0)|0;t[d>>2]=lD(t[a>>2]|0,t[h>>2]|0)|0;if(!(t[d>>2]|0)){n=t[a>>2]|0;r=lw(t[o>>2]|0)|0;pw(n,r,3069,158280,t[(t[h>>2]|0)+8>>2]|0,0);t[u>>2]=0;S=t[u>>2]|0;s=f;return S|0}e:do if((t[c>>2]|0)>=0){t[k>>2]=vb(t[(t[a>>2]|0)+64>>2]|0,t[b>>2]|0,0,t[c>>2]|0)|0;cb(t[(t[a>>2]|0)+64>>2]|0,t[k>>2]|0,t[l>>2]|0,t[(t[h>>2]|0)+8>>2]|0,t[(t[h>>2]|0)+52>>2]|0,t[h>>2]|0)|0;t[v>>2]=0;while(1){if((t[v>>2]|0)>=(t[(t[(t[d>>2]|0)+4>>2]|0)+4>>2]|0))break e;t[w>>2]=t[(t[t[(t[d>>2]|0)+4>>2]>>2]|0)+(t[v>>2]<<2)>>2];cb(t[(t[a>>2]|0)+64>>2]|0,t[k>>2]|0,t[l>>2]|0,t[(t[w>>2]|0)+8>>2]|0,t[(t[w>>2]|0)+52>>2]|0,t[w>>2]|0)|0;t[v>>2]=(t[v>>2]|0)+1}}else{if((t[(t[o>>2]|0)+20>>2]|0)==1){r=t[(t[a>>2]|0)+64>>2]|0;n=cb(t[(t[a>>2]|0)+64>>2]|0,t[b>>2]|0,0,t[(t[h>>2]|0)+8>>2]|0,t[(t[h>>2]|0)+52>>2]|0,t[h>>2]|0)|0;hb(r,n,t[l>>2]|0)|0;t[v>>2]=0;while(1){if((t[v>>2]|0)>=(t[(t[(t[d>>2]|0)+4>>2]|0)+4>>2]|0))break e;t[w>>2]=t[(t[t[(t[d>>2]|0)+4>>2]>>2]|0)+(t[v>>2]<<2)>>2];t[k>>2]=cb(t[(t[a>>2]|0)+64>>2]|0,t[b>>2]|0,0,t[(t[w>>2]|0)+8>>2]|0,t[(t[w>>2]|0)+52>>2]|0,t[w>>2]|0)|0;hb(t[(t[a>>2]|0)+64>>2]|0,t[k>>2]|0,t[l>>2]|0)|0;t[v>>2]=(t[v>>2]|0)+1}}if((t[(t[o>>2]|0)+20>>2]|0)==1073741824)g=1073741824;else g=(t[(t[o>>2]|0)+20>>2]|0)-1|0;t[p>>2]=g;if((t[(t[o>>2]|0)+16>>2]|0)<1)y=0;else y=(t[(t[o>>2]|0)+16>>2]|0)-1|0;t[E>>2]=y;t[c>>2]=db(t[(t[a>>2]|0)+64>>2]|0,t[E>>2]|0,t[p>>2]|0)|0;t[_>>2]=kb(t[(t[a>>2]|0)+64>>2]|0)|0;n=t[(t[a>>2]|0)+64>>2]|0;r=cb(t[(t[a>>2]|0)+64>>2]|0,t[b>>2]|0,0,t[(t[h>>2]|0)+8>>2]|0,t[(t[h>>2]|0)+52>>2]|0,t[h>>2]|0)|0;hb(n,r,t[_>>2]|0)|0;t[v>>2]=0;while(1){if((t[v>>2]|0)>=(t[(t[(t[d>>2]|0)+4>>2]|0)+4>>2]|0))break;t[w>>2]=t[(t[t[(t[d>>2]|0)+4>>2]>>2]|0)+(t[v>>2]<<2)>>2];r=t[(t[a>>2]|0)+64>>2]|0;n=cb(t[(t[a>>2]|0)+64>>2]|0,t[b>>2]|0,0,t[(t[w>>2]|0)+8>>2]|0,t[(t[w>>2]|0)+52>>2]|0,t[w>>2]|0)|0;hb(r,n,t[_>>2]|0)|0;t[v>>2]=(t[v>>2]|0)+1}vb(t[(t[a>>2]|0)+64>>2]|0,t[_>>2]|0,t[b>>2]|0,t[c>>2]|0)|0;mb(t[(t[a>>2]|0)+64>>2]|0,t[_>>2]|0,t[l>>2]|0,t[c>>2]|0)|0}while(0);if(!(t[(t[o>>2]|0)+16>>2]|0)){hb(t[(t[a>>2]|0)+64>>2]|0,t[b>>2]|0,t[l>>2]|0)|0;t[m>>2]=1}t[(t[a>>2]|0)+76>>2]=t[l>>2];t[u>>2]=t[m>>2];S=t[u>>2]|0;s=f;return S|0}function NL(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0;r=s;s=s+32|0;n=r+16|0;f=r+12|0;u=r+8|0;a=r+4|0;o=r;t[f>>2]=e;t[u>>2]=i;if(!(t[(t[f>>2]|0)+168>>2]|0)){t[n>>2]=0;c=t[n>>2]|0;s=r;return c|0}t[a>>2]=0;while(1){if((t[a>>2]|0)>=(t[(t[f>>2]|0)+168>>2]|0)){l=8;break}t[o>>2]=t[(t[(t[f>>2]|0)+164>>2]|0)+(t[a>>2]<<2)>>2];if((t[(t[o>>2]|0)+48>>2]|0)==(t[u>>2]|0)){l=6;break}t[a>>2]=(t[a>>2]|0)+1}if((l|0)==6){t[n>>2]=t[o>>2];c=t[n>>2]|0;s=r;return c|0}else if((l|0)==8){t[n>>2]=0;c=t[n>>2]|0;s=r;return c|0}return 0}function TL(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;var u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0;u=s;s=s+48|0;a=u+32|0;o=u+28|0;c=u+24|0;l=u+20|0;b=u+16|0;k=u+12|0;h=u+8|0;w=u+4|0;d=u;t[o>>2]=e;t[c>>2]=i;t[l>>2]=r;t[b>>2]=n;t[k>>2]=f;t[h>>2]=0;t[d>>2]=0;if((t[o>>2]|0)==0|(t[c>>2]|0)==0){t[a>>2]=-1;v=t[a>>2]|0;s=u;return v|0}f=t[o>>2]|0;if(!(t[(t[o>>2]|0)+88>>2]|0)){rh(f,155272,155304);t[a>>2]=-1;v=t[a>>2]|0;s=u;return v|0}t[w>>2]=t[f+88>>2];f=t[w>>2]|0;if(!(t[(t[w>>2]|0)+28>>2]|0)){rh(f,155272,155336);t[a>>2]=-1;v=t[a>>2]|0;s=u;return v|0}t[k>>2]=ST(t[f+80>>2]|0,t[k>>2]|0,t[l>>2]|0)|0;t[h>>2]=lh(t[w>>2]|0,1,t[k>>2]|0,0,0,0,t[l>>2]|0,0,t[b>>2]|0,d)|0;if(t[h>>2]|0){t[a>>2]=t[h>>2];v=t[a>>2]|0;s=u;return v|0}if(!(t[d>>2]|0)){mw(t[o>>2]|0,1879,t[l>>2]|0,0,155352,t[k>>2]|0,0,0);t[a>>2]=t[h>>2];v=t[a>>2]|0;s=u;return v|0}if((t[d>>2]|0)!=0?(t[(t[(t[w>>2]|0)+28>>2]|0)+16>>2]|0)==0:0)t[(t[(t[w>>2]|0)+28>>2]|0)+16>>2]=t[d>>2];if(((t[d>>2]|0)!=0?(t[(t[d>>2]|0)+20>>2]|0)!=0:0)?(t[(t[d>>2]|0)+32>>2]|0)==0:0){t[(t[w>>2]|0)+20>>2]=0;t[(t[w>>2]|0)+16>>2]=0;t[(t[w>>2]|0)+48>>2]=t[(t[d>>2]|0)+20>>2];t[h>>2]=sh(t[w>>2]|0,t[c>>2]|0,t[d>>2]|0)|0;if((t[h>>2]|0)==-1){t[(t[w>>2]|0)+48>>2]=0;t[(t[w>>2]|0)+48>>2]=0;t[a>>2]=-1;v=t[a>>2]|0;s=u;return v|0}if((t[h>>2]|0)==0?(t[(t[w>>2]|0)+20>>2]|0)!=0:0)t[h>>2]=t[(t[w>>2]|0)+16>>2];c=t[w>>2]|0;if(!(t[(t[w>>2]|0)+20>>2]|0)){bh(c,t[d>>2]|0)|0;t[h>>2]=t[(t[w>>2]|0)+16>>2];if((t[h>>2]|0)!=0?(t[(t[o>>2]|0)+52>>2]|0)==0:0)t[(t[o>>2]|0)+52>>2]=t[h>>2];d=(t[o>>2]|0)+56|0;t[d>>2]=(t[d>>2]|0)+(t[(t[w>>2]|0)+20>>2]|0)}else{d=(t[o>>2]|0)+56|0;t[d>>2]=(t[d>>2]|0)+(t[c+20>>2]|0)}t[(t[w>>2]|0)+48>>2]=0;t[a>>2]=t[h>>2];v=t[a>>2]|0;s=u;return v|0}t[a>>2]=0;v=t[a>>2]|0;s=u;return v|0}function LL(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0;f=s;s=s+48|0;u=f+40|0;a=f+36|0;o=f+32|0;c=f+28|0;l=f+24|0;b=f+20|0;k=f+16|0;h=f+12|0;w=f+8|0;d=f+4|0;v=f;t[a>>2]=e;t[o>>2]=i;t[c>>2]=r;t[l>>2]=n;t[b>>2]=0;if(!(t[c>>2]|0)){t[u>>2]=-1;m=t[u>>2]|0;s=f;return m|0}t[t[c>>2]>>2]=0;if(!(t[o>>2]|0)){t[u>>2]=0;m=t[u>>2]|0;s=f;return m|0}t[k>>2]=0;t[h>>2]=0;t[(t[a>>2]|0)+108>>2]=t[o>>2];t[b>>2]=bD(t[a>>2]|0,t[(t[o>>2]|0)+20>>2]|0,k,h)|0;do if(t[b>>2]|0){if((t[b>>2]|0)<0){rh(t[a>>2]|0,146768,146808);t[(t[a>>2]|0)+108>>2]=t[(t[(t[a>>2]|0)+100>>2]|0)+(t[(t[a>>2]|0)+96>>2]<<2)>>2];t[u>>2]=-1;m=t[u>>2]|0;s=f;return m|0}}else{o=iv(t[(t[a>>2]|0)+20>>2]|0,t[h>>2]|0,t[k>>2]|0)|0;t[t[c>>2]>>2]=o;if(!(t[t[c>>2]>>2]|0)){t[w>>2]=0;o=t[a>>2]|0;n=ED(21)|0;th(o,1851,0,n,146880,uh(w,t[k>>2]|0,t[h>>2]|0)|0,0);if(t[w>>2]|0){pAi[t[135736>>2]&511](t[w>>2]|0);t[w>>2]=0}t[b>>2]=t[(t[a>>2]|0)+52>>2];break}if(t[l>>2]|0){t[d>>2]=0;if(!((t[(t[l>>2]|0)+48>>2]&2048|0)==0?(t[(t[(t[l>>2]|0)+28>>2]|0)+48>>2]&262144|0)==0:0))t[d>>2]=t[d>>2]|2;if(!((t[(t[l>>2]|0)+48>>2]&4096|0)==0?(t[(t[(t[l>>2]|0)+28>>2]|0)+48>>2]&524288|0)==0:0))t[d>>2]=t[d>>2]|1;if(FL(t[a>>2]|0,t[t[c>>2]>>2]|0,t[(t[l>>2]|0)+28>>2]|0,t[d>>2]|0)|0){t[v>>2]=0;n=t[a>>2]|0;th(n,1852,0,0,146968,uh(v,t[(t[t[c>>2]>>2]|0)+112>>2]|0,t[(t[t[c>>2]>>2]|0)+8>>2]|0)|0,0);if(t[v>>2]|0){pAi[t[135736>>2]&511](t[v>>2]|0);t[v>>2]=0}t[b>>2]=t[(t[a>>2]|0)+52>>2];t[t[c>>2]>>2]=0}}}while(0);t[(t[a>>2]|0)+108>>2]=t[(t[(t[a>>2]|0)+100>>2]|0)+(t[(t[a>>2]|0)+96>>2]<<2)>>2];t[u>>2]=t[b>>2];m=t[u>>2]|0;s=f;return m|0}function DL(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0;r=s;s=s+32|0;n=r+28|0;f=r+24|0;u=r+20|0;a=r+16|0;o=r+12|0;c=r+8|0;l=r+4|0;b=r;t[f>>2]=e;t[u>>2]=i;t[o>>2]=0;t[c>>2]=t[(t[u>>2]|0)+100>>2];if(!(t[c>>2]|0)){t[n>>2]=0;k=t[n>>2]|0;s=r;return k|0}if(t[(t[(t[f>>2]|0)+108>>2]|0)+56>>2]|0){rh(t[f>>2]|0,146584,146616);t[n>>2]=-1;k=t[n>>2]|0;s=r;return k|0}e:while(1){do if((t[t[c>>2]>>2]|0)==24?(t[l>>2]=t[(t[(t[c>>2]|0)+36>>2]|0)+4>>2],(t[l>>2]|0)!=0):0){t[(t[(t[f>>2]|0)+108>>2]|0)+76>>2]=1;t[b>>2]=t[(t[f>>2]|0)+112>>2];while(1){if(!(t[b>>2]|0))break;if((t[(t[b>>2]|0)+4>>2]|0)==(t[l>>2]|0))break;t[b>>2]=t[t[b>>2]>>2]}if(!(t[b>>2]|0)){h=12;break e}if((t[(t[b>>2]|0)+8>>2]|0)!=-1?(t[(t[f>>2]|0)+96>>2]|0)>=(t[(t[b>>2]|0)+8>>2]|0):0)break;t[(t[b>>2]|0)+8>>2]=t[(t[f>>2]|0)+96>>2]}while(0);t[b>>2]=t[(t[f>>2]|0)+112>>2];while(1){if(!(t[b>>2]|0))break;if((t[(t[b>>2]|0)+4>>2]|0)==(t[c>>2]|0))break;t[b>>2]=t[t[b>>2]>>2]}w=t[f>>2]|0;if(!(t[b>>2]|0)){h=21;break}if(t[w+124>>2]|0){t[a>>2]=t[(t[f>>2]|0)+124>>2];t[(t[f>>2]|0)+124>>2]=t[(t[a>>2]|0)+12>>2];t[(t[a>>2]|0)+12>>2]=0}else{t[a>>2]=gAi[t[135744>>2]&511](36)|0;if(!(t[a>>2]|0)){h=25;break}u=(t[a>>2]|0)+0|0;i=u+36|0;do{t[u>>2]=0;u=u+4|0}while((u|0)<(i|0))}u=t[a>>2]|0;if(!(t[o>>2]|0))t[(t[(t[f>>2]|0)+108>>2]|0)+56>>2]=u;else t[(t[o>>2]|0)+8>>2]=u;t[o>>2]=t[a>>2];t[t[a>>2]>>2]=0;t[(t[a>>2]|0)+4>>2]=t[(t[f>>2]|0)+96>>2];t[(t[a>>2]|0)+16>>2]=t[b>>2];t[(t[a>>2]|0)+20>>2]=t[t[(t[b>>2]|0)+4>>2]>>2];if((CL(t[f>>2]|0,t[a>>2]|0,t[(t[c>>2]|0)+24>>2]|0,1)|0)==-1){h=31;break}t[c>>2]=t[(t[c>>2]|0)+8>>2];if(!(t[c>>2]|0)){h=33;break}}if((h|0)==12){rh(t[f>>2]|0,146584,146672);t[n>>2]=-1;k=t[n>>2]|0;s=r;return k|0}else if((h|0)==21){rh(w,146584,146672);t[n>>2]=-1;k=t[n>>2]|0;s=r;return k|0}else if((h|0)==25){kh(t[f>>2]|0,146736,0);t[n>>2]=-1;k=t[n>>2]|0;s=r;return k|0}else if((h|0)==31){t[n>>2]=-1;k=t[n>>2]|0;s=r;return k|0}else if((h|0)==33){t[n>>2]=0;k=t[n>>2]|0;s=r;return k|0}return 0}function CL(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0;f=s;s=s+32|0;u=f+20|0;a=f+16|0;o=f+12|0;c=f+8|0;l=f+4|0;b=f;t[a>>2]=e;t[o>>2]=i;t[c>>2]=r;t[l>>2]=n;do if(t[(t[a>>2]|0)+120>>2]|0){t[b>>2]=t[(t[a>>2]|0)+120>>2];t[(t[a>>2]|0)+120>>2]=t[(t[b>>2]|0)+4>>2];t[(t[b>>2]|0)+4>>2]=0}else{t[b>>2]=gAi[t[135744>>2]&511](36)|0;if(t[b>>2]|0){n=(t[b>>2]|0)+0|0;r=n+36|0;do{t[n>>2]=0;n=n+4|0}while((n|0)<(r|0));break}kh(0,146088,0);t[u>>2]=-1;k=t[u>>2]|0;s=f;return k|0}while(0);if(t[(t[a>>2]|0)+116>>2]|0)t[(t[b>>2]|0)+4>>2]=t[(t[a>>2]|0)+116>>2];t[(t[a>>2]|0)+116>>2]=t[b>>2];if(t[(t[b>>2]|0)+32>>2]|0)_j(t[(t[b>>2]|0)+32>>2]|0);n=Aj(t[(t[c>>2]|0)+16>>2]|0)|0;t[(t[b>>2]|0)+32>>2]=n;if(!(t[(t[b>>2]|0)+32>>2]|0)){rh(t[a>>2]|0,146120,146152);t[u>>2]=-1;k=t[u>>2]|0;s=f;return k|0}else{t[t[b>>2]>>2]=t[l>>2];t[(t[b>>2]|0)+8>>2]=t[(t[a>>2]|0)+96>>2];t[(t[b>>2]|0)+24>>2]=t[o>>2];t[(t[b>>2]|0)+28>>2]=t[c>>2];t[(t[b>>2]|0)+16>>2]=0;t[u>>2]=0;k=t[u>>2]|0;s=f;return k|0}return 0}function PL(e){e=e|0;var i=0,r=0,n=0,f=0,u=0,a=0,o=0;i=s;s=s+16|0;r=i+12|0;n=i+8|0;f=i+4|0;u=i;t[n>>2]=e;if(!(t[(t[n>>2]|0)+116>>2]|0)){t[r>>2]=0;a=t[r>>2]|0;s=i;return a|0}t[f>>2]=t[(t[n>>2]|0)+116>>2];while(1){t[u>>2]=gj(t[(t[f>>2]|0)+32>>2]|0)|0;if((t[u>>2]|0)==-1){o=5;break}t[f>>2]=t[(t[f>>2]|0)+4>>2];if(!(t[f>>2]|0)){o=7;break}}if((o|0)==5){t[r>>2]=-1;a=t[r>>2]|0;s=i;return a|0}else if((o|0)==7){t[r>>2]=0;a=t[r>>2]|0;s=i;return a|0}return 0}function BL(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,u=0,a=0,o=0,c=0,l=0,b=0;f=s;s=s+32|0;u=f+20|0;a=f+16|0;o=f+12|0;c=f+8|0;l=f+4|0;b=f;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;t[c>>2]=n;t[l>>2]=0;t[b>>2]=0;bw(l,t[u>>2]|0,t[c>>2]|0)|0;t[l>>2]=us(t[l>>2]|0,145232)|0;n=t[u>>2]|0;u=t[a>>2]|0;a=t[c>>2]|0;r=t[l>>2]|0;pd(n,u,a,r,kD(b,t[o>>2]|0,t[c>>2]|0)|0,0);if(t[b>>2]|0){pAi[t[135736>>2]&511](t[b>>2]|0);t[b>>2]=0}if(!(t[l>>2]|0)){s=f;return}pAi[t[135736>>2]&511](t[l>>2]|0);t[l>>2]=0;s=f;return}function IL(e,i){e=e|0;i=i|0;var r=0,n=0,f=0;r=s;s=s+16|0;n=r+4|0;f=r;t[n>>2]=e;t[f>>2]=i;i=Nd(t[n>>2]|0,t[f>>2]|0)|0;s=r;return i|0}function HL(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0;r=s;s=s+16|0;n=r+8|0;f=r+4|0;u=r;t[f>>2]=e;t[u>>2]=i;do if(t[(t[f>>2]|0)+140>>2]|0){if((t[(t[f>>2]|0)+148>>2]|0)<=(t[(t[f>>2]|0)+144>>2]|0)?(i=(t[f>>2]|0)+148|0,t[i>>2]=t[i>>2]<<1,i=MAi[t[135760>>2]&511](t[(t[f>>2]|0)+140>>2]|0,t[(t[f>>2]|0)+148>>2]<<2)|0,t[(t[f>>2]|0)+140>>2]=i,(t[(t[f>>2]|0)+140>>2]|0)==0):0){kh(t[f>>2]|0,143616,0);t[n>>2]=-1;a=t[n>>2]|0;s=r;return a|0}}else{i=gAi[t[135744>>2]&511](160)|0;t[(t[f>>2]|0)+140>>2]=i;i=t[f>>2]|0;if(t[(t[f>>2]|0)+140>>2]|0){t[i+148>>2]=40;break}kh(i,143576,0);t[n>>2]=-1;a=t[n>>2]|0;s=r;return a|0}while(0);i=t[u>>2]|0;u=(t[f>>2]|0)+144|0;e=t[u>>2]|0;t[u>>2]=e+1;t[(t[(t[f>>2]|0)+140>>2]|0)+(e<<2)>>2]=i;t[n>>2]=0;a=t[n>>2]|0;s=r;return a|0}function xL(e,i){e=e|0;i=i|0;var r=0,n=0;r=s;s=s+16|0;n=r;t[r+4>>2]=e;t[n>>2]=i;if(!(t[(t[n>>2]|0)+32>>2]|0)){i=hh()|0;t[(t[n>>2]|0)+32>>2]=i}s=r;return t[(t[n>>2]|0)+32>>2]|0}function UL(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0;f=s;s=s+32|0;u=f+24|0;a=f+20|0;o=f+16|0;c=f+12|0;l=f+8|0;b=f+4|0;k=f;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;t[c>>2]=n;t[k>>2]=0;n=Yl(142560)|0;t[t[a>>2]>>2]=n;t[l>>2]=0;while(1){h=t[t[a>>2]>>2]|0;if((t[l>>2]|0)>=(t[c>>2]|0))break;n=us(h,142568)|0;t[t[a>>2]>>2]=n;n=t[(t[(t[o>>2]|0)+(t[l>>2]<<2)>>2]|0)+4>>2]|0;t[b>>2]=WL(n,Ed(t[t[(t[o>>2]|0)+(t[l>>2]<<2)>>2]>>2]|0)|0,k)|0;if(!(t[b>>2]|0)){n=us(t[t[a>>2]>>2]|0,t[k>>2]|0)|0;t[t[a>>2]>>2]=n}else{rh(t[u>>2]|0,142576,142608);n=us(t[t[a>>2]>>2]|0,142648)|0;t[t[a>>2]>>2]=n}n=t[t[a>>2]>>2]|0;if((t[l>>2]|0)<((t[c>>2]|0)-1|0)){r=us(n,142656)|0;t[t[a>>2]>>2]=r}else{r=us(n,142568)|0;t[t[a>>2]>>2]=r}if(t[k>>2]|0){pAi[t[135736>>2]&511](t[k>>2]|0);t[k>>2]=0}t[l>>2]=(t[l>>2]|0)+1}l=us(h,142664)|0;t[t[a>>2]>>2]=l;s=f;return t[t[a>>2]>>2]|0}function zL(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0;r=s;s=s+16|0;n=r+8|0;f=r+4|0;u=r;t[f>>2]=e;t[u>>2]=i;do if(t[(t[f>>2]|0)+128>>2]|0){if((t[(t[f>>2]|0)+136>>2]|0)<=(t[(t[f>>2]|0)+132>>2]|0)?(i=(t[f>>2]|0)+136|0,t[i>>2]=t[i>>2]<<1,i=MAi[t[135760>>2]&511](t[(t[f>>2]|0)+128>>2]|0,t[(t[f>>2]|0)+136>>2]<<2)|0,t[(t[f>>2]|0)+128>>2]=i,(t[(t[f>>2]|0)+128>>2]|0)==0):0){kh(t[f>>2]|0,143528,0);t[n>>2]=-1;a=t[n>>2]|0;s=r;return a|0}}else{i=gAi[t[135744>>2]&511](80)|0;t[(t[f>>2]|0)+128>>2]=i;i=t[f>>2]|0;if(t[(t[f>>2]|0)+128>>2]|0){t[i+136>>2]=20;break}kh(i,143488,0);t[n>>2]=-1;a=t[n>>2]|0;s=r;return a|0}while(0);i=t[u>>2]|0;u=(t[f>>2]|0)+132|0;e=t[u>>2]|0;t[u>>2]=e+1;t[(t[(t[f>>2]|0)+128>>2]|0)+(e<<2)>>2]=i;t[n>>2]=0;a=t[n>>2]|0;s=r;return a|0}function jL(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0;n=s;s=s+32|0;f=n+16|0;u=n+12|0;a=n+8|0;o=n+4|0;c=n;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;t[a>>2]=kz(t[(t[u>>2]|0)+156>>2]|0,t[a>>2]|0,-1)|0;if(!(t[a>>2]|0)){t[f>>2]=-1;l=t[f>>2]|0;s=n;return l|0}if((t[o>>2]|0)!=0?(t[o>>2]=kz(t[(t[u>>2]|0)+156>>2]|0,t[o>>2]|0,-1)|0,(t[o>>2]|0)==0):0){t[f>>2]=-1;l=t[f>>2]|0;s=n;return l|0}t[c>>2]=0;while(1){if((t[c>>2]|0)>=(t[(t[(t[u>>2]|0)+180>>2]|0)+4>>2]|0)){b=12;break}if((t[(t[t[(t[u>>2]|0)+180>>2]>>2]|0)+(t[c>>2]<<2)>>2]|0)==(t[a>>2]|0)?(t[(t[t[(t[u>>2]|0)+180>>2]>>2]|0)+((t[c>>2]|0)+1<<2)>>2]|0)==(t[o>>2]|0):0){b=10;break}t[c>>2]=(t[c>>2]|0)+2}if((b|0)==10){t[f>>2]=t[c>>2];l=t[f>>2]|0;s=n;return l|0}else if((b|0)==12){t[c>>2]=t[(t[(t[u>>2]|0)+180>>2]|0)+4>>2];Cd(t[(t[u>>2]|0)+180>>2]|0,t[a>>2]|0)|0;Cd(t[(t[u>>2]|0)+180>>2]|0,t[o>>2]|0)|0;t[f>>2]=t[c>>2];l=t[f>>2]|0;s=n;return l|0}return 0}function VL(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0;r=s;s=s+32|0;n=r+16|0;f=r+12|0;u=r+8|0;a=r+4|0;o=r;t[f>>2]=e;t[u>>2]=i;t[a>>2]=t[(t[(t[f>>2]|0)+100>>2]|0)+(t[(t[u>>2]|0)+4>>2]<<2)>>2];if(!(t[(t[a>>2]|0)+52>>2]|0)){f=GL(t[(t[(t[u>>2]|0)+16>>2]|0)+4>>2]|0)|0;t[(t[a>>2]|0)+52>>2]=f;if(!(t[(t[a>>2]|0)+52>>2]|0)){t[n>>2]=0;c=t[n>>2]|0;s=r;return c|0}else{t[n>>2]=t[(t[a>>2]|0)+52>>2];c=t[n>>2]|0;s=r;return c|0}}t[o>>2]=0;t[o>>2]=t[(t[a>>2]|0)+52>>2];while(1){l=t[o>>2]|0;if((t[(t[o>>2]|0)+4>>2]|0)==(t[(t[(t[u>>2]|0)+16>>2]|0)+4>>2]|0)){b=7;break}if(!(t[l>>2]|0)){b=9;break}t[o>>2]=t[t[o>>2]>>2];if(!(t[o>>2]|0)){b=13;break}}if((b|0)==7){t[n>>2]=l;c=t[n>>2]|0;s=r;return c|0}else if((b|0)==9){l=GL(t[(t[(t[u>>2]|0)+16>>2]|0)+4>>2]|0)|0;t[t[o>>2]>>2]=l;if(!(t[t[o>>2]>>2]|0)){t[n>>2]=0;c=t[n>>2]|0;s=r;return c|0}else{t[n>>2]=t[t[o>>2]>>2];c=t[n>>2]|0;s=r;return c|0}}else if((b|0)==13){t[n>>2]=0;c=t[n>>2]|0;s=r;return c|0}return 0}function qL(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0;r=s;s=s+16|0;n=r+8|0;f=r+4|0;u=r;t[f>>2]=e;t[u>>2]=i;i=(t[f>>2]|0)+16|0;if(!(t[(t[f>>2]|0)+8>>2]|0)){t[i>>2]=10;e=gAi[t[135744>>2]&511](40)|0;t[(t[f>>2]|0)+8>>2]=e;if(!(t[(t[f>>2]|0)+8>>2]|0)){kh(0,142256,0);t[n>>2]=-1;a=t[n>>2]|0;s=r;return a|0}}else if((t[i>>2]|0)<=(t[(t[f>>2]|0)+12>>2]|0)?(i=(t[f>>2]|0)+16|0,t[i>>2]=t[i>>2]<<1,i=MAi[t[135760>>2]&511](t[(t[f>>2]|0)+8>>2]|0,t[(t[f>>2]|0)+16>>2]<<2)|0,t[(t[f>>2]|0)+8>>2]=i,(t[(t[f>>2]|0)+8>>2]|0)==0):0){kh(0,142712,0);t[n>>2]=-1;a=t[n>>2]|0;s=r;return a|0}i=t[u>>2]|0;u=(t[f>>2]|0)+12|0;e=t[u>>2]|0;t[u>>2]=e+1;t[(t[(t[f>>2]|0)+8>>2]|0)+(e<<2)>>2]=i;t[n>>2]=0;a=t[n>>2]|0;s=r;return a|0}function YL(e,i,r,n,f,u,a){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;u=u|0;a=a|0;var o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0;o=s;s=s+48|0;c=o+32|0;l=o+28|0;b=o+24|0;k=o+16|0;h=o+12|0;w=o+8|0;d=o+4|0;v=o;t[c>>2]=e;t[l>>2]=i;t[b>>2]=r;t[o+20>>2]=n;t[k>>2]=f;t[h>>2]=u;t[w>>2]=a;t[d>>2]=0;t[v>>2]=0;t[d>>2]=Yl(142688)|0;t[d>>2]=us(t[d>>2]|0,t[k>>2]|0)|0;t[d>>2]=us(t[d>>2]|0,142704)|0;k=t[c>>2]|0;a=t[l>>2]|0;l=t[(t[b>>2]|0)+8>>2]|0;u=t[d>>2]|0;f=uh(v,t[(t[t[(t[c>>2]|0)+180>>2]>>2]|0)+((t[(t[b>>2]|0)+12>>2]|0)+1<<2)>>2]|0,t[(t[t[(t[c>>2]|0)+180>>2]>>2]|0)+(t[(t[b>>2]|0)+12>>2]<<2)>>2]|0)|0;Ld(k,2,a,0,l,u,f,t[h>>2]|0,t[w>>2]|0,0);if(t[v>>2]|0){pAi[t[135736>>2]&511](t[v>>2]|0);t[v>>2]=0}if(!(t[d>>2]|0)){s=o;return}pAi[t[135736>>2]&511](t[d>>2]|0);t[d>>2]=0;s=o;return}function GL(e){e=e|0;var i=0,r=0,n=0,f=0,u=0;i=s;s=s+16|0;r=i+8|0;n=i+4|0;f=i;t[n>>2]=e;t[f>>2]=gAi[t[135744>>2]&511](24)|0;if(!(t[f>>2]|0)){kh(0,142304,0);t[r>>2]=0;u=t[r>>2]|0;s=i;return u|0}else{e=t[f>>2]|0;t[e+0>>2]=0;t[e+4>>2]=0;t[e+8>>2]=0;t[e+12>>2]=0;t[e+16>>2]=0;t[e+20>>2]=0;t[(t[f>>2]|0)+4>>2]=t[n>>2];t[r>>2]=t[f>>2];u=t[r>>2]|0;s=i;return u|0}return 0}function WL(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0;n=s;s=s+32|0;f=n+28|0;u=n+24|0;a=n+20|0;o=n+16|0;c=n+12|0;l=n+8|0;b=n+4|0;k=n;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;t[k>>2]=0;if((t[o>>2]|0)==0|(t[u>>2]|0)==0){t[f>>2]=-1;h=t[f>>2]|0;s=n;return h|0}r=(gD(t[u>>2]|0)|0)!=0;t[c>>2]=r?1:0;t[t[o>>2]>>2]=0;while(1){t[b>>2]=0;t[l>>2]=qD(t[u>>2]|0)|0;r=t[l>>2]|0;if((r|0)==46|(r|0)==2|(r|0)==1){t[b>>2]=yD(t[u>>2]|0)|0;if(t[b>>2]|0){if((t[a>>2]|0)!=3){if((t[a>>2]|0)==2)t[k>>2]=ND(t[b>>2]|0)|0}else t[k>>2]=TD(t[b>>2]|0)|0;if(t[k>>2]|0)t[b>>2]=t[k>>2]}}else{r=(VD(t[u>>2]|0,k)|0)==-1;w=t[k>>2]|0;if(r)break;t[b>>2]=w}r=t[b>>2]|0;do if(!(t[t[o>>2]>>2]|0)){if(r){i=Yl(t[b>>2]|0)|0;t[t[o>>2]>>2]=i;break}if(!(t[c>>2]|0)){i=Yl(142672)|0;t[t[o>>2]>>2]=i}}else if(r){i=us(t[t[o>>2]>>2]|0,142680)|0;t[t[o>>2]>>2]=i;i=us(t[t[o>>2]>>2]|0,t[b>>2]|0)|0;t[t[o>>2]>>2]=i}while(0);if(t[k>>2]|0){pAi[t[135736>>2]&511](t[k>>2]|0);t[k>>2]=0}t[u>>2]=gD(t[u>>2]|0)|0;if(!(t[u>>2]|0)){d=26;break}}if((d|0)==26){t[f>>2]=0;h=t[f>>2]|0;s=n;return h|0}if(w)pAi[t[135736>>2]&511](t[k>>2]|0);if(t[t[o>>2]>>2]|0)pAi[t[135736>>2]&511](t[t[o>>2]>>2]|0);if(t[k>>2]|0)pAi[t[135736>>2]&511](t[k>>2]|0);t[f>>2]=-1;h=t[f>>2]|0;s=n;return h|0}function KL(e){e=e|0;var i=0,r=0;i=s;s=s+16|0;r=i;t[r>>2]=e;e=sF(t[r>>2]|0)|0;s=i;return e|0}function XL(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0;n=s;s=s+16|0;f=n+12|0;u=n+8|0;a=n+4|0;o=n;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;r=t[u>>2]|0;if(t[a>>2]|0){t[f>>2]=uh(r,t[(t[a>>2]|0)+8>>2]|0,t[o>>2]|0)|0;c=t[f>>2]|0;s=n;return c|0}else{t[f>>2]=uh(r,0,t[o>>2]|0)|0;c=t[f>>2]|0;s=n;return c|0}return 0}function ZL(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;var u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0;u=s;s=s+48|0;a=u+32|0;o=u+28|0;c=u+24|0;l=u+20|0;b=u+16|0;k=u+12|0;h=u+8|0;w=u+4|0;d=u;t[o>>2]=e;t[c>>2]=i;t[l>>2]=r;t[b>>2]=n;t[k>>2]=f;if((t[o>>2]|0)==0|(t[c>>2]|0)==0|(t[l>>2]|0)==0|(t[b>>2]|0)==0){t[a>>2]=-1;v=t[a>>2]|0;s=u;return v|0}t[t[b>>2]>>2]=0;t[h>>2]=t[(t[l>>2]|0)+44>>2];while(1){if(!(t[h>>2]|0))break;c=t[h>>2]|0;if(!(t[(t[h>>2]|0)+36>>2]|0)){if((Xl(t[c+8>>2]|0,161384)|0)==0?(Xl(t[(t[h>>2]|0)+8>>2]|0,155456)|0)==0:0)_T(t[o>>2]|0,3035,0,t[h>>2]|0)}else if(Xl(t[(t[c+36>>2]|0)+8>>2]|0,t[38526]|0)|0)_T(t[o>>2]|0,3035,0,t[h>>2]|0);t[h>>2]=t[(t[h>>2]|0)+24>>2]}Pd(t[o>>2]|0,t[l>>2]|0,161384)|0;t[h>>2]=Bd(t[l>>2]|0,155456)|0;do if(t[h>>2]|0){t[w>>2]=0;t[d>>2]=0;c=t[o>>2]|0;f=t[h>>2]|0;n=ED(29)|0;if(!(Id(c,0,f,n,t[b>>2]|0)|0)){t[w>>2]=oF(t[(t[l>>2]|0)+32>>2]|0,t[l>>2]|0)|0;n=t[t[b>>2]>>2]|0;if(!(t[w>>2]|0))t[d>>2]=GA(n,t[(t[(t[l>>2]|0)+32>>2]|0)+72>>2]|0)|0;else{t[d>>2]=GA(n,t[w>>2]|0)|0;pAi[t[135736>>2]&511](t[w>>2]|0)}n=t[o>>2]|0;if(!(t[d>>2]|0)){rh(n,168224,168256);t[a>>2]=-1;v=t[a>>2]|0;s=u;return v|0}f=kz(t[n+80>>2]|0,t[d>>2]|0,-1)|0;t[t[b>>2]>>2]=f;pAi[t[135736>>2]&511](t[d>>2]|0);if(!(Xl(t[t[b>>2]>>2]|0,t[(t[o>>2]|0)+44>>2]|0)|0)){t[a>>2]=0;v=t[a>>2]|0;s=u;return v|0}f=t[o>>2]|0;n=t[l>>2]|0;c=t[t[b>>2]>>2]|0;if((t[k>>2]|0)==3){sv(f,3081,0,n,168304,c);break}else{sv(f,3050,0,n,168360,c);break}}}else FT(t[o>>2]|0,3036,0,t[l>>2]|0,155456,0);while(0);t[a>>2]=t[(t[o>>2]|0)+16>>2];v=t[a>>2]|0;s=u;return v|0}function JL(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0,S=0,g=0,y=0,F=0,O=0,A=0,M=0;r=s;s=s+96|0;n=r+88|0;f=r+84|0;u=r+80|0;a=r+76|0;o=r+72|0;c=r+68|0;l=r+64|0;b=r+60|0;k=r+56|0;h=r+52|0;w=r+48|0;d=r+44|0;v=r+40|0;m=r+36|0;_=r+32|0;p=r+28|0;E=r+24|0;S=r+20|0;g=r+16|0;y=r+12|0;F=r+8|0;O=r+4|0;A=r;t[f>>2]=e;t[u>>2]=i;if((t[f>>2]|0)==0|(t[u>>2]|0)==0){t[n>>2]=0;M=t[n>>2]|0;s=r;return M|0}do switch(t[t[f>>2]>>2]|0){case 16:{t[d>>2]=t[f>>2];t[v>>2]=t[(t[d>>2]|0)+24>>2];if(!(t[(t[d>>2]|0)+24>>2]|0)){t[(t[d>>2]|0)+24>>2]=t[u>>2];t[n>>2]=t[u>>2];M=t[n>>2]|0;s=r;return M|0}t[v>>2]=t[(t[d>>2]|0)+24>>2];if(t[t[v>>2]>>2]|0)t[v>>2]=t[t[v>>2]>>2];t[t[v>>2]>>2]=t[u>>2];break}case 2:case 21:{t[b>>2]=t[f>>2];t[k>>2]=t[(t[b>>2]|0)+8>>2];if(!(t[(t[b>>2]|0)+8>>2]|0)){t[(t[b>>2]|0)+8>>2]=t[u>>2];t[n>>2]=t[u>>2];M=t[n>>2]|0;s=r;return M|0}t[k>>2]=t[(t[b>>2]|0)+8>>2];if(t[t[k>>2]>>2]|0)t[k>>2]=t[t[k>>2]>>2];t[t[k>>2]>>2]=t[u>>2];break}case 18:{t[m>>2]=t[f>>2];t[_>>2]=t[(t[m>>2]|0)+8>>2];if(!(t[(t[m>>2]|0)+8>>2]|0)){t[(t[m>>2]|0)+8>>2]=t[u>>2];t[n>>2]=t[u>>2];M=t[n>>2]|0;s=r;return M|0}t[_>>2]=t[(t[m>>2]|0)+8>>2];if(t[t[_>>2]>>2]|0)t[_>>2]=t[t[_>>2]>>2];t[t[_>>2]>>2]=t[u>>2];break}case 5:case 4:{t[S>>2]=t[f>>2];t[g>>2]=t[(t[S>>2]|0)+24>>2];if(!(t[(t[S>>2]|0)+24>>2]|0)){t[(t[S>>2]|0)+24>>2]=t[u>>2];t[n>>2]=t[u>>2];M=t[n>>2]|0;s=r;return M|0}t[g>>2]=t[(t[S>>2]|0)+24>>2];if(t[t[g>>2]>>2]|0)t[g>>2]=t[t[g>>2]>>2];t[t[g>>2]>>2]=t[u>>2];break}case 1011:case 1010:case 1009:case 1008:case 1007:case 1006:case 1005:case 1004:case 1003:case 1002:case 1001:case 1e3:{t[p>>2]=t[f>>2];t[E>>2]=t[(t[p>>2]|0)+16>>2];if(!(t[(t[p>>2]|0)+16>>2]|0)){t[(t[p>>2]|0)+16>>2]=t[u>>2];t[n>>2]=t[u>>2];M=t[n>>2]|0;s=r;return M|0}t[E>>2]=t[(t[p>>2]|0)+16>>2];if(t[t[E>>2]>>2]|0)t[E>>2]=t[t[E>>2]>>2];t[t[E>>2]>>2]=t[u>>2];break}case 17:{t[y>>2]=t[f>>2];t[F>>2]=t[(t[y>>2]|0)+4>>2];if(!(t[(t[y>>2]|0)+4>>2]|0)){t[(t[y>>2]|0)+4>>2]=t[u>>2];t[n>>2]=t[u>>2];M=t[n>>2]|0;s=r;return M|0}t[F>>2]=t[(t[y>>2]|0)+4>>2];if(t[t[F>>2]>>2]|0)t[F>>2]=t[t[F>>2]>>2];t[t[F>>2]>>2]=t[u>>2];break}case 15:{t[c>>2]=t[f>>2];t[l>>2]=t[(t[c>>2]|0)+32>>2];if(!(t[(t[c>>2]|0)+32>>2]|0)){t[(t[c>>2]|0)+32>>2]=t[u>>2];t[n>>2]=t[u>>2];M=t[n>>2]|0;s=r;return M|0}t[l>>2]=t[(t[c>>2]|0)+32>>2];if(t[t[l>>2]>>2]|0)t[l>>2]=t[t[l>>2]>>2];t[t[l>>2]>>2]=t[u>>2];break}case 22:case 24:case 23:case 25:{t[h>>2]=t[f>>2];t[w>>2]=t[(t[h>>2]|0)+4>>2];if(!(t[(t[h>>2]|0)+4>>2]|0)){t[(t[h>>2]|0)+4>>2]=t[u>>2];t[n>>2]=t[u>>2];M=t[n>>2]|0;s=r;return M|0}t[w>>2]=t[(t[h>>2]|0)+4>>2];if(t[t[w>>2]>>2]|0)t[w>>2]=t[t[w>>2]>>2];t[t[w>>2]>>2]=t[u>>2];break}case 8:case 7:case 6:{t[O>>2]=t[f>>2];t[A>>2]=t[(t[O>>2]|0)+4>>2];if(!(t[(t[O>>2]|0)+4>>2]|0)){t[(t[O>>2]|0)+4>>2]=t[u>>2];t[n>>2]=t[u>>2];M=t[n>>2]|0;s=r;return M|0}t[A>>2]=t[(t[O>>2]|0)+4>>2];if(t[t[A>>2]>>2]|0)t[A>>2]=t[t[A>>2]>>2];t[t[A>>2]>>2]=t[u>>2];break}case 14:{t[a>>2]=t[f>>2];t[o>>2]=t[(t[a>>2]|0)+24>>2];if(!(t[(t[a>>2]|0)+24>>2]|0)){t[(t[a>>2]|0)+24>>2]=t[u>>2];t[n>>2]=t[u>>2];M=t[n>>2]|0;s=r;return M|0}t[o>>2]=t[(t[a>>2]|0)+24>>2];if(t[t[o>>2]>>2]|0)t[o>>2]=t[t[o>>2]>>2];t[t[o>>2]>>2]=t[u>>2];break}default:sv(0,3069,0,0,165080,0)}while(0);t[n>>2]=t[u>>2];M=t[n>>2]|0;s=r;return M|0}function QL(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0;f=s;s=s+32|0;u=f+28|0;a=f+24|0;o=f+20|0;c=f+16|0;l=f+12|0;b=f+8|0;k=f+4|0;h=f;t[a>>2]=e;t[o>>2]=i;t[c>>2]=r;t[l>>2]=n;t[k>>2]=0;if((t[a>>2]|0)==0|(t[o>>2]|0)==0|(t[c>>2]|0)==0){t[u>>2]=0;w=t[u>>2]|0;s=f;return w|0}t[b>>2]=t[(t[a>>2]|0)+84>>2];n=(t[b>>2]|0)+48|0;t[n>>2]=t[n>>2]|2;t[h>>2]=t[(t[c>>2]|0)+44>>2];while(1){if(!(t[h>>2]|0))break;n=t[h>>2]|0;if(!(t[(t[h>>2]|0)+36>>2]|0)){if((Xl(t[n+8>>2]|0,161384)|0)==0?(Xl(t[(t[h>>2]|0)+8>>2]|0,151424)|0)==0:0)_T(t[a>>2]|0,3035,0,t[h>>2]|0)}else if(Xl(t[(t[n+36>>2]|0)+8>>2]|0,t[38526]|0)|0)_T(t[a>>2]|0,3035,0,t[h>>2]|0);t[h>>2]=t[(t[h>>2]|0)+24>>2]}Pd(t[a>>2]|0,t[c>>2]|0,161384)|0;if((GT(t[a>>2]|0,t[o>>2]|0,0,t[c>>2]|0,151424,(t[b>>2]|0)+60|0,(t[b>>2]|0)+56|0)|0)==0?(t[(t[b>>2]|0)+56>>2]|0)==0:0)FT(t[a>>2]|0,3036,0,t[c>>2]|0,151424,0);t[k>>2]=t[(t[c>>2]|0)+12>>2];if((((t[k>>2]|0)!=0?(t[(t[k>>2]|0)+36>>2]|0)!=0:0)?(Xl(t[(t[k>>2]|0)+8>>2]|0,160992)|0)!=0:0)?(Xl(t[(t[(t[k>>2]|0)+36>>2]|0)+8>>2]|0,t[38526]|0)|0)!=0:0){h=t[b>>2]|0;JL(h,jd(t[a>>2]|0,t[k>>2]|0,1)|0)|0;t[k>>2]=t[(t[k>>2]|0)+24>>2]}do if((t[l>>2]|0)==10){if((((t[k>>2]|0)!=0?(t[(t[k>>2]|0)+36>>2]|0)!=0:0)?(Xl(t[(t[k>>2]|0)+8>>2]|0,161648)|0)!=0:0)?(Xl(t[(t[(t[k>>2]|0)+36>>2]|0)+8>>2]|0,t[38526]|0)|0)!=0:0){h=RT(t[a>>2]|0,t[o>>2]|0,t[k>>2]|0,8,1)|0;t[(t[b>>2]|0)+28>>2]=h;t[k>>2]=t[(t[k>>2]|0)+24>>2];break}if((((t[k>>2]|0)!=0?(t[(t[k>>2]|0)+36>>2]|0)!=0:0)?(Xl(t[(t[k>>2]|0)+8>>2]|0,161656)|0)!=0:0)?(Xl(t[(t[(t[k>>2]|0)+36>>2]|0)+8>>2]|0,t[38526]|0)|0)!=0:0){h=RT(t[a>>2]|0,t[o>>2]|0,t[k>>2]|0,7,1)|0;t[(t[b>>2]|0)+28>>2]=h;t[k>>2]=t[(t[k>>2]|0)+24>>2];break}if((((t[k>>2]|0)!=0?(t[(t[k>>2]|0)+36>>2]|0)!=0:0)?(Xl(t[(t[k>>2]|0)+8>>2]|0,161664)|0)!=0:0)?(Xl(t[(t[(t[k>>2]|0)+36>>2]|0)+8>>2]|0,t[38526]|0)|0)!=0:0){h=RT(t[a>>2]|0,t[o>>2]|0,t[k>>2]|0,6,1)|0;t[(t[b>>2]|0)+28>>2]=h;t[k>>2]=t[(t[k>>2]|0)+24>>2];break}if((((t[k>>2]|0)!=0?(t[(t[k>>2]|0)+36>>2]|0)!=0:0)?(Xl(t[(t[k>>2]|0)+8>>2]|0,161080)|0)!=0:0)?(Xl(t[(t[(t[k>>2]|0)+36>>2]|0)+8>>2]|0,t[38526]|0)|0)!=0:0){h=NT(t[a>>2]|0,t[o>>2]|0,t[k>>2]|0)|0;t[(t[b>>2]|0)+28>>2]=h;t[k>>2]=t[(t[k>>2]|0)+24>>2]}}while(0);if(t[k>>2]|0){if((TT(t[a>>2]|0,t[o>>2]|0,k,(t[b>>2]|0)+116|0,13,0)|0)==-1){t[u>>2]=0;w=t[u>>2]|0;s=f;return w|0}if((((t[k>>2]|0)!=0?(t[(t[k>>2]|0)+36>>2]|0)!=0:0)?(Xl(t[(t[k>>2]|0)+8>>2]|0,163328)|0)!=0:0)?(Xl(t[(t[(t[k>>2]|0)+36>>2]|0)+8>>2]|0,t[38526]|0)|0)!=0:0){b=LT(t[a>>2]|0,t[o>>2]|0,t[k>>2]|0)|0;t[(t[(t[a>>2]|0)+84>>2]|0)+84>>2]=b;t[k>>2]=t[(t[k>>2]|0)+24>>2]}}do if(t[k>>2]|0){b=t[a>>2]|0;o=t[c>>2]|0;h=t[k>>2]|0;if((t[l>>2]|0)==10){$d(b,3033,0,o,h,0,167440);break}else{$d(b,3033,0,o,h,0,163344);break}}while(0);t[u>>2]=0;w=t[u>>2]|0;s=f;return w|0}function $L(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0;n=s;s=s+48|0;f=n+40|0;u=n+36|0;a=n+32|0;o=n+28|0;c=n+24|0;l=n+20|0;b=n+16|0;k=n+12|0;h=n+8|0;w=n+4|0;d=n;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;t[l>>2]=0;t[d>>2]=0;if((t[u>>2]|0)==0|(t[a>>2]|0)==0|(t[o>>2]|0)==0){t[f>>2]=0;v=t[f>>2]|0;s=n;return v|0}t[w>>2]=t[(t[o>>2]|0)+44>>2];while(1){if(!(t[w>>2]|0))break;r=t[w>>2]|0;if(!(t[(t[w>>2]|0)+36>>2]|0)){if(((((Xl(t[r+8>>2]|0,161384)|0)==0?(Xl(t[(t[w>>2]|0)+8>>2]|0,161824)|0)==0:0)?(Xl(t[(t[w>>2]|0)+8>>2]|0,161808)|0)==0:0)?(Xl(t[(t[w>>2]|0)+8>>2]|0,162304)|0)==0:0)?(Xl(t[(t[w>>2]|0)+8>>2]|0,162320)|0)==0:0)_T(t[u>>2]|0,3035,0,t[w>>2]|0)}else if(Xl(t[(t[r+36>>2]|0)+8>>2]|0,t[38526]|0)|0)_T(t[u>>2]|0,3035,0,t[w>>2]|0);t[w>>2]=t[(t[w>>2]|0)+24>>2]}Pd(t[u>>2]|0,t[o>>2]|0,161384)|0;t[h>>2]=IT(t[u>>2]|0,t[o>>2]|0,0,1073741824,1,161768)|0;t[k>>2]=BT(t[u>>2]|0,t[o>>2]|0,0,-1,1,161744)|0;HT(t[u>>2]|0,0,t[o>>2]|0,t[k>>2]|0,t[h>>2]|0)|0;t[b>>2]=nL(t[u>>2]|0,t[a>>2]|0,2,t[o>>2]|0)|0;if(!(t[b>>2]|0)){t[f>>2]=0;v=t[f>>2]|0;s=n;return v|0}rD(t[u>>2]|0,t[a>>2]|0,t[b>>2]|0,t[o>>2]|0)|0;t[l>>2]=t[(t[o>>2]|0)+12>>2];if((((t[l>>2]|0)!=0?(t[(t[l>>2]|0)+36>>2]|0)!=0:0)?(Xl(t[(t[l>>2]|0)+8>>2]|0,160992)|0)!=0:0)?(Xl(t[(t[(t[l>>2]|0)+36>>2]|0)+8>>2]|0,t[38526]|0)|0)!=0:0){t[d>>2]=jd(t[u>>2]|0,t[l>>2]|0,1)|0;t[l>>2]=t[(t[l>>2]|0)+24>>2]}if(t[l>>2]|0)$d(t[u>>2]|0,3033,0,t[o>>2]|0,t[l>>2]|0,0,161392);if((t[k>>2]|0)==0&(t[h>>2]|0)==0){t[f>>2]=0;v=t[f>>2]|0;s=n;return v|0}t[c>>2]=Mv(t[u>>2]|0,t[o>>2]|0,t[k>>2]|0,t[h>>2]|0)|0;if(!(t[c>>2]|0)){t[f>>2]=0;v=t[f>>2]|0;s=n;return v|0}else{t[(t[c>>2]|0)+4>>2]=t[d>>2];t[(t[c>>2]|0)+12>>2]=t[b>>2];t[f>>2]=t[c>>2];v=t[f>>2]|0;s=n;return v|0}return 0}function eD(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;var u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0,S=0,g=0,y=0,F=0,O=0,A=0,M=0,R=0,N=0,T=0,L=0,D=0,C=0;u=s;s=s+112|0;a=u+96|0;o=u+92|0;c=u+88|0;l=u+84|0;b=u+80|0;k=u+76|0;h=u+72|0;w=u+68|0;d=u+64|0;v=u+60|0;m=u+56|0;_=u+52|0;p=u+48|0;E=u+44|0;S=u+40|0;g=u+36|0;y=u+32|0;F=u+28|0;O=u+24|0;A=u+20|0;M=u+16|0;R=u+12|0;N=u+8|0;T=u+4|0;L=u;t[o>>2]=e;t[c>>2]=i;t[l>>2]=r;t[b>>2]=n;t[k>>2]=f;t[w>>2]=0;t[d>>2]=0;t[v>>2]=0;t[m>>2]=0;t[p>>2]=0;t[E>>2]=0;t[S>>2]=0;t[g>>2]=0;t[y>>2]=2;t[O>>2]=0;t[A>>2]=0;if((t[o>>2]|0)==0|(t[c>>2]|0)==0|(t[l>>2]|0)==0){t[a>>2]=0;D=t[a>>2]|0;s=u;return D|0}t[_>>2]=Bd(t[l>>2]|0,160064)|0;do if(t[_>>2]|0){if(xT(t[o>>2]|0,t[c>>2]|0,0,t[_>>2]|0,p,E)|0){t[a>>2]=0;D=t[a>>2]|0;s=u;return D|0}if(!(UT(t[o>>2]|0,t[c>>2]|0,t[l>>2]|0,t[_>>2]|0,t[p>>2]|0)|0)){t[g>>2]=1;break}t[a>>2]=0;D=t[a>>2]|0;s=u;return D|0}while(0);t[F>>2]=t[(t[o>>2]|0)+20>>2];t[_>>2]=t[(t[l>>2]|0)+44>>2];while(1){if(!(t[_>>2]|0))break;e:do if(!(t[(t[_>>2]|0)+36>>2]|0)){f=t[(t[_>>2]|0)+8>>2]|0;do if(t[g>>2]|0)if(!(Xl(f,161384)|0))if(Xl(t[(t[_>>2]|0)+8>>2]|0,160064)|0)break e;else break;else{wT(t[o>>2]|0,t[_>>2]|0)|0;break e}else{if(Xl(f,161352)|0)break e;if(Xl(t[(t[_>>2]|0)+8>>2]|0,161384)|0){wT(t[o>>2]|0,t[_>>2]|0)|0;break e}if(Xl(t[(t[_>>2]|0)+8>>2]|0,155448)|0){xT(t[o>>2]|0,t[c>>2]|0,0,t[_>>2]|0,p,E)|0;break e}if(Xl(t[(t[_>>2]|0)+8>>2]|0,163528)|0){t[O>>2]=1;t[h>>2]=Hd(t[o>>2]|0,t[_>>2]|0)|0;if(Xl(t[h>>2]|0,163536)|0){t[d>>2]=t[(t[o>>2]|0)+112>>2];break e}if(Xl(t[h>>2]|0,163552)|0)break e;Ud(t[o>>2]|0,3037,0,t[_>>2]|0,0,163568,t[h>>2]|0,0,0,0);break e}}while(0);if(Xl(t[(t[_>>2]|0)+8>>2]|0,163600)|0){t[h>>2]=Hd(t[o>>2]|0,t[_>>2]|0)|0;if(Xl(t[h>>2]|0,163608)|0){t[y>>2]=2;break}if(Xl(t[h>>2]|0,163624)|0){t[y>>2]=0;break}if(Xl(t[h>>2]|0,163640)|0){t[y>>2]=1;break}else{Ud(t[o>>2]|0,1774,0,t[_>>2]|0,0,163656,t[h>>2]|0,0,0,0);break}}if(Xl(t[(t[_>>2]|0)+8>>2]|0,159128)|0){f=t[o>>2]|0;n=t[_>>2]|0;if(t[S>>2]|0){zT(f,3051,0,n,159128,159120);break}else{t[S>>2]=Hd(f,n)|0;t[A>>2]=1;break}}if(Xl(t[(t[_>>2]|0)+8>>2]|0,159120)|0){n=t[o>>2]|0;f=t[_>>2]|0;if(t[S>>2]|0){zT(n,3051,0,f,159128,159120);break}else{t[S>>2]=Hd(n,f)|0;t[A>>2]=2;break}}else C=43}else if(Xl(t[(t[(t[_>>2]|0)+36>>2]|0)+8>>2]|0,t[38526]|0)|0)C=43;while(0);if((C|0)==43){C=0;_T(t[o>>2]|0,3035,0,t[_>>2]|0)}t[_>>2]=t[(t[_>>2]|0)+24>>2]}if((t[A>>2]|0)==1&(t[y>>2]|0)!=2)Ud(t[o>>2]|0,3052,0,t[l>>2]|0,0,163656,0,163696,0,0);if((t[F>>2]|0)!=(t[(t[o>>2]|0)+20>>2]|0)){t[a>>2]=0;D=t[a>>2]|0;s=u;return D|0}if(t[g>>2]|0){if(t[y>>2]|0){t[v>>2]=hD(t[o>>2]|0,t[l>>2]|0)|0;if(!(t[v>>2]|0)){t[a>>2]=0;D=t[a>>2]|0;s=u;return D|0}qT((t[(t[o>>2]|0)+28>>2]|0)+20|0,10,t[v>>2]|0)|0;t[(t[v>>2]|0)+24>>2]=t[y>>2];t[R>>2]=VT(t[o>>2]|0,15,t[E>>2]|0,t[p>>2]|0)|0;if(!(t[R>>2]|0)){t[a>>2]=0;D=t[a>>2]|0;s=u;return D|0}t[(t[v>>2]|0)+12>>2]=t[R>>2];if(t[S>>2]|0)t[(t[v>>2]|0)+28>>2]=t[S>>2];if((t[A>>2]|0)==2){R=(t[v>>2]|0)+16|0;t[R>>2]=t[R>>2]|1}}}else{if((t[O>>2]|0)==0?(t[(t[c>>2]|0)+24>>2]&2|0)!=0:0)t[d>>2]=t[(t[o>>2]|0)+112>>2];if(Xl(t[d>>2]|0,t[38860]|0)|0)th(t[o>>2]|0,3057,t[l>>2]|0,0,163792,t[38860]|0,0);t[_>>2]=Bd(t[l>>2]|0,161352)|0;O=t[o>>2]|0;if(!(t[_>>2]|0)){FT(O,3036,0,t[l>>2]|0,161352,0);t[a>>2]=0;D=t[a>>2]|0;s=u;return D|0}R=t[_>>2]|0;if(Id(O,0,R,ED(22)|0,w)|0){t[a>>2]=0;D=t[a>>2]|0;s=u;return D|0}if(Xl(t[w>>2]|0,163840)|0){R=t[o>>2]|0;O=t[_>>2]|0;Ud(R,3056,0,O,ED(22)|0,0,0,163848,0,0);t[a>>2]=0;D=t[a>>2]|0;s=u;return D|0}if(t[y>>2]|0){t[v>>2]=hD(t[o>>2]|0,t[l>>2]|0)|0;if(!(t[v>>2]|0)){t[a>>2]=0;D=t[a>>2]|0;s=u;return D|0}t[(t[v>>2]|0)+24>>2]=t[y>>2];t[M>>2]=XT(t[o>>2]|0,t[c>>2]|0,t[w>>2]|0,t[d>>2]|0,t[l>>2]|0,0)|0;if(!(t[M>>2]|0)){t[a>>2]=0;D=t[a>>2]|0;s=u;return D|0}if(t[E>>2]|0){t[(t[M>>2]|0)+24>>2]=t[E>>2];t[(t[M>>2]|0)+28>>2]=t[p>>2]}t[(t[v>>2]|0)+12>>2]=t[M>>2];
	if((t[S>>2]|0)!=0?(t[(t[M>>2]|0)+44>>2]=t[S>>2],(t[A>>2]|0)==2):0){A=(t[M>>2]|0)+60|0;t[A>>2]=t[A>>2]|512}}}t[m>>2]=t[(t[l>>2]|0)+12>>2];A=(t[m>>2]|0)!=0;if(t[y>>2]|0){if(((A?(t[(t[m>>2]|0)+36>>2]|0)!=0:0)?(Xl(t[(t[m>>2]|0)+8>>2]|0,160992)|0)!=0:0)?(Xl(t[(t[(t[m>>2]|0)+36>>2]|0)+8>>2]|0,t[38526]|0)|0)!=0:0){y=jd(t[o>>2]|0,t[m>>2]|0,1)|0;t[(t[v>>2]|0)+4>>2]=y;t[m>>2]=t[(t[m>>2]|0)+24>>2]}y=(t[m>>2]|0)!=0;do if(t[g>>2]|0){if(y){if((((t[m>>2]|0)!=0?(t[(t[m>>2]|0)+36>>2]|0)!=0:0)?(Xl(t[(t[m>>2]|0)+8>>2]|0,161024)|0)!=0:0)?(Xl(t[(t[(t[m>>2]|0)+36>>2]|0)+8>>2]|0,t[38526]|0)|0)!=0:0){$d(t[o>>2]|0,3054,0,t[l>>2]|0,t[m>>2]|0,0,161392);break}$d(t[o>>2]|0,3033,0,t[l>>2]|0,t[m>>2]|0,0,161392)}}else{if(((y?(t[(t[m>>2]|0)+36>>2]|0)!=0:0)?(Xl(t[(t[m>>2]|0)+8>>2]|0,161024)|0)!=0:0)?(Xl(t[(t[(t[m>>2]|0)+36>>2]|0)+8>>2]|0,t[38526]|0)|0)!=0:0){M=t[o>>2]|0;if(t[(t[(t[v>>2]|0)+12>>2]|0)+24>>2]|0)$d(M,3055,0,t[l>>2]|0,t[m>>2]|0,164128,0);else{S=Wd(M,t[c>>2]|0,t[m>>2]|0,0)|0;t[(t[(t[v>>2]|0)+12>>2]|0)+48>>2]=S}t[m>>2]=t[(t[m>>2]|0)+24>>2]}if(t[m>>2]|0)$d(t[o>>2]|0,3033,0,t[l>>2]|0,t[m>>2]|0,0,164200)}while(0);t[a>>2]=t[v>>2];D=t[a>>2]|0;s=u;return D|0}if(((A?(t[(t[m>>2]|0)+36>>2]|0)!=0:0)?(Xl(t[(t[m>>2]|0)+8>>2]|0,160992)|0)!=0:0)?(Xl(t[(t[(t[m>>2]|0)+36>>2]|0)+8>>2]|0,t[38526]|0)|0)!=0:0){jd(t[o>>2]|0,t[m>>2]|0,0)|0;t[m>>2]=t[(t[m>>2]|0)+24>>2]}if(t[m>>2]|0)$d(t[o>>2]|0,3033,0,t[l>>2]|0,t[m>>2]|0,0,161392);if((t[k>>2]|0)==16){mw(t[o>>2]|0,3086,t[l>>2]|0,0,163904,0,0,0);t[a>>2]=0;D=t[a>>2]|0;s=u;return D|0}if((t[k>>2]|0)==13){mw(t[o>>2]|0,3086,t[l>>2]|0,0,163992,0,0,0);t[a>>2]=0;D=t[a>>2]|0;s=u;return D|0}if(!(t[g>>2]|0)){t[E>>2]=t[w>>2];t[p>>2]=t[d>>2]}e:do if(t[b>>2]|0){t[T>>2]=0;while(1){if((t[T>>2]|0)>=(t[(t[b>>2]|0)+4>>2]|0))break e;t[v>>2]=t[(t[t[b>>2]>>2]|0)+(t[T>>2]<<2)>>2];if(((t[t[v>>2]>>2]|0)==2001?(t[E>>2]|0)==(t[(t[v>>2]|0)+8>>2]|0):0)?(t[p>>2]|0)==(t[(t[v>>2]|0)+12>>2]|0):0)break;t[T>>2]=(t[T>>2]|0)+1}t[L>>2]=0;d=t[o>>2]|0;w=t[l>>2]|0;mw(d,3086,w,0,164072,uh(L,t[p>>2]|0,t[E>>2]|0)|0,0,0);if(t[L>>2]|0){pAi[t[135736>>2]&511](t[L>>2]|0);t[L>>2]=0}t[a>>2]=0;D=t[a>>2]|0;s=u;return D|0}while(0);t[N>>2]=wD(t[o>>2]|0)|0;if(!(t[N>>2]|0)){t[a>>2]=0;D=t[a>>2]|0;s=u;return D|0}t[(t[N>>2]|0)+4>>2]=t[l>>2];t[(t[N>>2]|0)+8>>2]=t[E>>2];t[(t[N>>2]|0)+12>>2]=t[p>>2];if(t[g>>2]|0)qT((t[(t[o>>2]|0)+28>>2]|0)+20|0,10,t[N>>2]|0)|0;t[a>>2]=t[N>>2];D=t[a>>2]|0;s=u;return D|0}function iD(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0;n=s;s=s+48|0;f=n+36|0;u=n+32|0;a=n+28|0;o=n+24|0;c=n+20|0;l=n+16|0;b=n+12|0;k=n+8|0;h=n+4|0;w=n;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;t[l>>2]=0;t[k>>2]=0;t[h>>2]=0;if((t[u>>2]|0)==0|(t[a>>2]|0)==0|(t[o>>2]|0)==0){t[f>>2]=0;d=t[f>>2]|0;s=n;return d|0}t[b>>2]=Bd(t[o>>2]|0,160064)|0;r=t[u>>2]|0;if(!(t[b>>2]|0)){FT(r,3036,0,t[o>>2]|0,160064,0);t[f>>2]=0;d=t[f>>2]|0;s=n;return d|0}xT(r,t[a>>2]|0,0,t[b>>2]|0,k,h)|0;if(UT(t[u>>2]|0,t[a>>2]|0,t[o>>2]|0,t[b>>2]|0,t[k>>2]|0)|0){t[f>>2]=0;d=t[f>>2]|0;s=n;return d|0}t[b>>2]=t[(t[o>>2]|0)+44>>2];while(1){if(!(t[b>>2]|0))break;a=t[b>>2]|0;if(!(t[(t[b>>2]|0)+36>>2]|0)){if((Xl(t[a+8>>2]|0,160064)|0)==0?(Xl(t[(t[b>>2]|0)+8>>2]|0,161384)|0)==0:0)_T(t[u>>2]|0,3035,0,t[b>>2]|0)}else if(Xl(t[(t[a+36>>2]|0)+8>>2]|0,t[38526]|0)|0)_T(t[u>>2]|0,3035,0,t[b>>2]|0);t[b>>2]=t[(t[b>>2]|0)+24>>2]}Pd(t[u>>2]|0,t[o>>2]|0,161384)|0;t[l>>2]=t[(t[o>>2]|0)+12>>2];if((((t[l>>2]|0)!=0?(t[(t[l>>2]|0)+36>>2]|0)!=0:0)?(Xl(t[(t[l>>2]|0)+8>>2]|0,160992)|0)!=0:0)?(Xl(t[(t[(t[l>>2]|0)+36>>2]|0)+8>>2]|0,t[38526]|0)|0)!=0:0){jd(t[u>>2]|0,t[l>>2]|0,0)|0;t[l>>2]=t[(t[l>>2]|0)+24>>2]}if(t[l>>2]|0)$d(t[u>>2]|0,3033,0,t[o>>2]|0,t[l>>2]|0,0,161392);do if(((((t[(t[u>>2]|0)+100>>2]|0)!=0?(t[(t[u>>2]|0)+120>>2]|0)!=0:0)?(t[t[(t[(t[u>>2]|0)+120>>2]|0)+4>>2]>>2]|0)==16:0)?(t[h>>2]|0)==(t[(t[(t[u>>2]|0)+120>>2]|0)+16>>2]|0):0)?(t[k>>2]|0)==(t[(t[(t[u>>2]|0)+120>>2]|0)+20>>2]|0):0)if(t[(t[u>>2]|0)+124>>2]|0){t[w>>2]=0;l=t[u>>2]|0;b=t[o>>2]|0;th(l,3081,b,0,163408,uh(w,t[k>>2]|0,t[h>>2]|0)|0,0);if(t[w>>2]|0){pAi[t[135736>>2]&511](t[w>>2]|0);t[w>>2]=0}t[f>>2]=0;d=t[f>>2]|0;s=n;return d|0}else{b=(t[u>>2]|0)+124|0;t[b>>2]=(t[b>>2]|0)+1;t[c>>2]=VT(t[u>>2]|0,16,t[h>>2]|0,t[k>>2]|0)|0;if(t[c>>2]|0){t[(t[c>>2]|0)+20>>2]=t[o>>2];t[(t[(t[u>>2]|0)+120>>2]|0)+8>>2]=t[c>>2];break}t[f>>2]=0;d=t[f>>2]|0;s=n;return d|0}else v=35;while(0);do if((v|0)==35){t[c>>2]=VT(t[u>>2]|0,16,t[h>>2]|0,t[k>>2]|0)|0;if(t[c>>2]|0){t[(t[c>>2]|0)+20>>2]=t[o>>2];qT((t[(t[u>>2]|0)+28>>2]|0)+20|0,10,t[c>>2]|0)|0;break}t[f>>2]=0;d=t[f>>2]|0;s=n;return d|0}while(0);t[f>>2]=t[c>>2];d=t[f>>2]|0;s=n;return d|0}function rD(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0,S=0,g=0,y=0,F=0,O=0,A=0;f=s;s=s+64|0;a=f+56|0;o=f+52|0;c=f+44|0;l=f+40|0;b=f+36|0;k=f+32|0;h=f+28|0;w=f+24|0;d=f+20|0;v=f+16|0;m=f+12|0;_=f+8|0;p=f+4|0;E=f;t[o>>2]=e;t[f+48>>2]=i;t[c>>2]=r;t[l>>2]=n;t[w>>2]=0;t[m>>2]=0;t[b>>2]=Sw(t[o>>2]|0,t[l>>2]|0,162320)|0;do if((t[b>>2]|0)!=0?(Xl(t[b>>2]|0,148184)|0)==0:0){if(Xl(t[b>>2]|0,148168)|0){t[(t[c>>2]|0)+24>>2]=1;break}if(Xl(t[b>>2]|0,148176)|0){t[(t[c>>2]|0)+24>>2]=2;break}else{Ud(t[o>>2]|0,3037,0,t[l>>2]|0,0,162336,t[b>>2]|0,0,0,0);t[(t[c>>2]|0)+24>>2]=3;t[w>>2]=3037;break}}else S=3;while(0);if((S|0)==3)t[(t[c>>2]|0)+24>>2]=3;t[_>>2]=Bd(t[l>>2]|0,162304)|0;t[k>>2]=Hd(t[o>>2]|0,t[_>>2]|0)|0;e:do if((t[_>>2]|0)!=0?(Xl(t[k>>2]|0,162360)|0)==0:0){if(Xl(t[k>>2]|0,144400)|0){l=aD(t[o>>2]|0)|0;t[(t[c>>2]|0)+36>>2]=l;if(t[(t[c>>2]|0)+36>>2]|0){t[(t[(t[c>>2]|0)+36>>2]|0)+4>>2]=t[(t[o>>2]|0)+112>>2];break}t[a>>2]=-1;g=t[a>>2]|0;s=f;return g|0}t[E>>2]=t[k>>2];while(1){do if((u[t[E>>2]>>0]|0|0)==32)y=1;else{if(9<=(u[t[E>>2]>>0]|0|0)?(u[t[E>>2]>>0]|0|0)<=10:0){y=1;break}y=(u[t[E>>2]>>0]|0|0)==13}while(0);l=t[E>>2]|0;if(y){t[E>>2]=l+1;continue}t[p>>2]=l;while(1){if(u[t[p>>2]>>0]|0){do if((u[t[p>>2]>>0]|0|0)==32)F=1;else{if(9<=(u[t[p>>2]>>0]|0|0)?(u[t[p>>2]>>0]|0|0)<=10:0){F=1;break}F=(u[t[p>>2]>>0]|0|0)==13}while(0);O=F^1}else O=0;A=t[p>>2]|0;if(!O)break;t[p>>2]=A+1}if((A|0)==(t[E>>2]|0))break e;t[d>>2]=ql(t[E>>2]|0,(t[p>>2]|0)-(t[E>>2]|0)|0)|0;if((Xl(t[d>>2]|0,144400)|0)==0?(Xl(t[d>>2]|0,162360)|0)==0:0){do if(!(Xl(t[d>>2]|0,162448)|0))if(Xl(t[d>>2]|0,162472)|0){t[h>>2]=0;break}else{l=t[o>>2]|0;b=t[_>>2]|0;n=t[d>>2]|0;dT(l,0,b,n,ED(29)|0)|0;t[h>>2]=kz(t[(t[o>>2]|0)+80>>2]|0,t[d>>2]|0,-1)|0;break}else t[h>>2]=t[(t[o>>2]|0)+112>>2];while(0);t[v>>2]=t[(t[c>>2]|0)+32>>2];while(1){if(!(t[v>>2]|0))break;if((t[h>>2]|0)==(t[(t[v>>2]|0)+4>>2]|0))break;t[v>>2]=t[t[v>>2]>>2]}if(!(t[v>>2]|0)){t[v>>2]=aD(t[o>>2]|0)|0;if(!(t[v>>2]|0))break;t[(t[v>>2]|0)+4>>2]=t[h>>2];t[t[v>>2]>>2]=0;if(t[(t[c>>2]|0)+32>>2]|0){if(t[m>>2]|0)t[t[m>>2]>>2]=t[v>>2]}else t[(t[c>>2]|0)+32>>2]=t[v>>2];t[m>>2]=t[v>>2]}}else{Ud(t[o>>2]|0,1792,0,t[_>>2]|0,0,162368,t[d>>2]|0,0,0,0);t[w>>2]=1792}pAi[t[135736>>2]&511](t[d>>2]|0);t[E>>2]=t[p>>2];if(!(u[t[E>>2]>>0]|0))break e}pAi[t[135736>>2]&511](t[d>>2]|0);t[a>>2]=-1;g=t[a>>2]|0;s=f;return g|0}else S=11;while(0);if((S|0)==11)t[(t[c>>2]|0)+28>>2]=1;t[a>>2]=t[w>>2];g=t[a>>2]|0;s=f;return g|0}function nD(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0;n=s;s=s+32|0;f=n+28|0;u=n+24|0;a=n+20|0;o=n+16|0;c=n+12|0;l=n+8|0;b=n+4|0;k=n;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;t[l>>2]=0;if((t[u>>2]|0)==0|(t[a>>2]|0)==0|(t[o>>2]|0)==0){t[f>>2]=0;h=t[f>>2]|0;s=n;return h|0}t[c>>2]=gk()|0;if(!(t[c>>2]|0)){Qh(t[u>>2]|0,166944,t[o>>2]|0);t[f>>2]=0;h=t[f>>2]|0;s=n;return h|0}t[(t[c>>2]|0)+20>>2]=t[o>>2];t[b>>2]=Sw(t[u>>2]|0,t[o>>2]|0,166968)|0;if(!(t[b>>2]|0)){QT(t[u>>2]|0,t[o>>2]|0,t[l>>2]|0,1708,166976,t[(t[o>>2]|0)+8>>2]|0,0);Fk(t[c>>2]|0);t[f>>2]=0;h=t[f>>2]|0;s=n;return h|0}if((((t[o>>2]|0)!=0?(t[(t[o>>2]|0)+36>>2]|0)!=0:0)?(Xl(t[(t[o>>2]|0)+8>>2]|0,157848)|0)!=0:0)?(Xl(t[(t[(t[o>>2]|0)+36>>2]|0)+8>>2]|0,t[38526]|0)|0)!=0:0)t[t[c>>2]>>2]=1e3;else w=12;do if((w|0)==12){if((((t[o>>2]|0)!=0?(t[(t[o>>2]|0)+36>>2]|0)!=0:0)?(Xl(t[(t[o>>2]|0)+8>>2]|0,157832)|0)!=0:0)?(Xl(t[(t[(t[o>>2]|0)+36>>2]|0)+8>>2]|0,t[38526]|0)|0)!=0:0){t[t[c>>2]>>2]=1001;break}if((((t[o>>2]|0)!=0?(t[(t[o>>2]|0)+36>>2]|0)!=0:0)?(Xl(t[(t[o>>2]|0)+8>>2]|0,157816)|0)!=0:0)?(Xl(t[(t[(t[o>>2]|0)+36>>2]|0)+8>>2]|0,t[38526]|0)|0)!=0:0){t[t[c>>2]>>2]=1002;break}if((((t[o>>2]|0)!=0?(t[(t[o>>2]|0)+36>>2]|0)!=0:0)?(Xl(t[(t[o>>2]|0)+8>>2]|0,157800)|0)!=0:0)?(Xl(t[(t[(t[o>>2]|0)+36>>2]|0)+8>>2]|0,t[38526]|0)|0)!=0:0){t[t[c>>2]>>2]=1003;break}if((((t[o>>2]|0)!=0?(t[(t[o>>2]|0)+36>>2]|0)!=0:0)?(Xl(t[(t[o>>2]|0)+8>>2]|0,157936)|0)!=0:0)?(Xl(t[(t[(t[o>>2]|0)+36>>2]|0)+8>>2]|0,t[38526]|0)|0)!=0:0){t[t[c>>2]>>2]=1004;break}if((((t[o>>2]|0)!=0?(t[(t[o>>2]|0)+36>>2]|0)!=0:0)?(Xl(t[(t[o>>2]|0)+8>>2]|0,157952)|0)!=0:0)?(Xl(t[(t[(t[o>>2]|0)+36>>2]|0)+8>>2]|0,t[38526]|0)|0)!=0:0){t[t[c>>2]>>2]=1005;break}if((((t[o>>2]|0)!=0?(t[(t[o>>2]|0)+36>>2]|0)!=0:0)?(Xl(t[(t[o>>2]|0)+8>>2]|0,157792)|0)!=0:0)?(Xl(t[(t[(t[o>>2]|0)+36>>2]|0)+8>>2]|0,t[38526]|0)|0)!=0:0){t[t[c>>2]>>2]=1006;break}if((((t[o>>2]|0)!=0?(t[(t[o>>2]|0)+36>>2]|0)!=0:0)?(Xl(t[(t[o>>2]|0)+8>>2]|0,157880)|0)!=0:0)?(Xl(t[(t[(t[o>>2]|0)+36>>2]|0)+8>>2]|0,t[38526]|0)|0)!=0:0){t[t[c>>2]>>2]=1007;break}if((((t[o>>2]|0)!=0?(t[(t[o>>2]|0)+36>>2]|0)!=0:0)?(Xl(t[(t[o>>2]|0)+8>>2]|0,157864)|0)!=0:0)?(Xl(t[(t[(t[o>>2]|0)+36>>2]|0)+8>>2]|0,t[38526]|0)|0)!=0:0){t[t[c>>2]>>2]=1008;break}if((((t[o>>2]|0)!=0?(t[(t[o>>2]|0)+36>>2]|0)!=0:0)?(Xl(t[(t[o>>2]|0)+8>>2]|0,157896)|0)!=0:0)?(Xl(t[(t[(t[o>>2]|0)+36>>2]|0)+8>>2]|0,t[38526]|0)|0)!=0:0){t[t[c>>2]>>2]=1009;break}if((((t[o>>2]|0)!=0?(t[(t[o>>2]|0)+36>>2]|0)!=0:0)?(Xl(t[(t[o>>2]|0)+8>>2]|0,157904)|0)!=0:0)?(Xl(t[(t[(t[o>>2]|0)+36>>2]|0)+8>>2]|0,t[38526]|0)|0)!=0:0){t[t[c>>2]>>2]=1010;break}if((((t[o>>2]|0)!=0?(t[(t[o>>2]|0)+36>>2]|0)!=0:0)?(Xl(t[(t[o>>2]|0)+8>>2]|0,157920)|0)!=0:0)?(Xl(t[(t[(t[o>>2]|0)+36>>2]|0)+8>>2]|0,t[38526]|0)|0)!=0:0){t[t[c>>2]>>2]=1011;break}QT(t[u>>2]|0,t[o>>2]|0,t[l>>2]|0,1741,167e3,t[(t[o>>2]|0)+8>>2]|0,0);Fk(t[c>>2]|0);t[f>>2]=0;h=t[f>>2]|0;s=n;return h|0}while(0);Pd(t[u>>2]|0,t[o>>2]|0,161384)|0;t[(t[c>>2]|0)+8>>2]=t[b>>2];if((((t[t[c>>2]>>2]|0)!=1006?(t[t[c>>2]>>2]|0)!=1007:0)?(t[k>>2]=Sw(t[u>>2]|0,t[o>>2]|0,159120)|0,(t[k>>2]|0)!=0):0)?(Xl(t[k>>2]|0,165504)|0)!=0:0)t[(t[c>>2]|0)+24>>2]=1;t[l>>2]=t[(t[o>>2]|0)+12>>2];if((((t[l>>2]|0)!=0?(t[(t[l>>2]|0)+36>>2]|0)!=0:0)?(Xl(t[(t[l>>2]|0)+8>>2]|0,160992)|0)!=0:0)?(Xl(t[(t[(t[l>>2]|0)+36>>2]|0)+8>>2]|0,t[38526]|0)|0)!=0:0){k=jd(t[u>>2]|0,t[l>>2]|0,1)|0;t[(t[c>>2]|0)+16>>2]=k;t[l>>2]=t[(t[l>>2]|0)+24>>2]}if(t[l>>2]|0)QT(t[u>>2]|0,t[o>>2]|0,t[l>>2]|0,1740,167024,t[(t[o>>2]|0)+8>>2]|0,0);t[f>>2]=t[c>>2];h=t[f>>2]|0;s=n;return h|0}function fD(e,i,r,n,f,u,a){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;u=u|0;a=a|0;var o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0,S=0;o=s;s=s+48|0;c=o+44|0;l=o+40|0;b=o+36|0;k=o+32|0;h=o+28|0;w=o+24|0;d=o+20|0;v=o+16|0;m=o+12|0;_=o+8|0;p=o+4|0;E=o;t[l>>2]=e;t[b>>2]=i;t[k>>2]=r;t[h>>2]=n;t[w>>2]=f;t[d>>2]=u;t[v>>2]=a;t[t[d>>2]>>2]=0;t[t[v>>2]>>2]=0;t[E>>2]=qg(t[w>>2]|0,1)|0;if((t[E>>2]|0)>0){a=t[l>>2]|0;u=t[k>>2]|0;f=t[h>>2]|0;n=ED(21)|0;Ud(a,3037,u,f,n,0,t[w>>2]|0,0,0,0);t[t[v>>2]>>2]=t[w>>2];t[c>>2]=t[(t[l>>2]|0)+16>>2];S=t[c>>2]|0;s=o;return S|0}if((t[E>>2]|0)<0){t[c>>2]=-1;S=t[c>>2]|0;s=o;return S|0}if(Yq(t[w>>2]|0,58)|0){E=jg(t[w>>2]|0,p)|0;t[t[v>>2]>>2]=E;E=kz(t[(t[l>>2]|0)+80>>2]|0,t[t[v>>2]>>2]|0,-1)|0;t[t[v>>2]>>2]=E;t[m>>2]=kz(t[(t[l>>2]|0)+80>>2]|0,t[w>>2]|0,t[p>>2]|0)|0;t[_>>2]=wF(t[(t[h>>2]|0)+32>>2]|0,t[(t[h>>2]|0)+20>>2]|0,t[m>>2]|0)|0;m=t[l>>2]|0;if(!(t[_>>2]|0)){p=t[k>>2]|0;k=t[h>>2]|0;E=ED(21)|0;Ud(m,3037,p,k,E,0,t[w>>2]|0,162952,t[w>>2]|0,0);t[c>>2]=t[(t[l>>2]|0)+16>>2];S=t[c>>2]|0;s=o;return S|0}else{E=kz(t[m+80>>2]|0,t[(t[_>>2]|0)+8>>2]|0,-1)|0;t[t[d>>2]>>2]=E;t[c>>2]=0;S=t[c>>2]|0;s=o;return S|0}}t[_>>2]=wF(t[(t[h>>2]|0)+32>>2]|0,t[(t[h>>2]|0)+20>>2]|0,0)|0;if(!(t[_>>2]|0)){if(t[(t[b>>2]|0)+24>>2]&512)t[t[d>>2]>>2]=t[(t[l>>2]|0)+112>>2]}else{b=kz(t[(t[l>>2]|0)+80>>2]|0,t[(t[_>>2]|0)+8>>2]|0,-1)|0;t[t[d>>2]>>2]=b}b=kz(t[(t[l>>2]|0)+80>>2]|0,t[w>>2]|0,-1)|0;t[t[v>>2]>>2]=b;t[c>>2]=0;S=t[c>>2]|0;s=o;return S|0}function tD(e,i,r,n,f,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;u=u|0;var a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0;a=s;s=s+32|0;o=a+28|0;c=a+24|0;l=a+20|0;b=a+16|0;k=a+12|0;h=a+8|0;w=a+4|0;d=a;t[c>>2]=e;t[l>>2]=i;t[b>>2]=r;t[k>>2]=n;t[h>>2]=f;t[w>>2]=u;t[d>>2]=0;if((t[c>>2]|0)==0|(t[l>>2]|0)==0|(t[b>>2]|0)==0){t[o>>2]=0;v=t[o>>2]|0;s=a;return v|0}t[d>>2]=gAi[t[135744>>2]&511](40)|0;if(!(t[d>>2]|0)){Qh(t[c>>2]|0,165384,0);t[o>>2]=0;v=t[o>>2]|0;s=a;return v|0}l=(t[d>>2]|0)+0|0;u=l+40|0;do{t[l>>2]=0;l=l+4|0}while((l|0)<(u|0));t[(t[d>>2]|0)+20>>2]=t[k>>2];t[(t[d>>2]|0)+16>>2]=t[b>>2];t[t[d>>2]>>2]=t[h>>2];t[(t[d>>2]|0)+12>>2]=t[w>>2];qT((t[(t[(t[c>>2]|0)+28>>2]|0)+16>>2]|0)+44|0,5,t[d>>2]|0)|0;if((t[h>>2]|0)==24)qT((t[(t[c>>2]|0)+28>>2]|0)+20|0,10,t[d>>2]|0)|0;t[o>>2]=t[d>>2];v=t[o>>2]|0;s=a;return v|0}function uD(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0;f=s;s=s+32|0;u=f+28|0;a=f+24|0;o=f+20|0;c=f+16|0;l=f+12|0;b=f+8|0;k=f+4|0;h=f;t[a>>2]=e;t[o>>2]=i;t[c>>2]=r;t[l>>2]=n;t[k>>2]=0;t[h>>2]=t[(t[c>>2]|0)+44>>2];while(1){if(!(t[h>>2]|0))break;n=t[h>>2]|0;if(!(t[(t[h>>2]|0)+36>>2]|0)){if((Xl(t[n+8>>2]|0,161384)|0)==0?(Xl(t[(t[h>>2]|0)+8>>2]|0,164904)|0)==0:0)_T(t[a>>2]|0,3035,0,t[h>>2]|0)}else if(Xl(t[(t[n+36>>2]|0)+8>>2]|0,t[38526]|0)|0)_T(t[a>>2]|0,3035,0,t[h>>2]|0);t[h>>2]=t[(t[h>>2]|0)+24>>2]}t[b>>2]=gAi[t[135744>>2]&511](20)|0;if(!(t[b>>2]|0)){Qh(t[a>>2]|0,164912,0);t[u>>2]=0;w=t[u>>2]|0;s=f;return w|0}n=t[b>>2]|0;t[n+0>>2]=0;t[n+4>>2]=0;t[n+8>>2]=0;t[n+12>>2]=0;t[n+16>>2]=0;t[h>>2]=Bd(t[c>>2]|0,164904)|0;n=t[a>>2]|0;if(t[h>>2]|0){r=Hd(n,t[h>>2]|0)|0;t[(t[b>>2]|0)+12>>2]=r;if((dD(t[a>>2]|0,t[o>>2]|0,t[b>>2]|0,t[h>>2]|0,t[l>>2]|0)|0)==-1)pw(t[a>>2]|0,t[h>>2]|0,3069,164976,0,0)}else FT(n,3036,0,t[c>>2]|0,161352,0);Pd(t[a>>2]|0,t[c>>2]|0,161384)|0;t[k>>2]=t[(t[c>>2]|0)+12>>2];if((((t[k>>2]|0)!=0?(t[(t[k>>2]|0)+36>>2]|0)!=0:0)?(Xl(t[(t[k>>2]|0)+8>>2]|0,160992)|0)!=0:0)?(Xl(t[(t[(t[k>>2]|0)+36>>2]|0)+8>>2]|0,t[38526]|0)|0)!=0:0){n=t[o>>2]|0;JL(n,jd(t[a>>2]|0,t[k>>2]|0,1)|0)|0;t[k>>2]=t[(t[k>>2]|0)+24>>2]}if(t[k>>2]|0)$d(t[a>>2]|0,3033,0,t[c>>2]|0,t[k>>2]|0,0,161392);t[u>>2]=t[b>>2];w=t[u>>2]|0;s=f;return w|0}function aD(e){e=e|0;var i=0,r=0,n=0,f=0,u=0;i=s;s=s+16|0;r=i+8|0;n=i+4|0;f=i;t[n>>2]=e;t[f>>2]=gAi[t[135744>>2]&511](8)|0;if(!(t[f>>2]|0)){Qh(t[n>>2]|0,152760,0);t[r>>2]=0;u=t[r>>2]|0;s=i;return u|0}else{t[(t[f>>2]|0)+4>>2]=0;t[t[f>>2]>>2]=0;t[r>>2]=t[f>>2];u=t[r>>2]|0;s=i;return u|0}return 0}function oD(e){e=e|0;var i=0,r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0;i=s;s=s+32|0;r=i+24|0;n=i+20|0;f=i+16|0;u=i+12|0;a=i+8|0;o=i+4|0;c=i;t[n>>2]=e;if((t[(t[n>>2]|0)+12>>2]|0)!=0?(t[(t[n>>2]|0)+16>>2]|0)!=0:0){if((t[t[(t[n>>2]|0)+12>>2]>>2]|0)!=7){t[o>>2]=0;t[c>>2]=t[(t[(t[n>>2]|0)+12>>2]|0)+12>>2];if(!(t[c>>2]|0)){t[r>>2]=0;l=t[r>>2]|0;s=i;return l|0}do{if((t[t[(t[c>>2]|0)+12>>2]>>2]|0)!=14?(t[t[(t[c>>2]|0)+12>>2]>>2]|0)!=2:0){e=oD(t[c>>2]|0)|0;t[o>>2]=(t[o>>2]|0)+e}else t[o>>2]=(t[o>>2]|0)+(t[(t[c>>2]|0)+16>>2]|0);t[c>>2]=t[(t[c>>2]|0)+8>>2]}while((t[c>>2]|0)!=0);t[r>>2]=te(t[(t[n>>2]|0)+16>>2]|0,t[o>>2]|0)|0;l=t[r>>2]|0;s=i;return l|0}t[f>>2]=-1;t[a>>2]=t[(t[(t[n>>2]|0)+12>>2]|0)+12>>2];if(!(t[a>>2]|0)){t[r>>2]=0;l=t[r>>2]|0;s=i;return l|0}while(1){if(!(t[a>>2]|0)){b=17;break}if((t[t[(t[a>>2]|0)+12>>2]>>2]|0)!=14?(t[t[(t[a>>2]|0)+12>>2]>>2]|0)!=2:0)t[u>>2]=oD(t[a>>2]|0)|0;else t[u>>2]=t[(t[a>>2]|0)+16>>2];if(!(t[u>>2]|0)){b=13;break}if((t[f>>2]|0)==-1?1:(t[f>>2]|0)>(t[u>>2]|0))t[f>>2]=t[u>>2];t[a>>2]=t[(t[a>>2]|0)+8>>2]}if((b|0)==13){t[r>>2]=0;l=t[r>>2]|0;s=i;return l|0}else if((b|0)==17){t[r>>2]=te(t[(t[n>>2]|0)+16>>2]|0,t[f>>2]|0)|0;l=t[r>>2]|0;s=i;return l|0}}t[r>>2]=0;l=t[r>>2]|0;s=i;return l|0}function cD(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0;f=s;s=s+32|0;u=f+20|0;a=f+16|0;o=f+12|0;c=f+8|0;l=f+4|0;b=f;t[a>>2]=e;t[o>>2]=i;t[c>>2]=r;t[l>>2]=n;t[b>>2]=vD(t[o>>2]|0,t[c>>2]|0)|0;if(t[b>>2]|0){t[u>>2]=0;k=t[u>>2]|0;s=f;return k|0}if(!((t[l>>2]&2|0)!=0?(t[(t[o>>2]|0)+48>>2]&2|0)!=0:0))h=4;do if((h|0)==4){if((t[l>>2]&1|0)!=0?(t[(t[o>>2]|0)+48>>2]&4|0)!=0:0)break;if((t[(t[o>>2]|0)+64>>2]|0)==(t[c>>2]|0)){t[u>>2]=0;k=t[u>>2]|0;s=f;return k|0}if((t[t[(t[o>>2]|0)+64>>2]>>2]|0)==1?(t[(t[(t[o>>2]|0)+64>>2]|0)+88>>2]|0)==45:0){t[u>>2]=1;k=t[u>>2]|0;s=f;return k|0}if((t[t[(t[o>>2]|0)+64>>2]>>2]|0)!=5?(t[(t[(t[o>>2]|0)+64>>2]|0)+88>>2]|0)!=45:0){t[u>>2]=lL(t[a>>2]|0,t[(t[o>>2]|0)+64>>2]|0,t[c>>2]|0,t[l>>2]|0)|0;k=t[u>>2]|0;s=f;return k|0}t[u>>2]=cD(t[a>>2]|0,t[(t[o>>2]|0)+64>>2]|0,t[c>>2]|0,t[l>>2]|0)|0;k=t[u>>2]|0;s=f;return k|0}while(0);t[u>>2]=1;k=t[u>>2]|0;s=f;return k|0}function lD(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0;r=s;s=s+16|0;n=r+8|0;f=r+4|0;u=r;t[f>>2]=e;t[u>>2]=i;if(!(t[(t[(t[f>>2]|0)+28>>2]|0)+24>>2]|0)){t[n>>2]=0;a=t[n>>2]|0;s=r;return a|0}else{t[n>>2]=fO(t[(t[(t[f>>2]|0)+28>>2]|0)+24>>2]|0,t[(t[u>>2]|0)+8>>2]|0,t[(t[u>>2]|0)+52>>2]|0)|0;a=t[n>>2]|0;s=r;return a|0}return 0}function sD(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0;r=s;s=s+16|0;n=r+12|0;f=r+8|0;u=r+4|0;a=r;t[f>>2]=e;t[u>>2]=i;if((t[(t[(t[f>>2]|0)+28>>2]|0)+24>>2]|0)==0?(i=KF(10,t[(t[f>>2]|0)+80>>2]|0)|0,t[(t[(t[f>>2]|0)+28>>2]|0)+24>>2]=i,(t[(t[(t[f>>2]|0)+28>>2]|0)+24>>2]|0)==0):0){t[n>>2]=0;o=t[n>>2]|0;s=r;return o|0}t[a>>2]=gAi[t[135744>>2]&511](8)|0;if(!(t[a>>2]|0)){Qh(0,158408,0);t[n>>2]=0;o=t[n>>2]|0;s=r;return o|0}i=t[a>>2]|0;t[i+0>>2]=0;t[i+4>>2]=0;t[t[a>>2]>>2]=t[u>>2];i=hh()|0;t[(t[a>>2]|0)+4>>2]=i;if(!(t[(t[a>>2]|0)+4>>2]|0)){$h(t[a>>2]|0);t[n>>2]=0;o=t[n>>2]|0;s=r;return o|0}if(QF(t[(t[(t[f>>2]|0)+28>>2]|0)+24>>2]|0,t[(t[u>>2]|0)+8>>2]|0,t[(t[u>>2]|0)+52>>2]|0,t[a>>2]|0)|0){rh(t[f>>2]|0,158456,158480);$h(t[a>>2]|0);t[n>>2]=0;o=t[n>>2]|0;s=r;return o|0}else{t[n>>2]=t[a>>2];o=t[n>>2]|0;s=r;return o|0}return 0}function bD(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0;f=s;s=s+32|0;u=f+28|0;a=f+24|0;o=f+20|0;c=f+16|0;l=f+12|0;b=f+8|0;k=f+4|0;h=f;t[a>>2]=e;t[o>>2]=i;t[c>>2]=r;t[l>>2]=n;t[b>>2]=0;if((t[c>>2]|0)==0|(t[l>>2]|0)==0){t[u>>2]=-1;w=t[u>>2]|0;s=f;return w|0}t[t[c>>2]>>2]=0;t[t[l>>2]>>2]=0;t[b>>2]=qg(t[o>>2]|0,1)|0;if((t[b>>2]|0)==-1){t[u>>2]=-1;w=t[u>>2]|0;s=f;return w|0}if((t[b>>2]|0)>0){b=t[a>>2]|0;n=t[o>>2]|0;ow(b,1824,0,n,ED(21)|0,1);t[u>>2]=1;w=t[u>>2]|0;s=f;return w|0}t[k>>2]=0;t[k>>2]=zg(t[o>>2]|0,h)|0;n=t[(t[a>>2]|0)+156>>2]|0;if(!(t[k>>2]|0)){b=kz(n,t[o>>2]|0,-1)|0;t[t[l>>2]>>2]=b}else{b=kz(n,t[k>>2]|0,-1)|0;t[t[l>>2]>>2]=b;pAi[t[135736>>2]&511](t[k>>2]|0)}k=Sd(t[a>>2]|0,t[h>>2]|0)|0;t[t[c>>2]>>2]=k;if((t[h>>2]|0)!=0?(pAi[t[135736>>2]&511](t[h>>2]|0),(t[t[c>>2]>>2]|0)==0):0){c=t[a>>2]|0;a=ED(21)|0;th(c,1824,0,a,154112,t[o>>2]|0,0);t[u>>2]=2;w=t[u>>2]|0;s=f;return w|0}t[u>>2]=0;w=t[u>>2]|0;s=f;return w|0}function kD(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0;n=s;s=s+16|0;f=n+12|0;u=n+8|0;a=n+4|0;o=n;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;if(t[o>>2]|0){r=t[u>>2]|0;i=t[o>>2]|0;if(t[(t[o>>2]|0)+36>>2]|0){t[f>>2]=uh(r,t[(t[i+36>>2]|0)+8>>2]|0,t[(t[o>>2]|0)+8>>2]|0)|0;c=t[f>>2]|0;s=n;return c|0}else{t[f>>2]=uh(r,0,t[i+8>>2]|0)|0;c=t[f>>2]|0;s=n;return c|0}}else if(t[a>>2]|0){t[f>>2]=uh(t[u>>2]|0,t[(t[a>>2]|0)+16>>2]|0,t[(t[a>>2]|0)+12>>2]|0)|0;c=t[f>>2]|0;s=n;return c|0}else{t[f>>2]=0;c=t[f>>2]|0;s=n;return c|0}return 0}function hD(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0;r=s;s=s+16|0;n=r+12|0;f=r+8|0;u=r+4|0;a=r;t[f>>2]=e;t[u>>2]=i;t[a>>2]=0;if(!(t[f>>2]|0)){t[n>>2]=0;o=t[n>>2]|0;s=r;return o|0}t[a>>2]=gAi[t[135744>>2]&511](36)|0;if(!(t[a>>2]|0)){Qh(t[f>>2]|0,164272,0);t[n>>2]=0;o=t[n>>2]|0;s=r;return o|0}else{i=(t[a>>2]|0)+0|0;e=i+36|0;do{t[i>>2]=0;i=i+4|0}while((i|0)<(e|0));t[t[a>>2]>>2]=26;t[(t[a>>2]|0)+20>>2]=t[u>>2];qT((t[(t[(t[f>>2]|0)+28>>2]|0)+16>>2]|0)+48|0,10,t[a>>2]|0)|0;t[n>>2]=t[a>>2];o=t[n>>2]|0;s=r;return o|0}return 0}function wD(e){e=e|0;var i=0,r=0,n=0,f=0,u=0;i=s;s=s+16|0;r=i+8|0;n=i+4|0;f=i;t[n>>2]=e;t[f>>2]=gAi[t[135744>>2]&511](20)|0;if(!(t[f>>2]|0)){Qh(t[n>>2]|0,164232,0);t[r>>2]=0;u=t[r>>2]|0;s=i;return u|0}else{e=t[f>>2]|0;t[e+0>>2]=0;t[e+4>>2]=0;t[e+8>>2]=0;t[e+12>>2]=0;t[e+16>>2]=0;t[t[f>>2]>>2]=2001;qT((t[(t[(t[n>>2]|0)+28>>2]|0)+16>>2]|0)+48|0,10,t[f>>2]|0)|0;t[r>>2]=t[f>>2];u=t[r>>2]|0;s=i;return u|0}return 0}function dD(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;var u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0;u=s;s=s+48|0;a=u+40|0;o=u+36|0;c=u+32|0;l=u+28|0;b=u+24|0;k=u+20|0;h=u+16|0;w=u+12|0;d=u+8|0;v=u+4|0;m=u;t[o>>2]=e;t[c>>2]=i;t[l>>2]=r;t[b>>2]=n;t[k>>2]=f;if(!(t[l>>2]|0)){pw(t[o>>2]|0,t[(t[c>>2]|0)+12>>2]|0,3069,165168,0,0);t[a>>2]=-1;_=t[a>>2]|0;s=u;return _|0}if(!(t[b>>2]|0))t[h>>2]=t[(t[c>>2]|0)+12>>2];else t[h>>2]=t[b>>2];if(!(t[(t[l>>2]|0)+12>>2]|0)){sv(t[o>>2]|0,3037,0,t[h>>2]|0,165248,0);t[a>>2]=3037;_=t[a>>2]|0;s=u;return _|0}t[w>>2]=0;t[d>>2]=0;if(!(t[b>>2]|0))t[d>>2]=0;else t[d>>2]=hF(t[(t[b>>2]|0)+32>>2]|0,t[(t[b>>2]|0)+20>>2]|0)|0;if(t[d>>2]|0){t[m>>2]=0;t[v>>2]=0;while(1){if(!(t[(t[d>>2]|0)+(t[v>>2]<<2)>>2]|0))break;t[m>>2]=(t[m>>2]|0)+1;t[v>>2]=(t[v>>2]|0)+1}t[w>>2]=gAi[t[135744>>2]&511]((t[m>>2]<<1)+1<<2)|0;if(!(t[w>>2]|0)){Qh(t[o>>2]|0,165304,0);pAi[t[135736>>2]&511](t[d>>2]|0);t[a>>2]=-1;_=t[a>>2]|0;s=u;return _|0}t[v>>2]=0;while(1){if((t[v>>2]|0)>=(t[m>>2]|0))break;t[(t[w>>2]|0)+(t[v>>2]<<1<<2)>>2]=t[(t[(t[d>>2]|0)+(t[v>>2]<<2)>>2]|0)+8>>2];t[(t[w>>2]|0)+((t[v>>2]<<1)+1<<2)>>2]=t[(t[(t[d>>2]|0)+(t[v>>2]<<2)>>2]|0)+12>>2];t[v>>2]=(t[v>>2]|0)+1}t[(t[w>>2]|0)+(t[m>>2]<<1<<2)>>2]=0;pAi[t[135736>>2]&511](t[d>>2]|0)}d=t[(t[l>>2]|0)+12>>2]|0;m=t[w>>2]|0;if(t[k>>2]|0){k=Fj(d,0,4,m)|0;t[(t[l>>2]|0)+16>>2]=k}else{k=Fj(d,0,2,m)|0;t[(t[l>>2]|0)+16>>2]=k}if(t[w>>2]|0)pAi[t[135736>>2]&511](t[w>>2]|0);if(!(t[(t[l>>2]|0)+16>>2]|0)){sv(t[o>>2]|0,3037,0,t[h>>2]|0,165336,t[(t[l>>2]|0)+12>>2]|0);t[a>>2]=3037;_=t[a>>2]|0;s=u;return _|0}else{t[a>>2]=0;_=t[a>>2]|0;s=u;return _|0}return 0}function vD(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0;r=s;s=s+16|0;n=r+8|0;f=r+4|0;u=r;t[f>>2]=e;t[u>>2]=i;if((t[f>>2]|0)==0|(t[u>>2]|0)==0){t[n>>2]=0;a=t[n>>2]|0;s=r;return a|0}else{t[n>>2]=(t[f>>2]|0)==(t[u>>2]|0)&1;a=t[n>>2]|0;s=r;return a|0}return 0}function mD(){var e=0,i=0,r=0,n=0,f=0;e=s;s=s+16|0;i=e+8|0;r=e+4|0;n=e;if(t[42590]|0){s=e;return}t[42592]=WF(40)|0;t[42596]=YD(170376,45,0)|0;t[(t[42596]|0)+64>>2]=t[42596];t[(t[42596]|0)+52>>2]=3;t[(t[42596]|0)+52>>2]=3;t[i>>2]=GD()|0;if(!(t[i>>2]|0)){s=e;return}t[(t[42596]|0)+28>>2]=t[i>>2];t[r>>2]=gAi[t[135744>>2]&511](20)|0;if(!(t[r>>2]|0)){WD(0,170392);s=e;return}f=t[r>>2]|0;t[f+0>>2]=0;t[f+4>>2]=0;t[f+8>>2]=0;t[f+12>>2]=0;t[f+16>>2]=0;t[t[r>>2]>>2]=6;t[(t[i>>2]|0)+12>>2]=t[r>>2];t[i>>2]=GD()|0;if(!(t[i>>2]|0)){s=e;return}t[(t[i>>2]|0)+16>>2]=0;t[(t[i>>2]|0)+20>>2]=1073741824;t[(t[r>>2]|0)+12>>2]=t[i>>2];t[n>>2]=gAi[t[135744>>2]&511](44)|0;if(!(t[n>>2]|0)){WD(0,170432);s=e;return}r=(t[n>>2]|0)+0|0;f=r+44|0;do{t[r>>2]=0;r=r+4|0}while((r|0)<(f|0));t[t[n>>2]>>2]=2;t[(t[n>>2]|0)+28>>2]=1;t[(t[n>>2]|0)+24>>2]=2;t[(t[i>>2]|0)+12>>2]=t[n>>2];t[n>>2]=gAi[t[135744>>2]&511](44)|0;if(!(t[n>>2]|0)){WD(0,170464);s=e;return}else{r=(t[n>>2]|0)+0|0;f=r+44|0;do{t[r>>2]=0;r=r+4|0}while((r|0)<(f|0));t[(t[n>>2]|0)+28>>2]=1;t[(t[n>>2]|0)+24>>2]=2;t[(t[42596]|0)+84>>2]=t[n>>2];t[42634]=YD(170520,46,t[42596]|0)|0;t[42638]=YD(170544,1,t[42634]|0)|0;t[42642]=YD(170560,3,t[42634]|0)|0;t[42646]=YD(170576,10,t[42634]|0)|0;t[42652]=YD(170592,11,t[42634]|0)|0;t[42656]=YD(170616,4,t[42634]|0)|0;t[42660]=YD(170632,8,t[42634]|0)|0;t[42666]=YD(170648,9,t[42634]|0)|0;t[42670]=YD(170672,6,t[42634]|0)|0;t[42676]=YD(170688,7,t[42634]|0)|0;t[42680]=YD(170712,5,t[42634]|0)|0;t[42686]=YD(170728,12,t[42634]|0)|0;t[42690]=YD(170752,13,t[42634]|0)|0;t[42694]=YD(170768,14,t[42634]|0)|0;t[42698]=YD(170784,15,t[42634]|0)|0;t[42702]=YD(170800,29,t[42634]|0)|0;t[42708]=YD(170816,43,t[42634]|0)|0;t[42714]=YD(170840,44,t[42634]|0)|0;t[42720]=YD(170864,28,t[42634]|0)|0;t[42724]=YD(170888,21,t[42634]|0)|0;t[42728]=YD(170904,30,t[42642]|0)|0;t[42736]=YD(170920,31,t[42728]|0)|0;t[42742]=YD(170952,32,t[42736]|0)|0;t[42746]=YD(170976,37,t[42728]|0)|0;t[42750]=YD(170992,35,t[42746]|0)|0;t[42754]=YD(171008,39,t[42750]|0)|0;t[42758]=YD(171024,41,t[42754]|0)|0;t[42766]=YD(171040,33,t[42728]|0)|0;t[42772]=YD(171072,38,t[42766]|0)|0;t[42778]=YD(171096,36,t[42772]|0)|0;t[42784]=YD(171120,40,t[42778]|0)|0;t[42790]=YD(171144,42,t[42784]|0)|0;t[42796]=YD(171168,34,t[42766]|0)|0;t[42804]=YD(171192,2,t[42638]|0)|0;t[42808]=YD(171224,16,t[42804]|0)|0;t[42814]=YD(171240,17,t[42808]|0)|0;t[42818]=YD(171264,20,t[42808]|0)|0;t[42822]=YD(171280,18,t[42808]|0)|0;t[42826]=YD(171296,22,t[42818]|0)|0;t[42830]=YD(171312,23,t[42826]|0)|0;t[42834]=YD(171328,24,t[42826]|0)|0;t[42838]=YD(171344,26,t[42826]|0)|0;t[42844]=YD(171360,27,t[42634]|0)|0;t[(t[42844]|0)+28>>2]=t[42838];t[42848]=YD(171384,25,t[42634]|0)|0;t[(t[42848]|0)+28>>2]=t[42834];t[42854]=YD(171400,19,t[42634]|0)|0;t[(t[42854]|0)+28>>2]=t[42822];t[42590]=1;s=e;return}}function _D(){var e=0,i=0;e=s;s=s+16|0;i=e;if(!(t[42590]|0)){s=e;return}yk(t[(t[42596]|0)+84>>2]|0);t[i>>2]=t[(t[42596]|0)+28>>2];yk(t[(t[(t[(t[i>>2]|0)+12>>2]|0)+12>>2]|0)+12>>2]|0);pAi[t[135736>>2]&511](t[(t[(t[i>>2]|0)+12>>2]|0)+12>>2]|0);pAi[t[135736>>2]&511](t[(t[i>>2]|0)+12>>2]|0);pAi[t[135736>>2]&511](t[i>>2]|0);t[(t[42596]|0)+28>>2]=0;XF(t[42592]|0,360);t[42590]=0;s=e;return}function pD(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0;r=s;s=s+16|0;n=r+8|0;f=r+4|0;u=r;t[f>>2]=e;t[u>>2]=i;e:do if(!(t[f>>2]|0))t[n>>2]=-1;else{if((t[t[f>>2]>>2]|0)!=1){t[n>>2]=-1;break}switch(t[(t[f>>2]|0)+88>>2]|0){case 15:{if((t[u>>2]|0)==1006|(t[u>>2]|0)==1008){t[n>>2]=1;break e}else{t[n>>2]=0;break e}break}case 3:{if((t[u>>2]|0)==1004|(t[u>>2]|0)==1005|(t[u>>2]|0)==1006|(t[u>>2]|0)==1008|(t[u>>2]|0)==1007|(t[u>>2]|0)==1002|(t[u>>2]|0)==1003|(t[u>>2]|0)==1e3|(t[u>>2]|0)==1001){t[n>>2]=1;break e}else{t[n>>2]=0;break e}break}case 14:case 13:case 12:case 11:case 10:case 9:case 8:case 7:case 6:case 5:case 4:{if((t[u>>2]|0)==1006|(t[u>>2]|0)==1007|(t[u>>2]|0)==1008|(t[u>>2]|0)==1002|(t[u>>2]|0)==1003|(t[u>>2]|0)==1e3|(t[u>>2]|0)==1001){t[n>>2]=1;break e}else{t[n>>2]=0;break e}break}case 43:case 44:case 29:case 21:case 28:case 1:{if((t[u>>2]|0)==1009|(t[u>>2]|0)==1011|(t[u>>2]|0)==1010|(t[u>>2]|0)==1006|(t[u>>2]|0)==1007|(t[u>>2]|0)==1008){t[n>>2]=1;break e}else{t[n>>2]=0;break e}break}default:{t[n>>2]=0;break e}}}while(0);s=r;return t[n>>2]|0}function ED(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i+4|0;n=i;t[n>>2]=e;if(!(t[42590]|0))mD();do switch(t[n>>2]|0){case 46:{t[r>>2]=t[42634];break}case 38:{t[r>>2]=t[42772];break}case 23:{t[r>>2]=t[42830];break}case 22:{t[r>>2]=t[42826];break}case 3:{t[r>>2]=t[42642];break}case 34:{t[r>>2]=t[42796];break}case 36:{t[r>>2]=t[42778];break}case 16:{t[r>>2]=t[42808];break}case 37:{t[r>>2]=t[42746];break}case 44:{t[r>>2]=t[42714];break}case 26:{t[r>>2]=t[42838];break}case 29:{t[r>>2]=t[42702];break}case 32:{t[r>>2]=t[42742];break}case 15:{t[r>>2]=t[42698];break}case 10:{t[r>>2]=t[42646];break}case 18:{t[r>>2]=t[42822];break}case 8:{t[r>>2]=t[42660];break}case 5:{t[r>>2]=t[42680];break}case 12:{t[r>>2]=t[42686];break}case 24:{t[r>>2]=t[42834];break}case 11:{t[r>>2]=t[42652];break}case 30:{t[r>>2]=t[42728];break}case 1:{t[r>>2]=t[42638];break}case 17:{t[r>>2]=t[42814];break}case 21:{t[r>>2]=t[42724];break}case 28:{t[r>>2]=t[42720];break}case 35:{t[r>>2]=t[42750];break}case 2:{t[r>>2]=t[42804];break}case 6:{t[r>>2]=t[42670];break}case 27:{t[r>>2]=t[42844];break}case 39:{t[r>>2]=t[42754];break}case 33:{t[r>>2]=t[42766];break}case 42:{t[r>>2]=t[42790];break}case 4:{t[r>>2]=t[42656];break}case 41:{t[r>>2]=t[42758];break}case 9:{t[r>>2]=t[42666];break}case 31:{t[r>>2]=t[42736];break}case 45:{t[r>>2]=t[42596];break}case 40:{t[r>>2]=t[42784];break}case 43:{t[r>>2]=t[42708];break}case 19:{t[r>>2]=t[42854];break}case 7:{t[r>>2]=t[42676];break}case 13:{t[r>>2]=t[42690];break}case 20:{t[r>>2]=t[42818];break}case 25:{t[r>>2]=t[42848];break}case 14:{t[r>>2]=t[42694];break}default:t[r>>2]=0}while(0);s=i;return t[r>>2]|0}function SD(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0;r=s;s=s+16|0;n=r+8|0;f=r+4|0;u=r;t[f>>2]=e;t[u>>2]=i;if((t[f>>2]|0)==0|(t[u>>2]|0)==0){t[n>>2]=-1;a=t[n>>2]|0;s=r;return a|0}else{t[(t[f>>2]|0)+4>>2]=t[u>>2];t[n>>2]=0;a=t[n>>2]|0;s=r;return a|0}return 0}function gD(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i+4|0;n=i;t[n>>2]=e;if(!(t[n>>2]|0))t[r>>2]=0;else t[r>>2]=t[(t[n>>2]|0)+4>>2];s=i;return t[r>>2]|0}function yD(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i+4|0;n=i;t[n>>2]=e;e:do if(!(t[n>>2]|0))t[r>>2]=0;else switch(t[t[n>>2]>>2]|0){case 29:case 26:case 24:case 23:case 22:case 20:case 18:case 17:case 16:case 46:case 2:case 1:{t[r>>2]=t[(t[n>>2]|0)+8>>2];break e;break}default:{t[r>>2]=0;break e}}while(0);s=i;return t[r>>2]|0}function FD(e){e=e|0;var i=0,r=0,n=0,f=0;i=s;s=s+16|0;r=i+4|0;n=i;t[n>>2]=e;if((t[n>>2]|0)!=0?(t[t[n>>2]>>2]|0)==15:0){t[r>>2]=t[(t[n>>2]|0)+8>>2];f=t[r>>2]|0;s=i;return f|0}t[r>>2]=0;f=t[r>>2]|0;s=i;return f|0}function OD(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0;r=s;s=s+16|0;n=r+12|0;f=r+8|0;u=r+4|0;a=r;t[f>>2]=e;t[u>>2]=i;t[a>>2]=KD(28)|0;if(!(t[a>>2]|0)){t[n>>2]=0;o=t[n>>2]|0;s=r;return o|0}t[(t[a>>2]|0)+8>>2]=t[f>>2];if(t[u>>2]|0)t[(t[a>>2]|0)+12>>2]=t[u>>2];t[n>>2]=t[a>>2];o=t[n>>2]|0;s=r;return o|0}function AD(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0;r=s;s=s+16|0;n=r+12|0;f=r+8|0;u=r+4|0;a=r;t[f>>2]=e;t[u>>2]=i;t[a>>2]=KD(21)|0;if(!(t[a>>2]|0)){t[n>>2]=0;o=t[n>>2]|0;s=r;return o|0}else{t[(t[a>>2]|0)+8>>2]=t[u>>2];t[(t[a>>2]|0)+12>>2]=t[f>>2];t[n>>2]=t[a>>2];o=t[n>>2]|0;s=r;return o|0}return 0}function MD(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i+4|0;n=i;t[r>>2]=e;while(1){if(!(t[r>>2]|0))break;switch(t[t[r>>2]>>2]|0){case 46:case 29:case 27:case 26:case 25:case 24:case 23:case 22:case 20:case 19:case 18:case 17:case 16:case 2:case 1:{if(t[(t[r>>2]|0)+8>>2]|0)pAi[t[135736>>2]&511](t[(t[r>>2]|0)+8>>2]|0);break}case 21:case 28:{if(t[(t[r>>2]|0)+12>>2]|0)pAi[t[135736>>2]&511](t[(t[r>>2]|0)+12>>2]|0);if(t[(t[r>>2]|0)+8>>2]|0)pAi[t[135736>>2]&511](t[(t[r>>2]|0)+8>>2]|0);break}case 44:{if(t[(t[r>>2]|0)+8>>2]|0)pAi[t[135736>>2]&511](t[(t[r>>2]|0)+8>>2]|0);break}case 43:{if(t[(t[r>>2]|0)+8>>2]|0)pAi[t[135736>>2]&511](t[(t[r>>2]|0)+8>>2]|0);break}default:{}}t[n>>2]=t[r>>2];t[r>>2]=t[(t[r>>2]|0)+4>>2];pAi[t[135736>>2]&511](t[n>>2]|0)}s=i;return}function RD(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0;r=s;s=s+16|0;n=r+8|0;f=r+4|0;u=r;t[f>>2]=e;t[u>>2]=i;if(!(t[42590]|0))mD();if(!(t[f>>2]|0)){t[n>>2]=0;a=t[n>>2]|0;s=r;return a|0}else{t[n>>2]=fO(t[42592]|0,t[f>>2]|0,t[u>>2]|0)|0;a=t[n>>2]|0;s=r;return a|0}return 0}function ND(e){e=e|0;var i=0,r=0,f=0,a=0,o=0,c=0,l=0,b=0,k=0;i=s;s=s+32|0;r=i+16|0;f=i+12|0;a=i+8|0;o=i+4|0;c=i;t[f>>2]=e;t[a>>2]=t[f>>2];t[o>>2]=0;if(!(t[f>>2]|0)){t[r>>2]=0;l=t[r>>2]|0;s=i;return l|0}while(1){if(((u[t[a>>2]>>0]|0|0)!=0?(u[t[a>>2]>>0]|0|0)!=13:0)?(u[t[a>>2]>>0]|0|0)!=9:0)b=(u[t[a>>2]>>0]|0|0)!=10;else b=0;k=t[a>>2]|0;if(!b)break;t[a>>2]=k+1}if(!(u[k>>0]|0)){t[r>>2]=0;l=t[r>>2]|0;s=i;return l|0}t[o>>2]=Yl(t[f>>2]|0)|0;t[c>>2]=(t[o>>2]|0)+((t[a>>2]|0)-(t[f>>2]|0));do{if(!(((u[t[c>>2]>>0]|0|0)!=13?(u[t[c>>2]>>0]|0|0)!=9:0)?(u[t[c>>2]>>0]|0|0)!=10:0))n[t[c>>2]>>0]=32;t[c>>2]=(t[c>>2]|0)+1}while((u[t[c>>2]>>0]|0|0)!=0);t[r>>2]=t[o>>2];l=t[r>>2]|0;s=i;return l|0}function TD(e){e=e|0;var i=0,r=0,f=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0;i=s;s=s+32|0;r=i+24|0;f=i+20|0;a=i+16|0;o=i+12|0;c=i+8|0;l=i+4|0;b=i;t[f>>2]=e;t[a>>2]=t[f>>2];t[b>>2]=0;if(!(t[f>>2]|0)){t[r>>2]=0;k=t[r>>2]|0;s=i;return k|0}while(1){do if(u[t[a>>2]>>0]|0)if((u[t[a>>2]>>0]|0|0)==32)h=1;else{if(9<=(u[t[a>>2]>>0]|0|0)?(u[t[a>>2]>>0]|0|0)<=10:0){h=1;break}h=(u[t[a>>2]>>0]|0|0)==13}else h=0;while(0);w=t[a>>2]|0;if(!h)break;t[a>>2]=w+1}t[o>>2]=w;while(1){if(!(u[t[o>>2]>>0]|0))break;if((u[t[o>>2]>>0]|0|0)==32){if((u[(t[o>>2]|0)+1>>0]|0|0)==32){d=17;break}if(9<=(u[(t[o>>2]|0)+1>>0]|0|0)?(u[(t[o>>2]|0)+1>>0]|0|0)<=10:0){d=17;break}if((u[(t[o>>2]|0)+1>>0]|0|0)==13){d=17;break}}if((u[t[o>>2]>>0]|0|0)==10){d=21;break}if((u[t[o>>2]>>0]|0|0)==9){d=21;break}if((u[t[o>>2]>>0]|0|0)==13){d=21;break}t[o>>2]=(t[o>>2]|0)+1;
	}if((d|0)==17)t[b>>2]=(t[o>>2]|0)-(t[a>>2]|0);else if((d|0)==21)t[b>>2]=(t[o>>2]|0)-(t[a>>2]|0);if(!(t[b>>2]|0)){t[c>>2]=t[o>>2];t[o>>2]=(t[o>>2]|0)+-1;while(1){do if((t[o>>2]|0)>>>0>(t[a>>2]|0)>>>0)if((u[t[o>>2]>>0]|0|0)==32)v=1;else{if(9<=(u[t[o>>2]>>0]|0|0)?(u[t[o>>2]>>0]|0|0)<=10:0){v=1;break}v=(u[t[o>>2]>>0]|0|0)==13}else v=0;while(0);m=t[o>>2]|0;if(!v)break;t[o>>2]=m+-1}t[o>>2]=m+1;if((t[a>>2]|0)==(t[f>>2]|0)?(t[c>>2]|0)==(t[o>>2]|0):0){t[r>>2]=0;k=t[r>>2]|0;s=i;return k|0}t[r>>2]=ql(t[a>>2]|0,(t[o>>2]|0)-(t[a>>2]|0)|0)|0;k=t[r>>2]|0;s=i;return k|0}t[a>>2]=Yl(t[a>>2]|0)|0;if(!(t[a>>2]|0)){t[r>>2]=0;k=t[r>>2]|0;s=i;return k|0}t[l>>2]=(t[a>>2]|0)+(t[b>>2]|0);t[o>>2]=t[l>>2];e:while(1){if(!(u[t[o>>2]>>0]|0))break;do if((u[t[o>>2]>>0]|0|0)!=32){if(9<=(u[t[o>>2]>>0]|0|0)?(u[t[o>>2]>>0]|0|0)<=10:0)break;if((u[t[o>>2]>>0]|0|0)!=13){b=t[o>>2]|0;t[o>>2]=b+1;c=n[b>>0]|0;b=t[l>>2]|0;t[l>>2]=b+1;n[b>>0]=c;continue e}}while(0);t[o>>2]=(t[o>>2]|0)+1;while(1){do if((u[t[o>>2]>>0]|0|0)==32)_=1;else{if(9<=(u[t[o>>2]>>0]|0|0)?(u[t[o>>2]>>0]|0|0)<=10:0){_=1;break}_=(u[t[o>>2]>>0]|0|0)==13}while(0);p=t[o>>2]|0;if(!_)break;t[o>>2]=p+1}if(!(u[p>>0]|0))continue;c=t[l>>2]|0;t[l>>2]=c+1;n[c>>0]=32}n[t[l>>2]>>0]=0;t[r>>2]=t[a>>2];k=t[r>>2]|0;s=i;return k|0}function LD(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,u=0,a=0,o=0,c=0;f=s;s=s+16|0;u=f+12|0;a=f+8|0;o=f+4|0;c=f;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;t[c>>2]=n;n=XD(t[u>>2]|0,t[a>>2]|0,t[o>>2]|0,t[c>>2]|0,0,0,1,1,0)|0;s=f;return n|0}function DD(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,u=0,a=0,o=0,c=0;f=s;s=s+16|0;u=f+12|0;a=f+8|0;o=f+4|0;c=f;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;t[c>>2]=n;n=XD(t[u>>2]|0,t[a>>2]|0,t[o>>2]|0,t[c>>2]|0,1,0,1,0,1)|0;s=f;return n|0}function CD(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0;n=s;s=s+16|0;f=n+8|0;u=n+4|0;a=n;t[f>>2]=e;t[u>>2]=i;t[a>>2]=r;r=LD(t[f>>2]|0,t[u>>2]|0,t[a>>2]|0,0)|0;s=n;return r|0}function PD(e){e=e|0;var i=0,r=0,n=0,f=0,u=0,a=0,o=0,c=0;i=s;s=s+32|0;r=i+16|0;n=i+12|0;f=i+8|0;u=i+4|0;a=i;t[n>>2]=e;t[f>>2]=0;t[u>>2]=0;e:while(1){if(!(t[n>>2]|0)){o=20;break}switch(t[t[n>>2]>>2]|0){case 43:{t[a>>2]=ZD(t[n>>2]|0)|0;if(t[(t[n>>2]|0)+8>>2]|0){e=Yl(t[(t[n>>2]|0)+8>>2]|0)|0;t[(t[a>>2]|0)+8>>2]=e}break}case 29:case 18:case 26:case 24:case 23:case 22:case 20:case 17:case 16:case 2:case 1:case 46:{t[a>>2]=ZD(t[n>>2]|0)|0;if(t[(t[n>>2]|0)+8>>2]|0){e=Yl(t[(t[n>>2]|0)+8>>2]|0)|0;t[(t[a>>2]|0)+8>>2]=e}break}case 19:case 27:case 25:case 45:{o=4;break e;break}case 28:case 21:{t[a>>2]=ZD(t[n>>2]|0)|0;if(t[(t[n>>2]|0)+8>>2]|0){e=Yl(t[(t[n>>2]|0)+8>>2]|0)|0;t[(t[a>>2]|0)+8>>2]=e}if(t[(t[n>>2]|0)+12>>2]|0){e=Yl(t[(t[n>>2]|0)+12>>2]|0)|0;t[(t[a>>2]|0)+12>>2]=e}break}case 44:{t[a>>2]=ZD(t[n>>2]|0)|0;if(t[(t[n>>2]|0)+8>>2]|0){e=Yl(t[(t[n>>2]|0)+8>>2]|0)|0;t[(t[a>>2]|0)+8>>2]=e}break}default:t[a>>2]=ZD(t[n>>2]|0)|0}e=t[a>>2]|0;if(!(t[f>>2]|0))t[f>>2]=e;else t[(t[u>>2]|0)+4>>2]=e;t[u>>2]=t[a>>2];t[n>>2]=t[(t[n>>2]|0)+4>>2]}if((o|0)==4){MD(t[f>>2]|0);t[r>>2]=0;c=t[r>>2]|0;s=i;return c|0}else if((o|0)==20){t[r>>2]=t[f>>2];c=t[r>>2]|0;s=i;return c|0}return 0}function BD(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0;r=s;s=s+32|0;n=r+16|0;f=r+12|0;u=r+8|0;a=r+4|0;o=r;t[f>>2]=e;t[u>>2]=i;if((t[f>>2]|0)==0|(t[u>>2]|0)==0){t[n>>2]=-2;c=t[n>>2]|0;s=r;return c|0}do if((t[t[f>>2]>>2]|0)!=1)if((t[t[f>>2]>>2]|0)==2){t[a>>2]=2;break}else{t[a>>2]=3;break}else t[a>>2]=1;while(0);do if((t[t[u>>2]>>2]|0)!=1)if((t[t[u>>2]>>2]|0)==2){t[o>>2]=2;break}else{t[o>>2]=3;break}else t[o>>2]=1;while(0);t[n>>2]=JD(t[t[f>>2]>>2]|0,t[f>>2]|0,0,t[a>>2]|0,t[t[u>>2]>>2]|0,t[u>>2]|0,0,t[o>>2]|0)|0;c=t[n>>2]|0;s=r;return c|0}function ID(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,u=0,a=0,o=0,c=0,l=0,b=0;f=s;s=s+32|0;u=f+16|0;a=f+12|0;o=f+8|0;c=f+4|0;l=f;t[a>>2]=e;t[o>>2]=i;t[c>>2]=r;t[l>>2]=n;if((t[a>>2]|0)==0|(t[c>>2]|0)==0){t[u>>2]=-2;b=t[u>>2]|0;s=f;return b|0}else{t[u>>2]=JD(t[t[a>>2]>>2]|0,t[a>>2]|0,0,t[o>>2]|0,t[t[c>>2]>>2]|0,t[c>>2]|0,0,t[l>>2]|0)|0;b=t[u>>2]|0;s=f;return b|0}return 0}function HD(e){e=e|0;var i=0,r=0,n=0,f=0;i=s;s=s+16|0;r=i+4|0;n=i;t[n>>2]=e;if(!(t[n>>2]|0)){t[r>>2]=0;f=t[r>>2]|0;s=i;return f|0}else{t[r>>2]=t[(t[(t[n>>2]|0)+32>>2]|0)+8>>2];f=t[r>>2]|0;s=i;return f|0}return 0}function xD(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,u=0,a=0,o=0,c=0,l=0,b=0;f=s;s=s+32|0;u=f+16|0;a=f+12|0;o=f+8|0;c=f+4|0;l=f;t[a>>2]=e;t[o>>2]=i;t[c>>2]=r;t[l>>2]=n;if(!(t[a>>2]|0)){t[u>>2]=-1;b=t[u>>2]|0;s=f;return b|0}do if((t[t[a>>2]>>2]|0)==1009){if((t[c>>2]|0)!=(t[(t[(t[a>>2]|0)+32>>2]|0)+8>>2]|0)){if(t[l>>2]|0)t[t[l>>2]>>2]=t[(t[(t[a>>2]|0)+32>>2]|0)+8>>2];t[u>>2]=1830;b=t[u>>2]|0;s=f;return b|0}}else{if((t[t[a>>2]>>2]|0)==1011){if((t[c>>2]|0)>>>0>=(t[(t[(t[a>>2]|0)+32>>2]|0)+8>>2]|0)>>>0)break;if(t[l>>2]|0)t[t[l>>2]>>2]=t[(t[(t[a>>2]|0)+32>>2]|0)+8>>2];t[u>>2]=1831;b=t[u>>2]|0;s=f;return b|0}if((t[t[a>>2]>>2]|0)!=1010){t[u>>2]=UD(0,t[a>>2]|0,t[o>>2]|0,0)|0;b=t[u>>2]|0;s=f;return b|0}if((t[c>>2]|0)>>>0>(t[(t[(t[a>>2]|0)+32>>2]|0)+8>>2]|0)>>>0){if(t[l>>2]|0)t[t[l>>2]>>2]=t[(t[(t[a>>2]|0)+32>>2]|0)+8>>2];t[u>>2]=1832;b=t[u>>2]|0;s=f;return b|0}}while(0);t[u>>2]=0;b=t[u>>2]|0;s=f;return b|0}function UD(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,u=0,a=0,o=0,c=0,l=0,b=0;f=s;s=s+32|0;u=f+16|0;a=f+12|0;o=f+8|0;c=f+4|0;l=f;t[a>>2]=e;t[o>>2]=i;t[c>>2]=r;t[l>>2]=n;if(t[l>>2]|0){t[u>>2]=QD(t[o>>2]|0,0,t[t[l>>2]>>2]|0,t[c>>2]|0,t[l>>2]|0,0)|0;b=t[u>>2]|0;s=f;return b|0}if(t[a>>2]|0){t[u>>2]=QD(t[o>>2]|0,0,t[(t[a>>2]|0)+88>>2]|0,t[c>>2]|0,t[l>>2]|0,0)|0;b=t[u>>2]|0;s=f;return b|0}else{t[u>>2]=-1;b=t[u>>2]|0;s=f;return b|0}return 0}function zD(e,i,r,n,f,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;u=u|0;var a=0,o=0,c=0,l=0,b=0,k=0,h=0;a=s;s=s+32|0;o=a+20|0;c=a+16|0;l=a+12|0;b=a+8|0;k=a+4|0;h=a;t[o>>2]=e;t[c>>2]=i;t[l>>2]=r;t[b>>2]=n;t[k>>2]=f;t[h>>2]=u;u=$D(t[o>>2]|0,t[c>>2]|0,t[l>>2]|0,t[b>>2]|0,t[k>>2]|0,t[h>>2]|0)|0;s=a;return u|0}function jD(e,i,r,n,f,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;u=u|0;var a=0,o=0,c=0,l=0,b=0,k=0,h=0;a=s;s=s+32|0;o=a+20|0;c=a+16|0;l=a+12|0;b=a+8|0;k=a+4|0;h=a;t[o>>2]=e;t[c>>2]=i;t[l>>2]=r;t[b>>2]=n;t[k>>2]=f;t[h>>2]=u;u=QD(t[o>>2]|0,t[c>>2]|0,t[l>>2]|0,t[b>>2]|0,t[k>>2]|0,t[h>>2]|0)|0;s=a;return u|0}function VD(e,i){e=e|0;i=i|0;var r=0,u=0,o=0,b=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0,S=0,g=0,y=0,F=0,O=0,A=0,M=0,R=0,N=0,T=0,L=0,D=0,C=0,P=0,B=0,I=0,H=0,x=0,U=0,z=0,j=0,V=0,q=0,W=0,K=0;r=s;s=s+512|0;u=r+16|0;o=r+148|0;b=r+144|0;h=r+140|0;w=r+120|0;d=r+116|0;v=r+112|0;m=r+108|0;_=r+104|0;p=r+100|0;E=r+80|0;S=r+76|0;g=r+400|0;y=r+72|0;F=r+68|0;O=r+64|0;A=r+60|0;M=r+56|0;R=r+8|0;N=r;T=r+368|0;L=r+332|0;D=r+302|0;C=r+52|0;P=r+272|0;B=r+48|0;I=r+222|0;H=r+44|0;x=r+192|0;U=r+152|0;t[b>>2]=e;t[h>>2]=i;if((t[h>>2]|0)==0|(t[b>>2]|0)==0){t[o>>2]=-1;z=t[o>>2]|0;s=r;return z|0}t[t[h>>2]>>2]=0;e:do switch(t[t[b>>2]>>2]|0){case 9:{i=t[(t[b>>2]|0)+8>>2]|0;if((t[(t[b>>2]|0)+8>>2]|0)<0){e=G(i|0)|0;j=t[(t[b>>2]|0)+12>>2]&15;t[u>>2]=e;t[u+4>>2]=j;SY(L,35,171648,u)|0}else{j=t[(t[b>>2]|0)+12>>2]&15;t[u>>2]=i;t[u+4>>2]=j;SY(L,35,171664,u)|0}j=Yl(L)|0;t[t[h>>2]>>2]=j;break}case 8:{t[u>>2]=t[(t[b>>2]|0)+8>>2];SY(T,30,171608,u)|0;j=Yl(T)|0;t[t[h>>2]>>2]=j;break}case 2:{if(!(t[(t[b>>2]|0)+8>>2]|0)){j=Yl(171424)|0;t[t[h>>2]>>2]=j;break e}j=ND(t[(t[b>>2]|0)+8>>2]|0)|0;t[t[h>>2]>>2]=j;if(!(t[t[h>>2]>>2]|0)){j=Yl(t[(t[b>>2]|0)+8>>2]|0)|0;t[t[h>>2]>>2]=j}break}case 3:{if(((a[(t[b>>2]|0)+24>>1]|0)>>>8&65535|0)==1?(t[(t[b>>2]|0)+8>>2]|0)==0:0){j=Yl(171448)|0;t[t[h>>2]>>2]=j;break e}j=(t[b>>2]|0)+8|0;t[w+0>>2]=t[j+0>>2];t[w+4>>2]=t[j+4>>2];t[w+8>>2]=t[j+8>>2];t[w+12>>2]=t[j+12>>2];t[w+16>>2]=t[j+16>>2];t[v>>2]=0;t[d>>2]=((a[w+16>>1]|0)>>>8&65535)+2;if(f[w+16>>1]&1)t[d>>2]=(t[d>>2]|0)+1;if(!(((a[w+16>>1]|0)>>>1&127|0)!=0?((a[w+16>>1]|0)>>>1&127|0)!=((a[w+16>>1]|0)>>>8&65535|0):0))t[d>>2]=(t[d>>2]|0)+1;t[v>>2]=gAi[t[135744>>2]&511](t[d>>2]|0)|0;if(!(t[v>>2]|0)){t[o>>2]=-1;z=t[o>>2]|0;s=r;return z|0}t[m>>2]=t[v>>2];if(f[w+16>>1]&1){j=t[m>>2]|0;t[m>>2]=j+1;n[j>>0]=45}if(((a[w+16>>1]|0)>>>1&127|0)==((a[w+16>>1]|0)>>>8&65535|0)){j=t[m>>2]|0;t[m>>2]=j+1;n[j>>0]=48;j=t[m>>2]|0;t[m>>2]=j+1;n[j>>0]=46}do if(!(t[w+8>>2]|0)){j=t[m>>2]|0;i=(t[d>>2]|0)-((t[m>>2]|0)-(t[v>>2]|0))|0;if(t[w+4>>2]|0){e=t[w>>2]|0;t[u>>2]=t[w+4>>2];t[u+4>>2]=e;SY(j,i,171472,u)|0;break}else{t[u>>2]=t[w>>2];SY(j,i,171480,u)|0;break}}else{i=t[m>>2]|0;j=(t[d>>2]|0)-((t[m>>2]|0)-(t[v>>2]|0))|0;e=t[w+4>>2]|0;V=t[w>>2]|0;t[u>>2]=t[w+8>>2];t[u+4>>2]=e;t[u+8>>2]=V;SY(i,j,171456,u)|0}while(0);do if((a[w+16>>1]|0)>>>1&127){if(((a[w+16>>1]|0)>>>1&127|0)!=((a[w+16>>1]|0)>>>8&65535|0)){t[_>>2]=((a[w+16>>1]|0)>>>8&65535)-((a[w+16>>1]|0)>>>1&127);GY((t[m>>2]|0)+(t[_>>2]|0)+1|0,(t[m>>2]|0)+(t[_>>2]|0)|0,((a[w+16>>1]|0)>>>1&127)+1|0)|0;n[(t[m>>2]|0)+(t[_>>2]|0)>>0]=46;break}t[p>>2]=0;while(1){q=t[p>>2]|0;if(!(n[(t[m>>2]|0)+(t[p>>2]|0)>>0]|0))break;t[p>>2]=q+1}if(q>>>0<((a[w+16>>1]|0)>>>8&65535)>>>0){GY((t[m>>2]|0)+(((a[w+16>>1]|0)>>>8&65535)-(t[p>>2]|0))|0,t[m>>2]|0,(t[p>>2]|0)+1|0)|0;VY(t[m>>2]|0,48,((a[w+16>>1]|0)>>>8&65535)-(t[p>>2]|0)|0)|0}}else{t[m>>2]=(t[v>>2]|0)+(t[d>>2]|0)+-1;j=t[m>>2]|0;t[m>>2]=j+-1;n[j>>0]=0;j=t[m>>2]|0;t[m>>2]=j+-1;n[j>>0]=48;j=t[m>>2]|0;t[m>>2]=j+-1;n[j>>0]=46}while(0);t[t[h>>2]>>2]=t[v>>2];break}case 7:{j=gAi[t[135744>>2]&511](8)|0;t[t[h>>2]>>2]=j;if(t[t[h>>2]>>2]|0){j=t[t[h>>2]>>2]|0;i=(t[(t[b>>2]|0)+12>>2]|0)>>>4&31;t[u>>2]=t[(t[b>>2]|0)+12>>2]&15;t[u+4>>2]=i;SY(j,8,171632,u)|0;break e}t[o>>2]=-1;z=t[o>>2]|0;s=r;return z|0}case 15:{if(t[(t[b>>2]|0)+8>>2]|0){j=Yl(171528)|0;t[t[h>>2]>>2]=j;break e}else{j=Yl(171536)|0;t[t[h>>2]>>2]=j;break e}break}case 5:{j=gAi[t[135744>>2]&511](6)|0;t[t[h>>2]>>2]=j;if(t[t[h>>2]>>2]|0){j=t[t[h>>2]>>2]|0;t[u>>2]=(t[(t[b>>2]|0)+12>>2]|0)>>>4&31;SY(j,6,171624,u)|0;break e}t[o>>2]=-1;z=t[o>>2]|0;s=r;return z|0}case 42:case 40:case 38:case 36:case 35:case 39:case 41:case 37:case 33:case 32:case 31:case 34:case 30:{if(((a[(t[b>>2]|0)+24>>1]|0)>>>8&65535|0)==1?(t[(t[b>>2]|0)+8>>2]|0)==0:0){j=Yl(171488)|0;t[t[h>>2]>>2]=j;break e}j=(t[b>>2]|0)+8|0;t[E+0>>2]=t[j+0>>2];t[E+4>>2]=t[j+4>>2];t[E+8>>2]=t[j+8>>2];t[E+12>>2]=t[j+12>>2];t[E+16>>2]=t[j+16>>2];t[S>>2]=((a[E+16>>1]|0)>>>8&65535)+1;if(f[E+16>>1]&1)t[S>>2]=(t[S>>2]|0)+1;j=gAi[t[135744>>2]&511](t[S>>2]|0)|0;t[t[h>>2]>>2]=j;if(!(t[t[h>>2]>>2]|0)){t[o>>2]=-1;z=t[o>>2]|0;s=r;return z|0}if(t[E+8>>2]|0){j=t[t[h>>2]>>2]|0;i=t[S>>2]|0;V=t[E+8>>2]|0;e=t[E+4>>2]|0;W=t[E>>2]|0;if(f[E+16>>1]&1){t[u>>2]=V;t[u+4>>2]=e;t[u+8>>2]=W;SY(j,i,171496,u)|0;break e}else{t[u>>2]=V;t[u+4>>2]=e;t[u+8>>2]=W;SY(j,i,171456,u)|0;break e}}i=(f[E+16>>1]&1|0)!=0;j=t[t[h>>2]>>2]|0;W=t[S>>2]|0;if(t[E+4>>2]|0){e=t[E+4>>2]|0;V=t[E>>2]|0;if(i){t[u>>2]=e;t[u+4>>2]=V;SY(j,W,171512,u)|0;break e}else{t[u>>2]=e;t[u+4>>2]=V;SY(j,W,171472,u)|0;break e}}else{V=t[E>>2]|0;if(i){t[u>>2]=V;SY(j,W,171520,u)|0;break e}else{t[u>>2]=V;SY(j,W,171480,u)|0;break e}}break}case 12:{t[A>>2]=0;t[M>>2]=0;l[R>>3]=0;t[y>>2]=~~+Y(+(+(G(t[(t[b>>2]|0)+8>>2]|0)|0)/12))>>>0;W=G(t[(t[b>>2]|0)+8>>2]|0)|0;t[F>>2]=W-((t[y>>2]|0)*12|0);t[O>>2]=~~+Y(+(+G(+ +l[(t[b>>2]|0)+16>>3])/86400))>>>0;K=+G(+ +l[(t[b>>2]|0)+16>>3]);l[N>>3]=K-+(((t[O>>2]|0)*86400|0)>>>0);if(+l[N>>3]>0?(t[A>>2]=~~+Y(+(+l[N>>3]/3600))>>>0,l[N>>3]=+l[N>>3]-+(((t[A>>2]|0)*3600|0)>>>0),+l[N>>3]>0):0){t[M>>2]=~~+Y(+(+l[N>>3]/60))>>>0;l[R>>3]=+l[N>>3]-+(((t[M>>2]|0)*60|0)>>>0)}if((t[(t[b>>2]|0)+8>>2]|0)>=0?!(+l[(t[b>>2]|0)+16>>3]<0):0){W=t[F>>2]|0;j=t[O>>2]|0;V=t[A>>2]|0;i=t[M>>2]|0;K=+l[R>>3];t[u>>2]=t[y>>2];t[u+4>>2]=W;t[u+8>>2]=j;t[u+12>>2]=V;t[u+16>>2]=i;i=u+20|0;l[k>>3]=K;t[i>>2]=t[k>>2];t[i+4>>2]=t[k+4>>2];SY(g,100,171576,u)|0}else{i=t[F>>2]|0;V=t[O>>2]|0;j=t[A>>2]|0;W=t[M>>2]|0;K=+l[R>>3];t[u>>2]=t[y>>2];t[u+4>>2]=i;t[u+8>>2]=V;t[u+12>>2]=j;t[u+16>>2]=W;W=u+20|0;l[k>>3]=K;t[W>>2]=t[k>>2];t[W+4>>2]=t[k+4>>2];SY(g,100,171544,u)|0}W=Yl(g)|0;t[t[h>>2]>>2]=W;break}case 10:{do if(f[(t[b>>2]|0)+24>>1]&1){t[B>>2]=eC(t[b>>2]|0,0)|0;if(t[B>>2]|0){W=t[(t[B>>2]|0)+12>>2]&15;j=(t[(t[B>>2]|0)+12>>2]|0)>>>4&31;t[u>>2]=t[(t[B>>2]|0)+8>>2];t[u+4>>2]=W;t[u+8>>2]=j;SY(P,30,171728,u)|0;MD(t[B>>2]|0);break}t[o>>2]=-1;z=t[o>>2]|0;s=r;return z|0}else{j=t[(t[b>>2]|0)+12>>2]&15;W=(t[(t[b>>2]|0)+12>>2]|0)>>>4&31;t[u>>2]=t[(t[b>>2]|0)+8>>2];t[u+4>>2]=j;t[u+8>>2]=W;SY(P,30,171752,u)|0}while(0);W=Yl(P)|0;t[t[h>>2]>>2]=W;break}case 29:case 28:case 26:case 24:case 23:case 22:case 20:case 18:case 17:case 16:{if(!(t[(t[b>>2]|0)+8>>2]|0)){t[o>>2]=-1;z=t[o>>2]|0;s=r;return z|0}else{W=TD(t[(t[b>>2]|0)+8>>2]|0)|0;t[t[h>>2]>>2]=W;if(t[t[h>>2]>>2]|0)break e;W=Yl(t[(t[b>>2]|0)+8>>2]|0)|0;t[t[h>>2]>>2]=W;break e}break}case 4:{do if(f[(t[b>>2]|0)+24>>1]&1){t[C>>2]=eC(t[b>>2]|0,0)|0;if(t[C>>2]|0){W=(t[(t[C>>2]|0)+12>>2]|0)>>>14&63;K=+l[(t[C>>2]|0)+16>>3];t[u>>2]=(t[(t[C>>2]|0)+12>>2]|0)>>>9&31;t[u+4>>2]=W;W=u+8|0;l[k>>3]=K;t[W>>2]=t[k>>2];t[W+4>>2]=t[k+4>>2];SY(D,30,171680,u)|0;MD(t[C>>2]|0);break}t[o>>2]=-1;z=t[o>>2]|0;s=r;return z|0}else{W=(t[(t[b>>2]|0)+12>>2]|0)>>>14&63;K=+l[(t[b>>2]|0)+16>>3];t[u>>2]=(t[(t[b>>2]|0)+12>>2]|0)>>>9&31;t[u+4>>2]=W;W=u+8|0;l[k>>3]=K;t[W>>2]=t[k>>2];t[W+4>>2]=t[k+4>>2];SY(D,30,171704,u)|0}while(0);W=Yl(D)|0;t[t[h>>2]>>2]=W;break}case 6:{W=gAi[t[135744>>2]&511](6)|0;t[t[h>>2]>>2]=W;if(t[t[h>>2]>>2]|0){W=t[t[h>>2]>>2]|0;t[u>>2]=t[(t[b>>2]|0)+12>>2]&15;SY(W,6,171616,u)|0;break e}t[o>>2]=-1;z=t[o>>2]|0;s=r;return z|0}case 43:{W=Yl(t[(t[b>>2]|0)+8>>2]|0)|0;t[t[h>>2]>>2]=W;break}case 44:{W=Yl(t[(t[b>>2]|0)+8>>2]|0)|0;t[t[h>>2]>>2]=W;break}case 13:{l[k>>3]=+c[(t[b>>2]|0)+8>>2];t[u>>2]=t[k>>2];t[u+4>>2]=t[k+4>>2];SY(x,30,171848,u)|0;W=Yl(x)|0;t[t[h>>2]>>2]=W;break}case 14:{l[k>>3]=+l[(t[b>>2]|0)+8>>3];t[u>>2]=t[k>>2];t[u+4>>2]=t[k+4>>2];SY(U,40,171848,u)|0;W=Yl(U)|0;t[t[h>>2]>>2]=W;break}case 11:{do if(f[(t[b>>2]|0)+24>>1]&1){t[H>>2]=eC(t[b>>2]|0,0)|0;if(t[H>>2]|0){W=t[(t[H>>2]|0)+12>>2]&15;j=(t[(t[H>>2]|0)+12>>2]|0)>>>4&31;V=(t[(t[H>>2]|0)+12>>2]|0)>>>9&31;i=(t[(t[H>>2]|0)+12>>2]|0)>>>14&63;K=+l[(t[H>>2]|0)+16>>3];t[u>>2]=t[(t[H>>2]|0)+8>>2];t[u+4>>2]=W;t[u+8>>2]=j;t[u+12>>2]=V;t[u+16>>2]=i;i=u+20|0;l[k>>3]=K;t[i>>2]=t[k>>2];t[i+4>>2]=t[k+4>>2];SY(I,50,171768,u)|0;MD(t[H>>2]|0);break}t[o>>2]=-1;z=t[o>>2]|0;s=r;return z|0}else{i=t[(t[b>>2]|0)+12>>2]&15;V=(t[(t[b>>2]|0)+12>>2]|0)>>>4&31;j=(t[(t[b>>2]|0)+12>>2]|0)>>>9&31;W=(t[(t[b>>2]|0)+12>>2]|0)>>>14&63;K=+l[(t[b>>2]|0)+16>>3];t[u>>2]=t[(t[b>>2]|0)+8>>2];t[u+4>>2]=i;t[u+8>>2]=V;t[u+12>>2]=j;t[u+16>>2]=W;W=u+20|0;l[k>>3]=K;t[W>>2]=t[k>>2];t[W+4>>2]=t[k+4>>2];SY(I,50,171808,u)|0}while(0);W=Yl(I)|0;t[t[h>>2]>>2]=W;break}case 1:{if(!(t[(t[b>>2]|0)+8>>2]|0)){W=Yl(171424)|0;t[t[h>>2]>>2]=W;break e}else{W=Yl(t[(t[b>>2]|0)+8>>2]|0)|0;t[t[h>>2]>>2]=W;break e}break}case 21:{if(t[(t[b>>2]|0)+12>>2]|0){W=Yl(171432)|0;t[t[h>>2]>>2]=W;W=us(t[t[h>>2]>>2]|0,t[(t[b>>2]|0)+12>>2]|0)|0;t[t[h>>2]>>2]=W;W=us(t[t[h>>2]>>2]|0,171440)|0;t[t[h>>2]>>2]=W;W=us(t[t[h>>2]>>2]|0,t[(t[b>>2]|0)+12>>2]|0)|0;t[t[h>>2]>>2]=W;break e}W=Yl(t[(t[b>>2]|0)+8>>2]|0)|0;t[t[h>>2]>>2]=W;t[o>>2]=0;z=t[o>>2]|0;s=r;return z|0}default:{W=Yl(171856)|0;t[t[h>>2]>>2]=W;t[o>>2]=1;z=t[o>>2]|0;s=r;return z|0}}while(0);if(!(t[t[h>>2]>>2]|0)){t[o>>2]=-1;z=t[o>>2]|0;s=r;return z|0}else{t[o>>2]=0;z=t[o>>2]|0;s=r;return z|0}return 0}function qD(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i+4|0;n=i;t[n>>2]=e;if(!(t[n>>2]|0))t[r>>2]=0;else t[r>>2]=t[t[n>>2]>>2];s=i;return t[r>>2]|0}function YD(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,l=0;n=s;s=s+32|0;f=n+16|0;u=n+12|0;a=n+8|0;o=n+4|0;c=n;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;t[c>>2]=gAi[t[135744>>2]&511](120)|0;if(!(t[c>>2]|0)){WD(0,172376);t[f>>2]=0;l=t[f>>2]|0;s=n;return l|0}r=(t[c>>2]|0)+0|0;i=r+120|0;do{t[r>>2]=0;r=r+4|0}while((r|0)<(i|0));t[(t[c>>2]|0)+8>>2]=t[u>>2];t[(t[c>>2]|0)+112>>2]=172416;t[t[c>>2]>>2]=1;t[(t[c>>2]|0)+64>>2]=t[o>>2];t[(t[c>>2]|0)+52>>2]=6;switch(t[a>>2]|0){case 28:case 21:case 44:case 43:case 29:case 15:case 14:case 13:case 12:case 5:case 7:case 6:case 9:case 8:case 4:case 11:case 10:case 3:case 1:{o=(t[c>>2]|0)+48|0;t[o>>2]=t[o>>2]|16384;break}default:{}}switch(t[a>>2]|0){case 46:case 45:break;case 27:case 19:case 25:{o=(t[c>>2]|0)+48|0;t[o>>2]=t[o>>2]|64;o=iC(1)|0;t[(t[c>>2]|0)+68>>2]=o;o=(t[c>>2]|0)+48|0;t[o>>2]=t[o>>2]|134217728;break}default:{o=(t[c>>2]|0)+48|0;t[o>>2]=t[o>>2]|256}}QF(t[42592]|0,t[(t[c>>2]|0)+8>>2]|0,172416,t[c>>2]|0)|0;t[(t[c>>2]|0)+88>>2]=t[a>>2];t[f>>2]=t[c>>2];l=t[f>>2]|0;s=n;return l|0}function GD(){var e=0,i=0,r=0,n=0,f=0;e=s;s=s+16|0;i=e+4|0;r=e;t[r>>2]=0;t[r>>2]=gAi[t[135744>>2]&511](28)|0;if(!(t[r>>2]|0)){WD(0,172344);t[i>>2]=0;n=t[i>>2]|0;s=e;return n|0}else{f=t[r>>2]|0;t[f+0>>2]=0;t[f+4>>2]=0;t[f+8>>2]=0;t[f+12>>2]=0;t[f+16>>2]=0;t[f+20>>2]=0;t[f+24>>2]=0;t[t[r>>2]>>2]=25;t[(t[r>>2]|0)+16>>2]=1;t[(t[r>>2]|0)+20>>2]=1;t[i>>2]=t[r>>2];n=t[i>>2]|0;s=e;return n|0}return 0}function WD(e,i){e=e|0;i=i|0;var r=0,n=0,f=0;r=s;s=s+16|0;n=r+4|0;f=r;t[n>>2]=e;t[f>>2]=i;dp(15,2,t[n>>2]|0,0,t[f>>2]|0);s=r;return}function KD(e){e=e|0;var i=0,r=0,n=0,f=0,u=0;i=s;s=s+16|0;r=i+8|0;n=i+4|0;f=i;t[n>>2]=e;t[f>>2]=gAi[t[135744>>2]&511](32)|0;if(!(t[f>>2]|0)){t[r>>2]=0;u=t[r>>2]|0;s=i;return u|0}else{e=t[f>>2]|0;t[e+0>>2]=0;t[e+4>>2]=0;t[e+8>>2]=0;t[e+12>>2]=0;t[e+16>>2]=0;t[e+20>>2]=0;t[e+24>>2]=0;t[e+28>>2]=0;t[t[f>>2]>>2]=t[n>>2];t[r>>2]=t[f>>2];u=t[r>>2]|0;s=i;return u|0}return 0}function XD(e,i,r,a,o,b,k,h,w){e=e|0;i=i|0;r=r|0;a=a|0;o=o|0;b=b|0;k=k|0;h=h|0;w=w|0;var d=0,v=0,m=0,_=0,p=0,E=0,S=0,g=0,y=0,F=0,O=0,A=0,M=0,R=0,N=0,T=0,L=0,D=0,C=0,P=0,B=0,I=0,H=0,x=0,U=0,z=0,j=0,V=0,q=0,Y=0,G=0,W=0,K=0,X=0,Z=0,J=0,Q=0,$=0,ee=0,ie=0,re=0,ne=0,fe=0,te=0,ue=0,ae=0,oe=0,ce=0,le=0,se=0,be=0,ke=0,he=0,we=0,de=0,ve=0,me=0,_e=0,pe=0,Ee=0,Se=0,ge=0,ye=0,Fe=0,Oe=0,Ae=0,Me=0,Re=0,Ne=0,Te=0,Le=0,De=0,Ce=0,Pe=0,Be=0,Ie=0,He=0,xe=0,Ue=0,ze=0,je=0,Ve=0,qe=0,Ye=0,Ge=0,We=0,Ke=0,Xe=0,Ze=0,Je=0,Qe=0,$e=0,ei=0;d=s;s=s+352|0;v=d;m=d+316|0;_=d+312|0;p=d+308|0;E=d+304|0;S=d+300|0;g=d+296|0;y=d+292|0;F=d+288|0;O=d+284|0;A=d+280|0;M=d+276|0;R=d+272|0;N=d+268|0;T=d+264|0;L=d+260|0;D=d+256|0;C=d+252|0;P=d+248|0;B=d+244|0;I=d+240|0;H=d+320|0;x=d+236|0;U=d+232|0;z=d+228|0;j=d+224|0;V=d+220|0;q=d+216|0;Y=d+212|0;G=d+208|0;W=d+204|0;K=d+200|0;X=d+196|0;Z=d+192|0;J=d+188|0;Q=d+184|0;$=d+180|0;ee=d+176|0;ie=d+172|0;re=d+168|0;ne=d+164|0;fe=d+160|0;te=d+156|0;ue=d+152|0;ae=d+148|0;oe=d+144|0;ce=d+140|0;le=d+136|0;se=d+132|0;be=d+128|0;ke=d+124|0;he=d+120|0;we=d+116|0;de=d+112|0;ve=d+108|0;me=d+104|0;_e=d+100|0;pe=d+96|0;Ee=d+92|0;Se=d+88|0;ge=d+84|0;ye=d+80|0;Fe=d+76|0;Oe=d+72|0;Ae=d+68|0;Me=d+64|0;Re=d+60|0;Ne=d+56|0;Te=d+52|0;Le=d+48|0;De=d+44|0;Ce=d+40|0;Pe=d+36|0;Be=d+32|0;Ie=d+28|0;He=d+24|0;xe=d+20|0;Ue=d+16|0;ze=d+12|0;je=d+8|0;t[_>>2]=e;t[p>>2]=i;t[E>>2]=r;t[S>>2]=a;t[g>>2]=o;t[y>>2]=b;t[F>>2]=k;t[O>>2]=h;t[A>>2]=w;t[R>>2]=0;t[N>>2]=0;if(!(t[42590]|0))mD();if(!(t[_>>2]|0)){t[m>>2]=-1;Ve=t[m>>2]|0;s=d;return Ve|0}if(!(t[p>>2]|0))t[p>>2]=171424;if(t[E>>2]|0)t[t[E>>2]>>2]=0;if((((t[g>>2]|0)==0&(t[p>>2]|0)!=0?(t[(t[_>>2]|0)+88>>2]|0)!=1:0)?(t[(t[_>>2]|0)+88>>2]|0)!=45:0)?(t[(t[_>>2]|0)+88>>2]|0)!=46:0){g=t[p>>2]|0;if((t[(t[_>>2]|0)+88>>2]|0)==2)t[R>>2]=ND(g)|0;else t[R>>2]=TD(g)|0;if(t[R>>2]|0)t[p>>2]=t[R>>2]}e:do switch(t[(t[_>>2]|0)+88>>2]|0){case 11:case 10:case 9:case 8:case 7:case 6:case 5:case 4:{t[N>>2]=nC(t[(t[_>>2]|0)+88>>2]|0,t[p>>2]|0,t[E>>2]|0,t[F>>2]|0)|0;qe=571;break}case 14:case 13:{t[U>>2]=t[p>>2];t[z>>2]=0;t[j>>2]=0;t[V>>2]=0;i:do if(t[F>>2]|0)while(1){do if((u[t[U>>2]>>0]|0)!=32){if(9<=(u[t[U>>2]>>0]|0)?(u[t[U>>2]>>0]|0)<=10:0)break;if((u[t[U>>2]>>0]|0)!=13)break i}while(0);t[U>>2]=(t[U>>2]|0)+1}while(0);if(((u[t[U>>2]>>0]|0)==78?(u[(t[U>>2]|0)+1>>0]|0)==97:0)?(u[(t[U>>2]|0)+2>>0]|0)==78:0){t[U>>2]=(t[U>>2]|0)+3;if(u[t[U>>2]>>0]|0){qe=577;break e}if(!(t[E>>2]|0)){qe=580;break e}do if((t[_>>2]|0)==(t[42690]|0)){t[M>>2]=KD(13)|0;if(t[M>>2]|0){c[(t[M>>2]|0)+8>>2]=+l[15984];break}else{MD(t[M>>2]|0);qe=583;break e}}else{t[M>>2]=KD(14)|0;if(t[M>>2]|0){l[(t[M>>2]|0)+8>>3]=+l[15984];break}else{MD(t[M>>2]|0);qe=583;break e}}while(0);t[t[E>>2]>>2]=t[M>>2];qe=580;break e}if((u[t[U>>2]>>0]|0)==45){t[z>>2]=1;t[U>>2]=(t[U>>2]|0)+1}if(((u[t[U>>2]>>0]|0)==73?(u[(t[U>>2]|0)+1>>0]|0)==78:0)?(u[(t[U>>2]|0)+2>>0]|0)==70:0){t[U>>2]=(t[U>>2]|0)+3;if(u[t[U>>2]>>0]|0){qe=577;break e}if(!(t[E>>2]|0)){qe=580;break e}do if((t[_>>2]|0)==(t[42690]|0)){t[M>>2]=KD(13)|0;if(!(t[M>>2]|0)){MD(t[M>>2]|0);qe=583;break e}if(t[z>>2]|0){c[(t[M>>2]|0)+8>>2]=+l[15986];break}else{c[(t[M>>2]|0)+8>>2]=+l[15985];break}}else{t[M>>2]=KD(14)|0;if(!(t[M>>2]|0)){MD(t[M>>2]|0);qe=583;break e}if(t[z>>2]|0){l[(t[M>>2]|0)+8>>3]=+l[15986];break}else{l[(t[M>>2]|0)+8>>3]=+l[15985];break}}while(0);t[t[E>>2]>>2]=t[M>>2];qe=580;break e}if((t[z>>2]|0)==0?(u[t[U>>2]>>0]|0)==43:0)t[U>>2]=(t[U>>2]|0)+1;if(((u[t[U>>2]>>0]|0)!=0?(u[t[U>>2]>>0]|0)!=43:0)?(u[t[U>>2]>>0]|0)!=45:0){while(1){if((u[t[U>>2]>>0]|0)>=48)Ye=(u[t[U>>2]>>0]|0)<=57;else Ye=0;Ge=t[U>>2]|0;if(!Ye)break;t[U>>2]=Ge+1;t[j>>2]=(t[j>>2]|0)+1}i:do if((u[Ge>>0]|0)==46){t[U>>2]=(t[U>>2]|0)+1;while(1){if((u[t[U>>2]>>0]|0)<48)break i;if((u[t[U>>2]>>0]|0)>57)break i;t[U>>2]=(t[U>>2]|0)+1;t[V>>2]=(t[V>>2]|0)+1}}while(0);if(!((t[j>>2]|0)==0&(t[V>>2]|0)==0)){if(!((u[t[U>>2]>>0]|0)!=101?(u[t[U>>2]>>0]|0)!=69:0))qe=168;i:do if((qe|0)==168){t[U>>2]=(t[U>>2]|0)+1;if(!((u[t[U>>2]>>0]|0)!=45?(u[t[U>>2]>>0]|0)!=43:0))t[U>>2]=(t[U>>2]|0)+1;while(1){if((u[t[U>>2]>>0]|0)<48)break i;if((u[t[U>>2]>>0]|0)>57)break i;t[U>>2]=(t[U>>2]|0)+1}}while(0);i:do if(t[F>>2]|0)while(1){do if((u[t[U>>2]>>0]|0)!=32){if(9<=(u[t[U>>2]>>0]|0)?(u[t[U>>2]>>0]|0)<=10:0)break;if((u[t[U>>2]>>0]|0)!=13)break i}while(0);t[U>>2]=(t[U>>2]|0)+1}while(0);if(!(u[t[U>>2]>>0]|0))if(t[E>>2]|0)if((t[_>>2]|0)==(t[42690]|0)){t[M>>2]=KD(13)|0;if(!(t[M>>2]|0)){qe=583;break e}g=t[p>>2]|0;t[v>>2]=(t[M>>2]|0)+8;w=(jq(g,172216,v)|0)==1;g=t[M>>2]|0;if(w){t[t[E>>2]>>2]=g;qe=580;break e}else{MD(g);qe=577;break e}}else{t[M>>2]=KD(14)|0;if(!(t[M>>2]|0)){qe=583;break e}g=t[p>>2]|0;t[v>>2]=(t[M>>2]|0)+8;w=(jq(g,172224,v)|0)==1;g=t[M>>2]|0;if(w){t[t[E>>2]>>2]=g;qe=580;break e}else{MD(g);qe=577;break e}}else qe=580;else qe=577}else qe=577}else qe=577;break}case 2:{i:do if(t[F>>2]|0){if(t[O>>2]|0){g=t[p>>2]|0;if((t[y>>2]|0)==3)t[R>>2]=TD(g)|0;else t[R>>2]=ND(g)|0;if(t[R>>2]|0)t[p>>2]=t[R>>2]}}else{t[L>>2]=t[p>>2];while(1){if(!(u[t[L>>2]>>0]|0))break i;if((u[t[L>>2]>>0]|0)==13){qe=577;break e}if((u[t[L>>2]>>0]|0)==10){qe=577;break e}if((u[t[L>>2]>>0]|0)==9){qe=577;break e}t[L>>2]=(t[L>>2]|0)+1}}while(0);if(t[E>>2]|0){t[M>>2]=KD(2)|0;if(t[M>>2]|0){g=Yl(t[p>>2]|0)|0;t[(t[M>>2]|0)+8>>2]=g;t[t[E>>2]>>2]=t[M>>2];qe=580}else qe=583}else qe=580;break}case 46:case 45:{if((t[A>>2]|0)!=0&(t[E>>2]|0)!=0){t[M>>2]=KD(46)|0;if(t[M>>2]|0){g=Yl(t[p>>2]|0)|0;t[(t[M>>2]|0)+8>>2]=g;t[t[E>>2]>>2]=t[M>>2];qe=580}else qe=583}else qe=580;break}case 3:{t[D>>2]=t[p>>2];t[x>>2]=H;if((t[D>>2]|0)!=0?(u[t[D>>2]>>0]|0)!=0:0){i:do if(t[F>>2]|0)while(1){do if((u[t[D>>2]>>0]|0)!=32){if(9<=(u[t[D>>2]>>0]|0)?(u[t[D>>2]>>0]|0)<=10:0)break;if((u[t[D>>2]>>0]|0)!=13)break i}while(0);t[D>>2]=(t[D>>2]|0)+1}while(0);t[P>>2]=0;if((u[t[D>>2]>>0]|0)!=45){if((u[t[D>>2]>>0]|0)==43)t[D>>2]=(t[D>>2]|0)+1}else{t[P>>2]=1;t[D>>2]=(t[D>>2]|0)+1}if(u[t[D>>2]>>0]|0){t[C>>2]=0;t[B>>2]=-1;t[I>>2]=0;while(1){We=t[D>>2]|0;if((u[t[D>>2]>>0]|0)!=48)break;t[D>>2]=We+1;t[I>>2]=1}i:do if(u[We>>0]|0){while(1){if((u[t[D>>2]>>0]|0)<48)break;if((u[t[D>>2]>>0]|0)>57)break;g=t[D>>2]|0;t[D>>2]=g+1;w=n[g>>0]|0;g=t[x>>2]|0;t[x>>2]=g+1;n[g>>0]=w;t[C>>2]=(t[C>>2]|0)+1;if((t[C>>2]|0)>>>0>=24)break i}if((u[t[D>>2]>>0]|0)==46){t[D>>2]=(t[D>>2]|0)+1;t[B>>2]=t[C>>2];do{if((u[t[D>>2]>>0]|0)<48)break;if((u[t[D>>2]>>0]|0)>57)break;w=t[D>>2]|0;t[D>>2]=w+1;g=n[w>>0]|0;w=t[x>>2]|0;t[x>>2]=w+1;n[w>>0]=g;t[C>>2]=(t[C>>2]|0)+1}while((t[C>>2]|0)>>>0<24);if(!((t[C>>2]|0)!=0|(t[I>>2]|0)!=0)){qe=577;break e}}}while(0);i:do if(t[F>>2]|0)while(1){do if((u[t[D>>2]>>0]|0)!=32){if(9<=(u[t[D>>2]>>0]|0)?(u[t[D>>2]>>0]|0)<=10:0)break;if((u[t[D>>2]>>0]|0)!=13)break i}while(0);t[D>>2]=(t[D>>2]|0)+1}while(0);if(!(u[t[D>>2]>>0]|0))if((t[E>>2]|0)!=0?(t[M>>2]=KD(3)|0,(t[M>>2]|0)!=0):0){if(t[C>>2]|0){i:do if((t[B>>2]|0)!=-1)while(1){if((t[C>>2]|0)==(t[B>>2]|0))break i;if((u[(t[x>>2]|0)+-1>>0]|0)!=48)break i;t[x>>2]=(t[x>>2]|0)+-1;t[C>>2]=(t[C>>2]|0)+-1}while(0);if(t[C>>2]|0){n[t[x>>2]>>0]=0;t[x>>2]=H;rC(x,(t[M>>2]|0)+8|0,(t[M>>2]|0)+12|0,(t[M>>2]|0)+16|0)|0}}g=(t[M>>2]|0)+24|0;f[g>>1]=f[g>>1]&-2|t[P>>2]&1;do if(t[C>>2]|0){g=(t[M>>2]|0)+24|0;f[g>>1]=f[g>>1]&255|(t[C>>2]&255)<<8&65535;if((t[B>>2]|0)==-1){g=(t[M>>2]|0)+24|0;f[g>>1]=f[g>>1]&-255;break}else{g=(t[M>>2]|0)+24|0;f[g>>1]=f[g>>1]&-255|((t[C>>2]|0)-(t[B>>2]|0)&127)<<1&65535;break}}else{g=(t[M>>2]|0)+24|0;f[g>>1]=f[g>>1]&255|256}while(0);t[t[E>>2]>>2]=t[M>>2];qe=580}else qe=580;else qe=577}else qe=577}else qe=577;break}case 1:{i:do if(!(t[F>>2]|0)){t[T>>2]=t[p>>2];if((t[y>>2]|0)==2)while(1){if(!(u[t[T>>2]>>0]|0))break i;if((u[t[T>>2]>>0]|0)==13){qe=577;break e}if((u[t[T>>2]>>0]|0)==10){qe=577;break e}if((u[t[T>>2]>>0]|0)==9){qe=577;break e}t[T>>2]=(t[T>>2]|0)+1}if((t[y>>2]|0)==3)while(1){if(!(u[t[T>>2]>>0]|0))break i;if((u[t[T>>2]>>0]|0)==13){qe=577;break e}if((u[t[T>>2]>>0]|0)==10){qe=577;break e}if((u[t[T>>2]>>0]|0)==9){qe=577;break e}g=(u[t[T>>2]>>0]|0)==32;t[T>>2]=(t[T>>2]|0)+1;if(!g)continue;if((u[t[T>>2]>>0]|0)==32){qe=577;break e}}}while(0);if((t[A>>2]|0)!=0&(t[E>>2]|0)!=0){if(t[O>>2]|0){if((t[y>>2]|0)!=3){if((t[y>>2]|0)==2)t[R>>2]=ND(t[p>>2]|0)|0}else t[R>>2]=TD(t[p>>2]|0)|0;if(t[R>>2]|0)t[p>>2]=t[R>>2]}t[M>>2]=KD(1)|0;if(t[M>>2]|0){g=Yl(t[p>>2]|0)|0;t[(t[M>>2]|0)+8>>2]=g;t[t[E>>2]>>2]=t[M>>2];qe=580}else qe=583}else qe=580;break}case 12:{t[N>>2]=fC(t[_>>2]|0,t[p>>2]|0,t[E>>2]|0,t[F>>2]|0)|0;qe=571;break}case 15:{t[q>>2]=t[p>>2];do if(t[F>>2]|0){while(1){do if((u[t[q>>2]>>0]|0)==32)Ke=1;else{if(9<=(u[t[q>>2]>>0]|0)?(u[t[q>>2]>>0]|0)<=10:0){Ke=1;break}Ke=(u[t[q>>2]>>0]|0)==13}while(0);Xe=t[q>>2]|0;if(!Ke)break;t[q>>2]=Xe+1}do if((u[Xe>>0]|0)==48){t[N>>2]=0;t[q>>2]=(t[q>>2]|0)+1}else{if((u[t[q>>2]>>0]|0)==49){t[N>>2]=1;t[q>>2]=(t[q>>2]|0)+1;break}g=t[q>>2]|0;if((u[t[q>>2]>>0]|0)==116){t[q>>2]=g+1;w=t[q>>2]|0;t[q>>2]=w+1;if((u[w>>0]|0)!=114){qe=577;break e}w=t[q>>2]|0;t[q>>2]=w+1;if((u[w>>0]|0)!=117){qe=577;break e}w=t[q>>2]|0;t[q>>2]=w+1;if((u[w>>0]|0)!=101){qe=577;break e}t[N>>2]=1;break}if((u[g>>0]|0)!=102){qe=577;break e}t[q>>2]=(t[q>>2]|0)+1;g=t[q>>2]|0;t[q>>2]=g+1;if((u[g>>0]|0)!=97){qe=577;break e}g=t[q>>2]|0;t[q>>2]=g+1;if((u[g>>0]|0)!=108){qe=577;break e}g=t[q>>2]|0;t[q>>2]=g+1;if((u[g>>0]|0)!=115){qe=577;break e}g=t[q>>2]|0;t[q>>2]=g+1;if((u[g>>0]|0)!=101){qe=577;break e}t[N>>2]=0}while(0);if(u[t[q>>2]>>0]|0){while(1){do if((u[t[q>>2]>>0]|0)==32)Ze=1;else{if(9<=(u[t[q>>2]>>0]|0)?(u[t[q>>2]>>0]|0)<=10:0){Ze=1;break}Ze=(u[t[q>>2]>>0]|0)==13}while(0);Je=t[q>>2]|0;if(!Ze)break;t[q>>2]=Je+1}if(u[Je>>0]|0){qe=577;break e}}}else{if((u[t[q>>2]>>0]|0)==48?(u[(t[q>>2]|0)+1>>0]|0)==0:0){t[N>>2]=0;break}if((u[t[q>>2]>>0]|0)==49?(u[(t[q>>2]|0)+1>>0]|0)==0:0){t[N>>2]=1;break}if(((((u[t[q>>2]>>0]|0)==116?(u[(t[q>>2]|0)+1>>0]|0)==114:0)?(u[(t[q>>2]|0)+2>>0]|0)==117:0)?(u[(t[q>>2]|0)+3>>0]|0)==101:0)?(u[(t[q>>2]|0)+4>>0]|0)==0:0){t[N>>2]=1;break}if((u[t[q>>2]>>0]|0)!=102){qe=577;break e}if((u[(t[q>>2]|0)+1>>0]|0)!=97){qe=577;break e}if((u[(t[q>>2]|0)+2>>0]|0)!=108){qe=577;break e}if((u[(t[q>>2]|0)+3>>0]|0)!=115){qe=577;break e}if((u[(t[q>>2]|0)+4>>0]|0)!=101){qe=577;break e}if(u[(t[q>>2]|0)+5>>0]|0){qe=577;break e}t[N>>2]=0}while(0);if(t[E>>2]|0){t[M>>2]=KD(15)|0;if(t[M>>2]|0){t[(t[M>>2]|0)+8>>2]=t[N>>2];t[t[E>>2]>>2]=t[M>>2];qe=580}else qe=583}else qe=580;break}case 16:{t[Y>>2]=t[p>>2];i:do if(!(t[F>>2]|0))while(1){if(!(u[t[Y>>2]>>0]|0))break i;if((u[t[Y>>2]>>0]|0)==13){qe=577;break e}if((u[t[Y>>2]>>0]|0)==10){qe=577;break e}if((u[t[Y>>2]>>0]|0)==9){qe=577;break e}g=(u[t[Y>>2]>>0]|0)==32;t[Y>>2]=(t[Y>>2]|0)+1;if(!g)continue;if(!(u[t[Y>>2]>>0]|0)){qe=577;break e}if((u[t[Y>>2]>>0]|0)==32){qe=577;break e}}while(0);if(t[E>>2]|0){t[M>>2]=KD(16)|0;if(t[M>>2]|0){g=Yl(t[p>>2]|0)|0;t[(t[M>>2]|0)+8>>2]=g;t[t[E>>2]>>2]=t[M>>2];qe=580}else qe=583}else qe=580;break}case 17:{if((t[F>>2]|0)!=0?(t[R>>2]=TD(t[p>>2]|0)|0,(t[R>>2]|0)!=0):0)t[p>>2]=t[R>>2];if(($p(t[p>>2]|0)|0)==1)if(t[E>>2]|0){t[M>>2]=KD(17)|0;if(t[M>>2]|0){g=Yl(t[p>>2]|0)|0;t[(t[M>>2]|0)+8>>2]=g;t[t[E>>2]>>2]=t[M>>2];qe=580}else qe=583}else qe=580;else qe=577;break}case 18:{if(!(Gg(t[p>>2]|0,1)|0))if(t[E>>2]|0){t[M>>2]=KD(18)|0;if(t[M>>2]|0){g=Yl(t[p>>2]|0)|0;t[(t[M>>2]|0)+8>>2]=g;t[t[E>>2]>>2]=t[M>>2];qe=580}else qe=583}else qe=580;else qe=577;break}case 20:{t[N>>2]=Yg(t[p>>2]|0,1)|0;if((t[N>>2]|0)==0&(t[E>>2]|0)!=0&(t[p>>2]|0)!=0){t[M>>2]=KD(20)|0;if(t[M>>2]|0){t[G>>2]=t[p>>2];while(1){do if((u[t[G>>2]>>0]|0)==32)Qe=1;else{if(9<=(u[t[G>>2]>>0]|0)?(u[t[G>>2]>>0]|0)<=10:0){Qe=1;break}Qe=(u[t[G>>2]>>0]|0)==13}while(0);$e=t[G>>2]|0;if(!Qe)break;t[G>>2]=$e+1}t[W>>2]=$e;while(1){if(!(u[t[W>>2]>>0]|0))break;do if((u[t[W>>2]>>0]|0)==32)ei=1;else{if(9<=(u[t[W>>2]>>0]|0)?(u[t[W>>2]>>0]|0)<=10:0){ei=1;break}ei=(u[t[W>>2]>>0]|0)==13}while(0);if(!(ei^1))break;t[W>>2]=(t[W>>2]|0)+1}g=ql(t[G>>2]|0,(t[W>>2]|0)-(t[G>>2]|0)|0)|0;t[(t[M>>2]|0)+8>>2]=g;t[t[E>>2]>>2]=t[M>>2];qe=571}else qe=583}else qe=571;break}case 19:{t[N>>2]=tC(t[42822]|0,t[p>>2]|0,t[E>>2]|0,t[S>>2]|0)|0;if((t[N>>2]|0)>0){t[N>>2]=0;qe=571;break e}else{t[N>>2]=1;qe=571;break e}break}case 21:{t[K>>2]=0;t[X>>2]=0;t[N>>2]=qg(t[p>>2]|0,1)|0;if(t[N>>2]|0)qe=571;else{if(t[S>>2]|0){t[X>>2]=zg(t[p>>2]|0,Z)|0;t[J>>2]=wF(t[(t[S>>2]|0)+32>>2]|0,t[S>>2]|0,t[Z>>2]|0)|0;if((t[J>>2]|0)==0&(t[Z>>2]|0)!=0){pAi[t[135736>>2]&511](t[Z>>2]|0);if(!(t[X>>2]|0)){qe=577;break e}pAi[t[135736>>2]&511](t[X>>2]|0);qe=577;break e}if(t[J>>2]|0)t[K>>2]=t[(t[J>>2]|0)+8>>2];if(t[Z>>2]|0)pAi[t[135736>>2]&511](t[Z>>2]|0)}if(!(t[E>>2]|0)){if(!(t[X>>2]|0)){qe=571;break e}pAi[t[135736>>2]&511](t[X>>2]|0);qe=571;break e}t[M>>2]=KD(21)|0;g=(t[X>>2]|0)!=0;if(!(t[M>>2]|0)){if(!g){qe=583;break e}pAi[t[135736>>2]&511](t[X>>2]|0);qe=583;break e}if(g)t[(t[M>>2]|0)+8>>2]=t[X>>2];else{g=Yl(t[p>>2]|0)|0;t[(t[M>>2]|0)+8>>2]=g}if(t[K>>2]|0){g=Yl(t[K>>2]|0)|0;t[(t[M>>2]|0)+12>>2]=g}t[t[E>>2]>>2]=t[M>>2];qe=571}break}case 23:{t[N>>2]=Vg(t[p>>2]|0,1)|0;if((t[N>>2]|0)==0&(t[E>>2]|0)!=0){t[M>>2]=KD(23)|0;if(!(t[M>>2]|0)){qe=583;break e}g=Yl(t[p>>2]|0)|0;t[(t[M>>2]|0)+8>>2]=g;t[t[E>>2]>>2]=t[M>>2]}if(((t[N>>2]|0)==0&(t[S>>2]|0)!=0?(t[(t[S>>2]|0)+4>>2]|0)==2:0)?(t[Q>>2]=t[S>>2],(t[(t[Q>>2]|0)+40>>2]|0)!=2):0){t[ee>>2]=uC(t[p>>2]|0)|0;g=t[(t[S>>2]|0)+32>>2]|0;if(t[ee>>2]|0){t[$>>2]=zM(0,g,t[ee>>2]|0,t[Q>>2]|0)|0;pAi[t[135736>>2]&511](t[ee>>2]|0)}else t[$>>2]=zM(0,g,t[p>>2]|0,t[Q>>2]|0)|0;if(!(t[$>>2]|0)){t[N>>2]=2;qe=571;break e}else{t[(t[Q>>2]|0)+40>>2]=2;qe=571;break e}}else qe=571;break}case 22:{t[N>>2]=Vg(t[p>>2]|0,1)|0;if((t[N>>2]|0)==0&(t[E>>2]|0)!=0){t[M>>2]=KD(22)|0;if(t[M>>2]|0){g=Yl(t[p>>2]|0)|0;t[(t[M>>2]|0)+8>>2]=g;t[t[E>>2]>>2]=t[M>>2];qe=571}else qe=583}else qe=571;break}case 24:{t[N>>2]=Vg(t[p>>2]|0,1)|0;if((t[N>>2]|0)==0&(t[E>>2]|0)!=0){t[M>>2]=KD(24)|0;if(!(t[M>>2]|0)){qe=583;break e}g=Yl(t[p>>2]|0)|0;t[(t[M>>2]|0)+8>>2]=g;t[t[E>>2]>>2]=t[M>>2]}if((t[N>>2]|0)==0&(t[S>>2]|0)!=0?(t[(t[S>>2]|0)+4>>2]|0)==2:0){t[ie>>2]=t[S>>2];t[re>>2]=uC(t[p>>2]|0)|0;g=t[(t[S>>2]|0)+32>>2]|0;if(t[re>>2]|0){WM(0,g,t[re>>2]|0,t[ie>>2]|0)|0;pAi[t[135736>>2]&511](t[re>>2]|0)}else WM(0,g,t[p>>2]|0,t[ie>>2]|0)|0;t[(t[ie>>2]|0)+40>>2]=3;qe=571}else qe=571;break}case 25:{t[N>>2]=tC(t[42834]|0,t[p>>2]|0,t[E>>2]|0,t[S>>2]|0)|0;if((t[N>>2]|0)<0)t[N>>2]=2;else t[N>>2]=0;if((t[N>>2]|0)==0&(t[S>>2]|0)!=0?(t[(t[S>>2]|0)+4>>2]|0)==2:0){t[ne>>2]=t[S>>2];t[(t[ne>>2]|0)+40>>2]=4;qe=571}else qe=571;break}case 26:{t[N>>2]=Vg(t[p>>2]|0,1)|0;if(!((t[S>>2]|0)!=0?(t[(t[S>>2]|0)+32>>2]|0)!=0:0))t[N>>2]=3;do if(!(t[N>>2]|0)){t[fe>>2]=uC(t[p>>2]|0)|0;g=t[(t[S>>2]|0)+32>>2]|0;if(t[fe>>2]|0){t[te>>2]=h_(g,t[fe>>2]|0)|0;pAi[t[135736>>2]&511](t[fe>>2]|0)}else t[te>>2]=h_(g,t[p>>2]|0)|0;if((t[te>>2]|0)!=0?(t[(t[te>>2]|0)+48>>2]|0)==3:0)break;t[N>>2]=4}while(0);if((t[N>>2]|0)==0&(t[E>>2]|0)!=0){g=t[33976]|0;w=t[33980]|0;t[v>>2]=171992;t[v+4>>2]=2831;yAi[g&511](w,171960,v)}if((t[N>>2]|0)==0&(t[S>>2]|0)!=0?(t[(t[S>>2]|0)+4>>2]|0)==2:0){t[ue>>2]=t[S>>2];t[(t[ue>>2]|0)+40>>2]=5;qe=571}else qe=571;break}case 27:{if((t[S>>2]|0)!=0?(t[(t[S>>2]|0)+32>>2]|0)!=0:0){
	t[N>>2]=tC(t[42838]|0,t[p>>2]|0,t[E>>2]|0,t[S>>2]|0)|0;if((t[N>>2]|0)<=0)t[N>>2]=1;else t[N>>2]=0;if(!((t[N>>2]|0)==0&(t[S>>2]|0)!=0)){qe=571;break e}if((t[(t[S>>2]|0)+4>>2]|0)!=2){qe=571;break e}t[ae>>2]=t[S>>2];t[(t[ae>>2]|0)+40>>2]=6;qe=571;break e}if(t[R>>2]|0)pAi[t[135736>>2]&511](t[R>>2]|0);t[m>>2]=3;Ve=t[m>>2]|0;s=d;return Ve|0}case 28:{t[oe>>2]=0;t[ce>>2]=0;t[N>>2]=qg(t[p>>2]|0,1)|0;if((t[N>>2]|0)==0&(t[S>>2]|0)!=0){t[ce>>2]=zg(t[p>>2]|0,le)|0;do if(t[le>>2]|0){t[se>>2]=wF(t[(t[S>>2]|0)+32>>2]|0,t[S>>2]|0,t[le>>2]|0)|0;if(!(t[se>>2]|0)){t[N>>2]=1;break}if(t[E>>2]|0)t[oe>>2]=Yl(t[(t[se>>2]|0)+8>>2]|0)|0}while(0);if((t[ce>>2]|0)!=0?(t[E>>2]|0)==0|(t[N>>2]|0)!=0:0)pAi[t[135736>>2]&511](t[ce>>2]|0);if(t[le>>2]|0)pAi[t[135736>>2]&511](t[le>>2]|0)}if(!((t[S>>2]|0)!=0?(t[(t[S>>2]|0)+32>>2]|0)!=0:0))t[N>>2]=3;do if(!(t[N>>2]|0)){t[N>>2]=eR(0,t[(t[S>>2]|0)+32>>2]|0,t[p>>2]|0)|0;if((t[N>>2]|0)==1){t[N>>2]=0;break}else{t[N>>2]=1;break}}while(0);if((t[N>>2]|0)==0&(t[E>>2]|0)!=0){t[M>>2]=KD(28)|0;w=(t[ce>>2]|0)!=0;if(!(t[M>>2]|0)){if(w)pAi[t[135736>>2]&511](t[ce>>2]|0);if(!(t[oe>>2]|0)){qe=583;break e}pAi[t[135736>>2]&511](t[oe>>2]|0);qe=583;break e}if(w)t[(t[M>>2]|0)+8>>2]=t[ce>>2];else{w=Yl(t[p>>2]|0)|0;t[(t[M>>2]|0)+8>>2]=w}if(t[oe>>2]|0)t[(t[M>>2]|0)+12>>2]=t[oe>>2];t[t[E>>2]>>2]=t[M>>2];qe=571}else qe=571;break}case 29:{if(u[t[p>>2]>>0]|0){if((t[F>>2]|0)!=0?(t[R>>2]=TD(t[p>>2]|0)|0,(t[R>>2]|0)!=0):0)t[p>>2]=t[R>>2];t[ke>>2]=Yl(t[p>>2]|0)|0;t[he>>2]=t[ke>>2];while(1){if(!(n[t[he>>2]>>0]|0))break;do if((((((((u[t[he>>2]>>0]|0)>=32?(u[t[he>>2]>>0]|0)<127:0)?(u[t[he>>2]>>0]|0)!=32:0)?(u[t[he>>2]>>0]|0)!=60:0)?(u[t[he>>2]>>0]|0)!=62:0)?(u[t[he>>2]>>0]|0)!=34:0)?(u[t[he>>2]>>0]|0)!=123:0)?(u[t[he>>2]>>0]|0)!=125:0){if((u[t[he>>2]>>0]|0)==124){qe=409;break}if((u[t[he>>2]>>0]|0)==92){qe=409;break}if((u[t[he>>2]>>0]|0)==94){qe=409;break}if((u[t[he>>2]>>0]|0)==96){qe=409;break}if((u[t[he>>2]>>0]|0)==39)qe=409}else qe=409;while(0);if((qe|0)==409){qe=0;n[t[he>>2]>>0]=95}t[he>>2]=(t[he>>2]|0)+1}t[be>>2]=IA(t[ke>>2]|0)|0;pAi[t[135736>>2]&511](t[ke>>2]|0);if(!(t[be>>2]|0)){qe=577;break e}xA(t[be>>2]|0)}if(t[E>>2]|0){t[M>>2]=KD(29)|0;if(!(t[M>>2]|0))qe=583;else{w=Yl(t[p>>2]|0)|0;t[(t[M>>2]|0)+8>>2]=w;t[t[E>>2]>>2]=t[M>>2];qe=580}}else qe=580;break}case 43:{t[we>>2]=t[p>>2];t[_e>>2]=0;if(t[we>>2]|0){i:do if(t[F>>2]|0)while(1){do if((u[t[we>>2]>>0]|0)!=32){if(9<=(u[t[we>>2]>>0]|0)?(u[t[we>>2]>>0]|0)<=10:0)break;if((u[t[we>>2]>>0]|0)!=13)break i}while(0);t[we>>2]=(t[we>>2]|0)+1}while(0);t[de>>2]=t[we>>2];i:while(1){if(!((u[t[we>>2]>>0]|0)>=48?(u[t[we>>2]>>0]|0)<=57:0))qe=426;do if((qe|0)==426){qe=0;if((u[t[we>>2]>>0]|0)>=65?(u[t[we>>2]>>0]|0)<=70:0)break;if((u[t[we>>2]>>0]|0)<97)break i;if((u[t[we>>2]>>0]|0)>102)break i}while(0);t[_e>>2]=(t[_e>>2]|0)+1;t[we>>2]=(t[we>>2]|0)+1}i:do if(t[F>>2]|0)while(1){do if((u[t[we>>2]>>0]|0)!=32){if(9<=(u[t[we>>2]>>0]|0)?(u[t[we>>2]>>0]|0)<=10:0)break;if((u[t[we>>2]>>0]|0)!=13)break i}while(0);t[we>>2]=(t[we>>2]|0)+1}while(0);if((u[t[we>>2]>>0]|0)==0?((t[_e>>2]|0)%2|0|0)==0:0)if(t[E>>2]|0){t[M>>2]=KD(43)|0;if(!(t[M>>2]|0))qe=583;else{t[we>>2]=ql(t[de>>2]|0,t[_e>>2]|0)|0;if(!(t[we>>2]|0)){WD(t[S>>2]|0,172232);pAi[t[135736>>2]&511](t[M>>2]|0);qe=577;break e}t[me>>2]=(t[_e>>2]|0)/2|0;t[ve>>2]=t[we>>2];while(1){w=t[_e>>2]|0;t[_e>>2]=w+-1;if((w|0)<=0)break;if((u[t[ve>>2]>>0]|0)>=97)n[t[ve>>2]>>0]=(u[t[ve>>2]>>0]|0)-32;t[ve>>2]=(t[ve>>2]|0)+1}t[(t[M>>2]|0)+8>>2]=t[we>>2];t[(t[M>>2]|0)+12>>2]=t[me>>2];t[t[E>>2]>>2]=t[M>>2];qe=580}}else qe=580;else qe=577}else qe=577;break}case 44:{t[pe>>2]=t[p>>2];t[ge>>2]=0;t[ye>>2]=0;if(t[pe>>2]|0){while(1){if(!(n[t[pe>>2]>>0]|0))break;t[Fe>>2]=aC(n[t[pe>>2]>>0]|0)|0;if((t[Fe>>2]|0)>=0){if((t[Fe>>2]|0)>=64)break;t[ge>>2]=(t[ge>>2]|0)+1}t[pe>>2]=(t[pe>>2]|0)+1}while(1){if(!(n[t[pe>>2]>>0]|0))break;t[Oe>>2]=aC(n[t[pe>>2]>>0]|0)|0;if((t[Oe>>2]|0)>=0&(t[Oe>>2]|0)<64){qe=577;break e}if((t[Oe>>2]|0)==64)t[ye>>2]=(t[ye>>2]|0)+1;t[pe>>2]=(t[pe>>2]|0)+1}t[Se>>2]=((t[ge>>2]|0)/4|0)*3;do if(!(t[ye>>2]|0)){if((t[ge>>2]|0)%4|0){qe=577;break e}}else{if((t[ye>>2]|0)==1){if(((t[ge>>2]|0)%4|0|0)!=3){qe=577;break e}t[Ae>>2]=aC(n[t[pe>>2]>>0]|0)|0;while(1){if(!((t[Ae>>2]|0)<0|(t[Ae>>2]|0)>63))break;t[pe>>2]=(t[pe>>2]|0)+-1;t[Ae>>2]=aC(n[t[pe>>2]>>0]|0)|0}if(t[Ae>>2]&-61){qe=577;break e}t[Se>>2]=(t[Se>>2]|0)+2;break}if((t[ye>>2]|0)!=2){qe=577;break e}if(((t[ge>>2]|0)%4|0|0)!=2){qe=577;break e}t[Me>>2]=aC(n[t[pe>>2]>>0]|0)|0;while(1){if(!((t[Me>>2]|0)<0|(t[Me>>2]|0)>63))break;t[pe>>2]=(t[pe>>2]|0)+-1;t[Me>>2]=aC(n[t[pe>>2]>>0]|0)|0}if(t[Me>>2]&-49){qe=577;break e}t[Se>>2]=(t[Se>>2]|0)+1}while(0);if(t[E>>2]|0){t[M>>2]=KD(44)|0;if(!(t[M>>2]|0))qe=583;else{t[Ee>>2]=gAi[t[135752>>2]&511]((t[ge>>2]|0)+(t[ye>>2]|0)+1|0)|0;if(!(t[Ee>>2]|0)){WD(t[S>>2]|0,172256);pAi[t[135736>>2]&511](t[M>>2]|0);qe=577;break e}t[(t[M>>2]|0)+8>>2]=t[Ee>>2];t[pe>>2]=t[p>>2];while(1){if(!(n[t[pe>>2]>>0]|0))break;if((aC(n[t[pe>>2]>>0]|0)|0)>=0){n[t[Ee>>2]>>0]=n[t[pe>>2]>>0]|0;t[Ee>>2]=(t[Ee>>2]|0)+1}t[pe>>2]=(t[pe>>2]|0)+1}n[t[Ee>>2]>>0]=0;t[(t[M>>2]|0)+12>>2]=t[Se>>2];t[t[E>>2]>>2]=t[M>>2];qe=580}}else qe=580}else qe=577;break}case 33:case 32:case 31:case 34:case 30:{t[Re>>2]=t[p>>2];t[De>>2]=0;if(t[Re>>2]|0){i:do if(t[F>>2]|0)while(1){do if((u[t[Re>>2]>>0]|0)!=32){if(9<=(u[t[Re>>2]>>0]|0)?(u[t[Re>>2]>>0]|0)<=10:0)break;if((u[t[Re>>2]>>0]|0)!=13)break i}while(0);t[Re>>2]=(t[Re>>2]|0)+1}while(0);if((u[t[Re>>2]>>0]|0)!=45){if((u[t[Re>>2]>>0]|0)==43)t[Re>>2]=(t[Re>>2]|0)+1}else{t[De>>2]=1;t[Re>>2]=(t[Re>>2]|0)+1}t[N>>2]=rC(Re,Ne,Te,Le)|0;if((t[N>>2]|0)>=0){i:do if(t[F>>2]|0)while(1){do if((u[t[Re>>2]>>0]|0)!=32){if(9<=(u[t[Re>>2]>>0]|0)?(u[t[Re>>2]>>0]|0)<=10:0)break;if((u[t[Re>>2]>>0]|0)!=13)break i}while(0);t[Re>>2]=(t[Re>>2]|0)+1}while(0);if(!(u[t[Re>>2]>>0]|0)){do if((t[(t[_>>2]|0)+88>>2]|0)==31){if((t[De>>2]|0)==0?(t[Le>>2]|0)!=0|(t[Te>>2]|0)!=0|(t[Ne>>2]|0)!=0:0){qe=577;break e}}else{if((t[(t[_>>2]|0)+88>>2]|0)==34){if((t[De>>2]|0)==1){qe=577;break e}if((t[Le>>2]|0)==0&(t[Te>>2]|0)==0&(t[Ne>>2]|0)==0){qe=577;break e}else break}if((t[(t[_>>2]|0)+88>>2]|0)==32){if(!(t[De>>2]|0)){qe=577;break e}if((t[Le>>2]|0)==0&(t[Te>>2]|0)==0&(t[Ne>>2]|0)==0){qe=577;break e}else break}else{if(!((t[De>>2]|0)==1?(t[(t[_>>2]|0)+88>>2]|0)==33:0))break;if((t[Le>>2]|0)!=0|(t[Te>>2]|0)!=0|(t[Ne>>2]|0)!=0){qe=577;break e}else break}}while(0);if((t[E>>2]|0)!=0?(t[M>>2]=KD(t[(t[_>>2]|0)+88>>2]|0)|0,(t[M>>2]|0)!=0):0){if(!(t[N>>2]|0))t[N>>2]=(t[N>>2]|0)+1;t[(t[M>>2]|0)+8>>2]=t[Ne>>2];t[(t[M>>2]|0)+12>>2]=t[Te>>2];t[(t[M>>2]|0)+16>>2]=t[Le>>2];w=(t[M>>2]|0)+24|0;f[w>>1]=f[w>>1]&-2|t[De>>2]&1;w=(t[M>>2]|0)+24|0;f[w>>1]=f[w>>1]&-255;w=(t[M>>2]|0)+24|0;f[w>>1]=f[w>>1]&255|(t[N>>2]&255)<<8&65535;t[t[E>>2]>>2]=t[M>>2];qe=580}else qe=580}else qe=577}else qe=577}else qe=577;break}case 35:case 39:case 41:case 37:{t[Ce>>2]=t[p>>2];t[He>>2]=0;if(t[Ce>>2]|0){if((u[t[Ce>>2]>>0]|0)!=45){if((u[t[Ce>>2]>>0]|0)==43)t[Ce>>2]=(t[Ce>>2]|0)+1}else{t[He>>2]=1;t[Ce>>2]=(t[Ce>>2]|0)+1}t[N>>2]=rC(Ce,Pe,Be,Ie)|0;if((t[N>>2]|0)>=0?(u[t[Ce>>2]>>0]|0)==0:0){do if((t[(t[_>>2]|0)+88>>2]|0)==37){if((t[Ie>>2]|0)>>>0>=922){if((t[Ie>>2]|0)>>>0>922){qe=577;break e}if((t[Be>>2]|0)>>>0>=33720368){if((t[Be>>2]|0)>>>0>33720368){qe=577;break e}if((t[He>>2]|0)==0&(t[Pe>>2]|0)>>>0>54775807){qe=577;break e}if((t[He>>2]|0)==1&(t[Pe>>2]|0)>>>0>54775808){qe=577;break e}}}}else{if((t[(t[_>>2]|0)+88>>2]|0)==35){if(t[Ie>>2]|0){qe=577;break e}if((t[Be>>2]|0)>>>0<21)break;if((t[Be>>2]|0)>>>0>21){qe=577;break e}if((t[He>>2]|0)==0&(t[Pe>>2]|0)>>>0>47483647){qe=577;break e}if((t[He>>2]|0)==1&(t[Pe>>2]|0)>>>0>47483648){qe=577;break e}else break}if((t[(t[_>>2]|0)+88>>2]|0)==39){if((t[Be>>2]|0)!=0|(t[Ie>>2]|0)!=0){qe=577;break e}if((t[He>>2]|0)==1&(t[Pe>>2]|0)>>>0>32768){qe=577;break e}if((t[He>>2]|0)==0&(t[Pe>>2]|0)>>>0>32767){qe=577;break e}else break}if((t[(t[_>>2]|0)+88>>2]|0)==41){if((t[Be>>2]|0)!=0|(t[Ie>>2]|0)!=0){qe=577;break e}if((t[He>>2]|0)==1&(t[Pe>>2]|0)>>>0>128){qe=577;break e}if((t[He>>2]|0)==0&(t[Pe>>2]|0)>>>0>127){qe=577;break e}}}while(0);if((t[E>>2]|0)!=0?(t[M>>2]=KD(t[(t[_>>2]|0)+88>>2]|0)|0,(t[M>>2]|0)!=0):0){t[(t[M>>2]|0)+8>>2]=t[Pe>>2];t[(t[M>>2]|0)+12>>2]=t[Be>>2];t[(t[M>>2]|0)+16>>2]=t[Ie>>2];w=(t[M>>2]|0)+24|0;f[w>>1]=f[w>>1]&-2|t[He>>2]&1;w=(t[M>>2]|0)+24|0;f[w>>1]=f[w>>1]&-255;w=(t[M>>2]|0)+24|0;f[w>>1]=f[w>>1]&255|(t[N>>2]&255)<<8&65535;t[t[E>>2]>>2]=t[M>>2];qe=580}else qe=580}else qe=577}else qe=577;break}case 42:case 40:case 38:case 36:{t[xe>>2]=t[p>>2];if(((t[xe>>2]|0)!=0?(t[N>>2]=rC(xe,Ue,ze,je)|0,(t[N>>2]|0)>=0):0)?(u[t[xe>>2]>>0]|0)==0:0){do if((t[(t[_>>2]|0)+88>>2]|0)==38){if((t[je>>2]|0)>>>0>=1844){if((t[je>>2]|0)>>>0>1844){qe=577;break e}if((t[ze>>2]|0)>>>0>=67440737?(t[ze>>2]|0)>>>0>67440737|(t[Ue>>2]|0)>>>0>9551615:0){qe=577;break e}}}else{if((t[(t[_>>2]|0)+88>>2]|0)==36){if(t[je>>2]|0){qe=577;break e}if((t[ze>>2]|0)>>>0<42)break;if((t[ze>>2]|0)>>>0>42|(t[Ue>>2]|0)>>>0>94967295){qe=577;break e}else break}if((t[(t[_>>2]|0)+88>>2]|0)==40)if((t[ze>>2]|0)!=0|(t[je>>2]|0)!=0|(t[Ue>>2]|0)>>>0>65535){qe=577;break e}else break;if((t[(t[_>>2]|0)+88>>2]|0)==42?(t[ze>>2]|0)!=0|(t[je>>2]|0)!=0|(t[Ue>>2]|0)>>>0>255:0){qe=577;break e}}while(0);if((t[E>>2]|0)!=0?(t[M>>2]=KD(t[(t[_>>2]|0)+88>>2]|0)|0,(t[M>>2]|0)!=0):0){t[(t[M>>2]|0)+8>>2]=t[Ue>>2];t[(t[M>>2]|0)+12>>2]=t[ze>>2];t[(t[M>>2]|0)+16>>2]=t[je>>2];w=(t[M>>2]|0)+24|0;f[w>>1]=f[w>>1]&-2;w=(t[M>>2]|0)+24|0;f[w>>1]=f[w>>1]&-255;w=(t[M>>2]|0)+24|0;f[w>>1]=f[w>>1]&255|(t[N>>2]&255)<<8&65535;t[t[E>>2]>>2]=t[M>>2];qe=580}else qe=580}else qe=577;break}case 0:{qe=583;break}default:qe=571}while(0);if((qe|0)==571){if(t[R>>2]|0)pAi[t[135736>>2]&511](t[R>>2]|0);t[m>>2]=t[N>>2];Ve=t[m>>2]|0;s=d;return Ve|0}else if((qe|0)==577){if(t[R>>2]|0)pAi[t[135736>>2]&511](t[R>>2]|0);t[m>>2]=1;Ve=t[m>>2]|0;s=d;return Ve|0}else if((qe|0)==580){if(t[R>>2]|0)pAi[t[135736>>2]&511](t[R>>2]|0);t[m>>2]=0;Ve=t[m>>2]|0;s=d;return Ve|0}else if((qe|0)==583){if(t[R>>2]|0)pAi[t[135736>>2]&511](t[R>>2]|0);t[m>>2]=-1;Ve=t[m>>2]|0;s=d;return Ve|0}return 0}function ZD(e){e=e|0;var i=0,r=0,n=0,f=0,u=0,a=0;i=s;s=s+16|0;r=i+8|0;n=i+4|0;f=i;t[n>>2]=e;t[f>>2]=KD(t[t[n>>2]>>2]|0)|0;if(!(t[f>>2]|0)){t[r>>2]=0;u=t[r>>2]|0;s=i;return u|0}else{e=t[f>>2]|0;a=t[n>>2]|0;t[e+0>>2]=t[a+0>>2];t[e+4>>2]=t[a+4>>2];t[e+8>>2]=t[a+8>>2];t[e+12>>2]=t[a+12>>2];t[e+16>>2]=t[a+16>>2];t[e+20>>2]=t[a+20>>2];t[e+24>>2]=t[a+24>>2];t[e+28>>2]=t[a+28>>2];t[(t[f>>2]|0)+4>>2]=0;t[r>>2]=t[f>>2];u=t[r>>2]|0;s=i;return u|0}return 0}function JD(e,i,r,n,f,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;u=u|0;a=a|0;o=o|0;var c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0,S=0,g=0,y=0,F=0;c=s;s=s+64|0;l=c;b=c+56|0;k=c+52|0;h=c+48|0;w=c+44|0;d=c+40|0;v=c+36|0;m=c+32|0;_=c+28|0;p=c+24|0;E=c+20|0;S=c+16|0;g=c+12|0;y=c+8|0;t[k>>2]=e;t[h>>2]=i;t[w>>2]=r;t[d>>2]=n;t[v>>2]=f;t[m>>2]=u;t[_>>2]=a;t[p>>2]=o;e:do switch(t[k>>2]|0){case 11:case 10:case 9:case 8:case 7:case 6:case 5:case 4:{if((t[h>>2]|0)==0|(t[m>>2]|0)==0){t[b>>2]=-2;break e}if((t[v>>2]|0)==11|(t[v>>2]|0)==4|(t[v>>2]|0)==5|(t[v>>2]|0)==6|(t[v>>2]|0)==7|(t[v>>2]|0)==8|(t[v>>2]|0)==10|(t[v>>2]|0)==9){t[b>>2]=lC(t[h>>2]|0,t[m>>2]|0)|0;break e}else{t[b>>2]=-2;break e}break}case 12:{if((t[h>>2]|0)==0|(t[m>>2]|0)==0){t[b>>2]=-2;break e}if((t[v>>2]|0)==12){t[b>>2]=cC(t[h>>2]|0,t[m>>2]|0)|0;break e}else{t[b>>2]=-2;break e}break}case 28:case 21:{if((t[h>>2]|0)==0|(t[m>>2]|0)==0){t[b>>2]=-2;break e}if(!((t[v>>2]|0)==21|(t[v>>2]|0)==28)){t[b>>2]=-2;break e}if((Xl(t[(t[h>>2]|0)+8>>2]|0,t[(t[m>>2]|0)+8>>2]|0)|0)!=0?(Xl(t[(t[h>>2]|0)+12>>2]|0,t[(t[m>>2]|0)+12>>2]|0)|0)!=0:0){t[b>>2]=0;break e}t[b>>2]=2;break}case 3:case 42:case 41:case 40:case 39:case 38:case 37:case 36:case 35:case 34:case 33:case 32:case 31:case 30:{if((t[h>>2]|0)==0|(t[m>>2]|0)==0){t[b>>2]=-2;break e}if((t[v>>2]|0)==(t[k>>2]|0)){t[b>>2]=oC(t[h>>2]|0,t[m>>2]|0)|0;break e}if((t[v>>2]|0)==3|(t[v>>2]|0)==30|(t[v>>2]|0)==31|(t[v>>2]|0)==32|(t[v>>2]|0)==33|(t[v>>2]|0)==34|(t[v>>2]|0)==35|(t[v>>2]|0)==36|(t[v>>2]|0)==37|(t[v>>2]|0)==38|(t[v>>2]|0)==39|(t[v>>2]|0)==40|(t[v>>2]|0)==41|(t[v>>2]|0)==42){t[b>>2]=oC(t[h>>2]|0,t[m>>2]|0)|0;break e}else{t[b>>2]=-2;break e}break}case 14:case 13:{if((t[h>>2]|0)==0|(t[m>>2]|0)==0){t[b>>2]=-2;break e}if((t[v>>2]|0)==13|(t[v>>2]|0)==14){t[b>>2]=dC(t[h>>2]|0,t[m>>2]|0)|0;break e}else{t[b>>2]=-2;break e}break}case 44:{if((t[h>>2]|0)==0|(t[m>>2]|0)==0){t[b>>2]=-2;break e}if((t[v>>2]|0)!=44){t[b>>2]=-2;break e}o=(t[h>>2]|0)+8|0;if((t[(t[h>>2]|0)+12>>2]|0)!=(t[(t[m>>2]|0)+12>>2]|0))if((t[o+4>>2]|0)>>>0>(t[(t[m>>2]|0)+12>>2]|0)>>>0){t[b>>2]=1;break e}else{t[b>>2]=-1;break e}t[y>>2]=Kl(t[o>>2]|0,t[(t[m>>2]|0)+8>>2]|0)|0;if((t[y>>2]|0)>0){t[b>>2]=1;break e}if(!(t[y>>2]|0)){t[b>>2]=0;break e}else{t[b>>2]=-1;break e}break}case 29:case 26:case 24:case 23:case 22:case 20:case 18:case 17:case 16:case 2:case 1:case 46:{if(!(t[h>>2]|0))t[E>>2]=t[w>>2];else t[E>>2]=t[(t[h>>2]|0)+8>>2];if(!(t[m>>2]|0))t[S>>2]=t[_>>2];else t[S>>2]=t[(t[m>>2]|0)+8>>2];if((t[v>>2]|0)==21){o=t[33976]|0;a=t[33980]|0;t[l>>2]=171992;t[l+4>>2]=4781;yAi[o&511](a,171960,l);t[b>>2]=-2;break e}do if((t[v>>2]|0)==46|(t[v>>2]|0)==1|(t[v>>2]|0)==2|(t[v>>2]|0)==16|(t[v>>2]|0)==17|(t[v>>2]|0)==18|(t[v>>2]|0)==20|(t[v>>2]|0)==22|(t[v>>2]|0)==23|(t[v>>2]|0)==24|(t[v>>2]|0)==26|(t[v>>2]|0)==29){if((t[d>>2]|0)==1){if((t[p>>2]|0)==1)if(Xl(t[E>>2]|0,t[S>>2]|0)|0){t[b>>2]=0;break e}else{t[b>>2]=2;break e}if((t[p>>2]|0)==2){t[b>>2]=sC(t[E>>2]|0,t[S>>2]|0,0)|0;break e}if((t[p>>2]|0)!=3)break;t[b>>2]=bC(t[E>>2]|0,t[S>>2]|0,0)|0;break e}if((t[d>>2]|0)==2){if((t[p>>2]|0)==1){t[b>>2]=sC(t[S>>2]|0,t[E>>2]|0,1)|0;break e}if((t[p>>2]|0)==2){t[b>>2]=kC(t[E>>2]|0,t[S>>2]|0)|0;break e}if((t[p>>2]|0)!=3)break;t[b>>2]=hC(t[E>>2]|0,t[S>>2]|0,0)|0;break e}if((t[d>>2]|0)!=3){t[b>>2]=-2;break e}if((t[p>>2]|0)==1){t[b>>2]=bC(t[S>>2]|0,t[E>>2]|0,1)|0;break e}if((t[p>>2]|0)==2){t[b>>2]=hC(t[S>>2]|0,t[E>>2]|0,1)|0;break e}if((t[p>>2]|0)==3){t[b>>2]=wC(t[E>>2]|0,t[S>>2]|0)|0;break e}}while(0);t[b>>2]=-2;break}case 45:case 0:{t[b>>2]=-2;break}case 19:case 27:case 25:{a=t[33976]|0;o=t[33980]|0;t[l>>2]=171992;t[l+4>>2]=4906;yAi[a&511](o,171960,l);F=102;break}case 43:{if((t[h>>2]|0)==0|(t[m>>2]|0)==0){t[b>>2]=-2;break e}if((t[v>>2]|0)!=43){t[b>>2]=-2;break e}o=(t[h>>2]|0)+8|0;if((t[(t[h>>2]|0)+12>>2]|0)==(t[(t[m>>2]|0)+12>>2]|0)){t[g>>2]=Kl(t[o>>2]|0,t[(t[m>>2]|0)+8>>2]|0)|0;if((t[g>>2]|0)>0){t[b>>2]=1;break e}if(!(t[g>>2]|0)){t[b>>2]=0;break e}}else if((t[o+4>>2]|0)>>>0>(t[(t[m>>2]|0)+12>>2]|0)>>>0){t[b>>2]=1;break e}t[b>>2]=-1;break}case 15:{if((t[h>>2]|0)==0|(t[m>>2]|0)==0){t[b>>2]=-2;break e}if((t[v>>2]|0)!=15){t[b>>2]=-2;break e}if((t[(t[h>>2]|0)+8>>2]|0)==(t[(t[m>>2]|0)+8>>2]|0)){t[b>>2]=0;break e}if(!(t[(t[h>>2]|0)+8>>2]|0)){t[b>>2]=-1;break e}else{t[b>>2]=1;break e}break}default:F=102}while(0);if((F|0)==102)t[b>>2]=-2;s=c;return t[b>>2]|0}function QD(e,i,r,n,f,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;u=u|0;var o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0;o=s;s=s+48|0;c=o;l=o+40|0;b=o+36|0;k=o+32|0;h=o+28|0;w=o+24|0;d=o+20|0;v=o+16|0;m=o+12|0;_=o+8|0;t[b>>2]=e;t[k>>2]=i;t[h>>2]=r;t[w>>2]=n;t[d>>2]=f;t[v>>2]=u;e:do if(!(t[b>>2]|0))t[l>>2]=-1;else{i:do switch(t[t[b>>2]>>2]|0){case 1008:{t[l>>2]=0;break e;break}case 1006:{if(!(t[w>>2]|0)){t[l>>2]=-1;break e}t[m>>2]=eb(t[(t[b>>2]|0)+36>>2]|0,t[w>>2]|0)|0;if((t[m>>2]|0)==1){t[l>>2]=0;break e}if(!(t[m>>2]|0)){t[l>>2]=1839;break e}else{t[l>>2]=t[m>>2];break e}break}case 1007:{u=t[b>>2]|0;if(!(t[v>>2]|0)){if((t[u+8>>2]|0)!=0?(Xl(t[(t[b>>2]|0)+8>>2]|0,t[w>>2]|0)|0)!=0:0){t[l>>2]=0;break e}}else{t[m>>2]=vC(t[t[u+32>>2]>>2]|0,t[(t[b>>2]|0)+32>>2]|0,t[(t[b>>2]|0)+8>>2]|0,t[k>>2]|0,t[h>>2]|0,t[d>>2]|0,t[w>>2]|0,t[v>>2]|0)|0;if((t[m>>2]|0)==-2){t[l>>2]=-1;break e}if(!(t[m>>2]|0)){t[l>>2]=0;break e}}t[l>>2]=1840;break e;break}case 1011:case 1010:{p=43;break}case 1009:{if((t[h>>2]|0)==21|(t[h>>2]|0)==28){t[l>>2]=0;break e}else p=43;break}case 1005:case 1004:{do if(t[(t[b>>2]|0)+32>>2]|0){if((t[t[(t[b>>2]|0)+32>>2]>>2]|0)!=34?(t[t[(t[b>>2]|0)+32>>2]>>2]|0)!=33:0)break;if(!((a[(t[(t[b>>2]|0)+32>>2]|0)+24>>1]|0)>>>1&127)){r:do if(t[d>>2]|0){do if((((((((((t[t[d>>2]>>2]|0)!=3?(t[t[d>>2]>>2]|0)!=30:0)?(t[t[d>>2]>>2]|0)!=31:0)?(t[t[d>>2]>>2]|0)!=32:0)?(t[t[d>>2]>>2]|0)!=33:0)?(t[t[d>>2]>>2]|0)!=34:0)?(t[t[d>>2]>>2]|0)!=35:0)?(t[t[d>>2]>>2]|0)!=36:0)?(t[t[d>>2]>>2]|0)!=37:0)?(t[t[d>>2]>>2]|0)!=38:0){if((t[t[d>>2]>>2]|0)==39)break;if((t[t[d>>2]>>2]|0)==40)break;if((t[t[d>>2]>>2]|0)==41)break;if((t[t[d>>2]>>2]|0)!=42)break r}while(0);if((t[t[b>>2]>>2]|0)==1004){if(((a[(t[d>>2]|0)+24>>1]|0)>>>8&65535)>>>0<=(t[(t[(t[b>>2]|0)+32>>2]|0)+8>>2]|0)>>>0)break i;t[l>>2]=1837;break e}if((t[t[b>>2]>>2]|0)!=1005)break i;if(((a[(t[d>>2]|0)+24>>1]|0)>>>1&127)>>>0<=(t[(t[(t[b>>2]|0)+32>>2]|0)+8>>2]|0)>>>0)break i;t[l>>2]=1838;break e}while(0);t[l>>2]=-1;break e}}while(0);t[l>>2]=-1;break e;break}case 1e3:{t[m>>2]=BD(t[d>>2]|0,t[(t[b>>2]|0)+32>>2]|0)|0;if((t[m>>2]|0)==-2){t[l>>2]=-1;break e}if((t[m>>2]|0)==1|(t[m>>2]|0)==0){t[l>>2]=0;break e}else{t[l>>2]=1833;break e}break}case 1002:{t[m>>2]=BD(t[d>>2]|0,t[(t[b>>2]|0)+32>>2]|0)|0;if((t[m>>2]|0)==-2){t[l>>2]=-1;break e}if((t[m>>2]|0)==-1|(t[m>>2]|0)==0){t[l>>2]=0;break e}else{t[l>>2]=1834;break e}break}case 1001:{t[m>>2]=BD(t[d>>2]|0,t[(t[b>>2]|0)+32>>2]|0)|0;if((t[m>>2]|0)==-2){t[l>>2]=-1;break e}if((t[m>>2]|0)==1){t[l>>2]=0;break e}else{t[l>>2]=1835;break e}break}case 1003:{t[m>>2]=BD(t[d>>2]|0,t[(t[b>>2]|0)+32>>2]|0)|0;if((t[m>>2]|0)==-2){t[l>>2]=-1;break e}if((t[m>>2]|0)==-1){t[l>>2]=0;break e}else{t[l>>2]=1836;break e}break}default:{u=t[33976]|0;f=t[33980]|0;t[c>>2]=171992;t[c+4>>2]=5498;yAi[u&511](f,171960,c)}}while(0);i:do if((p|0)==43){t[_>>2]=0;if((t[h>>2]|0)==21|(t[h>>2]|0)==28){t[l>>2]=0;break e}do if(t[(t[b>>2]|0)+32>>2]|0){if((t[t[(t[b>>2]|0)+32>>2]>>2]|0)!=3?(t[t[(t[b>>2]|0)+32>>2]>>2]|0)!=33:0)break;if(!((a[(t[(t[b>>2]|0)+32>>2]|0)+24>>1]|0)>>>1&127)){if((t[d>>2]|0)!=0?(t[t[d>>2]>>2]|0)==43:0)t[_>>2]=t[(t[d>>2]|0)+12>>2];else p=53;r:do if((p|0)==53){if((t[d>>2]|0)!=0?(t[t[d>>2]>>2]|0)==44:0){t[_>>2]=t[(t[d>>2]|0)+12>>2];break}switch(t[h>>2]|0){case 29:case 23:case 22:case 20:case 18:case 17:case 16:case 24:{if(!(t[w>>2]|0))break r;t[_>>2]=mC(t[w>>2]|0)|0;break r;break}case 2:case 1:{if(!(t[v>>2]|0)){f=t[w>>2]|0;if((t[h>>2]|0)==1){t[_>>2]=os(f)|0;break r}else{t[_>>2]=mC(f)|0;break r}}if(!(t[w>>2]|0))break r;f=t[w>>2]|0;if((t[v>>2]|0)==3){t[_>>2]=mC(f)|0;break r}else{t[_>>2]=os(f)|0;break r}break}default:{f=t[33976]|0;u=t[33980]|0;t[c>>2]=171992;t[c+4>>2]=5447;yAi[f&511](u,171960,c);break r}}}while(0);if((t[t[b>>2]>>2]|0)==1009){if((t[_>>2]|0)==(t[(t[(t[b>>2]|0)+32>>2]|0)+8>>2]|0))break i;t[l>>2]=1830;break e}u=t[_>>2]|0;f=t[(t[(t[b>>2]|0)+32>>2]|0)+8>>2]|0;if((t[t[b>>2]>>2]|0)==1011){if(u>>>0>=f>>>0)break i;t[l>>2]=1831;break e}else{if(u>>>0<=f>>>0)break i;t[l>>2]=1832;break e}}}while(0);t[l>>2]=-1;break e}while(0);t[l>>2]=0}while(0);s=o;return t[l>>2]|0}function $D(e,i,r,n,f,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;u=u|0;var o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0;o=s;s=s+48|0;c=o;l=o+36|0;b=o+32|0;k=o+28|0;h=o+24|0;w=o+20|0;d=o+16|0;v=o+12|0;m=o+8|0;t[b>>2]=e;t[k>>2]=i;t[h>>2]=r;t[w>>2]=n;t[d>>2]=f;t[v>>2]=u;t[m>>2]=0;if((t[d>>2]|0)==0|(t[b>>2]|0)==0){t[l>>2]=-1;_=t[l>>2]|0;s=o;return _|0}t[t[d>>2]>>2]=0;if(((t[t[b>>2]>>2]|0)!=1009?(t[t[b>>2]>>2]|0)!=1010:0)?(t[t[b>>2]>>2]|0)!=1011:0){t[l>>2]=-1;_=t[l>>2]|0;s=o;return _|0}do if(t[(t[b>>2]|0)+32>>2]|0){if((t[t[(t[b>>2]|0)+32>>2]>>2]|0)!=3?(t[t[(t[b>>2]|0)+32>>2]>>2]|0)!=33:0)break;if(!((a[(t[(t[b>>2]|0)+32>>2]|0)+24>>1]|0)>>>1&127)){if((t[w>>2]|0)!=0?(t[t[w>>2]>>2]|0)==43:0)t[m>>2]=t[(t[w>>2]|0)+12>>2];else p=15;e:do if((p|0)==15){if((t[w>>2]|0)!=0?(t[t[w>>2]>>2]|0)==44:0){t[m>>2]=t[(t[w>>2]|0)+12>>2];break}switch(t[k>>2]|0){case 28:case 21:{t[l>>2]=0;_=t[l>>2]|0;s=o;return _|0}case 29:case 23:case 22:case 20:case 18:case 17:case 16:case 24:{if(!(t[h>>2]|0))break e;t[m>>2]=mC(t[h>>2]|0)|0;break e;break}case 2:case 1:{if(!(t[v>>2]|0)){u=t[h>>2]|0;if((t[k>>2]|0)==1){t[m>>2]=os(u)|0;break e}else{t[m>>2]=mC(u)|0;break e}}if(!(t[h>>2]|0))break e;u=t[h>>2]|0;if((t[v>>2]|0)==3){t[m>>2]=mC(u)|0;break e}else{t[m>>2]=os(u)|0;break e}break}default:{u=t[33976]|0;f=t[33980]|0;t[c>>2]=171992;t[c+4>>2]=5207;yAi[u&511](f,171960,c);break e}}}while(0);t[t[d>>2]>>2]=t[m>>2];do if((t[t[b>>2]>>2]|0)==1009){if((t[m>>2]|0)!=(t[(t[(t[b>>2]|0)+32>>2]|0)+8>>2]|0)){t[l>>2]=1830;_=t[l>>2]|0;s=o;return _|0}}else{f=t[m>>2]|0;u=t[(t[(t[b>>2]|0)+32>>2]|0)+8>>2]|0;if((t[t[b>>2]>>2]|0)==1011){if(f>>>0>=u>>>0)break;t[l>>2]=1831;_=t[l>>2]|0;s=o;return _|0}else{if(f>>>0<=u>>>0)break;t[l>>2]=1832;_=t[l>>2]|0;s=o;return _|0}}while(0);t[l>>2]=0;_=t[l>>2]|0;s=o;return _|0}}while(0);t[l>>2]=-1;_=t[l>>2]|0;s=o;return _|0}function eC(e,i){e=e|0;i=+i;var r=0,n=0,u=0,a=0,o=0,c=0,b=0,k=0;r=s;s=s+32|0;n=r+20|0;u=r+16|0;a=r;o=r+12|0;c=r+8|0;t[u>>2]=e;l[a>>3]=i;if(!(t[u>>2]|0)){t[n>>2]=0;b=t[n>>2]|0;s=r;return b|0}if(!(((t[t[u>>2]>>2]|0)!=4?(t[t[u>>2]>>2]|0)!=11:0)?(t[t[u>>2]>>2]|0)!=10:0))k=6;if((k|0)==6?((f[(t[u>>2]|0)+24>>1]<<3&65535)<<16>>16>>4<<16>>16|0)!=0:0){t[o>>2]=KD(12)|0;if(!(t[o>>2]|0)){t[n>>2]=0;b=t[n>>2]|0;s=r;return b|0}k=(t[o>>2]|0)+16|0;l[k>>3]=+l[k>>3]-+l[a>>3];t[c>>2]=_C(t[u>>2]|0,t[o>>2]|0)|0;if(!(t[c>>2]|0)){t[n>>2]=0;b=t[n>>2]|0;s=r;return b|0}else{MD(t[o>>2]|0);t[n>>2]=t[c>>2];b=t[n>>2]|0;s=r;return b|0}}t[n>>2]=ZD(t[u>>2]|0)|0;b=t[n>>2]|0;s=r;return b|0}function iC(e){e=e|0;var i=0,r=0,n=0,f=0,u=0;i=s;s=s+16|0;r=i+8|0;n=i+4|0;f=i;t[n>>2]=e;t[f>>2]=gk()|0;if(!(t[f>>2]|0)){t[r>>2]=0;u=t[r>>2]|0;s=i;return u|0}t[t[f>>2]>>2]=1011;e=KD(33)|0;t[(t[f>>2]|0)+32>>2]=e;if(!(t[(t[f>>2]|0)+32>>2]|0)){pAi[t[135736>>2]&511](t[f>>2]|0);t[r>>2]=0;u=t[r>>2]|0;s=i;return u|0}else{t[(t[(t[f>>2]|0)+32>>2]|0)+8>>2]=t[n>>2];t[r>>2]=t[f>>2];u=t[r>>2]|0;s=i;return u|0}return 0}function rC(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0,S=0,g=0;f=s;s=s+48|0;a=f+44|0;o=f+40|0;c=f+36|0;l=f+32|0;b=f+28|0;k=f+24|0;h=f+20|0;w=f+16|0;d=f+12|0;v=f+8|0;m=f+4|0;_=f;t[o>>2]=e;t[c>>2]=i;t[l>>2]=r;t[b>>2]=n;t[k>>2]=0;t[h>>2]=0;t[w>>2]=0;t[v>>2]=t[t[o>>2]>>2];t[m>>2]=0;t[_>>2]=0;if((u[t[v>>2]>>0]|0|0)>=48?(u[t[v>>2]>>0]|0|0)<=57:0){while(1){p=t[v>>2]|0;if((u[t[v>>2]>>0]|0|0)!=48)break;t[v>>2]=p+1}t[d>>2]=p;while(1){if((u[t[d>>2]>>0]|0|0)!=0?(u[t[d>>2]>>0]|0|0)>=48:0)E=(u[t[d>>2]>>0]|0|0)<=57;else E=0;S=t[_>>2]|0;if(!E)break;t[_>>2]=S+1;t[d>>2]=(t[d>>2]|0)+1;t[m>>2]=(t[m>>2]|0)+1}if((S|0)>24){t[t[o>>2]>>2]=t[d>>2];t[a>>2]=-1;g=t[a>>2]|0;s=f;return g|0}while(1){if((t[_>>2]|0)<=16)break;d=(t[w>>2]|0)*10|0;S=t[v>>2]|0;t[v>>2]=S+1;t[w>>2]=d+((u[S>>0]|0)-48);t[_>>2]=(t[_>>2]|0)+-1}while(1){if((t[_>>2]|0)<=8)break;S=(t[h>>2]|0)*10|0;d=t[v>>2]|0;t[v>>2]=d+1;t[h>>2]=S+((u[d>>0]|0)-48);t[_>>2]=(t[_>>2]|0)+-1}while(1){if((t[_>>2]|0)<=0)break;d=(t[k>>2]|0)*10|0;S=t[v>>2]|0;t[v>>2]=S+1;t[k>>2]=d+((u[S>>0]|0)-48);t[_>>2]=(t[_>>2]|0)+-1}t[t[o>>2]>>2]=t[v>>2];t[t[c>>2]>>2]=t[k>>2];t[t[l>>2]>>2]=t[h>>2];t[t[b>>2]>>2]=t[w>>2];t[a>>2]=t[m>>2];g=t[a>>2]|0;s=f;return g|0}t[a>>2]=-2;g=t[a>>2]|0;s=f;return g|0}function nC(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var a=0,o=0,c=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0;a=s;s=s+48|0;o=a+32|0;c=a+28|0;b=a+24|0;k=a+20|0;h=a+16|0;w=a+12|0;d=a+8|0;v=a+4|0;m=a;t[c>>2]=e;t[b>>2]=i;t[k>>2]=r;t[h>>2]=n;t[v>>2]=t[b>>2];if(!(t[b>>2]|0)){t[o>>2]=-1;_=t[o>>2]|0;s=a;return _|0}e:do if(t[h>>2]|0)while(1){do if((u[t[v>>2]>>0]|0|0)!=32){if(9<=(u[t[v>>2]>>0]|0|0)?(u[t[v>>2]>>0]|0|0)<=10:0)break;if((u[t[v>>2]>>0]|0|0)!=13)break e}while(0);t[v>>2]=(t[v>>2]|0)+1}while(0);if(((u[t[v>>2]>>0]|0|0)!=45?(u[t[v>>2]>>0]|0|0)<48:0)?(u[t[v>>2]>>0]|0|0)>57:0){t[o>>2]=1;_=t[o>>2]|0;s=a;return _|0}t[w>>2]=KD(0)|0;if(!(t[w>>2]|0)){t[o>>2]=-1;_=t[o>>2]|0;s=a;return _|0}e:do if((u[t[v>>2]>>0]|0|0)==45?(u[(t[v>>2]|0)+1>>0]|0|0)==45:0){t[v>>2]=(t[v>>2]|0)+2;if((u[t[v>>2]>>0]|0|0)==45){if((t[c>>2]|0)==6)break;t[v>>2]=(t[v>>2]|0)+1;t[d>>2]=pC((t[w>>2]|0)+8|0,v)|0;if(t[d>>2]|0)break;if((((u[t[v>>2]>>0]|0|0)!=0?(u[t[v>>2]>>0]|0|0)!=90:0)?(u[t[v>>2]>>0]|0|0)!=43:0)?(u[t[v>>2]>>0]|0|0)!=45:0)break;t[d>>2]=EC((t[w>>2]|0)+8|0,v)|0;if(t[d>>2]|0)break;if(u[t[v>>2]>>0]|0)break;t[t[w>>2]>>2]=5;p=123;break}t[d>>2]=SC((t[w>>2]|0)+8|0,v)|0;if(!(t[d>>2]|0)){if((u[t[v>>2]>>0]|0|0)==45){t[m>>2]=t[v>>2];t[v>>2]=(t[v>>2]|0)+1;t[d>>2]=pC((t[w>>2]|0)+8|0,v)|0;do if(!(t[d>>2]|0)){if((u[t[v>>2]>>0]|0|0)!=0?(u[t[v>>2]>>0]|0|0)==58:0)break;if(((t[(t[w>>2]|0)+8>>2]|0)%4|0|0)==0?((t[(t[w>>2]|0)+8>>2]|0)%100|0|0)!=0:0)p=35;else if((t[(t[w>>2]|0)+8>>2]|0)%400|0){if(((t[(t[w>>2]|0)+12>>2]|0)>>>4&31)>>>0>(t[171912+((t[(t[w>>2]|0)+12>>2]&15)-1<<2)>>2]|0)>>>0)break}else p=35;if((p|0)==35?((t[(t[w>>2]|0)+12>>2]|0)>>>4&31)>>>0>(t[171864+((t[(t[w>>2]|0)+12>>2]&15)-1<<2)>>2]|0)>>>0:0)break;if((((u[t[v>>2]>>0]|0|0)!=0?(u[t[v>>2]>>0]|0|0)!=90:0)?(u[t[v>>2]>>0]|0|0)!=43:0)?(u[t[v>>2]>>0]|0|0)!=45:0)break e;t[d>>2]=EC((t[w>>2]|0)+8|0,v)|0;if(t[d>>2]|0)break e;if(u[t[v>>2]>>0]|0)break e;t[t[w>>2]>>2]=7;p=123;break e}while(0);t[v>>2]=t[m>>2]}if((((u[t[v>>2]>>0]|0|0)!=0?(u[t[v>>2]>>0]|0|0)!=90:0)?(u[t[v>>2]>>0]|0|0)!=43:0)?(u[t[v>>2]>>0]|0|0)!=45:0)break;t[d>>2]=EC((t[w>>2]|0)+8|0,v)|0;if((t[d>>2]|0)==0?(u[t[v>>2]>>0]|0|0)==0:0){t[t[w>>2]>>2]=6;p=123}}}else p=52;while(0);e:do if((p|0)==52){do if(((u[t[v>>2]>>0]|0|0)>=48?(u[t[v>>2]>>0]|0|0)<=57:0)?(t[d>>2]=gC((t[w>>2]|0)+8|0,v)|0,(t[d>>2]|0)==0):0){if((((u[t[v>>2]>>0]|0|0)!=0?(u[t[v>>2]>>0]|0|0)!=90:0)?(u[t[v>>2]>>0]|0|0)!=43:0)?(u[t[v>>2]>>0]|0|0)!=45:0)break;t[d>>2]=EC((t[w>>2]|0)+8|0,v)|0;if(!(t[d>>2]|0)){if(u[t[v>>2]>>0]|0)break e;t[t[w>>2]>>2]=4;p=123;break e}}while(0);t[v>>2]=t[b>>2];t[d>>2]=yC((t[w>>2]|0)+8|0,v)|0;if(!(t[d>>2]|0)){if(!((((u[t[v>>2]>>0]|0|0)!=0?(u[t[v>>2]>>0]|0|0)!=90:0)?(u[t[v>>2]>>0]|0|0)!=43:0)?(u[t[v>>2]>>0]|0|0)!=45:0))p=67;if((p|0)==67?(t[d>>2]=EC((t[w>>2]|0)+8|0,v)|0,(t[d>>2]|0)==0):0){if(u[t[v>>2]>>0]|0)break;t[t[w>>2]>>2]=8;p=123;break}if((u[t[v>>2]>>0]|0|0)==45?(t[v>>2]=(t[v>>2]|0)+1,t[d>>2]=SC((t[w>>2]|0)+8|0,v)|0,(t[d>>2]|0)==0):0){if(!((((u[t[v>>2]>>0]|0|0)!=0?(u[t[v>>2]>>0]|0|0)!=90:0)?(u[t[v>>2]>>0]|0|0)!=43:0)?(u[t[v>>2]>>0]|0|0)!=45:0))p=76;if((p|0)==76?(t[d>>2]=EC((t[w>>2]|0)+8|0,v)|0,(t[d>>2]|0)==0):0){if(u[t[v>>2]>>0]|0)break;t[t[w>>2]>>2]=9;p=123;break}if(((((u[t[v>>2]>>0]|0|0)==45?(t[v>>2]=(t[v>>2]|0)+1,t[d>>2]=pC((t[w>>2]|0)+8|0,v)|0,(t[d>>2]|0)==0):0)?(t[(t[w>>2]|0)+8>>2]|0)!=0:0)?(t[(t[w>>2]|0)+12>>2]&15|0)>=1:0)?(t[(t[w>>2]|0)+12>>2]&15|0)<=12:0){if(((t[(t[w>>2]|0)+8>>2]|0)%4|0|0)==0?((t[(t[w>>2]|0)+8>>2]|0)%100|0|0)!=0:0)p=87;else if((t[(t[w>>2]|0)+8>>2]|0)%400|0){if(((t[(t[w>>2]|0)+12>>2]|0)>>>4&31)>>>0>(t[171912+((t[(t[w>>2]|0)+12>>2]&15)-1<<2)>>2]|0)>>>0)break}else p=87;if((p|0)==87?((t[(t[w>>2]|0)+12>>2]|0)>>>4&31)>>>0>(t[171864+((t[(t[w>>2]|0)+12>>2]&15)-1<<2)>>2]|0)>>>0:0)break;do if(u[t[v>>2]>>0]|0){if((u[t[v>>2]>>0]|0|0)==90){p=93;break}if((u[t[v>>2]>>0]|0|0)==43){p=93;break}if((u[t[v>>2]>>0]|0|0)==45)p=93}else p=93;while(0);do if((p|0)==93){t[d>>2]=EC((t[w>>2]|0)+8|0,v)|0;if(t[d>>2]|0)break;if(u[t[v>>2]>>0]|0)break e;t[t[w>>2]>>2]=10;p=123;break e}while(0);if((u[t[v>>2]>>0]|0|0)==84){t[v>>2]=(t[v>>2]|0)+1;t[d>>2]=gC((t[w>>2]|0)+8|0,v)|0;if(t[d>>2]|0)break;t[d>>2]=EC((t[w>>2]|0)+8|0,v)|0;i:do if(t[h>>2]|0)while(1){do if((u[t[v>>2]>>0]|0|0)!=32){if(9<=(u[t[v>>2]>>0]|0|0)?(u[t[v>>2]>>0]|0|0)<=10:0)break;if((u[t[v>>2]>>0]|0|0)!=13)break i}while(0);t[v>>2]=(t[v>>2]|0)+1}while(0);if(t[d>>2]|0)break;if(u[t[v>>2]>>0]|0)break;if(!(t[(t[w>>2]|0)+8>>2]|0))break;if((t[(t[w>>2]|0)+12>>2]&15|0)<1)break;if((t[(t[w>>2]|0)+12>>2]&15|0)>12)break;if(((t[(t[w>>2]|0)+8>>2]|0)%4|0|0)==0?((t[(t[w>>2]|0)+8>>2]|0)%100|0|0)!=0:0)p=112;else p=111;do if((p|0)==111){if(!((t[(t[w>>2]|0)+8>>2]|0)%400|0)){p=112;break}if(((t[(t[w>>2]|0)+12>>2]|0)>>>4&31)>>>0>(t[171912+((t[(t[w>>2]|0)+12>>2]&15)-1<<2)>>2]|0)>>>0)break e}while(0);if((p|0)==112?((t[(t[w>>2]|0)+12>>2]|0)>>>4&31)>>>0>(t[171864+((t[(t[w>>2]|0)+12>>2]&15)-1<<2)>>2]|0)>>>0:0)break;if(((t[(t[w>>2]|0)+12>>2]|0)>>>9&31|0)<0)break;if(((t[(t[w>>2]|0)+12>>2]|0)>>>9&31|0)>23)break;if(((t[(t[w>>2]|0)+12>>2]|0)>>>14&63|0)<0)break;if(((t[(t[w>>2]|0)+12>>2]|0)>>>14&63|0)>59)break;if(!(+l[(t[w>>2]|0)+16>>3]>=0))break;if(!(+l[(t[w>>2]|0)+16>>3]<60))break;if(((f[(t[w>>2]|0)+24>>1]<<3&65535)<<16>>16>>4<<16>>16|0)<=-840)break;if(((f[(t[w>>2]|0)+24>>1]<<3&65535)<<16>>16>>4<<16>>16|0)>=840)break;t[t[w>>2]>>2]=11;p=123}}}}}while(0);do if((p|0)==123){if((t[c>>2]|0)!=0?(t[c>>2]|0)!=(t[t[w>>2]>>2]|0):0)break;v=t[w>>2]|0;if(t[k>>2]|0)t[t[k>>2]>>2]=v;else MD(v);t[o>>2]=0;_=t[o>>2]|0;s=a;return _|0}while(0);if(t[w>>2]|0)MD(t[w>>2]|0);t[o>>2]=1;_=t[o>>2]|0;s=a;return _|0}function fC(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,a=0,o=0,c=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0;f=s;s=s+64|0;a=f+52|0;o=f+44|0;c=f+40|0;b=f+36|0;k=f+32|0;h=f+28|0;w=f+24|0;d=f+20|0;v=f+8|0;m=f+16|0;_=f;t[f+48>>2]=e;t[o>>2]=i;t[c>>2]=r;t[b>>2]=n;t[k>>2]=t[o>>2];t[w>>2]=0;t[d>>2]=0;t[m>>2]=0;if(!(t[o>>2]|0)){t[a>>2]=-1;p=t[a>>2]|0;s=f;return p|0}e:do if(t[b>>2]|0)while(1){do if((u[t[k>>2]>>0]|0|0)!=32){if(9<=(u[t[k>>2]>>0]|0|0)?(u[t[k>>2]>>0]|0|0)<=10:0)break;if((u[t[k>>2]>>0]|0|0)!=13)break e}while(0);t[k>>2]=(t[k>>2]|0)+1}while(0);if((u[t[k>>2]>>0]|0|0)==45){t[w>>2]=1;t[k>>2]=(t[k>>2]|0)+1}o=t[k>>2]|0;t[k>>2]=o+1;if((u[o>>0]|0|0)!=80){t[a>>2]=1;p=t[a>>2]|0;s=f;return p|0}if(!(u[t[k>>2]>>0]|0)){t[a>>2]=1;p=t[a>>2]|0;s=f;return p|0}t[h>>2]=KD(12)|0;if(!(t[h>>2]|0)){t[a>>2]=-1;p=t[a>>2]|0;s=f;return p|0}e:while(1){if(!(u[t[k>>2]>>0]|0)){E=55;break}if((t[d>>2]|0)>>>0>=6){E=61;break}o=t[d>>2]|0;if((u[t[k>>2]>>0]|0|0)!=84){if((o|0)==3){E=61;break}}else{if(o>>>0>3){E=22;break}t[d>>2]=3;t[k>>2]=(t[k>>2]|0)+1}l[v>>3]=0;i:do if((u[t[k>>2]>>0]|0|0)>=48?(u[t[k>>2]>>0]|0|0)<=57:0)while(1){if((u[t[k>>2]>>0]|0|0)<48)break i;if((u[t[k>>2]>>0]|0|0)>57)break i;l[v>>3]=+l[v>>3]*10+ +((u[t[k>>2]>>0]|0)-48|0);t[k>>2]=(t[k>>2]|0)+1}else E=26;while(0);if((E|0)==26){E=0;t[m>>2]=-1}i:do if((t[m>>2]|0)==0?(u[t[k>>2]>>0]|0|0)==46:0){l[_>>3]=1;t[k>>2]=(t[k>>2]|0)+1;if((u[t[k>>2]>>0]|0|0)>=48?(u[t[k>>2]>>0]|0|0)<=57:0)t[m>>2]=1;else t[m>>2]=-1;while(1){if((u[t[k>>2]>>0]|0|0)<48)break i;if((u[t[k>>2]>>0]|0|0)>57)break i;l[_>>3]=+l[_>>3]/10;l[v>>3]=+l[v>>3]+ +((u[t[k>>2]>>0]|0)-48|0)*+l[_>>3];t[k>>2]=(t[k>>2]|0)+1}}while(0);if((t[m>>2]|0)==-1){E=61;break}if(!(u[t[k>>2]>>0]|0)){E=61;break}while(1){if((t[d>>2]|0)>>>0>=6)break;if((u[t[k>>2]>>0]|0|0)==(u[172280+(t[d>>2]|0)>>0]|0|0)){E=43;break}o=(t[d>>2]|0)+1|0;t[d>>2]=o;if((o|0)==3|(t[d>>2]|0)==6){E=61;break e}}do if((E|0)==43){E=0;if((t[m>>2]|0)!=0&(t[d>>2]|0)>>>0<5){E=61;break e}o=t[d>>2]|0;if((o|0)==1){n=(t[h>>2]|0)+8|0;t[n>>2]=(t[n>>2]|0)+~~+l[v>>3];break}else if(!o){t[(t[h>>2]|0)+8>>2]=~~+l[v>>3]*12;break}else{o=(t[h>>2]|0)+16|0;l[o>>3]=+l[o>>3]+ +l[v>>3]*+l[172288+(t[d>>2]<<3)>>3];t[d>>2]=(t[d>>2]|0)+1;break}}while(0);t[k>>2]=(t[k>>2]|0)+1;if(!(t[b>>2]|0))continue;while(1){do if((u[t[k>>2]>>0]|0|0)!=32){if(9<=(u[t[k>>2]>>0]|0|0)?(u[t[k>>2]>>0]|0|0)<=10:0)break;if((u[t[k>>2]>>0]|0|0)!=13)continue e}while(0);t[k>>2]=(t[k>>2]|0)+1}}if((E|0)==22){t[a>>2]=1;p=t[a>>2]|0;s=f;return p|0}else if((E|0)==55){if(t[w>>2]|0){t[(t[h>>2]|0)+8>>2]=0-(t[(t[h>>2]|0)+8>>2]|0);t[(t[h>>2]|0)+12>>2]=0-(t[(t[h>>2]|0)+12>>2]|0);l[(t[h>>2]|0)+16>>3]=-+l[(t[h>>2]|0)+16>>3]}w=t[h>>2]|0;if(t[c>>2]|0)t[t[c>>2]>>2]=w;else MD(w);t[a>>2]=0;p=t[a>>2]|0;s=f;return p|0}else if((E|0)==61){if(t[h>>2]|0)MD(t[h>>2]|0);t[a>>2]=1;p=t[a>>2]|0;s=f;return p|0}return 0}function tC(e,i,r,f){e=e|0;i=i|0;r=r|0;f=f|0;var a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0;a=s;s=s+48|0;o=a+36|0;c=a+32|0;l=a+28|0;b=a+24|0;k=a+20|0;h=a+16|0;w=a+12|0;d=a+8|0;v=a+4|0;m=a;t[c>>2]=e;t[l>>2]=i;t[b>>2]=r;t[k>>2]=f;t[v>>2]=0;t[m>>2]=0;if(!(t[l>>2]|0)){t[o>>2]=-1;_=t[o>>2]|0;s=a;return _|0}t[h>>2]=Yl(t[l>>2]|0)|0;if(!(t[h>>2]|0)){t[o>>2]=-1;_=t[o>>2]|0;s=a;return _|0}if(t[b>>2]|0)t[t[b>>2]>>2]=0;t[w>>2]=t[h>>2];e:while(1){do if((u[t[w>>2]>>0]|0|0)!=32){if(9<=(u[t[w>>2]>>0]|0|0)?(u[t[w>>2]>>0]|0|0)<=10:0)break;if((u[t[w>>2]>>0]|0|0)!=13)break e}while(0);b=t[w>>2]|0;t[w>>2]=b+1;n[b>>0]=0}e:while(1){if(!(u[t[w>>2]>>0]|0))break;do if((u[t[w>>2]>>0]|0|0)!=32){
	if(9<=(u[t[w>>2]>>0]|0|0)?(u[t[w>>2]>>0]|0|0)<=10:0)break;if((u[t[w>>2]>>0]|0|0)!=13){t[v>>2]=(t[v>>2]|0)+1;t[w>>2]=(t[w>>2]|0)+1;while(1){if(!(u[t[w>>2]>>0]|0))continue e;do if((u[t[w>>2]>>0]|0|0)==32)p=1;else{if(9<=(u[t[w>>2]>>0]|0|0)?(u[t[w>>2]>>0]|0|0)<=10:0){p=1;break}p=(u[t[w>>2]>>0]|0|0)==13}while(0);if(!(p^1))continue e;t[w>>2]=(t[w>>2]|0)+1}}}while(0);n[t[w>>2]>>0]=0;t[w>>2]=(t[w>>2]|0)+1;while(1){do if((u[t[w>>2]>>0]|0|0)!=32){if(9<=(u[t[w>>2]>>0]|0|0)?(u[t[w>>2]>>0]|0|0)<=10:0)break;if((u[t[w>>2]>>0]|0|0)!=13)continue e}while(0);b=t[w>>2]|0;t[w>>2]=b+1;n[b>>0]=0}}if(!(t[v>>2]|0)){pAi[t[135736>>2]&511](t[h>>2]|0);t[o>>2]=t[v>>2];_=t[o>>2]|0;s=a;return _|0}t[d>>2]=t[w>>2];t[w>>2]=t[h>>2];while(1){if(u[t[w>>2]>>0]|0)break;if((t[w>>2]|0)==(t[d>>2]|0))break;t[w>>2]=(t[w>>2]|0)+1}e:while(1){if((t[w>>2]|0)==(t[d>>2]|0))break;t[m>>2]=LD(t[c>>2]|0,t[w>>2]|0,0,t[k>>2]|0)|0;if(t[m>>2]|0)break;while(1){if(!(u[t[w>>2]>>0]|0))break;t[w>>2]=(t[w>>2]|0)+1}while(1){if(u[t[w>>2]>>0]|0)continue e;if((t[w>>2]|0)==(t[d>>2]|0))continue e;t[w>>2]=(t[w>>2]|0)+1}}pAi[t[135736>>2]&511](t[h>>2]|0);if(!(t[m>>2]|0)){t[o>>2]=t[v>>2];_=t[o>>2]|0;s=a;return _|0}else{t[o>>2]=-1;_=t[o>>2]|0;s=a;return _|0}return 0}function uC(e){e=e|0;var i=0,r=0,n=0,f=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0;i=s;s=s+32|0;r=i+16|0;n=i+12|0;f=i+8|0;a=i+4|0;o=i;t[n>>2]=e;t[f>>2]=t[n>>2];if(!(t[n>>2]|0)){t[r>>2]=0;c=t[r>>2]|0;s=i;return c|0}while(1){do if(u[t[f>>2]>>0]|0)if((u[t[f>>2]>>0]|0|0)==32)l=1;else{if(9<=(u[t[f>>2]>>0]|0|0)?(u[t[f>>2]>>0]|0|0)<=10:0){l=1;break}l=(u[t[f>>2]>>0]|0|0)==13}else l=0;while(0);b=t[f>>2]|0;if(!l)break;t[f>>2]=b+1}t[a>>2]=b;while(1){k=t[a>>2]|0;if(!(u[t[a>>2]>>0]|0))break;t[a>>2]=k+1}t[o>>2]=k;t[a>>2]=(t[a>>2]|0)+-1;while(1){do if((t[a>>2]|0)>>>0>(t[f>>2]|0)>>>0)if((u[t[a>>2]>>0]|0|0)==32)h=1;else{if(9<=(u[t[a>>2]>>0]|0|0)?(u[t[a>>2]>>0]|0|0)<=10:0){h=1;break}h=(u[t[a>>2]>>0]|0|0)==13}else h=0;while(0);w=t[a>>2]|0;if(!h)break;t[a>>2]=w+-1}t[a>>2]=w+1;if((t[f>>2]|0)==(t[n>>2]|0)?(t[o>>2]|0)==(t[a>>2]|0):0){t[r>>2]=0;c=t[r>>2]|0;s=i;return c|0}t[r>>2]=ql(t[f>>2]|0,(t[a>>2]|0)-(t[f>>2]|0)|0)|0;c=t[r>>2]|0;s=i;return c|0}function aC(e){e=e|0;var i=0,r=0,f=0,a=0;i=s;s=s+16|0;r=i;f=i+4|0;n[f>>0]=e;if(65<=(u[f>>0]|0|0)?(u[f>>0]|0|0)<=90:0)t[r>>2]=(u[f>>0]|0)-65;else a=4;do if((a|0)==4){if(97<=(u[f>>0]|0|0)?(u[f>>0]|0|0)<=122:0){t[r>>2]=(u[f>>0]|0)-97+26;break}if(48<=(u[f>>0]|0|0)?(u[f>>0]|0|0)<=57:0){t[r>>2]=(u[f>>0]|0)-48+52;break}if(43==(u[f>>0]|0|0)){t[r>>2]=62;break}if(47==(u[f>>0]|0|0)){t[r>>2]=63;break}if(61==(u[f>>0]|0|0)){t[r>>2]=64;break}else{t[r>>2]=-1;break}}while(0);s=i;return t[r>>2]|0}function oC(e,i){e=e|0;i=i|0;var r=0,n=0,u=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0,S=0;r=s;s=s+64|0;n=r+48|0;u=r+44|0;o=r+40|0;c=r+36|0;l=r+32|0;b=r+28|0;k=r+24|0;h=r+20|0;w=r+16|0;d=r+12|0;v=r+8|0;m=r+4|0;_=r;t[u>>2]=e;t[o>>2]=i;t[l>>2]=1;e:do if(f[(t[u>>2]|0)+24>>1]&1){if(((t[(t[u>>2]|0)+8>>2]|0)==0?(t[(t[u>>2]|0)+12>>2]|0)==0:0)?(t[(t[u>>2]|0)+16>>2]|0)==0:0){p=11;break}do if(f[(t[o>>2]|0)+24>>1]&1){if(((t[(t[o>>2]|0)+8>>2]|0)==0?(t[(t[o>>2]|0)+12>>2]|0)==0:0)?(t[(t[o>>2]|0)+16>>2]|0)==0:0)break;t[l>>2]=-1;break e}while(0);t[n>>2]=-1;E=t[n>>2]|0;s=r;return E|0}else p=11;while(0);do if((p|0)==11?(f[(t[o>>2]|0)+24>>1]&1|0)!=0:0){if(((t[(t[o>>2]|0)+8>>2]|0)==0?(t[(t[o>>2]|0)+12>>2]|0)==0:0)?(t[(t[o>>2]|0)+16>>2]|0)==0:0)break;t[n>>2]=1;E=t[n>>2]|0;s=r;return E|0}while(0);t[b>>2]=((a[(t[u>>2]|0)+24>>1]|0)>>>8&65535)-((a[(t[u>>2]|0)+24>>1]|0)>>>1&127);t[k>>2]=((a[(t[o>>2]|0)+24>>1]|0)>>>8&65535)-((a[(t[o>>2]|0)+24>>1]|0)>>>1&127);if((t[b>>2]|0)==1?(t[(t[u>>2]|0)+8>>2]|0)==0:0){if((t[k>>2]|0)!=1){t[n>>2]=0-(t[l>>2]|0);E=t[n>>2]|0;s=r;return E|0}if(t[(t[o>>2]|0)+8>>2]|0){t[n>>2]=0-(t[l>>2]|0);E=t[n>>2]|0;s=r;return E|0}else{t[n>>2]=0;E=t[n>>2]|0;s=r;return E|0}}if((t[k>>2]|0)==1?(t[(t[o>>2]|0)+8>>2]|0)==0:0){if((t[b>>2]|0)!=1){t[n>>2]=t[l>>2];E=t[n>>2]|0;s=r;return E|0}if(t[(t[u>>2]|0)+8>>2]|0){t[n>>2]=t[l>>2];E=t[n>>2]|0;s=r;return E|0}else{t[n>>2]=0;E=t[n>>2]|0;s=r;return E|0}}if((t[b>>2]|0)>(t[k>>2]|0)){t[n>>2]=t[l>>2];E=t[n>>2]|0;s=r;return E|0}if((t[k>>2]|0)>(t[b>>2]|0)){t[n>>2]=0-(t[l>>2]|0);E=t[n>>2]|0;s=r;return E|0}t[h>>2]=((a[(t[u>>2]|0)+24>>1]|0)>>>8&65535)-((a[(t[o>>2]|0)+24>>1]|0)>>>8&65535);if((t[h>>2]|0)<0){t[c>>2]=t[u>>2];t[w>>2]=t[(t[o>>2]|0)+16>>2];t[d>>2]=t[(t[o>>2]|0)+12>>2];t[v>>2]=t[(t[o>>2]|0)+8>>2];t[h>>2]=0-(t[h>>2]|0);t[l>>2]=0-(t[l>>2]|0)}else{t[c>>2]=t[o>>2];t[w>>2]=t[(t[u>>2]|0)+16>>2];t[d>>2]=t[(t[u>>2]|0)+12>>2];t[v>>2]=t[(t[u>>2]|0)+8>>2]}while(1){if((t[h>>2]|0)<=8)break;t[v>>2]=t[d>>2];t[d>>2]=t[w>>2];t[w>>2]=0;t[h>>2]=(t[h>>2]|0)-8}while(1){S=t[w>>2]|0;if((t[h>>2]|0)<=0)break;t[m>>2]=te((S>>>0)%10|0,1e8)|0;t[w>>2]=((t[w>>2]|0)>>>0)/10|0;t[_>>2]=te(((t[d>>2]|0)>>>0)%10|0,1e8)|0;t[d>>2]=(((t[d>>2]|0)+(t[m>>2]|0)|0)>>>0)/10|0;t[v>>2]=(((t[v>>2]|0)+(t[_>>2]|0)|0)>>>0)/10|0;t[h>>2]=(t[h>>2]|0)+-1}if(S>>>0>(t[(t[c>>2]|0)+16>>2]|0)>>>0){t[n>>2]=t[l>>2];E=t[n>>2]|0;s=r;return E|0}if((t[w>>2]|0)==(t[(t[c>>2]|0)+16>>2]|0)){if((t[d>>2]|0)>>>0>(t[(t[c>>2]|0)+12>>2]|0)>>>0){t[n>>2]=t[l>>2];E=t[n>>2]|0;s=r;return E|0}if((t[d>>2]|0)==(t[(t[c>>2]|0)+12>>2]|0)){if((t[v>>2]|0)>>>0>(t[(t[c>>2]|0)+8>>2]|0)>>>0){t[n>>2]=t[l>>2];E=t[n>>2]|0;s=r;return E|0}if((t[v>>2]|0)==(t[(t[c>>2]|0)+8>>2]|0))if(((a[(t[u>>2]|0)+24>>1]|0)>>>8&65535|0)==((a[(t[o>>2]|0)+24>>1]|0)>>>8&65535|0)){t[n>>2]=0;E=t[n>>2]|0;s=r;return E|0}else{t[n>>2]=t[l>>2];E=t[n>>2]|0;s=r;return E|0}}}t[n>>2]=0-(t[l>>2]|0);E=t[n>>2]|0;s=r;return E|0}function cC(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0;r=s;s=s+64|0;n=r+52|0;f=r+48|0;u=r+44|0;a=r+40|0;o=r+36|0;c=r+32|0;b=r;k=r+28|0;h=r+24|0;w=r+20|0;d=r+16|0;v=r+12|0;m=r+8|0;t[f>>2]=e;t[u>>2]=i;t[k>>2]=1;if((t[f>>2]|0)==0|(t[u>>2]|0)==0){t[n>>2]=-2;_=t[n>>2]|0;s=r;return _|0}t[o>>2]=(t[(t[f>>2]|0)+8>>2]|0)-(t[(t[u>>2]|0)+8>>2]|0);l[b>>3]=+l[(t[f>>2]|0)+16>>3]-+l[(t[u>>2]|0)+16>>3];t[a>>2]=~~(+l[b>>3]/86400);l[b>>3]=+l[b>>3]-+(t[a>>2]|0)*86400;t[c>>2]=(t[(t[f>>2]|0)+12>>2]|0)-(t[(t[u>>2]|0)+12>>2]|0)+(t[a>>2]|0);if(!(t[o>>2]|0)){if(t[c>>2]|0)if((t[c>>2]|0)<0){t[n>>2]=-1;_=t[n>>2]|0;s=r;return _|0}else{t[n>>2]=1;_=t[n>>2]|0;s=r;return _|0}if(+l[b>>3]==0){t[n>>2]=0;_=t[n>>2]|0;s=r;return _|0}if(+l[b>>3]<0){t[n>>2]=-1;_=t[n>>2]|0;s=r;return _|0}else{t[n>>2]=1;_=t[n>>2]|0;s=r;return _|0}}a=t[c>>2]|0;do if((t[o>>2]|0)>0){if(!((a|0)>=0&+l[b>>3]>=0)){t[h>>2]=t[o>>2];t[w>>2]=0-(t[c>>2]|0);break}t[n>>2]=1;_=t[n>>2]|0;s=r;return _|0}else{if(!((a|0)<=0&+l[b>>3]<=0)){t[k>>2]=-1;t[h>>2]=0-(t[o>>2]|0);t[w>>2]=t[c>>2];break}t[n>>2]=-1;_=t[n>>2]|0;s=r;return _|0}while(0);t[d>>2]=(t[h>>2]|0)/12|0;if(!(t[d>>2]|0)){t[v>>2]=0;t[m>>2]=0}else{t[m>>2]=((((t[d>>2]|0)+3|0)/4|0)*366|0)+((((t[d>>2]|0)-1|0)%4|0)*365|0);t[v>>2]=(t[m>>2]|0)-1}t[h>>2]=(t[h>>2]|0)%12|0;t[v>>2]=(t[v>>2]|0)+(t[172120+(t[h>>2]<<2)>>2]|0);t[m>>2]=(t[m>>2]|0)+(t[172168+(t[h>>2]<<2)>>2]|0);if((t[m>>2]|0)==(t[v>>2]|0)?(t[m>>2]|0)==(t[w>>2]|0):0){t[n>>2]=0;_=t[n>>2]|0;s=r;return _|0}if((t[m>>2]|0)<(t[w>>2]|0)){t[n>>2]=0-(t[k>>2]|0);_=t[n>>2]|0;s=r;return _|0}if((t[v>>2]|0)>(t[w>>2]|0)){t[n>>2]=t[k>>2];_=t[n>>2]|0;s=r;return _|0}else{t[n>>2]=2;_=t[n>>2]|0;s=r;return _|0}return 0}function lC(e,i){e=e|0;i=i|0;var r=0,a=0,o=0,c=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0,S=0,g=0,y=0,F=0,O=0,A=0,M=0,R=0,N=0;r=s;s=s+96|0;a=r+76|0;o=r+72|0;c=r+68|0;b=r+83|0;k=r+82|0;h=r+81|0;w=r+80|0;d=r+64|0;v=r+60|0;m=r+56|0;_=r+52|0;p=r+48|0;E=r+44|0;S=r+40|0;g=r+36|0;y=r+16|0;F=r+32|0;O=r+8|0;A=r+28|0;M=r+24|0;R=r;t[o>>2]=e;t[c>>2]=i;if((t[o>>2]|0)==0|(t[c>>2]|0)==0){t[a>>2]=-2;N=t[a>>2]|0;s=r;return N|0}i=(f[(t[c>>2]|0)+24>>1]&1|0)!=0;do if(f[(t[o>>2]|0)+24>>1]&1){if(!i){t[d>>2]=eC(t[o>>2]|0,0)|0;e=FC(t[d>>2]|0)|0;t[p>>2]=e+((t[(t[d>>2]|0)+12>>2]|0)>>>4&31);t[m>>2]=eC(t[c>>2]|0,50400)|0;e=FC(t[m>>2]|0)|0;t[S>>2]=e+((t[(t[m>>2]|0)+12>>2]|0)>>>4&31);if((t[p>>2]|0)<(t[S>>2]|0)){MD(t[d>>2]|0);MD(t[m>>2]|0);t[a>>2]=-1;N=t[a>>2]|0;s=r;return N|0}e=t[d>>2]|0;if((t[p>>2]|0)!=(t[S>>2]|0)){MD(e);MD(t[m>>2]|0);break}l[y>>3]=+((((t[e+12>>2]|0)>>>9&31)*3600|0)+(((t[(t[d>>2]|0)+12>>2]|0)>>>14&63)*60|0)+(((f[(t[d>>2]|0)+24>>1]<<3&65535)<<16>>16>>4<<16>>16)*60|0)|0)+ +l[(t[d>>2]|0)+16>>3]-(+((((t[(t[m>>2]|0)+12>>2]|0)>>>9&31)*3600|0)+(((t[(t[m>>2]|0)+12>>2]|0)>>>14&63)*60|0)+(((f[(t[m>>2]|0)+24>>1]<<3&65535)<<16>>16>>4<<16>>16)*60|0)|0)+ +l[(t[m>>2]|0)+16>>3]);if(+l[y>>3]<0){MD(t[d>>2]|0);MD(t[m>>2]|0);t[a>>2]=-1;N=t[a>>2]|0;s=r;return N|0}t[F>>2]=0;t[_>>2]=eC(t[c>>2]|0,-50400)|0;e=FC(t[_>>2]|0)|0;t[g>>2]=e+((t[(t[_>>2]|0)+12>>2]|0)>>>4&31);do if((t[p>>2]|0)<=(t[g>>2]|0)){if((t[p>>2]|0)==(t[g>>2]|0)){l[y>>3]=+((((t[(t[d>>2]|0)+12>>2]|0)>>>9&31)*3600|0)+(((t[(t[d>>2]|0)+12>>2]|0)>>>14&63)*60|0)+(((f[(t[d>>2]|0)+24>>1]<<3&65535)<<16>>16>>4<<16>>16)*60|0)|0)+ +l[(t[d>>2]|0)+16>>3]-(+((((t[(t[_>>2]|0)+12>>2]|0)>>>9&31)*3600|0)+(((t[(t[_>>2]|0)+12>>2]|0)>>>14&63)*60|0)+(((f[(t[_>>2]|0)+24>>1]<<3&65535)<<16>>16>>4<<16>>16)*60|0)|0)+ +l[(t[_>>2]|0)+16>>3]);if(+l[y>>3]>0){t[F>>2]=1;break}else{t[F>>2]=2;break}}}else t[F>>2]=1;while(0);MD(t[d>>2]|0);MD(t[m>>2]|0);MD(t[_>>2]|0);if(t[F>>2]|0){t[a>>2]=t[F>>2];N=t[a>>2]|0;s=r;return N|0}}}else if(i){t[m>>2]=eC(t[c>>2]|0,0)|0;e=FC(t[m>>2]|0)|0;t[S>>2]=e+((t[(t[m>>2]|0)+12>>2]|0)>>>4&31);t[d>>2]=eC(t[o>>2]|0,-50400)|0;e=FC(t[d>>2]|0)|0;t[p>>2]=e+((t[(t[d>>2]|0)+12>>2]|0)>>>4&31);if((t[p>>2]|0)<(t[S>>2]|0)){MD(t[d>>2]|0);MD(t[m>>2]|0);t[a>>2]=-1;N=t[a>>2]|0;s=r;return N|0}e=t[d>>2]|0;if((t[p>>2]|0)!=(t[S>>2]|0)){MD(e);MD(t[m>>2]|0);break}l[O>>3]=+((((t[e+12>>2]|0)>>>9&31)*3600|0)+(((t[(t[d>>2]|0)+12>>2]|0)>>>14&63)*60|0)+(((f[(t[d>>2]|0)+24>>1]<<3&65535)<<16>>16>>4<<16>>16)*60|0)|0)+ +l[(t[d>>2]|0)+16>>3]-(+((((t[(t[m>>2]|0)+12>>2]|0)>>>9&31)*3600|0)+(((t[(t[m>>2]|0)+12>>2]|0)>>>14&63)*60|0)+(((f[(t[m>>2]|0)+24>>1]<<3&65535)<<16>>16>>4<<16>>16)*60|0)|0)+ +l[(t[m>>2]|0)+16>>3]);if(+l[O>>3]<0){MD(t[d>>2]|0);MD(t[m>>2]|0);t[a>>2]=-1;N=t[a>>2]|0;s=r;return N|0}t[A>>2]=0;t[v>>2]=eC(t[o>>2]|0,50400)|0;e=FC(t[v>>2]|0)|0;t[E>>2]=e+((t[(t[v>>2]|0)+12>>2]|0)>>>4&31);do if((t[E>>2]|0)<=(t[S>>2]|0)){if((t[E>>2]|0)==(t[S>>2]|0)){l[O>>3]=+((((t[(t[v>>2]|0)+12>>2]|0)>>>9&31)*3600|0)+(((t[(t[v>>2]|0)+12>>2]|0)>>>14&63)*60|0)+(((f[(t[v>>2]|0)+24>>1]<<3&65535)<<16>>16>>4<<16>>16)*60|0)|0)+ +l[(t[v>>2]|0)+16>>3]-(+((((t[(t[m>>2]|0)+12>>2]|0)>>>9&31)*3600|0)+(((t[(t[m>>2]|0)+12>>2]|0)>>>14&63)*60|0)+(((f[(t[m>>2]|0)+24>>1]<<3&65535)<<16>>16>>4<<16>>16)*60|0)|0)+ +l[(t[m>>2]|0)+16>>3]);if(+l[O>>3]>0){t[A>>2]=1;break}else{t[A>>2]=2;break}}}else t[A>>2]=1;while(0);MD(t[d>>2]|0);MD(t[m>>2]|0);MD(t[v>>2]|0);if(t[A>>2]|0){t[a>>2]=t[A>>2];N=t[a>>2]|0;s=r;return N|0}}while(0);if((t[t[o>>2]>>2]|0)==(t[t[c>>2]>>2]|0)){t[M>>2]=0;t[m>>2]=eC(t[c>>2]|0,0)|0;A=FC(t[m>>2]|0)|0;t[S>>2]=A+((t[(t[m>>2]|0)+12>>2]|0)>>>4&31);t[d>>2]=eC(t[o>>2]|0,0)|0;A=FC(t[d>>2]|0)|0;t[p>>2]=A+((t[(t[d>>2]|0)+12>>2]|0)>>>4&31);do if((t[p>>2]|0)>=(t[S>>2]|0)){if((t[p>>2]|0)>(t[S>>2]|0)){t[M>>2]=1;break}l[R>>3]=+((((t[(t[d>>2]|0)+12>>2]|0)>>>9&31)*3600|0)+(((t[(t[d>>2]|0)+12>>2]|0)>>>14&63)*60|0)+(((f[(t[d>>2]|0)+24>>1]<<3&65535)<<16>>16>>4<<16>>16)*60|0)|0)+ +l[(t[d>>2]|0)+16>>3]-(+((((t[(t[m>>2]|0)+12>>2]|0)>>>9&31)*3600|0)+(((t[(t[m>>2]|0)+12>>2]|0)>>>14&63)*60|0)+(((f[(t[m>>2]|0)+24>>1]<<3&65535)<<16>>16>>4<<16>>16)*60|0)|0)+ +l[(t[m>>2]|0)+16>>3]);if(+l[R>>3]<0){t[M>>2]=-1;break}if(+l[R>>3]>0)t[M>>2]=1}else t[M>>2]=-1;while(0);MD(t[d>>2]|0);MD(t[m>>2]|0);t[a>>2]=t[M>>2];N=t[a>>2]|0;s=r;return N|0}switch(t[t[o>>2]>>2]|0){case 6:{n[b>>0]=2;break}case 5:{n[b>>0]=3;break}case 9:{n[b>>0]=3;break}case 7:{n[b>>0]=6;break}case 4:{n[b>>0]=8;break}case 11:{n[b>>0]=15;break}case 10:{n[b>>0]=7;break}case 8:{n[b>>0]=1;break}default:n[b>>0]=0}switch(t[t[c>>2]>>2]|0){case 11:{n[k>>0]=15;break}case 10:{n[k>>0]=7;break}case 8:{n[k>>0]=1;break}case 6:{n[k>>0]=2;break}case 5:{n[k>>0]=3;break}case 9:{n[k>>0]=3;break}case 7:{n[k>>0]=6;break}case 4:{n[k>>0]=8;break}default:n[k>>0]=0}n[h>>0]=(u[b>>0]|0)^(u[k>>0]|0);n[w>>0]=(u[b>>0]|0)&(u[k>>0]|0);if((u[h>>0]|0)&1){t[a>>2]=2;N=t[a>>2]|0;s=r;return N|0}if((u[w>>0]|0)&1){if((t[(t[o>>2]|0)+8>>2]|0)<(t[(t[c>>2]|0)+8>>2]|0)){t[a>>2]=-1;N=t[a>>2]|0;s=r;return N|0}if((t[(t[o>>2]|0)+8>>2]|0)>(t[(t[c>>2]|0)+8>>2]|0)){t[a>>2]=1;N=t[a>>2]|0;s=r;return N|0}}if((u[h>>0]|0)&2){t[a>>2]=2;N=t[a>>2]|0;s=r;return N|0}if((u[w>>0]|0)&2){if((t[(t[o>>2]|0)+12>>2]&15|0)<(t[(t[c>>2]|0)+12>>2]&15|0)){t[a>>2]=-1;N=t[a>>2]|0;s=r;return N|0}if((t[(t[o>>2]|0)+12>>2]&15|0)>(t[(t[c>>2]|0)+12>>2]&15|0)){t[a>>2]=1;N=t[a>>2]|0;s=r;return N|0}}if((u[h>>0]|0)&4){t[a>>2]=2;N=t[a>>2]|0;s=r;return N|0}if((u[w>>0]|0)&4){if(((t[(t[o>>2]|0)+12>>2]|0)>>>4&31|0)<((t[(t[c>>2]|0)+12>>2]|0)>>>4&31|0)){t[a>>2]=-1;N=t[a>>2]|0;s=r;return N|0}if(((t[(t[o>>2]|0)+12>>2]|0)>>>4&31|0)>((t[(t[c>>2]|0)+12>>2]|0)>>>4&31|0)){t[a>>2]=1;N=t[a>>2]|0;s=r;return N|0}}if((u[h>>0]|0)&8){t[a>>2]=2;N=t[a>>2]|0;s=r;return N|0}if((u[w>>0]|0)&8){if(((t[(t[o>>2]|0)+12>>2]|0)>>>9&31|0)<((t[(t[c>>2]|0)+12>>2]|0)>>>9&31|0)){t[a>>2]=-1;N=t[a>>2]|0;s=r;return N|0}if(((t[(t[o>>2]|0)+12>>2]|0)>>>9&31|0)>((t[(t[c>>2]|0)+12>>2]|0)>>>9&31|0)){t[a>>2]=1;N=t[a>>2]|0;s=r;return N|0}if(((t[(t[o>>2]|0)+12>>2]|0)>>>14&63|0)<((t[(t[c>>2]|0)+12>>2]|0)>>>14&63|0)){t[a>>2]=-1;N=t[a>>2]|0;s=r;return N|0}if(((t[(t[o>>2]|0)+12>>2]|0)>>>14&63|0)>((t[(t[c>>2]|0)+12>>2]|0)>>>14&63|0)){t[a>>2]=1;N=t[a>>2]|0;s=r;return N|0}if(+l[(t[o>>2]|0)+16>>3]<+l[(t[c>>2]|0)+16>>3]){t[a>>2]=-1;N=t[a>>2]|0;s=r;return N|0}if(+l[(t[o>>2]|0)+16>>3]>+l[(t[c>>2]|0)+16>>3]){t[a>>2]=1;N=t[a>>2]|0;s=r;return N|0}}t[a>>2]=0;N=t[a>>2]|0;s=r;return N|0}function sC(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,a=0,o=0,c=0,l=0,b=0;n=s;s=s+32|0;f=n+16|0;a=n+12|0;o=n+8|0;c=n+4|0;l=n;t[a>>2]=e;t[o>>2]=i;t[c>>2]=r;while(1){if(!(u[t[a>>2]>>0]|0)){b=24;break}if(!(u[t[o>>2]>>0]|0)){b=24;break}if(((u[t[o>>2]>>0]|0|0)!=9?(u[t[o>>2]>>0]|0|0)!=10:0)?(u[t[o>>2]>>0]|0|0)!=13:0){t[l>>2]=(u[t[a>>2]>>0]|0)-(u[t[o>>2]>>0]|0);if((t[l>>2]|0)<0){b=16;break}if((t[l>>2]|0)>0){b=20;break}}else b=7;if((b|0)==7?(b=0,(u[t[a>>2]>>0]|0|0)!=32):0){b=8;break}t[a>>2]=(t[a>>2]|0)+1;t[o>>2]=(t[o>>2]|0)+1}do if((b|0)==8){l=(t[c>>2]|0)!=0;if(((u[t[a>>2]>>0]|0)-32|0)<0)if(l){t[f>>2]=1;break}else{t[f>>2]=-1;break}else if(l){t[f>>2]=-1;break}else{t[f>>2]=1;break}}else if((b|0)==16)if(t[c>>2]|0){t[f>>2]=1;break}else{t[f>>2]=-1;break}else if((b|0)==20)if(t[c>>2]|0){t[f>>2]=-1;break}else{t[f>>2]=1;break}else if((b|0)==24){if(u[t[a>>2]>>0]|0)if(t[c>>2]|0){t[f>>2]=-1;break}else{t[f>>2]=1;break}if(!(u[t[o>>2]>>0]|0)){t[f>>2]=0;break}if(t[c>>2]|0){t[f>>2]=1;break}else{t[f>>2]=-1;break}}while(0);s=n;return t[f>>2]|0}function bC(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0;n=s;s=s+32|0;f=n+16|0;a=n+12|0;o=n+8|0;c=n+4|0;l=n;t[a>>2]=e;t[o>>2]=i;t[c>>2]=r;e:while(1){do if((u[t[o>>2]>>0]|0|0)!=32){if(9<=(u[t[o>>2]>>0]|0|0)?(u[t[o>>2]>>0]|0|0)<=10:0)break;if((u[t[o>>2]>>0]|0|0)!=13)break e}while(0);t[o>>2]=(t[o>>2]|0)+1}e:while(1){if(!(u[t[a>>2]>>0]|0)){b=35;break}if(!(u[t[o>>2]>>0]|0)){b=35;break}do if((u[t[o>>2]>>0]|0|0)!=32){if(9<=(u[t[o>>2]>>0]|0|0)?(u[t[o>>2]>>0]|0|0)<=10:0)break;if((u[t[o>>2]>>0]|0|0)!=13){r=t[a>>2]|0;t[a>>2]=r+1;i=u[r>>0]|0;r=t[o>>2]|0;t[o>>2]=r+1;t[l>>2]=i-(u[r>>0]|0);if((t[l>>2]|0)<0){b=28;break e}if((t[l>>2]|0)>0){b=32;break e}else continue e}}while(0);k=t[a>>2]|0;if((u[t[a>>2]>>0]|0|0)!=32){b=14;break}t[a>>2]=k+1;t[o>>2]=(t[o>>2]|0)+1;while(1){do if((u[t[o>>2]>>0]|0|0)!=32){if(9<=(u[t[o>>2]>>0]|0|0)?(u[t[o>>2]>>0]|0|0)<=10:0)break;if((u[t[o>>2]>>0]|0|0)!=13)continue e}while(0);t[o>>2]=(t[o>>2]|0)+1}}do if((b|0)==14){l=(t[c>>2]|0)!=0;if(((u[k>>0]|0)-32|0)<0)if(l){t[f>>2]=1;break}else{t[f>>2]=-1;break}else if(l){t[f>>2]=-1;break}else{t[f>>2]=1;break}}else if((b|0)==28)if(t[c>>2]|0){t[f>>2]=1;break}else{t[f>>2]=-1;break}else if((b|0)==32)if(t[c>>2]|0){t[f>>2]=-1;break}else{t[f>>2]=1;break}else if((b|0)==35){if(u[t[a>>2]>>0]|0)if(t[c>>2]|0){t[f>>2]=-1;break}else{t[f>>2]=1;break}if(u[t[o>>2]>>0]|0){while(1){do if((u[t[o>>2]>>0]|0|0)==32)h=1;else{if(9<=(u[t[o>>2]>>0]|0|0)?(u[t[o>>2]>>0]|0|0)<=10:0){h=1;break}h=(u[t[o>>2]>>0]|0|0)==13}while(0);w=t[o>>2]|0;if(!h)break;t[o>>2]=w+1}if(u[w>>0]|0)if(t[c>>2]|0){t[f>>2]=1;break}else{t[f>>2]=-1;break}}t[f>>2]=0}while(0);s=n;return t[f>>2]|0}function kC(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,a=0,o=0,c=0,l=0;r=s;s=s+16|0;n=r+12|0;f=r+8|0;a=r+4|0;o=r;t[f>>2]=e;t[a>>2]=i;e:while(1){if(!(u[t[f>>2]>>0]|0)){c=27;break}if(!(u[t[a>>2]>>0]|0)){c=27;break}do if((u[t[a>>2]>>0]|0|0)!=32){if(9<=(u[t[a>>2]>>0]|0|0)?(u[t[a>>2]>>0]|0|0)<=10:0){c=8;break}if((u[t[a>>2]>>0]|0|0)!=13){if((u[t[f>>2]>>0]|0|0)==32){c=19;break e}if(9<=(u[t[f>>2]>>0]|0|0)?(u[t[f>>2]>>0]|0|0)<=10:0){c=19;break e}if((u[t[f>>2]>>0]|0|0)==13){c=19;break e}t[o>>2]=(u[t[f>>2]>>0]|0)-(u[t[a>>2]>>0]|0);if((t[o>>2]|0)<0){c=23;break e}if((t[o>>2]|0)>0){c=25;break e}}else c=8}else c=8;while(0);do if((c|0)==8?(c=0,(u[t[f>>2]>>0]|0|0)!=32):0){if(9<=(u[t[f>>2]>>0]|0|0)?(u[t[f>>2]>>0]|0|0)<=10:0)break;if((u[t[f>>2]>>0]|0|0)!=13){c=12;break e}}while(0);t[f>>2]=(t[f>>2]|0)+1;t[a>>2]=(t[a>>2]|0)+1}if((c|0)==12)if(((u[t[f>>2]>>0]|0)-32|0)<0){t[n>>2]=-1;l=t[n>>2]|0;s=r;return l|0}else{t[n>>2]=1;l=t[n>>2]|0;s=r;return l|0}else if((c|0)==19)if((32-(u[t[a>>2]>>0]|0)|0)<0){t[n>>2]=-1;l=t[n>>2]|0;s=r;return l|0}else{t[n>>2]=1;l=t[n>>2]|0;s=r;return l|0}else if((c|0)==23){t[n>>2]=-1;l=t[n>>2]|0;s=r;return l|0}else if((c|0)==25){t[n>>2]=1;l=t[n>>2]|0;s=r;return l|0}else if((c|0)==27){if(u[t[f>>2]>>0]|0){t[n>>2]=1;l=t[n>>2]|0;s=r;return l|0}if(u[t[a>>2]>>0]|0){t[n>>2]=-1;l=t[n>>2]|0;s=r;return l|0}else{t[n>>2]=0;l=t[n>>2]|0;s=r;return l|0}}return 0}function hC(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0;n=s;s=s+32|0;f=n+16|0;a=n+12|0;o=n+8|0;c=n+4|0;l=n;t[a>>2]=e;t[o>>2]=i;t[c>>2]=r;e:while(1){do if((u[t[o>>2]>>0]|0|0)!=32){if(9<=(u[t[o>>2]>>0]|0|0)?(u[t[o>>2]>>0]|0|0)<=10:0)break;if((u[t[o>>2]>>0]|0|0)!=13)break e}while(0);t[o>>2]=(t[o>>2]|0)+1}e:while(1){if(!(u[t[a>>2]>>0]|0)){b=45;break}if(!(u[t[o>>2]>>0]|0)){b=45;break}do if((u[t[o>>2]>>0]|0|0)!=32){if(9<=(u[t[o>>2]>>0]|0|0)?(u[t[o>>2]>>0]|0|0)<=10:0)break;if((u[t[o>>2]>>0]|0|0)!=13){if((u[t[a>>2]>>0]|0|0)==32){b=34;break e}if(9<=(u[t[a>>2]>>0]|0|0)?(u[t[a>>2]>>0]|0|0)<=10:0){b=34;break e}if((u[t[a>>2]>>0]|0|0)==13){b=34;break e}r=t[a>>2]|0;t[a>>2]=r+1;i=u[r>>0]|0;r=t[o>>2]|0;t[o>>2]=r+1;t[l>>2]=i-(u[r>>0]|0);if((t[l>>2]|0)<0){b=42;break e}if((t[l>>2]|0)>0){b=44;break e}else continue e}}while(0);do if((u[t[a>>2]>>0]|0|0)!=32){if(9<=(u[t[a>>2]>>0]|0|0)?(u[t[a>>2]>>0]|0|0)<=10:0)break;if((u[t[a>>2]>>0]|0|0)!=13){b=17;break e}}while(0);t[a>>2]=(t[a>>2]|0)+1;t[o>>2]=(t[o>>2]|0)+1;while(1){do if((u[t[o>>2]>>0]|0|0)!=32){if(9<=(u[t[o>>2]>>0]|0|0)?(u[t[o>>2]>>0]|0|0)<=10:0)break;if((u[t[o>>2]>>0]|0|0)!=13)continue e}while(0);t[o>>2]=(t[o>>2]|0)+1}}if((b|0)==17){l=(t[c>>2]|0)!=0;if(((u[t[a>>2]>>0]|0)-32|0)<0)if(l){t[f>>2]=1;k=t[f>>2]|0;s=n;return k|0}else{t[f>>2]=-1;k=t[f>>2]|0;s=n;return k|0}else if(l){t[f>>2]=-1;k=t[f>>2]|0;s=n;return k|0}else{t[f>>2]=1;k=t[f>>2]|0;s=n;return k|0}}else if((b|0)==34){l=(t[c>>2]|0)!=0;if((32-(u[t[o>>2]>>0]|0)|0)<0)if(l){t[f>>2]=1;k=t[f>>2]|0;s=n;return k|0}else{t[f>>2]=-1;k=t[f>>2]|0;s=n;return k|0}else if(l){t[f>>2]=-1;k=t[f>>2]|0;s=n;return k|0}else{t[f>>2]=1;k=t[f>>2]|0;s=n;return k|0}}else if((b|0)==42){t[f>>2]=-1;k=t[f>>2]|0;s=n;return k|0}else if((b|0)==44){t[f>>2]=1;k=t[f>>2]|0;s=n;return k|0}else if((b|0)==45){if(u[t[a>>2]>>0]|0)if(t[c>>2]|0){t[f>>2]=-1;k=t[f>>2]|0;s=n;return k|0}else{t[f>>2]=1;k=t[f>>2]|0;s=n;return k|0}if(u[t[o>>2]>>0]|0){while(1){do if((u[t[o>>2]>>0]|0|0)==32)h=1;else{if(9<=(u[t[o>>2]>>0]|0|0)?(u[t[o>>2]>>0]|0|0)<=10:0){h=1;break}h=(u[t[o>>2]>>0]|0|0)==13}while(0);w=t[o>>2]|0;if(!h)break;t[o>>2]=w+1}if(u[w>>0]|0)if(t[c>>2]|0){t[f>>2]=1;k=t[f>>2]|0;s=n;return k|0}else{t[f>>2]=-1;k=t[f>>2]|0;s=n;return k|0}}t[f>>2]=0;k=t[f>>2]|0;s=n;return k|0}return 0}function wC(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0;r=s;s=s+16|0;n=r+12|0;f=r+8|0;a=r+4|0;o=r;t[f>>2]=e;t[a>>2]=i;e:while(1){do if((u[t[f>>2]>>0]|0|0)!=32){if(9<=(u[t[f>>2]>>0]|0|0)?(u[t[f>>2]>>0]|0|0)<=10:0)break;if((u[t[f>>2]>>0]|0|0)!=13)break e}while(0);t[f>>2]=(t[f>>2]|0)+1}e:while(1){do if((u[t[a>>2]>>0]|0|0)!=32){if(9<=(u[t[a>>2]>>0]|0|0)?(u[t[a>>2]>>0]|0|0)<=10:0)break;if((u[t[a>>2]>>0]|0|0)!=13)break e}while(0);t[a>>2]=(t[a>>2]|0)+1}e:while(1){if(u[t[f>>2]>>0]|0)c=(u[t[a>>2]>>0]|0|0)!=0;else c=0;l=u[t[f>>2]>>0]|0;if(!c){b=38;break}do if((l|0)!=32){if(9<=(u[t[f>>2]>>0]|0|0)?(u[t[f>>2]>>0]|0|0)<=10:0)break;if((u[t[f>>2]>>0]|0|0)!=13){i=t[f>>2]|0;t[f>>2]=i+1;e=u[i>>0]|0;i=t[a>>2]|0;t[a>>2]=i+1;t[o>>2]=e-(u[i>>0]|0);if((t[o>>2]|0)<0){b=35;break e}if((t[o>>2]|0)>0){b=37;break e}else continue e}}while(0);do if((u[t[a>>2]>>0]|0|0)!=32){if(9<=(u[t[a>>2]>>0]|0|0)?(u[t[a>>2]>>0]|0|0)<=10:0)break;if((u[t[a>>2]>>0]|0|0)!=13){b=23;break e}}while(0);i:while(1){do if((u[t[f>>2]>>0]|0|0)!=32){if(9<=(u[t[f>>2]>>0]|0|0)?(u[t[f>>2]>>0]|0|0)<=10:0)break;if((u[t[f>>2]>>0]|0|0)!=13)break i}while(0);t[f>>2]=(t[f>>2]|0)+1}while(1){do if((u[t[a>>2]>>0]|0|0)!=32){if(9<=(u[t[a>>2]>>0]|0|0)?(u[t[a>>2]>>0]|0|0)<=10:0)break;if((u[t[a>>2]>>0]|0|0)!=13)continue e}while(0);t[a>>2]=(t[a>>2]|0)+1}}if((b|0)==23){t[o>>2]=(u[t[f>>2]>>0]|0)-(u[t[a>>2]>>0]|0);t[n>>2]=t[o>>2];k=t[n>>2]|0;s=r;return k|0}else if((b|0)==35){t[n>>2]=-1;k=t[n>>2]|0;s=r;return k|0}else if((b|0)==37){t[n>>2]=1;k=t[n>>2]|0;s=r;return k|0}else if((b|0)==38){if(l){while(1){do if((u[t[f>>2]>>0]|0|0)==32)h=1;else{if(9<=(u[t[f>>2]>>0]|0|0)?(u[t[f>>2]>>0]|0|0)<=10:0){h=1;break}h=(u[t[f>>2]>>0]|0|0)==13}while(0);w=t[f>>2]|0;if(!h)break;t[f>>2]=w+1}if(u[w>>0]|0){t[n>>2]=1;k=t[n>>2]|0;s=r;return k|0}}if(u[t[a>>2]>>0]|0){while(1){do if((u[t[a>>2]>>0]|0|0)==32)d=1;else{if(9<=(u[t[a>>2]>>0]|0|0)?(u[t[a>>2]>>0]|0|0)<=10:0){d=1;break}d=(u[t[a>>2]>>0]|0|0)==13}while(0);v=t[a>>2]|0;if(!d)break;t[a>>2]=v+1}if(u[v>>0]|0){t[n>>2]=-1;k=t[n>>2]|0;s=r;return k|0}}t[n>>2]=0;k=t[n>>2]|0;s=r;return k|0}return 0}function dC(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0;r=s;s=s+32|0;n=r+24|0;f=r+20|0;u=r+16|0;a=r+8|0;o=r;t[f>>2]=e;t[u>>2]=i;e:do if(!((t[f>>2]|0)==0|(t[u>>2]|0)==0)){i=t[f>>2]|0;do if((t[t[f>>2]>>2]|0)!=14)if((t[i>>2]|0)==13){l[a>>3]=+c[(t[f>>2]|0)+8>>2];break}else{t[n>>2]=-2;break e}else l[a>>3]=+l[i+8>>3];while(0);i=t[u>>2]|0;do if((t[t[u>>2]>>2]|0)!=14)if((t[i>>2]|0)==13){l[o>>3]=+c[(t[u>>2]|0)+8>>2];break}else{t[n>>2]=-2;break e}else l[o>>3]=+l[i+8>>3];while(0);i=(hn(+l[a>>3])|0)!=0;e=(hn(+l[o>>3])|0)!=0;if(i)if(e){t[n>>2]=0;break}else{t[n>>2]=1;break}if(e){t[n>>2]=-1;break}e=+l[o>>3]==+l[15985];if(+l[a>>3]==+l[15985])if(e){t[n>>2]=0;break}else{t[n>>2]=1;break}if(e){t[n>>2]=-1;break}e=+l[o>>3]==+l[15986];if(+l[a>>3]==+l[15986])if(e){t[n>>2]=0;break}else{t[n>>2]=-1;break}if(e){t[n>>2]=1;break}if(+l[a>>3]<+l[o>>3]){t[n>>2]=-1;break}if(+l[a>>3]>+l[o>>3]){t[n>>2]=1;break}if(+l[a>>3]==+l[o>>3]){t[n>>2]=0;break}else{t[n>>2]=2;break}}else t[n>>2]=-2;while(0);s=r;return t[n>>2]|0}function vC(e,i,r,n,f,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;u=u|0;a=a|0;o=o|0;var c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0;c=s;s=s+32|0;l=c+28|0;b=c+24|0;k=c+20|0;h=c+16|0;w=c+12|0;d=c+8|0;v=c+4|0;m=c;t[l>>2]=e;t[b>>2]=i;t[k>>2]=r;t[h>>2]=n;t[w>>2]=f;t[d>>2]=u;t[v>>2]=a;t[m>>2]=o;o=JD(t[l>>2]|0,t[b>>2]|0,t[k>>2]|0,t[h>>2]|0,t[w>>2]|0,t[d>>2]|0,t[v>>2]|0,t[m>>2]|0)|0;s=c;return o|0}function mC(e){e=e|0;var i=0,r=0,n=0,f=0,a=0,o=0,c=0,l=0,b=0;i=s;s=s+16|0;r=i+12|0;n=i+8|0;f=i+4|0;a=i;t[n>>2]=e;t[a>>2]=0;if(!(t[n>>2]|0)){t[r>>2]=-1;o=t[r>>2]|0;s=i;return o|0}t[f>>2]=t[n>>2];e:while(1){do if((u[t[f>>2]>>0]|0|0)!=32){if(9<=(u[t[f>>2]>>0]|0|0)?(u[t[f>>2]>>0]|0|0)<=10:0)break;if((u[t[f>>2]>>0]|0|0)!=13)break e}while(0);t[f>>2]=(t[f>>2]|0)+1}e:while(1){if(!(u[t[f>>2]>>0]|0)){c=36;break}n=t[f>>2]|0;i:do if(!((u[t[f>>2]>>0]|0)&128)){do if((u[n>>0]|0|0)!=32){if(9<=(u[t[f>>2]>>0]|0|0)?(u[t[f>>2]>>0]|0|0)<=10:0)break;if((u[t[f>>2]>>0]|0|0)!=13){t[f>>2]=(t[f>>2]|0)+1;break i}}while(0);while(1){do if((u[t[f>>2]>>0]|0|0)==32)l=1;else{if(9<=(u[t[f>>2]>>0]|0|0)?(u[t[f>>2]>>0]|0|0)<=10:0){l=1;break}l=(u[t[f>>2]>>0]|0|0)==13}while(0);b=t[f>>2]|0;if(!l)break;t[f>>2]=b+1}if(!(u[b>>0]|0)){c=36;break e}}else{if(((u[n+1>>0]|0)&192|0)!=128){c=12;break e}e=(t[f>>2]|0)+2|0;if(((u[t[f>>2]>>0]|0)&224|0)!=224){t[f>>2]=e;break}if(((u[e>>0]|0)&192|0)!=128){c=15;break e}e=t[f>>2]|0;if(((u[t[f>>2]>>0]|0)&240|0)!=240){t[f>>2]=e+3;break}if(((u[e>>0]|0)&248|0)!=240){c=19;break e}if(((u[(t[f>>2]|0)+3>>0]|0)&192|0)!=128){c=19;break e}t[f>>2]=(t[f>>2]|0)+4}while(0);t[a>>2]=(t[a>>2]|0)+1}if((c|0)==12){t[r>>2]=-1;o=t[r>>2]|0;s=i;return o|0}else if((c|0)==15){t[r>>2]=-1;o=t[r>>2]|0;s=i;return o|0}else if((c|0)==19){t[r>>2]=-1;o=t[r>>2]|0;s=i;return o|0}else if((c|0)==36){t[r>>2]=t[a>>2];o=t[r>>2]|0;s=i;return o|0}return 0}function _C(e,i){e=e|0;i=i|0;var r=0,n=0,u=0,a=0,o=0,c=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0,S=0,g=0,y=0,F=0,O=0,A=0;r=s;s=s+64|0;n=r+48|0;u=r+44|0;a=r+40|0;o=r+36|0;c=r+32|0;b=r+28|0;k=r+24|0;h=r+20|0;w=r+16|0;d=r+12|0;v=r+8|0;m=r+4|0;_=r;t[u>>2]=e;t[a>>2]=i;if((t[u>>2]|0)==0|(t[a>>2]|0)==0){t[n>>2]=0;p=t[n>>2]|0;s=r;return p|0}t[o>>2]=KD(t[t[u>>2]>>2]|0)|0;if(!(t[o>>2]|0)){t[n>>2]=0;p=t[n>>2]|0;s=r;return p|0}t[c>>2]=ZD(t[u>>2]|0)|0;u=t[o>>2]|0;if(!(t[c>>2]|0)){MD(u);t[n>>2]=0;p=t[n>>2]|0;s=r;return p|0}t[w>>2]=u+8;t[d>>2]=(t[c>>2]|0)+8;t[v>>2]=(t[a>>2]|0)+8;if(!(t[(t[d>>2]|0)+4>>2]&15)){a=(t[d>>2]|0)+4|0;t[a>>2]=t[a>>2]&-16|1}a=(t[v>>2]|0)+8|0;l[a>>3]=+l[a>>3]-+(((f[(t[d>>2]|0)+16>>1]<<3&65535)<<16>>16>>4<<16>>16)*60|0);a=(t[d>>2]|0)+16|0;f[a>>1]=f[a>>1]&-8191;if(!((t[(t[d>>2]|0)+4>>2]|0)>>>4&31)){a=(t[d>>2]|0)+4|0;t[a>>2]=t[a>>2]&-497|16}t[b>>2]=(t[(t[d>>2]|0)+4>>2]&15)+(t[t[v>>2]>>2]|0);a=~~(+((t[b>>2]|0)-1|0)-+Y(+(+((t[b>>2]|0)-1|0)/12))*12+1)>>>0;u=(t[w>>2]|0)+4|0;t[u>>2]=t[u>>2]&-16|a&15;t[b>>2]=~~+Y(+(+((t[b>>2]|0)-1|0)/12));t[t[w>>2]>>2]=(t[t[d>>2]>>2]|0)+(t[b>>2]|0);do if(!(t[t[w>>2]>>2]|0)){a=t[w>>2]|0;u=t[a>>2]|0;if((t[t[d>>2]>>2]|0)>0){t[a>>2]=u+-1;break}else{t[a>>2]=u+1;break}}while(0);u=(t[w>>2]|0)+16|0;f[u>>1]=f[u>>1]&-8191|((f[(t[d>>2]|0)+16>>1]<<3&65535)<<16>>16>>4<<16>>16&4095)<<1&65535;u=(t[w>>2]|0)+16|0;f[u>>1]=f[u>>1]&-2|f[(t[d>>2]|0)+16>>1]&1;l[(t[w>>2]|0)+8>>3]=+l[(t[d>>2]|0)+8>>3]+ +l[(t[v>>2]|0)+8>>3];t[b>>2]=~~+Y(+(+(~~+l[(t[w>>2]|0)+8>>3]|0)/60));if(+l[(t[w>>2]|0)+8>>3]!=0){E=+l[(t[w>>2]|0)+8>>3]-+Y(+(+l[(t[w>>2]|0)+8>>3]/60))*60;l[(t[w>>2]|0)+8>>3]=E}t[b>>2]=(t[b>>2]|0)+((t[(t[d>>2]|0)+4>>2]|0)>>>14&63);u=~~(+(t[b>>2]|0)-+Y(+(+(t[b>>2]|0)/60))*60)>>>0;a=(t[w>>2]|0)+4|0;t[a>>2]=t[a>>2]&-1032193|(u&63)<<14;t[b>>2]=~~+Y(+(+(t[b>>2]|0)/60));t[b>>2]=(t[b>>2]|0)+((t[(t[d>>2]|0)+4>>2]|0)>>>9&31);u=~~(+(t[b>>2]|0)-+Y(+(+(t[b>>2]|0)/24))*24)>>>0;a=(t[w>>2]|0)+4|0;t[a>>2]=t[a>>2]&-15873|(u&31)<<9;t[b>>2]=~~+Y(+(+(t[b>>2]|0)/24));if(((t[t[w>>2]>>2]|0)!=0?(t[(t[w>>2]|0)+4>>2]&15|0)>=1:0)?(t[(t[w>>2]|0)+4>>2]&15|0)<=12:0){u=(t[(t[d>>2]|0)+4>>2]|0)>>>4&31;if(((t[t[w>>2]>>2]|0)%4|0|0)==0?((t[t[w>>2]>>2]|0)%100|0|0)!=0:0)S=23;else if(!((t[t[w>>2]>>2]|0)%400|0))S=23;else g=t[171912+((t[(t[w>>2]|0)+4>>2]&15)-1<<2)>>2]|0;if((S|0)==23)g=t[171864+((t[(t[w>>2]|0)+4>>2]&15)-1<<2)>>2]|0;if(u>>>0>g>>>0){if(((t[t[w>>2]>>2]|0)%4|0|0)==0?((t[t[w>>2]>>2]|0)%100|0|0)!=0:0)S=29;else if(!((t[t[w>>2]>>2]|0)%400|0))S=29;else y=t[171912+((t[(t[w>>2]|0)+4>>2]&15)-1<<2)>>2]|0;if((S|0)==29)y=t[171864+((t[(t[w>>2]|0)+4>>2]&15)-1<<2)>>2]|0;t[k>>2]=y}else S=32}else S=32;do if((S|0)==32)if(((t[(t[d>>2]|0)+4>>2]|0)>>>4&31|0)<1){t[k>>2]=1;break}else{t[k>>2]=(t[(t[d>>2]|0)+4>>2]|0)>>>4&31;break}while(0);t[k>>2]=(t[k>>2]|0)+((t[(t[v>>2]|0)+4>>2]|0)+(t[b>>2]|0));while(1){v=t[w>>2]|0;if((t[k>>2]|0)<1){t[m>>2]=~~(+((t[v+4>>2]&15)-1-1|0)-+Y(+(+((t[(t[w>>2]|0)+4>>2]&15)-1-1|0)/12))*12+1);t[_>>2]=(t[t[w>>2]>>2]|0)+~~+Y(+(+((t[(t[w>>2]|0)+4>>2]&15)-1-1|0)/12));if(!(t[_>>2]|0))t[_>>2]=(t[_>>2]|0)+-1;if((t[m>>2]|0)<1)t[m>>2]=1;if((t[m>>2]|0)>12)t[m>>2]=12;if(((t[_>>2]|0)%4|0|0)==0?((t[_>>2]|0)%100|0|0)!=0:0)S=46;else if(!((t[_>>2]|0)%400|0))S=46;else F=t[171912+((t[m>>2]|0)-1<<2)>>2]|0;if((S|0)==46){S=0;F=t[171864+((t[m>>2]|0)-1<<2)>>2]|0}t[k>>2]=(t[k>>2]|0)+F;t[b>>2]=-1}else{if(!(t[v>>2]|0))break;if((t[(t[w>>2]|0)+4>>2]&15|0)<1)break;if((t[(t[w>>2]|0)+4>>2]&15|0)>12)break;v=t[k>>2]|0;if(((t[t[w>>2]>>2]|0)%4|0|0)==0?((t[t[w>>2]>>2]|0)%100|0|0)!=0:0)S=55;else if(!((t[t[w>>2]>>2]|0)%400|0))S=55;else O=t[171912+((t[(t[w>>2]|0)+4>>2]&15)-1<<2)>>2]|0;if((S|0)==55){S=0;O=t[171864+((t[(t[w>>2]|0)+4>>2]&15)-1<<2)>>2]|0}if((v|0)<=(O|0))break;v=t[k>>2]|0;if(((t[t[w>>2]>>2]|0)%4|0|0)==0?((t[t[w>>2]>>2]|0)%100|0|0)!=0:0)S=61;else if(!((t[t[w>>2]>>2]|0)%400|0))S=61;else A=t[171912+((t[(t[w>>2]|0)+4>>2]&15)-1<<2)>>2]|0;if((S|0)==61){S=0;A=t[171864+((t[(t[w>>2]|0)+4>>2]&15)-1<<2)>>2]|0}t[k>>2]=v-A;t[b>>2]=1}t[h>>2]=(t[(t[w>>2]|0)+4>>2]&15)+(t[b>>2]|0);v=~~(+((t[h>>2]|0)-1|0)-+Y(+(+((t[h>>2]|0)-1|0)/12))*12+1)>>>0;d=(t[w>>2]|0)+4|0;t[d>>2]=t[d>>2]&-16|v&15;v=(t[t[w>>2]>>2]|0)+(~~+Y(+(+((t[h>>2]|0)-1|0)/12))>>>0)|0;t[t[w>>2]>>2]=v;if(t[t[w>>2]>>2]|0)continue;v=t[w>>2]|0;d=t[v>>2]|0;if((t[h>>2]|0)<1){t[v>>2]=d+-1;continue}else{t[v>>2]=d+1;continue}}h=(t[w>>2]|0)+4|0;t[h>>2]=t[h>>2]&-497|(t[k>>2]&31)<<4;do if((t[t[o>>2]>>2]|0)!=11){if((((t[(t[w>>2]|0)+4>>2]|0)>>>9&31|0)==0?((t[(t[w>>2]|0)+4>>2]|0)>>>14&63|0)==0:0)?!(+l[(t[w>>2]|0)+8>>3]!=0):0){if((t[t[o>>2]>>2]|0)==10)break;if((t[(t[w>>2]|0)+4>>2]&15|0)!=1?((t[(t[w>>2]|0)+4>>2]|0)>>>4&31|0)!=1:0){t[t[o>>2]>>2]=10;break}if((t[t[o>>2]>>2]|0)==9)break;if((t[(t[w>>2]|0)+4>>2]&15|0)==1)break;t[t[o>>2]>>2]=9;break}t[t[o>>2]>>2]=11}while(0);MD(t[c>>2]|0);t[n>>2]=t[o>>2];p=t[n>>2]|0;s=r;return p|0}function pC(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,a=0,o=0,c=0,l=0,b=0;r=s;s=s+32|0;n=r+20|0;f=r+16|0;a=r+12|0;o=r+8|0;c=r+4|0;l=r;t[f>>2]=e;t[a>>2]=i;t[o>>2]=t[t[a>>2]>>2];t[c>>2]=0;t[l>>2]=0;if((((u[t[o>>2]>>0]|0|0)>=48?(u[t[o>>2]>>0]|0|0)<=57:0)?(u[(t[o>>2]|0)+1>>0]|0|0)>=48:0)?(u[(t[o>>2]|0)+1>>0]|0|0)<=57:0)t[l>>2]=(((u[t[o>>2]>>0]|0)-48|0)*10|0)+((u[(t[o>>2]|0)+1>>0]|0)-48);else t[c>>2]=1;t[o>>2]=(t[o>>2]|0)+2;if(t[c>>2]|0){t[n>>2]=t[c>>2];b=t[n>>2]|0;s=r;return b|0}if((t[l>>2]|0)>>>0>=1&(t[l>>2]|0)>>>0<=31){c=(t[f>>2]|0)+4|0;t[c>>2]=t[c>>2]&-497|(t[l>>2]&31)<<4;t[t[a>>2]>>2]=t[o>>2];t[n>>2]=0;b=t[n>>2]|0;s=r;return b|0}else{t[n>>2]=2;b=t[n>>2]|0;s=r;return b|0}return 0}function EC(e,i){e=e|0;i=i|0;var r=0,n=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0;r=s;s=s+32|0;n=r+24|0;a=r+20|0;o=r+16|0;c=r+12|0;l=r+8|0;b=r+4|0;k=r;t[a>>2]=e;t[o>>2]=i;t[l>>2]=0;if(!(t[o>>2]|0)){t[n>>2]=-1;h=t[n>>2]|0;s=r;return h|0}t[c>>2]=t[t[o>>2]>>2];i=u[t[c>>2]>>0]|0;do if((i|0)==45|(i|0)==43){t[b>>2]=0;t[k>>2]=0;t[b>>2]=(u[t[c>>2]>>0]|0|0)==45&1;t[c>>2]=(t[c>>2]|0)+1;if((((u[t[c>>2]>>0]|0|0)>=48?(u[t[c>>2]>>0]|0|0)<=57:0)?(u[(t[c>>2]|0)+1>>0]|0|0)>=48:0)?(u[(t[c>>2]|0)+1>>0]|0|0)<=57:0)t[k>>2]=(((u[t[c>>2]>>0]|0)-48|0)*10|0)+((u[(t[c>>2]|0)+1>>0]|0)-48);else t[l>>2]=1;t[c>>2]=(t[c>>2]|0)+2;if(t[l>>2]|0){t[n>>2]=t[l>>2];h=t[n>>2]|0;s=r;return h|0}if(!((t[k>>2]|0)>=0&(t[k>>2]|0)<=23)){t[n>>2]=2;h=t[n>>2]|0;s=r;return h|0}if((u[t[c>>2]>>0]|0|0)!=58){t[n>>2]=1;h=t[n>>2]|0;s=r;return h|0}t[c>>2]=(t[c>>2]|0)+1;e=(t[a>>2]|0)+16|0;f[e>>1]=f[e>>1]&-8191|((t[k>>2]|0)*60&4095)<<1&65535;if((((u[t[c>>2]>>0]|0|0)>=48?(u[t[c>>2]>>0]|0|0)<=57:0)?(u[(t[c>>2]|0)+1>>0]|0|0)>=48:0)?(u[(t[c>>2]|0)+1>>0]|0|0)<=57:0)t[k>>2]=(((u[t[c>>2]>>0]|0)-48|0)*10|0)+((u[(t[c>>2]|0)+1>>0]|0)-48);else t[l>>2]=1;t[c>>2]=(t[c>>2]|0)+2;if(t[l>>2]|0){t[n>>2]=t[l>>2];h=t[n>>2]|0;s=r;return h|0}if(!((t[k>>2]|0)>=0&(t[k>>2]|0)<=59)){t[n>>2]=2;h=t[n>>2]|0;s=r;return h|0}e=(t[a>>2]|0)+16|0;f[e>>1]=f[e>>1]&-8191|(((f[e>>1]<<3&65535)<<16>>16>>4<<16>>16)+(t[k>>2]|0)&4095)<<1&65535;if(t[b>>2]|0){e=(t[a>>2]|0)+16|0;f[e>>1]=f[e>>1]&-8191|(0-((f[(t[a>>2]|0)+16>>1]<<3&65535)<<16>>16>>4<<16>>16)&4095)<<1&65535}if(((f[(t[a>>2]|0)+16>>1]<<3&65535)<<16>>16>>4<<16>>16|0)>-840?((f[(t[a>>2]|0)+16>>1]<<3&65535)<<16>>16>>4<<16>>16|0)<840:0){e=(t[a>>2]|0)+16|0;f[e>>1]=f[e>>1]&-2|1;break}t[n>>2]=2;h=t[n>>2]|0;s=r;return h|0}else if(!i){e=(t[a>>2]|0)+16|0;f[e>>1]=f[e>>1]&-2;e=(t[a>>2]|0)+16|0;f[e>>1]=f[e>>1]&-8191}else if((i|0)==90){
	e=(t[a>>2]|0)+16|0;f[e>>1]=f[e>>1]&-2|1;e=(t[a>>2]|0)+16|0;f[e>>1]=f[e>>1]&-8191;t[c>>2]=(t[c>>2]|0)+1}else{t[n>>2]=1;h=t[n>>2]|0;s=r;return h|0}while(0);t[t[o>>2]>>2]=t[c>>2];t[n>>2]=0;h=t[n>>2]|0;s=r;return h|0}function SC(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,a=0,o=0,c=0,l=0,b=0;r=s;s=s+32|0;n=r+20|0;f=r+16|0;a=r+12|0;o=r+8|0;c=r+4|0;l=r;t[f>>2]=e;t[a>>2]=i;t[o>>2]=t[t[a>>2]>>2];t[c>>2]=0;t[l>>2]=0;if((((u[t[o>>2]>>0]|0|0)>=48?(u[t[o>>2]>>0]|0|0)<=57:0)?(u[(t[o>>2]|0)+1>>0]|0|0)>=48:0)?(u[(t[o>>2]|0)+1>>0]|0|0)<=57:0)t[l>>2]=(((u[t[o>>2]>>0]|0)-48|0)*10|0)+((u[(t[o>>2]|0)+1>>0]|0)-48);else t[c>>2]=1;t[o>>2]=(t[o>>2]|0)+2;if(t[c>>2]|0){t[n>>2]=t[c>>2];b=t[n>>2]|0;s=r;return b|0}if((t[l>>2]|0)>>>0>=1&(t[l>>2]|0)>>>0<=12){c=(t[f>>2]|0)+4|0;t[c>>2]=t[c>>2]&-16|t[l>>2]&15;t[t[a>>2]>>2]=t[o>>2];t[n>>2]=0;b=t[n>>2]|0;s=r;return b|0}else{t[n>>2]=2;b=t[n>>2]|0;s=r;return b|0}return 0}function gC(e,i){e=e|0;i=i|0;var r=0,n=0,a=0,o=0,c=0,b=0,k=0,h=0,w=0;r=s;s=s+32|0;n=r+28|0;a=r+24|0;o=r+20|0;c=r+16|0;b=r+12|0;k=r+8|0;h=r;t[a>>2]=e;t[o>>2]=i;t[c>>2]=t[t[o>>2]>>2];t[b>>2]=0;t[k>>2]=0;if((((u[t[c>>2]>>0]|0|0)>=48?(u[t[c>>2]>>0]|0|0)<=57:0)?(u[(t[c>>2]|0)+1>>0]|0|0)>=48:0)?(u[(t[c>>2]|0)+1>>0]|0|0)<=57:0)t[k>>2]=(((u[t[c>>2]>>0]|0)-48|0)*10|0)+((u[(t[c>>2]|0)+1>>0]|0)-48);else t[b>>2]=1;t[c>>2]=(t[c>>2]|0)+2;if(t[b>>2]|0){t[n>>2]=t[b>>2];w=t[n>>2]|0;s=r;return w|0}if((u[t[c>>2]>>0]|0|0)!=58){t[n>>2]=1;w=t[n>>2]|0;s=r;return w|0}if(!((t[k>>2]|0)>=0&(t[k>>2]|0)<=23)){t[n>>2]=2;w=t[n>>2]|0;s=r;return w|0}t[c>>2]=(t[c>>2]|0)+1;i=(t[a>>2]|0)+4|0;t[i>>2]=t[i>>2]&-15873|(t[k>>2]&31)<<9;if((((u[t[c>>2]>>0]|0|0)>=48?(u[t[c>>2]>>0]|0|0)<=57:0)?(u[(t[c>>2]|0)+1>>0]|0|0)>=48:0)?(u[(t[c>>2]|0)+1>>0]|0|0)<=57:0)t[k>>2]=(((u[t[c>>2]>>0]|0)-48|0)*10|0)+((u[(t[c>>2]|0)+1>>0]|0)-48);else t[b>>2]=1;t[c>>2]=(t[c>>2]|0)+2;if(t[b>>2]|0){t[n>>2]=t[b>>2];w=t[n>>2]|0;s=r;return w|0}if(!((t[k>>2]|0)>=0&(t[k>>2]|0)<=59)){t[n>>2]=2;w=t[n>>2]|0;s=r;return w|0}i=(t[a>>2]|0)+4|0;t[i>>2]=t[i>>2]&-1032193|(t[k>>2]&63)<<14;if((u[t[c>>2]>>0]|0|0)!=58){t[n>>2]=1;w=t[n>>2]|0;s=r;return w|0}t[c>>2]=(t[c>>2]|0)+1;if((((u[t[c>>2]>>0]|0|0)>=48?(u[t[c>>2]>>0]|0|0)<=57:0)?(u[(t[c>>2]|0)+1>>0]|0|0)>=48:0)?(u[(t[c>>2]|0)+1>>0]|0|0)<=57:0)l[(t[a>>2]|0)+8>>3]=+((((u[t[c>>2]>>0]|0)-48|0)*10|0)+((u[(t[c>>2]|0)+1>>0]|0)-48)|0);else t[b>>2]=1;t[c>>2]=(t[c>>2]|0)+2;e:do if((t[b>>2]|0)==0?(u[t[c>>2]>>0]|0|0)==46:0){l[h>>3]=1;t[c>>2]=(t[c>>2]|0)+1;if(!((u[t[c>>2]>>0]|0|0)>=48?(u[t[c>>2]>>0]|0|0)<=57:0))t[b>>2]=1;while(1){if((u[t[c>>2]>>0]|0|0)<48)break e;if((u[t[c>>2]>>0]|0|0)>57)break e;l[h>>3]=+l[h>>3]/10;k=(t[a>>2]|0)+8|0;l[k>>3]=+l[k>>3]+ +((u[t[c>>2]>>0]|0)-48|0)*+l[h>>3];t[c>>2]=(t[c>>2]|0)+1}}while(0);if(t[b>>2]|0){t[n>>2]=t[b>>2];w=t[n>>2]|0;s=r;return w|0}if(((+l[(t[a>>2]|0)+8>>3]>=0?+l[(t[a>>2]|0)+8>>3]<60:0)?((f[(t[a>>2]|0)+16>>1]<<3&65535)<<16>>16>>4<<16>>16|0)>-840:0)?((f[(t[a>>2]|0)+16>>1]<<3&65535)<<16>>16>>4<<16>>16|0)<840:0){t[t[o>>2]>>2]=t[c>>2];t[n>>2]=0;w=t[n>>2]|0;s=r;return w|0}t[n>>2]=2;w=t[n>>2]|0;s=r;return w|0}function yC(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0;r=s;s=s+32|0;n=r+24|0;f=r+20|0;a=r+16|0;o=r+12|0;c=r+8|0;l=r+4|0;b=r;t[f>>2]=e;t[a>>2]=i;t[o>>2]=t[t[a>>2]>>2];t[l>>2]=0;t[b>>2]=0;if(!((u[t[o>>2]>>0]|0|0)>=48?(u[t[o>>2]>>0]|0|0)<=57:0))k=3;if(((k|0)==3?(u[t[o>>2]>>0]|0|0)!=45:0)?(u[t[o>>2]>>0]|0|0)!=43:0){t[n>>2]=-1;h=t[n>>2]|0;s=r;return h|0}if((u[t[o>>2]>>0]|0|0)==45){t[l>>2]=1;t[o>>2]=(t[o>>2]|0)+1}t[c>>2]=t[o>>2];while(1){if((u[t[o>>2]>>0]|0|0)<48)break;if((u[t[o>>2]>>0]|0|0)>57)break;t[t[f>>2]>>2]=((t[t[f>>2]>>2]|0)*10|0)+((u[t[o>>2]>>0]|0)-48);t[o>>2]=(t[o>>2]|0)+1;t[b>>2]=(t[b>>2]|0)+1}do if((t[b>>2]|0)>=4){if((t[b>>2]|0)>4?(u[t[c>>2]>>0]|0|0)==48:0)break;if(t[l>>2]|0)t[t[f>>2]>>2]=0-(t[t[f>>2]>>2]|0);if(t[t[f>>2]>>2]|0){t[t[a>>2]>>2]=t[o>>2];t[n>>2]=0;h=t[n>>2]|0;s=r;return h|0}else{t[n>>2]=2;h=t[n>>2]|0;s=r;return h|0}}while(0);t[n>>2]=1;h=t[n>>2]|0;s=r;return h|0}function FC(e){e=e|0;var i=0,r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0;i=s;s=s+16|0;r=i+8|0;n=i+4|0;f=i;t[r>>2]=e;e=t[(t[r>>2]|0)+12>>2]&15;t[f>>2]=e;t[f>>2]=(t[f>>2]|0)<=0?1:e;e=t[(t[r>>2]|0)+8>>2]|0;if((t[(t[r>>2]|0)+8>>2]|0)<=0){u=(e*365|0)+((((t[(t[r>>2]|0)+8>>2]|0)+1|0)/4|0)-(((t[(t[r>>2]|0)+8>>2]|0)+1|0)/100|0)+(((t[(t[r>>2]|0)+8>>2]|0)+1|0)/400|0))|0;if(((t[(t[r>>2]|0)+8>>2]|0)%4|0|0)==0?((t[(t[r>>2]|0)+8>>2]|0)%100|0|0)!=0:0)a=5;else if(!((t[(t[r>>2]|0)+8>>2]|0)%400|0))a=5;else o=t[172072+((t[f>>2]|0)-1<<2)>>2]|0;if((a|0)==5)o=t[172024+((t[f>>2]|0)-1<<2)>>2]|0;t[n>>2]=u+(o+0);c=t[n>>2]|0;s=i;return c|0}else{o=((e-1|0)*365|0)+((((t[(t[r>>2]|0)+8>>2]|0)-1|0)/4|0)-(((t[(t[r>>2]|0)+8>>2]|0)-1|0)/100|0)+(((t[(t[r>>2]|0)+8>>2]|0)-1|0)/400|0))|0;if(((t[(t[r>>2]|0)+8>>2]|0)%4|0|0)==0?((t[(t[r>>2]|0)+8>>2]|0)%100|0|0)!=0:0)a=11;else if(!((t[(t[r>>2]|0)+8>>2]|0)%400|0))a=11;else l=t[172072+((t[f>>2]|0)-1<<2)>>2]|0;if((a|0)==11)l=t[172024+((t[f>>2]|0)-1<<2)>>2]|0;t[n>>2]=o+(l+0);c=t[n>>2]|0;s=i;return c|0}return 0}function OC(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if((t[r>>2]|0)>=65792)n=(t[r>>2]|0)<=65855;else n=0;s=i;return n&1|0}function AC(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if((t[r>>2]|0)>=64256)n=(t[r>>2]|0)<=64335;else n=0;s=i;return n&1|0}function MC(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if((t[r>>2]|0)>=1536)n=(t[r>>2]|0)<=1791;else n=0;s=i;return n&1|0}function RC(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if((t[r>>2]|0)>=64336)n=(t[r>>2]|0)<=65023;else n=0;s=i;return n&1|0}function NC(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if((t[r>>2]|0)>=65136)n=(t[r>>2]|0)<=65279;else n=0;s=i;return n&1|0}function TC(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if((t[r>>2]|0)>=1328)n=(t[r>>2]|0)<=1423;else n=0;s=i;return n&1|0}function LC(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if((t[r>>2]|0)>=8592)n=(t[r>>2]|0)<=8703;else n=0;s=i;return n&1|0}function DC(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if((t[r>>2]|0)>=0)n=(t[r>>2]|0)<=127;else n=0;s=i;return n&1|0}function CC(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if((t[r>>2]|0)>=2432)n=(t[r>>2]|0)<=2559;else n=0;s=i;return n&1|0}function PC(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if((t[r>>2]|0)>=9600)n=(t[r>>2]|0)<=9631;else n=0;s=i;return n&1|0}function BC(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if((t[r>>2]|0)>=12544)n=(t[r>>2]|0)<=12591;else n=0;s=i;return n&1|0}function IC(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if((t[r>>2]|0)>=12704)n=(t[r>>2]|0)<=12735;else n=0;s=i;return n&1|0}function HC(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if((t[r>>2]|0)>=9472)n=(t[r>>2]|0)<=9599;else n=0;s=i;return n&1|0}function xC(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if((t[r>>2]|0)>=10240)n=(t[r>>2]|0)<=10495;else n=0;s=i;return n&1|0}function UC(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if((t[r>>2]|0)>=5952)n=(t[r>>2]|0)<=5983;else n=0;s=i;return n&1|0}function zC(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if((t[r>>2]|0)>=118784)n=(t[r>>2]|0)<=119039;else n=0;s=i;return n&1|0}function jC(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if((t[r>>2]|0)>=13056)n=(t[r>>2]|0)<=13311;else n=0;s=i;return n&1|0}function VC(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if((t[r>>2]|0)>=65072)n=(t[r>>2]|0)<=65103;else n=0;s=i;return n&1|0}function qC(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if((t[r>>2]|0)>=63744)n=(t[r>>2]|0)<=64255;else n=0;s=i;return n&1|0}function YC(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if((t[r>>2]|0)>=194560)n=(t[r>>2]|0)<=195103;else n=0;s=i;return n&1|0}function GC(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if((t[r>>2]|0)>=11904)n=(t[r>>2]|0)<=12031;else n=0;s=i;return n&1|0}function WC(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if((t[r>>2]|0)>=12288)n=(t[r>>2]|0)<=12351;else n=0;s=i;return n&1|0}function KC(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if((t[r>>2]|0)>=19968)n=(t[r>>2]|0)<=40959;else n=0;s=i;return n&1|0}function XC(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if((t[r>>2]|0)>=13312)n=(t[r>>2]|0)<=19903;else n=0;s=i;return n&1|0}function ZC(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if((t[r>>2]|0)>=131072)n=(t[r>>2]|0)<=173791;else n=0;s=i;return n&1|0}function JC(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if((t[r>>2]|0)>=5024)n=(t[r>>2]|0)<=5119;else n=0;s=i;return n&1|0}function QC(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if((t[r>>2]|0)>=768)n=(t[r>>2]|0)<=879;else n=0;s=i;return n&1|0}function $C(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if((t[r>>2]|0)>=8400)n=(t[r>>2]|0)<=8447;else n=0;s=i;return n&1|0}function eP(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if((t[r>>2]|0)>=65056)n=(t[r>>2]|0)<=65071;else n=0;s=i;return n&1|0}function iP(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if((t[r>>2]|0)>=8400)n=(t[r>>2]|0)<=8447;else n=0;s=i;return n&1|0}function rP(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if((t[r>>2]|0)>=9216)n=(t[r>>2]|0)<=9279;else n=0;s=i;return n&1|0}function nP(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if((t[r>>2]|0)>=8352)n=(t[r>>2]|0)<=8399;else n=0;s=i;return n&1|0}function fP(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if((t[r>>2]|0)>=67584)n=(t[r>>2]|0)<=67647;else n=0;s=i;return n&1|0}function tP(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if((t[r>>2]|0)>=1024)n=(t[r>>2]|0)<=1279;else n=0;s=i;return n&1|0}function uP(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if((t[r>>2]|0)>=1280)n=(t[r>>2]|0)<=1327;else n=0;s=i;return n&1|0}function aP(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if((t[r>>2]|0)>=66560)n=(t[r>>2]|0)<=66639;else n=0;s=i;return n&1|0}function oP(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if((t[r>>2]|0)>=2304)n=(t[r>>2]|0)<=2431;else n=0;s=i;return n&1|0}function cP(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if((t[r>>2]|0)>=9984)n=(t[r>>2]|0)<=10175;else n=0;s=i;return n&1|0}function lP(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if((t[r>>2]|0)>=9312)n=(t[r>>2]|0)<=9471;else n=0;s=i;return n&1|0}function sP(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if((t[r>>2]|0)>=12800)n=(t[r>>2]|0)<=13055;else n=0;s=i;return n&1|0}function bP(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if((t[r>>2]|0)>=4608)n=(t[r>>2]|0)<=4991;else n=0;s=i;return n&1|0}function kP(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if((t[r>>2]|0)>=8192)n=(t[r>>2]|0)<=8303;else n=0;s=i;return n&1|0}function hP(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if((t[r>>2]|0)>=9632)n=(t[r>>2]|0)<=9727;else n=0;s=i;return n&1|0}function wP(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if((t[r>>2]|0)>=4256)n=(t[r>>2]|0)<=4351;else n=0;s=i;return n&1|0}function dP(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if((t[r>>2]|0)>=66352)n=(t[r>>2]|0)<=66383;else n=0;s=i;return n&1|0}function vP(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if((t[r>>2]|0)>=880)n=(t[r>>2]|0)<=1023;else n=0;s=i;return n&1|0}function mP(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if((t[r>>2]|0)>=7936)n=(t[r>>2]|0)<=8191;else n=0;s=i;return n&1|0}function _P(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if((t[r>>2]|0)>=880)n=(t[r>>2]|0)<=1023;else n=0;s=i;return n&1|0}function pP(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if((t[r>>2]|0)>=2688)n=(t[r>>2]|0)<=2815;else n=0;s=i;return n&1|0}function EP(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if((t[r>>2]|0)>=2560)n=(t[r>>2]|0)<=2687;else n=0;s=i;return n&1|0}function SP(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if((t[r>>2]|0)>=65280)n=(t[r>>2]|0)<=65519;else n=0;s=i;return n&1|0}function gP(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if((t[r>>2]|0)>=12592)n=(t[r>>2]|0)<=12687;else n=0;s=i;return n&1|0}function yP(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if((t[r>>2]|0)>=4352)n=(t[r>>2]|0)<=4607;else n=0;s=i;return n&1|0}function FP(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if((t[r>>2]|0)>=44032)n=(t[r>>2]|0)<=55215;else n=0;s=i;return n&1|0}function OP(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if((t[r>>2]|0)>=5920)n=(t[r>>2]|0)<=5951;else n=0;s=i;return n&1|0}function AP(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if((t[r>>2]|0)>=1424)n=(t[r>>2]|0)<=1535;else n=0;s=i;return n&1|0}function MP(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if((t[r>>2]|0)>=56192)n=(t[r>>2]|0)<=56319;else n=0;s=i;return n&1|0}function RP(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if((t[r>>2]|0)>=55296)n=(t[r>>2]|0)<=56191;else n=0;s=i;return n&1|0}function NP(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if((t[r>>2]|0)>=12352)n=(t[r>>2]|0)<=12447;else n=0;s=i;return n&1|0}function TP(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if((t[r>>2]|0)>=592)n=(t[r>>2]|0)<=687;else n=0;s=i;return n&1|0}function LP(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if((t[r>>2]|0)>=12272)n=(t[r>>2]|0)<=12287;else n=0;s=i;return n&1|0}function DP(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if((t[r>>2]|0)>=12688)n=(t[r>>2]|0)<=12703;else n=0;s=i;return n&1|0}function CP(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if((t[r>>2]|0)>=12032)n=(t[r>>2]|0)<=12255;else n=0;s=i;return n&1|0}function PP(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if((t[r>>2]|0)>=3200)n=(t[r>>2]|0)<=3327;else n=0;s=i;return n&1|0}function BP(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if((t[r>>2]|0)>=12448)n=(t[r>>2]|0)<=12543;else n=0;s=i;return n&1|0}function IP(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if((t[r>>2]|0)>=12784)n=(t[r>>2]|0)<=12799;else n=0;s=i;return n&1|0}function HP(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if((t[r>>2]|0)>=6016)n=(t[r>>2]|0)<=6143;else n=0;s=i;return n&1|0}function xP(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if((t[r>>2]|0)>=6624)n=(t[r>>2]|0)<=6655;else n=0;s=i;return n&1|0}function UP(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if((t[r>>2]|0)>=3712)n=(t[r>>2]|0)<=3839;else n=0;s=i;return n&1|0}function zP(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if((t[r>>2]|0)>=128)n=(t[r>>2]|0)<=255;else n=0;s=i;return n&1|0}function jP(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if((t[r>>2]|0)>=256)n=(t[r>>2]|0)<=383;else n=0;s=i;return n&1|0}function VP(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if((t[r>>2]|0)>=384)n=(t[r>>2]|0)<=591;else n=0;s=i;return n&1|0}function qP(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if((t[r>>2]|0)>=7680)n=(t[r>>2]|0)<=7935;else n=0;s=i;return n&1|0}function YP(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if((t[r>>2]|0)>=8448)n=(t[r>>2]|0)<=8527;else n=0;s=i;return n&1|0}function GP(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if((t[r>>2]|0)>=6400)n=(t[r>>2]|0)<=6479;else n=0;s=i;return n&1|0}function WP(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if((t[r>>2]|0)>=65664)n=(t[r>>2]|0)<=65791;else n=0;s=i;return n&1|0}function KP(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if((t[r>>2]|0)>=65536)n=(t[r>>2]|0)<=65663;else n=0;s=i;return n&1|0}function XP(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if((t[r>>2]|0)>=56320)n=(t[r>>2]|0)<=57343;else n=0;s=i;return n&1|0}function ZP(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if((t[r>>2]|0)>=3328)n=(t[r>>2]|0)<=3455;else n=0;s=i;return n&1|0}function JP(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if((t[r>>2]|0)>=119808)n=(t[r>>2]|0)<=120831;else n=0;s=i;return n&1|0}function QP(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if((t[r>>2]|0)>=8704)n=(t[r>>2]|0)<=8959;else n=0;s=i;return n&1|0}function $P(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if((t[r>>2]|0)>=10176)n=(t[r>>2]|0)<=10223;else n=0;s=i;return n&1|0}function eB(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if((t[r>>2]|0)>=10624)n=(t[r>>2]|0)<=10751;else n=0;s=i;return n&1|0}function iB(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if((t[r>>2]|0)>=9728)n=(t[r>>2]|0)<=9983;else n=0;s=i;return n&1|0}function rB(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if((t[r>>2]|0)>=11008)n=(t[r>>2]|0)<=11263;else n=0;s=i;return n&1|0}function nB(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if((t[r>>2]|0)>=8960)n=(t[r>>2]|0)<=9215;else n=0;s=i;return n&1|0}function fB(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if((t[r>>2]|0)>=6144)n=(t[r>>2]|0)<=6319;else n=0;s=i;return n&1|0}function tB(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if((t[r>>2]|0)>=119040)n=(t[r>>2]|0)<=119295;else n=0;s=i;return n&1|0}function uB(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if((t[r>>2]|0)>=4096)n=(t[r>>2]|0)<=4255;else n=0;s=i;return n&1|0}function aB(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if((t[r>>2]|0)>=8528)n=(t[r>>2]|0)<=8591;else n=0;s=i;return n&1|0}function oB(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if((t[r>>2]|0)>=5760)n=(t[r>>2]|0)<=5791;else n=0;s=i;return n&1|0}function cB(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if((t[r>>2]|0)>=66304)n=(t[r>>2]|0)<=66351;else n=0;s=i;return n&1|0}function lB(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if((t[r>>2]|0)>=9280)n=(t[r>>2]|0)<=9311;else n=0;s=i;return n&1|0}function sB(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if((t[r>>2]|0)>=2816)n=(t[r>>2]|0)<=2943;else n=0;s=i;return n&1|0}function bB(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if((t[r>>2]|0)>=66688)n=(t[r>>2]|0)<=66735;else n=0;s=i;return n&1|0}function kB(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if((t[r>>2]|0)>=7424)n=(t[r>>2]|0)<=7551;else n=0;s=i;return n&1|0}function hB(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if(!((t[r>>2]|0)>=57344&(t[r>>2]|0)<=63743)?!((t[r>>2]|0)>=983040&(t[r>>2]|0)<=1048575):0)if((t[r>>2]|0)>=1048576)n=(t[r>>2]|0)<=1114111;else n=0;else n=1;s=i;return n&1|0}function wB(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if((t[r>>2]|0)>=57344)n=(t[r>>2]|0)<=63743;else n=0;s=i;return n&1|0}function dB(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if((t[r>>2]|0)>=5792)n=(t[r>>2]|0)<=5887;else n=0;s=i;return n&1|0}function vB(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if((t[r>>2]|0)>=66640)n=(t[r>>2]|0)<=66687;else n=0;s=i;return n&1|0}function mB(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if((t[r>>2]|0)>=3456)n=(t[r>>2]|0)<=3583;else n=0;s=i;return n&1|0}function _B(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if((t[r>>2]|0)>=65104)n=(t[r>>2]|0)<=65135;else n=0;s=i;return n&1|0}function pB(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if((t[r>>2]|0)>=688)n=(t[r>>2]|0)<=767;else n=0;s=i;return n&1|0}function EB(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if((t[r>>2]|0)>=65520)n=(t[r>>2]|0)<=65535;else n=0;s=i;return n&1|0}function SB(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if((t[r>>2]|0)>=8304)n=(t[r>>2]|0)<=8351;else n=0;s=i;return n&1|0}function gB(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if((t[r>>2]|0)>=10224)n=(t[r>>2]|0)<=10239;else n=0;s=i;return n&1|0}function yB(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if((t[r>>2]|0)>=10496)n=(t[r>>2]|0)<=10623;else n=0;s=i;return n&1|0}function FB(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if((t[r>>2]|0)>=10752)n=(t[r>>2]|0)<=11007;else n=0;s=i;return n&1|0}function OB(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if((t[r>>2]|0)>=983040)n=(t[r>>2]|0)<=1048575;else n=0;s=i;return n&1|0}function AB(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if((t[r>>2]|0)>=1048576)n=(t[r>>2]|0)<=1114111;else n=0;s=i;return n&1|0}function MB(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if((t[r>>2]|0)>=1792)n=(t[r>>2]|0)<=1871;else n=0;s=i;return n&1|0}function RB(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if((t[r>>2]|0)>=5888)n=(t[r>>2]|0)<=5919;else n=0;s=i;return n&1|0}function NB(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if((t[r>>2]|0)>=5984)n=(t[r>>2]|0)<=6015;else n=0;s=i;return n&1|0}function TB(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if((t[r>>2]|0)>=917504)n=(t[r>>2]|0)<=917631;else n=0;s=i;return n&1|0}function LB(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if((t[r>>2]|0)>=6480)n=(t[r>>2]|0)<=6527;else n=0;s=i;return n&1|0}function DB(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if((t[r>>2]|0)>=119552)n=(t[r>>2]|0)<=119647;else n=0;s=i;return n&1|0}function CB(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if((t[r>>2]|0)>=2944)n=(t[r>>2]|0)<=3071;else n=0;s=i;return n&1|0}function PB(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if((t[r>>2]|0)>=3072)n=(t[r>>2]|0)<=3199;else n=0;s=i;return n&1|0}function BB(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if((t[r>>2]|0)>=1920)n=(t[r>>2]|0)<=1983;else n=0;s=i;return n&1|0}function IB(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if((t[r>>2]|0)>=3584)n=(t[r>>2]|0)<=3711;else n=0;s=i;return n&1|0}function HB(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if((t[r>>2]|0)>=3840)n=(t[r>>2]|0)<=4095;else n=0;s=i;return n&1|0}function xB(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if((t[r>>2]|0)>=66432)n=(t[r>>2]|0)<=66463;else n=0;s=i;return n&1|0}function UB(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if((t[r>>2]|0)>=5120)n=(t[r>>2]|0)<=5759;else n=0;s=i;return n&1|0}function zB(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if((t[r>>2]|0)>=65024)n=(t[r>>2]|0)<=65039;else n=0;s=i;return n&1|0}function jB(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if((t[r>>2]|0)>=917760)n=(t[r>>2]|0)<=917999;else n=0;s=i;return n&1|0}function VB(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if((t[r>>2]|0)>=42128)n=(t[r>>2]|0)<=42191;else n=0;s=i;return n&1|0}function qB(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if((t[r>>2]|0)>=40960)n=(t[r>>2]|0)<=42127;else n=0;s=i;return n&1|0}function YB(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if((t[r>>2]|0)>=19904)n=(t[r>>2]|0)<=19967;else n=0;s=i;return n&1|0}function GB(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0;r=s;s=s+16|0;n=r+12|0;f=r+8|0;u=r+4|0;a=r;t[f>>2]=e;t[u>>2]=i;t[a>>2]=MI(172456,t[u>>2]|0)|0;if(!(t[a>>2]|0)){t[n>>2]=-1;o=t[n>>2]|0;s=r;return o|0}else{t[n>>2]=gAi[t[a>>2]&511](t[f>>2]|0)|0;o=t[n>>2]|0;s=r;return o|0}return 0}function WB(e){e=e|0;var i=0,r=0;i=s;s=s+16|0;r=i;t[r>>2]=e;e=dj(t[r>>2]|0,172464)|0;s=i;return e|0}function KB(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if(!((t[r>>2]|0)>=0&(t[r>>2]|0)<=31))if((t[r>>2]|0)>=127)n=(t[r>>2]|0)<=159;else n=0;else n=1;s=i;return n&1|0}function XB(e){e=e|0;var i=0,r=0;i=s;s=s+16|0;r=i;t[r>>2]=e;e=dj(t[r>>2]|0,172480)|0;s=i;return e|0}function ZB(e){e=e|0;var i=0,r=0,n=0,f=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if((t[r>>2]|0)==57344|(t[r>>2]|0)==63743|(t[r>>2]|0)==983040|(t[r>>2]|0)==1048573|(t[r>>2]|0)==1048576){n=1;f=n&1;s=i;return f|0}n=(t[r>>2]|0)==1114109;f=n&1;s=i;return f|0}function JB(e){e=e|0;var i=0,r=0;i=s;s=s+16|0;r=i;t[r>>2]=e;e=dj(t[r>>2]|0,172496)|0;s=i;return e|0}function QB(e){e=e|0;var i=0,r=0;i=s;s=s+16|0;r=i;t[r>>2]=e;e=dj(t[r>>2]|0,172512)|0;s=i;return e|0}function $B(e){e=e|0;var i=0,r=0;i=s;s=s+16|0;r=i;t[r>>2]=e;e=dj(t[r>>2]|0,172528)|0;s=i;return e|0}function eI(e){e=e|0;var i=0,r=0;i=s;s=s+16|0;r=i;t[r>>2]=e;e=dj(t[r>>2]|0,172544)|0;s=i;return e|0}function iI(e){e=e|0;var i=0,r=0;i=s;s=s+16|0;r=i;t[r>>2]=e;e=dj(t[r>>2]|0,172560)|0;s=i;return e|0}function rI(e){e=e|0;var i=0,r=0;i=s;s=s+16|0;r=i;t[r>>2]=e;e=dj(t[r>>2]|0,172576)|0;s=i;return e|0}function nI(e){e=e|0;var i=0,r=0;i=s;s=s+16|0;r=i;t[r>>2]=e;e=dj(t[r>>2]|0,172592)|0;s=i;return e|0}function fI(e){e=e|0;var i=0,r=0;i=s;s=s+16|0;r=i;t[r>>2]=e;e=dj(t[r>>2]|0,172608)|0;s=i;return e|0}function tI(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if(!((t[r>>2]|0)>=1160&(t[r>>2]|0)<=1161|(t[r>>2]|0)==1758)?!((t[r>>2]|0)>=8413&(t[r>>2]|0)<=8416):0)if((t[r>>2]|0)>=8418)n=(t[r>>2]|0)<=8420;else n=0;else n=1;s=i;return n&1|0}function uI(e){e=e|0;var i=0,r=0;i=s;s=s+16|0;r=i;t[r>>2]=e;e=dj(t[r>>2]|0,172624)|0;s=i;return e|0}function aI(e){e=e|0;var i=0,r=0;i=s;s=s+16|0;r=i;t[r>>2]=e;e=dj(t[r>>2]|0,172640)|0;s=i;return e|0}function oI(e){e=e|0;var i=0,r=0;i=s;s=s+16|0;r=i;t[r>>2]=e;e=dj(t[r>>2]|0,172656)|0;s=i;return e|0}function cI(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if(((!((t[r>>2]|0)>=5870&(t[r>>2]|0)<=5872)?!((t[r>>2]|0)>=8544&(t[r>>2]|0)<=8579|(t[r>>2]|0)==12295):0)?!((t[r>>2]|0)>=12321&(t[r>>2]|0)<=12329):0)?!((t[r>>2]|0)>=12344&(t[r>>2]|0)<=12346):0)n=(t[r>>2]|0)==66378;else n=1;s=i;return n&1|0}function lI(e){e=e|0;var i=0,r=0;i=s;s=s+16|0;r=i;t[r>>2]=e;e=dj(t[r>>2]|0,172672)|0;s=i;return e|0}function sI(e){e=e|0;var i=0,r=0;i=s;s=s+16|0;r=i;t[r>>2]=e;e=dj(t[r>>2]|0,172688)|0;s=i;return e|0}function bI(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if((((t[r>>2]|0)!=95?!((t[r>>2]|0)>=8255&(t[r>>2]|0)<=8256|(t[r>>2]|0)==8276|(t[r>>2]|0)==12539):0)?!((t[r>>2]|0)>=65075&(t[r>>2]|0)<=65076):0)?!((t[r>>2]|0)>=65101&(t[r>>2]|0)<=65103|(t[r>>2]|0)==65343):0)n=(t[r>>2]|0)==65381;else n=1;s=i;return n&1|0}function kI(e){e=e|0;var i=0,r=0;i=s;s=s+16|0;r=i;t[r>>2]=e;e=dj(t[r>>2]|0,172704)|0;s=i;return e|0}function hI(e){e=e|0;var i=0,r=0;i=s;s=s+16|0;r=i;t[r>>2]=e;e=dj(t[r>>2]|0,172720)|0;s=i;return e|0}function wI(e){e=e|0;var i=0,r=0,n=0,f=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if((t[r>>2]|0)==187|(t[r>>2]|0)==8217|(t[r>>2]|0)==8221){n=1;f=n&1;s=i;return f|0}n=(t[r>>2]|0)==8250;f=n&1;s=i;return f|0}function dI(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if(!((t[r>>2]|0)==171|(t[r>>2]|0)==8216)?!((t[r>>2]|0)>=8219&(t[r>>2]|0)<=8220|(t[r>>2]|0)==8223):0)n=(t[r>>2]|0)==8249;else n=1;s=i;return n&1|0}function vI(e){e=e|0;var i=0,r=0;i=s;s=s+16|0;r=i;t[r>>2]=e;e=dj(t[r>>2]|0,172736)|0;s=i;return e|0}function mI(e){e=e|0;var i=0,r=0;i=s;s=s+16|0;r=i;t[r>>2]=e;e=dj(t[r>>2]|0,172752)|0;s=i;return e|0}function _I(e){e=e|0;var i=0,r=0;i=s;s=s+16|0;r=i;t[r>>2]=e;e=dj(t[r>>2]|0,172768)|0;s=i;return e|0}function pI(e){e=e|0;var i=0,r=0;i=s;s=s+16|0;r=i;t[r>>2]=e;e=dj(t[r>>2]|0,172784)|0;s=i;return e|0}function EI(e){e=e|0;var i=0,r=0;i=s;s=s+16|0;r=i;t[r>>2]=e;e=dj(t[r>>2]|0,172800)|0;s=i;return e|0}function SI(e){e=e|0;var i=0,r=0;i=s;s=s+16|0;r=i;t[r>>2]=e;e=dj(t[r>>2]|0,172816)|0;s=i;return e|0}function gI(e){e=e|0;var i=0,r=0;i=s;s=s+16|0;r=i;t[r>>2]=e;e=dj(t[r>>2]|0,172832)|0;s=i;return e|0}function yI(e){e=e|0;var i=0,r=0;i=s;s=s+16|0;r=i;t[r>>2]=e;e=dj(t[r>>2]|0,172848)|0;s=i;return e|0}function FI(e){e=e|0;var i=0,r=0;i=s;s=s+16|0;r=i;t[r>>2]=e;s=i;return(t[r>>2]|0)==8232|0}function OI(e){e=e|0;var i=0,r=0;i=s;s=s+16|0;r=i;t[r>>2]=e;s=i;return(t[r>>2]|0)==8233|0}function AI(e){e=e|0;var i=0,r=0,n=0,f=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if((t[r>>2]|0)==32|(t[r>>2]|0)==160|(t[r>>2]|0)==5760|(t[r>>2]|0)==6158){n=1;f=n&1;s=i;return f|0}if((t[r>>2]|0)>=8192&(t[r>>2]|0)<=8202|(t[r>>2]|0)==8239|(t[r>>2]|0)==8287){n=1;f=n&1;s=i;return f|0}n=(t[r>>2]|0)==12288;f=n&1;s=i;return f|0}function MI(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0;r=s;s=s+32|0;n=r+28|0;f=r+24|0;u=r+20|0;a=r+16|0;o=r+12|0;c=r+8|0;l=r+4|0;b=r;t[f>>2]=e;t[u>>2]=i;if((t[f>>2]|0)==0|(t[u>>2]|0)==0){t[n>>2]=0;k=t[n>>2]|0;s=r;return k|0}t[a>>2]=0;t[o>>2]=(t[(t[f>>2]|0)+4>>2]|0)-1;t[b>>2]=t[t[f>>2]>>2];while(1){if((t[a>>2]|0)>(t[o>>2]|0)){h=10;break}t[c>>2]=((t[a>>2]|0)+(t[o>>2]|0)|0)/2|0;f=MY(t[u>>2]|0,t[(t[b>>2]|0)+(t[c>>2]<<3)>>2]|0)|0;t[l>>2]=f;if(!f){h=6;break}f=t[c>>2]|0;if((t[l>>2]|0)<0){t[o>>2]=f-1;continue}else{t[a>>2]=f+1;continue}}if((h|0)==6){t[n>>2]=t[(t[b>>2]|0)+(t[c>>2]<<3)+4>>2];k=t[n>>2]|0;s=r;return k|0}else if((h|0)==10){t[n>>2]=0;k=t[n>>2]|0;s=r;return k|0}return 0}function RI(e){e=e|0;var i=0,r=0,n=0,f=0,u=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0;i=s;s=s+48|0;r=i+36|0;n=i+32|0;f=i+28|0;u=i+24|0;o=i+20|0;c=i+16|0;l=i+12|0;b=i+8|0;k=i+4|0;h=i;t[n>>2]=e;t[u>>2]=0;t[o>>2]=0;t[c>>2]=0;if(!(t[n>>2]|0)){t[r>>2]=-1;w=t[r>>2]|0;s=i;return w|0}t[(t[n>>2]|0)+68>>2]=0;e=t[n>>2]|0;if(t[(t[n>>2]|0)+4>>2]|0){t[r>>2]=$I(e)|0;w=t[r>>2]|0;s=i;return w|0}if(!(t[e+20>>2]|0)){t[r>>2]=-1;w=t[r>>2]|0;s=i;return w|0}e=t[n>>2]|0;if(!(t[t[n>>2]>>2]|0)){t[e>>2]=1;do{t[f>>2]=eH(t[n>>2]|0)|0;d=t[n>>2]|0;if((t[f>>2]|0)<0){v=10;break}if(t[(t[d+20>>2]|0)+52>>2]|0)break;if((t[t[n>>2]>>2]|0)==3)break}while((t[(t[n>>2]|0)+16>>2]|0)!=5);if((v|0)==10){t[d>>2]=2;t[(t[n>>2]|0)+16>>2]=6;t[r>>2]=-1;w=t[r>>2]|0;s=i;return w|0}d=(t[(t[(t[n>>2]|0)+20>>2]|0)+8>>2]|0)!=0;do if(!(t[(t[(t[n>>2]|0)+20>>2]|0)+52>>2]|0)){if(d)t[(t[n>>2]|0)+64>>2]=t[(t[(t[(t[n>>2]|0)+20>>2]|0)+8>>2]|0)+12>>2];m=t[n>>2]|0;if(t[(t[n>>2]|0)+64>>2]|0){t[m+16>>2]=1;break}t[m>>2]=2;t[(t[n>>2]|0)+16>>2]=6;t[r>>2]=-1;w=t[r>>2]|0;s=i;return w|0}else{if(d)t[(t[n>>2]|0)+64>>2]=t[(t[(t[(t[n>>2]|0)+20>>2]|0)+8>>2]|0)+12>>2];if(!(t[(t[n>>2]|0)+64>>2]|0))t[(t[n>>2]|0)+64>>2]=t[t[(t[(t[n>>2]|0)+20>>2]|0)+64>>2]>>2];t[(t[n>>2]|0)+16>>2]=1}while(0);t[(t[n>>2]|0)+72>>2]=0;t[(t[(t[n>>2]|0)+20>>2]|0)+436>>2]=5;v=108}else{t[o>>2]=t[e+16>>2];t[u>>2]=t[(t[(t[n>>2]|0)+20>>2]|0)+56>>2];t[c>>2]=t[(t[n>>2]|0)+64>>2]}e:while(1){if((v|0)==108){v=0;do if((t[(t[n>>2]|0)+64>>2]|0)!=0?(t[(t[(t[n>>2]|0)+64>>2]|0)+24>>2]|0)==0:0){if((t[(t[(t[n>>2]|0)+64>>2]|0)+4>>2]|0)!=3?(t[(t[(t[n>>2]|0)+64>>2]|0)+4>>2]|0)!=4:0)break;if(!(NI(t[n>>2]|0)|0)){v=113;break e}}while(0);do if((((t[(t[n>>2]|0)+156>>2]|0)!=0?(t[(t[n>>2]|0)+64>>2]|0)!=0:0)?(t[(t[(t[n>>2]|0)+64>>2]|0)+4>>2]|0)==1:0)?(t[(t[(t[n>>2]|0)+64>>2]|0)+36>>2]|0)!=0:0){if((Xl(t[(t[(t[(t[n>>2]|0)+64>>2]|0)+36>>2]|0)+8>>2]|0,187376)|0)==0?(Xl(t[(t[(t[(t[n>>2]|0)+64>>2]|0)+36>>2]|0)+8>>2]|0,187408)|0)==0:0)break;if(!(t[(t[n>>2]|0)+164>>2]|0)){e=Eo(t[(t[(t[n>>2]|0)+20>>2]|0)+8>>2]|0)|0;t[(t[n>>2]|0)+164>>2]=e;go(t[(t[n>>2]|0)+164>>2]|0,t[(t[n>>2]|0)+188>>2]&-32769)|0}if(!(NI(t[n>>2]|0)|0)){v=123;break e}Ao(t[(t[n>>2]|0)+164>>2]|0,t[(t[n>>2]|0)+64>>2]|0)|0}while(0);if((t[(t[n>>2]|0)+64>>2]|0)!=0?(t[(t[(t[n>>2]|0)+64>>2]|0)+4>>2]|0)==19:0){e=(t[n>>2]|0)+168|0;t[e>>2]=(t[e>>2]|0)+1;continue}if((t[(t[n>>2]|0)+64>>2]|0)!=0?(t[(t[(t[n>>2]|0)+64>>2]|0)+4>>2]|0)==20:0){e=(t[n>>2]|0)+168|0;t[e>>2]=(t[e>>2]|0)+-1;continue}if((((t[(t[n>>2]|0)+64>>2]|0)!=0?(t[(t[(t[n>>2]|0)+64>>2]|0)+4>>2]|0)==5:0)?(t[(t[n>>2]|0)+20>>2]|0)!=0:0)?(t[(t[(t[n>>2]|0)+20>>2]|0)+16>>2]|0)==1:0){if(((t[(t[(t[n>>2]|0)+64>>2]|0)+12>>2]|0)==0?(t[t[(t[n>>2]|0)+20>>2]>>2]|0)!=0:0)?(t[(t[t[(t[n>>2]|0)+20>>2]>>2]|0)+20>>2]|0)!=0:0){e=MAi[t[(t[t[(t[n>>2]|0)+20>>2]>>2]|0)+20>>2]&511](t[(t[n>>2]|0)+20>>2]|0,t[(t[(t[n>>2]|0)+64>>2]|0)+8>>2]|0)|0;t[(t[(t[n>>2]|0)+64>>2]|0)+12>>2]=e}if(((t[(t[(t[n>>2]|0)+64>>2]|0)+12>>2]|0)!=0?(t[(t[(t[(t[n>>2]|0)+64>>2]|0)+12>>2]|0)+4>>2]|0)==17:0)?(t[(t[(t[(t[n>>2]|0)+64>>2]|0)+12>>2]|0)+12>>2]|0)!=0:0){nH(t[n>>2]|0,t[(t[n>>2]|0)+64>>2]|0)|0;t[(t[n>>2]|0)+64>>2]=t[(t[(t[(t[n>>2]|0)+64>>2]|0)+12>>2]|0)+12>>2]}}else v=143;if(((((v|0)==143?(v=0,(t[(t[n>>2]|0)+64>>2]|0)!=0):0)?(t[(t[(t[n>>2]|0)+64>>2]|0)+4>>2]|0)==5:0)?(t[(t[n>>2]|0)+20>>2]|0)!=0:0)?(t[(t[n>>2]|0)+8>>2]|0)!=0:0)fH(t[n>>2]|0);if(!(t[(t[n>>2]|0)+64>>2]|0)){v=153;break}if((t[(t[(t[n>>2]|0)+64>>2]|0)+4>>2]|0)!=17){v=153;break}if(!(t[(t[n>>2]|0)+92>>2]|0)){v=153;break}if((t[(t[(t[n>>2]|0)+92>>2]|0)+12>>2]|0)!=(t[(t[n>>2]|0)+64>>2]|0)){v=153;break}e=tH(t[n>>2]|0)|0;t[(t[n>>2]|0)+64>>2]=e;e=(t[n>>2]|0)+72|0;t[e>>2]=(t[e>>2]|0)+1}if(!(t[(t[n>>2]|0)+64>>2]|0)){v=28;break}i:while(1){if(!(t[(t[n>>2]|0)+64>>2]|0))break;if(t[(t[(t[n>>2]|0)+64>>2]|0)+24>>2]|0)break;if((t[(t[(t[n>>2]|0)+20>>2]|0)+56>>2]|0)!=(t[u>>2]|0))break;do if(((t[o>>2]|0)!=4?(t[(t[(t[n>>2]|0)+64>>2]|0)+12>>2]|0)!=0:0)?(t[(t[(t[n>>2]|0)+64>>2]|0)+4>>2]|0)!=5:0){if(((t[(t[(t[n>>2]|0)+64>>2]|0)+12>>2]|0)!=0?(t[(t[(t[(t[n>>2]|0)+64>>2]|0)+12>>2]|0)+4>>2]|0)==3:0)?(t[(t[(t[(t[n>>2]|0)+64>>2]|0)+12>>2]|0)+24>>2]|0)==0:0)break;if(((t[(t[(t[n>>2]|0)+64>>2]|0)+4>>2]|0)!=14?(t[(t[(t[n>>2]|0)+64>>2]|0)+4>>2]|0)!=9:0)?(t[(t[(t[n>>2]|0)+64>>2]|0)+4>>2]|0)!=13:0)break i}while(0);if(((t[(t[(t[n>>2]|0)+20>>2]|0)+52>>2]|0)!=0?(t[(t[(t[n>>2]|0)+20>>2]|0)+52>>2]|0)!=(t[(t[n>>2]|0)+64>>2]|0):0)?(t[(t[(t[n>>2]|0)+20>>2]|0)+52>>2]|0)!=(t[(t[(t[n>>2]|0)+64>>2]|0)+20>>2]|0):0)break;
	if((t[(t[(t[n>>2]|0)+20>>2]|0)+172>>2]|0)==-1)break;t[f>>2]=eH(t[n>>2]|0)|0;_=t[n>>2]|0;if((t[f>>2]|0)<0){v=48;break e}if(!(t[_+64>>2]|0))break e}if(((((t[o>>2]|0)!=4?(t[(t[(t[n>>2]|0)+64>>2]|0)+12>>2]|0)!=0:0)?(t[(t[(t[n>>2]|0)+64>>2]|0)+4>>2]|0)!=5:0)?(t[(t[(t[n>>2]|0)+64>>2]|0)+4>>2]|0)!=19:0)?(t[(t[(t[n>>2]|0)+64>>2]|0)+4>>2]|0)!=14:0){t[(t[n>>2]|0)+64>>2]=t[(t[(t[n>>2]|0)+64>>2]|0)+12>>2];e=(t[n>>2]|0)+72|0;t[e>>2]=(t[e>>2]|0)+1;t[(t[n>>2]|0)+16>>2]=1;v=108;continue}e=(t[o>>2]|0)==1;if(t[(t[(t[n>>2]|0)+64>>2]|0)+24>>2]|0){if((((e?(t[(t[(t[n>>2]|0)+64>>2]|0)+4>>2]|0)==1:0)?(t[(t[(t[n>>2]|0)+64>>2]|0)+12>>2]|0)==0:0)?((a[(t[(t[n>>2]|0)+64>>2]|0)+58>>1]|0)&1|0)==0:0)?(t[(t[n>>2]|0)+168>>2]|0)<=0:0){t[(t[n>>2]|0)+16>>2]=2;v=108;continue}if((t[(t[n>>2]|0)+8>>2]|0)!=0?(t[(t[(t[n>>2]|0)+64>>2]|0)+4>>2]|0)==1:0)iH(t[n>>2]|0);if((t[(t[n>>2]|0)+184>>2]|0)>0?((a[(t[(t[n>>2]|0)+64>>2]|0)+58>>1]|0)&4|0)!=0:0){d=(t[n>>2]|0)+184|0;t[d>>2]=(t[d>>2]|0)+-1}t[(t[n>>2]|0)+64>>2]=t[(t[(t[n>>2]|0)+64>>2]|0)+24>>2];t[(t[n>>2]|0)+16>>2]=1;if(t[(t[n>>2]|0)+184>>2]|0){v=108;continue}if(t[(t[n>>2]|0)+168>>2]|0){v=108;continue}if(t[(t[n>>2]|0)+96>>2]|0){v=108;continue}if(!(t[(t[(t[n>>2]|0)+64>>2]|0)+28>>2]|0)){v=108;continue}if((t[(t[(t[(t[n>>2]|0)+64>>2]|0)+28>>2]|0)+4>>2]|0)==14){v=108;continue}t[l>>2]=t[(t[(t[n>>2]|0)+64>>2]|0)+28>>2];if((a[(t[l>>2]|0)+58>>1]|0)&2){v=108;continue}iy(t[l>>2]|0);rH(t[n>>2]|0,t[l>>2]|0);v=108;continue}if(((e?(t[(t[(t[n>>2]|0)+64>>2]|0)+4>>2]|0)==1:0)?(t[(t[(t[n>>2]|0)+64>>2]|0)+12>>2]|0)==0:0)?((a[(t[(t[n>>2]|0)+64>>2]|0)+58>>1]|0)&1|0)==0:0){t[(t[n>>2]|0)+16>>2]=2;v=108;continue}if((t[(t[n>>2]|0)+8>>2]|0)!=0?(t[(t[(t[n>>2]|0)+64>>2]|0)+4>>2]|0)==1:0)iH(t[n>>2]|0);if((t[(t[n>>2]|0)+184>>2]|0)>0?((a[(t[(t[n>>2]|0)+64>>2]|0)+58>>1]|0)&4|0)!=0:0){e=(t[n>>2]|0)+184|0;t[e>>2]=(t[e>>2]|0)+-1}t[(t[n>>2]|0)+64>>2]=t[(t[(t[n>>2]|0)+64>>2]|0)+20>>2];if(!(t[(t[n>>2]|0)+64>>2]|0)){v=91;break}if((t[(t[(t[n>>2]|0)+64>>2]|0)+4>>2]|0)==9){v=91;break}if((t[(t[(t[n>>2]|0)+64>>2]|0)+4>>2]|0)==21){v=91;break}if((t[(t[(t[n>>2]|0)+64>>2]|0)+4>>2]|0)==13){v=91;break}do if((((t[(t[n>>2]|0)+184>>2]|0)==0?(t[(t[n>>2]|0)+168>>2]|0)==0:0)?(t[(t[n>>2]|0)+96>>2]|0)==0:0)?(t[(t[(t[n>>2]|0)+64>>2]|0)+16>>2]|0)!=0:0){if((a[(t[(t[(t[n>>2]|0)+64>>2]|0)+16>>2]|0)+58>>1]|0)&2)break;t[b>>2]=t[(t[(t[n>>2]|0)+64>>2]|0)+16>>2];iy(t[b>>2]|0);rH(t[n>>2]|0,t[b>>2]|0)}while(0);e=(t[n>>2]|0)+72|0;t[e>>2]=(t[e>>2]|0)+-1;t[(t[n>>2]|0)+16>>2]=4;v=108}if((v|0)==28)if((t[t[n>>2]>>2]|0)==3){t[r>>2]=0;w=t[r>>2]|0;s=i;return w|0}else{t[r>>2]=-1;w=t[r>>2]|0;s=i;return w|0}else if((v|0)==48){t[_>>2]=2;t[(t[n>>2]|0)+16>>2]=6;t[r>>2]=-1;w=t[r>>2]|0;s=i;return w|0}else if((v|0)==91){if((t[t[n>>2]>>2]|0)!=3?(t[f>>2]=nS(t[(t[n>>2]|0)+20>>2]|0,187368,0,1)|0,t[(t[n>>2]|0)+16>>2]=5,(t[f>>2]|0)!=0):0){t[r>>2]=-1;w=t[r>>2]|0;s=i;return w|0}t[(t[n>>2]|0)+64>>2]=0;t[(t[n>>2]|0)+72>>2]=-1;if((((((t[c>>2]|0)!=0?(t[(t[n>>2]|0)+184>>2]|0)==0:0)?(t[(t[n>>2]|0)+168>>2]|0)==0:0)?(t[(t[n>>2]|0)+96>>2]|0)==0:0)?(t[(t[c>>2]|0)+4>>2]|0)!=14:0)?((a[(t[c>>2]|0)+58>>1]|0)&2|0)==0:0){iy(t[c>>2]|0);rH(t[n>>2]|0,t[c>>2]|0)}}else if((v|0)==113){t[r>>2]=-1;w=t[r>>2]|0;s=i;return w|0}else if((v|0)==123){t[r>>2]=-1;w=t[r>>2]|0;s=i;return w|0}else if((v|0)==153){do if((t[(t[n>>2]|0)+8>>2]|0)!=0?(t[(t[n>>2]|0)+64>>2]|0)!=0:0){t[k>>2]=t[(t[n>>2]|0)+64>>2];if(((t[(t[k>>2]|0)+4>>2]|0)==1?(t[(t[n>>2]|0)+16>>2]|0)!=2:0)?(t[(t[n>>2]|0)+16>>2]|0)!=4:0){uH(t[n>>2]|0);break}if((t[(t[k>>2]|0)+4>>2]|0)!=3?(t[(t[k>>2]|0)+4>>2]|0)!=4:0)break;v=t[n>>2]|0;c=t[(t[k>>2]|0)+40>>2]|0;aH(v,c,rs(t[(t[k>>2]|0)+40>>2]|0)|0)}while(0);e:do if(((t[(t[n>>2]|0)+172>>2]|0)>0?(t[(t[n>>2]|0)+16>>2]|0)!=2:0)?(t[(t[n>>2]|0)+16>>2]|0)!=4:0){t[h>>2]=0;while(1){if((t[h>>2]|0)>=(t[(t[n>>2]|0)+172>>2]|0))break e;if((Oj(t[(t[(t[n>>2]|0)+180>>2]|0)+(t[h>>2]<<2)>>2]|0,t[(t[n>>2]|0)+64>>2]|0)|0)==1)break;t[h>>2]=(t[h>>2]|0)+1}TI(t[n>>2]|0)|0}while(0);if(((t[(t[n>>2]|0)+8>>2]|0)==4?(t[(t[n>>2]|0)+148>>2]|0)==0:0)?(t[(t[n>>2]|0)+140>>2]|0)!=0:0){h=((xk(t[(t[n>>2]|0)+140>>2]|0)|0)!=0^1)&1;t[(t[n>>2]|0)+148>>2]=h}t[r>>2]=1;w=t[r>>2]|0;s=i;return w|0}t[(t[n>>2]|0)+16>>2]=5;t[r>>2]=0;w=t[r>>2]|0;s=i;return w|0}function NI(e){e=e|0;var i=0,r=0,n=0,f=0;i=s;s=s+16|0;r=i+4|0;n=i;t[n>>2]=e;do if((t[n>>2]|0)!=0?(t[(t[n>>2]|0)+64>>2]|0)!=0:0){e=t[n>>2]|0;if(t[(t[n>>2]|0)+4>>2]|0){t[r>>2]=t[e+64>>2];break}if(!(t[e+20>>2]|0)){t[r>>2]=0;break}if((oH(t[n>>2]|0)|0)<0){t[r>>2]=0;break}else{t[r>>2]=t[(t[n>>2]|0)+64>>2];break}}else f=3;while(0);if((f|0)==3)t[r>>2]=0;s=i;return t[r>>2]|0}function TI(e){e=e|0;var i=0,r=0,n=0,u=0,o=0,c=0;i=s;s=s+16|0;r=i+12|0;n=i+8|0;u=i+4|0;o=i;t[n>>2]=e;if(!(t[n>>2]|0)){t[r>>2]=0;c=t[r>>2]|0;s=i;return c|0}e=t[n>>2]|0;if(t[(t[n>>2]|0)+68>>2]|0)t[u>>2]=t[e+68>>2];else t[u>>2]=t[e+64>>2];if(!(t[u>>2]|0)){t[r>>2]=0;c=t[r>>2]|0;s=i;return c|0}if((t[(t[u>>2]|0)+4>>2]|0)!=9?(t[(t[u>>2]|0)+4>>2]|0)!=14:0){e=(t[u>>2]|0)+58|0;f[e>>1]=a[e>>1]|0|2;e=(t[u>>2]|0)+58|0;f[e>>1]=a[e>>1]|0|4}e=(t[n>>2]|0)+184|0;t[e>>2]=(t[e>>2]|0)+1;t[o>>2]=t[(t[u>>2]|0)+20>>2];while(1){if(!(t[o>>2]|0))break;if((t[(t[o>>2]|0)+4>>2]|0)==1){e=(t[o>>2]|0)+58|0;f[e>>1]=a[e>>1]|0|2}t[o>>2]=t[(t[o>>2]|0)+20>>2]}t[r>>2]=t[u>>2];c=t[r>>2]|0;s=i;return c|0}function LI(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0;r=s;s=s+32|0;n=r;f=r+16|0;u=r+12|0;a=r+8|0;o=r+4|0;t[u>>2]=e;t[a>>2]=i;if(!(t[u>>2]|0)){t[f>>2]=0;c=t[f>>2]|0;s=r;return c|0}t[o>>2]=gAi[t[135744>>2]&511](196)|0;if(!(t[o>>2]|0)){yAi[t[135904>>2]&511](t[33980]|0,187440,n);t[f>>2]=0;c=t[f>>2]|0;s=r;return c|0}VY(t[o>>2]|0,0,196)|0;t[(t[o>>2]|0)+4>>2]=0;t[(t[o>>2]|0)+104>>2]=0;t[(t[o>>2]|0)+100>>2]=0;t[(t[o>>2]|0)+96>>2]=0;t[(t[o>>2]|0)+28>>2]=t[u>>2];i=vs(100)|0;t[(t[o>>2]|0)+84>>2]=i;if(!(t[(t[o>>2]|0)+84>>2]|0)){pAi[t[135736>>2]&511](t[o>>2]|0);yAi[t[135904>>2]&511](t[33980]|0,187440,n);t[f>>2]=0;c=t[f>>2]|0;s=r;return c|0}i=gAi[t[135744>>2]&511](128)|0;t[(t[o>>2]|0)+24>>2]=i;i=t[o>>2]|0;if(!(t[(t[o>>2]|0)+24>>2]|0)){Ss(t[i+84>>2]|0);pAi[t[135736>>2]&511](t[o>>2]|0);yAi[t[135904>>2]&511](t[33980]|0,187440,n);t[f>>2]=0;c=t[f>>2]|0;s=r;return c|0}ij(t[i+24>>2]|0,2)|0;t[(t[o>>2]|0)+32>>2]=t[(t[(t[o>>2]|0)+24>>2]|0)+56>>2];t[(t[(t[o>>2]|0)+24>>2]|0)+56>>2]=361;t[(t[o>>2]|0)+36>>2]=t[(t[(t[o>>2]|0)+24>>2]|0)+60>>2];t[(t[(t[o>>2]|0)+24>>2]|0)+60>>2]=362;i=t[o>>2]|0;if((t[(t[(t[o>>2]|0)+24>>2]|0)+108>>2]|0)==-554844497){t[(t[o>>2]|0)+40>>2]=t[(t[i+24>>2]|0)+116>>2];t[(t[(t[o>>2]|0)+24>>2]|0)+116>>2]=363;t[(t[o>>2]|0)+44>>2]=t[(t[(t[o>>2]|0)+24>>2]|0)+120>>2];t[(t[(t[o>>2]|0)+24>>2]|0)+120>>2]=364}else{t[i+40>>2]=0;t[(t[o>>2]|0)+44>>2]=0}t[(t[o>>2]|0)+48>>2]=t[(t[(t[o>>2]|0)+24>>2]|0)+68>>2];t[(t[(t[o>>2]|0)+24>>2]|0)+68>>2]=365;t[(t[(t[o>>2]|0)+24>>2]|0)+72>>2]=365;t[(t[o>>2]|0)+52>>2]=t[(t[(t[o>>2]|0)+24>>2]|0)+100>>2];t[(t[(t[o>>2]|0)+24>>2]|0)+100>>2]=366;t[t[o>>2]>>2]=0;t[(t[o>>2]|0)+64>>2]=0;t[(t[o>>2]|0)+68>>2]=0;if((Ts(t[(t[(t[o>>2]|0)+28>>2]|0)+16>>2]|0)|0)>>>0<4)QO(t[u>>2]|0,4)|0;u=(Ts(t[(t[(t[o>>2]|0)+28>>2]|0)+16>>2]|0)|0)>>>0>=4;i=t[(t[o>>2]|0)+24>>2]|0;if(u){u=Os(t[(t[(t[o>>2]|0)+28>>2]|0)+16>>2]|0)|0;e=fS(i,0,u,4,t[a>>2]|0)|0;t[(t[o>>2]|0)+20>>2]=e;t[(t[o>>2]|0)+56>>2]=0;t[(t[o>>2]|0)+60>>2]=4}else{e=fS(i,0,0,0,t[a>>2]|0)|0;t[(t[o>>2]|0)+20>>2]=e;t[(t[o>>2]|0)+56>>2]=0;t[(t[o>>2]|0)+60>>2]=0}if(!(t[(t[o>>2]|0)+20>>2]|0)){yAi[t[135904>>2]&511](t[33980]|0,187440,n);Ss(t[(t[o>>2]|0)+84>>2]|0);pAi[t[135736>>2]&511](t[(t[o>>2]|0)+24>>2]|0);pAi[t[135736>>2]&511](t[o>>2]|0);t[f>>2]=0;c=t[f>>2]|0;s=r;return c|0}else{t[(t[(t[o>>2]|0)+20>>2]|0)+436>>2]=5;t[(t[(t[o>>2]|0)+20>>2]|0)+272>>2]=t[o>>2];t[(t[(t[o>>2]|0)+20>>2]|0)+280>>2]=1;t[(t[(t[o>>2]|0)+20>>2]|0)+364>>2]=1;t[(t[o>>2]|0)+12>>2]=2;t[(t[(t[o>>2]|0)+20>>2]|0)+308>>2]=1;t[(t[o>>2]|0)+88>>2]=t[(t[(t[o>>2]|0)+20>>2]|0)+296>>2];t[(t[o>>2]|0)+156>>2]=0;t[(t[o>>2]|0)+176>>2]=0;t[(t[o>>2]|0)+180>>2]=0;t[f>>2]=t[o>>2];c=t[f>>2]|0;s=r;return c|0}return 0}function DI(e){e=e|0;var i=0,r=0,n=0,f=0,u=0,a=0,o=0;i=s;s=s+32|0;r=i+16|0;n=i+12|0;f=i+8|0;u=i+4|0;a=i;t[n>>2]=e;t[a>>2]=0;t[f>>2]=zO(t[n>>2]|0,0)|0;if(!(t[f>>2]|0)){t[r>>2]=0;o=t[r>>2]|0;s=i;return o|0}t[u>>2]=LI(t[f>>2]|0,t[n>>2]|0)|0;if(!(t[u>>2]|0)){IO(t[f>>2]|0);t[r>>2]=0;o=t[r>>2]|0;s=i;return o|0}f=(t[u>>2]|0)+12|0;t[f>>2]=t[f>>2]|1;if(!(t[(t[(t[u>>2]|0)+20>>2]|0)+180>>2]|0))t[a>>2]=rA(t[n>>2]|0)|0;if((t[a>>2]|0)!=0?(t[(t[(t[u>>2]|0)+20>>2]|0)+180>>2]|0)==0:0){n=Yl(t[a>>2]|0)|0;t[(t[(t[u>>2]|0)+20>>2]|0)+180>>2]=n}if(t[a>>2]|0)pAi[t[135736>>2]&511](t[a>>2]|0);t[r>>2]=t[u>>2];o=t[r>>2]|0;s=i;return o|0}function CI(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i+4|0;n=i;t[r>>2]=e;if(!(t[r>>2]|0)){s=i;return}if(t[(t[r>>2]|0)+116>>2]|0){CH(t[(t[r>>2]|0)+116>>2]|0);t[(t[r>>2]|0)+116>>2]=0}if(t[(t[r>>2]|0)+120>>2]|0){if(!(t[(t[r>>2]|0)+124>>2]|0))GH(t[(t[r>>2]|0)+120>>2]|0);t[(t[r>>2]|0)+120>>2]=0}if(t[(t[r>>2]|0)+152>>2]|0){jk(t[(t[r>>2]|0)+152>>2]|0)|0;t[(t[r>>2]|0)+152>>2]=0}if(t[(t[r>>2]|0)+140>>2]|0){if(!(t[(t[r>>2]|0)+144>>2]|0))Nk(t[(t[r>>2]|0)+140>>2]|0);t[(t[r>>2]|0)+140>>2]=0}if(t[(t[r>>2]|0)+136>>2]|0){Ak(t[(t[r>>2]|0)+136>>2]|0);t[(t[r>>2]|0)+136>>2]=0}if(t[(t[r>>2]|0)+164>>2]|0)So(t[(t[r>>2]|0)+164>>2]|0);if(t[(t[r>>2]|0)+180>>2]|0){t[n>>2]=0;while(1){if((t[n>>2]|0)>=(t[(t[r>>2]|0)+172>>2]|0))break;if(t[(t[(t[r>>2]|0)+180>>2]|0)+(t[n>>2]<<2)>>2]|0)vj(t[(t[(t[r>>2]|0)+180>>2]|0)+(t[n>>2]<<2)>>2]|0);t[n>>2]=(t[n>>2]|0)+1}pAi[t[135736>>2]&511](t[(t[r>>2]|0)+180>>2]|0)}if(t[(t[r>>2]|0)+76>>2]|0)ry(t[(t[r>>2]|0)+76>>2]|0);if(t[(t[r>>2]|0)+20>>2]|0){if((t[(t[r>>2]|0)+88>>2]|0)==(t[(t[(t[r>>2]|0)+20>>2]|0)+296>>2]|0))t[(t[r>>2]|0)+88>>2]=0;if(t[(t[(t[r>>2]|0)+20>>2]|0)+8>>2]|0){if(!(t[(t[r>>2]|0)+80>>2]|0))wH(t[r>>2]|0,t[(t[(t[r>>2]|0)+20>>2]|0)+8>>2]|0);t[(t[(t[r>>2]|0)+20>>2]|0)+8>>2]=0}if((t[(t[(t[r>>2]|0)+20>>2]|0)+160>>2]|0)!=0?(t[(t[(t[r>>2]|0)+20>>2]|0)+156>>2]|0)>0:0){pAi[t[135736>>2]&511](t[(t[(t[r>>2]|0)+20>>2]|0)+160>>2]|0);t[(t[(t[r>>2]|0)+20>>2]|0)+160>>2]=0;t[(t[(t[r>>2]|0)+20>>2]|0)+156>>2]=0}if(t[(t[r>>2]|0)+12>>2]&2)Up(t[(t[r>>2]|0)+20>>2]|0)}if(t[(t[r>>2]|0)+24>>2]|0)pAi[t[135736>>2]&511](t[(t[r>>2]|0)+24>>2]|0);if((t[(t[r>>2]|0)+28>>2]|0)!=0?(t[(t[r>>2]|0)+12>>2]&1|0)!=0:0)IO(t[(t[r>>2]|0)+28>>2]|0);if(t[(t[r>>2]|0)+84>>2]|0)Ss(t[(t[r>>2]|0)+84>>2]|0);if(t[(t[r>>2]|0)+104>>2]|0)pAi[t[135736>>2]&511](t[(t[r>>2]|0)+104>>2]|0);if(t[(t[r>>2]|0)+88>>2]|0)bz(t[(t[r>>2]|0)+88>>2]|0);pAi[t[135736>>2]&511](t[r>>2]|0);s=i;return}function PI(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0;r=s;s=s+16|0;n=r+12|0;f=r+8|0;u=r+4|0;a=r;t[f>>2]=e;t[u>>2]=i;do if(t[f>>2]|0){if(!(t[(t[f>>2]|0)+64>>2]|0)){t[n>>2]=0;break}t[a>>2]=wF(t[(t[(t[f>>2]|0)+64>>2]|0)+32>>2]|0,t[(t[f>>2]|0)+64>>2]|0,t[u>>2]|0)|0;if(!(t[a>>2]|0)){t[n>>2]=0;break}else{t[n>>2]=Yl(t[(t[a>>2]|0)+8>>2]|0)|0;break}}else t[n>>2]=0;while(0);s=r;return t[n>>2]|0}function BI(e){e=e|0;var i=0,r=0,n=0,f=0;i=s;s=s+16|0;r=i+8|0;n=i+4|0;f=i;t[n>>2]=e;e:do if(!(t[n>>2]|0))t[r>>2]=-1;else{if(!(t[(t[n>>2]|0)+64>>2]|0)){t[r>>2]=0;break}e=t[n>>2]|0;if(t[(t[n>>2]|0)+68>>2]|0)t[f>>2]=t[e+68>>2];else t[f>>2]=t[e+64>>2];do switch(t[(t[f>>2]|0)+4>>2]|0){case 7:{t[r>>2]=7;break e;break}case 2:case 18:{t[r>>2]=2;break e;break}case 1:{if((t[(t[n>>2]|0)+16>>2]|0)!=2?(t[(t[n>>2]|0)+16>>2]|0)!=4:0){t[r>>2]=1;break e}t[r>>2]=15;break e;break}case 5:{t[r>>2]=5;break e;break}case 12:{t[r>>2]=12;break e;break}case 21:case 13:case 9:{t[r>>2]=9;break e;break}case 6:{t[r>>2]=6;break e;break}case 11:{t[r>>2]=11;break e;break}case 3:{if(!(EF(t[(t[n>>2]|0)+64>>2]|0)|0)){t[r>>2]=3;break e}if(uF(t[(t[n>>2]|0)+64>>2]|0)|0){t[r>>2]=14;break e}else{t[r>>2]=13;break e}break}case 14:case 10:{t[r>>2]=10;break e;break}case 4:{t[r>>2]=4;break e;break}case 20:case 19:case 17:case 16:case 15:{t[r>>2]=0;break e;break}case 8:{t[r>>2]=8;break e;break}default:{t[r>>2]=-1;break e}}while(0)}while(0);s=i;return t[r>>2]|0}function II(e){e=e|0;var i=0,r=0,n=0,f=0;i=s;s=s+16|0;r=i+4|0;n=i;t[n>>2]=e;do if((t[n>>2]|0)!=0?(t[(t[n>>2]|0)+64>>2]|0)!=0:0){if((t[(t[(t[n>>2]|0)+64>>2]|0)+4>>2]|0)!=1){t[r>>2]=0;break}if(t[(t[n>>2]|0)+68>>2]|0){t[r>>2]=0;break}if(t[(t[(t[n>>2]|0)+64>>2]|0)+12>>2]|0){t[r>>2]=0;break}if((t[(t[n>>2]|0)+16>>2]|0)==2){t[r>>2]=0;break}if(t[(t[n>>2]|0)+4>>2]|0){t[r>>2]=1;break}if((t[(t[n>>2]|0)+168>>2]|0)>0){t[r>>2]=1;break}else{t[r>>2]=((a[(t[(t[n>>2]|0)+64>>2]|0)+58>>1]|0)&1|0)!=0&1;break}}else f=3;while(0);if((f|0)==3)t[r>>2]=-1;s=i;return t[r>>2]|0}function HI(e){e=e|0;var i=0,r=0,n=0,f=0,u=0,a=0;i=s;s=s+16|0;r=i+12|0;n=i+8|0;f=i+4|0;u=i;t[n>>2]=e;if((t[n>>2]|0)!=0?(t[(t[n>>2]|0)+64>>2]|0)!=0:0){e=t[n>>2]|0;if(t[(t[n>>2]|0)+68>>2]|0)t[f>>2]=t[e+68>>2];else t[f>>2]=t[e+64>>2];e=t[f>>2]|0;if((t[(t[f>>2]|0)+4>>2]|0)==18){t[u>>2]=e;if(!(t[(t[u>>2]|0)+12>>2]|0)){t[r>>2]=kz(t[(t[n>>2]|0)+88>>2]|0,187480,-1)|0;a=t[r>>2]|0;s=i;return a|0}else{t[r>>2]=t[(t[u>>2]|0)+12>>2];a=t[r>>2]|0;s=i;return a|0}}if((t[e+4>>2]|0)!=1?(t[(t[f>>2]|0)+4>>2]|0)!=2:0){t[r>>2]=xI(t[n>>2]|0)|0;a=t[r>>2]|0;s=i;return a|0}t[r>>2]=t[(t[f>>2]|0)+8>>2];a=t[r>>2]|0;s=i;return a|0}t[r>>2]=0;a=t[r>>2]|0;s=i;return a|0}function xI(e){e=e|0;var i=0,r=0,n=0,f=0,u=0,a=0;i=s;s=s+16|0;r=i+12|0;n=i+8|0;f=i+4|0;u=i;t[n>>2]=e;e:do if((t[n>>2]|0)!=0?(t[(t[n>>2]|0)+64>>2]|0)!=0:0){e=t[n>>2]|0;if(t[(t[n>>2]|0)+68>>2]|0)t[f>>2]=t[e+68>>2];else t[f>>2]=t[e+64>>2];do switch(t[(t[f>>2]|0)+4>>2]|0){case 20:case 19:case 17:case 16:case 15:{t[r>>2]=0;break e;break}case 11:{t[r>>2]=kz(t[(t[n>>2]|0)+88>>2]|0,187584,-1)|0;break e;break}case 18:{t[u>>2]=t[f>>2];e=t[(t[n>>2]|0)+88>>2]|0;if(!(t[(t[u>>2]|0)+12>>2]|0)){t[r>>2]=kz(e,187480,-1)|0;break e}else{t[r>>2]=hz(e,187480,t[(t[u>>2]|0)+12>>2]|0)|0;break e}break}case 21:case 13:case 9:{t[r>>2]=kz(t[(t[n>>2]|0)+88>>2]|0,187568,-1)|0;break e;break}case 4:{t[r>>2]=kz(t[(t[n>>2]|0)+88>>2]|0,187536,-1)|0;break e;break}case 2:case 1:{if((t[(t[f>>2]|0)+36>>2]|0)!=0?(t[(t[(t[f>>2]|0)+36>>2]|0)+12>>2]|0)!=0:0){t[r>>2]=hz(t[(t[n>>2]|0)+88>>2]|0,t[(t[(t[f>>2]|0)+36>>2]|0)+12>>2]|0,t[(t[f>>2]|0)+8>>2]|0)|0;break e}t[r>>2]=t[(t[f>>2]|0)+8>>2];break e;break}case 12:{t[r>>2]=kz(t[(t[n>>2]|0)+88>>2]|0,t[(t[f>>2]|0)+8>>2]|0,-1)|0;break e;break}case 5:case 6:{t[r>>2]=kz(t[(t[n>>2]|0)+88>>2]|0,t[(t[f>>2]|0)+8>>2]|0,-1)|0;break e;break}case 3:{t[r>>2]=kz(t[(t[n>>2]|0)+88>>2]|0,187528,-1)|0;break e;break}case 8:{t[r>>2]=kz(t[(t[n>>2]|0)+88>>2]|0,187552,-1)|0;break e;break}case 7:{t[r>>2]=kz(t[(t[n>>2]|0)+88>>2]|0,t[(t[f>>2]|0)+8>>2]|0,-1)|0;break e;break}case 14:case 10:{t[r>>2]=kz(t[(t[n>>2]|0)+88>>2]|0,t[(t[f>>2]|0)+8>>2]|0,-1)|0;break e;break}default:{t[r>>2]=0;break e}}while(0)}else a=3;while(0);if((a|0)==3)t[r>>2]=0;s=i;return t[r>>2]|0}function UI(e){e=e|0;var i=0,r=0,n=0,f=0,u=0;i=s;s=s+16|0;r=i+8|0;n=i+4|0;f=i;t[n>>2]=e;if((t[n>>2]|0)!=0?(t[(t[n>>2]|0)+64>>2]|0)!=0:0){e=t[n>>2]|0;if(t[(t[n>>2]|0)+68>>2]|0)t[f>>2]=t[e+68>>2];else t[f>>2]=t[e+64>>2];if((t[(t[f>>2]|0)+4>>2]|0)==18){t[r>>2]=kz(t[(t[n>>2]|0)+88>>2]|0,187488,-1)|0;u=t[r>>2]|0;s=i;return u|0}if((t[(t[f>>2]|0)+4>>2]|0)!=1?(t[(t[f>>2]|0)+4>>2]|0)!=2:0){t[r>>2]=0;u=t[r>>2]|0;s=i;return u|0}if(t[(t[f>>2]|0)+36>>2]|0){t[r>>2]=kz(t[(t[n>>2]|0)+88>>2]|0,t[(t[(t[f>>2]|0)+36>>2]|0)+8>>2]|0,-1)|0;u=t[r>>2]|0;s=i;return u|0}else{t[r>>2]=0;u=t[r>>2]|0;s=i;return u|0}}t[r>>2]=0;u=t[r>>2]|0;s=i;return u|0}function zI(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i+4|0;n=i;t[n>>2]=e;do if(!(t[n>>2]|0))t[r>>2]=-1;else{if(!(t[(t[n>>2]|0)+64>>2]|0)){t[r>>2]=0;break}e=t[n>>2]|0;if(!(t[(t[n>>2]|0)+68>>2]|0)){t[r>>2]=t[e+72>>2];break}if((t[(t[e+68>>2]|0)+4>>2]|0)!=2?(t[(t[(t[n>>2]|0)+68>>2]|0)+4>>2]|0)!=18:0){t[r>>2]=(t[(t[n>>2]|0)+72>>2]|0)+2;break}t[r>>2]=(t[(t[n>>2]|0)+72>>2]|0)+1}while(0);s=i;return t[r>>2]|0}function jI(e){e=e|0;var i=0,r=0,n=0,f=0;i=s;s=s+16|0;r=i+8|0;n=i+4|0;f=i;t[n>>2]=e;e:do if(!(t[n>>2]|0))t[r>>2]=-1;else{if(!(t[(t[n>>2]|0)+64>>2]|0)){t[r>>2]=0;break}e=t[n>>2]|0;if(t[(t[n>>2]|0)+68>>2]|0)t[f>>2]=t[e+68>>2];else t[f>>2]=t[e+64>>2];switch(t[(t[f>>2]|0)+4>>2]|0){case 18:case 8:case 7:case 4:case 3:case 2:{t[r>>2]=1;break e;break}default:{t[r>>2]=0;break e}}}while(0);s=i;return t[r>>2]|0}function VI(e){e=e|0;var i=0,r=0,n=0,f=0,u=0,a=0,o=0;i=s;s=s+32|0;r=i;n=i+16|0;f=i+12|0;u=i+8|0;a=i+4|0;t[f>>2]=e;if(!(t[f>>2]|0)){t[n>>2]=0;o=t[n>>2]|0;s=i;return o|0}if(!(t[(t[f>>2]|0)+64>>2]|0)){t[n>>2]=0;o=t[n>>2]|0;s=i;return o|0}e=t[f>>2]|0;if(t[(t[f>>2]|0)+68>>2]|0)t[u>>2]=t[e+68>>2];else t[u>>2]=t[e+64>>2];switch(t[(t[u>>2]|0)+4>>2]|0){case 8:case 7:case 4:case 3:{t[n>>2]=t[(t[u>>2]|0)+40>>2];o=t[n>>2]|0;s=i;return o|0}case 2:{t[a>>2]=t[u>>2];if(((t[(t[a>>2]|0)+12>>2]|0)!=0?(t[(t[(t[a>>2]|0)+12>>2]|0)+4>>2]|0)==3:0)?(t[(t[(t[a>>2]|0)+12>>2]|0)+24>>2]|0)==0:0){t[n>>2]=t[(t[(t[a>>2]|0)+12>>2]|0)+40>>2];o=t[n>>2]|0;s=i;return o|0}if(!(t[(t[f>>2]|0)+84>>2]|0)){a=vs(100)|0;t[(t[f>>2]|0)+84>>2]=a;if(!(t[(t[f>>2]|0)+84>>2]|0)){yAi[t[135904>>2]&511](t[33980]|0,187608,r);t[n>>2]=0;o=t[n>>2]|0;s=i;return o|0}}else gs(t[(t[f>>2]|0)+84>>2]|0);lF(t[(t[f>>2]|0)+84>>2]|0,t[u>>2]|0)|0;t[n>>2]=Os(t[(t[f>>2]|0)+84>>2]|0)|0;o=t[n>>2]|0;s=i;return o|0}case 18:{t[n>>2]=t[(t[u>>2]|0)+8>>2];o=t[n>>2]|0;s=i;return o|0}default:{t[n>>2]=0;o=t[n>>2]|0;s=i;return o|0}}return 0}function qI(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0;n=s;s=s+32|0;f=n+20|0;u=n+16|0;a=n+12|0;o=n+8|0;c=n+4|0;l=n;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;t[c>>2]=t[a>>2];e:do if((t[u>>2]|0)!=0?(t[(t[u>>2]|0)+20>>2]|0)!=0:0){t[l>>2]=t[(t[u>>2]|0)+20>>2];a=t[c>>2]|0;if((a|0)==4){r=(t[l>>2]|0)+16|0;if(t[o>>2]|0)t[r>>2]=1;else t[r>>2]=0;t[f>>2]=0;break}else if((a|0)==2){r=(t[l>>2]|0)+276|0;i=t[r>>2]|0;if(!(t[o>>2]|0)){if(i&4){e=(t[l>>2]|0)+276|0;t[e>>2]=(t[e>>2]|0)-4}}else t[r>>2]=i|4;t[f>>2]=0;break}else if((a|0)==1){i=(t[l>>2]|0)+276|0;do if(t[o>>2]|0){if(!(t[i>>2]|0))if(t[t[u>>2]>>2]|0){t[f>>2]=-1;break e}else{t[(t[l>>2]|0)+276>>2]=2;break}}else t[i>>2]=0;while(0);t[f>>2]=0;break}else if((a|0)==3){i=(t[l>>2]|0)+104|0;if(t[o>>2]|0){t[i>>2]=1;t[(t[u>>2]|0)+8>>2]=1}else t[i>>2]=0;t[f>>2]=0;break}else{t[f>>2]=-1;break}}else b=3;while(0);if((b|0)==3)t[f>>2]=-1;s=n;return t[f>>2]|0}function YI(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i+4|0;n=i;t[n>>2]=e;do if(t[n>>2]|0){e=t[n>>2]|0;if(t[(t[n>>2]|0)+68>>2]|0){t[r>>2]=t[e+68>>2];break}else{t[r>>2]=t[e+64>>2];break}}else t[r>>2]=0;while(0);s=i;return t[r>>2]|0}function GI(e,i){e=e|0;i=i|0;var r=0,n=0,f=0;r=s;s=s+16|0;n=r+4|0;f=r;t[n>>2]=e;t[f>>2]=i;i=pH(t[n>>2]|0,t[f>>2]|0,0,0)|0;s=r;return i|0}function WI(e,i){e=e|0;i=i|0;var r=0,n=0,f=0;r=s;s=s+16|0;n=r+4|0;f=r;t[n>>2]=e;t[f>>2]=i;i=EH(t[n>>2]|0,t[f>>2]|0,0,0)|0;s=r;return i|0}function KI(e){e=e|0;var i=0,r=0,n=0,f=0;i=s;s=s+16|0;r=i+4|0;n=i;t[n>>2]=e;do if(!(t[n>>2]|0))t[r>>2]=-1;else{e=t[n>>2]|0;if((t[(t[n>>2]|0)+8>>2]|0)==2){t[r>>2]=(t[e+128>>2]|0)==0&1;break}f=t[n>>2]|0;if((t[e+8>>2]|0)==4){t[r>>2]=(t[f+148>>2]|0)==0&1;break}if((t[f+20>>2]|0)!=0?(t[(t[(t[n>>2]|0)+20>>2]|0)+104>>2]|0)==1:0){t[r>>2]=t[(t[(t[n>>2]|0)+20>>2]|0)+100>>2];break}t[r>>2]=0}while(0);s=i;return t[r>>2]|0}function XI(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;var u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0;u=s;s=s+48|0;a=u;o=u+40|0;c=u+36|0;l=u+32|0;b=u+28|0;k=u+24|0;h=u+20|0;w=u+16|0;d=u+12|0;v=u+8|0;m=u+4|0;t[c>>2]=e;t[l>>2]=i;t[b>>2]=r;t[k>>2]=n;t[h>>2]=f;if(!(t[c>>2]|0)){if(t[l>>2]|0)IO(t[l>>2]|0);t[o>>2]=-1;_=t[o>>2]|0;s=u;return _|0}t[h>>2]=t[h>>2]|65536;t[(t[c>>2]|0)+4>>2]=0;t[(t[c>>2]|0)+96>>2]=0;t[(t[c>>2]|0)+188>>2]=t[h>>2];t[(t[c>>2]|0)+8>>2]=0;if(((t[l>>2]|0)!=0?(t[(t[c>>2]|0)+28>>2]|0)!=0:0)?(t[(t[c>>2]|0)+12>>2]&1|0)!=0:0){IO(t[(t[c>>2]|0)+28>>2]|0);t[(t[c>>2]|0)+28>>2]=0;f=(t[c>>2]|0)+12|0;t[f>>2]=(t[f>>2]|0)-1}if(t[l>>2]|0){t[(t[c>>2]|0)+28>>2]=t[l>>2];f=(t[c>>2]|0)+12|0;t[f>>2]=t[f>>2]|1}if(!(t[(t[c>>2]|0)+84>>2]|0)){f=vs(100)|0;t[(t[c>>2]|0)+84>>2]=f}if(!(t[(t[c>>2]|0)+84>>2]|0)){yAi[t[135904>>2]&511](t[33980]|0,187608,a);t[o>>2]=-1;_=t[o>>2]|0;s=u;return _|0}if(!(t[(t[c>>2]|0)+24>>2]|0)){f=gAi[t[135744>>2]&511](128)|0;t[(t[c>>2]|0)+24>>2]=f}if(!(t[(t[c>>2]|0)+24>>2]|0)){yAi[t[135904>>2]&511](t[33980]|0,187608,a);t[o>>2]=-1;_=t[o>>2]|0;s=u;return _|0}ij(t[(t[c>>2]|0)+24>>2]|0,2)|0;t[(t[c>>2]|0)+32>>2]=t[(t[(t[c>>2]|0)+24>>2]|0)+56>>2];t[(t[(t[c>>2]|0)+24>>2]|0)+56>>2]=361;t[(t[c>>2]|0)+36>>2]=t[(t[(t[c>>2]|0)+24>>2]|0)+60>>2];t[(t[(t[c>>2]|0)+24>>2]|0)+60>>2]=362;f=t[c>>2]|0;if((t[(t[(t[c>>2]|0)+24>>2]|0)+108>>2]|0)==-554844497){t[(t[c>>2]|0)+40>>2]=t[(t[f+24>>2]|0)+116>>2];t[(t[(t[c>>2]|0)+24>>2]|0)+116>>2]=363;t[(t[c>>2]|0)+44>>2]=t[(t[(t[c>>2]|0)+24>>2]|0)+120>>2];t[(t[(t[c>>2]|0)+24>>2]|0)+120>>2]=364}else{t[f+40>>2]=0;t[(t[c>>2]|0)+44>>2]=0}t[(t[c>>2]|0)+48>>2]=t[(t[(t[c>>2]|0)+24>>2]|0)+68>>2];t[(t[(t[c>>2]|0)+24>>2]|0)+68>>2]=365;t[(t[(t[c>>2]|0)+24>>2]|0)+72>>2]=365;t[(t[c>>2]|0)+52>>2]=t[(t[(t[c>>2]|0)+24>>2]|0)+100>>2];t[(t[(t[c>>2]|0)+24>>2]|0)+100>>2]=366;t[t[c>>2]>>2]=0;t[(t[c>>2]|0)+64>>2]=0;t[(t[c>>2]|0)+68>>2]=0;if(t[l>>2]|0){if((Ts(t[(t[(t[c>>2]|0)+28>>2]|0)+16>>2]|0)|0)>>>0<4)QO(t[l>>2]|0,4)|0;do if(!(t[(t[c>>2]|0)+20>>2]|0)){l=(Ts(t[(t[(t[c>>2]|0)+28>>2]|0)+16>>2]|0)|0)>>>0>=4;f=t[(t[c>>2]|0)+24>>2]|0;if(l){l=Os(t[(t[(t[c>>2]|0)+28>>2]|0)+16>>2]|0)|0;n=fS(f,0,l,4,t[b>>2]|0)|0;t[(t[c>>2]|0)+20>>2]=n;t[(t[c>>2]|0)+56>>2]=0;t[(t[c>>2]|0)+60>>2]=4;break}else{n=fS(f,0,0,0,t[b>>2]|0)|0;t[(t[c>>2]|0)+20>>2]=n;t[(t[c>>2]|0)+56>>2]=0;t[(t[c>>2]|0)+60>>2]=0;break}}else{t[v>>2]=0;vS(t[(t[c>>2]|0)+20>>2]|0);t[d>>2]=CO(t[v>>2]|0)|0;if(!(t[d>>2]|0)){t[o>>2]=-1;_=t[o>>2]|0;s=u;return _|0}t[w>>2]=Cp(t[(t[c>>2]|0)+20>>2]|0)|0;if(!(t[w>>2]|0)){IO(t[d>>2]|0);t[o>>2]=-1;_=t[o>>2]|0;s=u;return _|0}if(!(t[b>>2]|0))t[(t[w>>2]|0)+4>>2]=0;else{n=KA(t[b>>2]|0)|0;t[(t[w>>2]|0)+4>>2]=n}t[t[w>>2]>>2]=t[d>>2];zs(t[(t[d>>2]|0)+16>>2]|0,t[w>>2]|0)|0;eE(t[(t[c>>2]|0)+20>>2]|0,t[w>>2]|0)|0;t[(t[c>>2]|0)+60>>2]=0}while(0);if(!(t[(t[c>>2]|0)+20>>2]|0)){yAi[t[135904>>2]&511](t[33980]|0,187608,a);t[o>>2]=-1;_=t[o>>2]|0;s=u;return _|0}}a=t[(t[(t[c>>2]|0)+20>>2]|0)+296>>2]|0;do if(t[(t[c>>2]|0)+88>>2]|0){w=t[(t[c>>2]|0)+88>>2]|0;d=(t[(t[c>>2]|0)+20>>2]|0)+296|0;if(!a){t[d>>2]=w;break}if((w|0)!=(t[d>>2]|0)){bz(t[(t[c>>2]|0)+88>>2]|0);t[(t[c>>2]|0)+88>>2]=t[(t[(t[c>>2]|0)+20>>2]|0)+296>>2]}}else{if(!a){d=lz()|0;t[(t[(t[c>>2]|0)+20>>2]|0)+296>>2]=d}t[(t[c>>2]|0)+88>>2]=t[(t[(t[c>>2]|0)+20>>2]|0)+296>>2]}while(0);t[(t[(t[c>>2]|0)+20>>2]|0)+272>>2]=t[c>>2];t[(t[(t[c>>2]|0)+20>>2]|0)+280>>2]=1;t[(t[(t[c>>2]|0)+20>>2]|0)+364>>2]=1;t[(t[(t[c>>2]|0)+20>>2]|0)+308>>2]=1;t[(t[(t[c>>2]|0)+20>>2]|0)+436>>2]=5;if(t[(t[c>>2]|0)+164>>2]|0){So(t[(t[c>>2]|0)+164>>2]|0);t[(t[c>>2]|0)+164>>2]=0}a=(t[c>>2]|0)+156|0;if(t[h>>2]&1024){t[a>>2]=1;d=kz(t[(t[c>>2]|0)+88>>2]|0,187696,-1)|0;t[(t[c>>2]|0)+160>>2]=d;t[h>>2]=(t[h>>2]|0)-1024}else t[a>>2]=0;t[(t[c>>2]|0)+168>>2]=0;if(!(t[(t[c>>2]|0)+180>>2]|0)){t[(t[c>>2]|0)+172>>2]=0;t[(t[c>>2]|0)+176>>2]=0}while(1){if((t[(t[c>>2]|0)+172>>2]|0)<=0)break;a=(t[c>>2]|0)+172|0;t[a>>2]=(t[a>>2]|0)+-1;if(!(t[(t[(t[c>>2]|0)+180>>2]|0)+(t[(t[c>>2]|0)+172>>2]<<2)>>2]|0))continue;vj(t[(t[(t[c>>2]|0)+180>>2]|0)+(t[(t[c>>2]|0)+172>>2]<<2)>>2]|0);t[(t[(t[c>>2]|0)+180>>2]|0)+(t[(t[c>>2]|0)+172>>2]<<2)>>2]=0}if(t[h>>2]&16)t[(t[c>>2]|0)+8>>2]=1;mS(t[(t[c>>2]|0)+20>>2]|0,t[h>>2]|0)|0;if((t[k>>2]|0)!=0?(t[m>>2]=V_(t[k>>2]|0)|0,(t[m>>2]|0)!=0):0)Lp(t[(t[c>>2]|0)+20>>2]|0,t[m>>2]|0)|0;if(((t[b>>2]|0)!=0?(t[(t[(t[c>>2]|0)+20>>2]|0)+36>>2]|0)!=0:0)?(t[(t[(t[(t[c>>2]|0)+20>>2]|0)+36>>2]|0)+4>>2]|0)==0:0){m=Yl(t[b>>2]|0)|0;t[(t[(t[(t[c>>2]|0)+20>>2]|0)+36>>2]|0)+4>>2]=m}t[(t[c>>2]|0)+4>>2]=0;t[o>>2]=0;_=t[o>>2]|0;s=u;return _|0}function ZI(e){e=e|0;var i=0,r=0,n=0,f=0,u=0;i=s;s=s+16|0;r=i+12|0;n=i+8|0;f=i+4|0;t[n>>2]=e;if(!(t[n>>2]|0)){t[r>>2]=0;u=t[r>>2]|0;s=i;return u|0}t[f>>2]=gAi[t[135744>>2]&511](196)|0;if(!(t[f>>2]|0)){yAi[t[135904>>2]&511](t[33980]|0,187440,i);t[r>>2]=0;u=t[r>>2]|0;s=i;return u|0}else{VY(t[f>>2]|0,0,196)|0;t[(t[f>>2]|0)+96>>2]=0;t[(t[f>>2]|0)+28>>2]=0;t[t[f>>2]>>2]=0;t[(t[f>>2]|0)+64>>2]=0;t[(t[f>>2]|0)+68>>2]=0;t[(t[f>>2]|0)+56>>2]=0;t[(t[f>>2]|0)+60>>2]=0;t[(t[f>>2]|0)+12>>2]=2;t[(t[f>>2]|0)+4>>2]=t[n>>2];t[(t[f>>2]|0)+16>>2]=0;n=lz()|0;t[(t[f>>2]|0)+88>>2]=n;t[r>>2]=t[f>>2];u=t[r>>2]|0;s=i;return u|0}return 0}function JI(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;var u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0;u=s;s=s+32|0;a=u+28|0;o=u+24|0;c=u+20|0;l=u+16|0;b=u+12|0;k=u+8|0;h=u+4|0;w=u;t[o>>2]=e;t[c>>2]=i;t[l>>2]=r;t[b>>2]=n;t[k>>2]=f;t[w>>2]=WO(t[o>>2]|0,t[c>>2]|0,0)|0;if(!(t[w>>2]|0)){t[a>>2]=0;d=t[a>>2]|0;s=u;return d|0}t[h>>2]=LI(t[w>>2]|0,t[l>>2]|0)|0;if(!(t[h>>2]|0)){IO(t[w>>2]|0);t[a>>2]=0;d=t[a>>2]|0;s=u;return d|0}else{w=(t[h>>2]|0)+12|0;t[w>>2]=t[w>>2]|1;XI(t[h>>2]|0,0,t[l>>2]|0,t[b>>2]|0,t[k>>2]|0)|0;t[a>>2]=t[h>>2];d=t[a>>2]|0;s=u;return d|0}return 0}function QI(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,l=0;n=s;s=s+32|0;f=n+16|0;u=n+12|0;a=n+8|0;o=n+4|0;c=n;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;t[c>>2]=DI(t[u>>2]|0)|0;if(!(t[c>>2]|0)){t[f>>2]=0;l=t[f>>2]|0;s=n;return l|0}else{XI(t[c>>2]|0,0,0,t[a>>2]|0,t[o>>2]|0)|0;t[f>>2]=t[c>>2];l=t[f>>2]|0;s=n;return l|0}return 0}function $I(e){e=e|0;var i=0,r=0,n=0,f=0,u=0,a=0,o=0,c=0;i=s;s=s+16|0;r=i+4|0;n=i;t[n>>2]=e;if((t[(t[n>>2]|0)+16>>2]|0)==2){t[r>>2]=0;f=t[r>>2]|0;s=i;return f|0}e:while(1){e=t[n>>2]|0;do if(!(t[(t[n>>2]|0)+64>>2]|0)){u=t[n>>2]|0;if(!(t[(t[e+4>>2]|0)+12>>2]|0)){a=5;break e}t[(t[n>>2]|0)+64>>2]=t[(t[u+4>>2]|0)+12>>2];t[(t[n>>2]|0)+16>>2]=0}else{if((((t[e+16>>2]|0)!=4?(t[(t[(t[n>>2]|0)+64>>2]|0)+4>>2]|0)!=14:0)?(t[(t[(t[n>>2]|0)+64>>2]|0)+4>>2]|0)!=19:0)?(t[(t[(t[n>>2]|0)+64>>2]|0)+4>>2]|0)!=5:0){o=t[(t[n>>2]|0)+64>>2]|0;if(t[(t[(t[n>>2]|0)+64>>2]|0)+12>>2]|0){t[(t[n>>2]|0)+64>>2]=t[o+12>>2];c=(t[n>>2]|0)+72|0;t[c>>2]=(t[c>>2]|0)+1;t[(t[n>>2]|0)+16>>2]=0;break}if((t[o+4>>2]|0)==2){t[(t[n>>2]|0)+16>>2]=4;break}}o=t[(t[n>>2]|0)+64>>2]|0;if(t[(t[(t[n>>2]|0)+64>>2]|0)+24>>2]|0){t[(t[n>>2]|0)+64>>2]=t[o+24>>2];t[(t[n>>2]|0)+16>>2]=0;break}c=t[n>>2]|0;if(!(t[o+20>>2]|0)){t[c+16>>2]=2;break}if((t[(t[(t[c+64>>2]|0)+20>>2]|0)+4>>2]|0)==9){a=20;break e}if((t[(t[(t[(t[n>>2]|0)+64>>2]|0)+20>>2]|0)+4>>2]|0)==13){a=20;break e}t[(t[n>>2]|0)+64>>2]=t[(t[(t[n>>2]|0)+64>>2]|0)+20>>2];c=(t[n>>2]|0)+72|0;t[c>>2]=(t[c>>2]|0)+-1;t[(t[n>>2]|0)+16>>2]=4}while(0);if((t[(t[(t[n>>2]|0)+64>>2]|0)+4>>2]|0)==19)continue;if((t[(t[(t[n>>2]|0)+64>>2]|0)+4>>2]|0)!=20){a=25;break}}if((a|0)==5){t[u+16>>2]=2;t[r>>2]=0;f=t[r>>2]|0;s=i;return f|0}else if((a|0)==20){t[(t[n>>2]|0)+16>>2]=2;t[r>>2]=0;f=t[r>>2]|0;s=i;return f|0}else if((a|0)==25){t[r>>2]=1;f=t[r>>2]|0;s=i;return f|0}return 0}function eH(e){e=e|0;var i=0,r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0;i=s;s=s+32|0;r=i+24|0;n=i+20|0;f=i+16|0;u=i+12|0;a=i+8|0;o=i+4|0;c=i;t[n>>2]=e;if((t[(t[n>>2]|0)+28>>2]|0)!=0?(t[(t[(t[n>>2]|0)+28>>2]|0)+16>>2]|0)!=0:0){t[o>>2]=t[(t[n>>2]|0)+16>>2];t[(t[n>>2]|0)+16>>2]=-1;t[f>>2]=t[(t[(t[n>>2]|0)+28>>2]|0)+16>>2];t[c>>2]=ps(t[f>>2]|0)|0;e:do{if((t[(t[n>>2]|0)+16>>2]|0)!=-1)break;e=Ts(t[f>>2]|0)|0;do if(e>>>0<((t[(t[n>>2]|0)+60>>2]|0)+512|0)>>>0){if((t[t[n>>2]>>2]|0)==3)break e;t[u>>2]=QO(t[(t[n>>2]|0)+28>>2]|0,4096)|0;if((t[u>>2]|0)==0&(t[c>>2]|0)==2){l=Ts(t[f>>2]|0)|0;if((l|0)!=(t[(t[n>>2]|0)+60>>2]|0))break;t[t[n>>2]>>2]=3;t[(t[n>>2]|0)+16>>2]=t[o>>2];break}if((t[u>>2]|0)>=0)if(!(t[u>>2]|0)){b=16;break e}else break;t[t[n>>2]>>2]=3;t[(t[n>>2]|0)+16>>2]=t[o>>2];if(t[o>>2]|0){b=14;break e}if(t[(t[(t[n>>2]|0)+20>>2]|0)+8>>2]|0){b=14;break e}}while(0);e=Ts(t[f>>2]|0)|0;if(e>>>0<((t[(t[n>>2]|0)+60>>2]|0)+512|0)>>>0){b=21;break}e=t[(t[n>>2]|0)+20>>2]|0;l=Os(t[f>>2]|0)|0;t[u>>2]=nS(e,l+(t[(t[n>>2]|0)+60>>2]|0)|0,512,0)|0;l=(t[n>>2]|0)+60|0;t[l>>2]=(t[l>>2]|0)+512;if(t[u>>2]|0)t[(t[(t[n>>2]|0)+20>>2]|0)+12>>2]=0}while((t[(t[(t[n>>2]|0)+20>>2]|0)+12>>2]|0)!=0);if((b|0)==14){t[r>>2]=t[u>>2];k=t[r>>2]|0;s=i;return k|0}else if((b|0)==16)t[t[n>>2]>>2]=3;else if((b|0)==21?(b=Ts(t[f>>2]|0)|0,t[a>>2]=b-(t[(t[n>>2]|0)+60>>2]|0),b=t[(t[n>>2]|0)+20>>2]|0,l=Os(t[f>>2]|0)|0,t[u>>2]=nS(b,l+(t[(t[n>>2]|0)+60>>2]|0)|0,t[a>>2]|0,0)|0,l=(t[n>>2]|0)+60|0,t[l>>2]=(t[l>>2]|0)+(t[a>>2]|0),(t[u>>2]|0)!=0):0)t[(t[(t[n>>2]|0)+20>>2]|0)+12>>2]=0;do if((t[t[n>>2]>>2]|0)==1){if((((t[c>>2]|0)!=2?(t[(t[n>>2]|0)+60>>2]|0)>>>0>=4096:0)?(l=Ts(t[f>>2]|0)|0,(l-(t[(t[n>>2]|0)+60>>2]|0)|0)>>>0<=512):0)?(t[u>>2]=ys(t[f>>2]|0,t[(t[n>>2]|0)+60>>2]|0)|0,(t[u>>2]|0)>=0):0){l=(t[n>>2]|0)+60|0;t[l>>2]=(t[l>>2]|0)-(t[u>>2]|0)}}else if(((t[t[n>>2]>>2]|0)==3?(t[(t[n>>2]|0)+16>>2]|0)!=5:0)?(l=Ts(t[f>>2]|0)|0,t[a>>2]=l-(t[(t[n>>2]|0)+60>>2]|0),l=t[(t[n>>2]|0)+20>>2]|0,b=Os(t[f>>2]|0)|0,t[u>>2]=nS(l,b+(t[(t[n>>2]|0)+60>>2]|0)|0,t[a>>2]|0,1)|0,b=Ts(t[f>>2]|0)|0,t[(t[n>>2]|0)+60>>2]=b,t[(t[n>>2]|0)+16>>2]=5,(t[u>>2]|0)!=0):0){if(t[(t[(t[n>>2]|0)+20>>2]|0)+12>>2]|0){t[(t[(t[n>>2]|0)+20>>2]|0)+12>>2]=0;break}t[r>>2]=-1;k=t[r>>2]|0;s=i;return k|0}while(0);t[(t[n>>2]|0)+16>>2]=t[o>>2];if(!(t[(t[(t[n>>2]|0)+20>>2]|0)+12>>2]|0)){t[t[n>>2]>>2]=3;t[r>>2]=-1;k=t[r>>2]|0;s=i;return k|0}else{t[r>>2]=0;k=t[r>>2]|0;s=i;return k|0}}t[r>>2]=-1;k=t[r>>2]|0;s=i;return k|0}function iH(e){e=e|0;var i=0,r=0,n=0,f=0,u=0,a=0;i=s;s=s+16|0;r=i+12|0;n=i+8|0;f=i+4|0;u=i;t[r>>2]=e;t[n>>2]=t[(t[r>>2]|0)+64>>2];do if(((t[(t[r>>2]|0)+8>>2]|0)==1?(t[(t[r>>2]|0)+20>>2]|0)!=0:0)?(t[(t[(t[r>>2]|0)+20>>2]|0)+104>>2]|0)==1:0){if((t[(t[n>>2]|0)+36>>2]|0)!=0?(t[(t[(t[n>>2]|0)+36>>2]|0)+12>>2]|0)!=0:0){t[f>>2]=Yl(t[(t[(t[n>>2]|0)+36>>2]|0)+12>>2]|0)|0;t[f>>2]=us(t[f>>2]|0,187520)|0;t[f>>2]=us(t[f>>2]|0,t[(t[n>>2]|0)+8>>2]|0)|0;e=sR((t[(t[r>>2]|0)+20>>2]|0)+108|0,t[(t[(t[r>>2]|0)+20>>2]|0)+8>>2]|0,t[n>>2]|0,t[f>>2]|0)|0;a=(t[(t[r>>2]|0)+20>>2]|0)+100|0;t[a>>2]=t[a>>2]&e;if(!(t[f>>2]|0))break;pAi[t[135736>>2]&511](t[f>>2]|0);break}e=sR((t[(t[r>>2]|0)+20>>2]|0)+108|0,t[(t[(t[r>>2]|0)+20>>2]|0)+8>>2]|0,t[n>>2]|0,t[(t[n>>2]|0)+8>>2]|0)|0;a=(t[(t[r>>2]|0)+20>>2]|0)+100|0;t[a>>2]=t[a>>2]&e}while(0);if((t[(t[r>>2]|0)+8>>2]|0)!=2){s=i;return}if(!(t[(t[r>>2]|0)+120>>2]|0)){s=i;return}if(t[(t[r>>2]|0)+132>>2]|0){if((t[n>>2]|0)!=(t[(t[r>>2]|0)+132>>2]|0)){s=i;return}t[(t[r>>2]|0)+132>>2]=0;s=i;return}else{t[u>>2]=VH(t[(t[r>>2]|0)+120>>2]|0,t[(t[(t[r>>2]|0)+20>>2]|0)+8>>2]|0,t[n>>2]|0)|0;if((t[u>>2]|0)==1){s=i;return}u=(t[r>>2]|0)+128|0;t[u>>2]=(t[u>>2]|0)+1;s=i;return}}function rH(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0;r=s;s=s+16|0;n=r+8|0;f=r+4|0;u=r;t[n>>2]=e;t[f>>2]=i;if((t[n>>2]|0)!=0?(t[(t[n>>2]|0)+20>>2]|0)!=0:0)t[u>>2]=t[(t[(t[n>>2]|0)+20>>2]|0)+296>>2];else t[u>>2]=0;i=t[f>>2]|0;if((t[(t[f>>2]|0)+4>>2]|0)==14){ey(i);s=r;return}e=t[f>>2]|0;if((t[i+4>>2]|0)==18){Kg(e);s=r;return}if((t[e+4>>2]|0)==2){FH(t[n>>2]|0,t[f>>2]|0);s=r;return}if((t[(t[f>>2]|0)+12>>2]|0)!=0?(t[(t[f>>2]|0)+4>>2]|0)!=5:0){if((t[(t[(t[f>>2]|0)+12>>2]|0)+20>>2]|0)==(t[f>>2]|0))OH(t[n>>2]|0,t[(t[f>>2]|0)+12>>2]|0);t[(t[f>>2]|0)+12>>2]=0}if((t[18774]|0)!=0&(t[33970]|0)!=0)pAi[t[135880>>2]&511](t[f>>2]|0);if(!(((t[(t[f>>2]|0)+4>>2]|0)!=1?(t[(t[f>>2]|0)+4>>2]|0)!=19:0)?(t[(t[f>>2]|0)+4>>2]|0)!=20:0))a=21;if((a|0)==21?(t[(t[f>>2]|0)+44>>2]|0)!=0:0)AH(t[n>>2]|0,t[(t[f>>2]|0)+44>>2]|0);do if((((((t[(t[f>>2]|0)+40>>2]|0)!=((t[f>>2]|0)+44|0)?(t[(t[f>>2]|0)+4>>2]|0)!=1:0)?(t[(t[f>>2]|0)+4>>2]|0)!=19:0)?(t[(t[f>>2]|0)+4>>2]|0)!=20:0)?(t[(t[f>>2]|0)+4>>2]|0)!=5:0)?(t[(t[f>>2]|0)+40>>2]|0)!=0:0){if((t[u>>2]|0)!=0?(wz(t[u>>2]|0,t[(t[f>>2]|0)+40>>2]|0)|0)!=0:0)break;pAi[t[135736>>2]&511](t[(t[f>>2]|0)+40>>2]|0)}while(0);if(!(((t[(t[f>>2]|0)+4>>2]|0)!=1?(t[(t[f>>2]|0)+4>>2]|0)!=19:0)?(t[(t[f>>2]|0)+4>>2]|0)!=20:0))a=35;if((a|0)==35?(t[(t[f>>2]|0)+48>>2]|0)!=0:0)Zg(t[(t[f>>2]|0)+48>>2]|0);do if(((t[(t[f>>2]|0)+4>>2]|0)!=3?(t[(t[f>>2]|0)+4>>2]|0)!=8:0)?(t[(t[f>>2]|0)+8>>2]|0)!=0:0){if((t[u>>2]|0)!=0?(wz(t[u>>2]|0,t[(t[f>>2]|0)+8>>2]|0)|0)!=0:0)break;pAi[t[135736>>2]&511](t[(t[f>>2]|0)+8>>2]|0)}while(0);if((t[(t[f>>2]|0)+4>>2]|0)==1){if(t[n>>2]|0)a=46}else if((t[n>>2]|0)!=0?(t[(t[f>>2]|0)+4>>2]|0)==3:0)a=46;if(((a|0)==46?(t[(t[n>>2]|0)+20>>2]|0)!=0:0)?(t[(t[(t[n>>2]|0)+20>>2]|0)+368>>2]|0)<100:0){t[(t[f>>2]|0)+24>>2]=t[(t[(t[n>>2]|0)+20>>2]|0)+372>>2];t[(t[(t[n>>2]|0)+20>>2]|0)+372>>2]=t[f>>2];a=(t[(t[n>>2]|0)+20>>2]|0)+368|0;t[a>>2]=(t[a>>2]|0)+1;s=r;return}pAi[t[135736>>2]&511](t[f>>2]|0);s=r;return}function nH(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0;r=s;s=s+16|0;n=r;f=r+12|0;u=r+8|0;a=r+4|0;t[u>>2]=e;t[a>>2]=i;
	if((t[(t[u>>2]|0)+100>>2]|0)<=0?(t[(t[u>>2]|0)+100>>2]=10,i=gAi[t[135744>>2]&511](t[(t[u>>2]|0)+100>>2]<<2)|0,t[(t[u>>2]|0)+104>>2]=i,(t[(t[u>>2]|0)+104>>2]|0)==0):0){yAi[t[135904>>2]&511](t[33980]|0,187648,n);t[f>>2]=0;o=t[f>>2]|0;s=r;return o|0}if((t[(t[u>>2]|0)+96>>2]|0)>=(t[(t[u>>2]|0)+100>>2]|0)?(i=(t[u>>2]|0)+100|0,t[i>>2]=t[i>>2]<<1,i=MAi[t[135760>>2]&511](t[(t[u>>2]|0)+104>>2]|0,t[(t[u>>2]|0)+100>>2]<<2)|0,t[(t[u>>2]|0)+104>>2]=i,(t[(t[u>>2]|0)+104>>2]|0)==0):0){yAi[t[135904>>2]&511](t[33980]|0,187672,n);t[f>>2]=0;o=t[f>>2]|0;s=r;return o|0}t[(t[(t[u>>2]|0)+104>>2]|0)+(t[(t[u>>2]|0)+96>>2]<<2)>>2]=t[a>>2];t[(t[u>>2]|0)+92>>2]=t[a>>2];a=(t[u>>2]|0)+96|0;u=t[a>>2]|0;t[a>>2]=u+1;t[f>>2]=u;o=t[f>>2]|0;s=r;return o|0}function fH(e){e=e|0;var i=0,r=0,n=0,f=0,u=0,o=0,c=0,l=0,b=0,k=0;i=s;s=s+32|0;r=i+16|0;n=i+12|0;f=i+8|0;u=i+4|0;o=i;t[r>>2]=e;t[n>>2]=t[(t[r>>2]|0)+64>>2];t[f>>2]=t[(t[r>>2]|0)+64>>2];t[u>>2]=t[(t[r>>2]|0)+20>>2];e:while(1){e=t[f>>2]|0;do if((t[(t[f>>2]|0)+4>>2]|0)==5){if(((t[e+12>>2]|0)==0?(t[t[u>>2]>>2]|0)!=0:0)?(t[(t[t[u>>2]>>2]|0)+20>>2]|0)!=0:0){c=MAi[t[(t[t[u>>2]>>2]|0)+20>>2]&511](t[u>>2]|0,t[(t[f>>2]|0)+8>>2]|0)|0;t[(t[f>>2]|0)+12>>2]=c}if(((t[(t[f>>2]|0)+12>>2]|0)!=0?(t[(t[(t[f>>2]|0)+12>>2]|0)+4>>2]|0)==17:0)?(t[(t[(t[f>>2]|0)+12>>2]|0)+12>>2]|0)!=0:0){nH(t[r>>2]|0,t[f>>2]|0)|0;t[f>>2]=t[(t[(t[f>>2]|0)+12>>2]|0)+12>>2];break}if((t[f>>2]|0)==(t[n>>2]|0)){l=41;break e}t[f>>2]=t[(t[f>>2]|0)+24>>2];l=18}else{c=t[f>>2]|0;if((t[e+4>>2]|0)==1){t[(t[r>>2]|0)+64>>2]=c;uH(t[r>>2]|0);l=18;break}if((t[c+4>>2]|0)!=3?(t[(t[f>>2]|0)+4>>2]|0)!=4:0){l=18;break}c=t[r>>2]|0;b=t[(t[f>>2]|0)+40>>2]|0;aH(c,b,rs(t[(t[f>>2]|0)+40>>2]|0)|0);l=18}while(0);i:do if((l|0)==18){l=0;e=t[f>>2]|0;if(t[(t[f>>2]|0)+12>>2]|0){t[f>>2]=t[e+12>>2];break}if((t[e+4>>2]|0)==1)iH(t[r>>2]|0);if(t[(t[f>>2]|0)+24>>2]|0){t[f>>2]=t[(t[f>>2]|0)+24>>2];break}while(1){t[f>>2]=t[(t[f>>2]|0)+20>>2];if((t[(t[f>>2]|0)+4>>2]|0)==1){r:do if(!(t[(t[r>>2]|0)+96>>2]|0))while(1){e=t[(t[f>>2]|0)+16>>2]|0;t[o>>2]=e;if(!e)break r;if((a[(t[o>>2]|0)+58>>1]|0)&2)break r;iy(t[o>>2]|0);rH(t[r>>2]|0,t[o>>2]|0)}while(0);t[(t[r>>2]|0)+64>>2]=t[f>>2];iH(t[r>>2]|0)}if(((t[(t[f>>2]|0)+4>>2]|0)==17?(t[(t[r>>2]|0)+92>>2]|0)!=0:0)?(t[(t[(t[r>>2]|0)+92>>2]|0)+12>>2]|0)==(t[f>>2]|0):0)t[f>>2]=tH(t[r>>2]|0)|0;if((t[f>>2]|0)==(t[n>>2]|0))break i;k=t[f>>2]|0;if(t[(t[f>>2]|0)+24>>2]|0)break;if(!k)break i;if((t[f>>2]|0)==(t[n>>2]|0))break i}t[f>>2]=t[k+24>>2]}while(0);if(!(t[f>>2]|0)){l=41;break}if((t[f>>2]|0)==(t[n>>2]|0)){l=41;break}}if((l|0)==41){t[(t[r>>2]|0)+64>>2]=t[n>>2];s=i;return}}function tH(e){e=e|0;var i=0,r=0,n=0,f=0,u=0;i=s;s=s+16|0;r=i+8|0;n=i+4|0;f=i;t[n>>2]=e;if((t[(t[n>>2]|0)+96>>2]|0)<=0){t[r>>2]=0;u=t[r>>2]|0;s=i;return u|0}e=(t[n>>2]|0)+96|0;t[e>>2]=(t[e>>2]|0)+-1;e=t[n>>2]|0;if((t[(t[n>>2]|0)+96>>2]|0)>0)t[(t[n>>2]|0)+92>>2]=t[(t[(t[n>>2]|0)+104>>2]|0)+((t[e+96>>2]|0)-1<<2)>>2];else t[e+92>>2]=0;t[f>>2]=t[(t[(t[n>>2]|0)+104>>2]|0)+(t[(t[n>>2]|0)+96>>2]<<2)>>2];t[(t[(t[n>>2]|0)+104>>2]|0)+(t[(t[n>>2]|0)+96>>2]<<2)>>2]=0;t[r>>2]=t[f>>2];u=t[r>>2]|0;s=i;return u|0}function uH(e){e=e|0;var i=0,r=0,n=0,f=0,u=0,a=0,o=0;i=s;s=s+32|0;r=i;n=i+16|0;f=i+12|0;u=i+8|0;a=i+4|0;t[n>>2]=e;t[f>>2]=t[(t[n>>2]|0)+64>>2];do if(((t[(t[n>>2]|0)+8>>2]|0)==1?(t[(t[n>>2]|0)+20>>2]|0)!=0:0)?(t[(t[(t[n>>2]|0)+20>>2]|0)+104>>2]|0)==1:0){if((t[(t[f>>2]|0)+36>>2]|0)!=0?(t[(t[(t[f>>2]|0)+36>>2]|0)+12>>2]|0)!=0:0){t[u>>2]=Yl(t[(t[(t[f>>2]|0)+36>>2]|0)+12>>2]|0)|0;t[u>>2]=us(t[u>>2]|0,187520)|0;t[u>>2]=us(t[u>>2]|0,t[(t[f>>2]|0)+8>>2]|0)|0;e=cR((t[(t[n>>2]|0)+20>>2]|0)+108|0,t[(t[(t[n>>2]|0)+20>>2]|0)+8>>2]|0,t[f>>2]|0,t[u>>2]|0)|0;o=(t[(t[n>>2]|0)+20>>2]|0)+100|0;t[o>>2]=t[o>>2]&e;if(!(t[u>>2]|0))break;pAi[t[135736>>2]&511](t[u>>2]|0);break}e=cR((t[(t[n>>2]|0)+20>>2]|0)+108|0,t[(t[(t[n>>2]|0)+20>>2]|0)+8>>2]|0,t[f>>2]|0,t[(t[f>>2]|0)+8>>2]|0)|0;o=(t[(t[n>>2]|0)+20>>2]|0)+100|0;t[o>>2]=t[o>>2]&e}while(0);if((t[(t[n>>2]|0)+8>>2]|0)!=2){s=i;return}if(!(t[(t[n>>2]|0)+120>>2]|0)){s=i;return}if(t[(t[n>>2]|0)+132>>2]|0){s=i;return}t[a>>2]=zH(t[(t[n>>2]|0)+120>>2]|0,t[(t[(t[n>>2]|0)+20>>2]|0)+8>>2]|0,t[f>>2]|0)|0;do if(!(t[a>>2]|0)){t[f>>2]=NI(t[n>>2]|0)|0;if(!(t[f>>2]|0)){Je(187736,r|0)|0;t[a>>2]=-1;break}else{t[a>>2]=qH(t[(t[n>>2]|0)+120>>2]|0,t[(t[(t[n>>2]|0)+20>>2]|0)+8>>2]|0,t[f>>2]|0)|0;t[(t[n>>2]|0)+132>>2]=t[f>>2];break}}while(0);if((t[a>>2]|0)==1){s=i;return}a=(t[n>>2]|0)+128|0;t[a>>2]=(t[a>>2]|0)+1;s=i;return}function aH(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0;n=s;s=s+16|0;f=n+12|0;u=n+8|0;a=n+4|0;o=n;t[f>>2]=e;t[u>>2]=i;t[a>>2]=r;if(((t[(t[f>>2]|0)+8>>2]|0)==1?(t[(t[f>>2]|0)+20>>2]|0)!=0:0)?(t[(t[(t[f>>2]|0)+20>>2]|0)+104>>2]|0)==1:0){r=lR((t[(t[f>>2]|0)+20>>2]|0)+108|0,t[u>>2]|0,t[a>>2]|0)|0;i=(t[(t[f>>2]|0)+20>>2]|0)+100|0;t[i>>2]=t[i>>2]&r}if((t[(t[f>>2]|0)+8>>2]|0)!=2){s=n;return}if(!(t[(t[f>>2]|0)+120>>2]|0)){s=n;return}if(t[(t[f>>2]|0)+132>>2]|0){s=n;return}t[o>>2]=jH(t[(t[f>>2]|0)+120>>2]|0,t[u>>2]|0,t[a>>2]|0)|0;if((t[o>>2]|0)==1){s=n;return}o=(t[f>>2]|0)+128|0;t[o>>2]=(t[o>>2]|0)+1;s=n;return}function oH(e){e=e|0;var i=0,r=0,n=0,f=0,u=0,a=0;i=s;s=s+16|0;r=i+8|0;n=i+4|0;f=i;t[n>>2]=e;do if(((t[n>>2]|0)!=0?(t[(t[n>>2]|0)+64>>2]|0)!=0:0)?(t[(t[n>>2]|0)+20>>2]|0)!=0:0){while(1){if((t[(t[(t[n>>2]|0)+20>>2]|0)+172>>2]|0)==-1){u=6;break}if(MH(t[(t[n>>2]|0)+64>>2]|0)|0){u=8;break}if((t[(t[(t[n>>2]|0)+20>>2]|0)+56>>2]|0)<(t[(t[n>>2]|0)+72>>2]|0)){u=10;break}if((t[t[n>>2]>>2]|0)==3){u=12;break}t[f>>2]=eH(t[n>>2]|0)|0;a=t[n>>2]|0;if((t[f>>2]|0)<0){u=14;break}if((t[a>>2]|0)==3){u=16;break}}if((u|0)==6){t[r>>2]=1;break}else if((u|0)==8){t[r>>2]=1;break}else if((u|0)==10){t[r>>2]=1;break}else if((u|0)==12){t[r>>2]=1;break}else if((u|0)==14){t[a>>2]=2;t[r>>2]=-1;break}else if((u|0)==16){t[r>>2]=1;break}}else u=4;while(0);if((u|0)==4)t[r>>2]=-1;s=i;return t[r>>2]|0}function cH(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,a=0,o=0,c=0,l=0,b=0;n=s;s=s+32|0;a=n+16|0;o=n+12|0;c=n+8|0;l=n+4|0;b=n;t[a>>2]=e;t[o>>2]=i;t[c>>2]=r;t[l>>2]=t[a>>2];t[b>>2]=t[(t[l>>2]|0)+272>>2];if(((((((t[b>>2]|0)!=0?(t[(t[b>>2]|0)+32>>2]|0)!=0:0)?(yAi[t[(t[b>>2]|0)+32>>2]&511](t[a>>2]|0,t[o>>2]|0,t[c>>2]|0),(t[(t[l>>2]|0)+52>>2]|0)!=0):0)?(t[(t[l>>2]|0)+36>>2]|0)!=0:0)?(t[(t[(t[l>>2]|0)+36>>2]|0)+16>>2]|0)!=0:0)?(u[t[(t[(t[l>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==47:0)?(u[(t[(t[(t[l>>2]|0)+36>>2]|0)+16>>2]|0)+1>>0]|0|0)==62:0)f[(t[(t[l>>2]|0)+52>>2]|0)+58>>1]=1;if(!(t[b>>2]|0)){s=n;return}t[(t[b>>2]|0)+16>>2]=1;s=n;return}function lH(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0;r=s;s=s+16|0;n=r+12|0;f=r+8|0;u=r+4|0;a=r;t[n>>2]=e;t[f>>2]=i;t[u>>2]=t[n>>2];t[a>>2]=t[(t[u>>2]|0)+272>>2];if(!(t[a>>2]|0)){s=r;return}if(!(t[(t[a>>2]|0)+36>>2]|0)){s=r;return}EAi[t[(t[a>>2]|0)+36>>2]&511](t[n>>2]|0,t[f>>2]|0);s=r;return}function sH(e,i,r,n,a,o,c,l,b){e=e|0;i=i|0;r=r|0;n=n|0;a=a|0;o=o|0;c=c|0;l=l|0;b=b|0;var k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0,S=0,g=0,y=0;k=s;s=s+48|0;h=k+40|0;w=k+36|0;d=k+32|0;v=k+28|0;m=k+24|0;_=k+20|0;p=k+16|0;E=k+12|0;S=k+8|0;g=k+4|0;y=k;t[h>>2]=e;t[w>>2]=i;t[d>>2]=r;t[v>>2]=n;t[m>>2]=a;t[_>>2]=o;t[p>>2]=c;t[E>>2]=l;t[S>>2]=b;t[g>>2]=t[h>>2];t[y>>2]=t[(t[g>>2]|0)+272>>2];if(((((((t[y>>2]|0)!=0?(t[(t[y>>2]|0)+40>>2]|0)!=0:0)?(FAi[t[(t[y>>2]|0)+40>>2]&511](t[h>>2]|0,t[w>>2]|0,t[d>>2]|0,t[v>>2]|0,t[m>>2]|0,t[_>>2]|0,t[p>>2]|0,t[E>>2]|0,t[S>>2]|0),(t[(t[g>>2]|0)+52>>2]|0)!=0):0)?(t[(t[g>>2]|0)+36>>2]|0)!=0:0)?(t[(t[(t[g>>2]|0)+36>>2]|0)+16>>2]|0)!=0:0)?(u[t[(t[(t[g>>2]|0)+36>>2]|0)+16>>2]>>0]|0|0)==47:0)?(u[(t[(t[(t[g>>2]|0)+36>>2]|0)+16>>2]|0)+1>>0]|0|0)==62:0)f[(t[(t[g>>2]|0)+52>>2]|0)+58>>1]=1;if(!(t[y>>2]|0)){s=k;return}t[(t[y>>2]|0)+16>>2]=1;s=k;return}function bH(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,u=0,a=0,o=0,c=0,l=0,b=0;f=s;s=s+32|0;u=f+20|0;a=f+16|0;o=f+12|0;c=f+8|0;l=f+4|0;b=f;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;t[c>>2]=n;t[l>>2]=t[u>>2];t[b>>2]=t[(t[l>>2]|0)+272>>2];if(!(t[b>>2]|0)){s=f;return}if(!(t[(t[b>>2]|0)+44>>2]|0)){s=f;return}NAi[t[(t[b>>2]|0)+44>>2]&511](t[u>>2]|0,t[a>>2]|0,t[o>>2]|0,t[c>>2]|0);s=f;return}function kH(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0;n=s;s=s+32|0;f=n+16|0;u=n+12|0;a=n+8|0;o=n+4|0;c=n;t[f>>2]=e;t[u>>2]=i;t[a>>2]=r;t[o>>2]=t[f>>2];t[c>>2]=t[(t[o>>2]|0)+272>>2];if(!(t[c>>2]|0)){s=n;return}if(!(t[(t[c>>2]|0)+48>>2]|0)){s=n;return}yAi[t[(t[c>>2]|0)+48>>2]&511](t[f>>2]|0,t[u>>2]|0,t[a>>2]|0);s=n;return}function hH(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0;n=s;s=s+32|0;f=n+16|0;u=n+12|0;a=n+8|0;o=n+4|0;c=n;t[f>>2]=e;t[u>>2]=i;t[a>>2]=r;t[o>>2]=t[f>>2];t[c>>2]=t[(t[o>>2]|0)+272>>2];if(!(t[c>>2]|0)){s=n;return}if(!(t[(t[c>>2]|0)+52>>2]|0)){s=n;return}yAi[t[(t[c>>2]|0)+52>>2]&511](t[f>>2]|0,t[u>>2]|0,t[a>>2]|0);s=n;return}function wH(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0;r=s;s=s+16|0;n=r+12|0;f=r+8|0;u=r+4|0;a=r;t[n>>2]=e;t[f>>2]=i;if(!(t[f>>2]|0)){s=r;return}if((t[18774]|0)!=0&(t[33970]|0)!=0)pAi[t[135880>>2]&511](t[f>>2]|0);if(t[(t[f>>2]|0)+64>>2]|0)RH(t[(t[f>>2]|0)+64>>2]|0);t[(t[f>>2]|0)+64>>2]=0;if(t[(t[f>>2]|0)+68>>2]|0)KM(t[(t[f>>2]|0)+68>>2]|0);t[(t[f>>2]|0)+68>>2]=0;t[u>>2]=t[(t[f>>2]|0)+48>>2];t[a>>2]=t[(t[f>>2]|0)+44>>2];if((t[a>>2]|0)==(t[u>>2]|0))t[u>>2]=0;if(t[u>>2]|0){iy(t[(t[f>>2]|0)+48>>2]|0);t[(t[f>>2]|0)+48>>2]=0;ey(t[u>>2]|0)}if(t[a>>2]|0){iy(t[(t[f>>2]|0)+44>>2]|0);t[(t[f>>2]|0)+44>>2]=0;ey(t[a>>2]|0)}if(t[(t[f>>2]|0)+12>>2]|0)OH(t[n>>2]|0,t[(t[f>>2]|0)+12>>2]|0);if(t[(t[f>>2]|0)+56>>2]|0)pAi[t[135736>>2]&511](t[(t[f>>2]|0)+56>>2]|0);if(t[(t[f>>2]|0)+8>>2]|0)pAi[t[135736>>2]&511](t[(t[f>>2]|0)+8>>2]|0);if(t[(t[f>>2]|0)+60>>2]|0)pAi[t[135736>>2]&511](t[(t[f>>2]|0)+60>>2]|0);if(t[(t[f>>2]|0)+52>>2]|0)Zg(t[(t[f>>2]|0)+52>>2]|0);if(t[(t[f>>2]|0)+72>>2]|0)pAi[t[135736>>2]&511](t[(t[f>>2]|0)+72>>2]|0);if(t[(t[f>>2]|0)+80>>2]|0)bz(t[(t[f>>2]|0)+80>>2]|0);pAi[t[135736>>2]&511](t[f>>2]|0);s=r;return}function dH(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,l=0;n=s;s=s+48|0;f=n;u=n+36|0;a=n+32|0;o=n+28|0;c=n+24|0;l=n+8|0;t[u>>2]=e;t[a>>2]=i;t[o>>2]=t[u>>2];t[l>>2]=r;t[c>>2]=NH(t[a>>2]|0,l)|0;if(t[(t[o>>2]|0)+108>>2]|0)NAi[t[(t[o>>2]|0)+108>>2]&511](t[(t[o>>2]|0)+112>>2]|0,t[c>>2]|0,2,0);else{o=t[u>>2]|0;t[f>>2]=t[c>>2];SH(o,187728,f)}if(!(t[c>>2]|0)){s=n;return}pAi[t[135736>>2]&511](t[c>>2]|0);s=n;return}function vH(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,l=0;n=s;s=s+48|0;f=n;u=n+36|0;a=n+32|0;o=n+28|0;c=n+24|0;l=n+8|0;t[u>>2]=e;t[a>>2]=i;t[o>>2]=t[u>>2];t[l>>2]=r;t[c>>2]=NH(t[a>>2]|0,l)|0;if(t[(t[o>>2]|0)+108>>2]|0)NAi[t[(t[o>>2]|0)+108>>2]&511](t[(t[o>>2]|0)+112>>2]|0,t[c>>2]|0,1,0);else{o=t[u>>2]|0;t[f>>2]=t[c>>2];gH(o,187728,f)}if(!(t[c>>2]|0)){s=n;return}pAi[t[135736>>2]&511](t[c>>2]|0);s=n;return}function mH(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0;r=s;s=s+16|0;n=r+8|0;f=r+4|0;u=r;t[n>>2]=e;t[f>>2]=i;t[u>>2]=t[n>>2];n=t[u>>2]|0;if(t[(t[u>>2]|0)+192>>2]|0){EAi[t[n+192>>2]&511](t[(t[u>>2]|0)+112>>2]|0,t[f>>2]|0);s=r;return}else{yH(n,t[f>>2]|0);s=r;return}}function _H(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0;n=s;s=s+32|0;f=n+28|0;u=n+24|0;a=n+20|0;o=n+16|0;c=n+12|0;l=n+8|0;b=n+4|0;k=n;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;if((t[u>>2]|0)!=0?!((t[a>>2]|0)==0&(t[o>>2]|0)==0):0){if(t[a>>2]|0)t[t[a>>2]>>2]=0;if(t[o>>2]|0)t[t[o>>2]>>2]=0;t[c>>2]=t[u>>2];if((t[(t[c>>2]|0)+20>>2]|0)!=0?(t[(t[(t[c>>2]|0)+20>>2]|0)+36>>2]|0)!=0:0){if(t[a>>2]|0)t[t[a>>2]>>2]=t[(t[(t[(t[c>>2]|0)+20>>2]|0)+36>>2]|0)+4>>2];if(t[o>>2]|0)t[t[o>>2]>>2]=t[(t[(t[(t[c>>2]|0)+20>>2]|0)+36>>2]|0)+28>>2];t[f>>2]=0;h=t[f>>2]|0;s=n;return h|0}if(!(t[(t[c>>2]|0)+64>>2]|0)){t[f>>2]=-1;h=t[f>>2]|0;s=n;return h|0}t[b>>2]=0;do if(t[o>>2]|0){t[l>>2]=Qy(t[(t[c>>2]|0)+64>>2]|0)|0;if((t[l>>2]|0)>0){t[t[o>>2]>>2]=t[l>>2];break}else{t[b>>2]=-1;break}}while(0);do if(t[a>>2]|0){t[k>>2]=t[(t[(t[c>>2]|0)+64>>2]|0)+32>>2];if((t[k>>2]|0)!=0?(t[(t[k>>2]|0)+72>>2]|0)!=0:0){t[t[a>>2]>>2]=t[(t[k>>2]|0)+72>>2];break}t[b>>2]=-1}while(0);t[f>>2]=t[b>>2];h=t[f>>2]|0;s=n;return h|0}t[f>>2]=-1;h=t[f>>2]|0;s=n;return h|0}function pH(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,u=0,a=0,o=0,c=0,l=0,b=0;f=s;s=s+32|0;u=f+20|0;a=f+16|0;o=f+12|0;c=f+8|0;l=f;t[a>>2]=e;t[o>>2]=i;t[c>>2]=r;t[f+4>>2]=n;if(!(t[a>>2]|0)){t[u>>2]=-1;b=t[u>>2]|0;s=f;return b|0}if((t[o>>2]|0)!=0&(t[c>>2]|0)!=0){t[u>>2]=-1;b=t[u>>2]|0;s=f;return b|0}do if((t[o>>2]|0)!=0|(t[c>>2]|0)!=0){if((t[t[a>>2]>>2]|0)==0?(t[(t[a>>2]|0)+20>>2]|0)!=0:0)break;t[u>>2]=-1;b=t[u>>2]|0;s=f;return b|0}while(0);if(t[(t[a>>2]|0)+152>>2]|0){jk(t[(t[a>>2]|0)+152>>2]|0)|0;t[(t[a>>2]|0)+152>>2]=0}if(t[(t[a>>2]|0)+140>>2]|0){if(!(t[(t[a>>2]|0)+144>>2]|0))Nk(t[(t[a>>2]|0)+140>>2]|0);t[(t[a>>2]|0)+140>>2]=0}t[(t[a>>2]|0)+144>>2]=0;if(t[(t[a>>2]|0)+136>>2]|0){Ak(t[(t[a>>2]|0)+136>>2]|0);t[(t[a>>2]|0)+136>>2]=0}if((t[o>>2]|0)==0&(t[c>>2]|0)==0){t[u>>2]=0;b=t[u>>2]|0;s=f;return b|0}if(t[o>>2]|0){t[l>>2]=Mk(t[o>>2]|0)|0;if(t[(t[a>>2]|0)+108>>2]|0)Dk(t[l>>2]|0,367,368,t[a>>2]|0);o=Lk(t[l>>2]|0)|0;t[(t[a>>2]|0)+136>>2]=o;Rk(t[l>>2]|0);if(!(t[(t[a>>2]|0)+136>>2]|0)){t[u>>2]=-1;b=t[u>>2]|0;s=f;return b|0}l=Ik(t[(t[a>>2]|0)+136>>2]|0)|0;t[(t[a>>2]|0)+140>>2]=l;l=t[a>>2]|0;if(!(t[(t[a>>2]|0)+140>>2]|0)){Ak(t[l+136>>2]|0);t[(t[a>>2]|0)+136>>2]=0;t[u>>2]=-1;b=t[u>>2]|0;s=f;return b|0}o=zk(t[l+140>>2]|0,t[(t[a>>2]|0)+20>>2]|0,(t[(t[a>>2]|0)+20>>2]|0)+4|0)|0;t[(t[a>>2]|0)+152>>2]=o;if(!(t[(t[a>>2]|0)+152>>2]|0)){Ak(t[(t[a>>2]|0)+136>>2]|0);t[(t[a>>2]|0)+136>>2]=0;Nk(t[(t[a>>2]|0)+140>>2]|0);t[(t[a>>2]|0)+140>>2]=0;t[u>>2]=-1;b=t[u>>2]|0;s=f;return b|0}}else{t[(t[a>>2]|0)+140>>2]=t[c>>2];t[(t[a>>2]|0)+144>>2]=1;c=zk(t[(t[a>>2]|0)+140>>2]|0,t[(t[a>>2]|0)+20>>2]|0,(t[(t[a>>2]|0)+20>>2]|0)+4|0)|0;t[(t[a>>2]|0)+152>>2]=c;if(!(t[(t[a>>2]|0)+152>>2]|0)){t[(t[a>>2]|0)+140>>2]=0;t[(t[a>>2]|0)+144>>2]=0;t[u>>2]=-1;b=t[u>>2]|0;s=f;return b|0}}Vk(t[(t[a>>2]|0)+140>>2]|0,369,t[a>>2]|0);if(t[(t[a>>2]|0)+108>>2]|0)Ck(t[(t[a>>2]|0)+140>>2]|0,367,368,t[a>>2]|0);if(t[(t[a>>2]|0)+192>>2]|0)Bk(t[(t[a>>2]|0)+140>>2]|0,370,t[a>>2]|0);t[(t[a>>2]|0)+148>>2]=0;t[(t[a>>2]|0)+8>>2]=4;t[u>>2]=0;b=t[u>>2]|0;s=f;return b|0}function EH(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,u=0,a=0,o=0,c=0,l=0,b=0;f=s;s=s+32|0;u=f+20|0;a=f+16|0;o=f+12|0;c=f+8|0;l=f;t[a>>2]=e;t[o>>2]=i;t[c>>2]=r;t[f+4>>2]=n;if(!(t[a>>2]|0)){t[u>>2]=-1;b=t[u>>2]|0;s=f;return b|0}if((t[o>>2]|0)!=0&(t[c>>2]|0)!=0){t[u>>2]=-1;b=t[u>>2]|0;s=f;return b|0}do if((t[o>>2]|0)!=0|(t[c>>2]|0)!=0){if((t[t[a>>2]>>2]|0)==0?(t[(t[a>>2]|0)+20>>2]|0)!=0:0)break;t[u>>2]=-1;b=t[u>>2]|0;s=f;return b|0}while(0);if(t[(t[a>>2]|0)+120>>2]|0){if(!(t[(t[a>>2]|0)+124>>2]|0))GH(t[(t[a>>2]|0)+120>>2]|0);t[(t[a>>2]|0)+120>>2]=0}t[(t[a>>2]|0)+124>>2]=0;if(t[(t[a>>2]|0)+116>>2]|0){CH(t[(t[a>>2]|0)+116>>2]|0);t[(t[a>>2]|0)+116>>2]=0}if((t[o>>2]|0)==0&(t[c>>2]|0)==0){t[u>>2]=0;b=t[u>>2]|0;s=f;return b|0}if(t[o>>2]|0){t[l>>2]=IH(t[o>>2]|0)|0;if(t[(t[a>>2]|0)+108>>2]|0)UH(t[l>>2]|0,367,368,t[a>>2]|0);if(t[(t[a>>2]|0)+192>>2]|0)KH(t[(t[a>>2]|0)+120>>2]|0,370,t[a>>2]|0);o=xH(t[l>>2]|0)|0;t[(t[a>>2]|0)+116>>2]=o;HH(t[l>>2]|0);if(!(t[(t[a>>2]|0)+116>>2]|0)){t[u>>2]=-1;b=t[u>>2]|0;s=f;return b|0}l=YH(t[(t[a>>2]|0)+116>>2]|0)|0;t[(t[a>>2]|0)+120>>2]=l;if(!(t[(t[a>>2]|0)+120>>2]|0)){CH(t[(t[a>>2]|0)+116>>2]|0);t[(t[a>>2]|0)+116>>2]=0;t[u>>2]=-1;b=t[u>>2]|0;s=f;return b|0}}else{t[(t[a>>2]|0)+120>>2]=t[c>>2];t[(t[a>>2]|0)+124>>2]=1}if(t[(t[a>>2]|0)+108>>2]|0)WH(t[(t[a>>2]|0)+120>>2]|0,367,368,t[a>>2]|0);if(t[(t[a>>2]|0)+192>>2]|0)KH(t[(t[a>>2]|0)+120>>2]|0,370,t[a>>2]|0);t[(t[a>>2]|0)+128>>2]=0;t[(t[a>>2]|0)+132>>2]=0;t[(t[a>>2]|0)+8>>2]=2;t[u>>2]=0;b=t[u>>2]|0;s=f;return b|0}function SH(e,i,r){e=e|0;i=i|0;r=r|0;var f=0,u=0,a=0,o=0,c=0;f=s;s=s+32|0;u=f+28|0;a=f+24|0;o=f+8|0;c=f;t[u>>2]=e;t[a>>2]=i;t[c>>2]=rs(t[a>>2]|0)|0;if((t[c>>2]|0)<=1){s=f;return}if((n[(t[a>>2]|0)+((t[c>>2]|0)-2)>>0]|0)==58){s=f;return}t[o>>2]=r;r=t[u>>2]|0;TH(r,2,NH(t[a>>2]|0,o)|0);s=f;return}function gH(e,i,r){e=e|0;i=i|0;r=r|0;var f=0,u=0,a=0,o=0,c=0;f=s;s=s+32|0;u=f+28|0;a=f+24|0;o=f+8|0;c=f;t[u>>2]=e;t[a>>2]=i;t[c>>2]=rs(t[a>>2]|0)|0;if(!(t[c>>2]|0)){s=f;return}if((n[(t[a>>2]|0)+((t[c>>2]|0)-1)>>0]|0)==58){s=f;return}t[o>>2]=r;r=t[u>>2]|0;TH(r,1,NH(t[a>>2]|0,o)|0);s=f;return}function yH(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0;r=s;s=s+16|0;n=r+12|0;f=r+8|0;u=r+4|0;a=r;t[n>>2]=e;t[f>>2]=i;t[u>>2]=t[n>>2];t[a>>2]=t[(t[u>>2]|0)+272>>2];if(!(t[f>>2]|0)){s=r;return}if(!(t[(t[a>>2]|0)+192>>2]|0)){s=r;return}EAi[t[(t[a>>2]|0)+192>>2]&511](t[(t[a>>2]|0)+112>>2]|0,t[f>>2]|0);s=r;return}function FH(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0;r=s;s=s+16|0;n=r+8|0;f=r+4|0;u=r;t[n>>2]=e;t[f>>2]=i;if((t[n>>2]|0)!=0?(t[(t[n>>2]|0)+20>>2]|0)!=0:0)t[u>>2]=t[(t[(t[n>>2]|0)+20>>2]|0)+296>>2];else t[u>>2]=0;if(!(t[f>>2]|0)){s=r;return}if((t[18774]|0)!=0&(t[33970]|0)!=0)pAi[t[135880>>2]&511](t[f>>2]|0);do if((t[(t[f>>2]|0)+20>>2]|0)!=0?(t[(t[(t[f>>2]|0)+20>>2]|0)+32>>2]|0)!=0:0){if((t[(t[(t[(t[f>>2]|0)+20>>2]|0)+32>>2]|0)+44>>2]|0)==0?(t[(t[(t[(t[f>>2]|0)+20>>2]|0)+32>>2]|0)+48>>2]|0)==0:0)break;if(VM(t[(t[(t[f>>2]|0)+20>>2]|0)+32>>2]|0,t[(t[f>>2]|0)+20>>2]|0,t[f>>2]|0)|0)LH(t[(t[(t[f>>2]|0)+20>>2]|0)+32>>2]|0,t[f>>2]|0)|0}while(0);if(t[(t[f>>2]|0)+12>>2]|0)OH(t[n>>2]|0,t[(t[f>>2]|0)+12>>2]|0);do if(t[(t[f>>2]|0)+8>>2]|0){if((t[u>>2]|0)!=0?(wz(t[u>>2]|0,t[(t[f>>2]|0)+8>>2]|0)|0)!=0:0)break;pAi[t[135736>>2]&511](t[(t[f>>2]|0)+8>>2]|0)}while(0);if(((t[n>>2]|0)!=0?(t[(t[n>>2]|0)+20>>2]|0)!=0:0)?(t[(t[(t[n>>2]|0)+20>>2]|0)+376>>2]|0)<100:0){t[(t[f>>2]|0)+24>>2]=t[(t[(t[n>>2]|0)+20>>2]|0)+380>>2];t[(t[(t[n>>2]|0)+20>>2]|0)+380>>2]=t[f>>2];u=(t[(t[n>>2]|0)+20>>2]|0)+376|0;t[u>>2]=(t[u>>2]|0)+1;s=r;return}pAi[t[135736>>2]&511](t[f>>2]|0);s=r;return}function OH(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0;r=s;s=s+16|0;n=r+12|0;f=r+8|0;u=r+4|0;a=r;t[n>>2]=e;t[f>>2]=i;if((t[n>>2]|0)!=0?(t[(t[n>>2]|0)+20>>2]|0)!=0:0)t[a>>2]=t[(t[(t[n>>2]|0)+20>>2]|0)+296>>2];else t[a>>2]=0;if(!(t[f>>2]|0)){s=r;return}i=t[f>>2]|0;if((t[(t[f>>2]|0)+4>>2]|0)==18){Zg(i);s=r;return}if((t[i+4>>2]|0)!=9?(t[(t[f>>2]|0)+4>>2]|0)!=13:0){while(1){if(!(t[f>>2]|0))break;t[u>>2]=t[(t[f>>2]|0)+24>>2];do if((t[(t[f>>2]|0)+4>>2]|0)!=14){if((t[(t[f>>2]|0)+12>>2]|0)!=0?(t[(t[f>>2]|0)+4>>2]|0)!=5:0){if((t[(t[(t[f>>2]|0)+12>>2]|0)+20>>2]|0)==(t[f>>2]|0))OH(t[n>>2]|0,t[(t[f>>2]|0)+12>>2]|0);t[(t[f>>2]|0)+12>>2]=0}if((t[18774]|0)!=0&(t[33970]|0)!=0)pAi[t[135880>>2]&511](t[f>>2]|0);if(!(((t[(t[f>>2]|0)+4>>2]|0)!=1?(t[(t[f>>2]|0)+4>>2]|0)!=19:0)?(t[(t[f>>2]|0)+4>>2]|0)!=20:0))o=23;if((o|0)==23?(o=0,(t[(t[f>>2]|0)+44>>2]|0)!=0):0)AH(t[n>>2]|0,t[(t[f>>2]|0)+44>>2]|0);do if((((((t[(t[f>>2]|0)+40>>2]|0)!=((t[f>>2]|0)+44|0)?(t[(t[f>>2]|0)+4>>2]|0)!=1:0)?(t[(t[f>>2]|0)+4>>2]|0)!=19:0)?(t[(t[f>>2]|0)+4>>2]|0)!=20:0)?(t[(t[f>>2]|0)+4>>2]|0)!=5:0)?(t[(t[f>>2]|0)+40>>2]|0)!=0:0){if((t[a>>2]|0)!=0?(wz(t[a>>2]|0,t[(t[f>>2]|0)+40>>2]|0)|0)!=0:0)break;pAi[t[135736>>2]&511](t[(t[f>>2]|0)+40>>2]|0)}while(0);if(!(((t[(t[f>>2]|0)+4>>2]|0)!=1?(t[(t[f>>2]|0)+4>>2]|0)!=19:0)?(t[(t[f>>2]|0)+4>>2]|0)!=20:0))o=37;if((o|0)==37?(o=0,(t[(t[f>>2]|0)+48>>2]|0)!=0):0)Zg(t[(t[f>>2]|0)+48>>2]|0);do if(((t[(t[f>>2]|0)+4>>2]|0)!=3?(t[(t[f>>2]|0)+4>>2]|0)!=8:0)?(t[(t[f>>2]|0)+8>>2]|0)!=0:0){if((t[a>>2]|0)!=0?(wz(t[a>>2]|0,t[(t[f>>2]|0)+8>>2]|0)|0)!=0:0)break;pAi[t[135736>>2]&511](t[(t[f>>2]|0)+8>>2]|0)}while(0);if((t[(t[f>>2]|0)+4>>2]|0)==1){if(t[n>>2]|0)o=48}else if((t[n>>2]|0)!=0?(t[(t[f>>2]|0)+4>>2]|0)==3:0)o=48;if(((o|0)==48?(o=0,(t[(t[n>>2]|0)+20>>2]|0)!=0):0)?(t[(t[(t[n>>2]|0)+20>>2]|0)+368>>2]|0)<100:0){t[(t[f>>2]|0)+24>>2]=t[(t[(t[n>>2]|0)+20>>2]|0)+372>>2];t[(t[(t[n>>2]|0)+20>>2]|0)+372>>2]=t[f>>2];i=(t[(t[n>>2]|0)+20>>2]|0)+368|0;t[i>>2]=(t[i>>2]|0)+1;break}pAi[t[135736>>2]&511](t[f>>2]|0)}while(0);t[f>>2]=t[u>>2]}s=r;return}fy(t[f>>2]|0);s=r;return}function AH(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0;r=s;s=s+16|0;n=r+8|0;f=r+4|0;u=r;t[n>>2]=e;t[f>>2]=i;while(1){if(!(t[f>>2]|0))break;t[u>>2]=t[(t[f>>2]|0)+24>>2];FH(t[n>>2]|0,t[f>>2]|0);t[f>>2]=t[u>>2]}s=r;return}function MH(e){e=e|0;var i=0,r=0,n=0,f=0,u=0;i=s;s=s+16|0;r=i+4|0;n=i;t[n>>2]=e;do if(t[n>>2]|0){if(t[(t[n>>2]|0)+24>>2]|0){t[r>>2]=t[(t[n>>2]|0)+24>>2];break}while(1){t[n>>2]=t[(t[n>>2]|0)+20>>2];if(!(t[n>>2]|0)){f=9;break}u=t[n>>2]|0;if(t[(t[n>>2]|0)+24>>2]|0){f=7;break}if(!u){f=9;break}}if((f|0)==7){t[r>>2]=t[u+24>>2];break}else if((f|0)==9){t[r>>2]=t[n>>2];break}}else t[r>>2]=0;while(0);s=i;return t[r>>2]|0}function RH(e){e=e|0;var i=0,r=0;i=s;s=s+16|0;r=i;t[r>>2]=e;XF(t[r>>2]|0,371);s=i;return}function NH(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0;r=s;s=s+64|0;n=r;f=r+48|0;u=r+44|0;a=r+40|0;o=r+36|0;c=r+32|0;l=r+28|0;b=r+24|0;k=r+8|0;t[u>>2]=e;t[a>>2]=i;t[o>>2]=0;t[b>>2]=0;while(1){t[k>>2]=t[t[a>>2]>>2];t[c>>2]=yY(t[b>>2]|0,t[o>>2]|0,t[u>>2]|0,k)|0;if((t[c>>2]|0)<0){h=3;break}if((t[o>>2]|0)==64e3?1:(t[c>>2]|0)<(t[o>>2]|0)){h=15;break}if((t[c>>2]|0)<64e3)t[o>>2]=(t[c>>2]|0)+1;else t[o>>2]=64e3;i=MAi[t[135760>>2]&511](t[b>>2]|0,t[o>>2]|0)|0;t[l>>2]=i;if(!i){h=11;break}t[b>>2]=t[l>>2]}if((h|0)==3){yAi[t[135904>>2]&511](t[33980]|0,187704,n);if(t[b>>2]|0)pAi[t[135736>>2]&511](t[b>>2]|0);t[f>>2]=0;w=t[f>>2]|0;s=r;return w|0}else if((h|0)==11){yAi[t[135904>>2]&511](t[33980]|0,187672,n);if(t[b>>2]|0)pAi[t[135736>>2]&511](t[b>>2]|0);t[f>>2]=0;w=t[f>>2]|0;s=r;return w|0}else if((h|0)==15){t[f>>2]=t[b>>2];w=t[f>>2]|0;s=r;return w|0}return 0}function TH(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0;n=s;s=s+32|0;f=n+16|0;u=n+12|0;a=n+8|0;o=n+4|0;c=n;t[f>>2]=e;t[u>>2]=i;t[a>>2]=r;t[o>>2]=t[f>>2];t[c>>2]=t[(t[o>>2]|0)+272>>2];if(!(t[a>>2]|0)){s=n;return}if(t[(t[c>>2]|0)+108>>2]|0)NAi[t[(t[c>>2]|0)+108>>2]&511](t[(t[c>>2]|0)+112>>2]|0,t[a>>2]|0,t[u>>2]|0,t[o>>2]|0);pAi[t[135736>>2]&511](t[a>>2]|0);s=n;return}function LH(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0;r=s;s=s+32|0;n=r+20|0;f=r+16|0;u=r+12|0;a=r+8|0;o=r+4|0;c=r;t[f>>2]=e;t[u>>2]=i;do if(!(t[f>>2]|0))t[n>>2]=-1;else{if(!(t[u>>2]|0)){t[n>>2]=-1;break}t[a>>2]=t[(t[f>>2]|0)+64>>2];if(!(t[a>>2]|0)){t[n>>2]=-1;break}t[c>>2]=sy(t[f>>2]|0,t[(t[u>>2]|0)+12>>2]|0,1)|0;if(!(t[c>>2]|0)){t[n>>2]=-1;break}t[o>>2]=rO(t[a>>2]|0,t[c>>2]|0)|0;pAi[t[135736>>2]&511](t[c>>2]|0);if((t[o>>2]|0)!=0?(t[(t[o>>2]|0)+8>>2]|0)==(t[u>>2]|0):0){t[(t[o>>2]|0)+12>>2]=t[(t[u>>2]|0)+8>>2];t[(t[o>>2]|0)+8>>2]=0;t[n>>2]=0;break}t[n>>2]=-1}while(0);s=r;return t[n>>2]|0}function DH(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i+4|0;n=i;t[r>>2]=e;t[n>>2]=0;if(!(t[r>>2]|0)){s=i;return}if(t[(t[r>>2]|0)+20>>2]|0)t[n>>2]=t[(t[(t[r>>2]|0)+20>>2]|0)+80>>2];do if((t[(t[r>>2]|0)+4>>2]|0)!=0?(t[(t[r>>2]|0)+4>>2]|0)!=0:0){if((t[n>>2]|0)!=0?(wz(t[n>>2]|0,t[(t[r>>2]|0)+4>>2]|0)|0)!=0:0)break;pAi[t[135736>>2]&511](t[(t[r>>2]|0)+4>>2]|0)}while(0);pAi[t[135736>>2]&511](t[r>>2]|0);s=i;return}function CH(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i+4|0;n=i;t[r>>2]=e;if(!(t[r>>2]|0)){s=i;return}if(t[(t[r>>2]|0)+4>>2]|0)ZH(t[(t[r>>2]|0)+4>>2]|0);if(t[(t[r>>2]|0)+8>>2]|0)fy(t[(t[r>>2]|0)+8>>2]|0);if(t[(t[r>>2]|0)+24>>2]|0)JH(t[(t[r>>2]|0)+24>>2]|0);if(t[(t[r>>2]|0)+28>>2]|0)QH(t[(t[r>>2]|0)+28>>2]|0);if(t[(t[r>>2]|0)+36>>2]|0){t[n>>2]=0;while(1){if((t[n>>2]|0)>=(t[(t[r>>2]|0)+32>>2]|0))break;$H(t[(t[(t[r>>2]|0)+36>>2]|0)+(t[n>>2]<<2)>>2]|0);t[n>>2]=(t[n>>2]|0)+1}pAi[t[135736>>2]&511](t[(t[r>>2]|0)+36>>2]|0)}pAi[t[135736>>2]&511](t[r>>2]|0);s=i;return}function PH(){var e=0,i=0,r=0;e=s;s=s+16|0;i=e+4|0;if(t[46940]|0){t[i>>2]=0;r=t[i>>2]|0;s=e;return r|0}t[46942]=WF(10)|0;if(!(t[46942]|0)){yAi[t[135904>>2]&511](t[33980]|0,187776,e);t[i>>2]=-1;r=t[i>>2]|0;s=e;return r|0}else{tx(187824,0,372,373,374,375,376)|0;tx(t[46968]|0,0,377,378,379,0,0)|0;t[46940]=1;t[i>>2]=0;r=t[i>>2]|0;s=e;return r|0}return 0}function BH(){var e=0;e=s;_D();if(!(t[46940]|0)){s=e;return}XF(t[46942]|0,380);t[46940]=0;s=e;return}function IH(e){e=e|0;var i=0,r=0,n=0,f=0,u=0;i=s;s=s+16|0;r=i+8|0;n=i+4|0;f=i;t[n>>2]=e;if(!(t[n>>2]|0)){t[r>>2]=0;u=t[r>>2]|0;s=i;return u|0}t[f>>2]=gAi[t[135744>>2]&511](148)|0;if(!(t[f>>2]|0)){lx(0,187880);t[r>>2]=0;u=t[r>>2]|0;s=i;return u|0}else{VY(t[f>>2]|0,0,148)|0;e=Yl(t[n>>2]|0)|0;t[(t[f>>2]|0)+68>>2]=e;t[(t[f>>2]|0)+4>>2]=t[33976];t[t[f>>2]>>2]=t[33980];t[r>>2]=t[f>>2];u=t[r>>2]|0;s=i;return u|0}return 0}function HH(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i+4|0;n=i;t[r>>2]=e;if(!(t[r>>2]|0)){s=i;return}if(t[(t[r>>2]|0)+68>>2]|0)pAi[t[135736>>2]&511](t[(t[r>>2]|0)+68>>2]|0);if(t[(t[r>>2]|0)+96>>2]|0)sx(t[(t[r>>2]|0)+96>>2]|0);if(t[(t[r>>2]|0)+56>>2]|0)XF(t[(t[r>>2]|0)+56>>2]|0,0);if(t[(t[r>>2]|0)+60>>2]|0)JH(t[(t[r>>2]|0)+60>>2]|0);if(t[(t[r>>2]|0)+64>>2]|0)QH(t[(t[r>>2]|0)+64>>2]|0);if(t[(t[r>>2]|0)+108>>2]|0)pAi[t[135736>>2]&511](t[(t[r>>2]|0)+108>>2]|0);if(t[(t[r>>2]|0)+124>>2]|0)pAi[t[135736>>2]&511](t[(t[r>>2]|0)+124>>2]|0);if(t[(t[r>>2]|0)+84>>2]|0){t[n>>2]=0;while(1){if((t[n>>2]|0)>=(t[(t[r>>2]|0)+76>>2]|0))break;$H(t[(t[(t[r>>2]|0)+84>>2]|0)+(t[n>>2]<<2)>>2]|0);t[n>>2]=(t[n>>2]|0)+1}pAi[t[135736>>2]&511](t[(t[r>>2]|0)+84>>2]|0)}if((t[(t[r>>2]|0)+72>>2]|0)!=0?(t[(t[r>>2]|0)+144>>2]|0)!=0:0)fy(t[(t[r>>2]|0)+72>>2]|0);pAi[t[135736>>2]&511](t[r>>2]|0);s=i;return}function xH(e){e=e|0;var i=0,r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0;i=s;s=s+32|0;r=i+20|0;n=i+16|0;f=i+12|0;u=i+8|0;a=i+4|0;o=i;t[n>>2]=e;t[f>>2]=0;PH()|0;if(!(t[n>>2]|0)){t[r>>2]=0;c=t[r>>2]|0;s=i;return c|0}e=t[n>>2]|0;do if(t[(t[n>>2]|0)+68>>2]|0){t[u>>2]=_S(t[e+68>>2]|0,0,0)|0;if(!(t[u>>2]|0)){bx(t[n>>2]|0,0,1065,187904,t[(t[n>>2]|0)+68>>2]|0,0);t[r>>2]=0;c=t[r>>2]|0;s=i;return c|0}}else{l=t[n>>2]|0;if(t[e+88>>2]|0){t[u>>2]=pS(t[l+88>>2]|0,t[(t[n>>2]|0)+92>>2]|0,0,0,0)|0;if(t[u>>2]|0){b=Yl(187992)|0;t[(t[u>>2]|0)+72>>2]=b;b=Yl(187992)|0;t[(t[n>>2]|0)+68>>2]=b;break}bx(t[n>>2]|0,0,1065,187944,0,0);t[r>>2]=0;c=t[r>>2]|0;s=i;return c|0}else{b=t[n>>2]|0;if(t[l+72>>2]|0){t[u>>2]=t[b+72>>2];break}bx(b,0,1022,188016,0,0);t[r>>2]=0;c=t[r>>2]|0;s=i;return c|0}}while(0);t[(t[n>>2]|0)+72>>2]=t[u>>2];t[u>>2]=kx(t[n>>2]|0,t[u>>2]|0)|0;if(!(t[u>>2]|0)){fy(t[(t[n>>2]|0)+72>>2]|0);t[(t[n>>2]|0)+72>>2]=0;t[r>>2]=0;c=t[r>>2]|0;s=i;return c|0}t[a>>2]=eF(t[u>>2]|0)|0;e=t[n>>2]|0;if(!(t[a>>2]|0)){if(t[(t[n>>2]|0)+68>>2]|0)k=t[(t[n>>2]|0)+68>>2]|0;else k=188088;bx(e,t[u>>2]|0,1022,188056,k,0);fy(t[(t[n>>2]|0)+72>>2]|0);t[(t[n>>2]|0)+72>>2]=0;t[r>>2]=0;c=t[r>>2]|0;s=i;return c|0}t[f>>2]=hx(e,t[a>>2]|0)|0;a=t[n>>2]|0;if(!(t[f>>2]|0)){fy(t[a+72>>2]|0);t[(t[n>>2]|0)+72>>2]=0;t[r>>2]=0;c=t[r>>2]|0;s=i;return c|0}if(t[a+56>>2]|0)aO(t[(t[n>>2]|0)+56>>2]|0,381,t[n>>2]|0);a=t[f>>2]|0;if((t[(t[n>>2]|0)+36>>2]|0)>0){CH(a);t[(t[n>>2]|0)+72>>2]=0;fy(t[u>>2]|0);t[r>>2]=0;c=t[r>>2]|0;s=i;return c|0}if((t[a+4>>2]|0)!=0?(t[(t[(t[f>>2]|0)+4>>2]|0)+12>>2]|0)!=0:0){if((t[t[(t[(t[f>>2]|0)+4>>2]|0)+12>>2]>>2]|0)!=20?(t[o>>2]=dx(t[n>>2]|0,0)|0,(t[o>>2]|0)!=0):0){t[t[o>>2]>>2]=20;t[(t[o>>2]|0)+24>>2]=t[(t[(t[f>>2]|0)+4>>2]|0)+12>>2];t[(t[(t[f>>2]|0)+4>>2]|0)+12>>2]=t[o>>2]}vx(t[n>>2]|0,t[(t[(t[f>>2]|0)+4>>2]|0)+12>>2]|0)|0}t[(t[f>>2]|0)+8>>2]=t[u>>2];t[(t[n>>2]|0)+72>>2]=0;t[(t[f>>2]|0)+24>>2]=t[(t[n>>2]|0)+60>>2];t[(t[n>>2]|0)+60>>2]=0;t[(t[f>>2]|0)+28>>2]=t[(t[n>>2]|0)+64>>2];t[(t[n>>2]|0)+64>>2]=0;t[(t[f>>2]|0)+32>>2]=t[(t[n>>2]|0)+76>>2];t[(t[f>>2]|0)+36>>2]=t[(t[n>>2]|0)+84>>2];t[(t[n>>2]|0)+84>>2]=0;if((t[(t[n>>2]|0)+128>>2]|0)==1)t[(t[f>>2]|0)+12>>2]=1;t[r>>2]=t[f>>2];c=t[r>>2]|0;s=i;return c|0}function UH(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,u=0,a=0,o=0,c=0;f=s;s=s+16|0;u=f+12|0;a=f+8|0;o=f+4|0;c=f;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;t[c>>2]=n;if(!(t[u>>2]|0)){s=f;return}t[(t[u>>2]|0)+4>>2]=t[a>>2];t[(t[u>>2]|0)+8>>2]=t[o>>2];t[(t[u>>2]|0)+12>>2]=0;t[t[u>>2]>>2]=t[c>>2];s=f;return}function zH(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0;n=s;s=s+48|0;f=n+32|0;u=n+28|0;a=n+20|0;o=n+16|0;c=n+12|0;l=n+8|0;b=n+4|0;k=n;t[u>>2]=e;t[n+24>>2]=i;t[a>>2]=r;t[o>>2]=1;if((t[u>>2]|0)==0|(t[a>>2]|0)==0){t[f>>2]=-1;h=t[f>>2]|0;s=n;return h|0}do if(!(t[(t[u>>2]|0)+84>>2]|0)){t[c>>2]=t[(t[u>>2]|0)+20>>2];if(!(t[c>>2]|0)){mx(t[u>>2]|0,34,0,0,0);t[f>>2]=-1;h=t[f>>2]|0;s=n;return h|0}t[l>>2]=t[(t[c>>2]|0)+4>>2];if((t[l>>2]|0)!=0?(t[(t[l>>2]|0)+12>>2]|0)!=0:0){t[k>>2]=t[(t[l>>2]|0)+12>>2];r=t[k>>2]|0;if(!(t[(t[k>>2]|0)+52>>2]|0)){t[(t[u>>2]|0)+108>>2]=r;t[f>>2]=0;h=t[f>>2]|0;s=n;return h|0}t[b>>2]=Ws(t[r+52>>2]|0,382,t[u>>2]|0)|0;if(t[b>>2]|0){px(t[u>>2]|0,t[b>>2]|0)|0;break}t[f>>2]=-1;h=t[f>>2]|0;s=n;return h|0}mx(t[u>>2]|0,34,0,0,0);t[f>>2]=-1;h=t[f>>2]|0;s=n;return h|0}while(0);t[(t[u>>2]|0)+104>>2]=t[a>>2];t[(t[u>>2]|0)+100>>2]=0;b=t[(t[u>>2]|0)+84>>2]|0;k=t[(t[a>>2]|0)+8>>2]|0;if(t[(t[a>>2]|0)+36>>2]|0)t[o>>2]=Zs(b,k,t[(t[(t[a>>2]|0)+36>>2]|0)+8>>2]|0,t[u>>2]|0)|0;else t[o>>2]=Xs(b,k,t[u>>2]|0)|0;k=t[u>>2]|0;do if((t[o>>2]|0)>=0){if(!(t[k+100>>2]|0)){t[o>>2]=0;break}if((t[(t[u>>2]|0)+100>>2]|0)<0){t[o>>2]=-1;break}else{t[o>>2]=1;break}}else mx(k,38,t[(t[a>>2]|0)+8>>2]|0,0,0);while(0);t[f>>2]=t[o>>2];h=t[f>>2]|0;s=n;return h|0}function jH(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,a=0,o=0,c=0,l=0;n=s;s=s+32|0;f=n+16|0;a=n+12|0;o=n+8|0;c=n;t[a>>2]=e;t[o>>2]=i;t[n+4>>2]=r;t[c>>2]=1;if((t[a>>2]|0)!=0?!((t[o>>2]|0)==0?1:(t[(t[a>>2]|0)+84>>2]|0)==0):0){e:while(1){if(!(u[t[o>>2]>>0]|0))break;do if((u[t[o>>2]>>0]|0|0)!=32){if(9<=(u[t[o>>2]>>0]|0|0)?(u[t[o>>2]>>0]|0|0)<=10:0)break;if((u[t[o>>2]>>0]|0|0)!=13)break e}while(0);t[o>>2]=(t[o>>2]|0)+1}if(!(u[t[o>>2]>>0]|0)){t[f>>2]=1;l=t[f>>2]|0;s=n;return l|0}t[c>>2]=Xs(t[(t[a>>2]|0)+84>>2]|0,188096,t[a>>2]|0)|0;if((t[c>>2]|0)<0){mx(t[a>>2]|0,39,188104,0,0);t[f>>2]=-1;l=t[f>>2]|0;s=n;return l|0}else{t[f>>2]=1;l=t[f>>2]|0;s=n;return l|0}}t[f>>2]=-1;l=t[f>>2]|0;s=n;return l|0}function VH(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,l=0;n=s;s=s+32|0;f=n+20|0;u=n+16|0;a=n+8|0;o=n+4|0;c=n;t[u>>2]=e;t[n+12>>2]=i;t[a>>2]=r;if((t[u>>2]|0)!=0?!((t[a>>2]|0)==0?1:(t[(t[u>>2]|0)+84>>2]|0)==0):0){t[c>>2]=Ex(t[u>>2]|0)|0;t[o>>2]=Xs(t[c>>2]|0,0,0)|0;do if(t[o>>2]|0)if((t[o>>2]|0)<0){t[o>>2]=-1;break}else{t[o>>2]=1;break}else{mx(t[u>>2]|0,22,188112,0,0);t[o>>2]=-1}while(0);Ks(t[c>>2]|0);t[f>>2]=t[o>>2];l=t[f>>2]|0;s=n;return l|0}t[f>>2]=-1;l=t[f>>2]|0;s=n;return l|0}function qH(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,l=0;n=s;s=s+32|0;f=n+20|0;u=n+16|0;a=n+8|0;o=n+4|0;c=n;t[u>>2]=e;t[n+12>>2]=i;t[a>>2]=r;if((t[u>>2]|0)!=0?!((t[a>>2]|0)==0?1:(t[(t[u>>2]|0)+108>>2]|0)==0):0){t[c>>2]=Sx(t[u>>2]|0,t[(t[a>>2]|0)+20>>2]|0)|0;if(!(t[c>>2]|0)){t[f>>2]=-1;l=t[f>>2]|0;s=n;return l|0}t[(t[c>>2]|0)+4>>2]=t[a>>2];t[(t[u>>2]|0)+60>>2]=t[c>>2];t[(t[u>>2]|0)+40>>2]=0;t[o>>2]=gx(t[u>>2]|0,t[(t[u>>2]|0)+108>>2]|0)|0;if((t[o>>2]|0)==0?(t[(t[u>>2]|0)+40>>2]|0)==0:0)t[o>>2]=1;else t[o>>2]=-1;yx(t[u>>2]|0,t[(t[u>>2]|0)+60>>2]|0);t[(t[u>>2]|0)+60>>2]=0;t[f>>2]=t[o>>2];l=t[f>>2]|0;s=n;return l|0}t[f>>2]=-1;l=t[f>>2]|0;s=n;return l|0}function YH(e){e=e|0;var i=0,r=0,n=0,f=0,u=0,a=0;i=s;s=s+16|0;r=i+8|0;n=i+4|0;f=i;t[n>>2]=e;t[f>>2]=gAi[t[135744>>2]&511](116)|0;if(!(t[f>>2]|0)){Fx(0,188120);t[r>>2]=0;u=t[r>>2]|0;s=i;return u|0}e=(t[f>>2]|0)+0|0;a=e+116|0;do{t[e>>2]=0;e=e+4|0}while((e|0)<(a|0));t[(t[f>>2]|0)+20>>2]=t[n>>2];t[(t[f>>2]|0)+4>>2]=t[33976];t[t[f>>2]>>2]=t[33980];t[(t[f>>2]|0)+48>>2]=0;t[(t[f>>2]|0)+52>>2]=0;t[(t[f>>2]|0)+44>>2]=0;t[(t[f>>2]|0)+56>>2]=0;if(t[n>>2]|0)t[(t[f>>2]|0)+36>>2]=t[(t[n>>2]|0)+12>>2];t[(t[f>>2]|0)+64>>2]=0;t[(t[f>>2]|0)+68>>2]=0;t[(t[f>>2]|0)+80>>2]=0;t[(t[f>>2]|0)+40>>2]=0;t[r>>2]=t[f>>2];u=t[r>>2]|0;s=i;return u|0}function GH(e){e=e|0;var i=0,r=0,n=0,f=0;i=s;s=s+16|0;r=i+8|0;n=i+4|0;f=i;t[r>>2]=e;if(!(t[r>>2]|0)){s=i;return}if(t[(t[r>>2]|0)+64>>2]|0)Ox(0,t[(t[r>>2]|0)+64>>2]|0);if(t[(t[r>>2]|0)+68>>2]|0){t[n>>2]=0;while(1){if((t[n>>2]|0)>=(t[t[(t[r>>2]|0)+68>>2]>>2]|0))break;yx(0,t[(t[(t[(t[r>>2]|0)+68>>2]|0)+8>>2]|0)+(t[n>>2]<<2)>>2]|0);t[n>>2]=(t[n>>2]|0)+1}Ox(0,t[(t[r>>2]|0)+68>>2]|0)}if(t[(t[r>>2]|0)+80>>2]|0){t[n>>2]=0;while(1){if((t[n>>2]|0)>=(t[(t[r>>2]|0)+72>>2]|0))break;Ox(0,t[(t[(t[r>>2]|0)+80>>2]|0)+(t[n>>2]<<2)>>2]|0);t[n>>2]=(t[n>>2]|0)+1}pAi[t[135736>>2]&511](t[(t[r>>2]|0)+80>>2]|0)}if(t[(t[r>>2]|0)+56>>2]|0)pAi[t[135736>>2]&511](t[(t[r>>2]|0)+56>>2]|0);if(t[(t[r>>2]|0)+96>>2]|0){t[f>>2]=Ex(t[r>>2]|0)|0;while(1){if(!(t[f>>2]|0))break;Ks(t[f>>2]|0);t[f>>2]=Ex(t[r>>2]|0)|0}pAi[t[135736>>2]&511](t[(t[r>>2]|0)+96>>2]|0)}pAi[t[135736>>2]&511](t[r>>2]|0);s=i;return}function WH(e,i,r,n){e=e|0;i=i|0;r=r|0;
	n=n|0;var f=0,u=0,a=0,o=0,c=0;f=s;s=s+16|0;u=f+12|0;a=f+8|0;o=f+4|0;c=f;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;t[c>>2]=n;if(!(t[u>>2]|0)){s=f;return}t[(t[u>>2]|0)+4>>2]=t[a>>2];t[(t[u>>2]|0)+8>>2]=t[o>>2];t[t[u>>2]>>2]=t[c>>2];t[(t[u>>2]|0)+12>>2]=0;s=f;return}function KH(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0;n=s;s=s+16|0;f=n+8|0;u=n+4|0;a=n;t[f>>2]=e;t[u>>2]=i;t[a>>2]=r;if(!(t[f>>2]|0)){s=n;return}t[(t[f>>2]|0)+12>>2]=t[u>>2];t[(t[f>>2]|0)+4>>2]=0;t[(t[f>>2]|0)+8>>2]=0;t[t[f>>2]>>2]=t[a>>2];s=n;return}function XH(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0;r=s;s=s+16|0;n=r+12|0;f=r+8|0;u=r+4|0;a=r;t[f>>2]=e;t[u>>2]=i;if((t[f>>2]|0)==0|(t[u>>2]|0)==0){t[n>>2]=-1;o=t[n>>2]|0;s=r;return o|0}t[(t[f>>2]|0)+24>>2]=t[u>>2];t[a>>2]=Ax(t[f>>2]|0,t[u>>2]|0)|0;Mx(t[u>>2]|0);if((t[a>>2]|0)==-1){t[n>>2]=1;o=t[n>>2]|0;s=r;return o|0}else{t[n>>2]=t[a>>2];o=t[n>>2]|0;s=r;return o|0}return 0}function ZH(e){e=e|0;var i=0,r=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if(!(t[r>>2]|0)){s=i;return}if(t[(t[r>>2]|0)+4>>2]|0)ZH(t[(t[r>>2]|0)+4>>2]|0);if(t[(t[r>>2]|0)+8>>2]|0)ZH(t[(t[r>>2]|0)+8>>2]|0);if(t[(t[r>>2]|0)+28>>2]|0)XF(t[(t[r>>2]|0)+28>>2]|0,0);if(t[(t[r>>2]|0)+24>>2]|0)XF(t[(t[r>>2]|0)+24>>2]|0,0);pAi[t[135736>>2]&511](t[r>>2]|0);s=i;return}function JH(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i+4|0;n=i;t[r>>2]=e;while(1){if(!(t[r>>2]|0))break;t[n>>2]=t[t[r>>2]>>2];sx(t[r>>2]|0);t[r>>2]=t[n>>2]}s=i;return}function QH(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i+4|0;n=i;t[r>>2]=e;while(1){if(!(t[r>>2]|0))break;t[n>>2]=t[t[r>>2]>>2];Rx(t[r>>2]|0);t[r>>2]=t[n>>2]}s=i;return}function $H(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i+4|0;n=i;t[r>>2]=e;if(!(t[r>>2]|0)){s=i;return}if((((t[t[r>>2]>>2]|0)==7?(t[(t[r>>2]|0)+36>>2]|0)!=0:0)?(t[n>>2]=t[(t[r>>2]|0)+20>>2],(t[n>>2]|0)!=0):0)?(t[(t[n>>2]|0)+24>>2]|0)!=0:0)EAi[t[(t[n>>2]|0)+24>>2]&511](t[(t[n>>2]|0)+4>>2]|0,t[(t[r>>2]|0)+36>>2]|0);if((t[(t[r>>2]|0)+20>>2]|0)!=0?(t[t[r>>2]>>2]|0)==19:0)Nx(t[(t[r>>2]|0)+20>>2]|0);if((t[(t[r>>2]|0)+20>>2]|0)!=0?(t[t[r>>2]>>2]|0)==17:0)XF(t[(t[r>>2]|0)+20>>2]|0,0);if(t[(t[r>>2]|0)+8>>2]|0)pAi[t[135736>>2]&511](t[(t[r>>2]|0)+8>>2]|0);if(t[(t[r>>2]|0)+12>>2]|0)pAi[t[135736>>2]&511](t[(t[r>>2]|0)+12>>2]|0);if(t[(t[r>>2]|0)+16>>2]|0)pAi[t[135736>>2]&511](t[(t[r>>2]|0)+16>>2]|0);if(t[(t[r>>2]|0)+52>>2]|0)fb(t[(t[r>>2]|0)+52>>2]|0);pAi[t[135736>>2]&511](t[r>>2]|0);s=i;return}function ex(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0;r=s;s=s+16|0;n=r+12|0;f=r+4|0;u=r;t[r+8>>2]=e;t[f>>2]=i;do if(t[f>>2]|0){t[u>>2]=RD(t[f>>2]|0,196728)|0;if(!(t[u>>2]|0)){t[n>>2]=0;break}else{t[n>>2]=1;break}}else t[n>>2]=-1;while(0);s=r;return t[n>>2]|0}function ix(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;var u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0;u=s;s=s+32|0;a=u+28|0;o=u+20|0;c=u+16|0;l=u+12|0;b=u+8|0;k=u+4|0;h=u;t[u+24>>2]=e;t[o>>2]=i;t[c>>2]=r;t[l>>2]=n;t[b>>2]=f;do if(!((t[o>>2]|0)==0|(t[c>>2]|0)==0)){t[k>>2]=RD(t[o>>2]|0,196728)|0;if(!(t[k>>2]|0)){t[a>>2]=-1;break}t[h>>2]=LD(t[k>>2]|0,t[c>>2]|0,t[l>>2]|0,t[b>>2]|0)|0;if((t[h>>2]|0)==2){t[a>>2]=2;break}if(!(t[h>>2]|0)){t[a>>2]=1;break}if((t[h>>2]|0)>0){t[a>>2]=0;break}else{t[a>>2]=-1;break}}else t[a>>2]=-1;while(0);s=u;return t[a>>2]|0}function rx(e,i,r,n,f,u,a){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;u=u|0;a=a|0;var o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0;o=s;s=s+48|0;c=o+44|0;l=o+36|0;b=o+32|0;k=o+28|0;h=o+24|0;w=o+20|0;d=o+16|0;v=o+12|0;m=o+8|0;_=o+4|0;p=o;t[o+40>>2]=e;t[l>>2]=i;t[b>>2]=r;t[k>>2]=n;t[h>>2]=f;t[w>>2]=u;t[d>>2]=a;t[_>>2]=0;t[p>>2]=0;if((t[l>>2]|0)==0|(t[b>>2]|0)==0|(t[w>>2]|0)==0){t[c>>2]=-1;E=t[c>>2]|0;s=o;return E|0}t[m>>2]=RD(t[l>>2]|0,196728)|0;if(!(t[m>>2]|0)){t[c>>2]=-1;E=t[c>>2]|0;s=o;return E|0}if(!(t[h>>2]|0)){t[v>>2]=LD(t[m>>2]|0,t[b>>2]|0,_,t[k>>2]|0)|0;if(t[v>>2]|0){t[c>>2]=-1;E=t[c>>2]|0;s=o;return E|0}if(!(t[_>>2]|0)){t[c>>2]=-1;E=t[c>>2]|0;s=o;return E|0}}else t[_>>2]=t[h>>2];t[v>>2]=LD(t[m>>2]|0,t[w>>2]|0,p,t[d>>2]|0)|0;d=t[_>>2]|0;if(t[v>>2]|0){if((d|0)!=(t[h>>2]|0))MD(t[_>>2]|0);t[c>>2]=-1;E=t[c>>2]|0;s=o;return E|0}t[v>>2]=BD(d,t[p>>2]|0)|0;if((t[_>>2]|0)!=(t[h>>2]|0))MD(t[_>>2]|0);MD(t[p>>2]|0);if((t[v>>2]|0)==-2){t[c>>2]=-1;E=t[c>>2]|0;s=o;return E|0}if(!(t[v>>2]|0)){t[c>>2]=1;E=t[c>>2]|0;s=o;return E|0}else{t[c>>2]=0;E=t[c>>2]|0;s=o;return E|0}return 0}function nx(e,i,r,n,f,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;u=u|0;var a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0;a=s;s=s+48|0;o=a+36|0;c=a+28|0;l=a+24|0;b=a+20|0;k=a+16|0;h=a+12|0;w=a+8|0;d=a+4|0;v=a;t[a+32>>2]=e;t[c>>2]=i;t[l>>2]=r;t[b>>2]=n;t[k>>2]=f;t[h>>2]=u;if((t[c>>2]|0)==0|(t[k>>2]|0)==0){t[o>>2]=-1;m=t[o>>2]|0;s=a;return m|0}t[d>>2]=RD(t[c>>2]|0,196728)|0;if(!(t[d>>2]|0)){t[o>>2]=-1;m=t[o>>2]|0;s=a;return m|0}t[w>>2]=gk()|0;if(!(t[w>>2]|0)){t[o>>2]=-1;m=t[o>>2]|0;s=a;return m|0}do if(Xl(t[l>>2]|0,196768)|0)t[t[w>>2]>>2]=1e3;else{if(Xl(t[l>>2]|0,196784)|0){t[t[w>>2]>>2]=1001;break}if(Xl(t[l>>2]|0,196800)|0){t[t[w>>2]>>2]=1002;break}if(Xl(t[l>>2]|0,196816)|0){t[t[w>>2]>>2]=1003;break}if(Xl(t[l>>2]|0,196832)|0){t[t[w>>2]>>2]=1004;break}if(Xl(t[l>>2]|0,196848)|0){t[t[w>>2]>>2]=1005;break}if(Xl(t[l>>2]|0,196864)|0){t[t[w>>2]>>2]=1006;break}if(Xl(t[l>>2]|0,196872)|0){t[t[w>>2]>>2]=1007;break}if(Xl(t[l>>2]|0,196888)|0){t[t[w>>2]>>2]=1008;break}if(Xl(t[l>>2]|0,196904)|0){t[t[w>>2]>>2]=1009;break}if(Xl(t[l>>2]|0,196912)|0){t[t[w>>2]>>2]=1010;break}u=(Xl(t[l>>2]|0,196928)|0)!=0;f=t[w>>2]|0;if(u){t[f>>2]=1011;break}Fk(f);t[o>>2]=-1;m=t[o>>2]|0;s=a;return m|0}while(0);t[(t[w>>2]|0)+8>>2]=t[b>>2];t[v>>2]=Tk(t[w>>2]|0,t[d>>2]|0,0,t[c>>2]|0)|0;if(t[v>>2]|0){Fk(t[w>>2]|0);t[o>>2]=-1;m=t[o>>2]|0;s=a;return m|0}t[v>>2]=UD(t[d>>2]|0,t[w>>2]|0,t[k>>2]|0,t[h>>2]|0)|0;Fk(t[w>>2]|0);if(t[v>>2]|0){t[o>>2]=-1;m=t[o>>2]|0;s=a;return m|0}else{t[o>>2]=0;m=t[o>>2]|0;s=a;return m|0}return 0}function fx(e,i){e=e|0;i=i|0;var r=0,n=0;r=s;s=s+16|0;n=r;t[r+4>>2]=e;t[n>>2]=i;MD(t[n>>2]|0);s=r;return}function tx(e,i,r,n,f,u,a){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;u=u|0;a=a|0;var o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0;o=s;s=s+48|0;c=o;l=o+40|0;b=o+36|0;k=o+32|0;h=o+28|0;w=o+24|0;d=o+20|0;v=o+16|0;m=o+12|0;_=o+8|0;p=o+4|0;t[b>>2]=e;t[k>>2]=i;t[h>>2]=r;t[w>>2]=n;t[d>>2]=f;t[v>>2]=u;t[m>>2]=a;if((t[46942]|0)==0|(t[b>>2]|0)==0|(t[w>>2]|0)==0|(t[d>>2]|0)==0){t[l>>2]=-1;E=t[l>>2]|0;s=o;return E|0}if(rO(t[46942]|0,t[b>>2]|0)|0){a=t[33976]|0;u=t[33980]|0;t[c>>2]=t[b>>2];yAi[a&511](u,196944,c);t[l>>2]=-1;E=t[l>>2]|0;s=o;return E|0}t[_>>2]=gAi[t[135744>>2]&511](28)|0;if(!(t[_>>2]|0)){Fx(0,196992);t[l>>2]=-1;E=t[l>>2]|0;s=o;return E|0}u=t[_>>2]|0;t[u+0>>2]=0;t[u+4>>2]=0;t[u+8>>2]=0;t[u+12>>2]=0;t[u+16>>2]=0;t[u+20>>2]=0;t[u+24>>2]=0;u=Yl(t[b>>2]|0)|0;t[t[_>>2]>>2]=u;t[(t[_>>2]|0)+4>>2]=t[k>>2];t[(t[_>>2]|0)+8>>2]=t[h>>2];t[(t[_>>2]|0)+16>>2]=t[d>>2];t[(t[_>>2]|0)+12>>2]=t[w>>2];t[(t[_>>2]|0)+20>>2]=t[v>>2];t[(t[_>>2]|0)+24>>2]=t[m>>2];t[p>>2]=ZF(t[46942]|0,t[b>>2]|0,t[_>>2]|0)|0;if((t[p>>2]|0)<0){p=t[33976]|0;m=t[33980]|0;t[c>>2]=t[b>>2];yAi[p&511](m,197016,c);cx(t[_>>2]|0,t[b>>2]|0);t[l>>2]=-1;E=t[l>>2]|0;s=o;return E|0}else{t[l>>2]=0;E=t[l>>2]|0;s=o;return E|0}return 0}function ux(e,i){e=e|0;i=i|0;var r=0,n=0,f=0;r=s;s=s+16|0;n=r+8|0;f=r;t[r+4>>2]=e;t[f>>2]=i;do if(t[f>>2]|0){if(Xl(t[f>>2]|0,196712)|0){t[n>>2]=1;break}if(Xl(t[f>>2]|0,196720)|0){t[n>>2]=1;break}else{t[n>>2]=0;break}}else t[n>>2]=-1;while(0);s=r;return t[n>>2]|0}function ax(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;var u=0,a=0,o=0,c=0;u=s;s=s+32|0;a=u+20|0;o=u+12|0;c=u+8|0;t[u+16>>2]=e;t[o>>2]=i;t[c>>2]=r;t[u+4>>2]=n;t[u>>2]=f;do if(t[c>>2]|0){if(Xl(t[o>>2]|0,196712)|0){t[a>>2]=1;break}if(Xl(t[o>>2]|0,196720)|0){t[a>>2]=1;break}else{t[a>>2]=0;break}}else t[a>>2]=-1;while(0);s=u;return t[a>>2]|0}function ox(e,i,r,n,f,u,a){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;u=u|0;a=a|0;var o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0;o=s;s=s+48|0;c=o+32|0;l=o+28|0;b=o+16|0;k=o+8|0;h=o+4|0;w=o;t[o+36>>2]=e;t[c>>2]=i;t[l>>2]=r;t[o+24>>2]=n;t[o+20>>2]=f;t[b>>2]=u;t[o+12>>2]=a;t[k>>2]=-1;if(Xl(t[c>>2]|0,196712)|0){t[k>>2]=Xl(t[l>>2]|0,t[b>>2]|0)|0;d=t[k>>2]|0;s=o;return d|0}if(!(Xl(t[c>>2]|0,196720)|0)){d=t[k>>2]|0;s=o;return d|0}if(Xl(t[l>>2]|0,t[b>>2]|0)|0){t[k>>2]=1;d=t[k>>2]|0;s=o;return d|0}t[h>>2]=Tx(0,t[l>>2]|0)|0;t[w>>2]=Tx(0,t[b>>2]|0)|0;do if(!((t[h>>2]|0)==0|(t[w>>2]|0)==0))if(Xl(t[h>>2]|0,t[w>>2]|0)|0){t[k>>2]=1;break}else{t[k>>2]=0;break}else t[k>>2]=-1;while(0);if(t[h>>2]|0)pAi[t[135736>>2]&511](t[h>>2]|0);if(!(t[w>>2]|0)){d=t[k>>2]|0;s=o;return d|0}pAi[t[135736>>2]&511](t[w>>2]|0);d=t[k>>2]|0;s=o;return d|0}function cx(e,i){e=e|0;i=i|0;var r=0,n=0;r=s;s=s+16|0;n=r+4|0;t[n>>2]=e;t[r>>2]=i;if(!(t[n>>2]|0)){s=r;return}if(t[t[n>>2]>>2]|0)pAi[t[135736>>2]&511](t[t[n>>2]>>2]|0);pAi[t[135736>>2]&511](t[n>>2]|0);s=r;return}function lx(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0;r=s;s=s+32|0;n=r;f=r+20|0;u=r+16|0;a=r+12|0;o=r+8|0;c=r+4|0;t[f>>2]=e;t[u>>2]=i;t[a>>2]=0;t[o>>2]=0;t[c>>2]=0;if(t[f>>2]|0){i=t[f>>2]|0;if(t[(t[f>>2]|0)+12>>2]|0)t[a>>2]=t[i+12>>2];else t[o>>2]=t[i+4>>2];t[c>>2]=t[t[f>>2]>>2];i=(t[f>>2]|0)+36|0;t[i>>2]=(t[i>>2]|0)+1}i=t[a>>2]|0;a=t[o>>2]|0;o=t[c>>2]|0;if(t[u>>2]|0){c=t[u>>2]|0;t[n>>2]=t[u>>2];cp(i,a,o,0,0,18,2,3,0,0,c,0,0,0,0,189400,n);s=r;return}else{cp(i,a,o,0,0,18,2,3,0,0,0,0,0,0,0,189432,n);s=r;return}}function sx(e){e=e|0;var i=0,r=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if(!(t[r>>2]|0)){s=i;return}if(t[(t[r>>2]|0)+4>>2]|0)pAi[t[135736>>2]&511](t[(t[r>>2]|0)+4>>2]|0);if(t[(t[r>>2]|0)+8>>2]|0)fy(t[(t[r>>2]|0)+8>>2]|0);if(t[(t[r>>2]|0)+16>>2]|0)Lx(t[(t[r>>2]|0)+16>>2]|0);pAi[t[135736>>2]&511](t[r>>2]|0);s=i;return}function bx(e,i,r,n,f,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;u=u|0;var a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0;a=s;s=s+48|0;o=a;c=a+40|0;l=a+36|0;b=a+32|0;k=a+28|0;h=a+24|0;w=a+20|0;d=a+16|0;v=a+12|0;m=a+8|0;t[c>>2]=e;t[l>>2]=i;t[b>>2]=r;t[k>>2]=n;t[h>>2]=f;t[w>>2]=u;t[d>>2]=0;t[v>>2]=0;t[m>>2]=0;if(t[c>>2]|0){u=t[c>>2]|0;if(t[(t[c>>2]|0)+12>>2]|0)t[d>>2]=t[u+12>>2];else t[v>>2]=t[u+4>>2];t[m>>2]=t[t[c>>2]>>2];u=(t[c>>2]|0)+36|0;t[u>>2]=(t[u>>2]|0)+1}u=t[d>>2]|0;d=t[v>>2]|0;v=t[m>>2]|0;m=t[l>>2]|0;l=t[b>>2]|0;b=t[h>>2]|0;c=t[w>>2]|0;f=t[k>>2]|0;k=t[w>>2]|0;t[o>>2]=t[h>>2];t[o+4>>2]=k;cp(u,d,v,0,m,18,l,2,0,0,b,c,0,0,0,f,o);s=a;return}function kx(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0;r=s;s=s+16|0;n=r+12|0;f=r+8|0;u=r+4|0;a=r;t[f>>2]=e;t[u>>2]=i;t[a>>2]=eF(t[u>>2]|0)|0;i=t[f>>2]|0;if(!(t[a>>2]|0)){bx(i,t[u>>2]|0,1022,188056,t[(t[f>>2]|0)+68>>2]|0,0);t[n>>2]=0;o=t[n>>2]|0;s=r;return o|0}else{Dx(i,t[a>>2]|0);t[n>>2]=t[u>>2];o=t[n>>2]|0;s=r;return o|0}return 0}function hx(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0;r=s;s=s+32|0;n=r+28|0;f=r+24|0;u=r+20|0;a=r+16|0;o=r+12|0;c=r+8|0;l=r+4|0;b=r;t[f>>2]=e;t[u>>2]=i;t[a>>2]=0;if((t[f>>2]|0)==0|(t[u>>2]|0)==0){t[n>>2]=0;k=t[n>>2]|0;s=r;return k|0}t[a>>2]=Cx(t[f>>2]|0)|0;if(!(t[a>>2]|0)){t[n>>2]=0;k=t[n>>2]|0;s=r;return k|0}t[o>>2]=t[(t[f>>2]|0)+44>>2];t[(t[f>>2]|0)+44>>2]=0;if(((((t[u>>2]|0)!=0?(t[(t[u>>2]|0)+36>>2]|0)!=0:0)?(t[(t[u>>2]|0)+4>>2]|0)==1:0)?(Xl(t[(t[u>>2]|0)+8>>2]|0,190264)|0)!=0:0)?(Xl(t[(t[(t[u>>2]|0)+36>>2]|0)+8>>2]|0,t[46968]|0)|0)!=0:0){i=Px(t[f>>2]|0,t[(t[u>>2]|0)+12>>2]|0)|0;t[(t[a>>2]|0)+4>>2]=i;if(!(t[(t[a>>2]|0)+4>>2]|0)){CH(t[a>>2]|0);t[n>>2]=0;k=t[n>>2]|0;s=r;return k|0}}else{i=Bx(t[f>>2]|0)|0;t[b>>2]=i;t[(t[a>>2]|0)+4>>2]=i;if(!(t[(t[a>>2]|0)+4>>2]|0)){CH(t[a>>2]|0);t[n>>2]=0;k=t[n>>2]|0;s=r;return k|0}t[t[b>>2]>>2]=t[(t[f>>2]|0)+24>>2];do if(t[(t[f>>2]|0)+24>>2]|0){t[l>>2]=t[(t[(t[f>>2]|0)+24>>2]|0)+4>>2];if(!(t[l>>2]|0)){t[(t[(t[f>>2]|0)+24>>2]|0)+4>>2]=t[b>>2];break}while(1){if(!(t[(t[l>>2]|0)+8>>2]|0))break;t[l>>2]=t[(t[l>>2]|0)+8>>2]}t[(t[l>>2]|0)+8>>2]=t[b>>2]}while(0);t[c>>2]=t[(t[f>>2]|0)+24>>2];t[(t[f>>2]|0)+24>>2]=t[b>>2];Ix(t[f>>2]|0,t[u>>2]|0)|0;if(t[c>>2]|0)t[(t[f>>2]|0)+24>>2]=t[c>>2]}t[(t[f>>2]|0)+44>>2]=t[o>>2];if((t[(t[(t[a>>2]|0)+4>>2]|0)+12>>2]|0)!=0?(Hx(t[f>>2]|0,t[(t[(t[a>>2]|0)+4>>2]|0)+12>>2]|0,0)|0,(t[(t[f>>2]|0)+32>>2]&128|0)==0):0){xx(t[f>>2]|0,t[(t[(t[a>>2]|0)+4>>2]|0)+12>>2]|0,0);while(1){if(!(t[(t[(t[a>>2]|0)+4>>2]|0)+12>>2]|0))break;if((t[t[(t[(t[a>>2]|0)+4>>2]|0)+12>>2]>>2]|0)!=-1)break;if(!(t[(t[(t[(t[a>>2]|0)+4>>2]|0)+12>>2]|0)+32>>2]|0))break;t[(t[(t[a>>2]|0)+4>>2]|0)+12>>2]=t[(t[(t[(t[a>>2]|0)+4>>2]|0)+12>>2]|0)+24>>2]}Ux(t[f>>2]|0,t[(t[(t[a>>2]|0)+4>>2]|0)+12>>2]|0,16,-1)|0}t[n>>2]=t[a>>2];k=t[n>>2]|0;s=r;return k|0}function wx(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0,S=0,g=0,y=0;n=s;s=s+64|0;a=n+60|0;o=n+56|0;c=n+48|0;l=n+44|0;b=n+40|0;k=n+36|0;h=n+32|0;w=n+28|0;d=n+24|0;v=n+20|0;m=n+16|0;_=n+12|0;p=n+8|0;E=n+4|0;S=n;t[a>>2]=e;t[o>>2]=i;t[n+52>>2]=r;t[b>>2]=0;t[k>>2]=0;t[_>>2]=0;t[p>>2]=0;t[E>>2]=0;t[S>>2]=1;if(t[(t[o>>2]|0)+36>>2]|0){s=n;return}t[c>>2]=t[(t[a>>2]|0)+24>>2];while(1){if(!(t[c>>2]|0))break;t[p>>2]=(t[p>>2]|0)+1;t[c>>2]=t[(t[c>>2]|0)+32>>2]}t[k>>2]=gAi[t[135744>>2]&511](t[p>>2]<<2)|0;e:do if(t[k>>2]|0){t[c>>2]=t[(t[a>>2]|0)+24>>2];while(1){g=t[33936]|0;if(!(t[c>>2]|0))break;p=gAi[g&511](12)|0;t[(t[k>>2]|0)+(t[_>>2]<<2)>>2]=p;if(!(t[(t[k>>2]|0)+(t[_>>2]<<2)>>2]|0))break e;if((t[t[c>>2]>>2]|0)==3)t[E>>2]=(t[E>>2]|0)+1;t[t[(t[k>>2]|0)+(t[_>>2]<<2)>>2]>>2]=t[c>>2];p=zx(t[o>>2]|0,t[c>>2]|0,0)|0;t[(t[(t[k>>2]|0)+(t[_>>2]<<2)>>2]|0)+4>>2]=p;p=zx(t[o>>2]|0,t[c>>2]|0,1)|0;t[(t[(t[k>>2]|0)+(t[_>>2]<<2)>>2]|0)+8>>2]=p;t[_>>2]=(t[_>>2]|0)+1;t[c>>2]=t[(t[c>>2]|0)+32>>2]}t[b>>2]=gAi[g&511](16)|0;if(t[b>>2]|0){p=t[b>>2]|0;t[p+0>>2]=0;t[p+4>>2]=0;t[p+8>>2]=0;t[p+12>>2]=0;t[t[b>>2]>>2]=t[_>>2];p=WF(t[_>>2]|0)|0;t[(t[b>>2]|0)+4>>2]=p;t[w>>2]=0;while(1){if((t[w>>2]|0)>=(t[_>>2]|0))break;t[h>>2]=t[(t[k>>2]|0)+(t[w>>2]<<2)>>2];t[d>>2]=(t[w>>2]|0)+1;while(1){if((t[d>>2]|0)>=(t[_>>2]|0))break;if(t[(t[k>>2]|0)+(t[d>>2]<<2)>>2]|0){t[v>>2]=jx(t[o>>2]|0,t[(t[h>>2]|0)+4>>2]|0,t[(t[(t[k>>2]|0)+(t[d>>2]<<2)>>2]|0)+4>>2]|0)|0;if(!(t[v>>2]|0))bx(t[o>>2]|0,t[(t[a>>2]|0)+4>>2]|0,1021,190104,0,0);t[v>>2]=jx(t[o>>2]|0,t[(t[h>>2]|0)+8>>2]|0,t[(t[(t[k>>2]|0)+(t[d>>2]<<2)>>2]|0)+8>>2]|0)|0;if(!(t[v>>2]|0))bx(t[o>>2]|0,t[(t[a>>2]|0)+4>>2]|0,1001,190152,0,0)}t[d>>2]=(t[d>>2]|0)+1}t[l>>2]=t[(t[h>>2]|0)+4>>2];i:do if((t[l>>2]|0)!=0?(t[t[l>>2]>>2]|0)!=0:0)while(1){if(!(t[t[l>>2]>>2]|0))break i;do if((t[t[t[l>>2]>>2]>>2]|0)==3){t[m>>2]=QF(t[(t[b>>2]|0)+4>>2]|0,188096,0,(t[w>>2]|0)+1|0)|0;if(t[m>>2]|0)t[S>>2]=-1}else{if((t[t[t[l>>2]>>2]>>2]|0)==4?(t[(t[t[l>>2]>>2]|0)+8>>2]|0)!=0:0){if((t[(t[t[l>>2]>>2]|0)+12>>2]|0)!=0?(u[t[(t[t[l>>2]>>2]|0)+12>>2]>>0]|0)!=0:0)t[m>>2]=QF(t[(t[b>>2]|0)+4>>2]|0,t[(t[t[l>>2]>>2]|0)+8>>2]|0,t[(t[t[l>>2]>>2]|0)+12>>2]|0,(t[w>>2]|0)+1|0)|0;else t[m>>2]=QF(t[(t[b>>2]|0)+4>>2]|0,t[(t[t[l>>2]>>2]|0)+8>>2]|0,0,(t[w>>2]|0)+1|0)|0;if(!(t[m>>2]|0))break;t[S>>2]=-1;break}if((t[t[t[l>>2]>>2]>>2]|0)!=4){t[S>>2]=-1;break}if((t[(t[t[l>>2]>>2]|0)+12>>2]|0)!=0?(u[t[(t[t[l>>2]>>2]|0)+12>>2]>>0]|0)!=0:0)t[m>>2]=QF(t[(t[b>>2]|0)+4>>2]|0,189536,t[(t[t[l>>2]>>2]|0)+12>>2]|0,(t[w>>2]|0)+1|0)|0;else t[m>>2]=QF(t[(t[b>>2]|0)+4>>2]|0,189536,0,(t[w>>2]|0)+1|0)|0;if(t[(t[t[l>>2]>>2]|0)+40>>2]|0)t[S>>2]=2;if(t[m>>2]|0)t[S>>2]=-1}while(0);t[l>>2]=(t[l>>2]|0)+4}else y=48;while(0);if((y|0)==48){y=0;t[S>>2]=0}t[w>>2]=(t[w>>2]|0)+1}t[(t[b>>2]|0)+12>>2]=t[k>>2];t[(t[a>>2]|0)+20>>2]=t[b>>2];if(t[E>>2]|0){p=(t[a>>2]|0)+50|0;f[p>>1]=f[p>>1]|8}if((t[S>>2]|0)==1)t[(t[b>>2]|0)+8>>2]=1;if((t[S>>2]|0)!=2){s=n;return}t[(t[b>>2]|0)+8>>2]=3;s=n;return}}while(0);lx(t[o>>2]|0,190192);if(t[k>>2]|0){t[w>>2]=0;while(1){if((t[w>>2]|0)>=(t[_>>2]|0))break;if(t[(t[k>>2]|0)+(t[w>>2]<<2)>>2]|0){if(t[(t[(t[k>>2]|0)+(t[w>>2]<<2)>>2]|0)+4>>2]|0)pAi[t[135736>>2]&511](t[(t[(t[k>>2]|0)+(t[w>>2]<<2)>>2]|0)+4>>2]|0);pAi[t[135736>>2]&511](t[(t[k>>2]|0)+(t[w>>2]<<2)>>2]|0)}t[w>>2]=(t[w>>2]|0)+1}pAi[t[135736>>2]&511](t[k>>2]|0)}Nx(t[b>>2]|0);s=n;return}function dx(e,i){e=e|0;i=i|0;var r=0,n=0,u=0,a=0,o=0,c=0,l=0;r=s;s=s+32|0;n=r+16|0;u=r+12|0;a=r+8|0;o=r+4|0;c=r;t[u>>2]=e;t[a>>2]=i;i=(t[u>>2]|0)+80|0;do if(!(t[(t[u>>2]|0)+80>>2]|0)){t[i>>2]=16;t[(t[u>>2]|0)+76>>2]=0;e=gAi[t[135744>>2]&511](t[(t[u>>2]|0)+80>>2]<<2)|0;t[(t[u>>2]|0)+84>>2]=e;if(!(t[(t[u>>2]|0)+84>>2]|0)){lx(t[u>>2]|0,190080);t[n>>2]=0;l=t[n>>2]|0;s=r;return l|0}}else if((t[i>>2]|0)<=(t[(t[u>>2]|0)+76>>2]|0)){e=(t[u>>2]|0)+80|0;t[e>>2]=t[e>>2]<<1;t[c>>2]=MAi[t[135760>>2]&511](t[(t[u>>2]|0)+84>>2]|0,t[(t[u>>2]|0)+80>>2]<<2)|0;if(t[c>>2]|0){t[(t[u>>2]|0)+84>>2]=t[c>>2];break}lx(t[u>>2]|0,190080);t[n>>2]=0;l=t[n>>2]|0;s=r;return l|0}while(0);t[o>>2]=gAi[t[135744>>2]&511](56)|0;if(!(t[o>>2]|0)){lx(t[u>>2]|0,190080);t[n>>2]=0;l=t[n>>2]|0;s=r;return l|0}else{c=(t[o>>2]|0)+0|0;i=c+56|0;do{t[c>>2]=0;c=c+4|0}while((c|0)<(i|0));c=t[o>>2]|0;i=(t[u>>2]|0)+76|0;e=t[i>>2]|0;t[i>>2]=e+1;t[(t[(t[u>>2]|0)+84>>2]|0)+(e<<2)>>2]=c;t[(t[o>>2]|0)+4>>2]=t[a>>2];f[(t[o>>2]|0)+48>>1]=-1;t[n>>2]=t[o>>2];l=t[n>>2]|0;s=r;return l|0}return 0}function vx(e,i){e=e|0;i=i|0;var r=0,n=0,u=0,a=0,o=0,c=0,l=0,b=0;r=s;s=s+32|0;n=r+16|0;u=r+12|0;a=r+8|0;o=r+4|0;c=r;t[u>>2]=e;t[a>>2]=i;t[o>>2]=0;if((t[u>>2]|0)==0|(t[a>>2]|0)==0){t[n>>2]=-1;l=t[n>>2]|0;s=r;return l|0}if(!((t[t[a>>2]>>2]|0)!=20?(t[t[a>>2]>>2]|0)!=4:0))b=5;if(((b|0)==5?(t[o>>2]=Vx(t[a>>2]|0)|0,(f[(t[a>>2]|0)+50>>1]&64|0)!=0):0)?(f[(t[a>>2]|0)+48>>1]|0)!=-25:0){t[(t[u>>2]|0)+132>>2]=0;t[o>>2]=qx(t[u>>2]|0,t[a>>2]|0)|0;t[n>>2]=t[o>>2];l=t[n>>2]|0;s=r;return l|0}e:do switch(t[t[a>>2]>>2]|0){case 4:case 0:case 7:case 6:case 8:case 5:case 3:{t[o>>2]=0;break}case 13:case 12:case 11:case 20:case 10:case 18:case 17:case 16:case 15:case 14:{t[c>>2]=t[(t[a>>2]|0)+24>>2];while(1){if(!(t[c>>2]|0))break e;t[o>>2]=vx(t[u>>2]|0,t[c>>2]|0)|0;if(t[o>>2]|0)break e;t[c>>2]=t[(t[c>>2]|0)+32>>2]}break}case-1:{t[o>>2]=vx(t[u>>2]|0,t[(t[a>>2]|0)+24>>2]|0)|0;break}case 1:case 19:case 9:case 2:{t[o>>2]=0;break}default:{}}while(0);t[n>>2]=t[o>>2];l=t[n>>2]|0;s=r;return l|0}function mx(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;var u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0;u=s;s=s+32|0;a=u+24|0;o=u+20|0;c=u+16|0;l=u+12|0;b=u+8|0;k=u+4|0;h=u;t[a>>2]=e;t[o>>2]=i;t[c>>2]=r;t[l>>2]=n;t[b>>2]=f;if(!(t[a>>2]|0)){s=u;return}if(t[(t[a>>2]|0)+28>>2]&8){s=u;return}if((t[(t[a>>2]|0)+28>>2]&1|0)!=0?(t[(t[a>>2]|0)+28>>2]&2|0)==0:0){Wx(t[a>>2]|0,t[o>>2]|0,t[c>>2]|0,t[l>>2]|0,t[b>>2]|0)|0;s=u;return}if(t[(t[a>>2]|0)+48>>2]|0)Yx(t[a>>2]|0);if(t[(t[a>>2]|0)+60>>2]|0){t[k>>2]=t[t[(t[a>>2]|0)+60>>2]>>2];t[h>>2]=t[(t[(t[a>>2]|0)+60>>2]|0)+4>>2]}else{t[h>>2]=0;t[k>>2]=0}if((t[k>>2]|0)==0&(t[h>>2]|0)==0)t[k>>2]=t[(t[a>>2]|0)+104>>2];Gx(t[a>>2]|0,t[o>>2]|0,t[k>>2]|0,t[h>>2]|0,t[c>>2]|0,t[l>>2]|0);s=u;return}function _x(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,m=0,_=0,p=0,E=0,S=0,g=0,y=0;f=s;s=s+64|0;a=f;o=f+52|0;c=f+48|0;l=f+44|0;b=f+40|0;k=f+36|0;h=f+32|0;w=f+28|0;d=f+24|0;m=f+20|0;_=f+16|0;p=f+12|0;E=f+8|0;S=f+4|0;t[o>>2]=e;t[c>>2]=i;t[l>>2]=r;t[b>>2]=n;t[k>>2]=t[b>>2];t[h>>2]=t[l>>2];t[_>>2]=0;if(!(t[k>>2]|0)){l=t[v>>2]|0;t[a>>2]=t[c>>2];xe(l|0,189616,a|0)|0;s=f;return}t[m>>2]=t[(t[k>>2]|0)+104>>2];t[(t[k>>2]|0)+100>>2]=1;if(!(t[h>>2]|0)){if((u[t[c>>2]>>0]|0|0)==35){s=f;return}l=t[v>>2]|0;t[a>>2]=t[c>>2];xe(l|0,189648,a|0)|0;if((t[k>>2]|0)!=0?(t[(t[k>>2]|0)+40>>2]|0)==0:0)t[(t[k>>2]|0)+40>>2]=37;t[(t[k>>2]|0)+100>>2]=-1;s=f;return}if((t[k>>2]|0)==0|(t[h>>2]|0)==0){l=t[v>>2]|0;t[a>>2]=t[c>>2];xe(l|0,189680,a|0)|0;if((t[k>>2]|0)!=0?(t[(t[k>>2]|0)+40>>2]|0)==0:0)t[(t[k>>2]|0)+40>>2]=37;t[(t[k>>2]|0)+100>>2]=-1;s=f;return}if((t[t[h>>2]>>2]|0)!=4){l=t[v>>2]|0;t[a>>2]=t[c>>2];xe(l|0,189712,a|0)|0;if(!(t[(t[k>>2]|0)+40>>2]|0))t[(t[k>>2]|0)+40>>2]=37;t[(t[k>>2]|0)+100>>2]=-1;s=f;return}if((t[(t[m>>2]|0)+4>>2]|0)!=1){mx(t[k>>2]|0,23,0,0,0);if(!(t[(t[k>>2]|0)+28>>2]&1))Yx(t[k>>2]|0);t[(t[k>>2]|0)+100>>2]=-1;s=f;return}if(!(t[(t[h>>2]|0)+52>>2]|0)){t[(t[k>>2]|0)+100>>2]=0;t[(t[k>>2]|0)+108>>2]=t[h>>2];s=f;return}t[o>>2]=Ws(t[(t[h>>2]|0)+52>>2]|0,382,t[k>>2]|0)|0;a=t[k>>2]|0;if(!(t[o>>2]|0)){t[a+100>>2]=-1;s=f;return}px(a,t[o>>2]|0)|0;t[w>>2]=Sx(t[k>>2]|0,t[m>>2]|0)|0;o=t[k>>2]|0;if(!(t[w>>2]|0)){t[o+100>>2]=-1;s=f;return}t[d>>2]=t[o+60>>2];t[(t[k>>2]|0)+60>>2]=t[w>>2];if((t[(t[h>>2]|0)+36>>2]|0)!=0?(t[_>>2]=Kx(t[k>>2]|0,t[(t[h>>2]|0)+36>>2]|0)|0,(t[_>>2]|0)!=0):0){t[(t[k>>2]|0)+100>>2]=-1;mx(t[k>>2]|0,24,t[(t[m>>2]|0)+8>>2]|0,0,0)}m=t[k>>2]|0;if(!(t[(t[k>>2]|0)+60>>2]|0)){if(t[m+64>>2]|0){t[E>>2]=-1;t[p>>2]=t[(t[k>>2]|0)+28>>2];t[S>>2]=0;while(1){if((t[S>>2]|0)>=(t[t[(t[k>>2]|0)+64>>2]>>2]|0))break;t[w>>2]=t[(t[(t[(t[k>>2]|0)+64>>2]|0)+8>>2]|0)+(t[S>>2]<<2)>>2];t[(t[k>>2]|0)+60>>2]=t[w>>2];t[(t[(t[k>>2]|0)+60>>2]|0)+4>>2]=0;if(!(Xx(t[k>>2]|0,0)|0)){g=39;break}t[S>>2]=(t[S>>2]|0)+1}if((g|0)==39)t[E>>2]=0;if(t[E>>2]|0){g=(t[k>>2]|0)+28|0;t[g>>2]=t[g>>2]|1;Zx(t[k>>2]|0)}t[S>>2]=0;while(1){y=t[k>>2]|0;if((t[S>>2]|0)>=(t[t[(t[k>>2]|0)+64>>2]>>2]|0))break;yx(y,t[(t[(t[(t[k>>2]|0)+64>>2]|0)+8>>2]|0)+(t[S>>2]<<2)>>2]|0);t[S>>2]=(t[S>>2]|0)+1}Ox(y,t[(t[k>>2]|0)+64>>2]|0);t[(t[k>>2]|0)+64>>2]=0;if((t[_>>2]|0)==0&(t[E>>2]|0)==-1)t[(t[k>>2]|0)+100>>2]=-1;t[(t[k>>2]|0)+28>>2]=t[p>>2]}}else{t[(t[m+60>>2]|0)+4>>2]=0;t[_>>2]=Xx(t[k>>2]|0,1)|0;if(t[_>>2]|0)t[(t[k>>2]|0)+100>>2]=-1;yx(t[k>>2]|0,t[(t[k>>2]|0)+60>>2]|0)}if((t[(t[k>>2]|0)+100>>2]|0)==-1?(t[(t[k>>2]|0)+28>>2]&1|0)==0:0)Yx(t[k>>2]|0);t[(t[k>>2]|0)+60>>2]=t[d>>2];s=f;return}function px(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0;r=s;s=s+16|0;n=r+8|0;f=r+4|0;u=r;t[f>>2]=e;t[u>>2]=i;if((t[(t[f>>2]|0)+96>>2]|0)==0?(t[(t[f>>2]|0)+92>>2]=10,i=gAi[t[135744>>2]&511](t[(t[f>>2]|0)+92>>2]<<2)|0,t[(t[f>>2]|0)+96>>2]=i,(t[(t[f>>2]|0)+96>>2]|0)==0):0){Fx(t[f>>2]|0,189544);t[n>>2]=-1;a=t[n>>2]|0;s=r;return a|0}if((t[(t[f>>2]|0)+88>>2]|0)>=(t[(t[f>>2]|0)+92>>2]|0)?(i=(t[f>>2]|0)+92|0,t[i>>2]=t[i>>2]<<1,i=MAi[t[135760>>2]&511](t[(t[f>>2]|0)+96>>2]|0,t[(t[f>>2]|0)+92>>2]<<2)|0,t[(t[f>>2]|0)+96>>2]=i,(t[(t[f>>2]|0)+96>>2]|0)==0):0){Fx(t[f>>2]|0,189544);t[n>>2]=-1;a=t[n>>2]|0;s=r;return a|0}i=t[u>>2]|0;e=(t[f>>2]|0)+88|0;o=t[e>>2]|0;t[e>>2]=o+1;t[(t[(t[f>>2]|0)+96>>2]|0)+(o<<2)>>2]=i;t[(t[f>>2]|0)+84>>2]=t[u>>2];t[n>>2]=0;a=t[n>>2]|0;s=r;return a|0}function Ex(e){e=e|0;var i=0,r=0,n=0,f=0,u=0;i=s;s=s+16|0;r=i+8|0;n=i+4|0;f=i;t[n>>2]=e;if((t[(t[n>>2]|0)+88>>2]|0)<=0){t[r>>2]=0;u=t[r>>2]|0;s=i;return u|0}e=(t[n>>2]|0)+88|0;t[e>>2]=(t[e>>2]|0)+-1;t[f>>2]=t[(t[(t[n>>2]|0)+96>>2]|0)+(t[(t[n>>2]|0)+88>>2]<<2)>>2];t[(t[(t[n>>2]|0)+96>>2]|0)+(t[(t[n>>2]|0)+88>>2]<<2)>>2]=0;e=t[n>>2]|0;if((t[(t[n>>2]|0)+88>>2]|0)>0)t[(t[n>>2]|0)+84>>2]=t[(t[(t[n>>2]|0)+96>>2]|0)+((t[e+88>>2]|0)-1<<2)>>2];else t[e+84>>2]=0;t[r>>2]=t[f>>2];u=t[r>>2]|0;s=i;return u|0}function Sx(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0;r=s;s=s+128|0;n=r+112|0;f=r+108|0;u=r+104|0;a=r+100|0;o=r+96|0;c=r+16|0;l=r+8|0;b=r+4|0;k=r;t[f>>2]=e;t[u>>2]=i;t[l>>2]=0;t[b>>2]=0;e:do if(!(t[u>>2]|0)){t[b>>2]=eF(t[(t[f>>2]|0)+24>>2]|0)|0;if(!(t[b>>2]|0)){t[n>>2]=0;h=t[n>>2]|0;s=r;return h|0}}else{t[o>>2]=t[(t[u>>2]|0)+44>>2];while(1){if(!(t[o>>2]|0))break e;if((t[l>>2]|0)<20){i=t[o>>2]|0;e=t[l>>2]|0;t[l>>2]=e+1;t[c+(e<<2)>>2]=i}else t[l>>2]=(t[l>>2]|0)+1;t[o>>2]=t[(t[o>>2]|0)+24>>2]}}while(0);if((t[(t[f>>2]|0)+68>>2]|0)!=0?(t[t[(t[f>>2]|0)+68>>2]>>2]|0)>0:0){i=t[(t[f>>2]|0)+68>>2]|0;t[i>>2]=(t[i>>2]|0)+-1;t[a>>2]=t[(t[(t[(t[f>>2]|0)+68>>2]|0)+8>>2]|0)+(t[t[(t[f>>2]|0)+68>>2]>>2]<<2)>>2]}else w=13;do if((w|0)==13){t[a>>2]=gAi[t[135744>>2]&511](32)|0;if(t[a>>2]|0){i=t[a>>2]|0;t[i+0>>2]=0;t[i+4>>2]=0;t[i+8>>2]=0;t[i+12>>2]=0;t[i+16>>2]=0;t[i+20>>2]=0;t[i+24>>2]=0;t[i+28>>2]=0;break}Fx(t[f>>2]|0,189568);t[n>>2]=0;h=t[n>>2]|0;s=r;return h|0}while(0);t[(t[a>>2]|0)+20>>2]=0;t[(t[a>>2]|0)+24>>2]=0;if(!(t[u>>2]|0)){t[t[a>>2]>>2]=t[(t[f>>2]|0)+24>>2];t[(t[a>>2]|0)+4>>2]=t[b>>2]}else{t[t[a>>2]>>2]=t[u>>2];t[(t[a>>2]|0)+4>>2]=t[(t[u>>2]|0)+12>>2]}t[(t[a>>2]|0)+8>>2]=0;e:do if((t[l>>2]|0)>0){do if(!(t[(t[a>>2]|0)+28>>2]|0)){if((t[l>>2]|0)<4)t[(t[a>>2]|0)+12>>2]=4;else t[(t[a>>2]|0)+12>>2]=t[l>>2];b=gAi[t[135744>>2]&511](t[(t[a>>2]|0)+12>>2]<<2)|0;t[(t[a>>2]|0)+28>>2]=b;if(!(t[(t[a>>2]|0)+28>>2]|0)){Fx(t[f>>2]|0,189568);t[n>>2]=t[a>>2];h=t[n>>2]|0;s=r;return h|0}}else if((t[(t[a>>2]|0)+12>>2]|0)<(t[l>>2]|0)){t[k>>2]=MAi[t[135760>>2]&511](t[(t[a>>2]|0)+28>>2]|0,t[l>>2]<<2)|0;if(t[k>>2]|0){t[(t[a>>2]|0)+28>>2]=t[k>>2];t[(t[a>>2]|0)+12>>2]=t[l>>2];break}Fx(t[f>>2]|0,189568);t[n>>2]=t[a>>2];h=t[n>>2]|0;s=r;return h|0}while(0);t[(t[a>>2]|0)+8>>2]=t[l>>2];if((t[l>>2]|0)<20){YY(t[(t[a>>2]|0)+28>>2]|0,c|0,t[l>>2]<<2|0)|0;break}t[o>>2]=t[(t[u>>2]|0)+44>>2];t[l>>2]=0;while(1){if(!(t[o>>2]|0))break e;b=t[o>>2]|0;w=t[l>>2]|0;t[l>>2]=w+1;t[(t[(t[a>>2]|0)+28>>2]|0)+(w<<2)>>2]=b;t[o>>2]=t[(t[o>>2]|0)+24>>2]}}while(0);t[(t[a>>2]|0)+16>>2]=t[(t[a>>2]|0)+8>>2];t[n>>2]=t[a>>2];h=t[n>>2]|0;s=r;return h|0}function gx(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0;r=s;s=s+48|0;n=r;f=r+44|0;u=r+40|0;a=r+36|0;o=r+32|0;c=r+28|0;l=r+24|0;b=r+20|0;k=r+16|0;h=r+12|0;w=r+8|0;t[u>>2]=e;t[a>>2]=i;if((t[(t[u>>2]|0)+60>>2]|0)!=0?(t[(t[u>>2]|0)+64>>2]|0)!=0:0){i=t[33976]|0;e=t[33980]|0;t[n>>2]=189496;t[n+4>>2]=10608;yAi[i&511](e,189464,n);yx(t[u>>2]|0,t[(t[u>>2]|0)+60>>2]|0);t[(t[u>>2]|0)+60>>2]=0}if((t[(t[u>>2]|0)+64>>2]|0)!=0?(t[t[(t[u>>2]|0)+64>>2]>>2]|0)!=1:0){t[o>>2]=t[(t[u>>2]|0)+64>>2];t[(t[u>>2]|0)+64>>2]=0;t[c>>2]=0;t[b>>2]=0;t[w>>2]=t[(t[u>>2]|0)+28>>2];e=(t[u>>2]|0)+28|0;t[e>>2]=t[e>>2]|1;t[l>>2]=0;while(1){if((t[l>>2]|0)>=(t[t[o>>2]>>2]|0))break;t[(t[u>>2]|0)+60>>2]=t[(t[(t[o>>2]|0)+8>>2]|0)+(t[l>>2]<<2)>>2];t[(t[u>>2]|0)+64>>2]=0;t[h>>2]=Jx(t[u>>2]|0,t[a>>2]|0)|0;if((t[(t[u>>2]|0)+60>>2]|0)!=0?(t[(t[u>>2]|0)+64>>2]|0)!=0:0){e=t[33976]|0;i=t[33980]|0;t[n>>2]=189496;t[n+4>>2]=10645;yAi[e&511](i,189464,n);yx(t[u>>2]|0,t[(t[u>>2]|0)+60>>2]|0);t[(t[u>>2]|0)+60>>2]=0}i=t[u>>2]|0;e:do if(t[h>>2]|0){e=t[u>>2]|0;if(t[i+60>>2]|0){yx(e,t[(t[u>>2]|0)+60>>2]|0);t[(t[u>>2]|0)+60>>2]=0;break}if(t[e+64>>2]|0){t[k>>2]=0;while(1){d=t[u>>2]|0;if((t[k>>2]|0)>=(t[t[(t[u>>2]|0)+64>>2]>>2]|0))break;yx(d,t[(t[(t[(t[u>>2]|0)+64>>2]|0)+8>>2]|0)+(t[k>>2]<<2)>>2]|0);t[k>>2]=(t[k>>2]|0)+1}Ox(d,t[(t[u>>2]|0)+64>>2]|0);t[(t[u>>2]|0)+64>>2]=0}}else{e=t[c>>2]|0;if(!(t[i+64>>2]|0)){v=t[u>>2]|0;if(e){Qx(v,t[c>>2]|0,t[(t[u>>2]|0)+60>>2]|0)|0;t[(t[u>>2]|0)+60>>2]=0;break}else{m=t[v+60>>2]|0;v=t[b>>2]|0;t[b>>2]=v+1;t[(t[(t[o>>2]|0)+8>>2]|0)+(v<<2)>>2]=m;t[(t[u>>2]|0)+60>>2]=0;break}}if(!e){t[c>>2]=t[(t[u>>2]|0)+64>>2];t[(t[u>>2]|0)+64>>2]=0;t[k>>2]=0;while(1){if((t[k>>2]|0)>=(t[b>>2]|0))break e;Qx(t[u>>2]|0,t[c>>2]|0,t[(t[(t[o>>2]|0)+8>>2]|0)+(t[k>>2]<<2)>>2]|0)|0;t[k>>2]=(t[k>>2]|0)+1}}t[k>>2]=0;while(1){_=t[u>>2]|0;if((t[k>>2]|0)>=(t[t[(t[u>>2]|0)+64>>2]>>2]|0))break;Qx(_,t[c>>2]|0,t[(t[(t[(t[u>>2]|0)+64>>2]|0)+8>>2]|0)+(t[k>>2]<<2)>>2]|0)|0;t[k>>2]=(t[k>>2]|0)+1}Ox(_,t[(t[u>>2]|0)+64>>2]|0);t[(t[u>>2]|0)+64>>2]=0}while(0);t[l>>2]=(t[l>>2]|0)+1}t[(t[u>>2]|0)+28>>2]=t[w>>2];do if(!(t[c>>2]|0)){w=t[b>>2]|0;if((t[b>>2]|0)>1){t[t[o>>2]>>2]=w;t[(t[u>>2]|0)+64>>2]=t[o>>2];t[h>>2]=0;break}if((w|0)==1){t[(t[u>>2]|0)+60>>2]=t[t[(t[o>>2]|0)+8>>2]>>2];Ox(t[u>>2]|0,t[o>>2]|0);t[h>>2]=0;break}t[h>>2]=-1;Ox(t[u>>2]|0,t[o>>2]|0);if(t[(t[u>>2]|0)+64>>2]|0){Ox(t[u>>2]|0,t[(t[u>>2]|0)+64>>2]|0);t[(t[u>>2]|0)+64>>2]=0}}else{Ox(t[u>>2]|0,t[o>>2]|0);t[(t[u>>2]|0)+64>>2]=t[c>>2];t[h>>2]=0}while(0);if((t[(t[u>>2]|0)+60>>2]|0)!=0?(t[(t[u>>2]|0)+64>>2]|0)!=0:0){c=t[33976]|0;o=t[33980]|0;t[n>>2]=189496;t[n+4>>2]=10711;yAi[c&511](o,189464,n);yx(t[u>>2]|0,t[(t[u>>2]|0)+60>>2]|0);t[(t[u>>2]|0)+60>>2]=0}t[f>>2]=t[h>>2];p=t[f>>2]|0;s=r;return p|0}if(t[(t[u>>2]|0)+64>>2]|0){t[(t[u>>2]|0)+60>>2]=t[t[(t[(t[u>>2]|0)+64>>2]|0)+8>>2]>>2];Ox(t[u>>2]|0,t[(t[u>>2]|0)+64>>2]|0);t[(t[u>>2]|0)+64>>2]=0}t[h>>2]=Jx(t[u>>2]|0,t[a>>2]|0)|0;if((t[(t[u>>2]|0)+60>>2]|0)!=0?(t[(t[u>>2]|0)+64>>2]|0)!=0:0){a=t[33976]|0;o=t[33980]|0;t[n>>2]=189496;t[n+4>>2]=10620;yAi[a&511](o,189464,n);yx(t[u>>2]|0,t[(t[u>>2]|0)+60>>2]|0);t[(t[u>>2]|0)+60>>2]=0}if((t[(t[u>>2]|0)+64>>2]|0)!=0?(t[t[(t[u>>2]|0)+64>>2]>>2]|0)==1:0){t[(t[u>>2]|0)+60>>2]=t[t[(t[(t[u>>2]|0)+64>>2]|0)+8>>2]>>2];Ox(t[u>>2]|0,t[(t[u>>2]|0)+64>>2]|0);t[(t[u>>2]|0)+64>>2]=0}t[f>>2]=t[h>>2];p=t[f>>2]|0;s=r;return p|0}function yx(e,i){e=e|0;i=i|0;var r=0,n=0,f=0;r=s;s=s+16|0;n=r+4|0;f=r;t[n>>2]=e;t[f>>2]=i;if(!(t[f>>2]|0)){s=r;return}if((t[n>>2]|0)!=0?(t[(t[n>>2]|0)+68>>2]|0)==0:0){i=$x(t[n>>2]|0,40)|0;t[(t[n>>2]|0)+68>>2]=i}if((t[n>>2]|0)!=0?(t[(t[n>>2]|0)+68>>2]|0)!=0:0){eU(t[n>>2]|0,t[(t[n>>2]|0)+68>>2]|0,t[f>>2]|0)|0;s=r;return}if(t[(t[f>>2]|0)+28>>2]|0)pAi[t[135736>>2]&511](t[(t[f>>2]|0)+28>>2]|0);pAi[t[135736>>2]&511](t[f>>2]|0);s=r;return}function Fx(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0;r=s;s=s+32|0;n=r;f=r+20|0;u=r+16|0;a=r+12|0;o=r+8|0;c=r+4|0;t[f>>2]=e;t[u>>2]=i;t[a>>2]=0;t[o>>2]=0;t[c>>2]=0;if(t[f>>2]|0){i=t[f>>2]|0;if(t[(t[f>>2]|0)+12>>2]|0)t[a>>2]=t[i+12>>2];else t[o>>2]=t[i+4>>2];t[c>>2]=t[t[f>>2]>>2];i=(t[f>>2]|0)+16|0;t[i>>2]=(t[i>>2]|0)+1}i=t[a>>2]|0;a=t[o>>2]|0;o=t[c>>2]|0;if(t[u>>2]|0){c=t[u>>2]|0;t[n>>2]=t[u>>2];cp(i,a,o,0,0,19,2,3,0,0,c,0,0,0,0,189400,n);s=r;return}else{cp(i,a,o,0,0,19,2,3,0,0,0,0,0,0,0,189432,n);s=r;return}}function Ox(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0;r=s;s=s+16|0;n=r+8|0;f=r+4|0;u=r;t[n>>2]=e;t[f>>2]=i;if(!(t[f>>2]|0)){s=r;return}if((t[n>>2]|0)!=0?(t[(t[n>>2]|0)+80>>2]|0)==0:0){t[(t[n>>2]|0)+76>>2]=40;t[(t[n>>2]|0)+72>>2]=0;i=gAi[t[135744>>2]&511](t[(t[n>>2]|0)+76>>2]<<2)|0;t[(t[n>>2]|0)+80>>2]=i;if(!(t[(t[n>>2]|0)+80>>2]|0))Fx(t[n>>2]|0,189384)}else a=6;do if(((a|0)==6?(t[n>>2]|0)!=0:0)?(t[(t[n>>2]|0)+72>>2]|0)>=(t[(t[n>>2]|0)+76>>2]|0):0){t[u>>2]=MAi[t[135760>>2]&511](t[(t[n>>2]|0)+80>>2]|0,t[(t[n>>2]|0)+76>>2]<<1<<2)|0;if(t[u>>2]|0){t[(t[n>>2]|0)+80>>2]=t[u>>2];i=(t[n>>2]|0)+76|0;t[i>>2]=t[i>>2]<<1;break}Fx(t[n>>2]|0,189384);pAi[t[135736>>2]&511](t[(t[f>>2]|0)+8>>2]|0);pAi[t[135736>>2]&511](t[f>>2]|0);s=r;return}while(0);if((t[n>>2]|0)!=0?(t[(t[n>>2]|0)+80>>2]|0)!=0:0){u=t[f>>2]|0;a=(t[n>>2]|0)+72|0;i=t[a>>2]|0;t[a>>2]=i+1;t[(t[(t[n>>2]|0)+80>>2]|0)+(i<<2)>>2]=u;s=r;return}pAi[t[135736>>2]&511](t[(t[f>>2]|0)+8>>2]|0);pAi[t[135736>>2]&511](t[f>>2]|0);s=r;return}function Ax(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0;r=s;s=s+112|0;n=r+100|0;f=r+96|0;u=r+92|0;a=r+88|0;o=r+84|0;c=r+80|0;l=r+76|0;b=r+72|0;k=r+68|0;h=r+64|0;w=r;t[f>>2]=e;t[u>>2]=i;if((t[f>>2]|0)!=0?!((t[u>>2]|0)==0?1:(t[(t[f>>2]|0)+20>>2]|0)==0):0){t[(t[f>>2]|0)+40>>2]=0;t[o>>2]=t[(t[f>>2]|0)+20>>2];t[c>>2]=t[(t[o>>2]|0)+4>>2];o=t[f>>2]|0;if(!(t[c>>2]|0)){mx(o,34,0,0,0);t[n>>2]=-1;d=t[n>>2]|0;s=r;return d|0}t[l>>2]=Sx(o,0)|0;t[(t[f>>2]|0)+60>>2]=t[l>>2];t[a>>2]=gx(t[f>>2]|0,t[(t[c>>2]|0)+12>>2]|0)|0;if((t[(t[f>>2]|0)+60>>2]|0)!=0?(t[(t[l>>2]|0)+4>>2]|0)!=0:0){t[l>>2]=t[(t[f>>2]|0)+60>>2];t[b>>2]=t[(t[l>>2]|0)+4>>2];t[b>>2]=iU(t[f>>2]|0,t[b>>2]|0)|0;if((t[b>>2]|0)!=0&(t[a>>2]|0)!=-1){mx(t[f>>2]|0,35,0,0,0);t[a>>2]=-1}}else v=10;if((v|0)==10?(t[(t[f>>2]|0)+64>>2]|0)!=0:0){t[h>>2]=-1;t[k>>2]=0;while(1){if((t[k>>2]|0)>=(t[t[(t[f>>2]|0)+64>>2]>>2]|0))break;t[l>>2]=t[(t[(t[(t[f>>2]|0)+64>>2]|0)+8>>2]|0)+(t[k>>2]<<2)>>2];t[b>>2]=t[(t[l>>2]|0)+4>>2];t[b>>2]=iU(t[f>>2]|0,t[b>>2]|0)|0;if(!(t[b>>2]|0))t[h>>2]=0;yx(t[f>>2]|0,t[l>>2]|0);t[k>>2]=(t[k>>2]|0)+1}if((t[h>>2]|0)==-1&(t[a>>2]|0)!=-1){mx(t[f>>2]|0,35,0,0,0);t[a>>2]=-1}}if(t[(t[f>>2]|0)+60>>2]|0){yx(t[f>>2]|0,t[(t[f>>2]|0)+60>>2]|0);t[(t[f>>2]|0)+60>>2]=0}if(t[a>>2]|0)Yx(t[f>>2]|0);if((t[(t[f>>2]|0)+36>>2]|0)==1){h=w+0|0;k=h+64|0;do{t[h>>2]=0;h=h+4|0}while((h|0)<(k|0));t[w+36>>2]=1;t[w+4>>2]=t[(t[f>>2]|0)+4>>2];t[w+8>>2]=t[(t[f>>2]|0)+8>>2];t[w>>2]=t[t[f>>2]>>2];if((wR(w,t[u>>2]|0)|0)!=1)t[a>>2]=-1}if((t[a>>2]|0)==0?(t[(t[f>>2]|0)+40>>2]|0)!=0:0)t[a>>2]=-1;t[n>>2]=t[a>>2];d=t[n>>2]|0;s=r;return d|0}t[n>>2]=-1;d=t[n>>2]|0;s=r;return d|0}function Mx(e){e=e|0;var i=0,r=0,n=0,f=0,u=0;i=s;s=s+16|0;r=i+4|0;n=i;t[r>>2]=e;if(!(t[r>>2]|0)){s=i;return}if(((t[(t[r>>2]|0)+4>>2]|0)!=1?(t[(t[r>>2]|0)+4>>2]|0)!=9:0)?(t[(t[r>>2]|0)+4>>2]|0)!=13:0){s=i;return}if((t[(t[r>>2]|0)+4>>2]|0)==1)t[(t[r>>2]|0)+52>>2]=0;t[n>>2]=t[(t[r>>2]|0)+12>>2];e:while(1){if(!(t[n>>2]|0))break;if((t[(t[n>>2]|0)+4>>2]|0)==1?(t[(t[n>>2]|0)+52>>2]=0,(t[(t[n>>2]|0)+12>>2]|0)!=0):0){t[n>>2]=t[(t[n>>2]|0)+12>>2];continue}if(t[(t[n>>2]|0)+24>>2]|0){t[n>>2]=t[(t[n>>2]|0)+24>>2];continue}while(1){t[n>>2]=t[(t[n>>2]|0)+20>>2];if(!(t[n>>2]|0))continue e;
	if((t[n>>2]|0)==(t[r>>2]|0)){f=16;break}u=t[n>>2]|0;if(t[(t[n>>2]|0)+24>>2]|0){f=18;break}if(!u)continue e}if((f|0)==16){f=0;t[n>>2]=0;continue}else if((f|0)==18){f=0;t[n>>2]=t[u+24>>2];continue}}s=i;return}function Rx(e){e=e|0;var i=0,r=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if(!(t[r>>2]|0)){s=i;return}if(t[(t[r>>2]|0)+4>>2]|0)pAi[t[135736>>2]&511](t[(t[r>>2]|0)+4>>2]|0);if(t[(t[r>>2]|0)+8>>2]|0)fy(t[(t[r>>2]|0)+8>>2]|0);if(t[(t[r>>2]|0)+16>>2]|0)CH(t[(t[r>>2]|0)+16>>2]|0);pAi[t[135736>>2]&511](t[r>>2]|0);s=i;return}function Nx(e){e=e|0;var i=0,r=0,n=0,f=0;i=s;s=s+16|0;r=i+8|0;n=i+4|0;f=i;t[r>>2]=e;if(!(t[r>>2]|0)){s=i;return}if(t[(t[r>>2]|0)+12>>2]|0){t[f>>2]=0;while(1){if((t[f>>2]|0)>=(t[t[r>>2]>>2]|0))break;t[n>>2]=t[(t[(t[r>>2]|0)+12>>2]|0)+(t[f>>2]<<2)>>2];if(t[n>>2]|0){if(t[(t[n>>2]|0)+4>>2]|0)pAi[t[135736>>2]&511](t[(t[n>>2]|0)+4>>2]|0);if(t[(t[n>>2]|0)+8>>2]|0)pAi[t[135736>>2]&511](t[(t[n>>2]|0)+8>>2]|0);pAi[t[135736>>2]&511](t[n>>2]|0)}t[f>>2]=(t[f>>2]|0)+1}pAi[t[135736>>2]&511](t[(t[r>>2]|0)+12>>2]|0)}if(t[(t[r>>2]|0)+4>>2]|0)XF(t[(t[r>>2]|0)+4>>2]|0,0);pAi[t[135736>>2]&511](t[r>>2]|0);s=i;return}function Tx(e,i){e=e|0;i=i|0;var r=0,f=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0;r=s;s=s+32|0;f=r+24|0;a=r+20|0;o=r+16|0;c=r+12|0;l=r+8|0;b=r+4|0;k=r;t[a>>2]=e;t[o>>2]=i;if(!(t[o>>2]|0)){t[f>>2]=0;h=t[f>>2]|0;s=r;return h|0}t[b>>2]=t[o>>2];while(1){w=t[b>>2]|0;if(!(u[t[b>>2]>>0]|0))break;t[b>>2]=w+1}t[k>>2]=w-(t[o>>2]|0);t[c>>2]=gAi[t[135752>>2]&511]((t[k>>2]|0)+1|0)|0;if(!(t[c>>2]|0)){Fx(t[a>>2]|0,189544);t[f>>2]=0;h=t[f>>2]|0;s=r;return h|0}t[l>>2]=t[c>>2];e:while(1){do if((u[t[o>>2]>>0]|0|0)!=32){if(9<=(u[t[o>>2]>>0]|0|0)?(u[t[o>>2]>>0]|0|0)<=10:0)break;if((u[t[o>>2]>>0]|0|0)!=13)break e}while(0);t[o>>2]=(t[o>>2]|0)+1}e:while(1){if(!(u[t[o>>2]>>0]|0))break;do if((u[t[o>>2]>>0]|0|0)!=32){if(9<=(u[t[o>>2]>>0]|0|0)?(u[t[o>>2]>>0]|0|0)<=10:0)break;if((u[t[o>>2]>>0]|0|0)!=13){a=t[o>>2]|0;t[o>>2]=a+1;k=n[a>>0]|0;a=t[l>>2]|0;t[l>>2]=a+1;n[a>>0]=k;continue e}}while(0);while(1){do if((u[t[o>>2]>>0]|0|0)==32)d=1;else{if(9<=(u[t[o>>2]>>0]|0|0)?(u[t[o>>2]>>0]|0|0)<=10:0){d=1;break}d=(u[t[o>>2]>>0]|0|0)==13}while(0);v=t[o>>2]|0;if(!d)break;t[o>>2]=v+1}if(!(u[v>>0]|0))break;k=t[l>>2]|0;t[l>>2]=k+1;n[k>>0]=32}n[t[l>>2]>>0]=0;t[f>>2]=t[c>>2];h=t[f>>2]|0;s=r;return h|0}function Lx(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i+4|0;n=i;t[r>>2]=e;if(!(t[r>>2]|0)){s=i;return}if(t[(t[r>>2]|0)+8>>2]|0)fy(t[(t[r>>2]|0)+8>>2]|0);if(t[(t[r>>2]|0)+36>>2]|0){t[n>>2]=0;while(1){if((t[n>>2]|0)>=(t[(t[r>>2]|0)+32>>2]|0))break;$H(t[(t[(t[r>>2]|0)+36>>2]|0)+(t[n>>2]<<2)>>2]|0);t[n>>2]=(t[n>>2]|0)+1}pAi[t[135736>>2]&511](t[(t[r>>2]|0)+36>>2]|0)}pAi[t[135736>>2]&511](t[r>>2]|0);s=i;return}function Dx(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0,S=0,g=0,y=0,F=0,O=0,A=0,M=0,R=0,N=0,T=0,L=0,D=0,C=0,P=0,B=0,I=0,H=0,x=0,U=0,z=0,j=0,V=0,q=0;r=s;s=s+144|0;n=r+128|0;f=r+124|0;u=r+120|0;a=r+116|0;o=r+112|0;c=r+108|0;l=r+104|0;b=r+100|0;k=r+96|0;h=r+92|0;w=r+88|0;d=r+84|0;v=r+80|0;m=r+76|0;_=r+72|0;p=r+68|0;E=r+64|0;S=r+60|0;g=r+56|0;y=r+52|0;F=r+48|0;O=r+44|0;A=r+40|0;M=r+36|0;R=r+32|0;N=r+28|0;T=r+24|0;L=r+20|0;D=r+16|0;C=r+12|0;P=r+8|0;B=r+4|0;I=r;t[n>>2]=e;t[f>>2]=i;t[a>>2]=0;t[u>>2]=t[f>>2];e:while(1){H=(t[a>>2]|0)!=0;if(!(t[u>>2]|0))break;if(H){iy(t[a>>2]|0);ry(t[a>>2]|0);t[a>>2]=0}i=t[u>>2]|0;i:do if((t[(t[u>>2]|0)+4>>2]|0)!=1){if((t[i+4>>2]|0)!=3?(t[(t[u>>2]|0)+4>>2]|0)!=4:0){t[a>>2]=t[u>>2];break}if(tU(t[(t[u>>2]|0)+40>>2]|0)|0){if((t[(t[u>>2]|0)+20>>2]|0)!=0?(t[(t[(t[u>>2]|0)+20>>2]|0)+4>>2]|0)==1:0){if(Xl(t[(t[(t[u>>2]|0)+20>>2]|0)+8>>2]|0,189888)|0){x=158;break}if(Xl(t[(t[(t[u>>2]|0)+20>>2]|0)+8>>2]|0,190064)|0){x=158;break}t[a>>2]=t[u>>2];x=158;break}t[a>>2]=t[u>>2]}else x=158}else{if((t[i+36>>2]|0)!=0?(Xl(t[(t[(t[u>>2]|0)+36>>2]|0)+8>>2]|0,t[46968]|0)|0)!=0:0){rU(t[n>>2]|0,t[u>>2]|0);e=(Xl(t[(t[u>>2]|0)+8>>2]|0,189936)|0)!=0;U=t[u>>2]|0;r:do if(e){t[c>>2]=cF(U,192672)|0;n:do if(!(t[c>>2]|0)){t[h>>2]=t[(t[u>>2]|0)+20>>2];while(1){if(!(t[h>>2]|0))break n;if((t[(t[h>>2]|0)+4>>2]|0)!=1)break n;t[c>>2]=cF(t[h>>2]|0,192672)|0;if(t[c>>2]|0)break n;t[h>>2]=t[(t[h>>2]|0)+20>>2]}}while(0);t[o>>2]=cF(t[u>>2]|0,195400)|0;if(!(t[o>>2]|0)){bx(t[n>>2]|0,t[u>>2]|0,1052,195408,0,0);if(t[c>>2]|0)pAi[t[135736>>2]&511](t[c>>2]|0);t[a>>2]=t[u>>2];break i}t[w>>2]=IA(t[o>>2]|0)|0;if(!(t[w>>2]|0)){bx(t[n>>2]|0,t[u>>2]|0,1041,195464,t[o>>2]|0,0);if(t[c>>2]|0)pAi[t[135736>>2]&511](t[c>>2]|0);if(t[o>>2]|0)pAi[t[135736>>2]&511](t[o>>2]|0);t[a>>2]=t[u>>2];break i}if(t[(t[w>>2]|0)+32>>2]|0){bx(t[n>>2]|0,t[u>>2]|0,1041,195504,t[o>>2]|0,0);if(t[c>>2]|0)pAi[t[135736>>2]&511](t[c>>2]|0);xA(t[w>>2]|0);if(t[o>>2]|0)pAi[t[135736>>2]&511](t[o>>2]|0);t[a>>2]=t[u>>2];break i}xA(t[w>>2]|0);t[l>>2]=oF(t[(t[u>>2]|0)+32>>2]|0,t[u>>2]|0)|0;t[b>>2]=GA(t[o>>2]|0,t[l>>2]|0)|0;if(!(t[b>>2]|0)){bx(t[n>>2]|0,t[u>>2]|0,1041,195552,t[o>>2]|0,0);if(t[c>>2]|0)pAi[t[135736>>2]&511](t[c>>2]|0);if(t[o>>2]|0)pAi[t[135736>>2]&511](t[o>>2]|0);if(t[l>>2]|0)pAi[t[135736>>2]&511](t[l>>2]|0);t[a>>2]=t[u>>2];break i}if(t[o>>2]|0)pAi[t[135736>>2]&511](t[o>>2]|0);if(t[l>>2]|0)pAi[t[135736>>2]&511](t[l>>2]|0);t[k>>2]=nU(t[n>>2]|0,t[b>>2]|0,t[c>>2]|0)|0;if(!(t[k>>2]|0)){bx(t[n>>2]|0,t[u>>2]|0,1032,195600,t[b>>2]|0,0);if(t[c>>2]|0)pAi[t[135736>>2]&511](t[c>>2]|0);pAi[t[135736>>2]&511](t[b>>2]|0);t[a>>2]=t[u>>2];break i}else{if(t[c>>2]|0)pAi[t[135736>>2]&511](t[c>>2]|0);pAi[t[135736>>2]&511](t[b>>2]|0);t[(t[u>>2]|0)+52>>2]=t[k>>2];break}}else{z=(Xl(t[U+8>>2]|0,195024)|0)!=0;j=t[u>>2]|0;if(z){t[d>>2]=cF(j,195400)|0;if(!(t[d>>2]|0)){bx(t[n>>2]|0,t[u>>2]|0,1052,195632,0,0);t[a>>2]=t[u>>2];break i}t[m>>2]=oF(t[(t[u>>2]|0)+32>>2]|0,t[u>>2]|0)|0;t[_>>2]=GA(t[d>>2]|0,t[m>>2]|0)|0;if(!(t[_>>2]|0)){bx(t[n>>2]|0,t[u>>2]|0,1041,195680,t[d>>2]|0,0);if(t[d>>2]|0)pAi[t[135736>>2]&511](t[d>>2]|0);if(t[m>>2]|0)pAi[t[135736>>2]&511](t[m>>2]|0);t[a>>2]=t[u>>2];break i}if(t[d>>2]|0)pAi[t[135736>>2]&511](t[d>>2]|0);if(t[m>>2]|0)pAi[t[135736>>2]&511](t[m>>2]|0);t[v>>2]=cF(t[u>>2]|0,192672)|0;n:do if(!(t[v>>2]|0)){t[E>>2]=t[(t[u>>2]|0)+20>>2];while(1){if(!(t[E>>2]|0))break n;if((t[(t[E>>2]|0)+4>>2]|0)!=1)break n;t[v>>2]=cF(t[E>>2]|0,192672)|0;if(t[v>>2]|0)break n;t[E>>2]=t[(t[E>>2]|0)+20>>2]}}while(0);t[p>>2]=fU(t[n>>2]|0,t[_>>2]|0,t[u>>2]|0,t[v>>2]|0)|0;if(t[v>>2]|0)pAi[t[135736>>2]&511](t[v>>2]|0);if(!(t[p>>2]|0)){bx(t[n>>2]|0,t[u>>2]|0,1043,195720,t[_>>2]|0,0);pAi[t[135736>>2]&511](t[_>>2]|0);t[a>>2]=t[u>>2];break i}else{pAi[t[135736>>2]&511](t[_>>2]|0);t[(t[u>>2]|0)+52>>2]=t[p>>2];break}}if((Xl(t[j+8>>2]|0,189864)|0)==0?(Xl(t[(t[u>>2]|0)+8>>2]|0,189904)|0)==0:0){if(((Xl(t[(t[u>>2]|0)+8>>2]|0,192176)|0)==0?(Xl(t[(t[u>>2]|0)+8>>2]|0,193592)|0)==0:0)?(Xl(t[(t[u>>2]|0)+8>>2]|0,189888)|0)==0:0){do if(Xl(t[(t[u>>2]|0)+8>>2]|0,189848)|0){if((t[u>>2]|0)==(t[f>>2]|0))break;t[L>>2]=t[(t[n>>2]|0)+32>>2];do if(t[(t[u>>2]|0)+20>>2]|0){if(!(Xl(t[(t[(t[u>>2]|0)+20>>2]|0)+8>>2]|0,193584)|0))break;z=(t[n>>2]|0)+32|0;t[z>>2]=t[z>>2]|256;Dx(t[n>>2]|0,t[u>>2]|0);t[(t[n>>2]|0)+32>>2]=t[L>>2];break i}while(0);if(!(t[(t[u>>2]|0)+20>>2]|0))break r;if(!(Xl(t[(t[(t[u>>2]|0)+20>>2]|0)+8>>2]|0,193592)|0))break r;z=(t[n>>2]|0)+32|0;t[z>>2]=t[z>>2]|512;Dx(t[n>>2]|0,t[u>>2]|0);t[(t[n>>2]|0)+32>>2]=t[L>>2];break i}while(0);if(!(Xl(t[(t[u>>2]|0)+8>>2]|0,193584)|0))break;j=t[n>>2]|0;if(t[(t[n>>2]|0)+32>>2]&256){bx(j,t[u>>2]|0,1066,195896,0,0);break}if(!(t[j+32>>2]&512))break;bx(t[n>>2]|0,t[u>>2]|0,1084,195952,0,0);break}do if(!(dF(t[u>>2]|0,192672)|0)){t[A>>2]=0;t[O>>2]=t[(t[u>>2]|0)+20>>2];while(1){if(!(t[O>>2]|0))break;if((t[(t[O>>2]|0)+4>>2]|0)!=1)break;t[A>>2]=cF(t[O>>2]|0,192672)|0;if(t[A>>2]|0)break;t[O>>2]=t[(t[O>>2]|0)+20>>2]}j=t[u>>2]|0;if(!(t[A>>2]|0)){_F(j,192672,188112)|0;break}else{_F(j,192672,t[A>>2]|0)|0;pAi[t[135736>>2]&511](t[A>>2]|0);break}}while(0);if((Xl(t[(t[u>>2]|0)+8>>2]|0,192176)|0)!=0?(t[M>>2]=sF(t[u>>2]|0)|0,(t[M>>2]|0)!=0):0){t[R>>2]=zg(t[M>>2]|0,N)|0;if(t[R>>2]|0){t[T>>2]=wF(t[(t[u>>2]|0)+32>>2]|0,t[u>>2]|0,t[N>>2]|0)|0;if(!(t[T>>2]|0))bx(t[n>>2]|0,t[u>>2]|0,1097,195792,t[N>>2]|0,0);else{_F(t[u>>2]|0,192672,t[(t[T>>2]|0)+8>>2]|0)|0;Cy(t[u>>2]|0,t[R>>2]|0)}pAi[t[135736>>2]&511](t[R>>2]|0);pAi[t[135736>>2]&511](t[N>>2]|0)}pAi[t[135736>>2]&511](t[M>>2]|0)}if(!(Xl(t[(t[u>>2]|0)+8>>2]|0,193592)|0))break;if(!(t[(t[n>>2]|0)+32>>2]&512))break;bx(t[n>>2]|0,t[u>>2]|0,1085,195840,0,0);break}t[y>>2]=0;t[S>>2]=cF(t[u>>2]|0,192176)|0;if(t[S>>2]|0){j=t[u>>2]|0;if(t[(t[u>>2]|0)+12>>2]|0){t[F>>2]=Sy(t[j+32>>2]|0,t[(t[u>>2]|0)+36>>2]|0,192176,0)|0;if(t[F>>2]|0){Py(t[(t[u>>2]|0)+12>>2]|0,t[F>>2]|0)|0;t[y>>2]=yy(t[S>>2]|0)|0;Hy(t[F>>2]|0,t[y>>2]|0)|0;t[y>>2]=t[F>>2]}}else t[y>>2]=Ly(j,t[(t[u>>2]|0)+36>>2]|0,192176,t[S>>2]|0)|0;if(!(t[y>>2]|0))bx(t[n>>2]|0,t[u>>2]|0,1008,195752,t[S>>2]|0,0);mF(t[u>>2]|0,192176)|0;pAi[t[135736>>2]&511](t[S>>2]|0);t[g>>2]=cF(t[u>>2]|0,192672)|0;if(!(t[g>>2]|0)){if(!(Xl(t[(t[u>>2]|0)+8>>2]|0,189904)|0))break;_F(t[y>>2]|0,192672,188112)|0;break}if(t[y>>2]|0)_F(t[y>>2]|0,192672,t[g>>2]|0)|0;pAi[t[135736>>2]&511](t[g>>2]|0)}}while(0);if(!(Xl(t[(t[u>>2]|0)+8>>2]|0,196008)|0)){x=158;break}t[D>>2]=cF(t[u>>2]|0,192672)|0;t[C>>2]=t[(t[u>>2]|0)+12>>2];t[P>>2]=t[u>>2];while(1){V=(t[D>>2]|0)!=0;if(!(t[C>>2]|0))break;if(V?(dF(t[C>>2]|0,192672)|0)==0:0)_F(t[C>>2]|0,192672,t[D>>2]|0)|0;t[B>>2]=t[(t[C>>2]|0)+24>>2];iy(t[C>>2]|0);t[P>>2]=oy(t[P>>2]|0,t[C>>2]|0)|0;t[C>>2]=t[B>>2]}if(V)pAi[t[135736>>2]&511](t[D>>2]|0);if((t[(t[u>>2]|0)+48>>2]|0)!=0?(t[(t[u>>2]|0)+20>>2]|0)!=0:0){t[I>>2]=(t[(t[u>>2]|0)+20>>2]|0)+48;while(1){if(!(t[t[I>>2]>>2]|0))break;t[I>>2]=t[t[I>>2]>>2]}t[t[I>>2]>>2]=t[(t[u>>2]|0)+48>>2];t[(t[u>>2]|0)+48>>2]=0}t[a>>2]=t[u>>2];break}do if((t[(t[u>>2]|0)+20>>2]|0)!=0?(t[(t[(t[u>>2]|0)+20>>2]|0)+4>>2]|0)==1:0){if(((Xl(t[(t[(t[u>>2]|0)+20>>2]|0)+8>>2]|0,192176)|0)==0?(Xl(t[(t[(t[u>>2]|0)+20>>2]|0)+8>>2]|0,189888)|0)==0:0)?(Xl(t[(t[(t[u>>2]|0)+20>>2]|0)+8>>2]|0,190064)|0)==0:0)break;bx(t[n>>2]|0,t[u>>2]|0,1035,195352,t[(t[(t[u>>2]|0)+20>>2]|0)+8>>2]|0,0)}while(0);t[a>>2]=t[u>>2]}while(0);if(((((x|0)==158?(x=0,(t[(t[u>>2]|0)+12>>2]|0)!=0):0)?(t[(t[(t[u>>2]|0)+12>>2]|0)+4>>2]|0)!=17:0)?(t[(t[(t[u>>2]|0)+12>>2]|0)+4>>2]|0)!=5:0)?(t[(t[(t[u>>2]|0)+12>>2]|0)+4>>2]|0)!=6:0){t[u>>2]=t[(t[u>>2]|0)+12>>2];continue}if(t[(t[u>>2]|0)+24>>2]|0){t[u>>2]=t[(t[u>>2]|0)+24>>2];continue}while(1){t[u>>2]=t[(t[u>>2]|0)+20>>2];if(!(t[u>>2]|0))continue e;if((t[u>>2]|0)==(t[f>>2]|0)){x=167;break}q=t[u>>2]|0;if(t[(t[u>>2]|0)+24>>2]|0){x=169;break}if(!q)continue e}if((x|0)==167){x=0;t[u>>2]=0;continue}else if((x|0)==169){x=0;t[u>>2]=t[q+24>>2];continue}}if(!H){s=r;return}iy(t[a>>2]|0);ry(t[a>>2]|0);t[a>>2]=0;s=r;return}function Cx(e){e=e|0;var i=0,r=0,n=0,f=0,u=0;i=s;s=s+16|0;r=i+8|0;n=i+4|0;f=i;t[n>>2]=e;t[f>>2]=gAi[t[135744>>2]&511](40)|0;if(!(t[f>>2]|0)){lx(t[n>>2]|0,0);t[r>>2]=0;u=t[r>>2]|0;s=i;return u|0}else{n=(t[f>>2]|0)+0|0;e=n+40|0;do{t[n>>2]=0;n=n+4|0}while((n|0)<(e|0));t[r>>2]=t[f>>2];u=t[r>>2]|0;s=i;return u|0}return 0}function Px(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0;r=s;s=s+32|0;n=r+20|0;f=r+16|0;u=r+12|0;a=r+8|0;o=r+4|0;c=r;t[f>>2]=e;t[u>>2]=i;t[a>>2]=Bx(t[f>>2]|0)|0;if(!(t[a>>2]|0)){t[n>>2]=0;l=t[n>>2]|0;s=r;return l|0}t[t[a>>2]>>2]=t[(t[f>>2]|0)+24>>2];do if(t[(t[f>>2]|0)+24>>2]|0){t[o>>2]=t[(t[(t[f>>2]|0)+24>>2]|0)+4>>2];if(!(t[o>>2]|0)){t[(t[(t[f>>2]|0)+24>>2]|0)+4>>2]=t[a>>2];break}while(1){if(!(t[(t[o>>2]|0)+8>>2]|0))break;t[o>>2]=t[(t[o>>2]|0)+8>>2]}t[(t[o>>2]|0)+8>>2]=t[a>>2]}while(0);t[c>>2]=t[(t[f>>2]|0)+24>>2];t[(t[f>>2]|0)+24>>2]=t[a>>2];uU(t[f>>2]|0,t[u>>2]|0)|0;t[(t[f>>2]|0)+24>>2]=t[a>>2];o=t[f>>2]|0;if(t[(t[f>>2]|0)+24>>2]|0){if(!(t[(t[o+24>>2]|0)+12>>2]|0))bx(t[f>>2]|0,t[u>>2]|0,1039,194360,0,0)}else bx(o,t[u>>2]|0,1036,194320,0,0);aU(t[f>>2]|0,t[a>>2]|0);if(t[(t[a>>2]|0)+24>>2]|0)aO(t[(t[a>>2]|0)+24>>2]|0,383,t[f>>2]|0);if(t[(t[a>>2]|0)+28>>2]|0)aO(t[(t[a>>2]|0)+28>>2]|0,384,t[f>>2]|0);t[(t[f>>2]|0)+24>>2]=t[c>>2];t[n>>2]=t[a>>2];l=t[n>>2]|0;s=r;return l|0}function Bx(e){e=e|0;var i=0,r=0,n=0,f=0,u=0;i=s;s=s+16|0;r=i+8|0;n=i+4|0;f=i;t[n>>2]=e;t[f>>2]=gAi[t[135744>>2]&511](32)|0;if(!(t[f>>2]|0)){lx(t[n>>2]|0,0);t[r>>2]=0;u=t[r>>2]|0;s=i;return u|0}else{n=t[f>>2]|0;t[n+0>>2]=0;t[n+4>>2]=0;t[n+8>>2]=0;t[n+12>>2]=0;t[n+16>>2]=0;t[n+20>>2]=0;t[n+24>>2]=0;t[n+28>>2]=0;t[r>>2]=t[f>>2];u=t[r>>2]|0;s=i;return u|0}return 0}function Ix(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0;r=s;s=s+32|0;n=r+20|0;f=r+16|0;u=r+12|0;a=r+8|0;o=r+4|0;c=r;t[f>>2]=e;t[u>>2]=i;t[a>>2]=0;t[o>>2]=0;if(!(t[u>>2]|0)){bx(t[f>>2]|0,t[u>>2]|0,1106,191968,0,0);t[n>>2]=-1;l=t[n>>2]|0;s=r;return l|0}do if(((((t[u>>2]|0)!=0?(t[(t[u>>2]|0)+36>>2]|0)!=0:0)?(t[(t[u>>2]|0)+4>>2]|0)==1:0)?(Xl(t[(t[u>>2]|0)+8>>2]|0,189824)|0)!=0:0)?(Xl(t[(t[(t[u>>2]|0)+36>>2]|0)+8>>2]|0,t[46968]|0)|0)!=0:0){t[o>>2]=dx(t[f>>2]|0,t[u>>2]|0)|0;if(!(t[o>>2]|0)){t[n>>2]=-1;l=t[n>>2]|0;s=r;return l|0}else{t[t[o>>2]>>2]=0;if(!(t[(t[u>>2]|0)+12>>2]|0))break;bx(t[f>>2]|0,t[u>>2]|0,1024,191992,0,0);break}}else b=12;while(0);do if((b|0)==12){if(((((t[u>>2]|0)!=0?(t[(t[u>>2]|0)+36>>2]|0)!=0:0)?(t[(t[u>>2]|0)+4>>2]|0)==1:0)?(Xl(t[(t[u>>2]|0)+8>>2]|0,189832)|0)!=0:0)?(Xl(t[(t[(t[u>>2]|0)+36>>2]|0)+8>>2]|0,t[46968]|0)|0)!=0:0){t[o>>2]=dx(t[f>>2]|0,t[u>>2]|0)|0;if(!(t[o>>2]|0)){t[n>>2]=-1;l=t[n>>2]|0;s=r;return l|0}else{t[t[o>>2]>>2]=1;if(!(t[(t[u>>2]|0)+12>>2]|0))break;bx(t[f>>2]|0,t[u>>2]|0,1055,192024,0,0);break}}t[o>>2]=lU(t[f>>2]|0,t[u>>2]|0,1)|0}while(0);if(t[(t[(t[f>>2]|0)+24>>2]|0)+12>>2]|0){t[c>>2]=t[(t[(t[f>>2]|0)+24>>2]|0)+12>>2];while(1){if(!(t[(t[c>>2]|0)+32>>2]|0))break;t[c>>2]=t[(t[c>>2]|0)+32>>2]}t[(t[c>>2]|0)+32>>2]=t[o>>2]}else t[(t[(t[f>>2]|0)+24>>2]|0)+12>>2]=t[o>>2];t[u>>2]=t[(t[u>>2]|0)+24>>2];if(t[u>>2]|0){bx(t[f>>2]|0,t[u>>2]|0,1105,192064,0,0);t[n>>2]=-1;l=t[n>>2]|0;s=r;return l|0}else{t[n>>2]=t[a>>2];l=t[n>>2]|0;s=r;return l|0}return 0}function Hx(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0;n=s;s=s+32|0;u=n+16|0;a=n+12|0;o=n+8|0;c=n+4|0;l=n;t[a>>2]=e;t[o>>2]=i;t[c>>2]=r;t[l>>2]=0;e:while(1){if(!((t[l>>2]|0)==0&(t[o>>2]|0)!=0)){b=13;break}do if((t[t[o>>2]>>2]|0)!=11?(t[t[o>>2]>>2]|0)!=13:0){r=t[a>>2]|0;i=t[(t[o>>2]|0)+24>>2]|0;e=t[c>>2]|0;if((t[t[o>>2]>>2]|0)==4){t[l>>2]=Hx(r,i,e+1|0)|0;break}else{t[l>>2]=Hx(r,i,e)|0;break}}else b=5;while(0);do if((b|0)==5){b=0;e=t[c>>2]|0;if((f[(t[o>>2]|0)+48>>1]|0)!=-1)if((e|0)==(f[(t[o>>2]|0)+48>>1]|0)){b=8;break e}else break;else{f[(t[o>>2]|0)+48>>1]=e;t[l>>2]=Hx(t[a>>2]|0,t[(t[o>>2]|0)+24>>2]|0,t[c>>2]|0)|0;f[(t[o>>2]|0)+48>>1]=-2;break}}while(0);t[o>>2]=t[(t[o>>2]|0)+32>>2]}if((b|0)==8){bx(t[a>>2]|0,t[(t[o>>2]|0)+4>>2]|0,1099,191928,t[(t[o>>2]|0)+8>>2]|0,0);t[u>>2]=-1;k=t[u>>2]|0;s=n;return k|0}else if((b|0)==13){t[u>>2]=t[l>>2];k=t[u>>2]|0;s=n;return k|0}return 0}function xx(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0;n=s;s=s+32|0;u=n+24|0;a=n+20|0;o=n+16|0;c=n+12|0;l=n+8|0;b=n+4|0;k=n;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;t[c>>2]=0;e:while(1){if(!(t[a>>2]|0)){h=87;break}i:do if((t[t[a>>2]>>2]|0)!=11?(t[t[a>>2]>>2]|0)!=13:0){if((t[t[a>>2]>>2]|0)==1){t[(t[a>>2]|0)+28>>2]=t[o>>2];if(t[o>>2]|0){if((t[t[o>>2]>>2]|0)==9){h=15;break e}if((t[t[o>>2]>>2]|0)==8){h=15;break e}if((t[t[o>>2]>>2]|0)==18){h=15;break e}if((t[t[o>>2]>>2]|0)==19){h=15;break e}if((t[t[o>>2]>>2]|0)==16){h=15;break e}if((t[t[o>>2]>>2]|0)==15){h=15;break e}}if((t[o>>2]|0)!=0?(t[t[o>>2]>>2]|0)==17:0){t[c>>2]=sU(t[u>>2]|0,t[a>>2]|0,t[o>>2]|0,t[c>>2]|0)|0;break}t[c>>2]=t[a>>2];break}r=(t[t[a>>2]>>2]|0)==0;t[(t[a>>2]|0)+28>>2]=t[o>>2];if(r){if(t[o>>2]|0){if((t[t[o>>2]>>2]|0)==16){h=24;break e}if((t[t[o>>2]>>2]|0)==15){h=24;break e}}do if(t[o>>2]|0){if((t[t[o>>2]>>2]|0)!=18?(t[t[o>>2]>>2]|0)!=19:0)break;t[c>>2]=sU(t[u>>2]|0,t[a>>2]|0,t[o>>2]|0,t[c>>2]|0)|0;break i}while(0);t[c>>2]=t[a>>2];break}if(t[(t[a>>2]|0)+24>>2]|0)xx(t[u>>2]|0,t[(t[a>>2]|0)+24>>2]|0,t[a>>2]|0);if((t[t[a>>2]>>2]|0)!=7?(t[(t[a>>2]|0)+36>>2]|0)!=0:0)xx(t[u>>2]|0,t[(t[a>>2]|0)+36>>2]|0,t[a>>2]|0);if(t[(t[a>>2]|0)+40>>2]|0)xx(t[u>>2]|0,t[(t[a>>2]|0)+40>>2]|0,t[a>>2]|0);r:do if((t[t[a>>2]>>2]|0)==4){while(1){if(!(t[(t[a>>2]|0)+24>>2]|0))break;t[l>>2]=bU(t[u>>2]|0,t[(t[a>>2]|0)+24>>2]|0)|0;if((t[l>>2]|0)!=1)break;t[b>>2]=t[(t[a>>2]|0)+24>>2];t[(t[a>>2]|0)+24>>2]=t[(t[b>>2]|0)+32>>2];t[(t[b>>2]|0)+32>>2]=t[(t[a>>2]|0)+36>>2];t[(t[a>>2]|0)+36>>2]=t[b>>2]}t[k>>2]=t[(t[a>>2]|0)+24>>2];while(1){if(!(t[k>>2]|0))break r;if(!(t[(t[k>>2]|0)+32>>2]|0))break r;t[b>>2]=t[(t[k>>2]|0)+32>>2];t[l>>2]=bU(t[u>>2]|0,t[b>>2]|0)|0;r=t[b>>2]|0;if((t[l>>2]|0)==1){t[(t[k>>2]|0)+32>>2]=t[r+32>>2];t[(t[b>>2]|0)+32>>2]=t[(t[a>>2]|0)+36>>2];t[(t[a>>2]|0)+36>>2]=t[b>>2];continue}else{t[k>>2]=r;continue}}}while(0);if(!((t[t[a>>2]>>2]|0)!=18?(t[t[a>>2]>>2]|0)!=19:0))h=49;do if((h|0)==49){h=0;r=t[a>>2]|0;if(!(t[(t[a>>2]|0)+24>>2]|0)){t[r>>2]=0;break}if(!(t[(t[r+24>>2]|0)+32>>2]|0)){if((t[o>>2]|0)==0&(t[c>>2]|0)==0){t[t[a>>2]>>2]=-1;break}r=t[a>>2]|0;if(!(t[c>>2]|0)){t[(t[o>>2]|0)+24>>2]=t[r+24>>2];t[(t[(t[a>>2]|0)+24>>2]|0)+32>>2]=t[(t[a>>2]|0)+32>>2];t[a>>2]=t[(t[a>>2]|0)+24>>2];break}else{t[(t[(t[a>>2]|0)+24>>2]|0)+32>>2]=t[r+32>>2];t[(t[c>>2]|0)+32>>2]=t[(t[a>>2]|0)+24>>2];t[a>>2]=t[(t[a>>2]|0)+24>>2];break}}}while(0);if(((t[t[a>>2]>>2]|0)==2?(t[(t[a>>2]|0)+24>>2]|0)!=0:0)?(t[t[(t[a>>2]|0)+24>>2]>>2]|0)==1:0){t[c>>2]=sU(t[u>>2]|0,t[a>>2]|0,t[o>>2]|0,t[c>>2]|0)|0;break}if((t[t[a>>2]>>2]|0)==1){if(t[o>>2]|0){if((t[t[o>>2]>>2]|0)==9){h=69;break e}if((t[t[o>>2]>>2]|0)==8){h=69;break e}if((t[t[o>>2]>>2]|0)==18){h=69;break e}if((t[t[o>>2]>>2]|0)==19){h=69;break e}if((t[t[o>>2]>>2]|0)==16){h=69;break e}if((t[t[o>>2]>>2]|0)==15){h=69;break e}}if((t[o>>2]|0)!=0?(t[t[o>>2]>>2]|0)==17:0){t[c>>2]=sU(t[u>>2]|0,t[a>>2]|0,t[o>>2]|0,t[c>>2]|0)|0;break}t[c>>2]=t[a>>2];break}else{if(t[t[a>>2]>>2]|0){t[c>>2]=t[a>>2];break}if(t[o>>2]|0){if((t[t[o>>2]>>2]|0)==16){h=78;break e}if((t[t[o>>2]>>2]|0)==15){h=78;break e}}r:do if(t[o>>2]|0){do if((t[t[o>>2]>>2]|0)!=18){if((t[t[o>>2]>>2]|0)==19)break;if((t[t[o>>2]>>2]|0)!=17)break r}while(0);t[c>>2]=sU(t[u>>2]|0,t[a>>2]|0,t[o>>2]|0,t[c>>2]|0)|0;break i}while(0);t[c>>2]=t[a>>2];break}}else h=5;while(0);if((h|0)==5?(h=0,(f[(t[a>>2]|0)+48>>1]|0)!=-3):0){f[(t[a>>2]|0)+48>>1]=-3;xx(t[u>>2]|0,t[(t[a>>2]|0)+24>>2]|0,t[a>>2]|0)}t[a>>2]=t[(t[a>>2]|0)+32>>2]}if((h|0)==15){t[t[o>>2]>>2]=1;s=n;return}else if((h|0)==24){t[t[o>>2]>>2]=0;s=n;return}else if((h|0)==69){t[t[o>>2]>>2]=1;s=n;return}else if((h|0)==78){t[t[o>>2]>>2]=0;s=n;return}else if((h|0)==87){s=n;return}}function Ux(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0;u=s;s=s+32|0;a=u+28|0;o=u+24|0;c=u+20|0;l=u+16|0;b=u+12|0;k=u+8|0;h=u+4|0;w=u;t[a>>2]=e;t[o>>2]=i;t[c>>2]=r;t[l>>2]=n;t[w>>2]=0;while(1){if(!(t[o>>2]|0))break;t[k>>2]=0;do if((t[t[o>>2]>>2]|0)!=11?(t[t[o>>2]>>2]|0)!=13:0){if((t[t[o>>2]>>2]|0)==4){kU(t[a>>2]|0,t[o>>2]|0);if(t[c>>2]&8)bx(t[a>>2]|0,t[(t[o>>2]|0)+4>>2]|0,1070,190416,0,0);if(t[c>>2]&4)bx(t[a>>2]|0,t[(t[o>>2]|0)+4>>2]|0,1079,190472,0,0);if(t[c>>2]&1)bx(t[a>>2]|0,t[(t[o>>2]|0)+4>>2]|0,1068,190520,0,0);if(t[c>>2]&1)bx(t[a>>2]|0,t[(t[o>>2]|0)+4>>2]|0,1068,190520,0,0);t[b>>2]=0;t[k>>2]=Ux(t[a>>2]|0,t[(t[o>>2]|0)+36>>2]|0,t[b>>2]|0,t[t[o>>2]>>2]|0)|0;if(t[k>>2]|0)bx(t[a>>2]|0,t[(t[o>>2]|0)+4>>2]|0,1015,190576,t[(t[o>>2]|0)+8>>2]|0,0);t[k>>2]=Ux(t[a>>2]|0,t[(t[o>>2]|0)+24>>2]|0,t[b>>2]|0,t[t[o>>2]>>2]|0)|0;if((t[k>>2]|0)==-1){bx(t[a>>2]|0,t[(t[o>>2]|0)+4>>2]|0,1016,190632,t[(t[o>>2]|0)+8>>2]|0,0);break}else{t[k>>2]=2;break}}if((t[t[o>>2]>>2]|0)==9){if(t[c>>2]&1)bx(t[a>>2]|0,t[(t[o>>2]|0)+4>>2]|0,1067,190672,0,0);if(t[c>>2]&4)bx(t[a>>2]|0,t[(t[o>>2]|0)+4>>2]|0,1078,190720,0,0);if(t[c>>2]&32)bx(t[a>>2]|0,t[(t[o>>2]|0)+4>>2]|0,1086,190768,0,0);if(t[c>>2]&64)bx(t[a>>2]|0,t[(t[o>>2]|0)+4>>2]|0,1087,190824,0,0);if(t[c>>2]&8)bx(t[a>>2]|0,t[(t[o>>2]|0)+4>>2]|0,1069,190888,0,0);if(t[c>>2]&16)bx(t[a>>2]|0,t[(t[o>>2]|0)+4>>2]|0,1088,190936,0,0);do if((t[c>>2]&2|0)==0?(t[(t[o>>2]|0)+8>>2]|0)==0:0){n=t[a>>2]|0;r=t[(t[o>>2]|0)+4>>2]|0;if(!(t[(t[o>>2]|0)+12>>2]|0)){bx(n,r,1e3,190984,0,0);break}else{bx(n,r,1056,191040,0,0);break}}while(0);t[b>>2]=t[c>>2]|1;Ux(t[a>>2]|0,t[(t[o>>2]|0)+24>>2]|0,t[b>>2]|0,t[t[o>>2]>>2]|0)|0;t[k>>2]=0;break}if((t[t[o>>2]>>2]|0)!=16?(t[t[o>>2]>>2]|0)!=15:0){if((t[t[o>>2]>>2]|0)==8){if(t[c>>2]&4)bx(t[a>>2]|0,t[(t[o>>2]|0)+4>>2]|0,1081,191192,0,0);if(t[c>>2]&8)bx(t[a>>2]|0,t[(t[o>>2]|0)+4>>2]|0,1074,191232,0,0);if(t[c>>2]&16)bx(t[a>>2]|0,t[(t[o>>2]|0)+4>>2]|0,1093,191280,0,0);t[b>>2]=t[c>>2]|4;t[k>>2]=Ux(t[a>>2]|0,t[(t[o>>2]|0)+24>>2]|0,t[b>>2]|0,t[t[o>>2]>>2]|0)|0;break}if((t[t[o>>2]>>2]|0)==18){if(t[c>>2]&8)bx(t[a>>2]|0,t[(t[o>>2]|0)+4>>2]|0,1072,191320,0,0);if(t[c>>2]&16)bx(t[a>>2]|0,t[(t[o>>2]|0)+4>>2]|0,1091,191368,0,0);r=t[c>>2]|0;if(t[c>>2]&2)t[b>>2]=r|32;else t[b>>2]=r;t[k>>2]=Ux(t[a>>2]|0,t[(t[o>>2]|0)+24>>2]|0,t[b>>2]|0,t[t[o>>2]>>2]|0)|0;kU(t[a>>2]|0,t[o>>2]|0);break}if((t[t[o>>2]>>2]|0)==19){if(t[c>>2]&4)bx(t[a>>2]|0,t[(t[o>>2]|0)+4>>2]|0,1080,191408,0,0);if(t[c>>2]&8)bx(t[a>>2]|0,t[(t[o>>2]|0)+4>>2]|0,1073,191456,0,0);if(t[c>>2]&16)bx(t[a>>2]|0,t[(t[o>>2]|0)+4>>2]|0,1073,191512,0,0);r=t[c>>2]|0;if(t[c>>2]&2)t[b>>2]=r|64;else t[b>>2]=r;t[k>>2]=Ux(t[a>>2]|0,t[(t[o>>2]|0)+24>>2]|0,t[b>>2]|0,t[t[o>>2]>>2]|0)|0;break}r=t[o>>2]|0;if((t[t[o>>2]>>2]|0)==2){if((t[r+28>>2]|0)!=0?(t[t[(t[o>>2]|0)+28>>2]>>2]|0)==5:0)t[b>>2]=t[c>>2]|8;else t[b>>2]=t[c>>2];t[k>>2]=Ux(t[a>>2]|0,t[(t[o>>2]|0)+24>>2]|0,t[b>>2]|0,t[t[o>>2]>>2]|0)|0;break}if((t[r>>2]|0)==5){if(t[c>>2]&16)bx(t[a>>2]|0,t[(t[o>>2]|0)+4>>2]|0,1089,191560,0,0);Ux(t[a>>2]|0,t[(t[o>>2]|0)+24>>2]|0,t[c>>2]|0,t[t[o>>2]>>2]|0)|0;t[k>>2]=1;break}if((t[t[o>>2]>>2]|0)==7){if(t[c>>2]&16)bx(t[a>>2]|0,t[(t[o>>2]|0)+4>>2]|0,1096,191600,0,0);Ux(t[a>>2]|0,t[(t[o>>2]|0)+24>>2]|0,t[c>>2]|0,t[t[o>>2]>>2]|0)|0;t[k>>2]=1;break}if((t[t[o>>2]>>2]|0)==3){if(t[c>>2]&4)bx(t[a>>2]|0,t[(t[o>>2]|0)+4>>2]|0,1083,191640,0,0);if(t[c>>2]&8)bx(t[a>>2]|0,t[(t[o>>2]|0)+4>>2]|0,1077,191680,0,0);if(t[c>>2]&16)bx(t[a>>2]|0,t[(t[o>>2]|0)+4>>2]|0,1095,191728,0,0);t[k>>2]=2;break}if(t[t[o>>2]>>2]|0){r=t[a>>2]|0;n=t[o>>2]|0;if((t[t[o>>2]>>2]|0)==17){wU(r,n);t[k>>2]=Ux(t[a>>2]|0,t[(t[o>>2]|0)+24>>2]|0,t[c>>2]|0,t[t[o>>2]>>2]|0)|0;break}else{t[k>>2]=Ux(r,t[n+24>>2]|0,t[c>>2]|0,t[t[o>>2]>>2]|0)|0;break}}if(t[c>>2]&8)bx(t[a>>2]|0,t[(t[o>>2]|0)+4>>2]|0,1071,191768,0,0);if(t[c>>2]&16)bx(t[a>>2]|0,t[(t[o>>2]|0)+4>>2]|0,1090,191816,0,0);t[k>>2]=0;break}if(t[c>>2]&8)bx(t[a>>2]|0,t[(t[o>>2]|0)+4>>2]|0,1075,191096,0,0);if(t[c>>2]&16)bx(t[a>>2]|0,t[(t[o>>2]|0)+4>>2]|0,1094,191144,0,0);t[b>>2]=t[c>>2]|2;t[k>>2]=Ux(t[a>>2]|0,t[(t[o>>2]|0)+24>>2]|0,t[b>>2]|0,t[t[o>>2]>>2]|0)|0;t[k>>2]=hU(t[k>>2]|0,t[k>>2]|0)|0}else d=5;while(0);do if((d|0)==5){d=0;if(t[c>>2]&8)bx(t[a>>2]|0,t[(t[o>>2]|0)+4>>2]|0,1076,190272,0,0);do if(!(t[(t[o>>2]|0)+24>>2]|0)){n=t[a>>2]|0;r=t[(t[o>>2]|0)+4>>2]|0;if((t[t[o>>2]>>2]|0)==13){bx(n,r,1101,190320,0,0);break}if(t[(t[o>>2]|0)+8>>2]|0)v=t[(t[o>>2]|0)+8>>2]|0;else v=190408;bx(n,r,1101,190368,v,0)}while(0);r=(t[o>>2]|0)+48|0;if((f[(t[o>>2]|0)+48>>1]|0)>-4){f[r>>1]=-4;t[k>>2]=Ux(t[a>>2]|0,t[(t[o>>2]|0)+24>>2]|0,t[c>>2]|0,t[t[o>>2]>>2]|0)|0;f[(t[o>>2]|0)+48>>1]=(t[k>>2]|0)-15;break}if((f[r>>1]|0)==-4){t[k>>2]=2;break}else{t[k>>2]=(f[(t[o>>2]|0)+48>>1]|0)+15;break}}while(0);t[o>>2]=t[(t[o>>2]|0)+32>>2];if((t[l>>2]|0)==18){t[w>>2]=hU(t[w>>2]|0,t[k>>2]|0)|0;continue}if((t[l>>2]|0)==19){t[h>>2]=hU(t[w>>2]|0,t[k>>2]|0)|0;if((t[h>>2]|0)==-1)continue;t[h>>2]=dU(t[w>>2]|0,t[k>>2]|0)|0;continue}if((t[l>>2]|0)==17){t[w>>2]=dU(t[w>>2]|0,t[k>>2]|0)|0;continue}if((t[l>>2]|0)==8){t[w>>2]=1;continue}if((t[l>>2]|0)!=2){t[w>>2]=hU(t[w>>2]|0,t[k>>2]|0)|0;continue}if((t[k>>2]|0)==-1){t[w>>2]=-1;continue}else{t[w>>2]=1;continue}}s=u;return t[w>>2]|0}function zx(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0;n=s;s=s+48|0;f=n+40|0;u=n+36|0;a=n+32|0;o=n+28|0;c=n+24|0;l=n+20|0;b=n+16|0;k=n+12|0;h=n+8|0;w=n+4|0;d=n;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;t[c>>2]=0;t[h>>2]=0;t[w>>2]=0;if(t[(t[u>>2]|0)+36>>2]|0){t[f>>2]=0;v=t[f>>2]|0;s=n;return v|0}t[l>>2]=0;t[b>>2]=t[a>>2];e:while(1){if(!(t[b>>2]|0)){m=41;break}if(!(t[o>>2]|0))if((t[t[b>>2]>>2]|0)!=4?(t[t[b>>2]>>2]|0)!=3:0)m=8;else m=10;else m=8;do if((m|0)==8){m=0;if((t[o>>2]|0)==1?(t[t[b>>2]>>2]|0)==9:0){m=10;break}if((((((((((t[t[b>>2]>>2]|0)!=17?(t[t[b>>2]>>2]|0)!=19:0)?(t[t[b>>2]>>2]|0)!=18:0)?(t[t[b>>2]>>2]|0)!=16:0)?(t[t[b>>2]>>2]|0)!=15:0)?(t[t[b>>2]>>2]|0)!=14:0)?(t[t[b>>2]>>2]|0)!=13:0)?(t[t[b>>2]>>2]|0)!=11:0)?(t[t[b>>2]>>2]|0)!=10:0)?(t[t[b>>2]>>2]|0)!=12:0)break;if(t[(t[b>>2]|0)+24>>2]|0){t[l>>2]=t[b>>2];t[b>>2]=t[(t[b>>2]|0)+24>>2];t[k>>2]=t[b>>2];while(1){if(!(t[k>>2]|0))continue e;t[(t[k>>2]|0)+28>>2]=t[l>>2];t[k>>2]=t[(t[k>>2]|0)+32>>2]}}}while(0);if((m|0)==10){m=0;if(!(t[c>>2]|0)){t[w>>2]=10;t[c>>2]=gAi[t[135744>>2]&511]((t[w>>2]|0)+1<<2)|0;if(!(t[c>>2]|0)){m=12;break}}else if((t[w>>2]|0)<=(t[h>>2]|0)){t[w>>2]=t[w>>2]<<1;t[d>>2]=MAi[t[135760>>2]&511](t[c>>2]|0,(t[w>>2]|0)+1<<2)|0;if(!(t[d>>2]|0)){m=15;break}t[c>>2]=t[d>>2]}r=t[b>>2]|0;i=t[h>>2]|0;t[h>>2]=i+1;t[(t[c>>2]|0)+(i<<2)>>2]=r;t[(t[c>>2]|0)+(t[h>>2]<<2)>>2]=0}if((t[b>>2]|0)==(t[a>>2]|0)){m=41;break}if(t[(t[b>>2]|0)+32>>2]|0){t[b>>2]=t[(t[b>>2]|0)+32>>2];continue}while(1){t[b>>2]=t[(t[b>>2]|0)+28>>2];if(!(t[b>>2]|0))continue e;if((t[b>>2]|0)==(t[a>>2]|0)){m=37;break e}_=t[b>>2]|0;if(t[(t[b>>2]|0)+32>>2]|0)break;if(!_)continue e}t[b>>2]=t[_+32>>2]}if((m|0)==12){lx(t[u>>2]|0,190240);t[f>>2]=0;v=t[f>>2]|0;s=n;return v|0}else if((m|0)==15){lx(t[u>>2]|0,190240);pAi[t[135736>>2]&511](t[c>>2]|0);t[f>>2]=0;v=t[f>>2]|0;s=n;return v|0}else if((m|0)==37){t[f>>2]=t[c>>2];v=t[f>>2]|0;s=n;return v|0}else if((m|0)==41){t[f>>2]=t[c>>2];v=t[f>>2]|0;s=n;return v|0}return 0}function jx(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,l=0;n=s;s=s+32|0;f=n+16|0;u=n+8|0;a=n+4|0;o=n;t[n+12>>2]=e;t[u>>2]=i;t[a>>2]=r;t[o>>2]=t[a>>2];if((t[u>>2]|0)==0|(t[a>>2]|0)==0){t[f>>2]=1;c=t[f>>2]|0;s=n;return c|0}if((t[t[u>>2]>>2]|0)!=0?(t[t[a>>2]>>2]|0)!=0:0){e:while(1){if(!(t[t[u>>2]>>2]|0)){l=12;break}while(1){if(!(t[t[a>>2]>>2]|0))break;if(!(vU(t[t[u>>2]>>2]|0,t[t[a>>2]>>2]|0)|0)){l=9;break e}t[a>>2]=(t[a>>2]|0)+4}t[a>>2]=t[o>>2];t[u>>2]=(t[u>>2]|0)+4}if((l|0)==9){t[f>>2]=0;c=t[f>>2]|0;s=n;return c|0}else if((l|0)==12){t[f>>2]=1;c=t[f>>2]|0;s=n;return c|0}}t[f>>2]=1;c=t[f>>2]|0;s=n;return c|0}function Vx(e){e=e|0;var i=0,r=0,n=0,u=0,a=0,o=0,c=0,l=0,b=0;i=s;s=s+32|0;r=i+20|0;n=i+16|0;u=i+12|0;a=i+8|0;o=i+4|0;c=i;t[n>>2]=e;t[u>>2]=-1;if(!(t[n>>2]|0)){t[r>>2]=-1;l=t[r>>2]|0;s=i;return l|0}if((t[t[n>>2]>>2]|0)!=4?(f[(t[n>>2]|0)+50>>1]&64|0)!=0:0){t[r>>2]=1;l=t[r>>2]|0;s=i;return l|0}if((t[t[n>>2]>>2]|0)!=4?(f[(t[n>>2]|0)+50>>1]&128|0)!=0:0){t[r>>2]=0;l=t[r>>2]|0;s=i;return l|0}e:do switch(t[t[n>>2]>>2]|0){case 1:case 7:case 6:case 8:case 5:case 19:case 9:case 2:{t[u>>2]=0;break}case 13:case 12:case 11:{if((f[(t[n>>2]|0)+48>>1]|0)==-20){t[r>>2]=1;l=t[r>>2]|0;s=i;return l|0}f[(t[n>>2]|0)+48>>1]=-20;t[o>>2]=t[(t[n>>2]|0)+24>>2];while(1){if(!(t[o>>2]|0))break e;t[u>>2]=Vx(t[o>>2]|0)|0;if((t[u>>2]|0)!=1)break e;t[o>>2]=t[(t[o>>2]|0)+32>>2]}break}case 4:{if((f[(t[n>>2]|0)+50>>1]&128|0)==0?(f[(t[n>>2]|0)+50>>1]&64|0)==0:0){t[a>>2]=t[(t[n>>2]|0)+24>>2];while(1){if(!(t[a>>2]|0))break;t[u>>2]=Vx(t[a>>2]|0)|0;if((t[u>>2]|0)!=1)break;t[a>>2]=t[(t[a>>2]|0)+32>>2]}if(!(t[u>>2]|0)){e=(t[n>>2]|0)+50|0;f[e>>1]=f[e>>1]&-65;e=(t[n>>2]|0)+50|0;f[e>>1]=f[e>>1]|128}if((t[u>>2]|0)==1?(e=(t[n>>2]|0)+50|0,b=f[e>>1]&128,f[e>>1]=b,b<<16>>16==0):0){b=(t[n>>2]|0)+50|0;f[b>>1]=f[b>>1]|64}}if((t[(t[n>>2]|0)+40>>2]|0)==0?(t[(t[n>>2]|0)+8>>2]|0)!=0:0)t[u>>2]=1;else t[u>>2]=0;t[r>>2]=t[u>>2];l=t[r>>2]|0;s=i;return l|0}case 10:case 18:case 17:case 16:case 15:case 14:case 20:{t[c>>2]=t[(t[n>>2]|0)+24>>2];while(1){if(!(t[c>>2]|0))break e;t[u>>2]=Vx(t[c>>2]|0)|0;if((t[u>>2]|0)!=1)break e;t[c>>2]=t[(t[c>>2]|0)+32>>2]}break}case-1:{t[u>>2]=Vx(t[(t[n>>2]|0)+24>>2]|0)|0;break}case 0:case 3:{t[u>>2]=1;break}default:{}}while(0);if(!(t[u>>2]|0)){c=(t[n>>2]|0)+50|0;f[c>>1]=f[c>>1]|128}if((t[u>>2]|0)==1){c=(t[n>>2]|0)+50|0;f[c>>1]=f[c>>1]|64}t[r>>2]=t[u>>2];l=t[r>>2]|0;s=i;return l|0}function qx(e,i){e=e|0;i=i|0;var r=0,n=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,m=0,_=0,p=0,E=0,S=0,g=0,y=0,F=0,O=0,A=0,M=0,R=0,N=0;r=s;s=s+80|0;n=r;u=r+64|0;a=r+60|0;o=r+56|0;c=r+52|0;l=r+48|0;b=r+44|0;k=r+40|0;h=r+36|0;w=r+32|0;d=r+28|0;m=r+24|0;_=r+20|0;p=r+16|0;E=r+12|0;S=r+8|0;g=r+4|0;t[a>>2]=e;t[o>>2]=i;t[c>>2]=0;if((t[a>>2]|0)==0|(t[o>>2]|0)==0){t[u>>2]=-1;y=t[u>>2]|0;s=r;return y|0}e:do switch(t[t[o>>2]>>2]|0){case-1:{t[c>>2]=qx(t[a>>2]|0,t[(t[o>>2]|0)+24>>2]|0)|0;break}case 14:{t[m>>2]=t[(t[a>>2]|0)+136>>2];t[l>>2]=t[(t[o>>2]|0)+24>>2];while(1){F=t[a>>2]|0;if(!(t[l>>2]|0))break;qx(F,t[l>>2]|0)|0;t[l>>2]=t[(t[l>>2]|0)+32>>2]}hb(t[F+132>>2]|0,t[m>>2]|0,t[(t[a>>2]|0)+136>>2]|0)|0;break}case 17:{t[E>>2]=0;t[S>>2]=t[(t[a>>2]|0)+136>>2];t[l>>2]=t[(t[o>>2]|0)+24>>2];while(1){if(!(t[l>>2]|0))break;t[(t[a>>2]|0)+136>>2]=t[S>>2];t[c>>2]=qx(t[a>>2]|0,t[l>>2]|0)|0;if(t[c>>2]|0)break;i=t[a>>2]|0;if(!(t[E>>2]|0))t[E>>2]=t[i+136>>2];else hb(t[i+132>>2]|0,t[(t[a>>2]|0)+136>>2]|0,t[E>>2]|0)|0;t[l>>2]=t[(t[l>>2]|0)+32>>2]}t[(t[a>>2]|0)+136>>2]=t[E>>2];break}case 20:{if((Vx(t[o>>2]|0)|0)==1?(f[(t[o>>2]|0)+48>>1]|0)!=-25:0){t[b>>2]=t[(t[a>>2]|0)+132>>2];t[k>>2]=t[(t[a>>2]|0)+136>>2];f[(t[o>>2]|0)+48>>1]=-25;t[l>>2]=t[(t[o>>2]|0)+24>>2];i=rb()|0;t[(t[a>>2]|0)+132>>2]=i;if(!(t[(t[a>>2]|0)+132>>2]|0)){t[u>>2]=-1;y=t[u>>2]|0;s=r;return y|0}tb(t[(t[a>>2]|0)+132>>2]|0,1);i=ub(t[(t[a>>2]|0)+132>>2]|0)|0;t[(t[a>>2]|0)+136>>2]=i;while(1){O=t[a>>2]|0;if(!(t[l>>2]|0))break;qx(O,t[l>>2]|0)|0;t[l>>2]=t[(t[l>>2]|0)+32>>2]}ab(t[O+132>>2]|0,t[(t[a>>2]|0)+136>>2]|0)|0;if(pb(t[(t[a>>2]|0)+132>>2]|0)|0){i=_b(t[(t[a>>2]|0)+132>>2]|0)|0;t[(t[o>>2]|0)+52>>2]=i}nb(t[(t[a>>2]|0)+132>>2]|0);t[(t[a>>2]|0)+136>>2]=t[k>>2];t[(t[a>>2]|0)+132>>2]=t[b>>2]}break}case 3:{i=hb(t[(t[a>>2]|0)+132>>2]|0,t[(t[a>>2]|0)+136>>2]|0,0)|0;t[(t[a>>2]|0)+136>>2]=i;t[g>>2]=t[(t[a>>2]|0)+136>>2];qx(t[a>>2]|0,t[(t[o>>2]|0)+24>>2]|0)|0;ob(t[(t[a>>2]|0)+132>>2]|0,t[(t[a>>2]|0)+136>>2]|0,t[(t[a>>2]|0)+136>>2]|0,188096,0)|0;i=hb(t[(t[a>>2]|0)+132>>2]|0,t[g>>2]|0,0)|0;t[(t[a>>2]|0)+136>>2]=i;break}case 10:case 18:case 13:case 12:case 11:{t[l>>2]=t[(t[o>>2]|0)+24>>2];while(1){if(!(t[l>>2]|0))break e;t[c>>2]=qx(t[a>>2]|0,t[l>>2]|0)|0;if(t[c>>2]|0)break e;t[l>>2]=t[(t[l>>2]|0)+32>>2]}break}case 0:{i=hb(t[(t[a>>2]|0)+132>>2]|0,t[(t[a>>2]|0)+136>>2]|0,0)|0;t[(t[a>>2]|0)+136>>2]=i;break}case 4:{if((t[(t[a>>2]|0)+132>>2]|0)!=0?(t[(t[o>>2]|0)+8>>2]|0)!=0:0){i=cb(t[(t[a>>2]|0)+132>>2]|0,t[(t[a>>2]|0)+136>>2]|0,0,t[(t[o>>2]|0)+8>>2]|0,t[(t[o>>2]|0)+12>>2]|0,t[o>>2]|0)|0;t[(t[a>>2]|0)+136>>2]=i}if((f[(t[o>>2]|0)+50>>1]&64|0)!=0?(f[(t[o>>2]|0)+48>>1]|0)!=-25:0){t[h>>2]=t[(t[a>>2]|0)+132>>2];t[w>>2]=t[(t[a>>2]|0)+136>>2];f[(t[o>>2]|0)+48>>1]=-25;t[l>>2]=t[(t[o>>2]|0)+24>>2];i=rb()|0;t[(t[a>>2]|0)+132>>2]=i;if(!(t[(t[a>>2]|0)+132>>2]|0)){t[u>>2]=-1;y=t[u>>2]|0;s=r;return y|0}tb(t[(t[a>>2]|0)+132>>2]|0,1);i=ub(t[(t[a>>2]|0)+132>>2]|0)|0;t[(t[a>>2]|0)+136>>2]=i;while(1){A=t[a>>2]|0;if(!(t[l>>2]|0))break;qx(A,t[l>>2]|0)|0;t[l>>2]=t[(t[l>>2]|0)+32>>2]}ab(t[A+132>>2]|0,t[(t[a>>2]|0)+136>>2]|0)|0;i=_b(t[(t[a>>2]|0)+132>>2]|0)|0;t[(t[o>>2]|0)+52>>2]=i;if(!(ib(t[(t[o>>2]|0)+52>>2]|0)|0)){fb(t[(t[o>>2]|0)+52>>2]|0);t[(t[o>>2]|0)+52>>2]=0}nb(t[(t[a>>2]|0)+132>>2]|0);t[(t[a>>2]|0)+136>>2]=t[w>>2];t[(t[a>>2]|0)+132>>2]=t[h>>2];break e}t[d>>2]=t[(t[a>>2]|0)+132>>2];t[c>>2]=vx(t[a>>2]|0,t[o>>2]|0)|0;t[(t[a>>2]|0)+132>>2]=t[d>>2];break}case 7:case 6:case 8:case 5:case 1:case 19:case 9:case 2:{i=t[v>>2]|0;t[n>>2]=mU(t[o>>2]|0)|0;xe(i|0,189768,n|0)|0;break}case 15:{i=hb(t[(t[a>>2]|0)+132>>2]|0,t[(t[a>>2]|0)+136>>2]|0,0)|0;t[(t[a>>2]|0)+136>>2]=i;t[_>>2]=t[(t[a>>2]|0)+136>>2];t[l>>2]=t[(t[o>>2]|0)+24>>2];while(1){M=t[a>>2]|0;if(!(t[l>>2]|0))break;qx(M,t[l>>2]|0)|0;t[l>>2]=t[(t[l>>2]|0)+32>>2]}hb(t[M+132>>2]|0,t[(t[a>>2]|0)+136>>2]|0,t[_>>2]|0)|0;i=hb(t[(t[a>>2]|0)+132>>2]|0,t[_>>2]|0,0)|0;t[(t[a>>2]|0)+136>>2]=i;break}case 16:{t[l>>2]=t[(t[o>>2]|0)+24>>2];while(1){R=t[a>>2]|0;if(!(t[l>>2]|0))break;qx(R,t[l>>2]|0)|0;t[l>>2]=t[(t[l>>2]|0)+32>>2];
	}t[p>>2]=t[R+136>>2];t[l>>2]=t[(t[o>>2]|0)+24>>2];while(1){N=t[a>>2]|0;if(!(t[l>>2]|0))break;qx(N,t[l>>2]|0)|0;t[l>>2]=t[(t[l>>2]|0)+32>>2]}hb(t[N+132>>2]|0,t[(t[a>>2]|0)+136>>2]|0,t[p>>2]|0)|0;i=hb(t[(t[a>>2]|0)+132>>2]|0,t[p>>2]|0,0)|0;t[(t[a>>2]|0)+136>>2]=i;break}default:{}}while(0);t[u>>2]=t[c>>2];y=t[u>>2]|0;s=r;return y|0}function Yx(e){e=e|0;var i=0,r=0,n=0,f=0,u=0,a=0,o=0;i=s;s=s+32|0;r=i+20|0;n=i+16|0;f=i+12|0;u=i+8|0;a=i+4|0;o=i;t[r>>2]=e;t[n>>2]=0;t[u>>2]=0;while(1){if((t[n>>2]|0)>=(t[(t[r>>2]|0)+48>>2]|0))break;t[a>>2]=(t[(t[r>>2]|0)+56>>2]|0)+((t[n>>2]|0)*24|0);e:do if((t[u>>2]|0)<5){t[f>>2]=0;while(1){if((t[f>>2]|0)>=(t[n>>2]|0))break;t[o>>2]=(t[(t[r>>2]|0)+56>>2]|0)+((t[f>>2]|0)*24|0);if((((t[t[a>>2]>>2]|0)==(t[t[o>>2]>>2]|0)?(t[(t[a>>2]|0)+8>>2]|0)==(t[(t[o>>2]|0)+8>>2]|0):0)?(Xl(t[(t[a>>2]|0)+16>>2]|0,t[(t[o>>2]|0)+16>>2]|0)|0)!=0:0)?(Xl(t[(t[a>>2]|0)+20>>2]|0,t[(t[o>>2]|0)+20>>2]|0)|0)!=0:0)break e;t[f>>2]=(t[f>>2]|0)+1}Gx(t[r>>2]|0,t[t[a>>2]>>2]|0,t[(t[a>>2]|0)+8>>2]|0,t[(t[a>>2]|0)+12>>2]|0,t[(t[a>>2]|0)+16>>2]|0,t[(t[a>>2]|0)+20>>2]|0);t[u>>2]=(t[u>>2]|0)+1}while(0);if(t[(t[a>>2]|0)+4>>2]&1){if(t[(t[a>>2]|0)+16>>2]|0)pAi[t[135736>>2]&511](t[(t[a>>2]|0)+16>>2]|0);t[(t[a>>2]|0)+16>>2]=0;if(t[(t[a>>2]|0)+20>>2]|0)pAi[t[135736>>2]&511](t[(t[a>>2]|0)+20>>2]|0);t[(t[a>>2]|0)+20>>2]=0;t[(t[a>>2]|0)+4>>2]=0}t[n>>2]=(t[n>>2]|0)+1}t[(t[r>>2]|0)+48>>2]=0;s=i;return}function Gx(e,i,r,n,f,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;u=u|0;var a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0;a=s;s=s+32|0;o=a+24|0;c=a+20|0;l=a+16|0;b=a+12|0;k=a+8|0;h=a+4|0;w=a;t[o>>2]=e;t[c>>2]=i;t[l>>2]=r;t[b>>2]=n;t[k>>2]=f;t[h>>2]=u;if(t[(t[o>>2]|0)+28>>2]&8){s=a;return}t[w>>2]=_U(t[c>>2]|0,t[k>>2]|0,t[h>>2]|0)|0;if(!(t[w>>2]|0)){s=a;return}if(!(t[(t[o>>2]|0)+40>>2]|0))t[(t[o>>2]|0)+40>>2]=t[c>>2];pU(t[o>>2]|0,(t[b>>2]|0)==0?t[l>>2]|0:t[b>>2]|0,t[c>>2]|0,t[w>>2]|0,t[k>>2]|0,t[h>>2]|0);pAi[t[135736>>2]&511](t[w>>2]|0);s=a;return}function Wx(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;var u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0;u=s;s=s+32|0;a=u+24|0;o=u+20|0;c=u+16|0;l=u+12|0;b=u+8|0;k=u+4|0;h=u;t[o>>2]=e;t[c>>2]=i;t[l>>2]=r;t[b>>2]=n;t[k>>2]=f;do if(!(t[(t[o>>2]|0)+56>>2]|0)){t[(t[o>>2]|0)+52>>2]=8;t[(t[o>>2]|0)+48>>2]=0;f=gAi[t[135744>>2]&511]((t[(t[o>>2]|0)+52>>2]|0)*24|0)|0;t[(t[o>>2]|0)+56>>2]=f;f=t[o>>2]|0;if(t[(t[o>>2]|0)+56>>2]|0){t[f+44>>2]=0;break}Fx(f,189752);t[a>>2]=0;w=t[a>>2]|0;s=u;return w|0}while(0);do if((t[(t[o>>2]|0)+48>>2]|0)>=(t[(t[o>>2]|0)+52>>2]|0)){f=(t[o>>2]|0)+52|0;t[f>>2]=t[f>>2]<<1;f=MAi[t[135760>>2]&511](t[(t[o>>2]|0)+56>>2]|0,(t[(t[o>>2]|0)+52>>2]|0)*24|0)|0;t[(t[o>>2]|0)+56>>2]=f;f=t[o>>2]|0;if(t[(t[o>>2]|0)+56>>2]|0){t[(t[o>>2]|0)+44>>2]=(t[(t[o>>2]|0)+56>>2]|0)+(((t[f+48>>2]|0)-1|0)*24|0);break}Fx(f,189752);t[a>>2]=0;w=t[a>>2]|0;s=u;return w|0}while(0);if((((t[(t[o>>2]|0)+44>>2]|0)!=0?(t[(t[o>>2]|0)+60>>2]|0)!=0:0)?(t[(t[(t[o>>2]|0)+44>>2]|0)+8>>2]|0)==(t[t[(t[o>>2]|0)+60>>2]>>2]|0):0)?(t[t[(t[o>>2]|0)+44>>2]>>2]|0)==(t[c>>2]|0):0){t[a>>2]=t[(t[o>>2]|0)+48>>2];w=t[a>>2]|0;s=u;return w|0}t[h>>2]=(t[(t[o>>2]|0)+56>>2]|0)+((t[(t[o>>2]|0)+48>>2]|0)*24|0);t[t[h>>2]>>2]=t[c>>2];c=t[l>>2]|0;if(t[k>>2]|0){k=Yl(c)|0;t[(t[h>>2]|0)+16>>2]=k;k=Yl(t[b>>2]|0)|0;t[(t[h>>2]|0)+20>>2]=k;t[(t[h>>2]|0)+4>>2]=1}else{t[(t[h>>2]|0)+16>>2]=c;t[(t[h>>2]|0)+20>>2]=t[b>>2];t[(t[h>>2]|0)+4>>2]=0}if(t[(t[o>>2]|0)+60>>2]|0){t[(t[h>>2]|0)+8>>2]=t[t[(t[o>>2]|0)+60>>2]>>2];t[(t[h>>2]|0)+12>>2]=t[(t[(t[o>>2]|0)+60>>2]|0)+4>>2]}else{t[(t[h>>2]|0)+8>>2]=0;t[(t[h>>2]|0)+12>>2]=0}t[(t[o>>2]|0)+44>>2]=t[h>>2];h=(t[o>>2]|0)+48|0;o=t[h>>2]|0;t[h>>2]=o+1;t[a>>2]=o;w=t[a>>2]|0;s=u;return w|0}function Kx(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0;r=s;s=s+32|0;n=r+24|0;f=r+20|0;u=r+16|0;a=r+12|0;o=r+8|0;c=r+4|0;l=r;t[f>>2]=e;t[u>>2]=i;t[a>>2]=0;t[c>>2]=0;t[l>>2]=t[u>>2];while(1){if(!(t[l>>2]|0))break;if((t[t[l>>2]>>2]|0)==9){if(EU(t[f>>2]|0,t[l>>2]|0)|0)t[a>>2]=-1}else t[c>>2]=1;t[l>>2]=t[(t[l>>2]|0)+32>>2]}if(!(t[c>>2]|0)){t[n>>2]=t[a>>2];b=t[n>>2]|0;s=r;return b|0}t[l>>2]=t[u>>2];while(1){if(!(t[l>>2]|0)){k=20;break}if((t[t[l>>2]>>2]|0)!=9){if((t[(t[f>>2]|0)+60>>2]|0)==0?(t[(t[f>>2]|0)+64>>2]|0)==0:0){k=17;break}t[o>>2]=gx(t[f>>2]|0,t[l>>2]|0)|0;if((t[o>>2]|0)<0)t[a>>2]=-1;if((t[o>>2]|0)==-1){k=20;break}}t[l>>2]=t[(t[l>>2]|0)+32>>2]}if((k|0)==17){mx(t[f>>2]|0,6,0,0,0);t[n>>2]=-1;b=t[n>>2]|0;s=r;return b|0}else if((k|0)==20){t[n>>2]=t[a>>2];b=t[n>>2]|0;s=r;return b|0}return 0}function Xx(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0;r=s;s=s+32|0;n=r+16|0;f=r+12|0;u=r+8|0;a=r+4|0;o=r;t[f>>2]=e;t[u>>2]=i;t[o>>2]=t[(t[f>>2]|0)+60>>2];if((t[(t[o>>2]|0)+4>>2]|0)!=0?(i=iU(t[f>>2]|0,t[(t[o>>2]|0)+4>>2]|0)|0,t[(t[o>>2]|0)+4>>2]=i,(t[(t[o>>2]|0)+4>>2]|0)!=0):0){if(t[u>>2]|0)mx(t[f>>2]|0,26,t[(t[t[o>>2]>>2]|0)+8>>2]|0,t[(t[(t[o>>2]|0)+4>>2]|0)+8>>2]|0,0);t[n>>2]=-1;c=t[n>>2]|0;s=r;return c|0}t[a>>2]=0;while(1){if((t[a>>2]|0)>=(t[(t[o>>2]|0)+8>>2]|0)){l=13;break}if(t[(t[(t[o>>2]|0)+28>>2]|0)+(t[a>>2]<<2)>>2]|0)break;t[a>>2]=(t[a>>2]|0)+1}if((l|0)==13){t[n>>2]=0;c=t[n>>2]|0;s=r;return c|0}if(t[u>>2]|0)mx(t[f>>2]|0,27,t[(t[(t[(t[o>>2]|0)+28>>2]|0)+(t[a>>2]<<2)>>2]|0)+8>>2]|0,t[(t[t[o>>2]>>2]|0)+8>>2]|0,0);t[n>>2]=-1-(t[a>>2]|0);c=t[n>>2]|0;s=r;return c|0}function Zx(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i+4|0;n=i;t[r>>2]=e;if(!(t[r>>2]|0)){s=i;return}if(!(t[(t[r>>2]|0)+64>>2]|0)){s=i;return}if((t[t[(t[r>>2]|0)+64>>2]>>2]|0)<=0){s=i;return}t[n>>2]=SU(t[r>>2]|0)|0;if((t[n>>2]|0)<0){s=i;return}if((t[n>>2]|0)>=(t[t[(t[r>>2]|0)+64>>2]>>2]|0)){s=i;return}t[(t[r>>2]|0)+60>>2]=t[(t[(t[(t[r>>2]|0)+64>>2]|0)+8>>2]|0)+(t[n>>2]<<2)>>2];Xx(t[r>>2]|0,1)|0;s=i;return}function Jx(e,i){e=e|0;i=i|0;var r=0,n=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0,S=0,g=0,y=0,F=0,O=0,A=0,M=0,R=0,N=0,T=0,L=0,D=0,C=0,P=0,B=0,I=0,H=0,x=0,U=0,z=0,j=0,V=0,q=0,Y=0,G=0,W=0,K=0;r=s;s=s+144|0;n=r;u=r+136|0;a=r+132|0;o=r+128|0;c=r+124|0;l=r+120|0;b=r+116|0;k=r+112|0;h=r+108|0;w=r+104|0;d=r+100|0;v=r+96|0;m=r+92|0;_=r+88|0;p=r+84|0;E=r+80|0;S=r+76|0;g=r+72|0;y=r+68|0;F=r+64|0;O=r+60|0;A=r+56|0;M=r+52|0;R=r+48|0;N=r+44|0;T=r+40|0;L=r+36|0;D=r+32|0;C=r+28|0;P=r+24|0;B=r+20|0;I=r+16|0;H=r+12|0;x=r+8|0;t[a>>2]=e;t[o>>2]=i;t[l>>2]=0;t[d>>2]=0;i=t[a>>2]|0;if(!(t[o>>2]|0)){mx(i,7,0,0,0);t[u>>2]=-1;U=t[u>>2]|0;s=r;return U|0}if(t[i+60>>2]|0)t[c>>2]=t[(t[(t[a>>2]|0)+60>>2]|0)+4>>2];else t[c>>2]=0;i=(t[a>>2]|0)+32|0;t[i>>2]=(t[i>>2]|0)+1;e:do switch(t[t[o>>2]>>2]|0){case 1:{t[l>>2]=-1;break}case 3:{while(1){if(t[c>>2]|0)if(((t[(t[c>>2]|0)+4>>2]|0)!=3?(t[(t[c>>2]|0)+4>>2]|0)!=8:0)?(t[(t[c>>2]|0)+4>>2]|0)!=7:0)z=(t[(t[c>>2]|0)+4>>2]|0)==4;else z=1;else z=0;j=t[c>>2]|0;if(!z)break;t[c>>2]=t[j+24>>2]}t[(t[(t[a>>2]|0)+60>>2]|0)+4>>2]=j;break}case 0:{t[c>>2]=iU(t[a>>2]|0,t[c>>2]|0)|0;t[l>>2]=0;break}case 16:{t[w>>2]=t[(t[a>>2]|0)+48>>2];t[l>>2]=AU(t[a>>2]|0,t[(t[o>>2]|0)+24>>2]|0)|0;if(!(t[l>>2]|0))if((t[(t[a>>2]|0)+48>>2]|0)>(t[w>>2]|0)){gU(t[a>>2]|0,t[w>>2]|0);V=124}else V=124;break}case 15:{V=124;break}case 14:{t[w>>2]=t[(t[a>>2]|0)+48>>2];t[h>>2]=t[(t[a>>2]|0)+28>>2];i=(t[a>>2]|0)+28|0;t[i>>2]=t[i>>2]|1;t[d>>2]=MU(t[a>>2]|0,t[(t[a>>2]|0)+60>>2]|0)|0;t[l>>2]=AU(t[a>>2]|0,t[(t[o>>2]|0)+24>>2]|0)|0;i=t[a>>2]|0;if(t[l>>2]|0){if(t[i+60>>2]|0)yx(t[a>>2]|0,t[(t[a>>2]|0)+60>>2]|0);t[(t[a>>2]|0)+60>>2]=t[d>>2];t[(t[a>>2]|0)+28>>2]=t[h>>2];t[l>>2]=0;if((t[(t[a>>2]|0)+48>>2]|0)<=(t[w>>2]|0))break e;gU(t[a>>2]|0,t[w>>2]|0);break e}e=t[a>>2]|0;do if(t[i+64>>2]|0)Qx(e,t[(t[a>>2]|0)+64>>2]|0,t[d>>2]|0)|0;else{q=$x(e,1)|0;t[(t[a>>2]|0)+64>>2]=q;q=t[a>>2]|0;if(t[(t[a>>2]|0)+64>>2]|0){Qx(q,t[(t[a>>2]|0)+64>>2]|0,t[d>>2]|0)|0;Qx(t[a>>2]|0,t[(t[a>>2]|0)+64>>2]|0,t[(t[a>>2]|0)+60>>2]|0)|0;t[(t[a>>2]|0)+60>>2]=0;break}yx(q,t[d>>2]|0);t[(t[a>>2]|0)+28>>2]=t[h>>2];t[l>>2]=-1;if((t[(t[a>>2]|0)+48>>2]|0)<=(t[w>>2]|0))break e;gU(t[a>>2]|0,t[w>>2]|0);break e}while(0);t[(t[a>>2]|0)+28>>2]=t[h>>2];t[l>>2]=0;if((t[(t[a>>2]|0)+48>>2]|0)>(t[w>>2]|0))gU(t[a>>2]|0,t[w>>2]|0);break}case 4:{t[w>>2]=t[(t[a>>2]|0)+48>>2];t[c>>2]=iU(t[a>>2]|0,t[c>>2]|0)|0;if(!(t[c>>2]|0)){mx(t[a>>2]|0,22,t[(t[o>>2]|0)+8>>2]|0,0,0);t[l>>2]=-1;if(t[(t[a>>2]|0)+28>>2]&1)break e;Yx(t[a>>2]|0);break e}if((t[(t[c>>2]|0)+4>>2]|0)!=1){mx(t[a>>2]|0,23,0,0,0);t[l>>2]=-1;if(t[(t[a>>2]|0)+28>>2]&1)break e;Yx(t[a>>2]|0);break e}e=t[a>>2]|0;if((t[(t[c>>2]|0)+52>>2]|0)==(t[o>>2]|0)){i=iU(e,t[(t[c>>2]|0)+24>>2]|0)|0;t[(t[(t[a>>2]|0)+60>>2]|0)+4>>2]=i;if((t[(t[a>>2]|0)+48>>2]|0)>(t[w>>2]|0))gU(t[a>>2]|0,t[w>>2]|0);if(!(t[(t[a>>2]|0)+48>>2]|0))break e;while(1){if(!(t[(t[a>>2]|0)+44>>2]|0))break e;if(!((t[t[(t[a>>2]|0)+44>>2]>>2]|0)==13?(Xl(t[(t[(t[a>>2]|0)+44>>2]|0)+20>>2]|0,t[(t[c>>2]|0)+8>>2]|0)|0)!=0:0))V=30;do if((V|0)==30){V=0;if((t[t[(t[a>>2]|0)+44>>2]>>2]|0)==19?(Xl(t[(t[(t[a>>2]|0)+44>>2]|0)+16>>2]|0,t[(t[c>>2]|0)+8>>2]|0)|0)!=0:0)break;if((t[t[(t[a>>2]|0)+44>>2]>>2]|0)!=22?(t[t[(t[a>>2]|0)+44>>2]>>2]|0)!=23:0)break e}while(0);yU(t[a>>2]|0)}}t[l>>2]=FU(e,t[o>>2]|0,t[c>>2]|0)|0;if((t[l>>2]|0)<=0){t[l>>2]=-1;if(t[(t[a>>2]|0)+28>>2]&1)break e;Yx(t[a>>2]|0);break e}t[l>>2]=0;i:do if(t[(t[a>>2]|0)+48>>2]|0){if((t[(t[a>>2]|0)+48>>2]|0)>(t[w>>2]|0))gU(t[a>>2]|0,t[w>>2]|0);while(1){if(!(t[(t[a>>2]|0)+44>>2]|0))break i;if(!((t[t[(t[a>>2]|0)+44>>2]>>2]|0)==13?(Xl(t[(t[(t[a>>2]|0)+44>>2]|0)+20>>2]|0,t[(t[c>>2]|0)+8>>2]|0)|0)!=0:0))V=44;do if((V|0)==44){V=0;if((t[t[(t[a>>2]|0)+44>>2]>>2]|0)==19?(Xl(t[(t[(t[a>>2]|0)+44>>2]|0)+16>>2]|0,t[(t[c>>2]|0)+8>>2]|0)|0)!=0:0)break;if((t[t[(t[a>>2]|0)+44>>2]>>2]|0)!=22?(t[t[(t[a>>2]|0)+44>>2]>>2]|0)!=23:0)break i}while(0);yU(t[a>>2]|0)}}while(0);t[w>>2]=t[(t[a>>2]|0)+48>>2];t[h>>2]=t[(t[a>>2]|0)+28>>2];if(t[(t[a>>2]|0)+28>>2]&4){e=(t[a>>2]|0)+28|0;t[e>>2]=(t[e>>2]|0)-4}t[v>>2]=Sx(t[a>>2]|0,t[c>>2]|0)|0;if(!(t[v>>2]|0)){t[l>>2]=-1;if(t[(t[a>>2]|0)+28>>2]&1)break e;Yx(t[a>>2]|0);break e}t[d>>2]=t[(t[a>>2]|0)+60>>2];t[(t[a>>2]|0)+60>>2]=t[v>>2];if((t[(t[o>>2]|0)+36>>2]|0)!=0?(t[k>>2]=Kx(t[a>>2]|0,t[(t[o>>2]|0)+36>>2]|0)|0,(t[k>>2]|0)!=0):0){t[l>>2]=-1;mx(t[a>>2]|0,24,t[(t[c>>2]|0)+8>>2]|0,0,0)}do if(t[(t[o>>2]|0)+52>>2]|0){t[_>>2]=t[(t[a>>2]|0)+60>>2];t[p>>2]=t[(t[a>>2]|0)+64>>2];t[m>>2]=Sx(t[a>>2]|0,t[c>>2]|0)|0;t[(t[a>>2]|0)+60>>2]=t[m>>2];t[(t[a>>2]|0)+64>>2]=0;t[k>>2]=OU(t[a>>2]|0,t[(t[o>>2]|0)+52>>2]|0,t[(t[(t[a>>2]|0)+60>>2]|0)+4>>2]|0)|0;t[E>>2]=t[(t[(t[a>>2]|0)+60>>2]|0)+4>>2];t[(t[a>>2]|0)+60>>2]=t[_>>2];t[(t[a>>2]|0)+64>>2]=t[p>>2];yx(t[a>>2]|0,t[m>>2]|0);if(t[k>>2]|0)t[l>>2]=-1;if(!(t[(t[a>>2]|0)+64>>2]|0)){t[v>>2]=t[(t[a>>2]|0)+60>>2];if(t[(t[a>>2]|0)+60>>2]|0)t[(t[(t[a>>2]|0)+60>>2]|0)+4>>2]=t[E>>2];if(!(t[l>>2]|0))t[l>>2]=Xx(t[a>>2]|0,1)|0;yx(t[a>>2]|0,t[v>>2]|0);break}t[k>>2]=-1;t[b>>2]=0;while(1){if((t[b>>2]|0)>=(t[t[(t[a>>2]|0)+64>>2]>>2]|0))break;t[v>>2]=t[(t[(t[(t[a>>2]|0)+64>>2]|0)+8>>2]|0)+(t[b>>2]<<2)>>2];t[(t[a>>2]|0)+60>>2]=t[v>>2];t[(t[(t[a>>2]|0)+60>>2]|0)+4>>2]=t[E>>2];if(!(Xx(t[a>>2]|0,0)|0)){V=64;break}t[b>>2]=(t[b>>2]|0)+1}if((V|0)==64)t[k>>2]=0;if(t[k>>2]|0){e=(t[a>>2]|0)+28|0;t[e>>2]=t[e>>2]|1;Zx(t[a>>2]|0)}t[b>>2]=0;while(1){Y=t[a>>2]|0;if((t[b>>2]|0)>=(t[t[(t[a>>2]|0)+64>>2]>>2]|0))break;yx(Y,t[(t[(t[(t[a>>2]|0)+64>>2]|0)+8>>2]|0)+(t[b>>2]<<2)>>2]|0);t[b>>2]=(t[b>>2]|0)+1}Ox(Y,t[(t[a>>2]|0)+64>>2]|0);t[(t[a>>2]|0)+28>>2]=t[h>>2];t[(t[a>>2]|0)+64>>2]=0;if((t[l>>2]|0)==0&(t[k>>2]|0)==-1)t[l>>2]=-1}else{do if((t[(t[o>>2]|0)+24>>2]|0)!=0?(t[k>>2]=AU(t[a>>2]|0,t[(t[o>>2]|0)+24>>2]|0)|0,(t[k>>2]|0)!=0):0){t[l>>2]=-1;if(!(t[(t[a>>2]|0)+60>>2]|0)){t[(t[a>>2]|0)+60>>2]=t[d>>2];mx(t[a>>2]|0,25,t[(t[c>>2]|0)+8>>2]|0,0,0);t[(t[a>>2]|0)+60>>2]=0;break}else{mx(t[a>>2]|0,25,t[(t[c>>2]|0)+8>>2]|0,0,0);break}}while(0);if(!(t[(t[a>>2]|0)+64>>2]|0)){t[v>>2]=t[(t[a>>2]|0)+60>>2];if(!(t[l>>2]|0))t[l>>2]=Xx(t[a>>2]|0,1)|0;yx(t[a>>2]|0,t[v>>2]|0);break}t[k>>2]=-1;t[b>>2]=0;while(1){if((t[b>>2]|0)>=(t[t[(t[a>>2]|0)+64>>2]>>2]|0))break;t[v>>2]=t[(t[(t[(t[a>>2]|0)+64>>2]|0)+8>>2]|0)+(t[b>>2]<<2)>>2];t[(t[a>>2]|0)+60>>2]=t[v>>2];if(!(Xx(t[a>>2]|0,0)|0)){V=87;break}t[b>>2]=(t[b>>2]|0)+1}if((V|0)==87)t[k>>2]=0;if(t[k>>2]|0){e=(t[a>>2]|0)+28|0;t[e>>2]=t[e>>2]|1;Zx(t[a>>2]|0)}t[b>>2]=0;while(1){G=t[a>>2]|0;if((t[b>>2]|0)>=(t[t[(t[a>>2]|0)+64>>2]>>2]|0))break;yx(G,t[(t[(t[(t[a>>2]|0)+64>>2]|0)+8>>2]|0)+(t[b>>2]<<2)>>2]|0);t[(t[(t[(t[a>>2]|0)+64>>2]|0)+8>>2]|0)+(t[b>>2]<<2)>>2]=0;t[b>>2]=(t[b>>2]|0)+1}Ox(G,t[(t[a>>2]|0)+64>>2]|0);t[(t[a>>2]|0)+28>>2]=t[h>>2];t[(t[a>>2]|0)+64>>2]=0;if((t[l>>2]|0)==0&(t[k>>2]|0)==-1)t[l>>2]=-1}while(0);if(!(t[l>>2]|0))t[(t[c>>2]|0)+52>>2]=t[o>>2];t[(t[a>>2]|0)+28>>2]=t[h>>2];t[(t[a>>2]|0)+60>>2]=t[d>>2];if(t[d>>2]|0){e=iU(t[a>>2]|0,t[(t[c>>2]|0)+24>>2]|0)|0;t[(t[d>>2]|0)+4>>2]=e}e=t[a>>2]|0;if(t[l>>2]|0){if(t[e+28>>2]&1)break e;Yx(t[a>>2]|0);t[l>>2]=0;break e}else{if((t[e+48>>2]|0)<=(t[w>>2]|0))break e;gU(t[a>>2]|0,t[w>>2]|0);break e}break}case 18:case 10:{t[l>>2]=AU(t[a>>2]|0,t[(t[o>>2]|0)+24>>2]|0)|0;break}case 19:{t[l>>2]=RU(t[a>>2]|0,t[o>>2]|0)|0;break}case 9:{t[l>>2]=EU(t[a>>2]|0,t[o>>2]|0)|0;break}case 13:case 12:case 11:case-1:case 20:{t[l>>2]=gx(t[a>>2]|0,t[(t[o>>2]|0)+24>>2]|0)|0;break}case 5:{t[T>>2]=0;t[N>>2]=t[c>>2];while(1){if(!(t[N>>2]|0))break;if((t[(t[N>>2]|0)+4>>2]|0)==1){V=222;break}if(!((t[(t[N>>2]|0)+4>>2]|0)!=3?(t[(t[N>>2]|0)+4>>2]|0)!=4:0))t[T>>2]=us(t[T>>2]|0,t[(t[N>>2]|0)+40>>2]|0)|0;t[N>>2]=t[(t[N>>2]|0)+24>>2]}if((V|0)==222){mx(t[a>>2]|0,28,t[(t[(t[c>>2]|0)+20>>2]|0)+8>>2]|0,0,0);t[l>>2]=-1}e=t[T>>2]|0;if((t[l>>2]|0)==-1){if(!e)break e;pAi[t[135736>>2]&511](t[T>>2]|0);break e}if((e|0)==0?(t[T>>2]=Yl(188112)|0,(t[T>>2]|0)==0):0){Fx(t[a>>2]|0,189544);t[l>>2]=-1;break e}t[l>>2]=NU(t[a>>2]|0,t[T>>2]|0,t[o>>2]|0,t[(t[(t[a>>2]|0)+60>>2]|0)+4>>2]|0)|0;if((t[l>>2]|0)!=-1){if(!(t[l>>2]|0))t[(t[(t[a>>2]|0)+60>>2]|0)+4>>2]=0}else mx(t[a>>2]|0,31,t[(t[o>>2]|0)+8>>2]|0,0,0);if(t[T>>2]|0)pAi[t[135736>>2]&511](t[T>>2]|0);break}case 7:{t[L>>2]=0;t[C>>2]=t[c>>2];while(1){if(!(t[C>>2]|0))break;if((t[(t[C>>2]|0)+4>>2]|0)==1){V=242;break}if(!((t[(t[C>>2]|0)+4>>2]|0)!=3?(t[(t[C>>2]|0)+4>>2]|0)!=4:0))t[L>>2]=us(t[L>>2]|0,t[(t[C>>2]|0)+40>>2]|0)|0;t[C>>2]=t[(t[C>>2]|0)+24>>2]}if((V|0)==242){mx(t[a>>2]|0,29,t[(t[(t[c>>2]|0)+20>>2]|0)+8>>2]|0,0,0);t[l>>2]=-1}e=t[L>>2]|0;if((t[l>>2]|0)==-1){if(!e)break e;pAi[t[135736>>2]&511](t[L>>2]|0);break e}if((e|0)==0?(t[L>>2]=Yl(188112)|0,(t[L>>2]|0)==0):0){Fx(t[a>>2]|0,189544);t[l>>2]=-1;break e}t[D>>2]=t[(t[(t[a>>2]|0)+60>>2]|0)+20>>2];t[(t[(t[a>>2]|0)+60>>2]|0)+20>>2]=t[L>>2];t[l>>2]=TU(t[a>>2]|0,t[o>>2]|0)|0;t[(t[(t[a>>2]|0)+60>>2]|0)+20>>2]=t[D>>2];if((t[l>>2]|0)!=-1){if(!(t[l>>2]|0))t[(t[(t[a>>2]|0)+60>>2]|0)+4>>2]=0}else mx(t[a>>2]|0,32,t[(t[o>>2]|0)+8>>2]|0,0,0);if(t[L>>2]|0)pAi[t[135736>>2]&511](t[L>>2]|0);break}case 8:{t[P>>2]=0;t[B>>2]=t[c>>2];while(1){if(!(t[B>>2]|0))break;if((t[(t[B>>2]|0)+4>>2]|0)==1){V=262;break}if(!((t[(t[B>>2]|0)+4>>2]|0)!=3?(t[(t[B>>2]|0)+4>>2]|0)!=4:0))t[P>>2]=us(t[P>>2]|0,t[(t[B>>2]|0)+40>>2]|0)|0;t[B>>2]=t[(t[B>>2]|0)+24>>2]}if((V|0)==262){mx(t[a>>2]|0,30,t[(t[(t[c>>2]|0)+20>>2]|0)+8>>2]|0,0,0);t[l>>2]=-1}e=t[P>>2]|0;if((t[l>>2]|0)==-1){if(!e)break e;pAi[t[135736>>2]&511](t[P>>2]|0);break e}if((e|0)==0?(t[P>>2]=Yl(188112)|0,(t[P>>2]|0)==0):0){Fx(t[a>>2]|0,189544);t[l>>2]=-1;break e}t[x>>2]=rs(t[P>>2]|0)|0;t[I>>2]=t[(t[(t[a>>2]|0)+60>>2]|0)+20>>2];t[H>>2]=t[(t[(t[a>>2]|0)+60>>2]|0)+24>>2];t[(t[(t[a>>2]|0)+60>>2]|0)+20>>2]=t[P>>2];t[(t[(t[a>>2]|0)+60>>2]|0)+24>>2]=(t[P>>2]|0)+(t[x>>2]|0);t[l>>2]=TU(t[a>>2]|0,t[o>>2]|0)|0;t[(t[(t[a>>2]|0)+60>>2]|0)+20>>2]=t[I>>2];t[(t[(t[a>>2]|0)+60>>2]|0)+24>>2]=t[H>>2];if((t[l>>2]|0)!=-1){if((t[l>>2]|0)==0&(t[c>>2]|0)!=0)t[(t[(t[a>>2]|0)+60>>2]|0)+4>>2]=t[(t[c>>2]|0)+24>>2]}else mx(t[a>>2]|0,33,0,0,0);if(t[P>>2]|0)pAi[t[135736>>2]&511](t[P>>2]|0);break}case 6:case 2:{e=t[33976]|0;i=t[33980]|0;t[n>>2]=189496;t[n+4>>2]=10569;yAi[e&511](i,189464,n);t[l>>2]=-1;break}case 17:{t[A>>2]=0;t[M>>2]=0;t[c>>2]=iU(t[a>>2]|0,t[c>>2]|0)|0;t[w>>2]=t[(t[a>>2]|0)+48>>2];if((f[(t[o>>2]|0)+50>>1]&16|0)!=0?(t[c>>2]|0)!=0?(t[(t[o>>2]|0)+20>>2]|0)!=0:0:0){t[R>>2]=t[(t[o>>2]|0)+20>>2];if((t[(t[c>>2]|0)+4>>2]|0)!=3?(t[(t[c>>2]|0)+4>>2]|0)!=4:0){if((t[(t[c>>2]|0)+4>>2]|0)==1){i=t[R>>2]|0;e=t[(t[c>>2]|0)+8>>2]|0;if(t[(t[c>>2]|0)+36>>2]|0){t[A>>2]=fO(i,e,t[(t[(t[c>>2]|0)+36>>2]|0)+8>>2]|0)|0;if(!(t[A>>2]|0))t[A>>2]=fO(t[R>>2]|0,189536,t[(t[(t[c>>2]|0)+36>>2]|0)+8>>2]|0)|0}else t[A>>2]=fO(i,e,0)|0;if(!(t[A>>2]|0))t[A>>2]=fO(t[R>>2]|0,189536,0)|0}}else t[A>>2]=fO(t[R>>2]|0,188096,0)|0;if(!(t[A>>2]|0)){t[l>>2]=-1;mx(t[a>>2]|0,38,t[(t[c>>2]|0)+8>>2]|0,0,0);break e}else{t[l>>2]=gx(t[a>>2]|0,t[A>>2]|0)|0;break e}}t[A>>2]=t[(t[o>>2]|0)+24>>2];t[h>>2]=t[(t[a>>2]|0)+28>>2];e=(t[a>>2]|0)+28|0;t[e>>2]=t[e>>2]|1;while(1){if(!(t[A>>2]|0))break;t[d>>2]=MU(t[a>>2]|0,t[(t[a>>2]|0)+60>>2]|0)|0;t[l>>2]=gx(t[a>>2]|0,t[A>>2]|0)|0;do if(!(t[l>>2]|0)){if(!(t[M>>2]|0))t[M>>2]=$x(t[a>>2]|0,1)|0;e=t[a>>2]|0;if(t[(t[a>>2]|0)+60>>2]|0){Qx(e,t[M>>2]|0,t[(t[a>>2]|0)+60>>2]|0)|0;break}if(t[e+64>>2]|0){t[b>>2]=0;while(1){W=t[a>>2]|0;if((t[b>>2]|0)>=(t[t[(t[a>>2]|0)+64>>2]>>2]|0))break;Qx(W,t[M>>2]|0,t[(t[(t[(t[a>>2]|0)+64>>2]|0)+8>>2]|0)+(t[b>>2]<<2)>>2]|0)|0;t[b>>2]=(t[b>>2]|0)+1}Ox(W,t[(t[a>>2]|0)+64>>2]|0);t[(t[a>>2]|0)+64>>2]=0}}else yx(t[a>>2]|0,t[(t[a>>2]|0)+60>>2]|0);while(0);t[(t[a>>2]|0)+60>>2]=t[d>>2];t[A>>2]=t[(t[A>>2]|0)+32>>2]}e=t[a>>2]|0;if(t[M>>2]|0){yx(e,t[d>>2]|0);t[(t[a>>2]|0)+64>>2]=t[M>>2];t[(t[a>>2]|0)+60>>2]=0;t[l>>2]=0}else t[e+64>>2]=0;t[(t[a>>2]|0)+28>>2]=t[h>>2];e=t[a>>2]|0;if(t[l>>2]|0){if(t[e+28>>2]&1)break e;Yx(t[a>>2]|0);break e}else{if((t[e+48>>2]|0)<=(t[w>>2]|0))break e;gU(t[a>>2]|0,t[w>>2]|0);break e}break}default:{}}while(0);do if((V|0)==124){t[g>>2]=0;t[y>>2]=0;t[w>>2]=t[(t[a>>2]|0)+48>>2];t[y>>2]=$x(t[a>>2]|0,1)|0;if(!(t[y>>2]|0)){t[l>>2]=-1;break}e:do if(t[(t[a>>2]|0)+60>>2]|0){M=t[a>>2]|0;d=t[y>>2]|0;Qx(M,d,MU(t[a>>2]|0,t[(t[a>>2]|0)+60>>2]|0)|0)|0}else{t[O>>2]=0;while(1){if((t[O>>2]|0)>=(t[t[(t[a>>2]|0)+64>>2]>>2]|0))break e;d=t[a>>2]|0;M=t[y>>2]|0;Qx(d,M,MU(t[a>>2]|0,t[(t[(t[(t[a>>2]|0)+64>>2]|0)+8>>2]|0)+(t[O>>2]<<2)>>2]|0)|0)|0;t[O>>2]=(t[O>>2]|0)+1}}while(0);t[h>>2]=t[(t[a>>2]|0)+28>>2];M=(t[a>>2]|0)+28|0;t[M>>2]=t[M>>2]|1;e:do{t[S>>2]=0;t[F>>2]=t[t[y>>2]>>2];M=t[a>>2]|0;i:do if(!(t[(t[a>>2]|0)+64>>2]|0)){t[l>>2]=AU(M,t[(t[o>>2]|0)+24>>2]|0)|0;if(t[l>>2]|0){yx(t[a>>2]|0,t[(t[a>>2]|0)+60>>2]|0);t[(t[a>>2]|0)+60>>2]=0;break}t[F>>2]=t[t[y>>2]>>2];d=t[a>>2]|0;if(t[(t[a>>2]|0)+60>>2]|0){t[k>>2]=Qx(d,t[y>>2]|0,t[(t[a>>2]|0)+60>>2]|0)|0;t[(t[a>>2]|0)+60>>2]=0;if((t[k>>2]|0)!=1)break;t[S>>2]=1;break}if(t[d+64>>2]|0){t[O>>2]=0;while(1){if((t[O>>2]|0)>=(t[t[(t[a>>2]|0)+64>>2]>>2]|0))break;t[k>>2]=Qx(t[a>>2]|0,t[y>>2]|0,t[(t[(t[(t[a>>2]|0)+64>>2]|0)+8>>2]|0)+(t[O>>2]<<2)>>2]|0)|0;if((t[k>>2]|0)==1)t[S>>2]=1;t[O>>2]=(t[O>>2]|0)+1}d=t[a>>2]|0;if(!(t[g>>2]|0))t[g>>2]=t[d+64>>2];else Ox(d,t[(t[a>>2]|0)+64>>2]|0);t[(t[a>>2]|0)+64>>2]=0}}else{t[g>>2]=t[M+64>>2];t[b>>2]=0;while(1){if((t[b>>2]|0)>=(t[t[g>>2]>>2]|0))break i;t[(t[a>>2]|0)+60>>2]=t[(t[(t[g>>2]|0)+8>>2]|0)+(t[b>>2]<<2)>>2];t[(t[a>>2]|0)+64>>2]=0;t[l>>2]=AU(t[a>>2]|0,t[(t[o>>2]|0)+24>>2]|0)|0;d=(t[(t[a>>2]|0)+60>>2]|0)!=0;do if(!(t[l>>2]|0)){A=t[a>>2]|0;if(d){t[k>>2]=Qx(A,t[y>>2]|0,t[(t[a>>2]|0)+60>>2]|0)|0;t[(t[a>>2]|0)+60>>2]=0;if((t[k>>2]|0)!=1)break;t[S>>2]=1;break}if(t[A+64>>2]|0){t[O>>2]=0;while(1){K=t[a>>2]|0;if((t[O>>2]|0)>=(t[t[(t[a>>2]|0)+64>>2]>>2]|0))break;t[k>>2]=Qx(K,t[y>>2]|0,t[(t[(t[(t[a>>2]|0)+64>>2]|0)+8>>2]|0)+(t[O>>2]<<2)>>2]|0)|0;if((t[k>>2]|0)==1)t[S>>2]=1;t[O>>2]=(t[O>>2]|0)+1}Ox(K,t[(t[a>>2]|0)+64>>2]|0);t[(t[a>>2]|0)+64>>2]=0}}else if(d){yx(t[a>>2]|0,t[(t[a>>2]|0)+60>>2]|0);t[(t[a>>2]|0)+60>>2]=0}while(0);t[b>>2]=(t[b>>2]|0)+1}}while(0);do if(t[S>>2]|0){if(((t[t[y>>2]>>2]|0)-(t[F>>2]|0)|0)==1){M=MU(t[a>>2]|0,t[(t[(t[y>>2]|0)+8>>2]|0)+(t[F>>2]<<2)>>2]|0)|0;t[(t[a>>2]|0)+60>>2]=M;break}if((t[g>>2]|0)==0?($x(t[a>>2]|0,(t[t[y>>2]>>2]|0)-(t[F>>2]|0)|0)|0,t[g>>2]=t[(t[a>>2]|0)+64>>2],(t[g>>2]|0)==0):0){V=169;break e}t[t[g>>2]>>2]=0;t[b>>2]=t[F>>2];while(1){if((t[b>>2]|0)>=(t[t[y>>2]>>2]|0))break;M=t[a>>2]|0;d=t[g>>2]|0;Qx(M,d,MU(t[a>>2]|0,t[(t[(t[y>>2]|0)+8>>2]|0)+(t[b>>2]<<2)>>2]|0)|0)|0;t[b>>2]=(t[b>>2]|0)+1}t[(t[a>>2]|0)+64>>2]=t[g>>2]}while(0)}while((t[S>>2]|0)==1);if((V|0)==169)t[S>>2]=0;if(t[g>>2]|0)Ox(t[a>>2]|0,t[g>>2]|0);t[(t[a>>2]|0)+64>>2]=t[y>>2];t[(t[a>>2]|0)+28>>2]=t[h>>2];t[l>>2]=0}while(0);h=(t[a>>2]|0)+32|0;t[h>>2]=(t[h>>2]|0)+-1;t[u>>2]=t[l>>2];U=t[u>>2]|0;s=r;return U|0}function Qx(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0;n=s;s=s+32|0;f=n+24|0;u=n+20|0;a=n+16|0;o=n+12|0;c=n+8|0;l=n+4|0;b=n;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;if((t[o>>2]|0)==0|(t[a>>2]|0)==0){t[f>>2]=-1;k=t[f>>2]|0;s=n;return k|0}do if((t[t[a>>2]>>2]|0)>=(t[(t[a>>2]|0)+4>>2]|0)){t[b>>2]=t[(t[a>>2]|0)+4>>2]<<1;t[l>>2]=MAi[t[135760>>2]&511](t[(t[a>>2]|0)+8>>2]|0,t[b>>2]<<2)|0;if(t[l>>2]|0){t[(t[a>>2]|0)+8>>2]=t[l>>2];t[(t[a>>2]|0)+4>>2]=t[b>>2];break}Fx(t[u>>2]|0,189520);t[f>>2]=-1;k=t[f>>2]|0;s=n;return k|0}while(0);t[c>>2]=0;while(1){if((t[c>>2]|0)>=(t[t[a>>2]>>2]|0)){h=12;break}if(LU(t[u>>2]|0,t[o>>2]|0,t[(t[(t[a>>2]|0)+8>>2]|0)+(t[c>>2]<<2)>>2]|0)|0){h=10;break}t[c>>2]=(t[c>>2]|0)+1}if((h|0)==10){yx(t[u>>2]|0,t[o>>2]|0);t[f>>2]=0;k=t[f>>2]|0;s=n;return k|0}else if((h|0)==12){h=t[o>>2]|0;o=t[a>>2]|0;u=t[o>>2]|0;t[o>>2]=u+1;t[(t[(t[a>>2]|0)+8>>2]|0)+(u<<2)>>2]=h;t[f>>2]=1;k=t[f>>2]|0;s=n;return k|0}return 0}function $x(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0;r=s;s=s+16|0;n=r+12|0;f=r+8|0;u=r+4|0;a=r;t[f>>2]=e;t[u>>2]=i;if(((t[f>>2]|0)!=0?(t[(t[f>>2]|0)+80>>2]|0)!=0:0)?(t[(t[f>>2]|0)+72>>2]|0)>0:0){i=(t[f>>2]|0)+72|0;t[i>>2]=(t[i>>2]|0)+-1;t[a>>2]=t[(t[(t[f>>2]|0)+80>>2]|0)+(t[(t[f>>2]|0)+72>>2]<<2)>>2];t[t[a>>2]>>2]=0;t[n>>2]=t[a>>2];o=t[n>>2]|0;s=r;return o|0}if((t[u>>2]|0)<16)t[u>>2]=16;t[a>>2]=gAi[t[135744>>2]&511](12+((t[u>>2]|0)-1<<2)|0)|0;if(!(t[a>>2]|0)){Fx(t[f>>2]|0,189568);t[n>>2]=0;o=t[n>>2]|0;s=r;return o|0}t[t[a>>2]>>2]=0;t[(t[a>>2]|0)+4>>2]=t[u>>2];i=gAi[t[135744>>2]&511](t[u>>2]<<2)|0;t[(t[a>>2]|0)+8>>2]=i;if(!(t[(t[a>>2]|0)+8>>2]|0)){Fx(t[f>>2]|0,189568);pAi[t[135736>>2]&511](t[a>>2]|0);t[n>>2]=0;o=t[n>>2]|0;s=r;return o|0}else{t[n>>2]=t[a>>2];o=t[n>>2]|0;s=r;return o|0}return 0}function eU(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0;n=s;s=s+32|0;f=n+20|0;u=n+16|0;a=n+12|0;o=n+8|0;c=n+4|0;l=n;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;if(!(t[o>>2]|0)){t[f>>2]=-1;b=t[f>>2]|0;s=n;return b|0}do if((t[t[a>>2]>>2]|0)>=(t[(t[a>>2]|0)+4>>2]|0)){t[l>>2]=t[(t[a>>2]|0)+4>>2]<<1;t[c>>2]=MAi[t[135760>>2]&511](t[(t[a>>2]|0)+8>>2]|0,t[l>>2]<<2)|0;if(t[c>>2]|0){t[(t[a>>2]|0)+8>>2]=t[c>>2];t[(t[a>>2]|0)+4>>2]=t[l>>2];break}Fx(t[u>>2]|0,189520);t[f>>2]=-1;b=t[f>>2]|0;s=n;return b|0}while(0);u=t[o>>2]|0;o=t[a>>2]|0;l=t[o>>2]|0;t[o>>2]=l+1;t[(t[(t[a>>2]|0)+8>>2]|0)+(l<<2)>>2]=u;t[f>>2]=1;b=t[f>>2]|0;s=n;return b|0}function iU(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0;r=s;s=s+16|0;n=r+4|0;f=r;t[n>>2]=e;t[f>>2]=i;while(1){do if(t[f>>2]|0)if((((t[(t[f>>2]|0)+4>>2]|0)!=8?(t[(t[f>>2]|0)+4>>2]|0)!=7:0)?(t[(t[f>>2]|0)+4>>2]|0)!=19:0)?(t[(t[f>>2]|0)+4>>2]|0)!=20:0){if((t[(t[f>>2]|0)+4>>2]|0)!=3?(t[(t[f>>2]|0)+4>>2]|0)!=4:0){u=0;break}if(!(t[(t[n>>2]|0)+28>>2]&4))u=(tU(t[(t[f>>2]|0)+40>>2]|0)|0)!=0;else u=1}else u=1;else u=0;while(0);a=t[f>>2]|0;if(!u)break;t[f>>2]=t[a+24>>2]}s=r;return a|0}function rU(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,a=0,o=0,c=0,l=0,b=0;r=s;s=s+32|0;n=r+20|0;f=r+16|0;a=r+12|0;o=r+8|0;c=r+4|0;l=r;t[n>>2]=e;t[f>>2]=i;t[a>>2]=t[(t[f>>2]|0)+44>>2];while(1){if(!(t[a>>2]|0))break;t[o>>2]=t[(t[a>>2]|0)+24>>2];if(!((t[(t[a>>2]|0)+36>>2]|0)!=0?(Xl(t[(t[(t[a>>2]|0)+36>>2]|0)+8>>2]|0,t[46968]|0)|0)==0:0))b=5;do if((b|0)==5){b=0;if(Xl(t[(t[a>>2]|0)+8>>2]|0,192176)|0){if(Xl(t[(t[f>>2]|0)+8>>2]|0,189864)|0)break;if(Xl(t[(t[f>>2]|0)+8>>2]|0,189904)|0)break;if(Xl(t[(t[f>>2]|0)+8>>2]|0,189928)|0)break;if(Xl(t[(t[f>>2]|0)+8>>2]|0,189952)|0)break;if(Xl(t[(t[f>>2]|0)+8>>2]|0,190064)|0)break;if(Xl(t[(t[f>>2]|0)+8>>2]|0,195016)|0)break;bx(t[n>>2]|0,t[f>>2]|0,1034,196520,t[(t[a>>2]|0)+8>>2]|0,t[(t[f>>2]|0)+8>>2]|0);break}if(Xl(t[(t[a>>2]|0)+8>>2]|0,192784)|0){if(Xl(t[(t[f>>2]|0)+8>>2]|0,189888)|0)break;if(Xl(t[(t[f>>2]|0)+8>>2]|0,192360)|0)break;bx(t[n>>2]|0,t[f>>2]|0,1034,196520,t[(t[a>>2]|0)+8>>2]|0,t[(t[f>>2]|0)+8>>2]|0);break}if(Xl(t[(t[a>>2]|0)+8>>2]|0,195400)|0){if(Xl(t[(t[f>>2]|0)+8>>2]|0,189936)|0)break;if(Xl(t[(t[f>>2]|0)+8>>2]|0,195024)|0)break;bx(t[n>>2]|0,t[f>>2]|0,1034,196520,t[(t[a>>2]|0)+8>>2]|0,t[(t[f>>2]|0)+8>>2]|0);break}if(Xl(t[(t[a>>2]|0)+8>>2]|0,194568)|0){if(Xl(t[(t[f>>2]|0)+8>>2]|0,190048)|0)break;if(Xl(t[(t[f>>2]|0)+8>>2]|0,195016)|0)break;bx(t[n>>2]|0,t[f>>2]|0,1034,196520,t[(t[a>>2]|0)+8>>2]|0,t[(t[f>>2]|0)+8>>2]|0);break}if(!(Xl(t[(t[a>>2]|0)+8>>2]|0,193160)|0)){if(Xl(t[(t[a>>2]|0)+8>>2]|0,192672)|0)break;bx(t[n>>2]|0,t[f>>2]|0,1113,196680,t[(t[a>>2]|0)+8>>2]|0,t[(t[f>>2]|0)+8>>2]|0);break}t[c>>2]=sy(t[(t[f>>2]|0)+32>>2]|0,t[(t[a>>2]|0)+12>>2]|0,1)|0;if(t[c>>2]|0){do if(u[t[c>>2]>>0]|0){t[l>>2]=IA(t[c>>2]|0)|0;if(!(t[l>>2]|0)){bx(t[n>>2]|0,t[f>>2]|0,1050,196560,t[(t[a>>2]|0)+8>>2]|0,t[c>>2]|0);break}if(!(t[t[l>>2]>>2]|0))bx(t[n>>2]|0,t[f>>2]|0,1118,196600,t[(t[a>>2]|0)+8>>2]|0,t[c>>2]|0);if(t[(t[l>>2]|0)+32>>2]|0)bx(t[n>>2]|0,t[f>>2]|0,1117,196640,t[(t[a>>2]|0)+8>>2]|0,t[c>>2]|0);xA(t[l>>2]|0)}while(0);pAi[t[135736>>2]&511](t[c>>2]|0)}}while(0);t[a>>2]=t[o>>2]}s=r;return}function nU(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0;n=s;s=s+32|0;f=n+28|0;u=n+24|0;a=n+20|0;o=n+16|0;c=n+12|0;l=n+8|0;b=n+4|0;k=n;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;t[c>>2]=0;t[k>>2]=0;while(1){if((t[k>>2]|0)>=(t[(t[u>>2]|0)+100>>2]|0))break;if(Xl(t[(t[(t[(t[u>>2]|0)+108>>2]|0)+(t[k>>2]<<2)>>2]|0)+4>>2]|0,t[a>>2]|0)|0){h=4;break}t[k>>2]=(t[k>>2]|0)+1}if((h|0)==4){bx(t[u>>2]|0,0,1033,196408,t[a>>2]|0,0);t[f>>2]=0;w=t[f>>2]|0;s=n;return w|0}t[l>>2]=_S(t[a>>2]|0,0,0)|0;if(!(t[l>>2]|0)){bx(t[u>>2]|0,0,1065,196056,t[a>>2]|0,0);t[f>>2]=0;w=t[f>>2]|0;s=n;return w|0}t[c>>2]=gAi[t[135744>>2]&511](24)|0;if(!(t[c>>2]|0)){bx(t[u>>2]|0,t[l>>2]|0,2,196456,t[a>>2]|0,0);fy(t[l>>2]|0);t[f>>2]=0;w=t[f>>2]|0;s=n;return w|0}h=t[c>>2]|0;t[h+0>>2]=0;t[h+4>>2]=0;t[h+8>>2]=0;t[h+12>>2]=0;t[h+16>>2]=0;t[h+20>>2]=0;t[(t[c>>2]|0)+8>>2]=t[l>>2];h=Yl(t[a>>2]|0)|0;t[(t[c>>2]|0)+4>>2]=h;t[t[c>>2]>>2]=t[(t[u>>2]|0)+60>>2];t[(t[c>>2]|0)+20>>2]=1;t[(t[u>>2]|0)+60>>2]=t[c>>2];if(((t[o>>2]|0)!=0?(t[b>>2]=eF(t[l>>2]|0)|0,(t[b>>2]|0)!=0):0)?(dF(t[b>>2]|0,192672)|0)==0:0)_F(t[b>>2]|0,192672,t[o>>2]|0)|0;DU(t[u>>2]|0,t[c>>2]|0)|0;t[l>>2]=kx(t[u>>2]|0,t[l>>2]|0)|0;o=t[u>>2]|0;if(!(t[l>>2]|0)){t[o+96>>2]=0;t[f>>2]=0;w=t[f>>2]|0;s=n;return w|0}else{CU(o)|0;t[f>>2]=t[c>>2];w=t[f>>2]|0;s=n;return w|0}return 0}function fU(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0;f=s;s=s+64|0;u=f+48|0;a=f+44|0;o=f+40|0;c=f+36|0;l=f+32|0;b=f+28|0;k=f+24|0;h=f+20|0;w=f+16|0;d=f+12|0;v=f+8|0;m=f+4|0;_=f;t[a>>2]=e;t[o>>2]=i;t[c>>2]=r;t[l>>2]=n;t[b>>2]=0;t[h>>2]=0;while(1){if((t[h>>2]|0)>=(t[(t[a>>2]|0)+116>>2]|0))break;if(Xl(t[(t[(t[(t[a>>2]|0)+124>>2]|0)+(t[h>>2]<<2)>>2]|0)+4>>2]|0,t[o>>2]|0)|0){p=4;break}t[h>>2]=(t[h>>2]|0)+1}if((p|0)==4){bx(t[a>>2]|0,0,1044,196016,t[o>>2]|0,0);t[u>>2]=0;E=t[u>>2]|0;s=f;return E|0}t[k>>2]=_S(t[o>>2]|0,0,0)|0;if(!(t[k>>2]|0)){bx(t[a>>2]|0,t[c>>2]|0,1065,196056,t[o>>2]|0,0);t[u>>2]=0;E=t[u>>2]|0;s=f;return E|0}t[b>>2]=gAi[t[135744>>2]&511](20)|0;if(!(t[b>>2]|0)){lx(t[a>>2]|0,196088);fy(t[k>>2]|0);t[u>>2]=0;E=t[u>>2]|0;s=f;return E|0}h=t[b>>2]|0;t[h+0>>2]=0;t[h+4>>2]=0;t[h+8>>2]=0;t[h+12>>2]=0;t[h+16>>2]=0;t[(t[b>>2]|0)+8>>2]=t[k>>2];h=Yl(t[o>>2]|0)|0;t[(t[b>>2]|0)+4>>2]=h;t[t[b>>2]>>2]=t[(t[a>>2]|0)+64>>2];t[(t[a>>2]|0)+64>>2]=t[b>>2];if(((t[l>>2]|0)!=0?(t[w>>2]=eF(t[k>>2]|0)|0,(t[w>>2]|0)!=0):0)?(dF(t[w>>2]|0,192672)|0)==0:0)_F(t[w>>2]|0,192672,t[l>>2]|0)|0;PU(t[a>>2]|0,t[b>>2]|0)|0;t[k>>2]=kx(t[a>>2]|0,t[k>>2]|0)|0;l=t[a>>2]|0;if(!(t[k>>2]|0)){t[l+112>>2]=0;t[u>>2]=0;E=t[u>>2]|0;s=f;return E|0}BU(l)|0;t[w>>2]=eF(t[k>>2]|0)|0;if(!(t[w>>2]|0)){bx(t[a>>2]|0,t[c>>2]|0,1022,196112,t[o>>2]|0,0);t[u>>2]=0;E=t[u>>2]|0;s=f;return E|0}if(((((t[w>>2]|0)!=0?(t[(t[w>>2]|0)+36>>2]|0)!=0:0)?(t[(t[w>>2]|0)+4>>2]|0)==1:0)?(Xl(t[(t[w>>2]|0)+8>>2]|0,190264)|0)!=0:0)?(Xl(t[(t[(t[w>>2]|0)+36>>2]|0)+8>>2]|0,t[46968]|0)|0)!=0:0){t[d>>2]=t[(t[c>>2]|0)+12>>2];while(1){if(!(t[d>>2]|0))break;if(((((t[d>>2]|0)!=0?(t[(t[d>>2]|0)+36>>2]|0)!=0:0)?(t[(t[d>>2]|0)+4>>2]|0)==1:0)?(Xl(t[(t[d>>2]|0)+8>>2]|0,190048)|0)!=0:0)?(Xl(t[(t[(t[d>>2]|0)+36>>2]|0)+8>>2]|0,t[46968]|0)|0)!=0:0){t[v>>2]=0;t[v>>2]=IU(t[a>>2]|0,t[o>>2]|0,t[(t[w>>2]|0)+12>>2]|0,0)|0;if(!(t[v>>2]|0))bx(t[a>>2]|0,t[c>>2]|0,1107,196216,t[o>>2]|0,0)}else p=33;do if((((((p|0)==33?(p=0,(t[d>>2]|0)!=0):0)?(t[(t[d>>2]|0)+36>>2]|0)!=0:0)?(t[(t[d>>2]|0)+4>>2]|0)==1:0)?(Xl(t[(t[d>>2]|0)+8>>2]|0,195016)|0)!=0:0)?(Xl(t[(t[(t[d>>2]|0)+36>>2]|0)+8>>2]|0,t[46968]|0)|0)!=0:0){t[m>>2]=cF(t[d>>2]|0,192176)|0;if(!(t[m>>2]|0)){bx(t[a>>2]|0,t[c>>2]|0,1053,196288,t[o>>2]|0,0);break}HU(t[m>>2]|0);t[_>>2]=IU(t[a>>2]|0,t[o>>2]|0,t[(t[w>>2]|0)+12>>2]|0,t[m>>2]|0)|0;if(!(t[_>>2]|0))bx(t[a>>2]|0,t[c>>2]|0,1013,196336,t[o>>2]|0,t[m>>2]|0);pAi[t[135736>>2]&511](t[m>>2]|0)}while(0);t[d>>2]=t[(t[d>>2]|0)+24>>2]}t[u>>2]=t[b>>2];E=t[u>>2]|0;s=f;return E|0}bx(t[a>>2]|0,t[c>>2]|0,1038,196160,t[o>>2]|0,0);t[u>>2]=0;E=t[u>>2]|0;s=f;return E|0}function tU(e){e=e|0;var i=0,r=0,n=0,f=0,a=0;i=s;s=s+16|0;r=i+4|0;n=i;t[n>>2]=e;if(!(t[n>>2]|0)){t[r>>2]=1;f=t[r>>2]|0;s=i;return f|0}e:while(1){if(!(u[t[n>>2]>>0]|0)){a=10;break}do if((u[t[n>>2]>>0]|0|0)!=32){if(9<=(u[t[n>>2]>>0]|0|0)?(u[t[n>>2]>>0]|0|0)<=10:0)break;if((u[t[n>>2]>>0]|0|0)!=13){a=8;break e}}while(0);t[n>>2]=(t[n>>2]|0)+1}if((a|0)==8){t[r>>2]=0;f=t[r>>2]|0;s=i;return f|0}else if((a|0)==10){t[r>>2]=1;f=t[r>>2]|0;s=i;return f|0}return 0}function uU(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0;r=s;s=s+32|0;n=r+16|0;f=r+12|0;u=r+8|0;a=r+4|0;o=r;t[f>>2]=e;t[u>>2]=i;t[a>>2]=0;if(!(t[u>>2]|0)){bx(t[f>>2]|0,t[u>>2]|0,1037,194984,0,0);t[n>>2]=-1;c=t[n>>2]|0;s=r;return c|0}while(1){if(!(t[u>>2]|0))break;do if(((((t[u>>2]|0)!=0?(t[(t[u>>2]|0)+36>>2]|0)!=0:0)?(t[(t[u>>2]|0)+4>>2]|0)==1:0)?(Xl(t[(t[u>>2]|0)+8>>2]|0,190048)|0)!=0:0)?(Xl(t[(t[(t[u>>2]|0)+36>>2]|0)+8>>2]|0,t[46968]|0)|0)!=0:0){i=t[f>>2]|0;e=t[u>>2]|0;if(!(t[(t[u>>2]|0)+12>>2]|0)){bx(i,e,1106,191968,0,0);break}t[o>>2]=Ix(i,t[e+12>>2]|0)|0;if(t[o>>2]|0)t[a>>2]=-1}else l=13;while(0);do if((l|0)==13){l=0;if(((((t[u>>2]|0)!=0?(t[(t[u>>2]|0)+36>>2]|0)!=0:0)?(t[(t[u>>2]|0)+4>>2]|0)==1:0)?(Xl(t[(t[u>>2]|0)+8>>2]|0,195016)|0)!=0:0)?(Xl(t[(t[(t[u>>2]|0)+36>>2]|0)+8>>2]|0,t[46968]|0)|0)!=0:0){t[o>>2]=xU(t[f>>2]|0,t[u>>2]|0)|0;if(!(t[o>>2]|0))break;t[a>>2]=-1;break}if(((((t[u>>2]|0)!=0?(t[(t[u>>2]|0)+36>>2]|0)!=0:0)?(t[(t[u>>2]|0)+4>>2]|0)==1:0)?(Xl(t[(t[u>>2]|0)+8>>2]|0,195024)|0)!=0:0)?(Xl(t[(t[(t[u>>2]|0)+36>>2]|0)+8>>2]|0,t[46968]|0)|0)!=0:0){t[o>>2]=UU(t[f>>2]|0,t[u>>2]|0)|0;if(!(t[o>>2]|0))break;t[a>>2]=-1;break}bx(t[f>>2]|0,t[u>>2]|0,1036,195032,t[(t[u>>2]|0)+8>>2]|0,0);t[a>>2]=-1}while(0);t[u>>2]=t[(t[u>>2]|0)+24>>2]}t[n>>2]=t[a>>2];c=t[n>>2]|0;s=r;return c|0}function aU(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0;r=s;s=s+64|0;n=r;f=r+28|0;u=r+24|0;a=r+20|0;o=r+16|0;c=r+12|0;l=r+8|0;b=r+4|0;k=r+32|0;t[f>>2]=e;t[u>>2]=i;t[c>>2]=-1;t[l>>2]=0;t[a>>2]=t[(t[u>>2]|0)+12>>2];if(!(t[a>>2]|0)){s=r;return}if(!(t[(t[a>>2]|0)+32>>2]|0)){s=r;return}t[b>>2]=t[a>>2];while(1){if(!(t[b>>2]|0))break;if(((t[(t[b>>2]|0)+4>>2]|0)!=0?(t[(t[(t[b>>2]|0)+4>>2]|0)+20>>2]|0)!=0:0)?(Xl(t[(t[(t[(t[b>>2]|0)+4>>2]|0)+20>>2]|0)+8>>2]|0,190048)|0)!=0:0)t[o>>2]=cF(t[(t[(t[b>>2]|0)+4>>2]|0)+20>>2]|0,194568)|0;else{t[o>>2]=0;bx(t[f>>2]|0,t[(t[b>>2]|0)+4>>2]|0,1107,194784,0,0)}do if(!(t[o>>2]|0))if(!(t[l>>2]|0)){t[l>>2]=1;break}else{bx(t[f>>2]|0,t[(t[b>>2]|0)+4>>2]|0,1054,194928,0,0);break}else{do if(Xl(t[o>>2]|0,190016)|0){if((t[c>>2]|0)==-1){t[c>>2]=1;break}if(!(t[c>>2]|0))bx(t[f>>2]|0,t[(t[b>>2]|0)+4>>2]|0,1104,194832,0,0)}else{if(!(Xl(t[o>>2]|0,190032)|0)){bx(t[f>>2]|0,t[(t[b>>2]|0)+4>>2]|0,1114,194880,t[o>>2]|0,0);break}if((t[c>>2]|0)==-1){t[c>>2]=0;break}if((t[c>>2]|0)==1)bx(t[f>>2]|0,t[(t[b>>2]|0)+4>>2]|0,1104,194832,0,0)}while(0);pAi[t[135736>>2]&511](t[o>>2]|0)}while(0);t[b>>2]=t[(t[b>>2]|0)+32>>2];
	}if((t[c>>2]|0)==-1)t[c>>2]=0;t[b>>2]=dx(t[f>>2]|0,t[(t[a>>2]|0)+4>>2]|0)|0;if(!(t[b>>2]|0)){s=r;return}a=t[b>>2]|0;if(!(t[c>>2]|0))t[a>>2]=19;else t[a>>2]=17;t[(t[b>>2]|0)+24>>2]=t[(t[u>>2]|0)+12>>2];t[(t[u>>2]|0)+12>>2]=t[b>>2];if(t[c>>2]|0){s=r;return}if(!(t[(t[f>>2]|0)+56>>2]|0)){c=WF(10)|0;t[(t[f>>2]|0)+56>>2]=c}if(!(t[(t[f>>2]|0)+56>>2]|0)){bx(t[f>>2]|0,t[(t[b>>2]|0)+4>>2]|0,1046,194736,0,0);s=r;return}c=(t[f>>2]|0)+52|0;u=t[c>>2]|0;t[c>>2]=u+1;t[n>>2]=u;SY(k,32,192704,n)|0;if((ZF(t[(t[f>>2]|0)+56>>2]|0,k,t[b>>2]|0)|0)>=0){s=r;return}bx(t[f>>2]|0,t[(t[b>>2]|0)+4>>2]|0,1046,192720,k,0);s=r;return}function oU(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0;n=s;s=s+80|0;f=n;u=n+40|0;a=n+36|0;o=n+32|0;c=n+28|0;l=n+24|0;b=n+20|0;k=n+16|0;h=n+12|0;w=n+8|0;d=n+4|0;v=n+48|0;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;t[l>>2]=-1;t[b>>2]=0;if(!(t[(t[u>>2]|0)+44>>2]|0)){s=n;return}t[k>>2]=t[u>>2];while(1){if(!(t[k>>2]|0))break;t[c>>2]=cF(t[(t[k>>2]|0)+4>>2]|0,194568)|0;do if(!(t[c>>2]|0))if(!(t[b>>2]|0)){t[b>>2]=1;break}else{bx(t[a>>2]|0,t[(t[u>>2]|0)+4>>2]|0,1054,194680,t[o>>2]|0,0);break}else{do if(Xl(t[c>>2]|0,190016)|0){if((t[l>>2]|0)==-1){t[l>>2]=1;break}if(!(t[l>>2]|0))bx(t[a>>2]|0,t[(t[u>>2]|0)+4>>2]|0,1010,194576,t[o>>2]|0,0)}else{if(!(Xl(t[c>>2]|0,190032)|0)){bx(t[a>>2]|0,t[(t[u>>2]|0)+4>>2]|0,1114,194632,t[o>>2]|0,t[c>>2]|0);break}if((t[l>>2]|0)==-1){t[l>>2]=0;break}if((t[l>>2]|0)==1)bx(t[a>>2]|0,t[(t[u>>2]|0)+4>>2]|0,1010,194576,t[o>>2]|0,0)}while(0);pAi[t[135736>>2]&511](t[c>>2]|0)}while(0);t[k>>2]=t[(t[k>>2]|0)+44>>2]}if((t[l>>2]|0)==-1)t[l>>2]=0;t[k>>2]=dx(t[a>>2]|0,t[(t[u>>2]|0)+4>>2]|0)|0;if(!(t[k>>2]|0)){s=n;return}c=t[k>>2]|0;if(!(t[l>>2]|0))t[c>>2]=19;else t[c>>2]=17;t[w>>2]=t[u>>2];t[h>>2]=0;while(1){if(!(t[w>>2]|0))break;if(t[(t[w>>2]|0)+24>>2]|0){if(t[(t[(t[w>>2]|0)+24>>2]|0)+32>>2]|0){t[d>>2]=dx(t[a>>2]|0,t[(t[(t[w>>2]|0)+24>>2]|0)+4>>2]|0)|0;if(!(t[d>>2]|0))break;t[t[d>>2]>>2]=18;t[(t[d>>2]|0)+24>>2]=t[(t[w>>2]|0)+24>>2]}else t[d>>2]=t[(t[w>>2]|0)+24>>2];c=t[d>>2]|0;if(!(t[h>>2]|0))t[(t[k>>2]|0)+24>>2]=c;else t[(t[h>>2]|0)+32>>2]=c;t[h>>2]=t[d>>2]}t[(t[w>>2]|0)+24>>2]=t[k>>2];t[w>>2]=t[(t[w>>2]|0)+44>>2]}t[(t[u>>2]|0)+24>>2]=t[k>>2];if(t[l>>2]|0){s=n;return}if(!(t[(t[a>>2]|0)+56>>2]|0)){l=WF(10)|0;t[(t[a>>2]|0)+56>>2]=l}if(!(t[(t[a>>2]|0)+56>>2]|0)){bx(t[a>>2]|0,t[(t[u>>2]|0)+4>>2]|0,1046,194736,0,0);s=n;return}l=(t[a>>2]|0)+52|0;w=t[l>>2]|0;t[l>>2]=w+1;t[f>>2]=w;SY(v,32,192704,f)|0;if((ZF(t[(t[a>>2]|0)+56>>2]|0,v,t[k>>2]|0)|0)>=0){s=n;return}bx(t[a>>2]|0,t[(t[u>>2]|0)+4>>2]|0,1046,192720,v,0);s=n;return}function cU(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,u=0,a=0,o=0,c=0,l=0,b=0;n=s;s=s+32|0;u=n+20|0;a=n+16|0;o=n+12|0;c=n+8|0;l=n+4|0;b=n;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;if(f[(t[u>>2]|0)+50>>1]&256){s=n;return}t[c>>2]=t[(t[a>>2]|0)+24>>2];if(!(t[c>>2]|0)){bx(t[a>>2]|0,t[(t[u>>2]|0)+4>>2]|0,1,194400,t[o>>2]|0,0);s=n;return}if(t[(t[u>>2]|0)+24>>2]|0){bx(t[a>>2]|0,t[(t[u>>2]|0)+4>>2]|0,1,194456,t[o>>2]|0,0);s=n;return}if(!(t[(t[c>>2]|0)+24>>2]|0)){bx(t[a>>2]|0,t[(t[u>>2]|0)+4>>2]|0,1101,194520,t[o>>2]|0,0);s=n;return}t[l>>2]=rO(t[(t[c>>2]|0)+24>>2]|0,t[o>>2]|0)|0;if(!(t[l>>2]|0)){bx(t[a>>2]|0,t[(t[u>>2]|0)+4>>2]|0,1101,194520,t[o>>2]|0,0);s=n;return}t[b>>2]=t[u>>2];while(1){if(!(t[b>>2]|0))break;t[(t[b>>2]|0)+24>>2]=t[l>>2];t[b>>2]=t[(t[b>>2]|0)+44>>2]}s=n;return}function lU(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0;n=s;s=s+32|0;f=n+24|0;u=n+20|0;a=n+16|0;o=n+12|0;c=n+8|0;l=n+4|0;b=n;t[f>>2]=e;t[u>>2]=i;t[a>>2]=r;t[o>>2]=0;t[c>>2]=0;t[b>>2]=t[(t[f>>2]|0)+48>>2];while(1){if(!(t[u>>2]|0))break;if(((((t[u>>2]|0)!=0?(t[(t[u>>2]|0)+36>>2]|0)!=0:0)?(t[(t[u>>2]|0)+4>>2]|0)==1:0)?(Xl(t[(t[u>>2]|0)+8>>2]|0,189864)|0)!=0:0)?(Xl(t[(t[(t[u>>2]|0)+36>>2]|0)+8>>2]|0,t[46968]|0)|0)!=0:0){t[l>>2]=zU(t[f>>2]|0,t[u>>2]|0)|0;if(!(t[o>>2]|0)){r=t[l>>2]|0;t[c>>2]=r;t[o>>2]=r}else{if(((t[a>>2]|0)==1?(t[t[o>>2]>>2]|0)==4:0)?(t[o>>2]|0)==(t[c>>2]|0):0){t[o>>2]=dx(t[f>>2]|0,t[u>>2]|0)|0;t[t[o>>2]>>2]=18;t[(t[o>>2]|0)+24>>2]=t[c>>2]}t[(t[c>>2]|0)+32>>2]=t[l>>2];t[c>>2]=t[l>>2]}t[(t[l>>2]|0)+28>>2]=t[b>>2]}else k=16;do if((k|0)==16?(k=0,t[l>>2]=jU(t[f>>2]|0,t[u>>2]|0)|0,(t[l>>2]|0)!=0):0){r=t[l>>2]|0;if(!(t[o>>2]|0)){t[c>>2]=r;t[o>>2]=r;break}else{t[(t[c>>2]|0)+32>>2]=r;t[c>>2]=t[l>>2];break}}while(0);t[u>>2]=t[(t[u>>2]|0)+24>>2]}s=n;return t[o>>2]|0}function sU(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,u=0,a=0,o=0;f=s;s=s+16|0;u=f+8|0;a=f+4|0;o=f;t[f+12>>2]=e;t[u>>2]=i;t[a>>2]=r;t[o>>2]=n;do if(!(t[o>>2]|0)){if(!(t[a>>2]|0)){t[t[u>>2]>>2]=-1;t[o>>2]=t[u>>2];break}if((t[(t[a>>2]|0)+24>>2]|0)==(t[u>>2]|0)){t[(t[a>>2]|0)+24>>2]=t[(t[u>>2]|0)+32>>2];break}if((t[(t[a>>2]|0)+36>>2]|0)==(t[u>>2]|0)){t[(t[a>>2]|0)+36>>2]=t[(t[u>>2]|0)+32>>2];break}if((t[(t[a>>2]|0)+40>>2]|0)==(t[u>>2]|0))t[(t[a>>2]|0)+40>>2]=t[(t[u>>2]|0)+32>>2]}else t[(t[o>>2]|0)+32>>2]=t[(t[u>>2]|0)+32>>2];while(0);s=f;return t[o>>2]|0}function bU(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0;r=s;s=s+32|0;n=r+20|0;f=r+16|0;u=r+12|0;a=r+8|0;o=r+4|0;c=r;t[f>>2]=e;t[u>>2]=i;if(t[(t[f>>2]|0)+36>>2]|0){t[n>>2]=-1;l=t[n>>2]|0;s=r;return l|0}t[a>>2]=0;t[o>>2]=t[u>>2];e:while(1){if(!(t[o>>2]|0)){b=36;break}if((t[t[o>>2]>>2]|0)==4){b=12;break}if((t[t[o>>2]>>2]|0)==3){b=12;break}if((t[t[o>>2]>>2]|0)==5){b=12;break}if((t[t[o>>2]>>2]|0)==6){b=12;break}if((t[t[o>>2]>>2]|0)==8){b=12;break}if((t[t[o>>2]>>2]|0)==7){b=12;break}if(!(t[t[o>>2]>>2]|0)){b=12;break}if(!((((((((((t[t[o>>2]>>2]|0)!=17?(t[t[o>>2]>>2]|0)!=19:0)?(t[t[o>>2]>>2]|0)!=18:0)?(t[t[o>>2]>>2]|0)!=16:0)?(t[t[o>>2]>>2]|0)!=15:0)?(t[t[o>>2]>>2]|0)!=14:0)?(t[t[o>>2]>>2]|0)!=13:0)?(t[t[o>>2]>>2]|0)!=12:0)?(t[t[o>>2]>>2]|0)!=11:0)?(t[t[o>>2]>>2]|0)!=10:0))b=23;if((b|0)==23?(b=0,(t[(t[o>>2]|0)+24>>2]|0)!=0):0){t[a>>2]=t[o>>2];t[o>>2]=t[(t[o>>2]|0)+24>>2];t[c>>2]=t[o>>2];while(1){if(!(t[c>>2]|0))continue e;t[(t[c>>2]|0)+28>>2]=t[a>>2];t[c>>2]=t[(t[c>>2]|0)+32>>2]}}if((t[o>>2]|0)==(t[u>>2]|0)){b=36;break}if(t[(t[o>>2]|0)+32>>2]|0){t[o>>2]=t[(t[o>>2]|0)+32>>2];continue}while(1){t[o>>2]=t[(t[o>>2]|0)+28>>2];if(!(t[o>>2]|0))continue e;if((t[o>>2]|0)==(t[u>>2]|0)){b=32;break e}k=t[o>>2]|0;if(t[(t[o>>2]|0)+32>>2]|0)break;if(!k)continue e}t[o>>2]=t[k+32>>2]}if((b|0)==12){t[n>>2]=0;l=t[n>>2]|0;s=r;return l|0}else if((b|0)==32){t[n>>2]=1;l=t[n>>2]|0;s=r;return l|0}else if((b|0)==36){t[n>>2]=1;l=t[n>>2]|0;s=r;return l|0}return 0}function kU(e,i){e=e|0;i=i|0;var r=0,n=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0;r=s;s=s+32|0;n=r+28|0;u=r+24|0;a=r+20|0;o=r+16|0;c=r+12|0;l=r+8|0;b=r+4|0;k=r;t[n>>2]=e;t[u>>2]=i;t[c>>2]=0;if(!(t[u>>2]|0)){s=r;return}if((t[t[u>>2]>>2]|0)!=18?(t[t[u>>2]>>2]|0)!=4:0){s=r;return}if(f[(t[u>>2]|0)+50>>1]&32){s=r;return}if(t[(t[n>>2]|0)+36>>2]|0){s=r;return}t[o>>2]=t[(t[u>>2]|0)+36>>2];while(1){if(!(t[o>>2]|0))break;t[c>>2]=(t[c>>2]|0)+1;t[o>>2]=t[(t[o>>2]|0)+32>>2]}t[o>>2]=t[(t[u>>2]|0)+24>>2];while(1){if(!(t[o>>2]|0))break;t[c>>2]=(t[c>>2]|0)+1;t[o>>2]=t[(t[o>>2]|0)+32>>2]}t[a>>2]=gAi[t[135744>>2]&511](t[c>>2]<<2)|0;if(!(t[a>>2]|0)){lx(t[n>>2]|0,191880);s=r;return}t[l>>2]=0;t[o>>2]=t[(t[u>>2]|0)+36>>2];while(1){if(!(t[o>>2]|0))break;i=zx(t[n>>2]|0,t[o>>2]|0,1)|0;t[(t[a>>2]|0)+(t[l>>2]<<2)>>2]=i;t[l>>2]=(t[l>>2]|0)+1;t[o>>2]=t[(t[o>>2]|0)+32>>2]}t[o>>2]=t[(t[u>>2]|0)+24>>2];while(1){if(!(t[o>>2]|0))break;i=zx(t[n>>2]|0,t[o>>2]|0,1)|0;t[(t[a>>2]|0)+(t[l>>2]<<2)>>2]=i;t[l>>2]=(t[l>>2]|0)+1;t[o>>2]=t[(t[o>>2]|0)+32>>2]}t[l>>2]=0;while(1){if((t[l>>2]|0)>=(t[c>>2]|0))break;e:do if(t[(t[a>>2]|0)+(t[l>>2]<<2)>>2]|0){t[b>>2]=0;while(1){if((t[b>>2]|0)>=(t[l>>2]|0))break e;if((t[(t[a>>2]|0)+(t[b>>2]<<2)>>2]|0)!=0?(t[k>>2]=jx(t[n>>2]|0,t[(t[a>>2]|0)+(t[l>>2]<<2)>>2]|0,t[(t[a>>2]|0)+(t[b>>2]<<2)>>2]|0)|0,(t[k>>2]|0)==0):0)bx(t[n>>2]|0,t[(t[u>>2]|0)+4>>2]|0,1040,191896,0,0);t[b>>2]=(t[b>>2]|0)+1}}while(0);t[l>>2]=(t[l>>2]|0)+1}t[l>>2]=0;while(1){if((t[l>>2]|0)>=(t[c>>2]|0))break;if(t[(t[a>>2]|0)+(t[l>>2]<<2)>>2]|0)pAi[t[135736>>2]&511](t[(t[a>>2]|0)+(t[l>>2]<<2)>>2]|0);t[l>>2]=(t[l>>2]|0)+1}pAi[t[135736>>2]&511](t[a>>2]|0);a=(t[u>>2]|0)+50|0;f[a>>1]=f[a>>1]|32;s=r;return}function hU(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0;r=s;s=s+16|0;n=r+8|0;f=r+4|0;u=r;t[f>>2]=e;t[u>>2]=i;do if(!((t[f>>2]|0)==-1|(t[u>>2]|0)==-1)){i=t[u>>2]|0;if(!(t[f>>2]|0)){t[n>>2]=i;break}e=t[f>>2]|0;if(!i){t[n>>2]=e;break}if((e|0)==2&(t[u>>2]|0)==2){t[n>>2]=2;break}else{t[n>>2]=-1;break}}else t[n>>2]=-1;while(0);s=r;return t[n>>2]|0}function wU(e,i){e=e|0;i=i|0;var r=0,n=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0;r=s;s=s+64|0;n=r+52|0;a=r+48|0;o=r+44|0;c=r+40|0;l=r+36|0;b=r+32|0;k=r+28|0;h=r+24|0;w=r+20|0;d=r+16|0;v=r+12|0;m=r+8|0;_=r+4|0;p=r;t[n>>2]=e;t[a>>2]=i;t[l>>2]=0;t[w>>2]=0;t[d>>2]=0;t[v>>2]=0;t[m>>2]=1;if(!(t[a>>2]|0)){s=r;return}if((t[t[a>>2]>>2]|0)!=17){s=r;return}if(f[(t[a>>2]|0)+50>>1]&32){s=r;return}if(t[(t[n>>2]|0)+36>>2]|0){s=r;return}t[w>>2]=VU(t[a>>2]|0)|0;t[c>>2]=t[(t[a>>2]|0)+24>>2];while(1){if(!(t[c>>2]|0))break;t[l>>2]=(t[l>>2]|0)+1;t[c>>2]=t[(t[c>>2]|0)+32>>2]}t[o>>2]=gAi[t[135744>>2]&511](t[l>>2]<<2)|0;if(!(t[o>>2]|0)){lx(t[n>>2]|0,191856);s=r;return}t[b>>2]=0;if(!(t[w>>2]|0))t[v>>2]=WF(10)|0;else t[m>>2]=0;t[c>>2]=t[(t[a>>2]|0)+24>>2];while(1){if(!(t[c>>2]|0))break;w=zx(t[n>>2]|0,t[c>>2]|0,0)|0;t[(t[o>>2]|0)+(t[b>>2]<<2)>>2]=w;e:do if((t[(t[o>>2]|0)+(t[b>>2]<<2)>>2]|0)!=0?(t[t[(t[o>>2]|0)+(t[b>>2]<<2)>>2]>>2]|0)!=0:0){if((t[m>>2]|0)==1){t[_>>2]=t[(t[o>>2]|0)+(t[b>>2]<<2)>>2];while(1){if(!((t[m>>2]|0)==1?(t[t[_>>2]>>2]|0)!=0:0))break e;do if((t[t[t[_>>2]>>2]>>2]|0)==3){t[p>>2]=QF(t[v>>2]|0,188096,0,t[c>>2]|0)|0;if(t[p>>2]|0)t[m>>2]=-1}else{if((t[t[t[_>>2]>>2]>>2]|0)==4?(t[(t[t[_>>2]>>2]|0)+8>>2]|0)!=0:0){do if(!(t[(t[t[_>>2]>>2]|0)+12>>2]|0))E=28;else{if(!(u[t[(t[t[_>>2]>>2]|0)+12>>2]>>0]|0)){E=28;break}t[p>>2]=QF(t[v>>2]|0,t[(t[t[_>>2]>>2]|0)+8>>2]|0,t[(t[t[_>>2]>>2]|0)+12>>2]|0,t[c>>2]|0)|0}while(0);if((E|0)==28){E=0;t[p>>2]=QF(t[v>>2]|0,t[(t[t[_>>2]>>2]|0)+8>>2]|0,0,t[c>>2]|0)|0}if(!(t[p>>2]|0))break;t[m>>2]=-1;break}if((t[t[t[_>>2]>>2]>>2]|0)!=4){t[m>>2]=-1;break}do if(!(t[(t[t[_>>2]>>2]|0)+12>>2]|0))E=35;else{if(!(u[t[(t[t[_>>2]>>2]|0)+12>>2]>>0]|0)){E=35;break}t[p>>2]=QF(t[v>>2]|0,189536,t[(t[t[_>>2]>>2]|0)+12>>2]|0,t[c>>2]|0)|0}while(0);if((E|0)==35){E=0;t[p>>2]=QF(t[v>>2]|0,189536,0,t[c>>2]|0)|0}if(t[p>>2]|0)t[m>>2]=-1}while(0);t[_>>2]=(t[_>>2]|0)+4}}}else E=17;while(0);if((E|0)==17){E=0;t[m>>2]=0}t[b>>2]=(t[b>>2]|0)+1;t[c>>2]=t[(t[c>>2]|0)+32>>2]}t[b>>2]=0;while(1){if((t[b>>2]|0)>=(t[l>>2]|0))break;e:do if(t[(t[o>>2]|0)+(t[b>>2]<<2)>>2]|0){t[k>>2]=0;while(1){if((t[k>>2]|0)>=(t[b>>2]|0))break e;if((t[(t[o>>2]|0)+(t[k>>2]<<2)>>2]|0)!=0?(t[h>>2]=jx(t[n>>2]|0,t[(t[o>>2]|0)+(t[b>>2]<<2)>>2]|0,t[(t[o>>2]|0)+(t[k>>2]<<2)>>2]|0)|0,(t[h>>2]|0)==0):0)t[d>>2]=1;t[k>>2]=(t[k>>2]|0)+1}}while(0);t[b>>2]=(t[b>>2]|0)+1}t[b>>2]=0;while(1){if((t[b>>2]|0)>=(t[l>>2]|0))break;if(t[(t[o>>2]|0)+(t[b>>2]<<2)>>2]|0)pAi[t[135736>>2]&511](t[(t[o>>2]|0)+(t[b>>2]<<2)>>2]|0);t[b>>2]=(t[b>>2]|0)+1}pAi[t[135736>>2]&511](t[o>>2]|0);if(t[d>>2]|0){d=(t[a>>2]|0)+50|0;f[d>>1]=f[d>>1]|4}if((t[m>>2]|0)!=1){if(t[v>>2]|0)XF(t[v>>2]|0,0)}else{m=(t[a>>2]|0)+50|0;f[m>>1]=f[m>>1]|16;t[(t[a>>2]|0)+20>>2]=t[v>>2]}v=(t[a>>2]|0)+50|0;f[v>>1]=f[v>>1]|32;s=r;return}function dU(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0;r=s;s=s+16|0;n=r+8|0;f=r+4|0;u=r;t[f>>2]=e;t[u>>2]=i;do if(!((t[f>>2]|0)==-1|(t[u>>2]|0)==-1)){if((t[f>>2]|0)==1|(t[u>>2]|0)==1){t[n>>2]=1;break}if((t[f>>2]|0)==2|(t[u>>2]|0)==2){t[n>>2]=2;break}else{t[n>>2]=0;break}}else t[n>>2]=-1;while(0);s=r;return t[n>>2]|0}function vU(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0;r=s;s=s+240|0;n=r;f=r+224|0;a=r+220|0;o=r+216|0;c=r+212|0;l=r+152|0;b=r+128|0;k=r+8|0;t[a>>2]=e;t[o>>2]=i;t[c>>2]=1;i=k+0|0;e=i+116|0;do{t[i>>2]=0;i=i+4|0}while((i|0)<(e|0));t[k+28>>2]=9;do if((t[t[a>>2]>>2]|0)!=4?(t[t[a>>2]>>2]|0)!=9:0){if((t[t[a>>2]>>2]|0)!=3){i=t[33976]|0;e=t[33980]|0;if((t[t[a>>2]>>2]|0)==2){t[n>>2]=189496;t[n+4>>2]=3822;yAi[i&511](e,189464,n);t[c>>2]=0;break}else{t[n>>2]=189496;t[n+4>>2]=3824;yAi[i&511](e,189464,n);t[c>>2]=0;break}}if((t[t[o>>2]>>2]|0)==3){t[f>>2]=0;h=t[f>>2]|0;s=r;return h|0}else{t[f>>2]=1;h=t[f>>2]|0;s=r;return h|0}}else w=3;while(0);do if((w|0)==3){if((t[t[o>>2]>>2]|0)==3){t[f>>2]=1;h=t[f>>2]|0;s=r;return h|0}if(t[(t[a>>2]|0)+8>>2]|0)t[l+8>>2]=t[(t[a>>2]|0)+8>>2];else t[l+8>>2]=t[47556];do if(t[(t[a>>2]|0)+12>>2]|0){e=l+36|0;if(!(u[t[(t[a>>2]|0)+12>>2]>>0]|0)){t[e>>2]=0;break}else{t[e>>2]=b;t[b+8>>2]=t[(t[a>>2]|0)+12>>2];break}}else t[l+36>>2]=0;while(0);if(!(FU(k,t[o>>2]|0,l)|0)){t[c>>2]=1;break}if(t[(t[a>>2]|0)+40>>2]|0){t[c>>2]=vU(t[(t[a>>2]|0)+40>>2]|0,t[o>>2]|0)|0;break}else{t[c>>2]=0;break}}while(0);if(!(t[c>>2]|0)){t[f>>2]=t[c>>2];h=t[f>>2]|0;s=r;return h|0}if((t[t[o>>2]>>2]|0)!=4?(t[t[o>>2]>>2]|0)!=9:0){e=t[33976]|0;i=t[33980]|0;t[n>>2]=189496;t[n+4>>2]=3855;yAi[e&511](i,189464,n);t[c>>2]=0}else w=29;do if((w|0)==29){if(t[(t[o>>2]|0)+8>>2]|0)t[l+8>>2]=t[(t[o>>2]|0)+8>>2];else t[l+8>>2]=t[47556];t[l+36>>2]=b;do if(t[(t[o>>2]|0)+12>>2]|0)if(!(u[t[(t[o>>2]|0)+12>>2]>>0]|0)){t[l+36>>2]=0;break}else{t[b+8>>2]=t[(t[o>>2]|0)+12>>2];break}else t[b+8>>2]=t[47556];while(0);if(!(FU(k,t[a>>2]|0,l)|0)){t[c>>2]=1;break}if(t[(t[o>>2]|0)+40>>2]|0){t[c>>2]=vU(t[(t[o>>2]|0)+40>>2]|0,t[a>>2]|0)|0;break}else{t[c>>2]=0;break}}while(0);t[f>>2]=t[c>>2];h=t[f>>2]|0;s=r;return h|0}function mU(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i+4|0;n=i;t[n>>2]=e;e:do if(!(t[n>>2]|0))t[r>>2]=189816;else do switch(t[t[n>>2]>>2]|0){case 10:{t[r>>2]=189920;break e;break}case 5:{t[r>>2]=189872;break e;break}case 17:{t[r>>2]=190016;break e;break}case 16:{t[r>>2]=19e4;break e;break}case 8:{t[r>>2]=189896;break e;break}case 13:{t[r>>2]=189952;break e;break}case 12:{t[r>>2]=189936;break e;break}case 6:{t[r>>2]=190064;break e;break}case 2:{t[r>>2]=189848;break e;break}case 19:{t[r>>2]=190032;break e;break}case 0:{t[r>>2]=189824;break e;break}case 15:{t[r>>2]=189984;break e;break}case 18:{t[r>>2]=190024;break e;break}case 11:{t[r>>2]=189928;break e;break}case 20:{t[r>>2]=190048;break e;break}case 9:{t[r>>2]=189904;break e;break}case-1:{t[r>>2]=190056;break e;break}case 3:{t[r>>2]=189856;break e;break}case 1:{t[r>>2]=189832;break e;break}case 14:{t[r>>2]=189968;break e;break}case 7:{t[r>>2]=189888;break e;break}case 4:{t[r>>2]=189864;break e;break}default:{t[r>>2]=190072;break e}}while(0);while(0);s=i;return t[r>>2]|0}function _U(e,i,r){e=e|0;i=i|0;r=r|0;var f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0;f=s;s=s+1024|0;u=f;a=f+20|0;o=f+16|0;c=f+12|0;l=f+8|0;b=f+24|0;t[o>>2]=e;t[c>>2]=i;t[l>>2]=r;if(!(t[c>>2]|0))t[c>>2]=188112;if(!(t[l>>2]|0))t[l>>2]=188112;n[b>>0]=0;do switch(t[o>>2]|0){case 34:{t[a>>2]=Wl(189280)|0;k=t[a>>2]|0;s=f;return k|0}case 6:{t[a>>2]=Wl(188288)|0;k=t[a>>2]|0;s=f;return k|0}case 11:{t[a>>2]=Wl(188440)|0;k=t[a>>2]|0;s=f;return k|0}case 19:{t[u>>2]=t[c>>2];SY(b,1e3,188712,u)|0;break}case 13:{r=t[l>>2]|0;t[u>>2]=t[c>>2];t[u+4>>2]=r;SY(b,1e3,188504,u)|0;break}case 12:{t[u>>2]=t[c>>2];SY(b,1e3,188472,u)|0;break}case 27:{r=t[l>>2]|0;t[u>>2]=t[c>>2];t[u+4>>2]=r;SY(b,1e3,188992,u)|0;break}case 4:{t[u>>2]=t[c>>2];SY(b,1e3,188232,u)|0;break}case 8:{t[u>>2]=t[c>>2];SY(b,1e3,188376,u)|0;break}case 23:{t[a>>2]=Wl(188832)|0;k=t[a>>2]|0;s=f;return k|0}case 37:{t[u>>2]=t[c>>2];SY(b,1e3,188352,u)|0;break}case 29:{t[u>>2]=t[c>>2];SY(b,1e3,189112,u)|0;break}case 21:{t[u>>2]=t[c>>2];SY(b,1e3,188752,u)|0;break}case 28:{t[u>>2]=t[c>>2];SY(b,1e3,189072,u)|0;break}case 0:{t[a>>2]=0;k=t[a>>2]|0;s=f;return k|0}case 17:{r=t[l>>2]|0;t[u>>2]=t[c>>2];t[u+4>>2]=r;SY(b,1e3,188576,u)|0;break}case 35:{t[a>>2]=Wl(189304)|0;k=t[a>>2]|0;s=f;return k|0}case 32:{t[u>>2]=t[c>>2];SY(b,1e3,189224,u)|0;break}case 25:{t[u>>2]=t[c>>2];SY(b,1e3,188912,u)|0;break}case 36:{t[u>>2]=t[c>>2];SY(b,1e3,189032,u)|0;break}case 15:{t[u>>2]=t[c>>2];SY(b,1e3,188536,u)|0;break}case 39:{t[u>>2]=t[c>>2];SY(b,1e3,188664,u)|0;break}case 7:{t[a>>2]=Wl(188320)|0;k=t[a>>2]|0;s=f;return k|0}case 33:{t[a>>2]=Wl(189256)|0;k=t[a>>2]|0;s=f;return k|0}case 30:{t[u>>2]=t[c>>2];SY(b,1e3,189152,u)|0;break}case 38:{t[u>>2]=t[c>>2];SY(b,1e3,188624,u)|0;break}case 5:{t[u>>2]=t[c>>2];SY(b,1e3,188256,u)|0;break}case 22:{t[u>>2]=t[c>>2];SY(b,1e3,188792,u)|0;break}case 1:{t[a>>2]=Wl(188144)|0;k=t[a>>2]|0;s=f;return k|0}case 10:{t[a>>2]=Wl(188400)|0;k=t[a>>2]|0;s=f;return k|0}case 31:{t[u>>2]=t[c>>2];SY(b,1e3,189192,u)|0;break}case 3:{r=t[l>>2]|0;t[u>>2]=t[c>>2];t[u+4>>2]=r;SY(b,1e3,188192,u)|0;break}case 2:{t[u>>2]=t[c>>2];SY(b,1e3,188160,u)|0;break}case 24:{t[u>>2]=t[c>>2];SY(b,1e3,188864,u)|0;break}case 26:{r=t[l>>2]|0;t[u>>2]=t[c>>2];t[u+4>>2]=r;SY(b,1e3,188952,u)|0;break}default:{t[a>>2]=Wl(189336)|0;k=t[a>>2]|0;s=f;return k|0}}while(0);if(!(n[b>>0]|0)){t[u>>2]=t[o>>2];SY(b,1e3,189360,u)|0}n[b+999>>0]=0;t[a>>2]=Yl(b)|0;k=t[a>>2]|0;s=f;return k|0}function pU(e,i,r,n,f,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;u=u|0;var a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0;a=s;s=s+48|0;o=a;c=a+40|0;l=a+36|0;b=a+32|0;k=a+28|0;h=a+24|0;w=a+20|0;d=a+16|0;v=a+12|0;m=a+8|0;t[c>>2]=e;t[l>>2]=i;t[b>>2]=r;t[k>>2]=n;t[h>>2]=f;t[w>>2]=u;t[d>>2]=0;t[v>>2]=0;t[m>>2]=0;if(t[c>>2]|0){u=t[c>>2]|0;if(t[(t[c>>2]|0)+12>>2]|0)t[d>>2]=t[u+12>>2];else t[v>>2]=t[u+4>>2];t[m>>2]=t[t[c>>2]>>2];u=(t[c>>2]|0)+16|0;t[u>>2]=(t[u>>2]|0)+1}u=t[d>>2]|0;d=t[v>>2]|0;v=t[m>>2]|0;m=t[l>>2]|0;l=t[b>>2]|0;b=t[h>>2]|0;c=t[w>>2]|0;f=t[k>>2]|0;k=t[w>>2]|0;t[o>>2]=t[h>>2];t[o+4>>2]=k;cp(u,d,v,0,m,19,l,2,0,0,b,c,0,0,0,f,o);s=a;return}function EU(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0;r=s;s=s+48|0;n=r+36|0;f=r+32|0;a=r+28|0;o=r+24|0;c=r+20|0;l=r+16|0;b=r+12|0;k=r+8|0;h=r+4|0;w=r;t[f>>2]=e;t[a>>2]=i;t[o>>2]=0;t[k>>2]=0;if((t[(t[(t[f>>2]|0)+60>>2]|0)+16>>2]|0)<=0){t[n>>2]=-1;d=t[n>>2]|0;s=r;return d|0}i=(t[(t[a>>2]|0)+8>>2]|0)!=0;t[c>>2]=0;do if(i){while(1){if((t[c>>2]|0)>=(t[(t[(t[f>>2]|0)+60>>2]|0)+8>>2]|0))break;t[h>>2]=t[(t[(t[(t[f>>2]|0)+60>>2]|0)+28>>2]|0)+(t[c>>2]<<2)>>2];if((t[h>>2]|0)!=0?(Xl(t[(t[a>>2]|0)+8>>2]|0,t[(t[h>>2]|0)+8>>2]|0)|0)!=0:0){if(!((t[(t[a>>2]|0)+12>>2]|0)!=0?(u[t[(t[a>>2]|0)+12>>2]>>0]|0|0)!=0:0))v=9;if((v|0)==9?(v=0,(t[(t[h>>2]|0)+36>>2]|0)==0):0){v=12;break}if((t[(t[h>>2]|0)+36>>2]|0)!=0?(Xl(t[(t[a>>2]|0)+12>>2]|0,t[(t[(t[h>>2]|0)+36>>2]|0)+8>>2]|0)|0)!=0:0){v=12;break}}t[c>>2]=(t[c>>2]|0)+1}if((v|0)==12)t[k>>2]=t[h>>2];if(!(t[k>>2]|0)){t[o>>2]=-1;break}t[l>>2]=sy(t[(t[k>>2]|0)+32>>2]|0,t[(t[k>>2]|0)+12>>2]|0,1)|0;t[b>>2]=t[(t[(t[f>>2]|0)+60>>2]|0)+20>>2];t[w>>2]=t[(t[(t[f>>2]|0)+60>>2]|0)+4>>2];t[(t[(t[f>>2]|0)+60>>2]|0)+4>>2]=t[k>>2];t[(t[(t[f>>2]|0)+60>>2]|0)+20>>2]=t[l>>2];t[(t[(t[f>>2]|0)+60>>2]|0)+24>>2]=0;t[o>>2]=qU(t[f>>2]|0,t[(t[a>>2]|0)+24>>2]|0)|0;if(t[(t[(t[f>>2]|0)+60>>2]|0)+20>>2]|0)t[l>>2]=t[(t[(t[f>>2]|0)+60>>2]|0)+20>>2];if(t[l>>2]|0)pAi[t[135736>>2]&511](t[l>>2]|0);t[(t[(t[f>>2]|0)+60>>2]|0)+20>>2]=t[b>>2];t[(t[(t[f>>2]|0)+60>>2]|0)+4>>2]=t[w>>2];if(!(t[o>>2]|0)){t[(t[(t[(t[f>>2]|0)+60>>2]|0)+28>>2]|0)+(t[c>>2]<<2)>>2]=0;e=(t[(t[f>>2]|0)+60>>2]|0)+16|0;t[e>>2]=(t[e>>2]|0)+-1}}else{while(1){if((t[c>>2]|0)>=(t[(t[(t[f>>2]|0)+60>>2]|0)+8>>2]|0))break;t[h>>2]=t[(t[(t[(t[f>>2]|0)+60>>2]|0)+28>>2]|0)+(t[c>>2]<<2)>>2];if((t[h>>2]|0)!=0?(YU(t[f>>2]|0,t[a>>2]|0,t[h>>2]|0)|0)==1:0){v=25;break}t[c>>2]=(t[c>>2]|0)+1}if((v|0)==25)t[k>>2]=t[h>>2];if(!(t[k>>2]|0)){t[o>>2]=-1;break}t[l>>2]=sy(t[(t[k>>2]|0)+32>>2]|0,t[(t[k>>2]|0)+12>>2]|0,1)|0;t[b>>2]=t[(t[(t[f>>2]|0)+60>>2]|0)+20>>2];t[w>>2]=t[(t[(t[f>>2]|0)+60>>2]|0)+4>>2];t[(t[(t[f>>2]|0)+60>>2]|0)+4>>2]=t[k>>2];t[(t[(t[f>>2]|0)+60>>2]|0)+20>>2]=t[l>>2];t[o>>2]=qU(t[f>>2]|0,t[(t[a>>2]|0)+24>>2]|0)|0;if(t[(t[(t[f>>2]|0)+60>>2]|0)+20>>2]|0)t[l>>2]=t[(t[(t[f>>2]|0)+60>>2]|0)+20>>2];if(t[l>>2]|0)pAi[t[135736>>2]&511](t[l>>2]|0);t[(t[(t[f>>2]|0)+60>>2]|0)+20>>2]=t[b>>2];t[(t[(t[f>>2]|0)+60>>2]|0)+4>>2]=t[w>>2];if(!(t[o>>2]|0)){t[(t[(t[(t[f>>2]|0)+60>>2]|0)+28>>2]|0)+(t[c>>2]<<2)>>2]=0;e=(t[(t[f>>2]|0)+60>>2]|0)+16|0;t[e>>2]=(t[e>>2]|0)+-1}}while(0);t[n>>2]=t[o>>2];d=t[n>>2]|0;s=r;return d|0}function SU(e){e=e|0;var i=0,r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0;i=s;s=s+32|0;r=i+24|0;n=i+20|0;f=i+16|0;u=i+12|0;a=i+8|0;o=i+4|0;c=i;t[n>>2]=e;t[o>>2]=-1;t[c>>2]=1e6;if(((t[n>>2]|0)!=0?(t[(t[n>>2]|0)+64>>2]|0)!=0:0)?(t[t[(t[n>>2]|0)+64>>2]>>2]|0)>0:0){t[u>>2]=0;while(1){if((t[u>>2]|0)>=(t[t[(t[n>>2]|0)+64>>2]>>2]|0))break;t[f>>2]=t[(t[(t[(t[n>>2]|0)+64>>2]|0)+8>>2]|0)+(t[u>>2]<<2)>>2];do if(t[f>>2]|0){if(t[(t[f>>2]|0)+4>>2]|0){if(!((t[o>>2]|0)==-1|(t[c>>2]|0)>1e5))break;t[c>>2]=1e5;t[o>>2]=t[u>>2];break}t[a>>2]=t[(t[f>>2]|0)+16>>2];if((t[o>>2]|0)!=-1?(t[c>>2]|0)<=(t[a>>2]|0):0)break;t[c>>2]=t[a>>2];t[o>>2]=t[u>>2]}while(0);t[u>>2]=(t[u>>2]|0)+1}t[r>>2]=t[o>>2];l=t[r>>2]|0;s=i;return l|0}t[r>>2]=-1;l=t[r>>2]|0;s=i;return l|0}function gU(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0;r=s;s=s+16|0;n=r+12|0;f=r+8|0;u=r+4|0;a=r;t[n>>2]=e;t[f>>2]=i;t[u>>2]=t[f>>2];while(1){if((t[u>>2]|0)>=(t[(t[n>>2]|0)+48>>2]|0))break;t[a>>2]=(t[(t[n>>2]|0)+56>>2]|0)+((t[u>>2]|0)*24|0);if(t[(t[a>>2]|0)+4>>2]&1){if(t[(t[a>>2]|0)+16>>2]|0)pAi[t[135736>>2]&511](t[(t[a>>2]|0)+16>>2]|0);t[(t[a>>2]|0)+16>>2]=0;if(t[(t[a>>2]|0)+20>>2]|0)pAi[t[135736>>2]&511](t[(t[a>>2]|0)+20>>2]|0);t[(t[a>>2]|0)+20>>2]=0;t[(t[a>>2]|0)+4>>2]=0}t[u>>2]=(t[u>>2]|0)+1}t[(t[n>>2]|0)+48>>2]=t[f>>2];if((t[(t[n>>2]|0)+48>>2]|0)>0){s=r;return}t[(t[n>>2]|0)+44>>2]=0;s=r;return}function yU(e){e=e|0;var i=0,r=0,n=0,f=0;i=s;s=s+16|0;r=i+4|0;n=i;t[r>>2]=e;e=t[r>>2]|0;if((t[(t[r>>2]|0)+48>>2]|0)<=0){t[e+44>>2]=0;s=i;return}f=e+48|0;t[f>>2]=(t[f>>2]|0)+-1;f=t[r>>2]|0;if((t[(t[r>>2]|0)+48>>2]|0)>0)t[(t[r>>2]|0)+44>>2]=(t[(t[r>>2]|0)+56>>2]|0)+(((t[f+48>>2]|0)-1|0)*24|0);else t[f+44>>2]=0;t[n>>2]=(t[(t[r>>2]|0)+56>>2]|0)+((t[(t[r>>2]|0)+48>>2]|0)*24|0);if(!(t[(t[n>>2]|0)+4>>2]&1)){s=i;return}if(t[(t[n>>2]|0)+16>>2]|0)pAi[t[135736>>2]&511](t[(t[n>>2]|0)+16>>2]|0);t[(t[n>>2]|0)+16>>2]=0;if(t[(t[n>>2]|0)+20>>2]|0)pAi[t[135736>>2]&511](t[(t[n>>2]|0)+20>>2]|0);t[(t[n>>2]|0)+20>>2]=0;t[(t[n>>2]|0)+4>>2]=0;s=i;return}function FU(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0;n=s;s=s+48|0;f=n;a=n+36|0;o=n+32|0;c=n+28|0;l=n+24|0;b=n+20|0;k=n+16|0;h=n+12|0;w=n+8|0;t[o>>2]=e;t[c>>2]=i;t[l>>2]=r;t[b>>2]=0;t[k>>2]=0;if((t[(t[c>>2]|0)+8>>2]|0)!=0?(Xl(t[(t[l>>2]|0)+8>>2]|0,t[(t[c>>2]|0)+8>>2]|0)|0)==0:0){mx(t[o>>2]|0,13,t[(t[c>>2]|0)+8>>2]|0,t[(t[l>>2]|0)+8>>2]|0,0);t[a>>2]=0;d=t[a>>2]|0;s=n;return d|0}if((t[(t[c>>2]|0)+12>>2]|0)!=0?(u[t[(t[c>>2]|0)+12>>2]>>0]|0|0)!=0:0){if(!(t[(t[l>>2]|0)+36>>2]|0)){mx(t[o>>2]|0,15,t[(t[l>>2]|0)+8>>2]|0,0,0);t[a>>2]=0;d=t[a>>2]|0;s=n;return d|0}if(!(Xl(t[(t[(t[l>>2]|0)+36>>2]|0)+8>>2]|0,t[(t[c>>2]|0)+12>>2]|0)|0)){mx(t[o>>2]|0,17,t[(t[l>>2]|0)+8>>2]|0,t[(t[c>>2]|0)+12>>2]|0,0);t[a>>2]=0;d=t[a>>2]|0;s=n;return d|0}}else{if(((t[(t[l>>2]|0)+36>>2]|0)!=0?(t[(t[c>>2]|0)+12>>2]|0)!=0:0)?(t[(t[c>>2]|0)+8>>2]|0)==0:0){mx(t[o>>2]|0,19,t[(t[l>>2]|0)+8>>2]|0,0,0);t[a>>2]=0;d=t[a>>2]|0;s=n;return d|0}if((t[(t[l>>2]|0)+36>>2]|0)!=0?(t[(t[c>>2]|0)+8>>2]|0)!=0:0){mx(t[o>>2]|0,19,t[(t[c>>2]|0)+8>>2]|0,0,0);t[a>>2]=0;d=t[a>>2]|0;s=n;return d|0}}if(!(t[(t[c>>2]|0)+40>>2]|0)){t[a>>2]=1;d=t[a>>2]|0;s=n;return d|0}t[c>>2]=t[(t[c>>2]|0)+40>>2];do if((t[t[c>>2]>>2]|0)==2){if(t[o>>2]|0){t[k>>2]=t[(t[o>>2]|0)+28>>2];r=(t[o>>2]|0)+28|0;t[r>>2]=t[r>>2]|1}t[h>>2]=t[(t[c>>2]|0)+24>>2];while(1){if(!(t[h>>2]|0)){v=33;break}t[b>>2]=FU(t[o>>2]|0,t[h>>2]|0,t[l>>2]|0)|0;if((t[b>>2]|0)==1){v=25;break}if((t[b>>2]|0)<0){v=29;break}t[h>>2]=t[(t[h>>2]|0)+32>>2]}if((v|0)==25){if(t[o>>2]|0)t[(t[o>>2]|0)+28>>2]=t[k>>2];t[a>>2]=0;d=t[a>>2]|0;s=n;return d|0}else if((v|0)==29){if(t[o>>2]|0)t[(t[o>>2]|0)+28>>2]=t[k>>2];t[a>>2]=t[b>>2];d=t[a>>2]|0;s=n;return d|0}else if((v|0)==33){t[b>>2]=1;if(!(t[o>>2]|0))break;t[(t[o>>2]|0)+28>>2]=t[k>>2];break}}else{if((t[t[c>>2]>>2]|0)!=17){r=t[33976]|0;i=t[33980]|0;t[f>>2]=189496;t[f+4>>2]=9708;yAi[r&511](i,189464,f);t[b>>2]=-1;break}if(t[o>>2]|0){t[k>>2]=t[(t[o>>2]|0)+28>>2];i=(t[o>>2]|0)+28|0;t[i>>2]=t[i>>2]|1}t[w>>2]=t[(t[c>>2]|0)+40>>2];while(1){m=t[o>>2]|0;if(!(t[w>>2]|0)){v=49;break}t[b>>2]=FU(m,t[w>>2]|0,t[l>>2]|0)|0;if((t[b>>2]|0)==1){v=41;break}if((t[b>>2]|0)<0){v=45;break}t[w>>2]=t[(t[w>>2]|0)+32>>2]}if((v|0)==41){if(t[o>>2]|0)t[(t[o>>2]|0)+28>>2]=t[k>>2];t[a>>2]=1;d=t[a>>2]|0;s=n;return d|0}else if((v|0)==45){if(t[o>>2]|0)t[(t[o>>2]|0)+28>>2]=t[k>>2];t[a>>2]=t[b>>2];d=t[a>>2]|0;s=n;return d|0}else if((v|0)==49){do if(m){i=t[o>>2]|0;if(t[b>>2]|0){if(t[i+28>>2]&1)break;Yx(t[o>>2]|0);break}else{if((t[i+48>>2]|0)<=0)break;gU(t[o>>2]|0,0);break}}while(0);t[b>>2]=0;if(!(t[o>>2]|0))break;t[(t[o>>2]|0)+28>>2]=t[k>>2];break}}while(0);t[a>>2]=t[b>>2];d=t[a>>2]|0;s=n;return d|0}function OU(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0;n=s;s=s+32|0;f=n+28|0;u=n+24|0;a=n+20|0;o=n+16|0;c=n+12|0;l=n+8|0;b=n+4|0;k=n;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;t[b>>2]=0;if((t[u>>2]|0)==0|(t[a>>2]|0)==0){t[f>>2]=-1;h=t[f>>2]|0;s=n;return h|0}t[k>>2]=t[(t[u>>2]|0)+112>>2];t[c>>2]=Ws(t[a>>2]|0,385,t[u>>2]|0)|0;t[(t[u>>2]|0)+112>>2]=0;t[l>>2]=t[o>>2];while(1){if(!(t[l>>2]|0))break;t[(t[(t[u>>2]|0)+60>>2]|0)+4>>2]=t[l>>2];o=t[(t[l>>2]|0)+4>>2]|0;if((o|0)==1){a=t[c>>2]|0;r=t[(t[l>>2]|0)+8>>2]|0;if(t[(t[l>>2]|0)+36>>2]|0)t[b>>2]=Zs(a,r,t[(t[(t[l>>2]|0)+36>>2]|0)+8>>2]|0,t[u>>2]|0)|0;else t[b>>2]=Xs(a,r,t[u>>2]|0)|0;if((t[b>>2]|0)<0)mx(t[u>>2]|0,38,t[(t[l>>2]|0)+8>>2]|0,0,0)}else if(((o|0)==4|(o|0)==3?(EF(t[l>>2]|0)|0)==0:0)?(t[b>>2]=Xs(t[c>>2]|0,188096,t[u>>2]|0)|0,(t[b>>2]|0)<0):0)mx(t[u>>2]|0,39,t[(t[(t[l>>2]|0)+20>>2]|0)+8>>2]|0,0,0);if((t[b>>2]|0)<0)break;t[l>>2]=t[(t[l>>2]|0)+24>>2]}t[b>>2]=Xs(t[c>>2]|0,0,0)|0;do if((t[b>>2]|0)!=1){if(t[b>>2]|0){t[b>>2]=-1;break}mx(t[u>>2]|0,22,188112,0,0);t[b>>2]=-1;if(!(t[(t[u>>2]|0)+28>>2]&1))Yx(t[u>>2]|0)}else{t[b>>2]=0;t[(t[(t[u>>2]|0)+60>>2]|0)+4>>2]=0}while(0);Ks(t[c>>2]|0);if((t[b>>2]|0)==0?(t[(t[u>>2]|0)+112>>2]|0)!=0:0)t[b>>2]=t[(t[u>>2]|0)+112>>2];t[(t[u>>2]|0)+112>>2]=t[k>>2];t[f>>2]=t[b>>2];h=t[f>>2]|0;s=n;return h|0}function AU(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0;r=s;s=s+32|0;n=r+16|0;f=r+12|0;u=r+8|0;a=r+4|0;o=r;t[f>>2]=e;t[u>>2]=i;t[a>>2]=0;if(!(t[u>>2]|0)){mx(t[f>>2]|0,37,189592,0,0);t[n>>2]=-1;c=t[n>>2]|0;s=r;return c|0}while(1){if(!(t[u>>2]|0)){l=11;break}if((t[(t[f>>2]|0)+60>>2]|0)==0?(t[(t[f>>2]|0)+64>>2]|0)==0:0){l=8;break}t[o>>2]=gx(t[f>>2]|0,t[u>>2]|0)|0;if((t[o>>2]|0)<0)t[a>>2]=-1;if((t[o>>2]|0)==-1){l=11;break}t[u>>2]=t[(t[u>>2]|0)+32>>2]}if((l|0)==8){mx(t[f>>2]|0,6,0,0,0);t[n>>2]=-1;c=t[n>>2]|0;s=r;return c|0}else if((l|0)==11){t[n>>2]=t[a>>2];c=t[n>>2]|0;s=r;return c|0}return 0}function MU(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0;r=s;s=s+32|0;n=r+24|0;f=r+20|0;u=r+16|0;a=r+12|0;o=r+8|0;c=r+4|0;l=r;t[f>>2]=e;t[u>>2]=i;if(!(t[u>>2]|0)){t[n>>2]=0;b=t[n>>2]|0;s=r;return b|0}if((t[(t[f>>2]|0)+68>>2]|0)!=0?(t[t[(t[f>>2]|0)+68>>2]>>2]|0)>0:0){i=t[(t[f>>2]|0)+68>>2]|0;t[i>>2]=(t[i>>2]|0)+-1;t[a>>2]=t[(t[(t[(t[f>>2]|0)+68>>2]|0)+8>>2]|0)+(t[t[(t[f>>2]|0)+68>>2]>>2]<<2)>>2]}else k=6;do if((k|0)==6){t[a>>2]=gAi[t[135744>>2]&511](32)|0;if(t[a>>2]|0){i=t[a>>2]|0;t[i+0>>2]=0;t[i+4>>2]=0;t[i+8>>2]=0;t[i+12>>2]=0;t[i+16>>2]=0;t[i+20>>2]=0;t[i+24>>2]=0;t[i+28>>2]=0;break}Fx(t[f>>2]|0,189568);t[n>>2]=0;b=t[n>>2]|0;s=r;return b|0}while(0);t[c>>2]=t[(t[a>>2]|0)+28>>2];t[o>>2]=t[(t[a>>2]|0)+12>>2];k=t[a>>2]|0;i=t[u>>2]|0;t[k+0>>2]=t[i+0>>2];t[k+4>>2]=t[i+4>>2];t[k+8>>2]=t[i+8>>2];t[k+12>>2]=t[i+12>>2];t[k+16>>2]=t[i+16>>2];t[k+20>>2]=t[i+20>>2];t[k+24>>2]=t[i+24>>2];t[k+28>>2]=t[i+28>>2];t[(t[a>>2]|0)+28>>2]=t[c>>2];t[(t[a>>2]|0)+12>>2]=t[o>>2];if((t[(t[u>>2]|0)+8>>2]|0)>0){do if(!(t[(t[a>>2]|0)+28>>2]|0)){t[(t[a>>2]|0)+12>>2]=t[(t[u>>2]|0)+12>>2];o=gAi[t[135744>>2]&511](t[(t[a>>2]|0)+12>>2]<<2)|0;t[(t[a>>2]|0)+28>>2]=o;if(!(t[(t[a>>2]|0)+28>>2]|0)){Fx(t[f>>2]|0,189568);t[(t[a>>2]|0)+8>>2]=0;t[n>>2]=t[a>>2];b=t[n>>2]|0;s=r;return b|0}}else if((t[(t[a>>2]|0)+12>>2]|0)<(t[(t[u>>2]|0)+8>>2]|0)){t[l>>2]=MAi[t[135760>>2]&511](t[(t[a>>2]|0)+28>>2]|0,t[(t[u>>2]|0)+12>>2]<<2)|0;if(t[l>>2]|0){t[(t[a>>2]|0)+12>>2]=t[(t[u>>2]|0)+12>>2];t[(t[a>>2]|0)+28>>2]=t[l>>2];break}Fx(t[f>>2]|0,189568);t[(t[a>>2]|0)+8>>2]=0;t[n>>2]=t[a>>2];b=t[n>>2]|0;s=r;return b|0}while(0);YY(t[(t[a>>2]|0)+28>>2]|0,t[(t[u>>2]|0)+28>>2]|0,t[(t[u>>2]|0)+8>>2]<<2|0)|0}t[n>>2]=t[a>>2];b=t[n>>2]|0;s=r;return b|0}function RU(e,i){e=e|0;i=i|0;var r=0,n=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0,S=0,g=0,y=0,F=0,O=0,A=0,M=0,R=0,N=0,T=0;r=s;s=s+96|0;n=r+88|0;u=r+84|0;a=r+80|0;o=r+76|0;c=r+72|0;l=r+68|0;b=r+64|0;k=r+60|0;h=r+56|0;w=r+52|0;d=r+48|0;v=r+44|0;m=r+40|0;_=r+36|0;p=r+32|0;E=r+28|0;S=r+24|0;g=r+20|0;y=r+16|0;F=r+12|0;O=r+8|0;A=r+4|0;M=r;t[u>>2]=e;t[a>>2]=i;t[o>>2]=0;t[b>>2]=t[(t[u>>2]|0)+48>>2];t[d>>2]=0;t[_>>2]=0;t[p>>2]=0;t[S>>2]=0;t[g>>2]=0;if(!(t[(t[a>>2]|0)+20>>2]|0)){mx(t[u>>2]|0,10,0,0,0);t[n>>2]=-1;R=t[n>>2]|0;s=r;return R|0}t[w>>2]=t[(t[a>>2]|0)+20>>2];t[l>>2]=t[t[w>>2]>>2];t[k>>2]=t[(t[u>>2]|0)+28>>2];if((f[(t[a>>2]|0)+50>>1]&8|0)!=0?(a=(t[u>>2]|0)+28|0,t[a>>2]=t[a>>2]|4,(t[l>>2]|0)==2):0){if(t[(t[u>>2]|0)+60>>2]|0){a=iU(t[u>>2]|0,t[(t[(t[u>>2]|0)+60>>2]|0)+4>>2]|0)|0;t[(t[(t[u>>2]|0)+60>>2]|0)+4>>2]=a}a=t[u>>2]|0;i=t[(t[w>>2]|0)+12>>2]|0;if((t[t[t[t[(t[w>>2]|0)+12>>2]>>2]>>2]>>2]|0)==3)t[o>>2]=gx(a,t[t[i+4>>2]>>2]|0)|0;else t[o>>2]=gx(a,t[t[i>>2]>>2]|0)|0;if((t[o>>2]|0)==0?(t[(t[u>>2]|0)+60>>2]|0)!=0:0){i=iU(t[u>>2]|0,t[(t[(t[u>>2]|0)+60>>2]|0)+4>>2]|0)|0;t[(t[(t[u>>2]|0)+60>>2]|0)+4>>2]=i}t[(t[u>>2]|0)+28>>2]=t[k>>2];t[n>>2]=t[o>>2];R=t[n>>2]|0;s=r;return R|0}t[S>>2]=gAi[t[135744>>2]&511](t[l>>2]<<2)|0;if(!(t[S>>2]|0)){Fx(t[u>>2]|0,189544);t[n>>2]=-1;R=t[n>>2]|0;s=r;return R|0}VY(t[S>>2]|0,0,t[l>>2]<<2|0)|0;t[g>>2]=gAi[t[135744>>2]&511](t[l>>2]<<2)|0;if(!(t[g>>2]|0)){Fx(t[u>>2]|0,189544);t[n>>2]=-1;R=t[n>>2]|0;s=r;return R|0}VY(t[g>>2]|0,0,t[l>>2]<<2|0)|0;t[v>>2]=t[(t[(t[u>>2]|0)+60>>2]|0)+4>>2];t[v>>2]=iU(t[u>>2]|0,t[v>>2]|0)|0;t[m>>2]=t[v>>2];while(1){if(!(t[v>>2]|0))break;t[(t[(t[u>>2]|0)+60>>2]|0)+4>>2]=t[v>>2];do if((t[(t[w>>2]|0)+4>>2]|0)!=0?(t[(t[w>>2]|0)+8>>2]&1|0)!=0:0){t[y>>2]=0;if((t[(t[v>>2]|0)+4>>2]|0)!=3?(t[(t[v>>2]|0)+4>>2]|0)!=4:0){if((t[(t[v>>2]|0)+4>>2]|0)==1){i=t[(t[w>>2]|0)+4>>2]|0;a=t[(t[v>>2]|0)+8>>2]|0;if(t[(t[v>>2]|0)+36>>2]|0){t[y>>2]=fO(i,a,t[(t[(t[v>>2]|0)+36>>2]|0)+8>>2]|0)|0;if(!(t[y>>2]|0))t[y>>2]=fO(t[(t[w>>2]|0)+4>>2]|0,189536,t[(t[(t[v>>2]|0)+36>>2]|0)+8>>2]|0)|0}else t[y>>2]=fO(i,a,0)|0;if(!(t[y>>2]|0))t[y>>2]=fO(t[(t[w>>2]|0)+4>>2]|0,189536,0)|0}}else t[y>>2]=fO(t[(t[w>>2]|0)+4>>2]|0,188096,0)|0;if(!(t[y>>2]|0)){t[c>>2]=t[l>>2];break}t[c>>2]=(t[y>>2]|0)-1;if((t[(t[w>>2]|0)+8>>2]&2|0)!=0?(t[d>>2]=t[(t[(t[w>>2]|0)+12>>2]|0)+(t[c>>2]<<2)>>2],(WU(t[v>>2]|0,t[(t[d>>2]|0)+4>>2]|0)|0)==0):0)t[c>>2]=t[l>>2]}else N=37;while(0);e:do if((N|0)==37){N=0;t[c>>2]=0;while(1){if((t[c>>2]|0)>=(t[l>>2]|0))break e;t[d>>2]=t[(t[(t[w>>2]|0)+12>>2]|0)+(t[c>>2]<<2)>>2];if((t[d>>2]|0)!=0?(WU(t[v>>2]|0,t[(t[d>>2]|0)+4>>2]|0)|0)!=0:0)break e;t[c>>2]=(t[c>>2]|0)+1}}while(0);if((t[c>>2]|0)>=(t[l>>2]|0))break;a=t[v>>2]|0;i=t[c>>2]|0;if(t[(t[g>>2]|0)+(t[c>>2]<<2)>>2]|0){t[(t[(t[g>>2]|0)+(i<<2)>>2]|0)+24>>2]=a;t[(t[g>>2]|0)+(t[c>>2]<<2)>>2]=t[v>>2]}else{t[(t[S>>2]|0)+(i<<2)>>2]=a;t[(t[g>>2]|0)+(t[c>>2]<<2)>>2]=t[v>>2]}a=t[v>>2]|0;if(t[(t[v>>2]|0)+24>>2]|0)t[p>>2]=t[a+24>>2];else t[p>>2]=a;t[v>>2]=iU(t[u>>2]|0,t[(t[v>>2]|0)+24>>2]|0)|0}do if(!(t[o>>2]|0)){t[E>>2]=t[v>>2];t[h>>2]=t[(t[u>>2]|0)+60>>2];t[c>>2]=0;while(1){if((t[c>>2]|0)>=(t[l>>2]|0))break;y=MU(t[u>>2]|0,t[h>>2]|0)|0;t[(t[u>>2]|0)+60>>2]=y;if(!(t[(t[u>>2]|0)+60>>2]|0)){N=55;break}t[d>>2]=t[(t[(t[w>>2]|0)+12>>2]|0)+(t[c>>2]<<2)>>2];if(t[(t[g>>2]|0)+(t[c>>2]<<2)>>2]|0){t[_>>2]=t[(t[(t[g>>2]|0)+(t[c>>2]<<2)>>2]|0)+24>>2];t[(t[(t[g>>2]|0)+(t[c>>2]<<2)>>2]|0)+24>>2]=0}t[(t[(t[u>>2]|0)+60>>2]|0)+4>>2]=t[(t[S>>2]|0)+(t[c>>2]<<2)>>2];t[o>>2]=gx(t[u>>2]|0,t[t[d>>2]>>2]|0)|0;if(t[o>>2]|0)break;y=t[u>>2]|0;if(t[(t[u>>2]|0)+60>>2]|0){t[v>>2]=t[(t[y+60>>2]|0)+4>>2];t[v>>2]=iU(t[u>>2]|0,t[v>>2]|0)|0;yx(t[u>>2]|0,t[h>>2]|0);t[h>>2]=t[(t[u>>2]|0)+60>>2];t[(t[u>>2]|0)+60>>2]=0;if(t[v>>2]|0){N=61;break}}else{if(!(t[y+64>>2]|0)){N=89;break}t[O>>2]=0;t[A>>2]=-1;t[M>>2]=-1;t[F>>2]=0;e:while(1){if((t[F>>2]|0)>=(t[t[(t[u>>2]|0)+64>>2]>>2]|0))break;
	t[v>>2]=t[(t[(t[(t[(t[u>>2]|0)+64>>2]|0)+8>>2]|0)+(t[F>>2]<<2)>>2]|0)+4>>2];t[v>>2]=iU(t[u>>2]|0,t[v>>2]|0)|0;y=(t[O>>2]|0)==0;do if(!(t[v>>2]|0)){if(y){t[M>>2]=t[(t[(t[(t[(t[u>>2]|0)+64>>2]|0)+8>>2]|0)+(t[F>>2]<<2)>>2]|0)+16>>2];t[A>>2]=t[F>>2]}t[O>>2]=1;if((t[(t[(t[(t[(t[u>>2]|0)+64>>2]|0)+8>>2]|0)+(t[F>>2]<<2)>>2]|0)+16>>2]|0)<=(t[M>>2]|0)){t[M>>2]=t[(t[(t[(t[(t[u>>2]|0)+64>>2]|0)+8>>2]|0)+(t[F>>2]<<2)>>2]|0)+16>>2];t[A>>2]=t[F>>2]}if(!(t[M>>2]|0))break e}else if(y){a=t[(t[(t[(t[(t[u>>2]|0)+64>>2]|0)+8>>2]|0)+(t[F>>2]<<2)>>2]|0)+16>>2]|0;if((t[M>>2]|0)==-1){t[M>>2]=a;t[A>>2]=t[F>>2];break}if((a|0)>(t[M>>2]|0))break;t[M>>2]=t[(t[(t[(t[(t[u>>2]|0)+64>>2]|0)+8>>2]|0)+(t[F>>2]<<2)>>2]|0)+16>>2];t[A>>2]=t[F>>2]}while(0);t[F>>2]=(t[F>>2]|0)+1}do if((t[t[(t[u>>2]|0)+64>>2]>>2]|0)>0){yx(t[u>>2]|0,t[h>>2]|0);if((t[A>>2]|0)!=-1){t[h>>2]=t[(t[(t[(t[u>>2]|0)+64>>2]|0)+8>>2]|0)+(t[A>>2]<<2)>>2];t[(t[(t[(t[u>>2]|0)+64>>2]|0)+8>>2]|0)+(t[A>>2]<<2)>>2]=0;break}else{t[h>>2]=t[(t[(t[(t[u>>2]|0)+64>>2]|0)+8>>2]|0)+((t[t[(t[u>>2]|0)+64>>2]>>2]|0)-1<<2)>>2];t[(t[(t[(t[u>>2]|0)+64>>2]|0)+8>>2]|0)+((t[t[(t[u>>2]|0)+64>>2]>>2]|0)-1<<2)>>2]=0;y=t[(t[u>>2]|0)+64>>2]|0;t[y>>2]=(t[y>>2]|0)+-1;break}}while(0);t[F>>2]=0;while(1){T=t[u>>2]|0;if((t[F>>2]|0)>=(t[t[(t[u>>2]|0)+64>>2]>>2]|0))break;yx(T,t[(t[(t[(t[u>>2]|0)+64>>2]|0)+8>>2]|0)+(t[F>>2]<<2)>>2]|0);t[F>>2]=(t[F>>2]|0)+1}Ox(T,t[(t[u>>2]|0)+64>>2]|0);t[(t[u>>2]|0)+64>>2]=0;if(!(t[O>>2]|0)){N=85;break}}if(t[(t[g>>2]|0)+(t[c>>2]<<2)>>2]|0)t[(t[(t[g>>2]|0)+(t[c>>2]<<2)>>2]|0)+24>>2]=t[_>>2];t[c>>2]=(t[c>>2]|0)+1}if((N|0)==55)t[o>>2]=-1;else if((N|0)==61){mx(t[u>>2]|0,12,t[(t[v>>2]|0)+8>>2]|0,0,0);t[o>>2]=-1;t[(t[u>>2]|0)+60>>2]=t[h>>2];break}else if((N|0)==85){y=t[u>>2]|0;if(!(t[v>>2]|0))mx(y,12,189560,0,0);else mx(y,12,t[(t[v>>2]|0)+8>>2]|0,0,0);t[o>>2]=-1;t[(t[u>>2]|0)+60>>2]=t[h>>2];break}else if((N|0)==89)t[o>>2]=-1;if(t[(t[u>>2]|0)+60>>2]|0)yx(t[u>>2]|0,t[(t[u>>2]|0)+60>>2]|0);t[(t[u>>2]|0)+60>>2]=t[h>>2];t[(t[(t[u>>2]|0)+60>>2]|0)+4>>2]=t[E>>2];if(t[o>>2]|0){mx(t[u>>2]|0,11,0,0,0);t[o>>2]=-1}}else{mx(t[u>>2]|0,11,0,0,0);t[o>>2]=-1}while(0);t[(t[u>>2]|0)+28>>2]=t[k>>2];t[v>>2]=t[p>>2];while(1){if(!(t[v>>2]|0))break;if((t[v>>2]|0)==(t[m>>2]|0))break;if(!(t[(t[v>>2]|0)+28>>2]|0))break;t[(t[(t[v>>2]|0)+28>>2]|0)+24>>2]=t[v>>2];t[v>>2]=t[(t[v>>2]|0)+28>>2]}if((t[o>>2]|0)==0?(t[(t[u>>2]|0)+48>>2]|0)>(t[b>>2]|0):0)gU(t[u>>2]|0,t[b>>2]|0);pAi[t[135736>>2]&511](t[S>>2]|0);pAi[t[135736>>2]&511](t[g>>2]|0);t[n>>2]=t[o>>2];R=t[n>>2]|0;s=r;return R|0}function NU(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0;f=s;s=s+48|0;u=f+44|0;a=f+40|0;o=f+36|0;c=f+32|0;l=f+28|0;b=f+24|0;k=f+20|0;h=f+16|0;w=f+12|0;d=f+8|0;v=f+4|0;m=f;t[a>>2]=e;t[o>>2]=i;t[c>>2]=r;t[l>>2]=n;t[w>>2]=0;if((t[c>>2]|0)!=0?(t[(t[c>>2]|0)+20>>2]|0)!=0:0){t[h>>2]=t[(t[c>>2]|0)+20>>2];do if(t[(t[h>>2]|0)+12>>2]|0){if((t[(t[c>>2]|0)+36>>2]|0)!=0?(t[t[(t[c>>2]|0)+36>>2]>>2]|0)==6:0){t[b>>2]=RAi[t[(t[h>>2]|0)+12>>2]&511](t[(t[h>>2]|0)+4>>2]|0,t[(t[c>>2]|0)+8>>2]|0,t[o>>2]|0,w,t[l>>2]|0)|0;break}t[b>>2]=RAi[t[(t[h>>2]|0)+12>>2]&511](t[(t[h>>2]|0)+4>>2]|0,t[(t[c>>2]|0)+8>>2]|0,t[o>>2]|0,0,t[l>>2]|0)|0}else t[b>>2]=-1;while(0);if((t[b>>2]|0)<0){mx(t[a>>2]|0,2,t[(t[c>>2]|0)+8>>2]|0,0,0);if((t[w>>2]|0)!=0&(t[h>>2]|0)!=0?(t[(t[h>>2]|0)+24>>2]|0)!=0:0)EAi[t[(t[h>>2]|0)+24>>2]&511](t[(t[h>>2]|0)+4>>2]|0,t[w>>2]|0);t[u>>2]=-1;_=t[u>>2]|0;s=f;return _|0}do if((t[b>>2]|0)!=1){l=t[a>>2]|0;if((t[b>>2]|0)==2){mx(l,4,t[o>>2]|0,0,1);break}else{mx(l,3,t[(t[c>>2]|0)+8>>2]|0,t[o>>2]|0,1);t[b>>2]=-1;break}}else t[b>>2]=0;while(0);t[d>>2]=t[(t[c>>2]|0)+36>>2];while(1){if(!((t[b>>2]|0)==0&(t[d>>2]|0)!=0))break;if((t[t[d>>2]>>2]|0)!=6)break;if((t[(t[h>>2]|0)+20>>2]|0)!=0?(t[k>>2]=SAi[t[(t[h>>2]|0)+20>>2]&511](t[(t[h>>2]|0)+4>>2]|0,t[(t[c>>2]|0)+8>>2]|0,t[(t[d>>2]|0)+8>>2]|0,t[(t[d>>2]|0)+16>>2]|0,t[o>>2]|0,t[w>>2]|0)|0,(t[k>>2]|0)!=0):0)t[b>>2]=-1;t[d>>2]=t[(t[d>>2]|0)+32>>2]}if((t[b>>2]|0)==0?(t[(t[c>>2]|0)+24>>2]|0)!=0:0){t[v>>2]=t[(t[(t[a>>2]|0)+60>>2]|0)+20>>2];t[m>>2]=t[(t[(t[a>>2]|0)+60>>2]|0)+24>>2];t[(t[(t[a>>2]|0)+60>>2]|0)+20>>2]=t[o>>2];t[(t[(t[a>>2]|0)+60>>2]|0)+24>>2]=0;t[b>>2]=TU(t[a>>2]|0,t[(t[c>>2]|0)+24>>2]|0)|0;t[(t[(t[a>>2]|0)+60>>2]|0)+20>>2]=t[v>>2];t[(t[(t[a>>2]|0)+60>>2]|0)+24>>2]=t[m>>2]}if((t[w>>2]|0)!=0&(t[h>>2]|0)!=0?(t[(t[h>>2]|0)+24>>2]|0)!=0:0)EAi[t[(t[h>>2]|0)+24>>2]&511](t[(t[h>>2]|0)+4>>2]|0,t[w>>2]|0);t[u>>2]=t[b>>2];_=t[u>>2]|0;s=f;return _|0}t[u>>2]=-1;_=t[u>>2]|0;s=f;return _|0}function TU(e,i){e=e|0;i=i|0;var r=0,f=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0,S=0,g=0,y=0,F=0,O=0,A=0,M=0,R=0,N=0,T=0,L=0,D=0,C=0,P=0,B=0;r=s;s=s+96|0;f=r;a=r+92|0;o=r+88|0;c=r+84|0;l=r+80|0;b=r+76|0;k=r+72|0;h=r+68|0;w=r+64|0;d=r+60|0;v=r+56|0;m=r+52|0;_=r+48|0;p=r+44|0;E=r+40|0;S=r+36|0;g=r+32|0;y=r+28|0;F=r+24|0;O=r+20|0;A=r+16|0;M=r+12|0;R=r+8|0;t[o>>2]=e;t[c>>2]=i;t[l>>2]=0;t[k>>2]=t[(t[(t[o>>2]|0)+60>>2]|0)+20>>2];e:do switch(t[t[c>>2]>>2]|0){case 17:{t[m>>2]=t[(t[c>>2]|0)+24>>2];t[b>>2]=t[(t[o>>2]|0)+28>>2];i=(t[o>>2]|0)+28|0;t[i>>2]=t[i>>2]|1;t[_>>2]=t[(t[(t[o>>2]|0)+60>>2]|0)+20>>2];while(1){if(!(t[m>>2]|0))break;t[l>>2]=TU(t[o>>2]|0,t[m>>2]|0)|0;if(!(t[l>>2]|0))break;t[(t[(t[o>>2]|0)+60>>2]|0)+20>>2]=t[_>>2];t[m>>2]=t[(t[m>>2]|0)+32>>2]}t[(t[o>>2]|0)+28>>2]=t[b>>2];i=t[o>>2]|0;if(t[l>>2]|0){if(t[i+28>>2]&1)break e;Yx(t[o>>2]|0);break e}else{if((t[i+48>>2]|0)<=0)break e;gU(t[o>>2]|0,0);break e}break}case 5:{t[l>>2]=NU(t[o>>2]|0,t[k>>2]|0,t[c>>2]|0,t[(t[(t[o>>2]|0)+60>>2]|0)+4>>2]|0)|0;if(!(t[l>>2]|0))KU(t[o>>2]|0)|0;break}case 16:{t[l>>2]=XU(t[o>>2]|0,t[(t[c>>2]|0)+24>>2]|0)|0;if(!(t[l>>2]|0))N=78;break}case 15:{N=78;break}case 8:{t[p>>2]=t[(t[c>>2]|0)+24>>2];t[E>>2]=t[(t[(t[o>>2]|0)+60>>2]|0)+20>>2];t[S>>2]=t[(t[(t[o>>2]|0)+60>>2]|0)+24>>2];t[g>>2]=Yl(t[E>>2]|0)|0;if(!(t[g>>2]|0))t[g>>2]=Yl(188112)|0;if(!(t[g>>2]|0)){mx(t[o>>2]|0,6,0,0,0);t[a>>2]=-1;T=t[a>>2]|0;s=r;return T|0}t[y>>2]=t[g>>2];i:while(1){L=t[y>>2]|0;if(!(u[t[y>>2]>>0]|0))break;do if((u[L>>0]|0|0)!=32){if(9<=(u[t[y>>2]>>0]|0|0)?(u[t[y>>2]>>0]|0|0)<=10:0)break;if((u[t[y>>2]>>0]|0|0)!=13){t[y>>2]=(t[y>>2]|0)+1;continue i}}while(0);n[t[y>>2]>>0]=0;t[y>>2]=(t[y>>2]|0)+1;while(1){do if((u[t[y>>2]>>0]|0|0)!=32){if(9<=(u[t[y>>2]>>0]|0|0)?(u[t[y>>2]>>0]|0|0)<=10:0)break;if((u[t[y>>2]>>0]|0|0)!=13)continue i}while(0);i=t[y>>2]|0;t[y>>2]=i+1;n[i>>0]=0}}t[(t[(t[o>>2]|0)+60>>2]|0)+24>>2]=L;t[y>>2]=t[g>>2];while(1){if(!(u[t[y>>2]>>0]|0))D=(t[y>>2]|0)!=(t[(t[(t[o>>2]|0)+60>>2]|0)+24>>2]|0);else D=0;C=t[y>>2]|0;if(!D)break;t[y>>2]=C+1}t[(t[(t[o>>2]|0)+60>>2]|0)+20>>2]=C;while(1){if(!(t[p>>2]|0))break;if((t[(t[(t[o>>2]|0)+60>>2]|0)+20>>2]|0)==(t[(t[(t[o>>2]|0)+60>>2]|0)+24>>2]|0))t[(t[(t[o>>2]|0)+60>>2]|0)+20>>2]=0;t[l>>2]=TU(t[o>>2]|0,t[p>>2]|0)|0;if(t[l>>2]|0)break;t[p>>2]=t[(t[p>>2]|0)+32>>2]}if(((t[l>>2]|0)==0?(t[(t[(t[o>>2]|0)+60>>2]|0)+20>>2]|0)!=0:0)?(t[(t[(t[o>>2]|0)+60>>2]|0)+20>>2]|0)!=(t[(t[(t[o>>2]|0)+60>>2]|0)+24>>2]|0):0){mx(t[o>>2]|0,8,t[(t[(t[o>>2]|0)+60>>2]|0)+20>>2]|0,0,0);t[l>>2]=-1}pAi[t[135736>>2]&511](t[g>>2]|0);t[(t[(t[o>>2]|0)+60>>2]|0)+20>>2]=t[E>>2];t[(t[(t[o>>2]|0)+60>>2]|0)+24>>2]=t[S>>2];break}case 7:{do if(!(Xl(t[k>>2]|0,t[(t[c>>2]|0)+16>>2]|0)|0)){if(!(t[(t[c>>2]|0)+8>>2]|0)){t[d>>2]=Tx(t[o>>2]|0,t[(t[c>>2]|0)+16>>2]|0)|0;t[v>>2]=Tx(t[o>>2]|0,t[k>>2]|0)|0;if(!(!((t[d>>2]|0)==0|(t[v>>2]|0)==0)?(Xl(t[d>>2]|0,t[v>>2]|0)|0)!=0:0))t[l>>2]=-1;if(t[d>>2]|0)pAi[t[135736>>2]&511](t[d>>2]|0);if(!(t[v>>2]|0))break;pAi[t[135736>>2]&511](t[v>>2]|0);break}t[w>>2]=t[(t[c>>2]|0)+20>>2];if((t[w>>2]|0)!=0?(t[(t[w>>2]|0)+16>>2]|0)!=0:0)t[l>>2]=wAi[t[(t[w>>2]|0)+16>>2]&511](t[(t[w>>2]|0)+4>>2]|0,t[(t[c>>2]|0)+8>>2]|0,t[(t[c>>2]|0)+16>>2]|0,t[(t[c>>2]|0)+4>>2]|0,t[(t[c>>2]|0)+36>>2]|0,t[k>>2]|0,t[t[(t[o>>2]|0)+60>>2]>>2]|0)|0;else t[l>>2]=-1;if((t[l>>2]|0)<0){mx(t[o>>2]|0,5,t[(t[c>>2]|0)+8>>2]|0,0,0);t[a>>2]=-1;T=t[a>>2]|0;s=r;return T|0}if((t[l>>2]|0)==1){t[l>>2]=0;break}else{t[l>>2]=-1;break}}while(0);if(!(t[l>>2]|0))KU(t[o>>2]|0)|0;break}case 0:{if((t[k>>2]|0)!=0?(u[t[k>>2]>>0]|0|0)!=0:0){t[h>>2]=0;while(1){do if((u[(t[k>>2]|0)+(t[h>>2]|0)>>0]|0|0)==32)P=1;else{if(9<=(u[(t[k>>2]|0)+(t[h>>2]|0)>>0]|0|0)?(u[(t[k>>2]|0)+(t[h>>2]|0)>>0]|0|0)<=10:0){P=1;break}P=(u[(t[k>>2]|0)+(t[h>>2]|0)>>0]|0|0)==13}while(0);B=t[h>>2]|0;if(!P)break;t[h>>2]=B+1}if(u[(t[k>>2]|0)+B>>0]|0)t[l>>2]=-1}break}case 18:case 10:{t[R>>2]=t[(t[c>>2]|0)+24>>2];while(1){if(!(t[R>>2]|0))break e;t[l>>2]=TU(t[o>>2]|0,t[R>>2]|0)|0;if(t[l>>2]|0)break;t[l>>2]=0;t[R>>2]=t[(t[R>>2]|0)+32>>2]}t[l>>2]=-1;break}case 13:case 11:{i=t[o>>2]|0;if(!(t[(t[c>>2]|0)+24>>2]|0)){mx(i,7,0,0,0);t[l>>2]=-1;break e}else{t[l>>2]=TU(i,t[(t[c>>2]|0)+24>>2]|0)|0;break e}break}case 3:break;case 2:{t[M>>2]=t[(t[c>>2]|0)+24>>2];while(1){if(!(t[M>>2]|0))break e;t[l>>2]=TU(t[o>>2]|0,t[M>>2]|0)|0;if(!(t[l>>2]|0))break;t[l>>2]=0;t[M>>2]=t[(t[M>>2]|0)+32>>2]}t[l>>2]=-1;break}case 14:{if((t[(t[(t[o>>2]|0)+60>>2]|0)+20>>2]|0)!=0?(u[t[(t[(t[o>>2]|0)+60>>2]|0)+20>>2]>>0]|0|0)!=0:0){t[b>>2]=t[(t[o>>2]|0)+28>>2];i=(t[o>>2]|0)+28|0;t[i>>2]=t[i>>2]|1;t[A>>2]=t[(t[(t[o>>2]|0)+60>>2]|0)+20>>2];t[l>>2]=TU(t[o>>2]|0,t[(t[c>>2]|0)+24>>2]|0)|0;t[(t[o>>2]|0)+28>>2]=t[b>>2];if(!(t[l>>2]|0)){if((t[(t[o>>2]|0)+48>>2]|0)<=0)break e;gU(t[o>>2]|0,0);break e}t[(t[(t[o>>2]|0)+60>>2]|0)+20>>2]=t[A>>2];if((t[(t[o>>2]|0)+48>>2]|0)>0)gU(t[o>>2]|0,0);t[l>>2]=0;break e}t[l>>2]=0;break}default:{i=t[33976]|0;e=t[33980]|0;t[f>>2]=189496;t[f+4>>2]=8982;yAi[i&511](e,189464,f);t[l>>2]=-1}}while(0);do if((N|0)==78){if((t[(t[(t[o>>2]|0)+60>>2]|0)+20>>2]|0)!=0?(u[t[(t[(t[o>>2]|0)+60>>2]|0)+20>>2]>>0]|0|0)!=0:0){t[b>>2]=t[(t[o>>2]|0)+28>>2];f=(t[o>>2]|0)+28|0;t[f>>2]=t[f>>2]|1;t[F>>2]=t[(t[(t[o>>2]|0)+60>>2]|0)+20>>2];t[O>>2]=0;while(1){if(!(t[F>>2]|0))break;if((t[F>>2]|0)==(t[(t[(t[o>>2]|0)+60>>2]|0)+24>>2]|0))break;if((t[O>>2]|0)==(t[F>>2]|0))break;t[O>>2]=t[F>>2];t[l>>2]=XU(t[o>>2]|0,t[(t[c>>2]|0)+24>>2]|0)|0;if(t[l>>2]|0){N=86;break}t[F>>2]=t[(t[(t[o>>2]|0)+60>>2]|0)+20>>2]}if((N|0)==86){t[(t[(t[o>>2]|0)+60>>2]|0)+20>>2]=t[O>>2];t[l>>2]=0}t[(t[o>>2]|0)+28>>2]=t[b>>2];if((t[(t[o>>2]|0)+48>>2]|0)<=0)break;gU(t[o>>2]|0,0);break}t[l>>2]=0}while(0);t[a>>2]=t[l>>2];T=t[a>>2]|0;s=r;return T|0}function LU(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0;n=s;s=s+32|0;f=n+16|0;u=n+8|0;a=n+4|0;o=n;t[n+12>>2]=e;t[u>>2]=i;t[a>>2]=r;do if(!((t[u>>2]|0)==0|(t[a>>2]|0)==0)){if((t[u>>2]|0)==(t[a>>2]|0)){t[f>>2]=1;break}if((t[t[u>>2]>>2]|0)!=(t[t[a>>2]>>2]|0)){t[f>>2]=0;break}if((t[(t[u>>2]|0)+4>>2]|0)!=(t[(t[a>>2]|0)+4>>2]|0)){t[f>>2]=0;break}if((t[(t[u>>2]|0)+16>>2]|0)!=(t[(t[a>>2]|0)+16>>2]|0)){t[f>>2]=0;break}if((t[(t[u>>2]|0)+8>>2]|0)!=(t[(t[a>>2]|0)+8>>2]|0)){t[f>>2]=0;break}if((t[(t[u>>2]|0)+24>>2]|0)!=(t[(t[a>>2]|0)+24>>2]|0)){t[f>>2]=0;break}if((t[(t[u>>2]|0)+20>>2]|0)!=(t[(t[a>>2]|0)+20>>2]|0)?(Xl(t[(t[u>>2]|0)+20>>2]|0,t[(t[a>>2]|0)+20>>2]|0)|0)==0:0){t[f>>2]=0;break}t[o>>2]=0;while(1){if((t[o>>2]|0)>=(t[(t[u>>2]|0)+8>>2]|0)){c=23;break}if((t[(t[(t[u>>2]|0)+28>>2]|0)+(t[o>>2]<<2)>>2]|0)!=(t[(t[(t[a>>2]|0)+28>>2]|0)+(t[o>>2]<<2)>>2]|0)){c=21;break}t[o>>2]=(t[o>>2]|0)+1}if((c|0)==21){t[f>>2]=0;break}else if((c|0)==23){t[f>>2]=1;break}}else t[f>>2]=0;while(0);s=n;return t[f>>2]|0}function DU(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0;r=s;s=s+16|0;n=r+8|0;f=r+4|0;u=r;t[f>>2]=e;t[u>>2]=i;if((t[(t[f>>2]|0)+108>>2]|0)==0?(t[(t[f>>2]|0)+104>>2]=4,t[(t[f>>2]|0)+100>>2]=0,i=gAi[t[135744>>2]&511](t[(t[f>>2]|0)+104>>2]<<2)|0,t[(t[f>>2]|0)+108>>2]=i,(t[(t[f>>2]|0)+108>>2]|0)==0):0){lx(t[f>>2]|0,196496);t[n>>2]=0;a=t[n>>2]|0;s=r;return a|0}if((t[(t[f>>2]|0)+100>>2]|0)>=(t[(t[f>>2]|0)+104>>2]|0)?(i=(t[f>>2]|0)+104|0,t[i>>2]=t[i>>2]<<1,i=MAi[t[135760>>2]&511](t[(t[f>>2]|0)+108>>2]|0,t[(t[f>>2]|0)+104>>2]<<2)|0,t[(t[f>>2]|0)+108>>2]=i,(t[(t[f>>2]|0)+108>>2]|0)==0):0){lx(t[f>>2]|0,196496);t[n>>2]=0;a=t[n>>2]|0;s=r;return a|0}t[(t[(t[f>>2]|0)+108>>2]|0)+(t[(t[f>>2]|0)+100>>2]<<2)>>2]=t[u>>2];t[(t[f>>2]|0)+96>>2]=t[u>>2];u=(t[f>>2]|0)+100|0;f=t[u>>2]|0;t[u>>2]=f+1;t[n>>2]=f;a=t[n>>2]|0;s=r;return a|0}function CU(e){e=e|0;var i=0,r=0,n=0,f=0,u=0;i=s;s=s+16|0;r=i+8|0;n=i+4|0;f=i;t[n>>2]=e;if((t[(t[n>>2]|0)+100>>2]|0)<=0){t[r>>2]=0;u=t[r>>2]|0;s=i;return u|0}e=(t[n>>2]|0)+100|0;t[e>>2]=(t[e>>2]|0)+-1;e=t[n>>2]|0;if((t[(t[n>>2]|0)+100>>2]|0)>0)t[(t[n>>2]|0)+96>>2]=t[(t[(t[n>>2]|0)+108>>2]|0)+((t[e+100>>2]|0)-1<<2)>>2];else t[e+96>>2]=0;t[f>>2]=t[(t[(t[n>>2]|0)+108>>2]|0)+(t[(t[n>>2]|0)+100>>2]<<2)>>2];t[(t[(t[n>>2]|0)+108>>2]|0)+(t[(t[n>>2]|0)+100>>2]<<2)>>2]=0;t[r>>2]=t[f>>2];u=t[r>>2]|0;s=i;return u|0}function PU(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0;r=s;s=s+16|0;n=r+8|0;f=r+4|0;u=r;t[f>>2]=e;t[u>>2]=i;if((t[(t[f>>2]|0)+124>>2]|0)==0?(t[(t[f>>2]|0)+120>>2]=4,t[(t[f>>2]|0)+116>>2]=0,i=gAi[t[135744>>2]&511](t[(t[f>>2]|0)+120>>2]<<2)|0,t[(t[f>>2]|0)+124>>2]=i,(t[(t[f>>2]|0)+124>>2]|0)==0):0){lx(t[f>>2]|0,196088);t[n>>2]=0;a=t[n>>2]|0;s=r;return a|0}if((t[(t[f>>2]|0)+116>>2]|0)>=(t[(t[f>>2]|0)+120>>2]|0)?(i=(t[f>>2]|0)+120|0,t[i>>2]=t[i>>2]<<1,i=MAi[t[135760>>2]&511](t[(t[f>>2]|0)+124>>2]|0,t[(t[f>>2]|0)+120>>2]<<2)|0,t[(t[f>>2]|0)+124>>2]=i,(t[(t[f>>2]|0)+124>>2]|0)==0):0){lx(t[f>>2]|0,196088);t[n>>2]=0;a=t[n>>2]|0;s=r;return a|0}t[(t[(t[f>>2]|0)+124>>2]|0)+(t[(t[f>>2]|0)+116>>2]<<2)>>2]=t[u>>2];t[(t[f>>2]|0)+112>>2]=t[u>>2];u=(t[f>>2]|0)+116|0;f=t[u>>2]|0;t[u>>2]=f+1;t[n>>2]=f;a=t[n>>2]|0;s=r;return a|0}function BU(e){e=e|0;var i=0,r=0,n=0,f=0,u=0;i=s;s=s+16|0;r=i+8|0;n=i+4|0;f=i;t[n>>2]=e;if((t[(t[n>>2]|0)+116>>2]|0)<=0){t[r>>2]=0;u=t[r>>2]|0;s=i;return u|0}e=(t[n>>2]|0)+116|0;t[e>>2]=(t[e>>2]|0)+-1;e=t[n>>2]|0;if((t[(t[n>>2]|0)+116>>2]|0)>0)t[(t[n>>2]|0)+112>>2]=t[(t[(t[n>>2]|0)+124>>2]|0)+((t[e+116>>2]|0)-1<<2)>>2];else t[e+112>>2]=0;t[f>>2]=t[(t[(t[n>>2]|0)+124>>2]|0)+(t[(t[n>>2]|0)+116>>2]<<2)>>2];t[(t[(t[n>>2]|0)+124>>2]|0)+(t[(t[n>>2]|0)+116>>2]<<2)>>2]=0;t[r>>2]=t[f>>2];u=t[r>>2]|0;s=i;return u|0}function IU(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0;f=s;s=s+48|0;u=f+36|0;a=f+28|0;o=f+24|0;c=f+20|0;l=f+16|0;b=f+12|0;k=f+8|0;h=f+4|0;w=f;t[u>>2]=e;t[f+32>>2]=i;t[a>>2]=r;t[o>>2]=n;t[c>>2]=0;t[l>>2]=t[a>>2];while(1){if(!(t[l>>2]|0))break;t[b>>2]=t[(t[l>>2]|0)+24>>2];if(((((t[o>>2]|0)==0&(t[l>>2]|0)!=0?(t[(t[l>>2]|0)+36>>2]|0)!=0:0)?(t[(t[l>>2]|0)+4>>2]|0)==1:0)?(Xl(t[(t[l>>2]|0)+8>>2]|0,190048)|0)!=0:0)?(Xl(t[(t[(t[l>>2]|0)+36>>2]|0)+8>>2]|0,t[46968]|0)|0)!=0:0){t[c>>2]=1;iy(t[l>>2]|0);ry(t[l>>2]|0)}else d=9;do if((d|0)==9){d=0;if(((((t[o>>2]|0)!=0&(t[l>>2]|0)!=0?(t[(t[l>>2]|0)+36>>2]|0)!=0:0)?(t[(t[l>>2]|0)+4>>2]|0)==1:0)?(Xl(t[(t[l>>2]|0)+8>>2]|0,195016)|0)!=0:0)?(Xl(t[(t[(t[l>>2]|0)+36>>2]|0)+8>>2]|0,t[46968]|0)|0)!=0:0){t[k>>2]=cF(t[l>>2]|0,192176)|0;HU(t[k>>2]|0);if(!(t[k>>2]|0))break;if(Xl(t[o>>2]|0,t[k>>2]|0)|0){t[c>>2]=1;iy(t[l>>2]|0);ry(t[l>>2]|0)}pAi[t[135736>>2]&511](t[k>>2]|0);break}if((((((((((t[l>>2]|0)!=0?(t[(t[l>>2]|0)+36>>2]|0)!=0:0)?(t[(t[l>>2]|0)+4>>2]|0)==1:0)?(Xl(t[(t[l>>2]|0)+8>>2]|0,195024)|0)!=0:0)?(Xl(t[(t[(t[l>>2]|0)+36>>2]|0)+8>>2]|0,t[46968]|0)|0)!=0:0)?(t[h>>2]=0,t[w>>2]=t[(t[l>>2]|0)+52>>2],(t[w>>2]|0)!=0):0)?(t[(t[w>>2]|0)+8>>2]|0)!=0:0)?(t[(t[(t[w>>2]|0)+8>>2]|0)+12>>2]|0)!=0:0)?(Xl(t[(t[(t[(t[w>>2]|0)+8>>2]|0)+12>>2]|0)+8>>2]|0,190264)|0)!=0:0)?(a=t[u>>2]|0,n=t[h>>2]|0,r=t[(eF(t[(t[w>>2]|0)+8>>2]|0)|0)+12>>2]|0,(IU(a,n,r,t[o>>2]|0)|0)==1):0)t[c>>2]=1}while(0);t[l>>2]=t[b>>2]}s=f;return t[c>>2]|0}function HU(e){e=e|0;var i=0,r=0,f=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0;i=s;s=s+16|0;r=i+8|0;f=i+4|0;a=i;t[r>>2]=e;t[f>>2]=t[r>>2];t[a>>2]=t[r>>2];if(!(t[r>>2]|0)){s=i;return}while(1){do if((u[t[a>>2]>>0]|0|0)==32)o=1;else{if(9<=(u[t[a>>2]>>0]|0|0)?(u[t[a>>2]>>0]|0|0)<=10:0){o=1;break}o=(u[t[a>>2]>>0]|0|0)==13}while(0);c=t[a>>2]|0;if(!o)break;t[a>>2]=c+1}if((c|0)==(t[f>>2]|0)){while(1){if(u[t[a>>2]>>0]|0){do if((u[t[a>>2]>>0]|0|0)==32)l=1;else{if(9<=(u[t[a>>2]>>0]|0|0)?(u[t[a>>2]>>0]|0|0)<=10:0){l=1;break}l=(u[t[a>>2]>>0]|0|0)==13}while(0);b=l^1}else b=0;c=t[a>>2]|0;if(b){t[a>>2]=c+1;continue}if(!(u[c>>0]|0)){k=46;break}t[f>>2]=t[a>>2];while(1){do if((u[t[a>>2]>>0]|0|0)==32)h=1;else{if(9<=(u[t[a>>2]>>0]|0|0)?(u[t[a>>2]>>0]|0|0)<=10:0){h=1;break}h=(u[t[a>>2]>>0]|0|0)==13}while(0);w=t[a>>2]|0;if(!h)break;t[a>>2]=w+1}if(!(u[w>>0]|0))break}if((k|0)==46){s=i;return}n[t[f>>2]>>0]=0;s=i;return}while(1){if(u[t[a>>2]>>0]|0){do if((u[t[a>>2]>>0]|0|0)==32)d=1;else{if(9<=(u[t[a>>2]>>0]|0|0)?(u[t[a>>2]>>0]|0|0)<=10:0){d=1;break}d=(u[t[a>>2]>>0]|0|0)==13}while(0);v=d^1}else v=0;w=t[a>>2]|0;if(v){t[a>>2]=w+1;h=n[w>>0]|0;b=t[f>>2]|0;t[f>>2]=b+1;n[b>>0]=h;continue}if(!(u[w>>0]|0)){k=36;break}while(1){do if((u[t[a>>2]>>0]|0|0)==32)m=1;else{if(9<=(u[t[a>>2]>>0]|0|0)?(u[t[a>>2]>>0]|0|0)<=10:0){m=1;break}m=(u[t[a>>2]>>0]|0|0)==13}while(0);_=t[a>>2]|0;if(!m)break;t[a>>2]=_+1}if(!(u[_>>0]|0)){k=44;break}w=t[a>>2]|0;t[a>>2]=w+1;h=n[w>>0]|0;w=t[f>>2]|0;t[f>>2]=w+1;n[w>>0]=h}if((k|0)==36){n[t[f>>2]>>0]=0;s=i;return}else if((k|0)==44){n[t[f>>2]>>0]=0;s=i;return}}function xU(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0;r=s;s=s+48|0;n=r+32|0;f=r+28|0;u=r+24|0;a=r+20|0;o=r+16|0;c=r+12|0;l=r+8|0;b=r+4|0;k=r;t[f>>2]=e;t[u>>2]=i;t[o>>2]=0;t[a>>2]=cF(t[u>>2]|0,192176)|0;do if(t[a>>2]|0){HU(t[a>>2]|0);if(Vg(t[a>>2]|0,0)|0)bx(t[f>>2]|0,t[u>>2]|0,1049,195200,t[a>>2]|0,0);t[l>>2]=dx(t[f>>2]|0,t[u>>2]|0)|0;if(!(t[l>>2]|0)){pAi[t[135736>>2]&511](t[a>>2]|0);t[n>>2]=-1;h=t[n>>2]|0;s=r;return h|0}t[t[l>>2]>>2]=10;t[(t[l>>2]|0)+8>>2]=t[a>>2];i=t[f>>2]|0;if(!(t[(t[u>>2]|0)+12>>2]|0))bx(i,t[u>>2]|0,1012,195240,0,0);else{t[b>>2]=t[i+44>>2];t[(t[f>>2]|0)+44>>2]=t[a>>2];i=lU(t[f>>2]|0,t[(t[u>>2]|0)+12>>2]|0,0)|0;t[(t[l>>2]|0)+24>>2]=i;t[(t[f>>2]|0)+44>>2]=t[b>>2]}if(!(t[(t[(t[f>>2]|0)+24>>2]|0)+24>>2]|0)){i=WF(10)|0;t[(t[(t[f>>2]|0)+24>>2]|0)+24>>2]=i}i=t[f>>2]|0;if(!(t[(t[(t[f>>2]|0)+24>>2]|0)+24>>2]|0)){bx(i,t[u>>2]|0,1011,195264,0,0);t[o>>2]=-1;break}t[c>>2]=ZF(t[(t[i+24>>2]|0)+24>>2]|0,t[a>>2]|0,t[l>>2]|0)|0;if((t[c>>2]|0)<0){t[k>>2]=rO(t[(t[(t[f>>2]|0)+24>>2]|0)+24>>2]|0,t[a>>2]|0)|0;if(!(t[k>>2]|0)){bx(t[f>>2]|0,t[u>>2]|0,1011,195304,t[a>>2]|0,0);t[o>>2]=-1;break}while(1){if(!(t[(t[k>>2]|0)+44>>2]|0))break;t[k>>2]=t[(t[k>>2]|0)+44>>2]}t[(t[k>>2]|0)+44>>2]=t[l>>2]}}else bx(t[f>>2]|0,t[u>>2]|0,1014,195176,0,0);while(0);t[n>>2]=t[o>>2];h=t[n>>2]|0;s=r;return h|0}function UU(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0;r=s;s=s+32|0;n=r+24|0;f=r+20|0;u=r+16|0;a=r+12|0;o=r+8|0;c=r+4|0;l=r;t[f>>2]=e;t[u>>2]=i;t[c>>2]=0;t[a>>2]=t[(t[u>>2]|0)+52>>2];if(!(t[a>>2]|0)){bx(t[f>>2]|0,t[u>>2]|0,1042,195072,0,0);t[n>>2]=-1;b=t[n>>2]|0;s=r;return b|0}t[o>>2]=eF(t[(t[a>>2]|0)+8>>2]|0)|0;if(!(t[o>>2]|0)){bx(t[f>>2]|0,t[u>>2]|0,1022,195104,0,0);t[n>>2]=-1;b=t[n>>2]|0;s=r;return b|0}if(!(Xl(t[(t[o>>2]|0)+8>>2]|0,190264)|0)){bx(t[f>>2]|0,t[u>>2]|0,1038,195136,0,0);t[n>>2]=-1;b=t[n>>2]|0;s=r;return b|0}if((t[(t[o>>2]|0)+12>>2]|0)!=0?(t[l>>2]=uU(t[f>>2]|0,t[(t[o>>2]|0)+12>>2]|0)|0,(t[l>>2]|0)!=0):0)t[c>>2]=-1;if((t[(t[u>>2]|0)+12>>2]|0)!=0?(t[l>>2]=uU(t[f>>2]|0,t[(t[u>>2]|0)+12>>2]|0)|0,(t[l>>2]|0)!=0):0)t[c>>2]=-1;t[n>>2]=t[c>>2];b=t[n>>2]|0;s=r;return b|0}function zU(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0;r=s;s=s+32|0;n=r+28|0;f=r+24|0;u=r+20|0;a=r+16|0;o=r+12|0;c=r+8|0;l=r+4|0;b=r;t[f>>2]=e;t[u>>2]=i;t[a>>2]=dx(t[f>>2]|0,t[u>>2]|0)|0;if(!(t[a>>2]|0)){t[n>>2]=0;k=t[n>>2]|0;s=r;return k|0}t[t[a>>2]>>2]=4;t[(t[a>>2]|0)+28>>2]=t[(t[f>>2]|0)+48>>2];t[l>>2]=t[(t[u>>2]|0)+12>>2];i=t[f>>2]|0;if(!(t[l>>2]|0)){bx(i,t[u>>2]|0,1017,194024,0,0);t[n>>2]=t[a>>2];k=t[n>>2]|0;s=r;return k|0}t[o>>2]=ZU(i,t[l>>2]|0,t[a>>2]|0)|0;if(t[o>>2]|0)t[l>>2]=t[(t[l>>2]|0)+24>>2];i=t[f>>2]|0;if(!(t[l>>2]|0)){bx(i,t[u>>2]|0,1020,194080,0,0);t[n>>2]=t[a>>2];k=t[n>>2]|0;s=r;return k|0}t[b>>2]=t[i+44>>2];t[(t[f>>2]|0)+44>>2]=0;t[c>>2]=0;while(1){if(!(t[l>>2]|0))break;t[o>>2]=jU(t[f>>2]|0,t[l>>2]|0)|0;e:do if(t[o>>2]|0){t[(t[o>>2]|0)+28>>2]=t[a>>2];switch(t[t[o>>2]>>2]|0){case 20:{bx(t[f>>2]|0,t[u>>2]|0,1018,194128,0,0);break e;break}case 9:{t[(t[o>>2]|0)+32>>2]=t[(t[a>>2]|0)+36>>2];t[(t[a>>2]|0)+36>>2]=t[o>>2];break e;break}case 19:case 18:case 17:case 14:case 16:case 15:case 10:case 12:case 13:case 11:case 8:case 7:case 5:case 4:case 3:case 1:case 0:{if(!(t[c>>2]|0)){i=t[o>>2]|0;t[c>>2]=i;t[(t[a>>2]|0)+24>>2]=i;break e}do if((t[t[c>>2]>>2]|0)==4?(t[(t[a>>2]|0)+24>>2]|0)==(t[c>>2]|0):0){i=dx(t[f>>2]|0,t[u>>2]|0)|0;t[(t[a>>2]|0)+24>>2]=i;if(t[(t[a>>2]|0)+24>>2]|0){t[t[(t[a>>2]|0)+24>>2]>>2]=18;t[(t[(t[a>>2]|0)+24>>2]|0)+24>>2]=t[c>>2];break}else{t[(t[a>>2]|0)+24>>2]=t[c>>2];break}}while(0);t[(t[c>>2]|0)+32>>2]=t[o>>2];t[c>>2]=t[o>>2];break e;break}case-1:{bx(t[f>>2]|0,t[u>>2]|0,1018,194272,0,0);break e;break}case 6:{bx(t[f>>2]|0,t[u>>2]|0,1018,194176,0,0);break e;break}case 2:{bx(t[f>>2]|0,t[u>>2]|0,1018,194224,0,0);break e;break}default:break e}}while(0);t[l>>2]=t[(t[l>>2]|0)+24>>2]}t[(t[f>>2]|0)+44>>2]=t[b>>2];t[n>>2]=t[a>>2];k=t[n>>2]|0;s=r;return k|0}function jU(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0;r=s;s=s+48|0;n=r+44|0;f=r+40|0;u=r+36|0;a=r+32|0;o=r+28|0;c=r+24|0;l=r+20|0;b=r+16|0;k=r+12|0;h=r+8|0;w=r+4|0;d=r;t[f>>2]=e;t[u>>2]=i;t[a>>2]=0;if(!(t[u>>2]|0)){t[n>>2]=0;v=t[n>>2]|0;s=r;return v|0}if(((((t[u>>2]|0)!=0?(t[(t[u>>2]|0)+36>>2]|0)!=0:0)?(t[(t[u>>2]|0)+4>>2]|0)==1:0)?(Xl(t[(t[u>>2]|0)+8>>2]|0,189864)|0)!=0:0)?(Xl(t[(t[(t[u>>2]|0)+36>>2]|0)+8>>2]|0,t[46968]|0)|0)!=0:0)t[a>>2]=zU(t[f>>2]|0,t[u>>2]|0)|0;else m=9;e:do if((m|0)==9){if(((((t[u>>2]|0)!=0?(t[(t[u>>2]|0)+36>>2]|0)!=0:0)?(t[(t[u>>2]|0)+4>>2]|0)==1:0)?(Xl(t[(t[u>>2]|0)+8>>2]|0,189904)|0)!=0:0)?(Xl(t[(t[(t[u>>2]|0)+36>>2]|0)+8>>2]|0,t[46968]|0)|0)!=0:0){t[a>>2]=JU(t[f>>2]|0,t[u>>2]|0)|0;break}if(((((t[u>>2]|0)!=0?(t[(t[u>>2]|0)+36>>2]|0)!=0:0)?(t[(t[u>>2]|0)+4>>2]|0)==1:0)?(Xl(t[(t[u>>2]|0)+8>>2]|0,189824)|0)!=0:0)?(Xl(t[(t[(t[u>>2]|0)+36>>2]|0)+8>>2]|0,t[46968]|0)|0)!=0:0){t[a>>2]=dx(t[f>>2]|0,t[u>>2]|0)|0;if(!(t[a>>2]|0)){t[n>>2]=0;v=t[n>>2]|0;s=r;return v|0}else{t[t[a>>2]>>2]=0;if(!(t[(t[u>>2]|0)+12>>2]|0))break;bx(t[f>>2]|0,t[u>>2]|0,1025,192096,0,0);break}}if(((((t[u>>2]|0)!=0?(t[(t[u>>2]|0)+36>>2]|0)!=0:0)?(t[(t[u>>2]|0)+4>>2]|0)==1:0)?(Xl(t[(t[u>>2]|0)+8>>2]|0,189856)|0)!=0:0)?(Xl(t[(t[(t[u>>2]|0)+36>>2]|0)+8>>2]|0,t[46968]|0)|0)!=0:0){t[a>>2]=dx(t[f>>2]|0,t[u>>2]|0)|0;if(!(t[a>>2]|0)){t[n>>2]=0;v=t[n>>2]|0;s=r;return v|0}else{t[t[a>>2]>>2]=3;if(!(t[(t[u>>2]|0)+12>>2]|0))break;bx(t[f>>2]|0,t[u>>2]|0,1109,192128,0,0);break}}if(((((t[u>>2]|0)!=0?(t[(t[u>>2]|0)+36>>2]|0)!=0:0)?(t[(t[u>>2]|0)+4>>2]|0)==1:0)?(Xl(t[(t[u>>2]|0)+8>>2]|0,189984)|0)!=0:0)?(Xl(t[(t[(t[u>>2]|0)+36>>2]|0)+8>>2]|0,t[46968]|0)|0)!=0:0){t[a>>2]=dx(t[f>>2]|0,t[u>>2]|0)|0;if(!(t[a>>2]|0)){t[n>>2]=0;v=t[n>>2]|0;s=r;return v|0}t[t[a>>2]>>2]=15;i=t[f>>2]|0;e=t[u>>2]|0;if(!(t[(t[u>>2]|0)+12>>2]|0)){bx(i,e,1023,192152,t[(t[u>>2]|0)+8>>2]|0,0);break}else{_=lU(i,t[e+12>>2]|0,1)|0;t[(t[a>>2]|0)+24>>2]=_;break}}if(((((t[u>>2]|0)!=0?(t[(t[u>>2]|0)+36>>2]|0)!=0:0)?(t[(t[u>>2]|0)+4>>2]|0)==1:0)?(Xl(t[(t[u>>2]|0)+8>>2]|0,19e4)|0)!=0:0)?(Xl(t[(t[(t[u>>2]|0)+36>>2]|0)+8>>2]|0,t[46968]|0)|0)!=0:0){t[a>>2]=dx(t[f>>2]|0,t[u>>2]|0)|0;if(!(t[a>>2]|0)){t[n>>2]=0;v=t[n>>2]|0;s=r;return v|0}t[t[a>>2]>>2]=16;_=t[f>>2]|0;e=t[u>>2]|0;if(!(t[(t[u>>2]|0)+12>>2]|0)){bx(_,e,1023,192152,t[(t[u>>2]|0)+8>>2]|0,0);break}else{i=lU(_,t[e+12>>2]|0,1)|0;t[(t[a>>2]|0)+24>>2]=i;break}}if(((((t[u>>2]|0)!=0?(t[(t[u>>2]|0)+36>>2]|0)!=0:0)?(t[(t[u>>2]|0)+4>>2]|0)==1:0)?(Xl(t[(t[u>>2]|0)+8>>2]|0,189968)|0)!=0:0)?(Xl(t[(t[(t[u>>2]|0)+36>>2]|0)+8>>2]|0,t[46968]|0)|0)!=0:0){t[a>>2]=dx(t[f>>2]|0,t[u>>2]|0)|0;if(!(t[a>>2]|0)){t[n>>2]=0;v=t[n>>2]|0;s=r;return v|0}t[t[a>>2]>>2]=14;i=t[f>>2]|0;e=t[u>>2]|0;if(!(t[(t[u>>2]|0)+12>>2]|0)){bx(i,e,1023,192152,t[(t[u>>2]|0)+8>>2]|0,0);break}else{_=lU(i,t[e+12>>2]|0,1)|0;t[(t[a>>2]|0)+24>>2]=_;break}}if(((((t[u>>2]|0)!=0?(t[(t[u>>2]|0)+36>>2]|0)!=0:0)?(t[(t[u>>2]|0)+4>>2]|0)==1:0)?(Xl(t[(t[u>>2]|0)+8>>2]|0,190016)|0)!=0:0)?(Xl(t[(t[(t[u>>2]|0)+36>>2]|0)+8>>2]|0,t[46968]|0)|0)!=0:0){t[a>>2]=dx(t[f>>2]|0,t[u>>2]|0)|0;if(!(t[a>>2]|0)){t[n>>2]=0;v=t[n>>2]|0;s=r;return v|0}t[t[a>>2]>>2]=17;_=t[f>>2]|0;e=t[u>>2]|0;if(!(t[(t[u>>2]|0)+12>>2]|0)){bx(_,e,1023,192152,t[(t[u>>2]|0)+8>>2]|0,0);break}else{i=lU(_,t[e+12>>2]|0,0)|0;t[(t[a>>2]|0)+24>>2]=i;break}}if(((((t[u>>2]|0)!=0?(t[(t[u>>2]|0)+36>>2]|0)!=0:0)?(t[(t[u>>2]|0)+4>>2]|0)==1:0)?(Xl(t[(t[u>>2]|0)+8>>2]|0,190024)|0)!=0:0)?(Xl(t[(t[(t[u>>2]|0)+36>>2]|0)+8>>2]|0,t[46968]|0)|0)!=0:0){t[a>>2]=dx(t[f>>2]|0,t[u>>2]|0)|0;if(!(t[a>>2]|0)){t[n>>2]=0;v=t[n>>2]|0;s=r;return v|0}t[t[a>>2]>>2]=18;i=t[f>>2]|0;e=t[u>>2]|0;if(!(t[(t[u>>2]|0)+12>>2]|0)){bx(i,e,1023,192152,t[(t[u>>2]|0)+8>>2]|0,0);break}else{_=lU(i,t[e+12>>2]|0,0)|0;t[(t[a>>2]|0)+24>>2]=_;break}}if(((((t[u>>2]|0)!=0?(t[(t[u>>2]|0)+36>>2]|0)!=0:0)?(t[(t[u>>2]|0)+4>>2]|0)==1:0)?(Xl(t[(t[u>>2]|0)+8>>2]|0,189928)|0)!=0:0)?(Xl(t[(t[(t[u>>2]|0)+36>>2]|0)+8>>2]|0,t[46968]|0)|0)!=0:0){t[a>>2]=dx(t[f>>2]|0,t[u>>2]|0)|0;if(!(t[a>>2]|0)){t[n>>2]=0;v=t[n>>2]|0;s=r;return v|0}t[t[a>>2]>>2]=11;_=cF(t[u>>2]|0,192176)|0;t[(t[a>>2]|0)+8>>2]=_;do if(!(t[(t[a>>2]|0)+8>>2]|0))bx(t[f>>2]|0,t[u>>2]|0,1102,192184,0,0);else{HU(t[(t[a>>2]|0)+8>>2]|0);if(!(Vg(t[(t[a>>2]|0)+8>>2]|0,0)|0))break;bx(t[f>>2]|0,t[u>>2]|0,1100,192208,t[(t[a>>2]|0)+8>>2]|0,0)}while(0);if(t[(t[u>>2]|0)+12>>2]|0)bx(t[f>>2]|0,t[u>>2]|0,1103,192240,0,0);if(!(t[(t[(t[f>>2]|0)+24>>2]|0)+28>>2]|0)){_=WF(10)|0;t[(t[(t[f>>2]|0)+24>>2]|0)+28>>2]=_}_=t[f>>2]|0;if(!(t[(t[(t[f>>2]|0)+24>>2]|0)+28>>2]|0)){bx(_,t[u>>2]|0,1098,192264,0,0);t[a>>2]=0;break}t[o>>2]=ZF(t[(t[_+24>>2]|0)+28>>2]|0,t[(t[a>>2]|0)+8>>2]|0,t[a>>2]|0)|0;if((t[o>>2]|0)>=0)break;t[c>>2]=rO(t[(t[(t[f>>2]|0)+24>>2]|0)+28>>2]|0,t[(t[a>>2]|0)+8>>2]|0)|0;if(t[c>>2]|0){t[(t[a>>2]|0)+44>>2]=t[(t[c>>2]|0)+44>>2];t[(t[c>>2]|0)+44>>2]=t[a>>2];break}_=t[f>>2]|0;e=t[u>>2]|0;if(t[(t[a>>2]|0)+8>>2]|0)bx(_,e,1098,192304,t[(t[a>>2]|0)+8>>2]|0,0);else bx(_,e,1098,192336,0,0);t[a>>2]=0;break}if(((((t[u>>2]|0)!=0?(t[(t[u>>2]|0)+36>>2]|0)!=0:0)?(t[(t[u>>2]|0)+4>>2]|0)==1:0)?(Xl(t[(t[u>>2]|0)+8>>2]|0,192360)|0)!=0:0)?(Xl(t[(t[(t[u>>2]|0)+36>>2]|0)+8>>2]|0,t[46968]|0)|0)!=0:0){t[a>>2]=QU(t[f>>2]|0,t[u>>2]|0)|0;break}if(((((t[u>>2]|0)!=0?(t[(t[u>>2]|0)+36>>2]|0)!=0:0)?(t[(t[u>>2]|0)+4>>2]|0)==1:0)?(Xl(t[(t[u>>2]|0)+8>>2]|0,189888)|0)!=0:0)?(Xl(t[(t[(t[u>>2]|0)+36>>2]|0)+8>>2]|0,t[46968]|0)|0)!=0:0){t[a>>2]=$U(t[f>>2]|0,t[u>>2]|0)|0;break}if(((((t[u>>2]|0)!=0?(t[(t[u>>2]|0)+36>>2]|0)!=0:0)?(t[(t[u>>2]|0)+4>>2]|0)==1:0)?(Xl(t[(t[u>>2]|0)+8>>2]|0,189896)|0)!=0:0)?(Xl(t[(t[(t[u>>2]|0)+36>>2]|0)+8>>2]|0,t[46968]|0)|0)!=0:0){t[a>>2]=dx(t[f>>2]|0,t[u>>2]|0)|0;if(!(t[a>>2]|0)){t[n>>2]=0;v=t[n>>2]|0;s=r;return v|0}t[t[a>>2]>>2]=8;e=t[f>>2]|0;_=t[u>>2]|0;if(!(t[(t[u>>2]|0)+12>>2]|0)){bx(e,_,1023,192152,t[(t[u>>2]|0)+8>>2]|0,0);break}else{i=lU(e,t[_+12>>2]|0,0)|0;t[(t[a>>2]|0)+24>>2]=i;break}}do if((((t[u>>2]|0)!=0?(t[(t[u>>2]|0)+36>>2]|0)!=0:0)?(t[(t[u>>2]|0)+4>>2]|0)==1:0)?(Xl(t[(t[u>>2]|0)+8>>2]|0,190032)|0)!=0:0){if(!(Xl(t[(t[(t[u>>2]|0)+36>>2]|0)+8>>2]|0,t[46968]|0)|0))break;t[a>>2]=ez(t[f>>2]|0,t[u>>2]|0)|0;break e}while(0);do if(((t[u>>2]|0)!=0?(t[(t[u>>2]|0)+36>>2]|0)!=0:0)?(t[(t[u>>2]|0)+4>>2]|0)==1:0){if(!(Xl(t[(t[u>>2]|0)+8>>2]|0,189936)|0))break;if(!(Xl(t[(t[(t[u>>2]|0)+36>>2]|0)+8>>2]|0,t[46968]|0)|0))break;t[a>>2]=iz(t[f>>2]|0,t[u>>2]|0)|0;break e}while(0);do if((t[u>>2]|0)!=0?(t[(t[u>>2]|0)+36>>2]|0)!=0:0){if((t[(t[u>>2]|0)+4>>2]|0)!=1)break;if(!(Xl(t[(t[u>>2]|0)+8>>2]|0,189832)|0))break;if(!(Xl(t[(t[(t[u>>2]|0)+36>>2]|0)+8>>2]|0,t[46968]|0)|0))break;t[a>>2]=dx(t[f>>2]|0,t[u>>2]|0)|0;if(!(t[a>>2]|0)){t[n>>2]=0;v=t[n>>2]|0;s=r;return v|0}else{t[t[a>>2]>>2]=1;if(!(t[(t[u>>2]|0)+12>>2]|0))break e;bx(t[f>>2]|0,t[u>>2]|0,1055,192368,0,0);break e}}while(0);do if(t[u>>2]|0){if(!(t[(t[u>>2]|0)+36>>2]|0))break;if((t[(t[u>>2]|0)+4>>2]|0)!=1)break;if(!(Xl(t[(t[u>>2]|0)+8>>2]|0,190264)|0))break;if(!(Xl(t[(t[(t[u>>2]|0)+36>>2]|0)+8>>2]|0,t[46968]|0)|0))break;t[k>>2]=t[(t[f>>2]|0)+28>>2];t[b>>2]=t[(t[f>>2]|0)+24>>2];t[(t[f>>2]|0)+28>>2]=t[b>>2];t[l>>2]=Px(t[f>>2]|0,t[(t[u>>2]|0)+12>>2]|0)|0;if(t[b>>2]|0){t[(t[f>>2]|0)+24>>2]=t[b>>2];t[(t[f>>2]|0)+28>>2]=t[k>>2]}if(t[l>>2]|0){t[a>>2]=t[(t[l>>2]|0)+12>>2];break e}else{t[a>>2]=0;break e}}while(0);do if(t[u>>2]|0){if(!(t[(t[u>>2]|0)+36>>2]|0))break;if((t[(t[u>>2]|0)+4>>2]|0)!=1)break;if(!(Xl(t[(t[u>>2]|0)+8>>2]|0,189952)|0))break;if(!(Xl(t[(t[(t[u>>2]|0)+36>>2]|0)+8>>2]|0,t[46968]|0)|0))break;i=t[f>>2]|0;_=t[u>>2]|0;if(!(t[(t[f>>2]|0)+28>>2]|0)){bx(i,_,1063,192424,0,0);t[n>>2]=0;v=t[n>>2]|0;s=r;return v|0}t[a>>2]=dx(i,_)|0;if(!(t[a>>2]|0)){t[n>>2]=0;v=t[n>>2]|0;s=r;return v|0}t[t[a>>2]>>2]=13;_=cF(t[u>>2]|0,192176)|0;t[(t[a>>2]|0)+8>>2]=_;do if(!(t[(t[a>>2]|0)+8>>2]|0))bx(t[f>>2]|0,t[u>>2]|0,1062,192472,0,0);else{HU(t[(t[a>>2]|0)+8>>2]|0);if(!(Vg(t[(t[a>>2]|0)+8>>2]|0,0)|0))break;bx(t[f>>2]|0,t[u>>2]|0,1061,192496,t[(t[a>>2]|0)+8>>2]|0,0)}while(0);if(t[(t[u>>2]|0)+12>>2]|0)bx(t[f>>2]|0,t[u>>2]|0,1064,192536,0,0);if(!(t[(t[(t[f>>2]|0)+28>>2]|0)+28>>2]|0)){_=WF(10)|0;t[(t[(t[f>>2]|0)+28>>2]|0)+28>>2]=_}if(!(t[(t[(t[f>>2]|0)+28>>2]|0)+28>>2]|0)){bx(t[f>>2]|0,t[u>>2]|0,1060,192264,0,0);t[a>>2]=0;break e}if(!(t[(t[a>>2]|0)+8>>2]|0))break e;t[h>>2]=ZF(t[(t[(t[f>>2]|0)+28>>2]|0)+28>>2]|0,t[(t[a>>2]|0)+8>>2]|0,t[a>>2]|0)|0;if((t[h>>2]|0)>=0)break e;t[w>>2]=rO(t[(t[(t[f>>2]|0)+28>>2]|0)+28>>2]|0,t[(t[a>>2]|0)+8>>2]|0)|0;if(!(t[w>>2]|0)){bx(t[f>>2]|0,t[u>>2]|0,1060,192560,t[(t[a>>2]|0)+8>>2]|0,0);t[a>>2]=0;break e}else{t[(t[a>>2]|0)+44>>2]=t[(t[w>>2]|0)+44>>2];t[(t[w>>2]|0)+44>>2]=t[a>>2];break e}}while(0);do if(t[u>>2]|0){if(!(t[(t[u>>2]|0)+36>>2]|0))break;if((t[(t[u>>2]|0)+4>>2]|0)!=1)break;if(!(Xl(t[(t[u>>2]|0)+8>>2]|0,192608)|0))break;if(!(Xl(t[(t[(t[u>>2]|0)+36>>2]|0)+8>>2]|0,t[46968]|0)|0))break;_=t[f>>2]|0;i=t[u>>2]|0;if(!(t[(t[u>>2]|0)+12>>2]|0)){bx(_,i,1023,192616,0,0);t[a>>2]=0;break e}t[a>>2]=ez(_,i)|0;if(!(t[a>>2]|0))break e;do if(t[(t[a>>2]|0)+24>>2]|0){if(!(t[(t[(t[a>>2]|0)+24>>2]|0)+32>>2]|0))break;t[d>>2]=dx(t[f>>2]|0,t[u>>2]|0)|0;if(!(t[d>>2]|0))break;t[t[d>>2]>>2]=18;t[(t[d>>2]|0)+24>>2]=t[(t[a>>2]|0)+24>>2];t[(t[a>>2]|0)+24>>2]=t[d>>2]}while(0);t[d>>2]=dx(t[f>>2]|0,t[u>>2]|0)|0;if(t[d>>2]|0){t[t[d>>2]>>2]=3;t[(t[d>>2]|0)+32>>2]=t[(t[a>>2]|0)+24>>2];t[(t[a>>2]|0)+24>>2]=t[d>>2];break e}t[n>>2]=t[a>>2];v=t[n>>2]|0;s=r;return v|0}while(0);bx(t[f>>2]|0,t[u>>2]|0,1115,192632,t[(t[u>>2]|0)+8>>2]|0,0);t[a>>2]=0}while(0);t[n>>2]=t[a>>2];v=t[n>>2]|0;s=r;return v|0}function VU(e){e=e|0;var i=0,r=0,n=0,u=0,a=0,o=0,c=0;i=s;s=s+32|0;r=i+16|0;n=i+12|0;u=i+8|0;a=i+4|0;o=i;t[n>>2]=e;if(!(t[n>>2]|0)){t[r>>2]=-1;c=t[r>>2]|0;s=i;return c|0}if(f[(t[n>>2]|0)+50>>1]&1){t[r>>2]=1;c=t[r>>2]|0;s=i;return c|0}if(f[(t[n>>2]|0)+50>>1]&2){t[r>>2]=0;c=t[r>>2]|0;s=i;return c|0}e:do switch(t[t[n>>2]>>2]|0){case 16:case 13:case 12:case 11:case 10:case-1:{t[u>>2]=VU(t[(t[n>>2]|0)+24>>2]|0)|0;break}case 9:case 8:case 7:case 6:case 5:case 4:case 1:case 2:{t[u>>2]=0;break}case 3:case 0:{t[u>>2]=1;break}case 18:case 19:case 20:{t[o>>2]=t[(t[n>>2]|0)+24>>2];while(1){if(!(t[o>>2]|0))break;t[u>>2]=VU(t[o>>2]|0)|0;if((t[u>>2]|0)!=1)break e;t[o>>2]=t[(t[o>>2]|0)+32>>2]}t[r>>2]=1;c=t[r>>2]|0;s=i;return c|0}case 17:{t[a>>2]=t[(t[n>>2]|0)+24>>2];while(1){if(!(t[a>>2]|0))break;t[u>>2]=VU(t[a>>2]|0)|0;if(t[u>>2]|0)break e;t[a>>2]=t[(t[a>>2]|0)+32>>2]}t[u>>2]=0;break}default:{t[r>>2]=-1;c=t[r>>2]|0;s=i;return c|0}}while(0);if(!(t[u>>2]|0)){a=(t[n>>2]|0)+50|0;f[a>>1]=f[a>>1]|2}if((t[u>>2]|0)==1){a=(t[n>>2]|0)+50|0;f[a>>1]=f[a>>1]|1}t[r>>2]=t[u>>2];c=t[r>>2]|0;s=i;return c|0}function qU(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0;r=s;s=s+16|0;n=r+8|0;f=r+4|0;u=r;t[n>>2]=e;t[f>>2]=i;t[u>>2]=0;while(1){if(!(t[f>>2]|0)){a=5;break}t[u>>2]=TU(t[n>>2]|0,t[f>>2]|0)|0;if(t[u>>2]|0){a=5;break}t[f>>2]=t[(t[f>>2]|0)+32>>2]}if((a|0)==5){s=r;return t[u>>2]|0}return 0}function YU(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0;n=s;s=s+48|0;f=n;a=n+32|0;o=n+28|0;c=n+24|0;l=n+20|0;b=n+16|0;k=n+12|0;h=n+8|0;t[o>>2]=e;t[c>>2]=i;t[l>>2]=r;if((t[(t[c>>2]|0)+8>>2]|0)!=0?(Xl(t[(t[c>>2]|0)+8>>2]|0,t[(t[l>>2]|0)+8>>2]|0)|0)==0:0){t[a>>2]=0;
	w=t[a>>2]|0;s=n;return w|0}do if(t[(t[c>>2]|0)+12>>2]|0){r=t[(t[l>>2]|0)+36>>2]|0;if(!(u[t[(t[c>>2]|0)+12>>2]>>0]|0)){if(!r)break;t[a>>2]=0;w=t[a>>2]|0;s=n;return w|0}if((r|0)!=0?(Xl(t[(t[c>>2]|0)+12>>2]|0,t[(t[(t[l>>2]|0)+36>>2]|0)+8>>2]|0)|0)!=0:0)break;t[a>>2]=0;w=t[a>>2]|0;s=n;return w|0}while(0);if(!(t[(t[c>>2]|0)+40>>2]|0)){t[a>>2]=1;w=t[a>>2]|0;s=n;return w|0}t[c>>2]=t[(t[c>>2]|0)+40>>2];r=t[c>>2]|0;e:do if((t[t[c>>2]>>2]|0)==2){t[k>>2]=t[r+24>>2];while(1){if(!(t[k>>2]|0))break e;t[b>>2]=YU(t[o>>2]|0,t[k>>2]|0,t[l>>2]|0)|0;if((t[b>>2]|0)==1){d=17;break}if((t[b>>2]|0)<0){d=19;break}t[k>>2]=t[(t[k>>2]|0)+32>>2]}if((d|0)==17){t[a>>2]=0;w=t[a>>2]|0;s=n;return w|0}else if((d|0)==19){t[a>>2]=t[b>>2];w=t[a>>2]|0;s=n;return w|0}}else{if((t[r>>2]|0)!=17){i=t[33976]|0;e=t[33980]|0;t[f>>2]=189496;t[f+4>>2]=9070;yAi[i&511](e,189464,f);break}t[h>>2]=t[(t[c>>2]|0)+40>>2];while(1){if(!(t[h>>2]|0)){d=29;break}t[b>>2]=YU(t[o>>2]|0,t[h>>2]|0,t[l>>2]|0)|0;if((t[b>>2]|0)==1){d=25;break}if((t[b>>2]|0)<0){d=27;break}t[h>>2]=t[(t[h>>2]|0)+32>>2]}if((d|0)==25){t[a>>2]=1;w=t[a>>2]|0;s=n;return w|0}else if((d|0)==27){t[a>>2]=t[b>>2];w=t[a>>2]|0;s=n;return w|0}else if((d|0)==29){t[a>>2]=0;w=t[a>>2]|0;s=n;return w|0}}while(0);t[a>>2]=1;w=t[a>>2]|0;s=n;return w|0}function GU(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0;f=s;s=s+32|0;a=f;o=f+24|0;c=f+20|0;l=f+16|0;b=f+12|0;k=f+8|0;h=f+4|0;t[f+28>>2]=e;t[o>>2]=i;t[c>>2]=r;t[l>>2]=n;t[b>>2]=t[l>>2];t[k>>2]=t[c>>2];if(!(t[b>>2]|0)){c=t[v>>2]|0;t[a>>2]=t[o>>2];xe(c|0,189616,a|0)|0;s=f;return}if(!(t[k>>2]|0)){if((u[t[o>>2]>>0]|0|0)==35){s=f;return}c=t[v>>2]|0;t[a>>2]=t[o>>2];xe(c|0,189648,a|0)|0;if(!(t[b>>2]|0)){s=f;return}if(t[(t[b>>2]|0)+40>>2]|0){s=f;return}t[(t[b>>2]|0)+40>>2]=37;s=f;return}if((t[b>>2]|0)==0|(t[k>>2]|0)==0){c=t[v>>2]|0;t[a>>2]=t[o>>2];xe(c|0,189680,a|0)|0;if(!(t[b>>2]|0)){s=f;return}if(t[(t[b>>2]|0)+40>>2]|0){s=f;return}t[(t[b>>2]|0)+40>>2]=37;s=f;return}if((t[t[k>>2]>>2]|0)!=4){c=t[v>>2]|0;t[a>>2]=t[o>>2];xe(c|0,189712,a|0)|0;if(t[(t[b>>2]|0)+40>>2]|0){s=f;return}t[(t[b>>2]|0)+40>>2]=37;s=f;return}else{t[h>>2]=gx(t[b>>2]|0,t[k>>2]|0)|0;if(!(t[h>>2]|0)){s=f;return}t[(t[b>>2]|0)+112>>2]=t[h>>2];s=f;return}}function WU(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0;r=s;s=s+32|0;n=r+20|0;f=r+16|0;u=r+12|0;a=r+8|0;o=r+4|0;c=r;t[f>>2]=e;t[u>>2]=i;t[o>>2]=0;if((t[f>>2]|0)==0|(t[u>>2]|0)==0){t[n>>2]=0;l=t[n>>2]|0;s=r;return l|0}i=t[o>>2]|0;t[o>>2]=i+1;t[a>>2]=t[(t[u>>2]|0)+(i<<2)>>2];e:while(1){if(!(t[a>>2]|0)){b=14;break}if((t[(t[f>>2]|0)+4>>2]|0)==1?(t[t[a>>2]>>2]|0)==4:0){t[c>>2]=FU(0,t[a>>2]|0,t[f>>2]|0)|0;if((t[c>>2]|0)==1){b=8;break}}else b=9;do if((b|0)==9){b=0;if((t[(t[f>>2]|0)+4>>2]|0)!=3?(t[(t[f>>2]|0)+4>>2]|0)!=4:0)break;if((t[t[a>>2]>>2]|0)==3){b=12;break e}}while(0);i=t[o>>2]|0;t[o>>2]=i+1;t[a>>2]=t[(t[u>>2]|0)+(i<<2)>>2]}if((b|0)==8){t[n>>2]=1;l=t[n>>2]|0;s=r;return l|0}else if((b|0)==12){t[n>>2]=1;l=t[n>>2]|0;s=r;return l|0}else if((b|0)==14){t[n>>2]=0;l=t[n>>2]|0;s=r;return l|0}return 0}function KU(e){e=e|0;var i=0,r=0,n=0,f=0,a=0,o=0,c=0;i=s;s=s+16|0;r=i+8|0;n=i+4|0;f=i;t[n>>2]=e;t[f>>2]=t[(t[(t[n>>2]|0)+60>>2]|0)+20>>2];if((t[f>>2]|0)!=0?(t[(t[(t[n>>2]|0)+60>>2]|0)+24>>2]|0)!=0:0){while(1){if(!(u[t[f>>2]>>0]|0))break;t[f>>2]=(t[f>>2]|0)+1}while(1){if((t[f>>2]|0)!=(t[(t[(t[n>>2]|0)+60>>2]|0)+24>>2]|0))a=(u[t[f>>2]>>0]|0|0)==0;else a=0;o=t[f>>2]|0;if(!a)break;t[f>>2]=o+1}if((o|0)==(t[(t[(t[n>>2]|0)+60>>2]|0)+24>>2]|0))t[(t[(t[n>>2]|0)+60>>2]|0)+20>>2]=0;else t[(t[(t[n>>2]|0)+60>>2]|0)+20>>2]=t[f>>2];t[r>>2]=0;c=t[r>>2]|0;s=i;return c|0}t[(t[(t[n>>2]|0)+60>>2]|0)+20>>2]=0;t[(t[(t[n>>2]|0)+60>>2]|0)+24>>2]=0;t[r>>2]=0;c=t[r>>2]|0;s=i;return c|0}function XU(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0;r=s;s=s+16|0;n=r+8|0;f=r+4|0;u=r;t[n>>2]=e;t[f>>2]=i;t[u>>2]=0;while(1){if(!(t[f>>2]|0)){a=5;break}t[u>>2]=TU(t[n>>2]|0,t[f>>2]|0)|0;if(t[u>>2]|0){a=5;break}t[f>>2]=t[(t[f>>2]|0)+32>>2]}if((a|0)==5){s=r;return t[u>>2]|0}return 0}function ZU(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0;n=s;s=s+48|0;f=n+32|0;a=n+28|0;o=n+24|0;c=n+20|0;l=n+16|0;b=n+12|0;k=n+8|0;h=n+4|0;w=n;t[a>>2]=e;t[o>>2]=i;t[c>>2]=r;t[l>>2]=t[c>>2];if(((((t[o>>2]|0)!=0?(t[(t[o>>2]|0)+36>>2]|0)!=0:0)?(t[(t[o>>2]|0)+4>>2]|0)==1:0)?(Xl(t[(t[o>>2]|0)+8>>2]|0,192176)|0)!=0:0)?(Xl(t[(t[(t[o>>2]|0)+36>>2]|0)+8>>2]|0,t[46968]|0)|0)!=0:0)d=16;else d=6;do if((d|0)==6){if(((((t[o>>2]|0)!=0?(t[(t[o>>2]|0)+36>>2]|0)!=0:0)?(t[(t[o>>2]|0)+4>>2]|0)==1:0)?(Xl(t[(t[o>>2]|0)+8>>2]|0,193584)|0)!=0:0)?(Xl(t[(t[(t[o>>2]|0)+36>>2]|0)+8>>2]|0,t[46968]|0)|0)!=0:0){d=16;break}if(((((t[o>>2]|0)!=0?(t[(t[o>>2]|0)+36>>2]|0)!=0:0)?(t[(t[o>>2]|0)+4>>2]|0)==1:0)?(Xl(t[(t[o>>2]|0)+8>>2]|0,193592)|0)!=0:0)?(Xl(t[(t[(t[o>>2]|0)+36>>2]|0)+8>>2]|0,t[46968]|0)|0)!=0:0)d=16}while(0);do if(((d|0)==16?(t[t[c>>2]>>2]|0)!=4:0)?(t[t[c>>2]>>2]|0)!=9:0){t[l>>2]=dx(t[a>>2]|0,t[o>>2]|0)|0;if(!(t[l>>2]|0)){t[f>>2]=0;v=t[f>>2]|0;s=n;return v|0}t[(t[l>>2]|0)+28>>2]=t[c>>2];r=t[l>>2]|0;if(t[(t[a>>2]|0)+32>>2]&1){t[r>>2]=9;break}else{t[r>>2]=4;break}}while(0);if(((((t[o>>2]|0)!=0?(t[(t[o>>2]|0)+36>>2]|0)!=0:0)?(t[(t[o>>2]|0)+4>>2]|0)==1:0)?(Xl(t[(t[o>>2]|0)+8>>2]|0,192176)|0)!=0:0)?(Xl(t[(t[(t[o>>2]|0)+36>>2]|0)+8>>2]|0,t[46968]|0)|0)!=0:0){t[k>>2]=sF(t[o>>2]|0)|0;HU(t[k>>2]|0);do if(Vg(t[k>>2]|0,0)|0){r=t[a>>2]|0;i=t[o>>2]|0;if(t[(t[o>>2]|0)+20>>2]|0){bx(r,i,1019,193600,t[(t[(t[o>>2]|0)+20>>2]|0)+8>>2]|0,t[k>>2]|0);break}else{bx(r,i,1019,193640,t[k>>2]|0,0);break}}while(0);t[(t[l>>2]|0)+8>>2]=t[k>>2];t[k>>2]=cF(t[o>>2]|0,192672)|0;t[(t[l>>2]|0)+12>>2]=t[k>>2];if(((t[k>>2]|0)!=0?(t[(t[a>>2]|0)+32>>2]&1|0)!=0:0)?(Xl(t[k>>2]|0,193672)|0)!=0:0)bx(t[a>>2]|0,t[o>>2]|0,1122,193704,t[k>>2]|0,0);if((((t[k>>2]|0)!=0?(t[(t[a>>2]|0)+32>>2]&1|0)!=0:0)?(u[t[k>>2]>>0]|0|0)==0:0)?(Xl(t[(t[l>>2]|0)+8>>2]|0,193752)|0)!=0:0)bx(t[a>>2]|0,t[o>>2]|0,1121,193760,t[k>>2]|0,0)}else d=39;e:do if((d|0)==39){if(((((t[o>>2]|0)!=0?(t[(t[o>>2]|0)+36>>2]|0)!=0:0)?(t[(t[o>>2]|0)+4>>2]|0)==1:0)?(Xl(t[(t[o>>2]|0)+8>>2]|0,193584)|0)!=0:0)?(Xl(t[(t[(t[o>>2]|0)+36>>2]|0)+8>>2]|0,t[46968]|0)|0)!=0:0){t[(t[l>>2]|0)+8>>2]=0;t[(t[l>>2]|0)+12>>2]=0;if(!(t[(t[o>>2]|0)+12>>2]|0))break;k=rz(t[a>>2]|0,t[(t[o>>2]|0)+12>>2]|0,(t[t[c>>2]>>2]|0)==9&1)|0;t[(t[l>>2]|0)+40>>2]=k;break}if(((((t[o>>2]|0)!=0?(t[(t[o>>2]|0)+36>>2]|0)!=0:0)?(t[(t[o>>2]|0)+4>>2]|0)==1:0)?(Xl(t[(t[o>>2]|0)+8>>2]|0,193592)|0)!=0:0)?(Xl(t[(t[(t[o>>2]|0)+36>>2]|0)+8>>2]|0,t[46968]|0)|0)!=0:0){t[(t[l>>2]|0)+8>>2]=0;k=cF(t[o>>2]|0,192672)|0;t[(t[l>>2]|0)+12>>2]=k;if(!(t[(t[l>>2]|0)+12>>2]|0))bx(t[a>>2]|0,t[o>>2]|0,1057,193808,0,0);if(((t[(t[a>>2]|0)+32>>2]&1|0)!=0?(t[(t[l>>2]|0)+12>>2]|0)!=0:0)?(Xl(t[(t[l>>2]|0)+12>>2]|0,193672)|0)!=0:0)bx(t[a>>2]|0,t[o>>2]|0,1122,193704,t[(t[l>>2]|0)+12>>2]|0,0);if(!(t[(t[o>>2]|0)+12>>2]|0))break;k=rz(t[a>>2]|0,t[(t[o>>2]|0)+12>>2]|0,(t[t[c>>2]>>2]|0)==9&1)|0;t[(t[l>>2]|0)+40>>2]=k;break}if(((((t[o>>2]|0)!=0?(t[(t[o>>2]|0)+36>>2]|0)!=0:0)?(t[(t[o>>2]|0)+4>>2]|0)==1:0)?(Xl(t[(t[o>>2]|0)+8>>2]|0,190016)|0)!=0:0)?(Xl(t[(t[(t[o>>2]|0)+36>>2]|0)+8>>2]|0,t[46968]|0)|0)!=0:0){t[w>>2]=0;t[l>>2]=dx(t[a>>2]|0,t[o>>2]|0)|0;if(!(t[l>>2]|0)){t[f>>2]=0;v=t[f>>2]|0;s=n;return v|0}t[(t[l>>2]|0)+28>>2]=t[c>>2];t[t[l>>2]>>2]=17;if(!(t[(t[o>>2]|0)+12>>2]|0)){bx(t[a>>2]|0,t[o>>2]|0,1007,193840,0,0);break}t[h>>2]=t[(t[o>>2]|0)+12>>2];while(1){if(!(t[h>>2]|0))break e;t[b>>2]=ZU(t[a>>2]|0,t[h>>2]|0,t[l>>2]|0)|0;do if(t[b>>2]|0){k=t[b>>2]|0;if(!(t[w>>2]|0)){t[(t[l>>2]|0)+40>>2]=k;t[w>>2]=k;break}else{t[(t[w>>2]|0)+32>>2]=k;t[w>>2]=t[b>>2];break}}while(0);t[h>>2]=t[(t[h>>2]|0)+24>>2]}}if(!(t[o>>2]|0))m=193928;else m=t[(t[o>>2]|0)+8>>2]|0;bx(t[a>>2]|0,t[o>>2]|0,1006,193872,m,0);t[f>>2]=0;v=t[f>>2]|0;s=n;return v|0}while(0);do if((t[l>>2]|0)!=(t[c>>2]|0)){if(!(t[(t[c>>2]|0)+40>>2]|0)){t[(t[c>>2]|0)+40>>2]=t[l>>2];break}t[b>>2]=t[(t[c>>2]|0)+40>>2];while(1){if(!(t[(t[b>>2]|0)+32>>2]|0))break;t[b>>2]=t[(t[b>>2]|0)+32>>2]}t[(t[b>>2]|0)+32>>2]=t[l>>2]}while(0);t[f>>2]=t[l>>2];v=t[f>>2]|0;s=n;return v|0}function JU(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0;r=s;s=s+32|0;n=r+24|0;f=r+20|0;u=r+16|0;a=r+12|0;o=r+8|0;c=r+4|0;l=r;t[f>>2]=e;t[u>>2]=i;t[a>>2]=dx(t[f>>2]|0,t[u>>2]|0)|0;if(!(t[a>>2]|0)){t[n>>2]=0;b=t[n>>2]|0;s=r;return b|0}t[t[a>>2]>>2]=9;t[(t[a>>2]|0)+28>>2]=t[(t[f>>2]|0)+48>>2];t[c>>2]=t[(t[u>>2]|0)+12>>2];i=t[f>>2]|0;if(!(t[c>>2]|0)){bx(i,t[u>>2]|0,1004,193408,0,0);t[n>>2]=t[a>>2];b=t[n>>2]|0;s=r;return b|0}t[l>>2]=t[i+32>>2];i=(t[f>>2]|0)+32|0;t[i>>2]=t[i>>2]|1;t[o>>2]=ZU(t[f>>2]|0,t[c>>2]|0,t[a>>2]|0)|0;if(t[o>>2]|0)t[c>>2]=t[(t[c>>2]|0)+24>>2];if(t[c>>2]|0){t[o>>2]=jU(t[f>>2]|0,t[c>>2]|0)|0;e:do if(t[o>>2]|0)switch(t[t[o>>2]>>2]|0){case-1:{bx(t[f>>2]|0,t[u>>2]|0,1005,193496,0,0);break e;break}case 2:case 6:case 20:{bx(t[f>>2]|0,t[u>>2]|0,1003,193464,0,0);break e;break}case 9:case 19:case 18:case 17:case 14:case 15:case 16:case 10:case 12:case 13:case 11:case 8:case 7:case 5:case 4:case 3:case 1:case 0:{t[(t[a>>2]|0)+24>>2]=t[o>>2];t[(t[o>>2]|0)+28>>2]=t[a>>2];break e;break}default:break e}while(0);t[c>>2]=t[(t[c>>2]|0)+24>>2]}if(t[c>>2]|0)bx(t[f>>2]|0,t[u>>2]|0,1002,193544,0,0);t[(t[f>>2]|0)+32>>2]=t[l>>2];t[n>>2]=t[a>>2];b=t[n>>2]|0;s=r;return b|0}function QU(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0;r=s;s=s+64|0;n=r+56|0;f=r+52|0;u=r+48|0;a=r+44|0;o=r+40|0;c=r+36|0;l=r+32|0;b=r+28|0;k=r+24|0;h=r+20|0;w=r+16|0;d=r+12|0;v=r+8|0;m=r+4|0;_=r;t[f>>2]=e;t[u>>2]=i;t[a>>2]=0;t[l>>2]=0;t[k>>2]=cF(t[u>>2]|0,192784)|0;if(!(t[k>>2]|0)){bx(t[f>>2]|0,t[u>>2]|0,1110,193184,0,0);t[n>>2]=0;p=t[n>>2]|0;s=r;return p|0}HU(t[k>>2]|0);if(Vg(t[k>>2]|0,0)|0)bx(t[f>>2]|0,t[u>>2]|0,1112,193208,t[k>>2]|0,0);t[h>>2]=nz(t[f>>2]|0,t[u>>2]|0)|0;if(!(t[h>>2]|0))t[h>>2]=Yl(192832)|0;t[a>>2]=dx(t[f>>2]|0,t[u>>2]|0)|0;if(!(t[a>>2]|0)){pAi[t[135736>>2]&511](t[k>>2]|0);t[n>>2]=0;p=t[n>>2]|0;s=r;return p|0}t[t[a>>2]>>2]=5;t[(t[a>>2]|0)+8>>2]=t[k>>2];t[(t[a>>2]|0)+12>>2]=t[h>>2];t[b>>2]=rO(t[46942]|0,t[h>>2]|0)|0;do if(t[b>>2]|0){t[(t[a>>2]|0)+20>>2]=t[b>>2];if(!(t[(t[b>>2]|0)+8>>2]|0)){bx(t[f>>2]|0,t[u>>2]|0,1026,192912,t[h>>2]|0,0);break}t[d>>2]=MAi[t[(t[b>>2]|0)+8>>2]&511](t[(t[b>>2]|0)+4>>2]|0,t[(t[a>>2]|0)+8>>2]|0)|0;if((t[d>>2]|0)!=1){bx(t[f>>2]|0,t[u>>2]|0,1111,192968,t[(t[a>>2]|0)+8>>2]|0,t[h>>2]|0);break}if(Xl(t[h>>2]|0,187824)|0){if((Xl(t[(t[a>>2]|0)+8>>2]|0,193248)|0)==0?(Xl(t[(t[a>>2]|0)+8>>2]|0,193256)|0)==0:0)break;t[(t[f>>2]|0)+128>>2]=1}}else{bx(t[f>>2]|0,t[u>>2]|0,1116,192872,t[h>>2]|0,0);t[(t[a>>2]|0)+20>>2]=0}while(0);t[w>>2]=t[(t[u>>2]|0)+12>>2];e:while(1){if(!(t[w>>2]|0))break;if(!(Xl(t[(t[w>>2]|0)+8>>2]|0,190064)|0))break;d=(Xl(t[h>>2]|0,192832)|0)!=0;b=t[f>>2]|0;k=t[u>>2]|0;if(d){bx(b,k,1058,193264,t[h>>2]|0,0);t[w>>2]=t[(t[w>>2]|0)+24>>2];while(1){if(!(t[w>>2]|0))continue e;if(!(Xl(t[(t[w>>2]|0)+8>>2]|0,190064)|0))continue e;t[w>>2]=t[(t[w>>2]|0)+24>>2]}}t[c>>2]=dx(b,k)|0;if(t[c>>2]|0){t[t[c>>2]>>2]=6;d=cF(t[w>>2]|0,192176)|0;t[(t[c>>2]|0)+8>>2]=d;if(!(t[(t[c>>2]|0)+8>>2]|0))bx(t[f>>2]|0,t[u>>2]|0,1059,193320,0,0);d=sF(t[w>>2]|0)|0;t[(t[c>>2]|0)+16>>2]=d;d=t[c>>2]|0;if(!(t[l>>2]|0)){t[l>>2]=d;t[(t[a>>2]|0)+36>>2]=d}else{t[(t[l>>2]|0)+32>>2]=d;t[l>>2]=t[c>>2]}}t[w>>2]=t[(t[w>>2]|0)+24>>2]}if((t[w>>2]|0)!=0?(Xl(t[(t[w>>2]|0)+8>>2]|0,189848)|0)!=0:0){t[_>>2]=0;t[o>>2]=dx(t[f>>2]|0,t[u>>2]|0)|0;if(!(t[o>>2]|0)){t[n>>2]=t[a>>2];p=t[n>>2]|0;s=r;return p|0}t[t[o>>2]>>2]=2;t[v>>2]=t[(t[w>>2]|0)+12>>2];t[(t[a>>2]|0)+24>>2]=t[o>>2];if(!(t[v>>2]|0))bx(t[f>>2]|0,t[w>>2]|0,1030,193344,0,0);while(1){if(!(t[v>>2]|0))break;t[m>>2]=jU(t[f>>2]|0,t[v>>2]|0)|0;do if(t[m>>2]|0){u=t[m>>2]|0;if(!(t[_>>2]|0)){t[_>>2]=u;t[(t[o>>2]|0)+24>>2]=u;break}else{t[(t[_>>2]|0)+32>>2]=u;t[_>>2]=t[m>>2];break}}while(0);t[v>>2]=t[(t[v>>2]|0)+24>>2]}t[w>>2]=t[(t[w>>2]|0)+24>>2]}if(t[w>>2]|0)bx(t[f>>2]|0,t[w>>2]|0,1009,193368,t[(t[w>>2]|0)+8>>2]|0,0);t[n>>2]=t[a>>2];p=t[n>>2]|0;s=r;return p|0}function $U(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0;r=s;s=s+48|0;n=r+32|0;f=r+28|0;u=r+24|0;a=r+20|0;o=r+16|0;c=r+12|0;l=r+8|0;b=r+4|0;k=r;t[f>>2]=e;t[u>>2]=i;t[a>>2]=0;t[o>>2]=0;t[b>>2]=0;t[a>>2]=dx(t[f>>2]|0,t[u>>2]|0)|0;if(!(t[a>>2]|0)){t[n>>2]=0;h=t[n>>2]|0;s=r;return h|0}t[t[a>>2]>>2]=7;t[c>>2]=cF(t[u>>2]|0,192784)|0;do if(t[c>>2]|0){HU(t[c>>2]|0);if(Vg(t[c>>2]|0,0)|0)bx(t[f>>2]|0,t[u>>2]|0,1112,192792,t[c>>2]|0,0);t[l>>2]=nz(t[f>>2]|0,t[u>>2]|0)|0;if(!(t[l>>2]|0))t[l>>2]=Yl(192832)|0;t[(t[a>>2]|0)+8>>2]=t[c>>2];t[(t[a>>2]|0)+12>>2]=t[l>>2];t[o>>2]=rO(t[46942]|0,t[l>>2]|0)|0;if(!(t[o>>2]|0)){bx(t[f>>2]|0,t[u>>2]|0,1116,192872,t[l>>2]|0,0);t[(t[a>>2]|0)+20>>2]=0;break}t[(t[a>>2]|0)+20>>2]=t[o>>2];if(!(t[(t[o>>2]|0)+8>>2]|0)){bx(t[f>>2]|0,t[u>>2]|0,1026,192912,t[l>>2]|0,0);break}t[b>>2]=MAi[t[(t[o>>2]|0)+8>>2]&511](t[(t[o>>2]|0)+4>>2]|0,t[(t[a>>2]|0)+8>>2]|0)|0;if((t[b>>2]|0)!=1)bx(t[f>>2]|0,t[u>>2]|0,1111,192968,t[(t[a>>2]|0)+8>>2]|0,t[l>>2]|0)}while(0);do if(!(t[(t[u>>2]|0)+12>>2]|0)){l=Yl(188112)|0;t[(t[a>>2]|0)+16>>2]=l}else{if(!((t[(t[(t[u>>2]|0)+12>>2]|0)+4>>2]|0)!=3?(t[(t[(t[u>>2]|0)+12>>2]|0)+4>>2]|0)!=4:0))w=18;if((w|0)==18?(t[(t[(t[u>>2]|0)+12>>2]|0)+24>>2]|0)==0:0){if(!(t[a>>2]|0))break;l=sF(t[u>>2]|0)|0;t[(t[a>>2]|0)+16>>2]=l;if(!(t[(t[a>>2]|0)+16>>2]|0)){bx(t[f>>2]|0,t[u>>2]|0,1120,193080,0,0);break}if(!(t[o>>2]|0))break;if(!((t[b>>2]|0)==1?(t[(t[o>>2]|0)+12>>2]|0)!=0:0))break;t[k>>2]=0;t[b>>2]=RAi[t[(t[o>>2]|0)+12>>2]&511](t[(t[o>>2]|0)+4>>2]|0,t[(t[a>>2]|0)+8>>2]|0,t[(t[a>>2]|0)+16>>2]|0,k,t[u>>2]|0)|0;if((t[b>>2]|0)!=1){bx(t[f>>2]|0,t[u>>2]|0,1051,193112,t[(t[a>>2]|0)+16>>2]|0,t[(t[a>>2]|0)+8>>2]|0);break}if(!(t[k>>2]|0))break;t[(t[a>>2]|0)+36>>2]=t[k>>2];break}bx(t[f>>2]|0,t[u>>2]|0,1108,193024,0,0)}while(0);t[n>>2]=t[a>>2];h=t[n>>2]|0;s=r;return h|0}function ez(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0;r=s;s=s+64|0;n=r;f=r+28|0;u=r+24|0;a=r+20|0;o=r+16|0;c=r+12|0;l=r+8|0;b=r+4|0;k=r+32|0;t[u>>2]=e;t[a>>2]=i;t[o>>2]=0;t[c>>2]=0;t[o>>2]=dx(t[u>>2]|0,t[a>>2]|0)|0;if(!(t[o>>2]|0)){t[f>>2]=0;h=t[f>>2]|0;s=r;return h|0}t[t[o>>2]>>2]=19;if(!(t[(t[u>>2]|0)+56>>2]|0)){i=WF(10)|0;t[(t[u>>2]|0)+56>>2]=i}if(t[(t[u>>2]|0)+56>>2]|0){i=(t[u>>2]|0)+52|0;e=t[i>>2]|0;t[i>>2]=e+1;t[n>>2]=e;SY(k,32,192704,n)|0;if((ZF(t[(t[u>>2]|0)+56>>2]|0,k,t[o>>2]|0)|0)<0)bx(t[u>>2]|0,t[a>>2]|0,1045,192720,k,0)}else lx(t[u>>2]|0,192680);t[b>>2]=t[(t[a>>2]|0)+12>>2];if(!(t[b>>2]|0))bx(t[u>>2]|0,t[a>>2]|0,1048,192752,0,0);while(1){if(!(t[b>>2]|0))break;if(((((t[b>>2]|0)!=0?(t[(t[b>>2]|0)+36>>2]|0)!=0:0)?(t[(t[b>>2]|0)+4>>2]|0)==1:0)?(Xl(t[(t[b>>2]|0)+8>>2]|0,189864)|0)!=0:0)?(Xl(t[(t[(t[b>>2]|0)+36>>2]|0)+8>>2]|0,t[46968]|0)|0)!=0:0)t[l>>2]=zU(t[u>>2]|0,t[b>>2]|0)|0;else t[l>>2]=jU(t[u>>2]|0,t[b>>2]|0)|0;do if(t[l>>2]|0){t[(t[l>>2]|0)+28>>2]=t[o>>2];a=t[l>>2]|0;if(!(t[c>>2]|0)){t[c>>2]=a;t[(t[o>>2]|0)+24>>2]=a;break}else{t[(t[c>>2]|0)+32>>2]=a;t[c>>2]=t[l>>2];break}}while(0);t[b>>2]=t[(t[b>>2]|0)+24>>2]}t[f>>2]=t[o>>2];h=t[f>>2]|0;s=r;return h|0}function iz(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0;r=s;s=s+48|0;n=r+36|0;f=r+32|0;u=r+28|0;a=r+24|0;o=r+20|0;c=r+16|0;l=r+12|0;b=r+8|0;k=r+4|0;h=r;t[f>>2]=e;t[u>>2]=i;t[b>>2]=0;t[a>>2]=t[(t[u>>2]|0)+52>>2];if(t[a>>2]|0){t[h>>2]=dx(t[f>>2]|0,t[u>>2]|0)|0;if(!(t[h>>2]|0)){t[n>>2]=0;w=t[n>>2]|0;s=r;return w|0}t[t[h>>2]>>2]=12;if(!(t[(t[a>>2]|0)+12>>2]|0)){t[o>>2]=eF(t[(t[a>>2]|0)+8>>2]|0)|0;if(!(t[o>>2]|0)){bx(t[f>>2]|0,t[u>>2]|0,1031,188056,t[(t[f>>2]|0)+68>>2]|0,0);t[n>>2]=0;w=t[n>>2]|0;s=r;return w|0}t[l>>2]=cF(t[o>>2]|0,192672)|0;if(!(t[l>>2]|0)){t[c>>2]=t[u>>2];while(1){if(!(t[c>>2]|0))break;if((t[(t[c>>2]|0)+4>>2]|0)!=1)break;t[l>>2]=cF(t[c>>2]|0,192672)|0;if(t[l>>2]|0)break;t[c>>2]=t[(t[c>>2]|0)+20>>2]}if(t[l>>2]|0){_F(t[o>>2]|0,192672,t[l>>2]|0)|0;t[b>>2]=1;pAi[t[135736>>2]&511](t[l>>2]|0)}}else pAi[t[135736>>2]&511](t[l>>2]|0);t[k>>2]=t[(t[f>>2]|0)+32>>2];l=(t[f>>2]|0)+32|0;t[l>>2]=t[l>>2]|128;l=hx(t[f>>2]|0,t[o>>2]|0)|0;t[(t[a>>2]|0)+16>>2]=l;t[(t[f>>2]|0)+32>>2]=t[k>>2];if(((t[(t[a>>2]|0)+16>>2]|0)!=0?(t[(t[(t[a>>2]|0)+16>>2]|0)+4>>2]|0)!=0:0)?(t[(t[a>>2]|0)+12>>2]=t[(t[(t[(t[a>>2]|0)+16>>2]|0)+4>>2]|0)+12>>2],(t[(t[(t[(t[a>>2]|0)+16>>2]|0)+4>>2]|0)+28>>2]|0)!=0):0)fz(t[f>>2]|0,t[(t[(t[a>>2]|0)+16>>2]|0)+4>>2]|0)|0;if((t[b>>2]|0)==1)mF(t[o>>2]|0,192672)|0}t[(t[h>>2]|0)+24>>2]=t[(t[a>>2]|0)+12>>2]}else t[h>>2]=0;t[n>>2]=t[h>>2];w=t[n>>2]|0;s=r;return w|0}function rz(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0;n=s;s=s+32|0;f=n+28|0;u=n+24|0;a=n+20|0;o=n+16|0;c=n+12|0;l=n+8|0;b=n+4|0;k=n;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;t[b>>2]=0;if(((((t[a>>2]|0)!=0?(t[(t[a>>2]|0)+36>>2]|0)!=0:0)?(t[(t[a>>2]|0)+4>>2]|0)==1:0)?(Xl(t[(t[a>>2]|0)+8>>2]|0,189848)|0)!=0:0)?(Xl(t[(t[(t[a>>2]|0)+36>>2]|0)+8>>2]|0,t[46968]|0)|0)!=0:0){if(t[(t[a>>2]|0)+24>>2]|0)bx(t[u>>2]|0,t[a>>2]|0,1029,193968,0,0);r=t[u>>2]|0;i=t[a>>2]|0;if(!(t[(t[a>>2]|0)+12>>2]|0)){bx(r,i,1027,193344,0,0);t[f>>2]=0;h=t[f>>2]|0;s=n;return h|0}t[c>>2]=dx(r,i)|0;if(!(t[c>>2]|0)){t[f>>2]=0;h=t[f>>2]|0;s=n;return h|0}t[t[c>>2]>>2]=2;t[k>>2]=t[(t[a>>2]|0)+12>>2];while(1){if(!(t[k>>2]|0))break;t[l>>2]=dx(t[u>>2]|0,t[k>>2]|0)|0;if(!(t[l>>2]|0))break;i=t[l>>2]|0;if(t[o>>2]|0)t[i>>2]=9;else t[i>>2]=4;if(ZU(t[u>>2]|0,t[k>>2]|0,t[l>>2]|0)|0){i=t[l>>2]|0;if(!(t[b>>2]|0))t[(t[c>>2]|0)+24>>2]=i;else t[(t[b>>2]|0)+32>>2]=i;t[b>>2]=t[l>>2]}t[k>>2]=t[(t[k>>2]|0)+24>>2]}t[f>>2]=t[c>>2];h=t[f>>2]|0;s=n;return h|0}bx(t[u>>2]|0,t[a>>2]|0,1028,193936,0,0);t[f>>2]=0;h=t[f>>2]|0;s=n;return h|0}function nz(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,a=0,o=0,c=0,l=0;r=s;s=s+32|0;n=r+16|0;f=r+8|0;a=r+4|0;o=r;t[r+12>>2]=e;t[f>>2]=i;if(!(t[f>>2]|0)){t[n>>2]=0;c=t[n>>2]|0;s=r;return c|0}if(((((t[f>>2]|0)!=0?(t[(t[f>>2]|0)+36>>2]|0)!=0:0)?(t[(t[f>>2]|0)+4>>2]|0)==1:0)?(Xl(t[(t[f>>2]|0)+8>>2]|0,192360)|0)!=0:0)?(Xl(t[(t[(t[f>>2]|0)+36>>2]|0)+8>>2]|0,t[46968]|0)|0)!=0:0)l=13;else l=8;if((((((l|0)==8?(t[f>>2]|0)!=0:0)?(t[(t[f>>2]|0)+36>>2]|0)!=0:0)?(t[(t[f>>2]|0)+4>>2]|0)==1:0)?(Xl(t[(t[f>>2]|0)+8>>2]|0,189888)|0)!=0:0)?(Xl(t[(t[(t[f>>2]|0)+36>>2]|0)+8>>2]|0,t[46968]|0)|0)!=0:0)l=13;if((l|0)==13?(t[a>>2]=cF(t[f>>2]|0,193160)|0,(t[a>>2]|0)!=0):0){if(!(u[t[a>>2]>>0]|0)){pAi[t[135736>>2]&511](t[a>>2]|0);t[n>>2]=0;c=t[n>>2]|0;s=r;return c|0}t[o>>2]=qA(t[a>>2]|0,193176)|0;if(!(t[o>>2]|0)){t[n>>2]=t[a>>2];c=t[n>>2]|0;s=r;return c|0}else{pAi[t[135736>>2]&511](t[a>>2]|0);t[n>>2]=t[o>>2];c=t[n>>2]|0;s=r;return c|0}}t[f>>2]=t[(t[f>>2]|0)+20>>2];while(1){if(!(t[f>>2]|0)){l=29;break}if((t[(t[f>>2]|0)+4>>2]|0)!=1){l=29;break}t[a>>2]=cF(t[f>>2]|0,193160)|0;if(t[a>>2]|0)break;t[f>>2]=t[(t[f>>2]|0)+20>>2]}if((l|0)==29){t[n>>2]=0;c=t[n>>2]|0;s=r;return c|0}if(!(u[t[a>>2]>>0]|0)){pAi[t[135736>>2]&511](t[a>>2]|0);t[n>>2]=0;c=t[n>>2]|0;s=r;return c|0}t[o>>2]=qA(t[a>>2]|0,193176)|0;if(!(t[o>>2]|0)){t[n>>2]=t[a>>2];c=t[n>>2]|0;s=r;return c|0}else{pAi[t[135736>>2]&511](t[a>>2]|0);t[n>>2]=t[o>>2];c=t[n>>2]|0;s=r;return c|0}return 0}function fz(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0;r=s;s=s+16|0;n=r+8|0;f=r+4|0;u=r;t[f>>2]=e;t[u>>2]=i;if(!((t[f>>2]|0)==0|(t[u>>2]|0)==0)?(t[(t[f>>2]|0)+24>>2]|0)!=0:0){if(!(t[(t[u>>2]|0)+28>>2]|0)){t[n>>2]=0;a=t[n>>2]|0;s=r;return a|0}if(!(t[(t[(t[f>>2]|0)+24>>2]|0)+28>>2]|0)){i=WF(10)|0;t[(t[(t[f>>2]|0)+24>>2]|0)+28>>2]=i}if(!(t[(t[(t[f>>2]|0)+24>>2]|0)+28>>2]|0)){bx(t[f>>2]|0,0,1098,192264,0,0);t[n>>2]=-1;a=t[n>>2]|0;s=r;return a|0}else{aO(t[(t[u>>2]|0)+28>>2]|0,386,t[f>>2]|0);t[n>>2]=0;a=t[n>>2]|0;s=r;return a|0}}t[n>>2]=-1;a=t[n>>2]|0;s=r;return a|0}function tz(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0;n=s;s=s+32|0;u=n+24|0;a=n+20|0;o=n+16|0;c=n+12|0;l=n+8|0;b=n+4|0;k=n;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;t[c>>2]=t[a>>2];t[l>>2]=t[u>>2];u=(t[l>>2]|0)+50|0;f[u>>1]=f[u>>1]|256;t[b>>2]=ZF(t[(t[(t[c>>2]|0)+24>>2]|0)+28>>2]|0,t[o>>2]|0,t[l>>2]|0)|0;if((t[b>>2]|0)>=0){s=n;return}t[k>>2]=rO(t[(t[(t[c>>2]|0)+24>>2]|0)+28>>2]|0,t[(t[l>>2]|0)+8>>2]|0)|0;if(t[k>>2]|0){t[(t[l>>2]|0)+44>>2]=t[(t[k>>2]|0)+44>>2];t[(t[k>>2]|0)+44>>2]=t[l>>2];s=n;return}k=t[c>>2]|0;if(t[(t[l>>2]|0)+8>>2]|0){bx(k,0,1098,192304,t[(t[l>>2]|0)+8>>2]|0,0);s=n;return}else{bx(k,0,1098,192336,0,0);s=n;return}}function uz(){return 0}function az(){var e=0,i=0,r=0;e=s;s=s+16|0;i=e;do if(!(t[49266]|0)){r=Qc()|0;t[49268]=r;if(!r){t[i>>2]=0;break}else{el(t[49268]|0);t[49270]=bi(0)|0;vY(197080)|0;t[49266]=1;il(t[49268]|0);t[i>>2]=1;break}}else t[i>>2]=1;while(0);s=e;return t[i>>2]|0}function oz(){var e=0,i=0;e=s;s=s+16|0;i=e;if(!(t[49266]|0))az()|0;el(t[49268]|0);t[i>>2]=vY(197080)|0;il(t[49268]|0);s=e;return t[i>>2]|0}function cz(){var e=0;e=s;if(!(t[49266]|0)){s=e;return}$c(t[49268]|0);t[49266]=0;s=e;return}function lz(){var e=0,i=0,r=0,n=0,f=0;e=s;s=s+16|0;i=e+4|0;r=e;if((t[49266]|0)==0?(az()|0)==0:0){t[i>>2]=0;n=t[i>>2]|0;s=e;return n|0}t[r>>2]=gAi[t[135744>>2]&511](32)|0;do if(t[r>>2]|0){t[t[r>>2]>>2]=1;t[(t[r>>2]|0)+28>>2]=0;t[(t[r>>2]|0)+8>>2]=128;t[(t[r>>2]|0)+12>>2]=0;f=gAi[t[135744>>2]&511](2560)|0;t[(t[r>>2]|0)+4>>2]=f;t[(t[r>>2]|0)+16>>2]=0;t[(t[r>>2]|0)+20>>2]=0;if(!(t[(t[r>>2]|0)+4>>2]|0)){pAi[t[135736>>2]&511](t[r>>2]|0);break}VY(t[(t[r>>2]|0)+4>>2]|0,0,2560)|0;f=oz()|0;t[(t[r>>2]|0)+24>>2]=f;t[i>>2]=t[r>>2];n=t[i>>2]|0;s=e;return n|0}while(0);t[i>>2]=0;n=t[i>>2]|0;s=e;return n|0}function sz(e){e=e|0;var i=0,r=0,n=0,f=0;i=s;s=s+16|0;r=i+4|0;n=i;t[n>>2]=e;if((t[49266]|0)==0?(az()|0)==0:0)t[r>>2]=-1;else f=4;do if((f|0)==4)if(!(t[n>>2]|0)){t[r>>2]=-1;break}else{el(t[49268]|0);e=t[n>>2]|0;t[e>>2]=(t[e>>2]|0)+1;il(t[49268]|0);t[r>>2]=0;break}while(0);s=i;return t[r>>2]|0}function bz(e){e=e|0;var i=0,r=0,n=0,f=0,u=0,a=0,o=0,c=0;i=s;s=s+32|0;r=i+24|0;n=i+20|0;f=i+16|0;u=i+12|0;a=i+8|0;o=i+4|0;c=i;t[r>>2]=e;t[a>>2]=0;if(!(t[r>>2]|0)){s=i;return}if((t[49266]|0)==0?(az()|0)==0:0){s=i;return}el(t[49268]|0);e=t[r>>2]|0;t[e>>2]=(t[e>>2]|0)+-1;e=(t[t[r>>2]>>2]|0)>0;il(t[49268]|0);if(e){s=i;return}if(t[(t[r>>2]|0)+20>>2]|0)bz(t[(t[r>>2]|0)+20>>2]|0);if(t[(t[r>>2]|0)+4>>2]|0){t[n>>2]=0;while(1){if((t[n>>2]|0)>>>0>=(t[(t[r>>2]|0)+8>>2]|0)>>>0)break;if((t[(t[r>>2]|0)+12>>2]|0)>>>0<=0)break;t[f>>2]=(t[(t[r>>2]|0)+4>>2]|0)+((t[n>>2]|0)*20|0);e:do if(t[(t[f>>2]|0)+12>>2]|0){t[a>>2]=1;while(1){if(!(t[f>>2]|0))break e;t[u>>2]=t[t[f>>2]>>2];if(!(t[a>>2]|0))pAi[t[135736>>2]&511](t[f>>2]|0);e=(t[r>>2]|0)+12|0;t[e>>2]=(t[e>>2]|0)+-1;t[a>>2]=0;t[f>>2]=t[u>>2]}}while(0);t[n>>2]=(t[n>>2]|0)+1}pAi[t[135736>>2]&511](t[(t[r>>2]|0)+4>>2]|0)}t[o>>2]=t[(t[r>>2]|0)+16>>2];while(1){if(!(t[o>>2]|0))break;t[c>>2]=t[t[o>>2]>>2];pAi[t[135736>>2]&511](t[o>>2]|0);t[o>>2]=t[c>>2]}pAi[t[135736>>2]&511](t[r>>2]|0);s=i;return}function kz(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0,S=0,g=0,y=0;n=s;s=s+64|0;f=n+48|0;u=n+44|0;a=n+40|0;o=n+36|0;c=n+32|0;l=n+28|0;b=n+24|0;k=n+20|0;h=n+16|0;w=n+12|0;d=n+8|0;v=n+4|0;m=n;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;t[b>>2]=0;if((t[u>>2]|0)==0|(t[a>>2]|0)==0){t[f>>2]=0;_=t[f>>2]|0;s=n;return _|0}if((t[o>>2]|0)<0)t[d>>2]=HY(t[a>>2]|0)|0;else t[d>>2]=t[o>>2];o=t[d>>2]|0;if((t[(t[u>>2]|0)+28>>2]|0)>>>0>0){if((t[d>>2]|0)>>>0>1073741823?1:o>>>0>=(t[(t[u>>2]|0)+28>>2]|0)>>>0)p=9}else if(o>>>0>1073741823)p=9;if((p|0)==9){t[f>>2]=0;_=t[f>>2]|0;s=n;return _|0}o=t[a>>2]|0;r=t[d>>2]|0;i=t[(t[u>>2]|0)+24>>2]|0;if((t[(t[u>>2]|0)+8>>2]|0)==128)E=vz(o,r,i)|0;else E=mz(o,r,i)|0;t[l>>2]=E;t[c>>2]=((t[l>>2]|0)>>>0)%((t[(t[u>>2]|0)+8>>2]|0)>>>0)|0;if(t[(t[(t[u>>2]|0)+4>>2]|0)+((t[c>>2]|0)*20|0)+12>>2]|0){t[h>>2]=(t[(t[u>>2]|0)+4>>2]|0)+((t[c>>2]|0)*20|0);while(1){S=(t[(t[h>>2]|0)+16>>2]|0)==(t[l>>2]|0);if(!(t[t[h>>2]>>2]|0))break;if((S?(t[(t[h>>2]|0)+8>>2]|0)==(t[d>>2]|0):0)?(AY(t[(t[h>>2]|0)+4>>2]|0,t[a>>2]|0,t[d>>2]|0)|0)==0:0){p=20;break}t[b>>2]=(t[b>>2]|0)+1;t[h>>2]=t[t[h>>2]>>2]}if((p|0)==20){t[f>>2]=t[(t[h>>2]|0)+4>>2];_=t[f>>2]|0;s=n;return _|0}if((S?(t[(t[h>>2]|0)+8>>2]|0)==(t[d>>2]|0):0)?(AY(t[(t[h>>2]|0)+4>>2]|0,t[a>>2]|0,t[d>>2]|0)|0)==0:0){t[f>>2]=t[(t[h>>2]|0)+4>>2];_=t[f>>2]|0;s=n;return _|0}}else t[h>>2]=0;if(t[(t[u>>2]|0)+20>>2]|0){if((t[(t[u>>2]|0)+8>>2]|0)==128?(t[(t[(t[u>>2]|0)+20>>2]|0)+8>>2]|0)!=128:0)p=31;else p=29;do if((p|0)==29){if((t[(t[u>>2]|0)+8>>2]|0)!=128?(t[(t[(t[u>>2]|0)+20>>2]|0)+8>>2]|0)==128:0){p=31;break}t[v>>2]=t[l>>2]}while(0);if((p|0)==31){S=t[a>>2]|0;E=t[d>>2]|0;i=t[(t[(t[u>>2]|0)+20>>2]|0)+24>>2]|0;if((t[(t[(t[u>>2]|0)+20>>2]|0)+8>>2]|0)==128)g=vz(S,E,i)|0;else g=mz(S,E,i)|0;t[v>>2]=g}t[c>>2]=((t[v>>2]|0)>>>0)%((t[(t[(t[u>>2]|0)+20>>2]|0)+8>>2]|0)>>>0)|0;if(t[(t[(t[(t[u>>2]|0)+20>>2]|0)+4>>2]|0)+((t[c>>2]|0)*20|0)+12>>2]|0){t[m>>2]=(t[(t[(t[u>>2]|0)+20>>2]|0)+4>>2]|0)+((t[c>>2]|0)*20|0);while(1){y=(t[(t[m>>2]|0)+16>>2]|0)==(t[v>>2]|0);if(!(t[t[m>>2]>>2]|0))break;if((y?(t[(t[m>>2]|0)+8>>2]|0)==(t[d>>2]|0):0)?(AY(t[(t[m>>2]|0)+4>>2]|0,t[a>>2]|0,t[d>>2]|0)|0)==0:0){p=42;break}t[b>>2]=(t[b>>2]|0)+1;t[m>>2]=t[t[m>>2]>>2]}if((p|0)==42){t[f>>2]=t[(t[m>>2]|0)+4>>2];_=t[f>>2]|0;s=n;return _|0}if((y?(t[(t[m>>2]|0)+8>>2]|0)==(t[d>>2]|0):0)?(AY(t[(t[m>>2]|0)+4>>2]|0,t[a>>2]|0,t[d>>2]|0)|0)==0:0){t[f>>2]=t[(t[m>>2]|0)+4>>2];_=t[f>>2]|0;s=n;return _|0}}t[c>>2]=((t[l>>2]|0)>>>0)%((t[(t[u>>2]|0)+8>>2]|0)>>>0)|0}t[w>>2]=_z(t[u>>2]|0,t[a>>2]|0,t[d>>2]|0)|0;if(!(t[w>>2]|0)){t[f>>2]=0;_=t[f>>2]|0;s=n;return _|0}if(t[h>>2]|0){t[k>>2]=gAi[t[135744>>2]&511](20)|0;if(!(t[k>>2]|0)){t[f>>2]=0;_=t[f>>2]|0;s=n;return _|0}}else t[k>>2]=(t[(t[u>>2]|0)+4>>2]|0)+((t[c>>2]|0)*20|0);t[(t[k>>2]|0)+4>>2]=t[w>>2];t[(t[k>>2]|0)+8>>2]=t[d>>2];t[t[k>>2]>>2]=0;t[(t[k>>2]|0)+12>>2]=1;t[(t[k>>2]|0)+16>>2]=t[l>>2];if(t[h>>2]|0)t[t[h>>2]>>2]=t[k>>2];k=(t[u>>2]|0)+12|0;t[k>>2]=(t[k>>2]|0)+1;if(((t[b>>2]|0)>>>0>3?(t[(t[u>>2]|0)+8>>2]|0)>>>0<=2730:0)?(pz(t[u>>2]|0,(t[(t[u>>2]|0)+8>>2]|0)*6|0)|0)!=0:0){t[f>>2]=0;_=t[f>>2]|0;s=n;return _|0}t[f>>2]=t[w>>2];_=t[f>>2]|0;s=n;return _|0}function hz(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0,S=0,g=0,y=0,F=0,O=0,A=0,M=0,R=0;n=s;s=s+64|0;f=n+56|0;u=n+52|0;a=n+48|0;o=n+44|0;c=n+40|0;l=n+36|0;b=n+32|0;k=n+28|0;h=n+24|0;w=n+20|0;d=n+16|0;v=n+12|0;m=n+8|0;_=n+4|0;p=n;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;t[b>>2]=0;if((t[u>>2]|0)==0|(t[o>>2]|0)==0){t[f>>2]=0;E=t[f>>2]|0;s=n;return E|0}if(!(t[a>>2]|0)){t[f>>2]=kz(t[u>>2]|0,t[o>>2]|0,-1)|0;E=t[f>>2]|0;s=n;return E|0}r=HY(t[o>>2]|0)|0;t[d>>2]=r;t[m>>2]=r;t[v>>2]=HY(t[a>>2]|0)|0;t[d>>2]=(t[d>>2]|0)+(1+(t[v>>2]|0));r=(t[(t[u>>2]|0)+8>>2]|0)==128;do if(!(t[a>>2]|0)){i=t[o>>2]|0;e=t[m>>2]|0;S=t[(t[u>>2]|0)+24>>2]|0;if(r){g=vz(i,e,S)|0;break}else{g=mz(i,e,S)|0;break}}else{S=t[a>>2]|0;e=t[v>>2]|0;i=t[o>>2]|0;y=t[m>>2]|0;F=t[(t[u>>2]|0)+24>>2]|0;if(r){g=Ez(S,e,i,y,F)|0;break}else{g=Sz(S,e,i,y,F)|0;break}}while(0);t[c>>2]=g;t[l>>2]=((t[c>>2]|0)>>>0)%((t[(t[u>>2]|0)+8>>2]|0)>>>0)|0;if(t[(t[(t[u>>2]|0)+4>>2]|0)+((t[l>>2]|0)*20|0)+12>>2]|0){t[h>>2]=(t[(t[u>>2]|0)+4>>2]|0)+((t[l>>2]|0)*20|0);while(1){O=(t[(t[h>>2]|0)+16>>2]|0)==(t[c>>2]|0);if(!(t[t[h>>2]>>2]|0))break;if((O?(t[(t[h>>2]|0)+8>>2]|0)==(t[d>>2]|0):0)?(Zl(t[a>>2]|0,t[o>>2]|0,t[(t[h>>2]|0)+4>>2]|0)|0)!=0:0){A=19;break}t[b>>2]=(t[b>>2]|0)+1;t[h>>2]=t[t[h>>2]>>2]}if((A|0)==19){t[f>>2]=t[(t[h>>2]|0)+4>>2];E=t[f>>2]|0;s=n;return E|0}if((O?(t[(t[h>>2]|0)+8>>2]|0)==(t[d>>2]|0):0)?(Zl(t[a>>2]|0,t[o>>2]|0,t[(t[h>>2]|0)+4>>2]|0)|0)!=0:0){t[f>>2]=t[(t[h>>2]|0)+4>>2];E=t[f>>2]|0;s=n;return E|0}}else t[h>>2]=0;if(t[(t[u>>2]|0)+20>>2]|0){if((t[(t[u>>2]|0)+8>>2]|0)==128?(t[(t[(t[u>>2]|0)+20>>2]|0)+8>>2]|0)!=128:0)A=30;else A=28;do if((A|0)==28){if((t[(t[u>>2]|0)+8>>2]|0)!=128?(t[(t[(t[u>>2]|0)+20>>2]|0)+8>>2]|0)==128:0){A=30;break}t[_>>2]=t[c>>2]}while(0);if((A|0)==30){O=(t[(t[(t[u>>2]|0)+20>>2]|0)+8>>2]|0)==128;do if(!(t[a>>2]|0)){g=t[o>>2]|0;r=t[m>>2]|0;F=t[(t[(t[u>>2]|0)+20>>2]|0)+24>>2]|0;if(O){M=vz(g,r,F)|0;break}else{M=mz(g,r,F)|0;break}}else{F=t[a>>2]|0;r=t[v>>2]|0;g=t[o>>2]|0;y=t[m>>2]|0;i=t[(t[(t[u>>2]|0)+20>>2]|0)+24>>2]|0;if(O){M=Ez(F,r,g,y,i)|0;break}else{M=Sz(F,r,g,y,i)|0;break}}while(0);t[_>>2]=M}t[l>>2]=((t[_>>2]|0)>>>0)%((t[(t[(t[u>>2]|0)+20>>2]|0)+8>>2]|0)>>>0)|0;if(t[(t[(t[(t[u>>2]|0)+20>>2]|0)+4>>2]|0)+((t[l>>2]|0)*20|0)+12>>2]|0){t[p>>2]=(t[(t[(t[u>>2]|0)+20>>2]|0)+4>>2]|0)+((t[l>>2]|0)*20|0);while(1){R=(t[(t[p>>2]|0)+16>>2]|0)==(t[_>>2]|0);if(!(t[t[p>>2]>>2]|0))break;if((R?(t[(t[p>>2]|0)+8>>2]|0)==(t[d>>2]|0):0)?(Zl(t[a>>2]|0,t[o>>2]|0,t[(t[p>>2]|0)+4>>2]|0)|0)!=0:0){A=45;break}t[b>>2]=(t[b>>2]|0)+1;t[p>>2]=t[t[p>>2]>>2]}if((A|0)==45){t[f>>2]=t[(t[p>>2]|0)+4>>2];E=t[f>>2]|0;s=n;return E|0}if((R?(t[(t[p>>2]|0)+8>>2]|0)==(t[d>>2]|0):0)?(Zl(t[a>>2]|0,t[o>>2]|0,t[(t[p>>2]|0)+4>>2]|0)|0)!=0:0){t[f>>2]=t[(t[p>>2]|0)+4>>2];E=t[f>>2]|0;s=n;return E|0}}t[l>>2]=((t[c>>2]|0)>>>0)%((t[(t[u>>2]|0)+8>>2]|0)>>>0)|0}t[w>>2]=gz(t[u>>2]|0,t[a>>2]|0,t[v>>2]|0,t[o>>2]|0,t[m>>2]|0)|0;if(!(t[w>>2]|0)){t[f>>2]=0;E=t[f>>2]|0;s=n;return E|0}if(t[h>>2]|0){t[k>>2]=gAi[t[135744>>2]&511](20)|0;if(!(t[k>>2]|0)){t[f>>2]=0;E=t[f>>2]|0;s=n;return E|0}}else t[k>>2]=(t[(t[u>>2]|0)+4>>2]|0)+((t[l>>2]|0)*20|0);t[(t[k>>2]|0)+4>>2]=t[w>>2];t[(t[k>>2]|0)+8>>2]=t[d>>2];t[t[k>>2]>>2]=0;t[(t[k>>2]|0)+12>>2]=1;t[(t[k>>2]|0)+16>>2]=t[c>>2];if(t[h>>2]|0)t[t[h>>2]>>2]=t[k>>2];k=(t[u>>2]|0)+12|0;t[k>>2]=(t[k>>2]|0)+1;if((t[b>>2]|0)>>>0>3?(t[(t[u>>2]|0)+8>>2]|0)>>>0<=2730:0)pz(t[u>>2]|0,(t[(t[u>>2]|0)+8>>2]|0)*6|0)|0;t[f>>2]=t[w>>2];E=t[f>>2]|0;s=n;return E|0}function wz(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0;r=s;s=s+16|0;n=r+12|0;f=r+8|0;u=r+4|0;a=r;t[f>>2]=e;t[u>>2]=i;if((t[f>>2]|0)==0|(t[u>>2]|0)==0){t[n>>2]=-1;o=t[n>>2]|0;s=r;return o|0}t[a>>2]=t[(t[f>>2]|0)+16>>2];while(1){if(!(t[a>>2]|0))break;if((t[u>>2]|0)>>>0>=((t[a>>2]|0)+20|0)>>>0?(t[u>>2]|0)>>>0<=(t[(t[a>>2]|0)+4>>2]|0)>>>0:0){c=7;break}t[a>>2]=t[t[a>>2]>>2]}if((c|0)==7){t[n>>2]=1;o=t[n>>2]|0;s=r;return o|0}if(t[(t[f>>2]|0)+20>>2]|0){t[n>>2]=wz(t[(t[f>>2]|0)+20>>2]|0,t[u>>2]|0)|0;o=t[n>>2]|0;s=r;return o|0}else{t[n>>2]=0;o=t[n>>2]|0;s=r;return o|0}return 0}function dz(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0;r=s;s=s+16|0;n=r+12|0;f=r+8|0;u=r+4|0;a=r;t[f>>2]=e;t[u>>2]=i;if(!(t[f>>2]|0)){t[n>>2]=0;o=t[n>>2]|0;s=r;return o|0}else{t[a>>2]=t[(t[f>>2]|0)+28>>2];t[(t[f>>2]|0)+28>>2]=t[u>>2];t[n>>2]=t[a>>2];o=t[n>>2]|0;s=r;return o|0}return 0}function vz(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,a=0,o=0,c=0,l=0,b=0,k=0;n=s;s=s+32|0;f=n+16|0;a=n+12|0;o=n+8|0;c=n+4|0;l=n;t[a>>2]=e;t[o>>2]=i;t[c>>2]=r;t[l>>2]=t[c>>2];if(!(t[a>>2]|0)){t[f>>2]=0;b=t[f>>2]|0;s=n;return b|0}t[l>>2]=u[t[a>>2]>>0];t[l>>2]=t[l>>2]<<5;if((t[o>>2]|0)>10){t[l>>2]=(t[l>>2]|0)+(u[(t[a>>2]|0)+((t[o>>2]|0)-1)>>0]|0);t[o>>2]=10}switch(t[o>>2]|0){case 7:{k=9;break}case 6:{k=10;break}case 9:{k=7;break}case 3:{k=13;break}case 8:{k=8;break}case 10:{t[l>>2]=(t[l>>2]|0)+(u[(t[a>>2]|0)+9>>0]|0);k=7;break}case 2:{k=14;break}case 4:{k=12;break}case 5:{k=11;break}default:{}}if((k|0)==7){t[l>>2]=(t[l>>2]|0)+(u[(t[a>>2]|0)+8>>0]|0);k=8}if((k|0)==8){t[l>>2]=(t[l>>2]|0)+(u[(t[a>>2]|0)+7>>0]|0);k=9}if((k|0)==9){t[l>>2]=(t[l>>2]|0)+(u[(t[a>>2]|0)+6>>0]|0);k=10}if((k|0)==10){t[l>>2]=(t[l>>2]|0)+(u[(t[a>>2]|0)+5>>0]|0);k=11}if((k|0)==11){t[l>>2]=(t[l>>2]|0)+(u[(t[a>>2]|0)+4>>0]|0);k=12}if((k|0)==12){t[l>>2]=(t[l>>2]|0)+(u[(t[a>>2]|0)+3>>0]|0);k=13}if((k|0)==13){t[l>>2]=(t[l>>2]|0)+(u[(t[a>>2]|0)+2>>0]|0);k=14}if((k|0)==14)t[l>>2]=(t[l>>2]|0)+(u[(t[a>>2]|0)+1>>0]|0);t[f>>2]=t[l>>2];b=t[f>>2]|0;s=n;return b|0}function mz(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,a=0,o=0,c=0,l=0,b=0,k=0;n=s;s=s+32|0;f=n+20|0;a=n+16|0;o=n+12|0;c=n+8|0;l=n+4|0;b=n;t[a>>2]=e;t[o>>2]=i;t[c>>2]=r;if((t[o>>2]|0)<=0|(t[a>>2]|0)==0){t[f>>2]=0;k=t[f>>2]|0;s=n;return k|0}t[l>>2]=t[c>>2];t[b>>2]=0;while(1){if((t[b>>2]|0)>=(t[o>>2]|0))break;t[l>>2]=(t[l>>2]|0)+(u[(t[a>>2]|0)+(t[b>>2]|0)>>0]|0);t[l>>2]=(t[l>>2]|0)+(t[l>>2]<<10);t[l>>2]=t[l>>2]^(t[l>>2]|0)>>>6;t[b>>2]=(t[b>>2]|0)+1}t[l>>2]=(t[l>>2]|0)+(t[l>>2]<<3);t[l>>2]=t[l>>2]^(t[l>>2]|0)>>>11;t[l>>2]=(t[l>>2]|0)+(t[l>>2]<<15);t[f>>2]=t[l>>2];k=t[f>>2]|0;s=n;return k|0}function _z(e,i,r){e=e|0;i=i|0;r=r|0;var f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0;f=s;s=s+32|0;u=f+28|0;a=f+24|0;o=f+20|0;c=f+16|0;l=f+12|0;b=f+8|0;k=f+4|0;h=f;t[a>>2]=e;t[o>>2]=i;t[c>>2]=r;t[k>>2]=0;t[h>>2]=0;t[l>>2]=t[(t[a>>2]|0)+16>>2];while(1){w=t[l>>2]|0;
	if(!(t[l>>2]|0)){d=7;break}if(((t[w+8>>2]|0)-(t[(t[l>>2]|0)+4>>2]|0)|0)>>>0>(t[c>>2]|0)>>>0)break;if((t[(t[l>>2]|0)+12>>2]|0)>>>0>(t[k>>2]|0)>>>0)t[k>>2]=t[(t[l>>2]|0)+12>>2];t[h>>2]=(t[h>>2]|0)+(t[(t[l>>2]|0)+12>>2]|0);t[l>>2]=t[t[l>>2]>>2]}do if((d|0)==7?(w|0)==0:0){if((t[(t[a>>2]|0)+28>>2]|0)>>>0>0?(t[h>>2]|0)>>>0>(t[(t[a>>2]|0)+28>>2]|0)>>>0:0){t[u>>2]=0;v=t[u>>2]|0;s=f;return v|0}if(!(t[k>>2]|0))t[k>>2]=1e3;else t[k>>2]=t[k>>2]<<2;if((t[k>>2]|0)>>>0<t[c>>2]<<2>>>0)t[k>>2]=t[c>>2]<<2;t[l>>2]=gAi[t[135744>>2]&511](24+(t[k>>2]|0)|0)|0;if(t[l>>2]|0){t[(t[l>>2]|0)+12>>2]=t[k>>2];t[(t[l>>2]|0)+16>>2]=0;t[(t[l>>2]|0)+4>>2]=(t[l>>2]|0)+20;t[(t[l>>2]|0)+8>>2]=(t[l>>2]|0)+20+(t[k>>2]|0);t[t[l>>2]>>2]=t[(t[a>>2]|0)+16>>2];t[(t[a>>2]|0)+16>>2]=t[l>>2];break}t[u>>2]=0;v=t[u>>2]|0;s=f;return v|0}while(0);t[b>>2]=t[(t[l>>2]|0)+4>>2];YY(t[(t[l>>2]|0)+4>>2]|0,t[o>>2]|0,t[c>>2]|0)|0;o=(t[l>>2]|0)+4|0;t[o>>2]=(t[o>>2]|0)+(t[c>>2]|0);c=(t[l>>2]|0)+4|0;o=t[c>>2]|0;t[c>>2]=o+1;n[o>>0]=0;o=(t[l>>2]|0)+16|0;t[o>>2]=(t[o>>2]|0)+1;t[u>>2]=t[b>>2];v=t[u>>2]|0;s=f;return v|0}function pz(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0;r=s;s=s+64|0;n=r+48|0;f=r+44|0;u=r+40|0;a=r+36|0;o=r+32|0;c=r+28|0;l=r+24|0;b=r+20|0;k=r+16|0;h=r+12|0;w=r+8|0;d=r+4|0;v=r;t[f>>2]=e;t[u>>2]=i;t[w>>2]=0;t[d>>2]=1;if(!(t[f>>2]|0)){t[n>>2]=-1;m=t[n>>2]|0;s=r;return m|0}if((t[u>>2]|0)>>>0<8){t[n>>2]=-1;m=t[n>>2]|0;s=r;return m|0}if((t[u>>2]|0)>>>0>16384){t[n>>2]=-1;m=t[n>>2]|0;s=r;return m|0}t[c>>2]=t[(t[f>>2]|0)+8>>2];t[h>>2]=t[(t[f>>2]|0)+4>>2];if(!(t[h>>2]|0)){t[n>>2]=-1;m=t[n>>2]|0;s=r;return m|0}if((t[c>>2]|0)==128)t[d>>2]=0;i=gAi[t[135744>>2]&511]((t[u>>2]|0)*20|0)|0;t[(t[f>>2]|0)+4>>2]=i;if(!(t[(t[f>>2]|0)+4>>2]|0)){t[(t[f>>2]|0)+4>>2]=t[h>>2];t[n>>2]=-1;m=t[n>>2]|0;s=r;return m|0}VY(t[(t[f>>2]|0)+4>>2]|0,0,(t[u>>2]|0)*20|0)|0;t[(t[f>>2]|0)+8>>2]=t[u>>2];t[l>>2]=0;while(1){if((t[l>>2]|0)>>>0>=(t[c>>2]|0)>>>0)break;do if(t[(t[h>>2]|0)+((t[l>>2]|0)*20|0)+12>>2]|0){if(t[d>>2]|0)t[o>>2]=t[(t[h>>2]|0)+((t[l>>2]|0)*20|0)+16>>2];else{u=t[(t[h>>2]|0)+((t[l>>2]|0)*20|0)+4>>2]|0;i=t[(t[h>>2]|0)+((t[l>>2]|0)*20|0)+8>>2]|0;e=t[(t[f>>2]|0)+24>>2]|0;if((t[(t[f>>2]|0)+8>>2]|0)==128)_=vz(u,i,e)|0;else _=mz(u,i,e)|0;t[o>>2]=_}t[a>>2]=((t[o>>2]|0)>>>0)%((t[(t[f>>2]|0)+8>>2]|0)>>>0)|0;if(!(t[(t[(t[f>>2]|0)+4>>2]|0)+((t[a>>2]|0)*20|0)+12>>2]|0)){e=(t[(t[f>>2]|0)+4>>2]|0)+((t[a>>2]|0)*20|0)|0;i=(t[h>>2]|0)+((t[l>>2]|0)*20|0)|0;t[e+0>>2]=t[i+0>>2];t[e+4>>2]=t[i+4>>2];t[e+8>>2]=t[i+8>>2];t[e+12>>2]=t[i+12>>2];t[e+16>>2]=t[i+16>>2];t[(t[(t[f>>2]|0)+4>>2]|0)+((t[a>>2]|0)*20|0)>>2]=0;t[(t[(t[f>>2]|0)+4>>2]|0)+((t[a>>2]|0)*20|0)+16>>2]=t[o>>2];break}t[v>>2]=gAi[t[135744>>2]&511](20)|0;if(t[v>>2]|0){t[(t[v>>2]|0)+4>>2]=t[(t[h>>2]|0)+((t[l>>2]|0)*20|0)+4>>2];t[(t[v>>2]|0)+8>>2]=t[(t[h>>2]|0)+((t[l>>2]|0)*20|0)+8>>2];t[(t[v>>2]|0)+16>>2]=t[o>>2];t[t[v>>2]>>2]=t[(t[(t[f>>2]|0)+4>>2]|0)+((t[a>>2]|0)*20|0)>>2];t[(t[v>>2]|0)+12>>2]=1;t[(t[(t[f>>2]|0)+4>>2]|0)+((t[a>>2]|0)*20|0)>>2]=t[v>>2];break}else{t[w>>2]=-1;break}}while(0);t[l>>2]=(t[l>>2]|0)+1}t[l>>2]=0;while(1){if((t[l>>2]|0)>>>0>=(t[c>>2]|0)>>>0)break;t[b>>2]=t[(t[h>>2]|0)+((t[l>>2]|0)*20|0)>>2];while(1){if(!(t[b>>2]|0))break;t[k>>2]=t[t[b>>2]>>2];if(t[d>>2]|0)t[o>>2]=t[(t[b>>2]|0)+16>>2];else{v=t[(t[b>>2]|0)+4>>2]|0;_=t[(t[b>>2]|0)+8>>2]|0;i=t[(t[f>>2]|0)+24>>2]|0;if((t[(t[f>>2]|0)+8>>2]|0)==128)p=vz(v,_,i)|0;else p=mz(v,_,i)|0;t[o>>2]=p}t[a>>2]=((t[o>>2]|0)>>>0)%((t[(t[f>>2]|0)+8>>2]|0)>>>0)|0;i=(t[(t[f>>2]|0)+4>>2]|0)+((t[a>>2]|0)*20|0)|0;if(!(t[(t[(t[f>>2]|0)+4>>2]|0)+((t[a>>2]|0)*20|0)+12>>2]|0)){_=t[b>>2]|0;t[i+0>>2]=t[_+0>>2];t[i+4>>2]=t[_+4>>2];t[i+8>>2]=t[_+8>>2];t[i+12>>2]=t[_+12>>2];t[i+16>>2]=t[_+16>>2];t[(t[(t[f>>2]|0)+4>>2]|0)+((t[a>>2]|0)*20|0)>>2]=0;t[(t[(t[f>>2]|0)+4>>2]|0)+((t[a>>2]|0)*20|0)+12>>2]=1;t[(t[(t[f>>2]|0)+4>>2]|0)+((t[a>>2]|0)*20|0)+16>>2]=t[o>>2];pAi[t[135736>>2]&511](t[b>>2]|0)}else{t[t[b>>2]>>2]=t[i>>2];t[(t[b>>2]|0)+16>>2]=t[o>>2];t[(t[(t[f>>2]|0)+4>>2]|0)+((t[a>>2]|0)*20|0)>>2]=t[b>>2]}t[b>>2]=t[k>>2]}t[l>>2]=(t[l>>2]|0)+1}pAi[t[135736>>2]&511](t[h>>2]|0);t[n>>2]=t[w>>2];m=t[n>>2]|0;s=r;return m|0}function Ez(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;var a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0;a=s;s=s+32|0;o=a+20|0;c=a+16|0;l=a+12|0;b=a+8|0;k=a+4|0;h=a;t[o>>2]=e;t[c>>2]=i;t[l>>2]=r;t[b>>2]=n;t[k>>2]=f;t[h>>2]=t[k>>2];if(!(t[c>>2]|0))t[h>>2]=(t[h>>2]|0)+1740;else t[h>>2]=(t[h>>2]|0)+((u[t[o>>2]>>0]|0)*30|0);if((t[b>>2]|0)>10?(t[h>>2]=(t[h>>2]|0)+(u[(t[l>>2]|0)+((t[b>>2]|0)-((t[c>>2]|0)+2))>>0]|0),t[b>>2]=10,(t[c>>2]|0)>10):0)t[c>>2]=10;switch(t[c>>2]|0){case 9:{w=9;break}case 10:{t[h>>2]=(t[h>>2]|0)+(u[(t[o>>2]|0)+9>>0]|0);w=9;break}case 5:{w=13;break}case 1:{w=17;break}case 2:{w=16;break}case 8:{w=10;break}case 4:{w=14;break}case 3:{w=15;break}case 7:{w=11;break}case 6:{w=12;break}default:{}}if((w|0)==9){t[h>>2]=(t[h>>2]|0)+(u[(t[o>>2]|0)+8>>0]|0);w=10}if((w|0)==10){t[h>>2]=(t[h>>2]|0)+(u[(t[o>>2]|0)+7>>0]|0);w=11}if((w|0)==11){t[h>>2]=(t[h>>2]|0)+(u[(t[o>>2]|0)+6>>0]|0);w=12}if((w|0)==12){t[h>>2]=(t[h>>2]|0)+(u[(t[o>>2]|0)+5>>0]|0);w=13}if((w|0)==13){t[h>>2]=(t[h>>2]|0)+(u[(t[o>>2]|0)+4>>0]|0);w=14}if((w|0)==14){t[h>>2]=(t[h>>2]|0)+(u[(t[o>>2]|0)+3>>0]|0);w=15}if((w|0)==15){t[h>>2]=(t[h>>2]|0)+(u[(t[o>>2]|0)+2>>0]|0);w=16}if((w|0)==16){t[h>>2]=(t[h>>2]|0)+(u[(t[o>>2]|0)+1>>0]|0);w=17}if((w|0)==17)t[h>>2]=(t[h>>2]|0)+(u[t[o>>2]>>0]|0);t[b>>2]=(t[b>>2]|0)-(t[c>>2]|0);if((t[b>>2]|0)>0){t[h>>2]=(t[h>>2]|0)+58;t[b>>2]=(t[b>>2]|0)+-1}switch(t[b>>2]|0){case 10:{t[h>>2]=(t[h>>2]|0)+(u[(t[l>>2]|0)+9>>0]|0);w=22;break}case 3:{w=28;break}case 1:break;case 9:{w=22;break}case 5:{w=26;break}case 8:{w=23;break}case 6:{w=25;break}case 7:{w=24;break}case 2:{w=29;break}case 4:{w=27;break}default:{d=t[h>>2]|0;s=a;return d|0}}if((w|0)==22){t[h>>2]=(t[h>>2]|0)+(u[(t[l>>2]|0)+8>>0]|0);w=23}if((w|0)==23){t[h>>2]=(t[h>>2]|0)+(u[(t[l>>2]|0)+7>>0]|0);w=24}if((w|0)==24){t[h>>2]=(t[h>>2]|0)+(u[(t[l>>2]|0)+6>>0]|0);w=25}if((w|0)==25){t[h>>2]=(t[h>>2]|0)+(u[(t[l>>2]|0)+5>>0]|0);w=26}if((w|0)==26){t[h>>2]=(t[h>>2]|0)+(u[(t[l>>2]|0)+4>>0]|0);w=27}if((w|0)==27){t[h>>2]=(t[h>>2]|0)+(u[(t[l>>2]|0)+3>>0]|0);w=28}if((w|0)==28){t[h>>2]=(t[h>>2]|0)+(u[(t[l>>2]|0)+2>>0]|0);w=29}if((w|0)==29)t[h>>2]=(t[h>>2]|0)+(u[(t[l>>2]|0)+1>>0]|0);t[h>>2]=(t[h>>2]|0)+(u[t[l>>2]>>0]|0);d=t[h>>2]|0;s=a;return d|0}function Sz(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;var a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0;a=s;s=s+32|0;o=a+24|0;c=a+20|0;l=a+16|0;b=a+12|0;k=a+8|0;h=a+4|0;w=a;t[o>>2]=e;t[c>>2]=i;t[l>>2]=r;t[b>>2]=n;t[k>>2]=f;t[h>>2]=t[k>>2];t[w>>2]=0;while(1){if((t[w>>2]|0)>=(t[c>>2]|0))break;t[h>>2]=(t[h>>2]|0)+(u[(t[o>>2]|0)+(t[w>>2]|0)>>0]|0);t[h>>2]=(t[h>>2]|0)+(t[h>>2]<<10);t[h>>2]=t[h>>2]^(t[h>>2]|0)>>>6;t[w>>2]=(t[w>>2]|0)+1}t[h>>2]=(t[h>>2]|0)+58;t[h>>2]=(t[h>>2]|0)+(t[h>>2]<<10);t[h>>2]=t[h>>2]^(t[h>>2]|0)>>>6;t[w>>2]=0;while(1){if((t[w>>2]|0)>=(t[b>>2]|0))break;t[h>>2]=(t[h>>2]|0)+(u[(t[l>>2]|0)+(t[w>>2]|0)>>0]|0);t[h>>2]=(t[h>>2]|0)+(t[h>>2]<<10);t[h>>2]=t[h>>2]^(t[h>>2]|0)>>>6;t[w>>2]=(t[w>>2]|0)+1}t[h>>2]=(t[h>>2]|0)+(t[h>>2]<<3);t[h>>2]=t[h>>2]^(t[h>>2]|0)>>>11;t[h>>2]=(t[h>>2]|0)+(t[h>>2]<<15);s=a;return t[h>>2]|0}function gz(e,i,r,f,u){e=e|0;i=i|0;r=r|0;f=f|0;u=u|0;var a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0;a=s;s=s+48|0;o=a+36|0;c=a+32|0;l=a+28|0;b=a+24|0;k=a+20|0;h=a+16|0;w=a+12|0;d=a+8|0;v=a+4|0;m=a;t[c>>2]=e;t[l>>2]=i;t[b>>2]=r;t[k>>2]=f;t[h>>2]=u;t[v>>2]=0;t[m>>2]=0;u=t[c>>2]|0;if(!(t[l>>2]|0)){t[o>>2]=_z(u,t[k>>2]|0,t[h>>2]|0)|0;_=t[o>>2]|0;s=a;return _|0}t[w>>2]=t[u+16>>2];while(1){p=t[w>>2]|0;if(!(t[w>>2]|0)){E=9;break}if(((t[p+8>>2]|0)-(t[(t[w>>2]|0)+4>>2]|0)|0)>>>0>((t[h>>2]|0)+(t[b>>2]|0)+1|0)>>>0)break;if((t[(t[w>>2]|0)+12>>2]|0)>>>0>(t[v>>2]|0)>>>0)t[v>>2]=t[(t[w>>2]|0)+12>>2];t[m>>2]=(t[m>>2]|0)+(t[(t[w>>2]|0)+12>>2]|0);t[w>>2]=t[t[w>>2]>>2]}do if((E|0)==9?(p|0)==0:0){if((t[(t[c>>2]|0)+28>>2]|0)>>>0>0?(t[m>>2]|0)>>>0>(t[(t[c>>2]|0)+28>>2]|0)>>>0:0){t[o>>2]=0;_=t[o>>2]|0;s=a;return _|0}if(!(t[v>>2]|0))t[v>>2]=1e3;else t[v>>2]=t[v>>2]<<2;if((t[v>>2]|0)>>>0<(t[h>>2]|0)+(t[b>>2]|0)+1<<2>>>0)t[v>>2]=(t[h>>2]|0)+(t[b>>2]|0)+1<<2;t[w>>2]=gAi[t[135744>>2]&511](24+(t[v>>2]|0)|0)|0;if(t[w>>2]|0){t[(t[w>>2]|0)+12>>2]=t[v>>2];t[(t[w>>2]|0)+16>>2]=0;t[(t[w>>2]|0)+4>>2]=(t[w>>2]|0)+20;t[(t[w>>2]|0)+8>>2]=(t[w>>2]|0)+20+(t[v>>2]|0);t[t[w>>2]>>2]=t[(t[c>>2]|0)+16>>2];t[(t[c>>2]|0)+16>>2]=t[w>>2];break}t[o>>2]=0;_=t[o>>2]|0;s=a;return _|0}while(0);t[d>>2]=t[(t[w>>2]|0)+4>>2];YY(t[(t[w>>2]|0)+4>>2]|0,t[l>>2]|0,t[b>>2]|0)|0;l=(t[w>>2]|0)+4|0;t[l>>2]=(t[l>>2]|0)+(t[b>>2]|0);b=(t[w>>2]|0)+4|0;l=t[b>>2]|0;t[b>>2]=l+1;n[l>>0]=58;YY(t[(t[w>>2]|0)+4>>2]|0,t[k>>2]|0,t[h>>2]|0)|0;k=(t[w>>2]|0)+4|0;t[k>>2]=(t[k>>2]|0)+(t[h>>2]|0);h=(t[w>>2]|0)+4|0;k=t[h>>2]|0;t[h>>2]=k+1;n[k>>0]=0;k=(t[w>>2]|0)+16|0;t[k>>2]=(t[k>>2]|0)+1;t[o>>2]=t[d>>2];_=t[o>>2]|0;s=a;return _|0}function yz(e){e=e|0;var i=0;i=s;s=s+16|0;t[i>>2]=e;s=i;return 0}function Fz(e){e=e|0;var i=0,r=0,n=0,f=0,u=0;i=s;s=s+16|0;r=i+8|0;n=i+4|0;f=i;t[n>>2]=e;t[f>>2]=t[n>>2];if((t[n>>2]|0)!=0?(t[(t[f>>2]|0)+36>>2]|0)!=0:0){t[r>>2]=t[(t[(t[f>>2]|0)+36>>2]|0)+4>>2];u=t[r>>2]|0;s=i;return u|0}t[r>>2]=0;u=t[r>>2]|0;s=i;return u|0}function Oz(e){e=e|0;var i=0,r=0,n=0,f=0,u=0;i=s;s=s+16|0;r=i+8|0;n=i+4|0;f=i;t[n>>2]=e;t[f>>2]=t[n>>2];if((t[n>>2]|0)!=0?(t[(t[f>>2]|0)+36>>2]|0)!=0:0){t[r>>2]=t[(t[(t[f>>2]|0)+36>>2]|0)+28>>2];u=t[r>>2]|0;s=i;return u|0}t[r>>2]=0;u=t[r>>2]|0;s=i;return u|0}function Az(e){e=e|0;var i=0,r=0,n=0,f=0,u=0;i=s;s=s+16|0;r=i+8|0;n=i+4|0;f=i;t[n>>2]=e;t[f>>2]=t[n>>2];if((t[n>>2]|0)!=0?(t[(t[f>>2]|0)+36>>2]|0)!=0:0){t[r>>2]=t[(t[(t[f>>2]|0)+36>>2]|0)+32>>2];u=t[r>>2]|0;s=i;return u|0}t[r>>2]=0;u=t[r>>2]|0;s=i;return u|0}function Mz(e){e=e|0;var i=0,r=0,n=0,f=0,u=0;i=s;s=s+16|0;r=i+8|0;n=i+4|0;f=i;t[n>>2]=e;t[f>>2]=t[n>>2];if((t[n>>2]|0)!=0?(t[(t[f>>2]|0)+8>>2]|0)!=0:0){t[r>>2]=(t[(t[(t[f>>2]|0)+8>>2]|0)+40>>2]|0)==1&1;u=t[r>>2]|0;s=i;return u|0}t[r>>2]=0;u=t[r>>2]|0;s=i;return u|0}function Rz(e){e=e|0;var i=0,r=0,n=0,f=0,u=0;i=s;s=s+16|0;r=i+8|0;n=i+4|0;f=i;t[n>>2]=e;t[f>>2]=t[n>>2];if((t[f>>2]|0)!=0?(t[(t[f>>2]|0)+8>>2]|0)!=0:0){t[r>>2]=(t[(t[(t[f>>2]|0)+8>>2]|0)+44>>2]|0)!=0&1;u=t[r>>2]|0;s=i;return u|0}t[r>>2]=0;u=t[r>>2]|0;s=i;return u|0}function Nz(e){e=e|0;var i=0,r=0,n=0,f=0,u=0;i=s;s=s+16|0;r=i+8|0;n=i+4|0;f=i;t[n>>2]=e;t[f>>2]=t[n>>2];if((t[f>>2]|0)!=0?(t[(t[f>>2]|0)+8>>2]|0)!=0:0){t[r>>2]=(t[(t[(t[f>>2]|0)+8>>2]|0)+48>>2]|0)!=0&1;u=t[r>>2]|0;s=i;return u|0}t[r>>2]=0;u=t[r>>2]|0;s=i;return u|0}function Tz(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,u=0,a=0,o=0,c=0,l=0,b=0;f=s;s=s+32|0;u=f+20|0;a=f+16|0;o=f+12|0;c=f+8|0;l=f+4|0;b=f;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;t[c>>2]=n;t[l>>2]=t[u>>2];if(!(t[u>>2]|0)){s=f;return}if(!(t[(t[l>>2]|0)+8>>2]|0)){s=f;return}t[b>>2]=Qg(t[(t[l>>2]|0)+8>>2]|0)|0;do if(t[b>>2]|0)if(t[(t[l>>2]|0)+32>>2]|0){s=f;return}else{iy(t[b>>2]|0);ey(t[b>>2]|0);t[(t[(t[l>>2]|0)+8>>2]|0)+44>>2]=0;break}while(0);b=$g(t[(t[l>>2]|0)+8>>2]|0,t[a>>2]|0,t[o>>2]|0,t[c>>2]|0)|0;t[(t[(t[l>>2]|0)+8>>2]|0)+44>>2]=b;if(t[(t[(t[l>>2]|0)+8>>2]|0)+44>>2]|0){s=f;return}tj(t[l>>2]|0,197088);s=f;return}function Lz(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0;f=s;s=s+64|0;u=f+48|0;a=f+44|0;o=f+40|0;c=f+36|0;l=f+32|0;b=f+28|0;k=f+24|0;h=f+20|0;w=f+16|0;d=f+12|0;v=f+8|0;m=f+4|0;_=f;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;t[c>>2]=n;t[l>>2]=t[u>>2];if(!(t[u>>2]|0)){s=f;return}if(!((t[o>>2]|0)!=0|(t[c>>2]|0)!=0)){s=f;return}if((t[(t[l>>2]|0)+104>>2]|0)==0?(t[(t[l>>2]|0)+276>>2]|0)==0:0){s=f;return}if(!(t[(t[l>>2]|0)+12>>2]|0)){s=f;return}if(!(t[(t[l>>2]|0)+8>>2]|0)){s=f;return}t[d>>2]=0;if((t[t[l>>2]>>2]|0)!=0?(t[(t[t[l>>2]>>2]|0)+16>>2]|0)!=0:0)t[d>>2]=dAi[t[(t[t[l>>2]>>2]|0)+16>>2]&511](t[(t[l>>2]|0)+4>>2]|0,t[o>>2]|0,t[c>>2]|0)|0;if(!(t[d>>2]|0)){s=f;return}Jg(t[(t[l>>2]|0)+8>>2]|0,t[a>>2]|0,t[o>>2]|0,t[c>>2]|0)|0;t[b>>2]=t[(t[l>>2]|0)+36>>2];t[k>>2]=t[(t[l>>2]|0)+40>>2];t[h>>2]=t[(t[l>>2]|0)+44>>2];t[w>>2]=t[(t[l>>2]|0)+48>>2];t[m>>2]=t[(t[l>>2]|0)+256>>2];t[_>>2]=t[(t[l>>2]|0)+24>>2];t[(t[l>>2]|0)+24>>2]=0;a=gAi[t[135744>>2]&511](20)|0;t[(t[l>>2]|0)+48>>2]=a;a=t[l>>2]|0;if(!(t[(t[l>>2]|0)+48>>2]|0)){tj(a,197112);t[(t[l>>2]|0)+36>>2]=t[b>>2];t[(t[l>>2]|0)+40>>2]=t[k>>2];t[(t[l>>2]|0)+44>>2]=t[h>>2];t[(t[l>>2]|0)+48>>2]=t[w>>2];t[(t[l>>2]|0)+256>>2]=t[m>>2];t[(t[l>>2]|0)+24>>2]=t[_>>2];s=f;return}t[a+40>>2]=0;t[(t[l>>2]|0)+44>>2]=5;t[(t[l>>2]|0)+36>>2]=0;cE(t[l>>2]|0,t[d>>2]|0)|0;if((t[(t[(t[l>>2]|0)+36>>2]|0)+24>>2]|0)>=4){t[v>>2]=L_(t[(t[(t[l>>2]|0)+36>>2]|0)+16>>2]|0,4)|0;Tp(t[l>>2]|0,t[v>>2]|0)|0}if(!(t[(t[d>>2]|0)+4>>2]|0)){v=KA(t[c>>2]|0)|0;t[(t[d>>2]|0)+4>>2]=v}t[(t[d>>2]|0)+28>>2]=1;t[(t[d>>2]|0)+32>>2]=1;t[(t[d>>2]|0)+12>>2]=t[(t[(t[l>>2]|0)+36>>2]|0)+16>>2];t[(t[d>>2]|0)+16>>2]=t[(t[(t[l>>2]|0)+36>>2]|0)+16>>2];t[(t[d>>2]|0)+40>>2]=0;zE(t[l>>2]|0,t[o>>2]|0,t[c>>2]|0);while(1){p=t[l>>2]|0;if((t[(t[l>>2]|0)+40>>2]|0)<=1)break;aE(p)|0}Dp(t[p+36>>2]|0);pAi[t[135736>>2]&511](t[(t[l>>2]|0)+48>>2]|0);t[(t[l>>2]|0)+36>>2]=t[b>>2];t[(t[l>>2]|0)+40>>2]=t[k>>2];t[(t[l>>2]|0)+44>>2]=t[h>>2];t[(t[l>>2]|0)+48>>2]=t[w>>2];t[(t[l>>2]|0)+256>>2]=t[m>>2];do if(t[(t[l>>2]|0)+24>>2]|0){if((t[(t[l>>2]|0)+296>>2]|0)!=0?(wz(t[(t[l>>2]|0)+296>>2]|0,t[(t[l>>2]|0)+24>>2]|0)|0)!=0:0)break;pAi[t[135736>>2]&511](t[(t[l>>2]|0)+24>>2]|0)}while(0);t[(t[l>>2]|0)+24>>2]=t[_>>2];s=f;return}function Dz(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0;n=s;s=s+32|0;f=n+28|0;u=n+24|0;a=n+20|0;o=n+16|0;c=n+12|0;l=n+8|0;b=n+4|0;k=n;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;t[c>>2]=t[u>>2];t[k>>2]=0;if(!(t[u>>2]|0)){t[f>>2]=0;h=t[f>>2]|0;s=n;return h|0}if(t[(t[c>>2]|0)+36>>2]|0)t[k>>2]=t[(t[(t[c>>2]|0)+36>>2]|0)+4>>2];if(!(t[k>>2]|0))t[k>>2]=t[(t[c>>2]|0)+180>>2];t[b>>2]=GA(t[o>>2]|0,t[k>>2]|0)|0;t[l>>2]=uA(t[b>>2]|0,t[a>>2]|0,t[c>>2]|0)|0;if(t[b>>2]|0)pAi[t[135736>>2]&511](t[b>>2]|0);t[f>>2]=t[l>>2];h=t[f>>2]|0;s=n;return h|0}function Cz(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0;r=s;s=s+32|0;n=r+28|0;f=r+24|0;u=r+20|0;a=r+16|0;o=r+12|0;c=r+8|0;l=r+4|0;b=r;t[f>>2]=e;t[u>>2]=i;t[a>>2]=t[f>>2];t[o>>2]=0;if(!(t[f>>2]|0)){t[n>>2]=0;k=t[n>>2]|0;s=r;return k|0}if((t[(t[a>>2]|0)+216>>2]|0)==0?(t[o>>2]=l_(t[u>>2]|0)|0,(t[o>>2]|0)!=0):0){t[n>>2]=t[o>>2];k=t[n>>2]|0;s=r;return k|0}do if((t[(t[a>>2]|0)+8>>2]|0)!=0?(t[(t[(t[a>>2]|0)+8>>2]|0)+40>>2]|0)==1:0){f=t[(t[a>>2]|0)+8>>2]|0;if((t[(t[a>>2]|0)+216>>2]|0)==2){t[f+40>>2]=0;t[o>>2]=h_(t[(t[a>>2]|0)+8>>2]|0,t[u>>2]|0)|0;t[(t[(t[a>>2]|0)+8>>2]|0)+40>>2]=1;break}t[o>>2]=h_(f,t[u>>2]|0)|0;if(!(t[o>>2]|0)){t[(t[(t[a>>2]|0)+8>>2]|0)+40>>2]=0;t[o>>2]=h_(t[(t[a>>2]|0)+8>>2]|0,t[u>>2]|0)|0;if(t[o>>2]|0)uj(t[a>>2]|0,103,197136,t[u>>2]|0,0);t[(t[(t[a>>2]|0)+8>>2]|0)+40>>2]=1}}else h=14;while(0);if((h|0)==14)t[o>>2]=h_(t[(t[a>>2]|0)+8>>2]|0,t[u>>2]|0)|0;do if(t[o>>2]|0){if((t[(t[a>>2]|0)+104>>2]|0)==0?(t[(t[a>>2]|0)+16>>2]|0)==0:0)break;if((t[(t[o>>2]|0)+12>>2]|0)==0?(t[(t[o>>2]|0)+48>>2]|0)==2:0){t[b>>2]=t[(t[a>>2]|0)+440>>2];t[c>>2]=oS(t[a>>2]|0,t[(t[o>>2]|0)+64>>2]|0,t[(t[o>>2]|0)+52>>2]|0,l)|0;if(t[c>>2]|0){uj(t[a>>2]|0,104,197208,t[u>>2]|0,0);t[(t[a>>2]|0)+104>>2]=0;t[n>>2]=0;k=t[n>>2]|0;s=r;return k|0}Iy(t[o>>2]|0,t[l>>2]|0)|0;t[(t[o>>2]|0)+68>>2]=1;if(((t[(t[o>>2]|0)+72>>2]|0)==0?(t[(t[o>>2]|0)+72>>2]=(t[(t[a>>2]|0)+440>>2]|0)-(t[b>>2]|0)+1<<1,(t[(t[o>>2]|0)+40>>2]|0)!=0):0)?(es(t[(t[o>>2]|0)+40>>2]|0,60)|0)!=0:0){h=(t[o>>2]|0)+72|0;t[h>>2]=t[h>>2]|1}}}while(0);t[n>>2]=t[o>>2];k=t[n>>2]|0;s=r;return k|0}function Pz(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0;r=s;s=s+32|0;n=r+16|0;f=r+12|0;u=r+8|0;a=r+4|0;o=r;t[f>>2]=e;t[u>>2]=i;t[a>>2]=t[f>>2];if(!(t[f>>2]|0)){t[n>>2]=0;c=t[n>>2]|0;s=r;return c|0}else{t[o>>2]=k_(t[(t[a>>2]|0)+8>>2]|0,t[u>>2]|0)|0;t[n>>2]=t[o>>2];c=t[n>>2]|0;s=r;return c|0}return 0}function Bz(e,i,r,n,f,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;u=u|0;var a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0;a=s;s=s+64|0;o=a;c=a+48|0;l=a+44|0;b=a+40|0;k=a+36|0;h=a+32|0;w=a+28|0;d=a+24|0;v=a+20|0;m=a+16|0;_=a+12|0;p=a+8|0;E=a+4|0;t[c>>2]=e;t[l>>2]=i;t[b>>2]=r;t[k>>2]=n;t[h>>2]=f;t[w>>2]=u;t[v>>2]=t[c>>2];if(!(t[c>>2]|0)){s=a;return}c=t[v>>2]|0;if((t[(t[v>>2]|0)+216>>2]|0)==1){t[d>>2]=b_(t[c+8>>2]|0,t[l>>2]|0,t[b>>2]|0,t[k>>2]|0,t[h>>2]|0,t[w>>2]|0)|0;if((t[d>>2]|0)==0?(t[(t[v>>2]|0)+268>>2]|0)!=0:0)aj(t[v>>2]|0,107,197240,t[l>>2]|0);if(!(t[d>>2]|0)){s=a;return}if(!((t[h>>2]|0)!=0?(t[(t[d>>2]|0)+64>>2]|0)==0:0)){s=a;return}t[_>>2]=0;if(t[(t[v>>2]|0)+36>>2]|0)t[_>>2]=t[(t[(t[v>>2]|0)+36>>2]|0)+4>>2];if(!(t[_>>2]|0))t[_>>2]=t[(t[v>>2]|0)+180>>2];t[m>>2]=GA(t[h>>2]|0,t[_>>2]|0)|0;t[(t[d>>2]|0)+64>>2]=t[m>>2];s=a;return}m=t[v>>2]|0;if((t[c+216>>2]|0)!=2){uj(m,104,197352,t[l>>2]|0,0);s=a;return}t[d>>2]=s_(t[m+8>>2]|0,t[l>>2]|0,t[b>>2]|0,t[k>>2]|0,t[h>>2]|0,t[w>>2]|0)|0;if((((t[d>>2]|0)==0?(t[(t[v>>2]|0)+268>>2]|0)!=0:0)?(t[t[v>>2]>>2]|0)!=0:0)?(t[(t[t[v>>2]>>2]|0)+84>>2]|0)!=0:0){w=t[(t[t[v>>2]>>2]|0)+84>>2]|0;k=t[(t[v>>2]|0)+4>>2]|0;t[o>>2]=t[l>>2];yAi[w&511](k,197296,o)}if(!(t[d>>2]|0)){s=a;return}if(!((t[h>>2]|0)!=0?(t[(t[d>>2]|0)+64>>2]|0)==0:0)){s=a;return}t[E>>2]=0;if(t[(t[v>>2]|0)+36>>2]|0)t[E>>2]=t[(t[(t[v>>2]|0)+36>>2]|0)+4>>2];if(!(t[E>>2]|0))t[E>>2]=t[(t[v>>2]|0)+180>>2];t[p>>2]=GA(t[h>>2]|0,t[E>>2]|0)|0;t[(t[d>>2]|0)+64>>2]=t[p>>2];s=a;return}function Iz(e,i,r,n,f,u,a){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;u=u|0;a=a|0;var o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0;o=s;s=s+48|0;c=o+44|0;l=o+40|0;b=o+36|0;k=o+32|0;h=o+28|0;w=o+24|0;d=o+20|0;v=o+16|0;m=o+12|0;_=o+8|0;p=o+4|0;E=o;t[c>>2]=e;t[l>>2]=i;t[b>>2]=r;t[k>>2]=n;t[h>>2]=f;t[w>>2]=u;t[d>>2]=a;t[v>>2]=t[c>>2];t[_>>2]=0;t[p>>2]=0;if(!(t[v>>2]|0)){s=o;return}if(!(t[(t[v>>2]|0)+8>>2]|0)){s=o;return}c=(Xl(t[b>>2]|0,197408)|0)!=0;if(c&(t[k>>2]|0)!=2){t[E>>2]=t[(t[v>>2]|0)+100>>2];oj(t[v>>2]|0,540,197416,0,0);t[(t[v>>2]|0)+100>>2]=t[E>>2]}t[_>>2]=wE(t[v>>2]|0,t[b>>2]|0,p)|0;t[(t[v>>2]|0)+144>>2]=1;b=t[v>>2]|0;do if((t[(t[v>>2]|0)+216>>2]|0)==1)t[m>>2]=LM(b+108|0,t[(t[(t[v>>2]|0)+8>>2]|0)+44>>2]|0,t[l>>2]|0,t[_>>2]|0,t[p>>2]|0,t[k>>2]|0,t[h>>2]|0,t[w>>2]|0,t[d>>2]|0)|0;else{E=t[v>>2]|0;if((t[b+216>>2]|0)==2){t[m>>2]=LM(E+108|0,t[(t[(t[v>>2]|0)+8>>2]|0)+48>>2]|0,t[l>>2]|0,t[_>>2]|0,t[p>>2]|0,t[k>>2]|0,t[h>>2]|0,t[w>>2]|0,t[d>>2]|0)|0;break}uj(E,1,197456,t[_>>2]|0,0);NM(t[d>>2]|0);s=o;return}while(0);if(!(t[(t[v>>2]|0)+144>>2]|0))t[(t[v>>2]|0)+100>>2]=0;if((((t[m>>2]|0)!=0?(t[(t[v>>2]|0)+104>>2]|0)!=0:0)?(t[(t[v>>2]|0)+12>>2]|0)!=0:0)?(t[(t[(t[v>>2]|0)+8>>2]|0)+44>>2]|0)!=0:0){d=tR((t[v>>2]|0)+108|0,t[(t[v>>2]|0)+8>>2]|0,t[m>>2]|0)|0;m=(t[v>>2]|0)+100|0;t[m>>2]=t[m>>2]&d}if(t[p>>2]|0)pAi[t[135736>>2]&511](t[p>>2]|0);if(!(t[_>>2]|0)){s=o;return}pAi[t[135736>>2]&511](t[_>>2]|0);s=o;return}function Hz(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,u=0,a=0,o=0,c=0,l=0,b=0;f=s;s=s+32|0;u=f+20|0;a=f+16|0;o=f+12|0;c=f+8|0;l=f+4|0;b=f;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;t[c>>2]=n;t[l>>2]=t[u>>2];t[b>>2]=0;if(!(t[l>>2]|0)){s=f;return}if(!(t[(t[l>>2]|0)+8>>2]|0)){s=f;return}u=t[l>>2]|0;do if((t[(t[l>>2]|0)+216>>2]|0)==1)t[b>>2]=FM(u+108|0,t[(t[(t[l>>2]|0)+8>>2]|0)+44>>2]|0,t[a>>2]|0,t[o>>2]|0,t[c>>2]|0)|0;else{n=t[l>>2]|0;if((t[u+216>>2]|0)==2){t[b>>2]=FM(n+108|0,t[(t[(t[l>>2]|0)+8>>2]|0)+48>>2]|0,t[a>>2]|0,t[o>>2]|0,t[c>>2]|0)|0;break}uj(n,1,197520,t[a>>2]|0,0);s=f;return}while(0);if(!(t[b>>2]|0))t[(t[l>>2]|0)+100>>2]=0;if(!(t[(t[l>>2]|0)+104>>2]|0)){s=f;return}if(!(t[(t[l>>2]|0)+12>>2]|0)){s=f;return}if(!(t[(t[l>>2]|0)+8>>2]|0)){s=f;return}if(!(t[(t[(t[l>>2]|0)+8>>2]|0)+44>>2]|0)){s=f;return}a=uR((t[l>>2]|0)+108|0,t[(t[l>>2]|0)+8>>2]|0,t[b>>2]|0)|0;b=(t[l>>2]|0)+100|0;t[b>>2]=t[b>>2]&a;s=f;return}function xz(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,u=0,a=0,o=0,c=0,l=0,b=0;f=s;s=s+32|0;u=f+20|0;a=f+16|0;o=f+12|0;c=f+8|0;l=f+4|0;b=f;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;t[c>>2]=n;t[l>>2]=t[u>>2];t[b>>2]=0;if(!(t[l>>2]|0)){s=f;return}if(!(t[(t[l>>2]|0)+8>>2]|0)){s=f;return}u=t[l>>2]|0;if((t[o>>2]|0)==0&(t[c>>2]|0)==0){uj(u,105,197576,t[a>>2]|0,0);s=f;return}n=t[l>>2]|0;do if((t[u+216>>2]|0)==1)t[b>>2]=BM(n+108|0,t[(t[(t[l>>2]|0)+8>>2]|0)+44>>2]|0,t[a>>2]|0,t[o>>2]|0,t[c>>2]|0)|0;else{r=t[l>>2]|0;if((t[n+216>>2]|0)==2){t[b>>2]=BM(r+108|0,t[(t[(t[l>>2]|0)+8>>2]|0)+48>>2]|0,t[a>>2]|0,t[o>>2]|0,t[c>>2]|0)|0;break}uj(r,105,197640,t[a>>2]|0,0);s=f;return}while(0);if(!(t[b>>2]|0))t[(t[l>>2]|0)+100>>2]=0;if(!(t[(t[l>>2]|0)+104>>2]|0)){s=f;return}if(!(t[(t[l>>2]|0)+12>>2]|0)){s=f;return}if(!(t[(t[(t[l>>2]|0)+8>>2]|0)+44>>2]|0)){s=f;return}a=rR((t[l>>2]|0)+108|0,t[(t[l>>2]|0)+8>>2]|0,t[b>>2]|0)|0;b=(t[l>>2]|0)+100|0;t[b>>2]=t[b>>2]&a;s=f;return}function Uz(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;var u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0;u=s;s=s+48|0;a=u;o=u+44|0;c=u+40|0;l=u+36|0;b=u+32|0;k=u+28|0;h=u+24|0;w=u+20|0;d=u+16|0;v=u+12|0;m=u+8|0;_=u+4|0;t[o>>2]=e;t[c>>2]=i;t[l>>2]=r;t[b>>2]=n;t[k>>2]=f;t[w>>2]=t[o>>2];if(!(t[o>>2]|0)){s=u;return}o=t[w>>2]|0;if((t[(t[w>>2]|0)+216>>2]|0)==1){t[h>>2]=b_(t[o+8>>2]|0,t[c>>2]|0,3,t[l>>2]|0,t[b>>2]|0,t[k>>2]|0)|0;if((((t[h>>2]|0)==0?(t[(t[w>>2]|0)+268>>2]|0)!=0:0)?(t[t[w>>2]>>2]|0)!=0:0)?(t[(t[t[w>>2]>>2]|0)+84>>2]|0)!=0:0){f=t[(t[t[w>>2]>>2]|0)+84>>2]|0;n=t[(t[w>>2]|0)+4>>2]|0;t[a>>2]=t[c>>2];yAi[f&511](n,197240,a)}if(!(t[h>>2]|0)){s=u;return}if(!((t[b>>2]|0)!=0?(t[(t[h>>2]|0)+64>>2]|0)==0:0)){s=u;return}t[v>>2]=0;if(t[(t[w>>2]|0)+36>>2]|0)t[v>>2]=t[(t[(t[w>>2]|0)+36>>2]|0)+4>>2];if(!(t[v>>2]|0))t[v>>2]=t[(t[w>>2]|0)+180>>2];t[d>>2]=GA(t[b>>2]|0,t[v>>2]|0)|0;t[(t[h>>2]|0)+64>>2]=t[d>>2];s=u;return}d=t[w>>2]|0;if((t[o+216>>2]|0)!=2){uj(d,1,197696,t[c>>2]|0,0);s=u;return}t[h>>2]=s_(t[d+8>>2]|0,t[c>>2]|0,3,t[l>>2]|0,t[b>>2]|0,t[k>>2]|0)|0;if((((t[h>>2]|0)==0?(t[(t[w>>2]|0)+268>>2]|0)!=0:0)?(t[t[w>>2]>>2]|0)!=0:0)?(t[(t[t[w>>2]>>2]|0)+84>>2]|0)!=0:0){k=t[(t[t[w>>2]>>2]|0)+84>>2]|0;l=t[(t[w>>2]|0)+4>>2]|0;t[a>>2]=t[c>>2];yAi[k&511](l,197296,a)}if(!(t[h>>2]|0)){s=u;return}if(!((t[b>>2]|0)!=0?(t[(t[h>>2]|0)+64>>2]|0)==0:0)){s=u;return}t[_>>2]=0;if(t[(t[w>>2]|0)+36>>2]|0)t[_>>2]=t[(t[(t[w>>2]|0)+36>>2]|0)+4>>2];if(!(t[_>>2]|0))t[_>>2]=t[(t[w>>2]|0)+180>>2];t[m>>2]=GA(t[b>>2]|0,t[_>>2]|0)|0;t[(t[h>>2]|0)+64>>2]=t[m>>2];s=u;return}function zz(e,i){e=e|0;i=i|0;var r=0;r=s;s=s+16|0;t[r+4>>2]=e;t[r>>2]=i;s=r;return}function jz(e){e=e|0;var i=0,r=0,n=0,f=0;i=s;s=s+16|0;r=i+8|0;n=i+4|0;f=i;t[r>>2]=e;t[n>>2]=t[r>>2];if(!(t[r>>2]|0)){s=i;return}r=t[n>>2]|0;do if(!(t[(t[n>>2]|0)+32>>2]|0)){e=ny(t[r+20>>2]|0)|0;t[(t[n>>2]|0)+8>>2]=e;t[f>>2]=e;if(!(t[f>>2]|0)){tj(t[n>>2]|0,197760);s=i;return}t[(t[f>>2]|0)+92>>2]=0;if(t[(t[n>>2]|0)+360>>2]&131072){e=(t[f>>2]|0)+92|0;t[e>>2]=t[e>>2]|4}t[(t[f>>2]|0)+88>>2]=t[(t[n>>2]|0)+360>>2];if(t[(t[n>>2]|0)+24>>2]|0){e=Yl(t[(t[n>>2]|0)+24>>2]|0)|0;t[(t[f>>2]|0)+60>>2]=e}else t[(t[f>>2]|0)+60>>2]=0;t[(t[f>>2]|0)+40>>2]=t[(t[n>>2]|0)+28>>2];if((t[f>>2]|0)!=0?(t[(t[n>>2]|0)+364>>2]|0)!=0:0){t[(t[f>>2]|0)+80>>2]=t[(t[n>>2]|0)+296>>2];sz(t[(t[f>>2]|0)+80>>2]|0)|0}}else{if(!(t[r+8>>2]|0)){e=vN(0,0)|0;t[(t[n>>2]|0)+8>>2]=e}e=t[n>>2]|0;if(t[(t[n>>2]|0)+8>>2]|0){t[(t[e+8>>2]|0)+92>>2]=128;t[(t[(t[n>>2]|0)+8>>2]|0)+88>>2]=t[(t[n>>2]|0)+360>>2];break}tj(e,197760);s=i;return}while(0);if(!(t[(t[n>>2]|0)+8>>2]|0)){s=i;return}if(t[(t[(t[n>>2]|0)+8>>2]|0)+72>>2]|0){s=i;return}if(!(t[(t[n>>2]|0)+36>>2]|0)){s=i;return}if(!(t[(t[(t[n>>2]|0)+36>>2]|0)+4>>2]|0)){s=i;return}r=XA(t[(t[(t[n>>2]|0)+36>>2]|0)+4>>2]|0)|0;t[(t[(t[n>>2]|0)+8>>2]|0)+72>>2]=r;if(t[(t[(t[n>>2]|0)+8>>2]|0)+72>>2]|0){s=i;return}tj(t[n>>2]|0,197760);s=i;return}function Vz(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i+4|0;n=i;t[r>>2]=e;t[n>>2]=t[r>>2];if(!(t[r>>2]|0)){s=i;return}if((((t[(t[n>>2]|0)+104>>2]|0)!=0?(t[(t[n>>2]|0)+12>>2]|0)!=0:0)?(t[(t[n>>2]|0)+8>>2]|0)!=0:0)?(t[(t[(t[n>>2]|0)+8>>2]|0)+44>>2]|0)!=0:0){r=wR((t[n>>2]|0)+108|0,t[(t[n>>2]|0)+8>>2]|0)|0;e=(t[n>>2]|0)+100|0;t[e>>2]=t[e>>2]&r}if(((t[(t[n>>2]|0)+24>>2]|0)!=0?(t[(t[n>>2]|0)+8>>2]|0)!=0:0)?(t[(t[(t[n>>2]|0)+8>>2]|0)+60>>2]|0)==0:0){t[(t[(t[n>>2]|0)+8>>2]|0)+60>>2]=t[(t[n>>2]|0)+24>>2];t[(t[n>>2]|0)+24>>2]=0}if((((((t[(t[n>>2]|0)+48>>2]|0)!=0?(t[(t[n>>2]|0)+40>>2]|0)>0:0)?(t[t[(t[n>>2]|0)+48>>2]>>2]|0)!=0:0)?(t[(t[t[(t[n>>2]|0)+48>>2]>>2]|0)+44>>2]|0)!=0:0)?(t[(t[n>>2]|0)+8>>2]|0)!=0:0)?(t[(t[(t[n>>2]|0)+8>>2]|0)+60>>2]|0)==0:0){r=Yl(t[(t[t[(t[n>>2]|0)+48>>2]>>2]|0)+44>>2]|0)|0;t[(t[(t[n>>2]|0)+8>>2]|0)+60>>2]=r}if(!(t[(t[n>>2]|0)+256>>2]|0)){s=i;return}if(!(t[(t[n>>2]|0)+8>>2]|0)){s=i;return}if(t[(t[(t[n>>2]|0)+8>>2]|0)+76>>2]|0){s=i;return}t[(t[(t[n>>2]|0)+8>>2]|0)+76>>2]=t[(t[n>>2]|0)+256>>2];s=i;return}function qz(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0;n=s;s=s+64|0;a=n+48|0;o=n+44|0;c=n+40|0;l=n+36|0;b=n+32|0;k=n+28|0;h=n+24|0;w=n+20|0;d=n+16|0;v=n+12|0;m=n+8|0;_=n+4|0;p=n;t[a>>2]=e;t[o>>2]=i;t[c>>2]=r;t[l>>2]=t[a>>2];if((t[a>>2]|0)==0|(t[o>>2]|0)==0){s=n;return}if(!(t[(t[l>>2]|0)+8>>2]|0)){s=n;return}t[k>>2]=t[(t[l>>2]|0)+52>>2];do if((t[(t[l>>2]|0)+104>>2]|0)!=0?(t[(t[(t[l>>2]|0)+8>>2]|0)+48>>2]|0)==0:0){if(t[(t[(t[l>>2]|0)+8>>2]|0)+44>>2]|0){if(t[(t[(t[(t[l>>2]|0)+8>>2]|0)+44>>2]|0)+36>>2]|0)break;if(t[(t[(t[(t[l>>2]|0)+8>>2]|0)+44>>2]|0)+40>>2]|0)break;if(t[(t[(t[(t[l>>2]|0)+8>>2]|0)+44>>2]|0)+44>>2]|0)break;if(t[(t[(t[(t[l>>2]|0)+8>>2]|0)+44>>2]|0)+48>>2]|0)break}oj(t[l>>2]|0,94,197784,0,0);t[(t[l>>2]|0)+104>>2]=0}while(0);t[w>>2]=wE(t[l>>2]|0,t[o>>2]|0,d)|0;t[b>>2]=gy(t[(t[l>>2]|0)+8>>2]|0,0,t[w>>2]|0,0)|0;if(!(t[b>>2]|0)){if(t[d>>2]|0)pAi[t[135736>>2]&511](t[d>>2]|0);tj(t[l>>2]|0,197824);s=n;return}if(t[(t[(t[l>>2]|0)+8>>2]|0)+12>>2]|0){if(!(t[k>>2]|0))t[k>>2]=t[(t[(t[l>>2]|0)+8>>2]|0)+12>>2]}else Hy(t[(t[l>>2]|0)+8>>2]|0,t[b>>2]|0)|0;t[(t[l>>2]|0)+264>>2]=-1;do if((t[(t[l>>2]|0)+280>>2]|0)!=0?(t[(t[l>>2]|0)+36>>2]|0)!=0:0)if((t[(t[(t[l>>2]|0)+36>>2]|0)+28>>2]|0)<65535){f[(t[b>>2]|0)+56>>1]=t[(t[(t[l>>2]|0)+36>>2]|0)+28>>2];break}else{f[(t[b>>2]|0)+56>>1]=-1;break}while(0);rE(t[l>>2]|0,t[b>>2]|0)|0;do if(t[k>>2]|0){o=t[k>>2]|0;a=t[b>>2]|0;if((t[(t[k>>2]|0)+4>>2]|0)==1){Hy(o,a)|0;break}else{By(o,a)|0;break}}while(0);do if(!(t[(t[l>>2]|0)+32>>2]|0)){if((t[(t[(t[l>>2]|0)+8>>2]|0)+44>>2]|0)==0?(t[(t[(t[l>>2]|0)+8>>2]|0)+48>>2]|0)==0:0)break;cj(t[l>>2]|0,t[w>>2]|0,t[d>>2]|0,t[c>>2]|0)}while(0);if((t[c>>2]|0)!=0?(t[_>>2]=0,w=t[_>>2]|0,t[_>>2]=w+1,t[v>>2]=t[(t[c>>2]|0)+(w<<2)>>2],w=t[_>>2]|0,t[_>>2]=w+1,t[m>>2]=t[(t[c>>2]|0)+(w<<2)>>2],((t[v>>2]|0)!=0?(t[(t[l>>2]|0)+32>>2]|0)==0:0)&(t[m>>2]|0)!=0):0)do{if(((((u[t[v>>2]>>0]|0|0)==120?(u[(t[v>>2]|0)+1>>0]|0|0)==109:0)?(u[(t[v>>2]|0)+2>>0]|0|0)==108:0)?(u[(t[v>>2]|0)+3>>0]|0|0)==110:0)?(u[(t[v>>2]|0)+4>>0]|0|0)==115:0)lj(t[l>>2]|0,t[v>>2]|0,t[m>>2]|0,t[d>>2]|0);w=t[_>>2]|0;t[_>>2]=w+1;t[v>>2]=t[(t[c>>2]|0)+(w<<2)>>2];w=t[_>>2]|0;t[_>>2]=w+1;t[m>>2]=t[(t[c>>2]|0)+(w<<2)>>2]}while((t[v>>2]|0)!=0&(t[m>>2]|0)!=0);t[h>>2]=wF(t[(t[l>>2]|0)+8>>2]|0,t[b>>2]|0,t[d>>2]|0)|0;if((t[h>>2]|0)==0&(t[k>>2]|0)!=0)t[h>>2]=wF(t[(t[l>>2]|0)+8>>2]|0,t[k>>2]|0,t[d>>2]|0)|0;if((t[d>>2]|0)!=0&(t[h>>2]|0)==0){t[h>>2]=Wg(t[b>>2]|0,0,t[d>>2]|0)|0;sj(t[l>>2]|0,201,197848,t[d>>2]|0,0)}do if((t[h>>2]|0)!=0?(t[(t[h>>2]|0)+8>>2]|0)!=0:0){if((u[t[(t[h>>2]|0)+8>>2]>>0]|0|0)==0?(t[(t[h>>2]|0)+12>>2]|0)==0:0)break;Xg(t[b>>2]|0,t[h>>2]|0)}while(0);e:do if(t[c>>2]|0){t[_>>2]=0;h=t[_>>2]|0;t[_>>2]=h+1;t[v>>2]=t[(t[c>>2]|0)+(h<<2)>>2];h=t[_>>2]|0;t[_>>2]=h+1;t[m>>2]=t[(t[c>>2]|0)+(h<<2)>>2];if(t[(t[l>>2]|0)+32>>2]|0)while(1){if(!(t[v>>2]|0))break e;lj(t[l>>2]|0,t[v>>2]|0,t[m>>2]|0,0);h=t[_>>2]|0;t[_>>2]=h+1;t[v>>2]=t[(t[c>>2]|0)+(h<<2)>>2];h=t[_>>2]|0;t[_>>2]=h+1;t[m>>2]=t[(t[c>>2]|0)+(h<<2)>>2]}while(1){if(!((t[v>>2]|0)!=0&(t[m>>2]|0)!=0))break e;do if((u[t[v>>2]>>0]|0|0)==120?(u[(t[v>>2]|0)+1>>0]|0|0)==109:0){if((u[(t[v>>2]|0)+2>>0]|0|0)!=108){E=60;break}if((u[(t[v>>2]|0)+3>>0]|0|0)!=110){E=60;break}if((u[(t[v>>2]|0)+4>>0]|0|0)!=115)E=60}else E=60;while(0);if((E|0)==60){E=0;lj(t[l>>2]|0,t[v>>2]|0,t[m>>2]|0,0)}h=t[_>>2]|0;t[_>>2]=h+1;t[v>>2]=t[(t[c>>2]|0)+(h<<2)>>2];h=t[_>>2]|0;t[_>>2]=h+1;t[m>>2]=t[(t[c>>2]|0)+(h<<2)>>2]}}while(0);if((t[(t[l>>2]|0)+104>>2]|0)!=0?(t[(t[l>>2]|0)+136>>2]|0)==-1412623820:0){t[p>>2]=vR((t[l>>2]|0)+108|0,t[(t[l>>2]|0)+8>>2]|0)|0;if((t[p>>2]|0)<=0)t[(t[l>>2]|0)+100>>2]=0;if((t[p>>2]|0)<0)t[(t[l>>2]|0)+12>>2]=0;p=kR((t[l>>2]|0)+108|0,t[(t[l>>2]|0)+8>>2]|0)|0;c=(t[l>>2]|0)+100|0;t[c>>2]=t[c>>2]&p;t[(t[l>>2]|0)+136>>2]=-1412623819}if(!(t[d>>2]|0)){s=n;return}pAi[t[135736>>2]&511](t[d>>2]|0);s=n;return}function Yz(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0;r=s;s=s+16|0;n=r+12|0;f=r+4|0;u=r;t[n>>2]=e;t[r+8>>2]=i;t[f>>2]=t[n>>2];if(!(t[n>>2]|0)){s=r;return}t[u>>2]=t[(t[f>>2]|0)+52>>2];if((t[u>>2]|0)!=0?(t[(t[f>>2]|0)+68>>2]|0)!=0:0){t[(t[(t[f>>2]|0)+448>>2]|0)+12>>2]=(t[(t[(t[f>>2]|0)+36>>2]|0)+16>>2]|0)-(t[(t[(t[f>>2]|0)+36>>2]|0)+12>>2]|0);t[(t[(t[f>>2]|0)+448>>2]|0)+16>>2]=t[(t[(t[f>>2]|0)+36>>2]|0)+28>>2];t[t[(t[f>>2]|0)+448>>2]>>2]=t[u>>2];Vp(t[f>>2]|0,t[(t[f>>2]|0)+448>>2]|0)}t[(t[f>>2]|0)+264>>2]=-1;if((((t[(t[f>>2]|0)+104>>2]|0)!=0?(t[(t[f>>2]|0)+12>>2]|0)!=0:0)?(t[(t[f>>2]|0)+8>>2]|0)!=0:0)?(t[(t[(t[f>>2]|0)+8>>2]|0)+44>>2]|0)!=0:0){n=bR((t[f>>2]|0)+108|0,t[(t[f>>2]|0)+8>>2]|0,t[u>>2]|0)|0;u=(t[f>>2]|0)+100|0;t[u>>2]=t[u>>2]&n}nE(t[f>>2]|0)|0;s=r;return}function Gz(e,i,r,n,u,a,o,c,l){e=e|0;i=i|0;r=r|0;n=n|0;u=u|0;a=a|0;o=o|0;c=c|0;l=l|0;var b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0,S=0,g=0,y=0,F=0,O=0,A=0,M=0,R=0,N=0,T=0,L=0,D=0,C=0,P=0;b=s;s=s+96|0;k=b+84|0;h=b+80|0;w=b+76|0;d=b+72|0;v=b+68|0;m=b+64|0;_=b+60|0;p=b+56|0;E=b+52|0;S=b+48|0;g=b+44|0;y=b+40|0;F=b+36|0;O=b+32|0;A=b+28|0;M=b+24|0;R=b+20|0;N=b+16|0;T=b+12|0;L=b+8|0;D=b+4|0;C=b;t[k>>2]=e;t[h>>2]=i;t[w>>2]=r;t[d>>2]=n;t[v>>2]=u;t[m>>2]=a;t[_>>2]=o;t[p>>2]=c;t[E>>2]=l;t[S>>2]=t[k>>2];t[F>>2]=0;t[R>>2]=0;if(!(t[k>>2]|0)){s=b;return}t[y>>2]=t[(t[S>>2]|0)+52>>2];do if((t[(t[S>>2]|0)+104>>2]|0)!=0?(t[(t[(t[S>>2]|0)+8>>2]|0)+48>>2]|0)==0:0){if(t[(t[(t[S>>2]|0)+8>>2]|0)+44>>2]|0){if(t[(t[(t[(t[S>>2]|0)+8>>2]|0)+44>>2]|0)+36>>2]|0)break;if(t[(t[(t[(t[S>>2]|0)+8>>2]|0)+44>>2]|0)+40>>2]|0)break;if(t[(t[(t[(t[S>>2]|0)+8>>2]|0)+44>>2]|0)+44>>2]|0)break;if(t[(t[(t[(t[S>>2]|0)+8>>2]|0)+44>>2]|0)+48>>2]|0)break}oj(t[S>>2]|0,522,197784,0,0);t[(t[S>>2]|0)+104>>2]=0}while(0);do if((t[w>>2]|0)!=0&(t[d>>2]|0)==0){if(!(t[(t[S>>2]|0)+364>>2]|0)){t[R>>2]=Ug(t[h>>2]|0,t[w>>2]|0,0,0)|0;break}t[L>>2]=hz(t[(t[S>>2]|0)+296>>2]|0,t[w>>2]|0,t[h>>2]|0)|0;if(t[L>>2]|0)t[h>>2]=t[L>>2]}while(0);L=t[S>>2]|0;if(t[(t[S>>2]|0)+372>>2]|0){t[g>>2]=t[L+372>>2];t[(t[S>>2]|0)+372>>2]=t[(t[g>>2]|0)+24>>2];k=(t[S>>2]|0)+368|0;t[k>>2]=(t[k>>2]|0)+-1;k=(t[g>>2]|0)+0|0;l=k+60|0;do{t[k>>2]=0;k=k+4|0}while((k|0)<(l|0));t[(t[g>>2]|0)+4>>2]=1;if(!(t[(t[S>>2]|0)+364>>2]|0)){if(!(t[R>>2]|0)){k=Yl(t[h>>2]|0)|0;t[(t[g>>2]|0)+8>>2]=k}else t[(t[g>>2]|0)+8>>2]=t[R>>2];if(!(t[(t[g>>2]|0)+8>>2]|0)){tj(t[S>>2]|0,197888);s=b;return}}else t[(t[g>>2]|0)+8>>2]=t[h>>2];if((t[18774]|0)!=0&(t[33968]|0)!=0)pAi[t[135872>>2]&511](t[g>>2]|0)}else{do if(!(t[L+364>>2]|0)){k=t[(t[S>>2]|0)+8>>2]|0;if(!(t[R>>2]|0)){t[g>>2]=Sy(k,0,t[h>>2]|0,0)|0;break}else{t[g>>2]=gy(k,0,t[R>>2]|0,0)|0;break}}else t[g>>2]=gy(t[(t[S>>2]|0)+8>>2]|0,0,t[h>>2]|0,0)|0;while(0);if(!(t[g>>2]|0)){tj(t[S>>2]|0,197888);s=b;return}}do if((t[(t[S>>2]|0)+280>>2]|0)!=0?(t[(t[S>>2]|0)+36>>2]|0)!=0:0)if((t[(t[(t[S>>2]|0)+36>>2]|0)+28>>2]|0)<65535){f[(t[g>>2]|0)+56>>1]=t[(t[(t[S>>2]|0)+36>>2]|0)+28>>2];break}else{f[(t[g>>2]|0)+56>>1]=-1;break}while(0);if(!(t[y>>2]|0))Hy(t[(t[S>>2]|0)+8>>2]|0,t[g>>2]|0)|0;t[N>>2]=0;t[T>>2]=0;while(1){if((t[T>>2]|0)>=(t[v>>2]|0))break;h=t[N>>2]|0;t[N>>2]=h+1;t[M>>2]=t[(t[m>>2]|0)+(h<<2)>>2];h=t[N>>2]|0;t[N>>2]=h+1;t[A>>2]=t[(t[m>>2]|0)+(h<<2)>>2];t[O>>2]=Wg(0,t[A>>2]|0,t[M>>2]|0)|0;if(t[O>>2]|0){h=t[O>>2]|0;if(!(t[F>>2]|0)){t[F>>2]=h;t[(t[g>>2]|0)+48>>2]=h}else{t[t[F>>2]>>2]=h;t[F>>2]=t[O>>2]}if((t[d>>2]|0)!=0?(t[w>>2]|0)==(t[M>>2]|0):0)t[(t[g>>2]|0)+36>>2]=t[O>>2];if(((((t[(t[S>>2]|0)+32>>2]|0)==0?(t[(t[S>>2]|0)+104>>2]|0)!=0:0)?(t[(t[S>>2]|0)+12>>2]|0)!=0:0)?(t[(t[S>>2]|0)+8>>2]|0)!=0:0)?(t[(t[(t[S>>2]|0)+8>>2]|0)+44>>2]|0)!=0:0){h=oR((t[S>>2]|0)+108|0,t[(t[S>>2]|0)+8>>2]|0,t[g>>2]|0,t[w>>2]|0,t[O>>2]|0,t[A>>2]|0)|0;L=(t[S>>2]|0)+100|0;t[L>>2]=t[L>>2]&h}}t[T>>2]=(t[T>>2]|0)+1;
	}t[(t[S>>2]|0)+264>>2]=-1;rE(t[S>>2]|0,t[g>>2]|0)|0;do if(t[y>>2]|0){A=t[y>>2]|0;M=t[g>>2]|0;if((t[(t[y>>2]|0)+4>>2]|0)==1){Hy(A,M)|0;break}else{By(A,M)|0;break}}while(0);if((t[p>>2]|0)!=0?(t[(t[S>>2]|0)+276>>2]&4|0)==0:0)t[_>>2]=(t[_>>2]|0)-(t[p>>2]|0);do if((t[d>>2]|0)!=0?(t[(t[g>>2]|0)+36>>2]|0)==0:0){p=wF(t[(t[S>>2]|0)+8>>2]|0,t[y>>2]|0,t[w>>2]|0)|0;t[(t[g>>2]|0)+36>>2]=p;if((t[(t[g>>2]|0)+36>>2]|0)==0?(Xl(t[w>>2]|0,197912)|0)!=0:0){p=wF(t[(t[S>>2]|0)+8>>2]|0,t[g>>2]|0,t[w>>2]|0)|0;t[(t[g>>2]|0)+36>>2]=p}if(!(t[(t[g>>2]|0)+36>>2]|0)){t[O>>2]=Wg(t[g>>2]|0,0,t[w>>2]|0)|0;if(!(t[O>>2]|0)){tj(t[S>>2]|0,197888);s=b;return}p=t[S>>2]|0;if(t[w>>2]|0){sj(p,201,197920,t[w>>2]|0,0);break}else{sj(p,201,197960,0,0);break}}}while(0);e:do if((t[_>>2]|0)>0){t[T>>2]=0;t[N>>2]=0;while(1){if((t[N>>2]|0)>=(t[_>>2]|0))break e;do if((t[(t[E>>2]|0)+((t[T>>2]|0)+1<<2)>>2]|0)!=0?(t[(t[E>>2]|0)+((t[T>>2]|0)+2<<2)>>2]|0)==0:0)if(t[(t[S>>2]|0)+364>>2]|0){t[D>>2]=hz(t[(t[S>>2]|0)+296>>2]|0,t[(t[E>>2]|0)+((t[T>>2]|0)+1<<2)>>2]|0,t[(t[E>>2]|0)+(t[T>>2]<<2)>>2]|0)|0;if(!(t[D>>2]|0)){P=83;break}bj(t[S>>2]|0,t[D>>2]|0,0,t[(t[E>>2]|0)+((t[T>>2]|0)+3<<2)>>2]|0,t[(t[E>>2]|0)+((t[T>>2]|0)+4<<2)>>2]|0);break}else{t[R>>2]=Ug(t[(t[E>>2]|0)+(t[T>>2]<<2)>>2]|0,t[(t[E>>2]|0)+((t[T>>2]|0)+1<<2)>>2]|0,0,0)|0;if(!(t[R>>2]|0)){P=83;break}bj(t[S>>2]|0,t[R>>2]|0,0,t[(t[E>>2]|0)+((t[T>>2]|0)+3<<2)>>2]|0,t[(t[E>>2]|0)+((t[T>>2]|0)+4<<2)>>2]|0);pAi[t[135736>>2]&511](t[R>>2]|0);break}else P=83;while(0);if((P|0)==83){P=0;bj(t[S>>2]|0,t[(t[E>>2]|0)+(t[T>>2]<<2)>>2]|0,t[(t[E>>2]|0)+((t[T>>2]|0)+1<<2)>>2]|0,t[(t[E>>2]|0)+((t[T>>2]|0)+3<<2)>>2]|0,t[(t[E>>2]|0)+((t[T>>2]|0)+4<<2)>>2]|0)}t[N>>2]=(t[N>>2]|0)+1;t[T>>2]=(t[T>>2]|0)+5}}while(0);if(!(t[(t[S>>2]|0)+104>>2]|0)){s=b;return}if((t[(t[S>>2]|0)+136>>2]|0)!=-1412623820){s=b;return}t[C>>2]=vR((t[S>>2]|0)+108|0,t[(t[S>>2]|0)+8>>2]|0)|0;if((t[C>>2]|0)<=0)t[(t[S>>2]|0)+100>>2]=0;if((t[C>>2]|0)<0)t[(t[S>>2]|0)+12>>2]=0;C=kR((t[S>>2]|0)+108|0,t[(t[S>>2]|0)+8>>2]|0)|0;T=(t[S>>2]|0)+100|0;t[T>>2]=t[T>>2]&C;t[(t[S>>2]|0)+136>>2]=-1412623819;s=b;return}function Wz(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,u=0,a=0,o=0,c=0;f=s;s=s+48|0;u=f+40|0;a=f+24|0;o=f+4|0;c=f;t[u>>2]=e;t[f+36>>2]=i;t[f+32>>2]=r;t[f+28>>2]=n;t[a>>2]=t[u>>2];if(!(t[u>>2]|0)){s=f;return}t[c>>2]=t[(t[a>>2]|0)+52>>2];if((t[c>>2]|0)!=0?(t[(t[a>>2]|0)+68>>2]|0)!=0:0){t[o+12>>2]=(t[(t[(t[a>>2]|0)+36>>2]|0)+16>>2]|0)-(t[(t[(t[a>>2]|0)+36>>2]|0)+12>>2]|0);t[o+16>>2]=t[(t[(t[a>>2]|0)+36>>2]|0)+28>>2];t[o>>2]=t[c>>2];Vp(t[a>>2]|0,o)}t[(t[a>>2]|0)+264>>2]=-1;if((((t[(t[a>>2]|0)+104>>2]|0)!=0?(t[(t[a>>2]|0)+12>>2]|0)!=0:0)?(t[(t[a>>2]|0)+8>>2]|0)!=0:0)?(t[(t[(t[a>>2]|0)+8>>2]|0)+44>>2]|0)!=0:0){o=bR((t[a>>2]|0)+108|0,t[(t[a>>2]|0)+8>>2]|0,t[c>>2]|0)|0;c=(t[a>>2]|0)+100|0;t[c>>2]=t[c>>2]&o}nE(t[a>>2]|0)|0;s=f;return}function Kz(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,a=0,o=0;r=s;s=s+16|0;n=r+12|0;f=r+8|0;a=r+4|0;o=r;t[n>>2]=e;t[f>>2]=i;t[a>>2]=t[n>>2];if(!(t[n>>2]|0)){s=r;return}n=t[(t[a>>2]|0)+8>>2]|0;i=t[f>>2]|0;if((u[t[f>>2]>>0]|0|0)==35)t[o>>2]=Fy(n,i)|0;else t[o>>2]=cy(n,i)|0;if(Hy(t[(t[a>>2]|0)+52>>2]|0,t[o>>2]|0)|0){s=r;return}ry(t[o>>2]|0);s=r;return}function Xz(e,i,r){e=e|0;i=i|0;r=r|0;var f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0;f=s;s=s+32|0;u=f+28|0;a=f+24|0;o=f+20|0;c=f+16|0;l=f+12|0;b=f+8|0;k=f+4|0;h=f;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;t[c>>2]=t[u>>2];if(!(t[u>>2]|0)){s=f;return}if(!(t[(t[c>>2]|0)+52>>2]|0)){s=f;return}t[l>>2]=t[(t[(t[c>>2]|0)+52>>2]|0)+16>>2];if(!(t[l>>2]|0)){t[l>>2]=kj(t[c>>2]|0,t[a>>2]|0,t[o>>2]|0)|0;if(t[l>>2]|0){t[(t[(t[c>>2]|0)+52>>2]|0)+12>>2]=t[l>>2];t[(t[(t[c>>2]|0)+52>>2]|0)+16>>2]=t[l>>2];t[(t[l>>2]|0)+20>>2]=t[(t[c>>2]|0)+52>>2];t[(t[l>>2]|0)+32>>2]=t[(t[(t[c>>2]|0)+52>>2]|0)+32>>2];t[(t[c>>2]|0)+260>>2]=t[o>>2];t[(t[c>>2]|0)+264>>2]=(t[o>>2]|0)+1;s=f;return}else{tj(t[c>>2]|0,198e3);s=f;return}}if((t[l>>2]|0)!=0?(t[(t[l>>2]|0)+4>>2]|0)==3:0)w=(t[(t[l>>2]|0)+8>>2]|0)==75104;else w=0;t[b>>2]=w&1;if((t[b>>2]|0)!=0?(t[(t[c>>2]|0)+264>>2]|0)!=0:0){if((t[(t[l>>2]|0)+40>>2]|0)!=((t[l>>2]|0)+44|0)){if((t[(t[c>>2]|0)+264>>2]|0)==((t[(t[c>>2]|0)+260>>2]|0)+1|0)?(wz(t[(t[c>>2]|0)+296>>2]|0,t[(t[l>>2]|0)+40>>2]|0)|0)!=0:0){w=Yl(t[(t[l>>2]|0)+40>>2]|0)|0;t[(t[l>>2]|0)+40>>2]=w}}else{w=Yl(t[(t[l>>2]|0)+40>>2]|0)|0;t[(t[l>>2]|0)+40>>2]=w;t[(t[l>>2]|0)+44>>2]=0}w=t[c>>2]|0;if(!(t[(t[l>>2]|0)+40>>2]|0)){tj(w,198024);s=f;return}if(((t[w+260>>2]|0)+(t[o>>2]|0)|0)>>>0>1e7?(t[(t[c>>2]|0)+360>>2]&524288|0)==0:0){tj(t[c>>2]|0,198072);s=f;return}if((t[(t[c>>2]|0)+260>>2]|0)>>>0<=(-1-(t[o>>2]|0)|0)>>>0?((t[(t[c>>2]|0)+264>>2]|0)+(t[o>>2]|0)|0)>>>0<=2147483647:0){do if(((t[(t[c>>2]|0)+260>>2]|0)+(t[o>>2]|0)|0)>=(t[(t[c>>2]|0)+264>>2]|0)){t[h>>2]=(t[(t[c>>2]|0)+264>>2]|0)+(t[o>>2]|0);t[h>>2]=t[h>>2]<<1;t[k>>2]=MAi[t[135760>>2]&511](t[(t[l>>2]|0)+40>>2]|0,t[h>>2]|0)|0;if(t[k>>2]|0){t[(t[c>>2]|0)+264>>2]=t[h>>2];t[(t[l>>2]|0)+40>>2]=t[k>>2];break}tj(t[c>>2]|0,198e3);s=f;return}while(0);YY((t[(t[l>>2]|0)+40>>2]|0)+(t[(t[c>>2]|0)+260>>2]|0)|0,t[a>>2]|0,t[o>>2]|0)|0;k=(t[c>>2]|0)+260|0;t[k>>2]=(t[k>>2]|0)+(t[o>>2]|0);n[(t[(t[l>>2]|0)+40>>2]|0)+(t[(t[c>>2]|0)+260>>2]|0)>>0]=0;s=f;return}tj(t[c>>2]|0,198112);s=f;return}if(t[b>>2]|0){if(SF(t[l>>2]|0,t[a>>2]|0,t[o>>2]|0)|0)tj(t[c>>2]|0,198e3);if(!(t[(t[(t[c>>2]|0)+52>>2]|0)+12>>2]|0)){s=f;return}b=rs(t[(t[l>>2]|0)+40>>2]|0)|0;t[(t[c>>2]|0)+260>>2]=b;t[(t[c>>2]|0)+264>>2]=(t[(t[c>>2]|0)+260>>2]|0)+1;s=f;return}else{t[l>>2]=kj(t[c>>2]|0,t[a>>2]|0,t[o>>2]|0)|0;if(!(t[l>>2]|0)){s=f;return}Hy(t[(t[c>>2]|0)+52>>2]|0,t[l>>2]|0)|0;if(!(t[(t[(t[c>>2]|0)+52>>2]|0)+12>>2]|0)){s=f;return}t[(t[c>>2]|0)+260>>2]=t[o>>2];t[(t[c>>2]|0)+264>>2]=(t[o>>2]|0)+1;s=f;return}}function Zz(e,i,r){e=e|0;i=i|0;r=r|0;var n=0;n=s;s=s+16|0;t[n+8>>2]=e;t[n+4>>2]=i;t[n>>2]=r;s=n;return}function Jz(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,u=0,a=0,o=0,c=0,l=0,b=0;n=s;s=s+32|0;u=n+20|0;a=n+16|0;o=n+12|0;c=n+8|0;l=n+4|0;b=n;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;t[c>>2]=t[u>>2];if(!(t[u>>2]|0)){s=n;return}t[b>>2]=t[(t[c>>2]|0)+52>>2];t[l>>2]=_y(t[(t[c>>2]|0)+8>>2]|0,t[a>>2]|0,t[o>>2]|0)|0;if(!(t[l>>2]|0)){s=n;return}do if((t[(t[c>>2]|0)+280>>2]|0)!=0?(t[(t[c>>2]|0)+36>>2]|0)!=0:0)if((t[(t[(t[c>>2]|0)+36>>2]|0)+28>>2]|0)<65535){f[(t[l>>2]|0)+56>>1]=t[(t[(t[c>>2]|0)+36>>2]|0)+28>>2];break}else{f[(t[l>>2]|0)+56>>1]=-1;break}while(0);o=t[c>>2]|0;if((t[(t[c>>2]|0)+216>>2]|0)==1){Hy(t[(t[o+8>>2]|0)+44>>2]|0,t[l>>2]|0)|0;s=n;return}if((t[o+216>>2]|0)==2){Hy(t[(t[(t[c>>2]|0)+8>>2]|0)+48>>2]|0,t[l>>2]|0)|0;s=n;return}if(!(t[b>>2]|0)){Hy(t[(t[c>>2]|0)+8>>2]|0,t[l>>2]|0)|0;s=n;return}c=t[b>>2]|0;o=t[l>>2]|0;if((t[(t[b>>2]|0)+4>>2]|0)==1){Hy(c,o)|0;s=n;return}else{By(c,o)|0;s=n;return}}function Qz(e,i){e=e|0;i=i|0;var r=0,n=0,u=0,a=0,o=0,c=0;r=s;s=s+32|0;n=r+16|0;u=r+12|0;a=r+8|0;o=r+4|0;c=r;t[n>>2]=e;t[u>>2]=i;t[a>>2]=t[n>>2];if(!(t[n>>2]|0)){s=r;return}t[c>>2]=t[(t[a>>2]|0)+52>>2];t[o>>2]=Ry(t[(t[a>>2]|0)+8>>2]|0,t[u>>2]|0)|0;if(!(t[o>>2]|0)){s=r;return}do if((t[(t[a>>2]|0)+280>>2]|0)!=0?(t[(t[a>>2]|0)+36>>2]|0)!=0:0)if((t[(t[(t[a>>2]|0)+36>>2]|0)+28>>2]|0)<65535){f[(t[o>>2]|0)+56>>1]=t[(t[(t[a>>2]|0)+36>>2]|0)+28>>2];break}else{f[(t[o>>2]|0)+56>>1]=-1;break}while(0);u=t[a>>2]|0;if((t[(t[a>>2]|0)+216>>2]|0)==1){Hy(t[(t[u+8>>2]|0)+44>>2]|0,t[o>>2]|0)|0;s=r;return}if((t[u+216>>2]|0)==2){Hy(t[(t[(t[a>>2]|0)+8>>2]|0)+48>>2]|0,t[o>>2]|0)|0;s=r;return}if(!(t[c>>2]|0)){Hy(t[(t[a>>2]|0)+8>>2]|0,t[o>>2]|0)|0;s=r;return}a=t[c>>2]|0;u=t[o>>2]|0;if((t[(t[c>>2]|0)+4>>2]|0)==1){Hy(a,u)|0;s=r;return}else{By(a,u)|0;s=r;return}}function $z(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,l=0;n=s;s=s+32|0;f=n+20|0;u=n+16|0;a=n+12|0;o=n+8|0;c=n+4|0;l=n;t[f>>2]=e;t[u>>2]=i;t[a>>2]=r;t[o>>2]=t[f>>2];if(!(t[f>>2]|0)){s=n;return}t[l>>2]=Uy(t[(t[o>>2]|0)+52>>2]|0)|0;if((t[l>>2]|0)!=0?(t[(t[l>>2]|0)+4>>2]|0)==4:0){SF(t[l>>2]|0,t[u>>2]|0,t[a>>2]|0)|0;s=n;return}t[c>>2]=My(t[(t[o>>2]|0)+8>>2]|0,t[u>>2]|0,t[a>>2]|0)|0;Hy(t[(t[o>>2]|0)+52>>2]|0,t[c>>2]|0)|0;s=n;return}function ej(e){e=e|0;var i=0,r=0,n=0,f=0,u=0;i=s;s=s+16|0;r=i+8|0;n=i+4|0;f=i;t[n>>2]=e;t[f>>2]=t[49538];if((t[n>>2]|0)!=1&(t[n>>2]|0)!=2){t[r>>2]=-1;u=t[r>>2]|0;s=i;return u|0}else{t[49538]=t[n>>2];t[r>>2]=t[f>>2];u=t[r>>2]|0;s=i;return u|0}return 0}function ij(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0;r=s;s=s+16|0;n=r+8|0;f=r+4|0;u=r;t[f>>2]=e;t[u>>2]=i;if(!(t[f>>2]|0)){t[n>>2]=-1;a=t[n>>2]|0;s=r;return a|0}do if((t[u>>2]|0)==2){t[(t[f>>2]|0)+56>>2]=0;t[(t[f>>2]|0)+60>>2]=0;t[(t[f>>2]|0)+116>>2]=387;t[(t[f>>2]|0)+120>>2]=388;t[(t[f>>2]|0)+124>>2]=0;t[(t[f>>2]|0)+108>>2]=-554844497}else{if((t[u>>2]|0)==1){t[(t[f>>2]|0)+56>>2]=50;t[(t[f>>2]|0)+60>>2]=51;t[(t[f>>2]|0)+108>>2]=1;break}t[n>>2]=-1;a=t[n>>2]|0;s=r;return a|0}while(0);t[t[f>>2]>>2]=36;t[(t[f>>2]|0)+104>>2]=60;t[(t[f>>2]|0)+4>>2]=37;t[(t[f>>2]|0)+8>>2]=38;t[(t[f>>2]|0)+12>>2]=39;t[(t[f>>2]|0)+16>>2]=40;t[(t[f>>2]|0)+20>>2]=41;t[(t[f>>2]|0)+96>>2]=58;t[(t[f>>2]|0)+24>>2]=42;t[(t[f>>2]|0)+32>>2]=44;t[(t[f>>2]|0)+36>>2]=45;t[(t[f>>2]|0)+28>>2]=43;t[(t[f>>2]|0)+40>>2]=46;t[(t[f>>2]|0)+44>>2]=47;t[(t[f>>2]|0)+48>>2]=48;t[(t[f>>2]|0)+52>>2]=49;t[(t[f>>2]|0)+64>>2]=52;t[(t[f>>2]|0)+68>>2]=53;t[(t[f>>2]|0)+100>>2]=59;t[(t[f>>2]|0)+72>>2]=53;t[(t[f>>2]|0)+76>>2]=54;t[(t[f>>2]|0)+80>>2]=55;t[(t[f>>2]|0)+84>>2]=56;t[(t[f>>2]|0)+88>>2]=57;t[(t[f>>2]|0)+92>>2]=57;t[n>>2]=0;a=t[n>>2]|0;s=r;return a|0}function rj(){var e=0;e=s;ij(135968,1)|0;s=e;return}function nj(e){e=e|0;var i=0,r=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if(!(t[r>>2]|0)){s=i;return}if(t[(t[r>>2]|0)+108>>2]|0){s=i;return}t[t[r>>2]>>2]=36;t[(t[r>>2]|0)+104>>2]=0;t[(t[r>>2]|0)+4>>2]=0;t[(t[r>>2]|0)+8>>2]=0;t[(t[r>>2]|0)+12>>2]=0;t[(t[r>>2]|0)+16>>2]=0;t[(t[r>>2]|0)+20>>2]=41;t[(t[r>>2]|0)+96>>2]=0;t[(t[r>>2]|0)+24>>2]=0;t[(t[r>>2]|0)+32>>2]=0;t[(t[r>>2]|0)+36>>2]=0;t[(t[r>>2]|0)+28>>2]=0;t[(t[r>>2]|0)+40>>2]=0;t[(t[r>>2]|0)+44>>2]=47;t[(t[r>>2]|0)+48>>2]=48;t[(t[r>>2]|0)+52>>2]=49;t[(t[r>>2]|0)+56>>2]=50;t[(t[r>>2]|0)+60>>2]=51;t[(t[r>>2]|0)+64>>2]=0;t[(t[r>>2]|0)+68>>2]=53;t[(t[r>>2]|0)+100>>2]=59;t[(t[r>>2]|0)+72>>2]=65;t[(t[r>>2]|0)+76>>2]=54;t[(t[r>>2]|0)+80>>2]=55;t[(t[r>>2]|0)+84>>2]=56;t[(t[r>>2]|0)+88>>2]=57;t[(t[r>>2]|0)+92>>2]=57;t[(t[r>>2]|0)+108>>2]=1;s=i;return}function fj(){var e=0;e=s;nj(136096);s=e;return}function tj(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0;r=s;s=s+32|0;n=r;f=r+20|0;u=r+16|0;a=r+12|0;o=r+8|0;t[f>>2]=e;t[u>>2]=i;t[a>>2]=0;t[o>>2]=198680;if(!(t[f>>2]|0)){i=t[a>>2]|0;e=t[f>>2]|0;c=t[o>>2]|0;l=t[u>>2]|0;t[n>>2]=t[o>>2];t[n+4>>2]=0;cp(i,0,0,e,0,1,2,2,0,0,c,0,0,0,0,l,n);s=r;return}t[(t[f>>2]|0)+84>>2]=2;if((t[t[f>>2]>>2]|0)!=0?(t[(t[t[f>>2]>>2]|0)+108>>2]|0)==-554844497:0)t[a>>2]=t[(t[t[f>>2]>>2]|0)+124>>2];l=t[a>>2]|0;a=t[(t[f>>2]|0)+112>>2]|0;c=t[(t[f>>2]|0)+108>>2]|0;e=t[f>>2]|0;i=t[o>>2]|0;b=t[u>>2]|0;t[n>>2]=t[o>>2];t[n+4>>2]=0;cp(l,a,c,e,0,1,2,2,0,0,i,0,0,0,0,b,n);t[(t[f>>2]|0)+84>>2]=2;t[(t[f>>2]|0)+172>>2]=-1;t[(t[f>>2]|0)+212>>2]=1;s=r;return}function uj(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;var u=0,a=0,o=0,c=0,l=0,b=0,k=0;u=s;s=s+32|0;a=u;o=u+24|0;c=u+20|0;l=u+16|0;b=u+12|0;k=u+8|0;t[o>>2]=e;t[c>>2]=i;t[l>>2]=r;t[b>>2]=n;t[k>>2]=f;if(((t[o>>2]|0)!=0?(t[(t[o>>2]|0)+212>>2]|0)!=0:0)?(t[(t[o>>2]|0)+172>>2]|0)==-1:0){s=u;return}if(t[o>>2]|0)t[(t[o>>2]|0)+84>>2]=t[c>>2];f=t[o>>2]|0;n=t[c>>2]|0;c=t[b>>2]|0;r=t[k>>2]|0;i=t[l>>2]|0;l=t[k>>2]|0;t[a>>2]=t[b>>2];t[a+4>>2]=l;cp(0,0,0,f,0,1,n,3,0,0,c,r,0,0,0,i,a);if(!(t[o>>2]|0)){s=u;return}t[(t[o>>2]|0)+12>>2]=0;t[(t[o>>2]|0)+100>>2]=0;if(t[(t[o>>2]|0)+288>>2]|0){s=u;return}t[(t[o>>2]|0)+212>>2]=1;s=u;return}function aj(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,u=0,a=0,o=0,c=0,l=0;f=s;s=s+32|0;u=f;a=f+16|0;o=f+12|0;c=f+8|0;l=f+4|0;t[a>>2]=e;t[o>>2]=i;t[c>>2]=r;t[l>>2]=n;if(((t[a>>2]|0)!=0?(t[(t[a>>2]|0)+212>>2]|0)!=0:0)?(t[(t[a>>2]|0)+172>>2]|0)==-1:0){s=f;return}if(t[a>>2]|0)t[(t[a>>2]|0)+84>>2]=t[o>>2];n=t[a>>2]|0;a=t[o>>2]|0;o=t[l>>2]|0;r=t[c>>2]|0;t[u>>2]=t[l>>2];cp(0,0,0,n,0,1,a,1,0,0,o,0,0,0,0,r,u);s=f;return}function oj(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;var u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0;u=s;s=s+32|0;a=u;o=u+28|0;c=u+24|0;l=u+20|0;b=u+16|0;k=u+12|0;h=u+8|0;t[o>>2]=e;t[c>>2]=i;t[l>>2]=r;t[b>>2]=n;t[k>>2]=f;t[h>>2]=0;if(((t[o>>2]|0)!=0?(t[(t[o>>2]|0)+212>>2]|0)!=0:0)?(t[(t[o>>2]|0)+172>>2]|0)==-1:0){s=u;return}if(!(t[o>>2]|0)){f=t[h>>2]|0;n=t[o>>2]|0;r=t[c>>2]|0;i=t[b>>2]|0;e=t[k>>2]|0;w=t[l>>2]|0;d=t[k>>2]|0;t[a>>2]=t[b>>2];t[a+4>>2]=d;cp(f,0,0,n,0,4,r,2,0,0,i,e,0,0,0,w,a);s=u;return}t[(t[o>>2]|0)+84>>2]=t[c>>2];if((t[t[o>>2]>>2]|0)!=0?(t[(t[t[o>>2]>>2]|0)+108>>2]|0)==-554844497:0)t[h>>2]=t[(t[t[o>>2]>>2]|0)+124>>2];w=t[h>>2]|0;h=t[(t[o>>2]|0)+112>>2]|0;e=t[(t[o>>2]|0)+108>>2]|0;i=t[o>>2]|0;r=t[c>>2]|0;c=t[b>>2]|0;n=t[k>>2]|0;f=t[l>>2]|0;l=t[k>>2]|0;t[a>>2]=t[b>>2];t[a+4>>2]=l;cp(w,h,e,i,0,4,r,2,0,0,c,n,0,0,0,f,a);t[(t[o>>2]|0)+100>>2]=0;s=u;return}function cj(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0;f=s;s=s+112|0;u=f+44|0;a=f+40|0;o=f+36|0;c=f+32|0;l=f+28|0;b=f+24|0;k=f+20|0;h=f+16|0;w=f+12|0;d=f+8|0;v=f+4|0;m=f+48|0;_=f;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;t[c>>2]=n;t[k>>2]=1;t[l>>2]=JM(t[(t[(t[u>>2]|0)+8>>2]|0)+44>>2]|0,t[a>>2]|0,t[o>>2]|0)|0;if(!(t[l>>2]|0)){t[l>>2]=JM(t[(t[(t[u>>2]|0)+8>>2]|0)+48>>2]|0,t[a>>2]|0,t[o>>2]|0)|0;t[k>>2]=0}e:while(1){if(!(t[l>>2]|0)){p=48;break}t[w>>2]=t[(t[l>>2]|0)+44>>2];i:do if(((t[(t[(t[u>>2]|0)+8>>2]|0)+40>>2]|0)==1?(t[(t[(t[u>>2]|0)+8>>2]|0)+48>>2]|0)!=0:0)?(t[w>>2]|0)!=0?(t[(t[u>>2]|0)+104>>2]|0)!=0:0:0){while(1){if(((t[(t[w>>2]|0)+48>>2]|0)!=0?(n=QM(t[(t[(t[u>>2]|0)+8>>2]|0)+48>>2]|0,t[(t[w>>2]|0)+60>>2]|0,t[(t[w>>2]|0)+8>>2]|0,t[(t[w>>2]|0)+56>>2]|0)|0,(n|0)==(t[w>>2]|0)):0)?(QM(t[(t[(t[u>>2]|0)+8>>2]|0)+44>>2]|0,t[(t[w>>2]|0)+60>>2]|0,t[(t[w>>2]|0)+8>>2]|0,t[(t[w>>2]|0)+56>>2]|0)|0)==0:0){n=t[w>>2]|0;if(t[(t[w>>2]|0)+56>>2]|0){t[d>>2]=Yl(t[n+56>>2]|0)|0;t[d>>2]=us(t[d>>2]|0,198608)|0;t[d>>2]=us(t[d>>2]|0,t[(t[w>>2]|0)+8>>2]|0)|0}else t[d>>2]=Yl(t[n+8>>2]|0)|0;if(!(t[d>>2]|0))break;t[b>>2]=0;r:do if(t[c>>2]|0){t[h>>2]=0;t[b>>2]=t[(t[c>>2]|0)+(t[h>>2]<<2)>>2];while(1){if(!(t[b>>2]|0))break r;if(Xl(t[b>>2]|0,t[d>>2]|0)|0)break r;t[h>>2]=(t[h>>2]|0)+2;t[b>>2]=t[(t[c>>2]|0)+(t[h>>2]<<2)>>2]}}while(0);if(!(t[b>>2]|0))oj(t[u>>2]|0,538,198616,t[d>>2]|0,t[(t[w>>2]|0)+60>>2]|0);pAi[t[135736>>2]&511](t[d>>2]|0)}t[w>>2]=t[(t[w>>2]|0)+36>>2];if(!(t[w>>2]|0))break i}tj(t[u>>2]|0,197824)}while(0);t[w>>2]=t[(t[l>>2]|0)+44>>2];while(1){if(!(t[w>>2]|0))break;i:do if(t[(t[w>>2]|0)+48>>2]|0){if(!((t[(t[w>>2]|0)+56>>2]|0)!=0?(Xl(t[(t[w>>2]|0)+56>>2]|0,198248)|0)!=0:0))p=29;do if((p|0)==29){p=0;if((t[(t[w>>2]|0)+56>>2]|0)==0?(Xl(t[(t[w>>2]|0)+8>>2]|0,198248)|0)!=0:0)break;if(!(t[(t[u>>2]|0)+276>>2]&4))break i}while(0);t[v>>2]=QM(t[(t[(t[u>>2]|0)+8>>2]|0)+44>>2]|0,t[(t[w>>2]|0)+60>>2]|0,t[(t[w>>2]|0)+8>>2]|0,t[(t[w>>2]|0)+56>>2]|0)|0;if((t[v>>2]|0)==0?1:(t[v>>2]|0)==(t[w>>2]|0)){t[_>>2]=Ug(t[(t[w>>2]|0)+8>>2]|0,t[(t[w>>2]|0)+56>>2]|0,m,50)|0;if(!(t[_>>2]|0)){p=34;break e}t[b>>2]=0;r:do if(t[c>>2]|0){t[h>>2]=0;t[b>>2]=t[(t[c>>2]|0)+(t[h>>2]<<2)>>2];while(1){if(!(t[b>>2]|0))break r;if(Xl(t[b>>2]|0,t[_>>2]|0)|0)break r;t[h>>2]=(t[h>>2]|0)+2;t[b>>2]=t[(t[c>>2]|0)+(t[h>>2]<<2)>>2]}}while(0);if(!(t[b>>2]|0))lj(t[u>>2]|0,t[_>>2]|0,t[(t[w>>2]|0)+48>>2]|0,t[o>>2]|0);if((t[_>>2]|0)!=(m|0)?(t[_>>2]|0)!=(t[(t[w>>2]|0)+8>>2]|0):0)pAi[t[135736>>2]&511](t[_>>2]|0)}}while(0);t[w>>2]=t[(t[w>>2]|0)+36>>2]}if((t[k>>2]|0)!=1){p=48;break}t[l>>2]=JM(t[(t[(t[u>>2]|0)+8>>2]|0)+48>>2]|0,t[a>>2]|0,t[o>>2]|0)|0;t[k>>2]=0}if((p|0)==34){tj(t[u>>2]|0,197824);s=f;return}else if((p|0)==48){s=f;return}}function lj(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0,S=0,g=0,y=0,F=0,O=0,A=0,M=0,R=0;f=s;s=s+96|0;a=f;o=f+80|0;c=f+76|0;l=f+72|0;b=f+68|0;k=f+64|0;h=f+60|0;w=f+56|0;d=f+52|0;v=f+48|0;m=f+44|0;_=f+40|0;p=f+36|0;E=f+32|0;S=f+28|0;g=f+24|0;y=f+20|0;F=f+16|0;O=f+12|0;A=f+8|0;M=f+4|0;t[o>>2]=e;t[c>>2]=i;t[l>>2]=r;t[b>>2]=n;t[k>>2]=t[o>>2];if(!(t[(t[k>>2]|0)+32>>2]|0)){t[w>>2]=wE(t[k>>2]|0,t[c>>2]|0,d)|0;if((t[w>>2]|0)!=0?(u[t[w>>2]>>0]|0|0)==0:0){o=(Xl(t[d>>2]|0,198248)|0)!=0;n=t[k>>2]|0;r=t[c>>2]|0;if(o)hj(n,35,198256,r,0);else sj(n,106,198296,r,0);if(t[d>>2]|0)pAi[t[135736>>2]&511](t[d>>2]|0);t[d>>2]=0;pAi[t[135736>>2]&511](t[w>>2]|0);t[w>>2]=Yl(t[c>>2]|0)|0}}else{t[w>>2]=Yl(t[c>>2]|0)|0;t[d>>2]=0;t[m>>2]=0}r=t[k>>2]|0;if(!(t[w>>2]|0)){tj(r,197824);if(!(t[d>>2]|0)){s=f;return}pAi[t[135736>>2]&511](t[d>>2]|0);s=f;return}if((t[r+32>>2]|0)!=0&(t[l>>2]|0)==0?(Ki(t[c>>2]|0)|0)!=0:0){t[v>>2]=Yl(t[c>>2]|0)|0;t[l>>2]=t[v>>2]}else{t[(t[k>>2]|0)+144>>2]=1;t[v>>2]=nR((t[k>>2]|0)+108|0,t[(t[k>>2]|0)+8>>2]|0,t[(t[k>>2]|0)+52>>2]|0,t[c>>2]|0,t[l>>2]|0)|0;if((t[(t[k>>2]|0)+144>>2]|0)!=1)t[(t[k>>2]|0)+100>>2]=0;if(t[v>>2]|0)t[l>>2]=t[v>>2]}if((((((((t[d>>2]|0)==0?(t[(t[k>>2]|0)+32>>2]|0)==0:0)?(u[t[w>>2]>>0]|0|0)==120:0)?(u[(t[w>>2]|0)+1>>0]|0|0)==109:0)?(u[(t[w>>2]|0)+2>>0]|0|0)==108:0)?(u[(t[w>>2]|0)+3>>0]|0|0)==110:0)?(u[(t[w>>2]|0)+4>>0]|0|0)==115:0)?(u[(t[w>>2]|0)+5>>0]|0|0)==0:0){if(!(t[(t[k>>2]|0)+16>>2]|0)){r=(t[k>>2]|0)+248|0;t[r>>2]=(t[r>>2]|0)+1;t[p>>2]=hE(t[k>>2]|0,t[l>>2]|0,1,0,0,0)|0;r=(t[k>>2]|0)+248|0;t[r>>2]=(t[r>>2]|0)+-1;if(!(t[p>>2]|0)){tj(t[k>>2]|0,197824);if(!(t[w>>2]|0)){s=f;return}pAi[t[135736>>2]&511](t[w>>2]|0);s=f;return}}else t[p>>2]=t[l>>2];do if(u[t[p>>2]>>0]|0){t[E>>2]=IA(t[p>>2]|0)|0;if(!(t[E>>2]|0)){if(!(t[t[k>>2]>>2]|0))break;if(!(t[(t[t[k>>2]>>2]|0)+84>>2]|0))break;r=t[(t[t[k>>2]>>2]|0)+84>>2]|0;n=t[(t[k>>2]|0)+4>>2]|0;t[a>>2]=t[p>>2];yAi[r&511](n,198344,a);break}if(((t[t[E>>2]>>2]|0)==0?(t[t[k>>2]>>2]|0)!=0:0)?(t[(t[t[k>>2]>>2]|0)+84>>2]|0)!=0:0){n=t[(t[t[k>>2]>>2]|0)+84>>2]|0;r=t[(t[k>>2]|0)+4>>2]|0;t[a>>2]=t[p>>2];yAi[n&511](r,198376,a)}xA(t[E>>2]|0)}while(0);t[_>>2]=Wg(t[(t[k>>2]|0)+52>>2]|0,t[p>>2]|0,0)|0;if(((((t[_>>2]|0)!=0?(t[(t[k>>2]|0)+104>>2]|0)!=0:0)?(t[(t[k>>2]|0)+12>>2]|0)!=0:0)?(t[(t[k>>2]|0)+8>>2]|0)!=0:0)?(t[(t[(t[k>>2]|0)+8>>2]|0)+44>>2]|0)!=0:0){E=oR((t[k>>2]|0)+108|0,t[(t[k>>2]|0)+8>>2]|0,t[(t[k>>2]|0)+52>>2]|0,t[b>>2]|0,t[_>>2]|0,t[p>>2]|0)|0;_=(t[k>>2]|0)+100|0;t[_>>2]=t[_>>2]&E}if(t[w>>2]|0)pAi[t[135736>>2]&511](t[w>>2]|0);if(t[v>>2]|0)pAi[t[135736>>2]&511](t[v>>2]|0);if((t[p>>2]|0)==(t[l>>2]|0)){s=f;return}pAi[t[135736>>2]&511](t[p>>2]|0);s=f;return}if((((((((t[d>>2]|0)!=0?(t[(t[k>>2]|0)+32>>2]|0)==0:0)?(u[t[d>>2]>>0]|0|0)==120:0)?(u[(t[d>>2]|0)+1>>0]|0|0)==109:0)?(u[(t[d>>2]|0)+2>>0]|0|0)==108:0)?(u[(t[d>>2]|0)+3>>0]|0|0)==110:0)?(u[(t[d>>2]|0)+4>>0]|0|0)==115:0)?(u[(t[d>>2]|0)+5>>0]|0|0)==0:0){if(!(t[(t[k>>2]|0)+16>>2]|0)){p=(t[k>>2]|0)+248|0;t[p>>2]=(t[p>>2]|0)+1;t[g>>2]=hE(t[k>>2]|0,t[l>>2]|0,1,0,0,0)|0;p=(t[k>>2]|0)+248|0;t[p>>2]=(t[p>>2]|0)+-1;if(!(t[g>>2]|0)){tj(t[k>>2]|0,197824);pAi[t[135736>>2]&511](t[d>>2]|0);if(!(t[w>>2]|0)){s=f;return}pAi[t[135736>>2]&511](t[w>>2]|0);s=f;return}}else t[g>>2]=t[l>>2];if(!(u[t[g>>2]>>0]|0))hj(t[k>>2]|0,204,198408,t[w>>2]|0,0);do if((t[(t[k>>2]|0)+268>>2]|0)!=0?(u[t[g>>2]>>0]|0|0)!=0:0){t[y>>2]=IA(t[g>>2]|0)|0;if(!(t[y>>2]|0)){sj(t[k>>2]|0,99,198448,t[w>>2]|0,t[l>>2]|0);break}if(!(t[t[y>>2]>>2]|0))sj(t[k>>2]|0,100,198480,t[w>>2]|0,t[l>>2]|0);xA(t[y>>2]|0)}while(0);t[S>>2]=Wg(t[(t[k>>2]|0)+52>>2]|0,t[g>>2]|0,t[w>>2]|0)|0;pAi[t[135736>>2]&511](t[d>>2]|0);do if((((t[S>>2]|0)!=0?(t[(t[k>>2]|0)+104>>2]|0)!=0:0)?(t[(t[k>>2]|0)+12>>2]|0)!=0:0)?(t[(t[k>>2]|0)+8>>2]|0)!=0:0){if(!(t[(t[(t[k>>2]|0)+8>>2]|0)+44>>2]|0))break;y=oR((t[k>>2]|0)+108|0,t[(t[k>>2]|0)+8>>2]|0,t[(t[k>>2]|0)+52>>2]|0,t[b>>2]|0,t[S>>2]|0,t[l>>2]|0)|0;p=(t[k>>2]|0)+100|0;t[p>>2]=t[p>>2]&y}while(0);if(t[w>>2]|0)pAi[t[135736>>2]&511](t[w>>2]|0);if(t[v>>2]|0)pAi[t[135736>>2]&511](t[v>>2]|0);if((t[g>>2]|0)==(t[l>>2]|0)){s=f;return}pAi[t[135736>>2]&511](t[g>>2]|0);s=f;return}e:do if(t[d>>2]|0){t[m>>2]=wF(t[(t[k>>2]|0)+8>>2]|0,t[(t[k>>2]|0)+52>>2]|0,t[d>>2]|0)|0;g=t[k>>2]|0;if(!(t[m>>2]|0)){hj(g,201,198520,t[d>>2]|0,t[w>>2]|0);R=101;break}t[F>>2]=t[(t[g+52>>2]|0)+44>>2];while(1){if(!(t[F>>2]|0)){R=101;break e}if((t[(t[F>>2]|0)+36>>2]|0)!=0?(Xl(t[w>>2]|0,t[(t[F>>2]|0)+8>>2]|0)|0)!=0:0){if((t[m>>2]|0)==(t[(t[F>>2]|0)+36>>2]|0))break;if(Xl(t[(t[m>>2]|0)+8>>2]|0,t[(t[(t[F>>2]|0)+36>>2]|0)+8>>2]|0)|0)break}t[F>>2]=t[(t[F>>2]|0)+24>>2]}hj(t[k>>2]|0,42,198576,t[w>>2]|0,t[(t[m>>2]|0)+8>>2]|0);t[(t[k>>2]|0)+12>>2]=0;if(!(t[(t[k>>2]|0)+288>>2]|0))t[(t[k>>2]|0)+212>>2]=1}else{t[m>>2]=0;R=101}while(0);do if((R|0)==101){t[h>>2]=hy(t[(t[k>>2]|0)+52>>2]|0,t[m>>2]|0,t[w>>2]|0,0)|0;e:do if(t[h>>2]|0){if((t[(t[k>>2]|0)+16>>2]|0)==0?(t[(t[k>>2]|0)+32>>2]|0)==0:0){F=ly(t[(t[k>>2]|0)+8>>2]|0,t[l>>2]|0)|0;t[(t[h>>2]|0)+12>>2]=F;t[O>>2]=t[(t[h>>2]|0)+12>>2];while(1){if(!(t[O>>2]|0))break e;t[(t[O>>2]|0)+20>>2]=t[h>>2];if(!(t[(t[O>>2]|0)+24>>2]|0))t[(t[h>>2]|0)+16>>2]=t[O>>2];t[O>>2]=t[(t[O>>2]|0)+24>>2]}}if((t[l>>2]|0)!=0?(F=ay(t[(t[k>>2]|0)+8>>2]|0,t[l>>2]|0)|0,t[(t[h>>2]|0)+12>>2]=F,t[(t[h>>2]|0)+16>>2]=t[(t[h>>2]|0)+12>>2],(t[(t[h>>2]|0)+12>>2]|0)!=0):0)t[(t[(t[h>>2]|0)+12>>2]|0)+20>>2]=t[h>>2]}while(0);if(((((t[(t[k>>2]|0)+32>>2]|0)==0?(t[(t[k>>2]|0)+104>>2]|0)!=0:0)?(t[(t[k>>2]|0)+12>>2]|0)!=0:0)?(t[(t[k>>2]|0)+8>>2]|0)!=0:0)?(t[(t[(t[k>>2]|0)+8>>2]|0)+44>>2]|0)!=0:0){F=t[k>>2]|0;if(t[(t[k>>2]|0)+16>>2]|0){g=aR(F+108|0,t[(t[k>>2]|0)+8>>2]|0,t[(t[k>>2]|0)+52>>2]|0,t[h>>2]|0,t[l>>2]|0)|0;S=(t[k>>2]|0)+100|0;t[S>>2]=t[S>>2]&g;break}g=F+248|0;t[g>>2]=(t[g>>2]|0)+1;t[A>>2]=hE(t[k>>2]|0,t[l>>2]|0,1,0,0,0)|0;g=(t[k>>2]|0)+248|0;t[g>>2]=(t[g>>2]|0)+-1;g=t[k>>2]|0;if(!(t[A>>2]|0)){F=aR(g+108|0,t[(t[k>>2]|0)+8>>2]|0,t[(t[k>>2]|0)+52>>2]|0,t[h>>2]|0,t[l>>2]|0)|0;S=(t[k>>2]|0)+100|0;t[S>>2]=t[S>>2]&F;break}t[M>>2]=fR(t[g+8>>2]|0,t[(t[k>>2]|0)+52>>2]|0,t[c>>2]|0,t[A>>2]|0)|0;if(t[M>>2]|0){pAi[t[135736>>2]&511](t[A>>2]|0);t[A>>2]=t[M>>2]}g=aR((t[k>>2]|0)+108|0,t[(t[k>>2]|0)+8>>2]|0,t[(t[k>>2]|0)+52>>2]|0,t[h>>2]|0,t[A>>2]|0)|0;F=(t[k>>2]|0)+100|0;t[F>>2]=t[F>>2]&g;pAi[t[135736>>2]&511](t[A>>2]|0);break}if(!(t[(t[k>>2]|0)+276>>2]&8)){if(!((t[(t[k>>2]|0)+16>>2]|0)==0?(t[(t[k>>2]|0)+96>>2]|0)!=2:0)){if(!(t[(t[k>>2]|0)+16>>2]|0))break;if(t[(t[k>>2]|0)+216>>2]|0)break}if(Xl(t[c>>2]|0,197408)|0){if(Vg(t[l>>2]|0,1)|0)oj(t[k>>2]|0,539,198200,t[l>>2]|0,0);zM((t[k>>2]|0)+108|0,t[(t[k>>2]|0)+8>>2]|0,t[l>>2]|0,t[h>>2]|0)|0;break}g=(VM(t[(t[k>>2]|0)+8>>2]|0,t[(t[k>>2]|0)+52>>2]|0,t[h>>2]|0)|0)!=0;F=t[k>>2]|0;if(g){zM(F+108|0,t[(t[k>>2]|0)+8>>2]|0,t[l>>2]|0,t[h>>2]|0)|0;break}if(XM(t[F+8>>2]|0,t[(t[k>>2]|0)+52>>2]|0,t[h>>2]|0)|0)WM((t[k>>2]|0)+108|0,t[(t[k>>2]|0)+8>>2]|0,t[l>>2]|0,t[h>>2]|0)|0}}while(0);if(t[v>>2]|0)pAi[t[135736>>2]&511](t[v>>2]|0);if(!(t[d>>2]|0)){s=f;return}pAi[t[135736>>2]&511](t[d>>2]|0);s=f;return}function sj(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;var u=0,a=0,o=0,c=0,l=0,b=0,k=0;u=s;s=s+32|0;a=u;o=u+24|0;c=u+20|0;l=u+16|0;b=u+12|0;k=u+8|0;t[o>>2]=e;t[c>>2]=i;t[l>>2]=r;t[b>>2]=n;t[k>>2]=f;if(((t[o>>2]|0)!=0?(t[(t[o>>2]|0)+212>>2]|0)!=0:0)?(t[(t[o>>2]|0)+172>>2]|0)==-1:0){s=u;return}if(t[o>>2]|0)t[(t[o>>2]|0)+84>>2]=t[c>>2];f=t[o>>2]|0;o=t[c>>2]|0;c=t[b>>2]|0;n=t[k>>2]|0;r=t[l>>2]|0;l=t[k>>2]|0;t[a>>2]=t[b>>2];t[a+4>>2]=l;cp(0,0,0,f,0,3,o,1,0,0,c,n,0,0,0,r,a);s=u;return}function bj(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;var a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0,S=0,g=0;a=s;s=s+112|0;o=a+48|0;c=a+44|0;l=a+40|0;b=a+36|0;k=a+32|0;h=a+28|0;w=a+24|0;d=a+20|0;v=a+16|0;m=a+12|0;_=a+8|0;p=a+4|0;E=a+52|0;S=a;t[o>>2]=e;t[c>>2]=i;t[l>>2]=r;t[b>>2]=n;t[k>>2]=f;t[w>>2]=0;t[d>>2]=0;if(t[l>>2]|0)t[w>>2]=wF(t[(t[o>>2]|0)+8>>2]|0,t[(t[o>>2]|0)+52>>2]|0,t[l>>2]|0)|0;f=t[o>>2]|0;if(t[(t[o>>2]|0)+380>>2]|0){t[h>>2]=t[f+380>>2];t[(t[o>>2]|0)+380>>2]=t[(t[h>>2]|0)+24>>2];n=(t[o>>2]|0)+376|0;t[n>>2]=(t[n>>2]|0)+-1;n=(t[h>>2]|0)+0|0;r=n+48|0;do{t[n>>2]=0;n=n+4|0}while((n|0)<(r|0));t[(t[h>>2]|0)+4>>2]=2;t[(t[h>>2]|0)+20>>2]=t[(t[o>>2]|0)+52>>2];t[(t[h>>2]|0)+32>>2]=t[(t[o>>2]|0)+8>>2];t[(t[h>>2]|0)+36>>2]=t[w>>2];n=t[c>>2]|0;if(t[(t[o>>2]|0)+364>>2]|0)t[(t[h>>2]|0)+8>>2]=n;else{r=Yl(n)|0;t[(t[h>>2]|0)+8>>2]=r}if(!(t[(t[(t[o>>2]|0)+52>>2]|0)+44>>2]|0))t[(t[(t[o>>2]|0)+52>>2]|0)+44>>2]=t[h>>2];else{t[v>>2]=t[(t[(t[o>>2]|0)+52>>2]|0)+44>>2];while(1){if(!(t[(t[v>>2]|0)+24>>2]|0))break;t[v>>2]=t[(t[v>>2]|0)+24>>2]}t[(t[v>>2]|0)+24>>2]=t[h>>2];t[(t[h>>2]|0)+28>>2]=t[v>>2]}if((t[18774]|0)!=0&(t[33968]|0)!=0)pAi[t[135872>>2]&511](t[h>>2]|0)}else{v=t[(t[o>>2]|0)+52>>2]|0;r=t[w>>2]|0;w=t[c>>2]|0;if(t[f+364>>2]|0)t[h>>2]=hy(v,r,w,0)|0;else t[h>>2]=ky(v,r,w,0)|0;if(!(t[h>>2]|0)){Sp(t[o>>2]|0,198176);s=a;return}}e:do if((t[(t[o>>2]|0)+16>>2]|0)==0?(t[(t[o>>2]|0)+32>>2]|0)==0:0){w=t[o>>2]|0;if(u[t[k>>2]>>0]|0){t[m>>2]=kj(w,t[b>>2]|0,(t[k>>2]|0)-(t[b>>2]|0)|0)|0;t[(t[h>>2]|0)+12>>2]=t[m>>2];t[(t[h>>2]|0)+16>>2]=t[m>>2];if(!(t[m>>2]|0))break;t[(t[m>>2]|0)+32>>2]=t[(t[h>>2]|0)+32>>2];t[(t[m>>2]|0)+20>>2]=t[h>>2];break}r=uy(t[w+8>>2]|0,t[b>>2]|0,(t[k>>2]|0)-(t[b>>2]|0)|0)|0;t[(t[h>>2]|0)+12>>2]=r;t[m>>2]=t[(t[h>>2]|0)+12>>2];while(1){if(!(t[m>>2]|0))break e;t[(t[m>>2]|0)+32>>2]=t[(t[h>>2]|0)+32>>2];t[(t[m>>2]|0)+20>>2]=t[h>>2];if(!(t[(t[m>>2]|0)+24>>2]|0))t[(t[h>>2]|0)+16>>2]=t[m>>2];t[m>>2]=t[(t[m>>2]|0)+24>>2]}}else g=30;while(0);if(((g|0)==30?(t[b>>2]|0)!=0:0)?(t[_>>2]=kj(t[o>>2]|0,t[b>>2]|0,(t[k>>2]|0)-(t[b>>2]|0)|0)|0,t[(t[h>>2]|0)+12>>2]=t[_>>2],t[(t[h>>2]|0)+16>>2]=t[_>>2],(t[_>>2]|0)!=0):0){t[(t[_>>2]|0)+32>>2]=t[(t[h>>2]|0)+32>>2];t[(t[_>>2]|0)+20>>2]=t[h>>2]}do if(((((t[(t[o>>2]|0)+32>>2]|0)==0?(t[(t[o>>2]|0)+104>>2]|0)!=0:0)?(t[(t[o>>2]|0)+12>>2]|0)!=0:0)?(t[(t[o>>2]|0)+8>>2]|0)!=0:0)?(t[(t[(t[o>>2]|0)+8>>2]|0)+44>>2]|0)!=0:0){if(t[(t[o>>2]|0)+16>>2]|0){t[d>>2]=ql(t[b>>2]|0,(t[k>>2]|0)-(t[b>>2]|0)|0)|0;_=aR((t[o>>2]|0)+108|0,t[(t[o>>2]|0)+8>>2]|0,t[(t[o>>2]|0)+52>>2]|0,t[h>>2]|0,t[d>>2]|0)|0;m=(t[o>>2]|0)+100|0;t[m>>2]=t[m>>2]&_;break}t[d>>2]=wj(t[o>>2]|0,t[b>>2]|0,t[k>>2]|0)|0;if(!(t[d>>2]|0))if(!(u[t[k>>2]>>0]|0)){_=aR((t[o>>2]|0)+108|0,t[(t[o>>2]|0)+8>>2]|0,t[(t[o>>2]|0)+52>>2]|0,t[h>>2]|0,t[b>>2]|0)|0;m=(t[o>>2]|0)+100|0;t[m>>2]=t[m>>2]&_;break}else{t[d>>2]=ql(t[b>>2]|0,(t[k>>2]|0)-(t[b>>2]|0)|0)|0;_=aR((t[o>>2]|0)+108|0,t[(t[o>>2]|0)+8>>2]|0,t[(t[o>>2]|0)+52>>2]|0,t[h>>2]|0,t[d>>2]|0)|0;m=(t[o>>2]|0)+100|0;t[m>>2]=t[m>>2]&_;break}if((t[(t[o>>2]|0)+352>>2]|0)!=0?(t[S>>2]=Ug(t[c>>2]|0,t[l>>2]|0,E,50)|0,(t[S>>2]|0)!=0):0){t[(t[o>>2]|0)+144>>2]=1;t[p>>2]=nR((t[o>>2]|0)+108|0,t[(t[o>>2]|0)+8>>2]|0,t[(t[o>>2]|0)+52>>2]|0,t[S>>2]|0,t[d>>2]|0)|0;if((t[(t[o>>2]|0)+144>>2]|0)!=1)t[(t[o>>2]|0)+100>>2]=0;if((t[S>>2]|0)!=(E|0)?(t[S>>2]|0)!=(t[c>>2]|0):0)pAi[t[135736>>2]&511](t[S>>2]|0);if(t[p>>2]|0){pAi[t[135736>>2]&511](t[d>>2]|0);t[d>>2]=t[p>>2]}}_=aR((t[o>>2]|0)+108|0,t[(t[o>>2]|0)+8>>2]|0,t[(t[o>>2]|0)+52>>2]|0,t[h>>2]|0,t[d>>2]|0)|0;m=(t[o>>2]|0)+100|0;t[m>>2]=t[m>>2]&_}else g=54;while(0);do if((g|0)==54?(t[(t[o>>2]|0)+276>>2]&8|0)==0:0){if(!((t[(t[o>>2]|0)+16>>2]|0)==0?(t[(t[o>>2]|0)+96>>2]|0)!=2:0)){if(!(t[(t[o>>2]|0)+16>>2]|0))break;if(t[(t[o>>2]|0)+216>>2]|0)break}if((((t[l>>2]|0)==(t[(t[o>>2]|0)+312>>2]|0)?(u[t[c>>2]>>0]|0|0)==105:0)?(u[(t[c>>2]|0)+1>>0]|0|0)==100:0)?(u[(t[c>>2]|0)+2>>0]|0|0)==0:0){if(!(t[d>>2]|0))t[d>>2]=ql(t[b>>2]|0,(t[k>>2]|0)-(t[b>>2]|0)|0)|0;if(Vg(t[d>>2]|0,1)|0)oj(t[o>>2]|0,539,198200,t[d>>2]|0,0);zM((t[o>>2]|0)+108|0,t[(t[o>>2]|0)+8>>2]|0,t[d>>2]|0,t[h>>2]|0)|0;break}if(VM(t[(t[o>>2]|0)+8>>2]|0,t[(t[o>>2]|0)+52>>2]|0,t[h>>2]|0)|0){if(!(t[d>>2]|0))t[d>>2]=ql(t[b>>2]|0,(t[k>>2]|0)-(t[b>>2]|0)|0)|0;zM((t[o>>2]|0)+108|0,t[(t[o>>2]|0)+8>>2]|0,t[d>>2]|0,t[h>>2]|0)|0;break}if(XM(t[(t[o>>2]|0)+8>>2]|0,t[(t[o>>2]|0)+52>>2]|0,t[h>>2]|0)|0){if(!(t[d>>2]|0))t[d>>2]=ql(t[b>>2]|0,(t[k>>2]|0)-(t[b>>2]|0)|0)|0;WM((t[o>>2]|0)+108|0,t[(t[o>>2]|0)+8>>2]|0,t[d>>2]|0,t[h>>2]|0)|0}}while(0);if(!(t[d>>2]|0)){s=a;return}pAi[t[135736>>2]&511](t[d>>2]|0);s=a;return}function kj(e,i,r){e=e|0;i=i|0;r=r|0;var a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0;a=s;s=s+48|0;o=a+28|0;c=a+24|0;l=a+20|0;b=a+16|0;k=a+12|0;h=a+8|0;w=a+32|0;d=a+4|0;v=a;t[c>>2]=e;t[l>>2]=i;t[b>>2]=r;t[h>>2]=0;if(t[(t[c>>2]|0)+372>>2]|0){t[k>>2]=t[(t[c>>2]|0)+372>>2];t[(t[c>>2]|0)+372>>2]=t[(t[k>>2]|0)+24>>2];r=(t[c>>2]|0)+368|0;t[r>>2]=(t[r>>2]|0)+-1}else t[k>>2]=gAi[t[135744>>2]&511](60)|0;if(!(t[k>>2]|0)){Sp(t[c>>2]|0,198e3);t[o>>2]=0;m=t[o>>2]|0;s=a;return m|0}r=(t[k>>2]|0)+0|0;i=r+60|0;do{t[r>>2]=0;r=r+4|0}while((r|0)<(i|0));e:do if(t[(t[c>>2]|0)+364>>2]|0){n[w>>0]=n[(t[l>>2]|0)+(t[b>>2]|0)>>0]|0;if((t[b>>2]|0)<8?(t[(t[c>>2]|0)+360>>2]&65536|0)!=0:0){t[d>>2]=(t[k>>2]|0)+44;YY(t[d>>2]|0,t[l>>2]|0,t[b>>2]|0)|0;n[(t[d>>2]|0)+(t[b>>2]|0)>>0]=0;t[h>>2]=t[d>>2];break}do if((t[b>>2]|0)<=3){if((u[w>>0]|0|0)!=34?(u[w>>0]|0|0)!=39:0){if((u[w>>0]|0|0)!=60)break;if((u[(t[l>>2]|0)+((t[b>>2]|0)+1)>>0]|0|0)==33)break}t[h>>2]=kz(t[(t[c>>2]|0)+296>>2]|0,t[l>>2]|0,t[b>>2]|0)|0;break e}while(0);do if((u[t[l>>2]>>0]|0|0)!=32){if(9<=(u[t[l>>2]>>0]|0|0)?(u[t[l>>2]>>0]|0|0)<=10:0){_=20;break}if(!((t[b>>2]|0)<60?(u[t[l>>2]>>0]|0|0)==13:0))break e}else _=20;while(0);if((_|0)==20?(t[b>>2]|0)>=60:0)break;if((u[w>>0]|0|0)==60?(u[(t[l>>2]|0)+((t[b>>2]|0)+1)>>0]|0|0)!=33:0){t[v>>2]=1;while(1){if((t[v>>2]|0)>=(t[b>>2]|0))break;do if((u[(t[l>>2]|0)+(t[v>>2]|0)>>0]|0|0)!=32){if(9<=(u[(t[l>>2]|0)+(t[v>>2]|0)>>0]|0|0)?(u[(t[l>>2]|0)+(t[v>>2]|0)>>0]|0|0)<=10:0)break;if((u[(t[l>>2]|0)+(t[v>>2]|0)>>0]|0|0)!=13)break e}while(0);t[v>>2]=(t[v>>2]|0)+1}t[h>>2]=kz(t[(t[c>>2]|0)+296>>2]|0,t[l>>2]|0,t[b>>2]|0)|0}}while(0);t[(t[k>>2]|0)+4>>2]=3;t[(t[k>>2]|0)+8>>2]=75104;if(!(t[h>>2]|0)){v=ql(t[l>>2]|0,t[b>>2]|0)|0;t[(t[k>>2]|0)+40>>2]=v;if(!(t[(t[k>>2]|0)+40>>2]|0)){tj(t[c>>2]|0,198160);pAi[t[135736>>2]&511](t[k>>2]|0);t[o>>2]=0;m=t[o>>2]|0;s=a;return m|0}}else t[(t[k>>2]|0)+40>>2]=t[h>>2];do if((t[(t[c>>2]|0)+280>>2]|0)!=0?(t[(t[c>>2]|0)+36>>2]|0)!=0:0){if((t[(t[(t[c>>2]|0)+36>>2]|0)+28>>2]|0)<65535){f[(t[k>>2]|0)+56>>1]=t[(t[(t[c>>2]|0)+36>>2]|0)+28>>2];break}f[(t[k>>2]|0)+56>>1]=-1;if(t[(t[c>>2]|0)+360>>2]&4194304)t[(t[k>>2]|0)+52>>2]=t[(t[(t[c>>2]|0)+36>>2]|0)+28>>2]}while(0);if((t[18774]|0)!=0&(t[33968]|0)!=0)pAi[t[135872>>2]&511](t[k>>2]|0);t[o>>2]=t[k>>2];m=t[o>>2]|0;s=a;return m|0}function hj(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;var u=0,a=0,o=0,c=0,l=0,b=0,k=0;u=s;s=s+32|0;a=u;o=u+24|0;c=u+20|0;l=u+16|0;b=u+12|0;k=u+8|0;t[o>>2]=e;t[c>>2]=i;t[l>>2]=r;t[b>>2]=n;t[k>>2]=f;if(((t[o>>2]|0)!=0?(t[(t[o>>2]|0)+212>>2]|0)!=0:0)?(t[(t[o>>2]|0)+172>>2]|0)==-1:0){s=u;return}if(t[o>>2]|0)t[(t[o>>2]|0)+84>>2]=t[c>>2];f=t[o>>2]|0;o=t[c>>2]|0;c=t[b>>2]|0;n=t[k>>2]|0;r=t[l>>2]|0;l=t[k>>2]|0;t[a>>2]=t[b>>2];t[a+4>>2]=l;cp(0,0,0,f,0,3,o,2,0,0,c,n,0,0,0,r,a);s=u;return}function wj(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0;n=s;s=s+32|0;f=n+20|0;a=n+16|0;o=n+12|0;c=n+8|0;l=n+4|0;b=n;t[a>>2]=e;t[o>>2]=i;t[c>>2]=r;t[l>>2]=t[o>>2];while(1){if((t[l>>2]|0)>>>0>=(t[c>>2]|0)>>>0){k=4;break}r=t[l>>2]|0;t[l>>2]=r+1;if((u[r>>0]|0|0)==38){k=5;break}}if((k|0)==4){t[f>>2]=0;h=t[f>>2]|0;s=n;return h|0}else if((k|0)==5){k=(t[a>>2]|0)+248|0;t[k>>2]=(t[k>>2]|0)+1;t[b>>2]=kE(t[a>>2]|0,t[o>>2]|0,(t[c>>2]|0)-(t[o>>2]|0)|0,1,0,0,0)|0;o=(t[a>>2]|0)+248|0;t[o>>2]=(t[o>>2]|0)+-1;t[f>>2]=t[b>>2];h=t[f>>2]|0;s=n;return h|0}return 0}function dj(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,o=0,c=0,l=0,b=0,k=0,h=0;r=s;s=s+32|0;n=r+28|0;f=r+24|0;u=r+20|0;o=r+16|0;c=r+12|0;l=r+8|0;b=r+4|0;k=r;t[f>>2]=e;t[u>>2]=i;if(!(t[u>>2]|0)){t[n>>2]=0;h=t[n>>2]|0;s=r;return h|0}i=t[u>>2]|0;e:do if((t[f>>2]|0)>>>0<65536){if(!(t[i>>2]|0)){t[n>>2]=0;h=t[n>>2]|0;s=r;return h|0}t[o>>2]=0;t[c>>2]=(t[t[u>>2]>>2]|0)-1;t[b>>2]=t[(t[u>>2]|0)+8>>2];while(1){if((t[o>>2]|0)>(t[c>>2]|0))break e;t[l>>2]=((t[o>>2]|0)+(t[c>>2]|0)|0)/2|0;if((t[f>>2]&65535|0)<(a[(t[b>>2]|0)+(t[l>>2]<<2)>>1]|0|0)){t[c>>2]=(t[l>>2]|0)-1;continue}if((t[f>>2]&65535|0)<=(a[(t[b>>2]|0)+(t[l>>2]<<2)+2>>1]|0|0))break;t[o>>2]=(t[l>>2]|0)+1}t[n>>2]=1;h=t[n>>2]|0;s=r;return h|0}else{if(!(t[i+4>>2]|0)){t[n>>2]=0;h=t[n>>2]|0;s=r;return h|0}t[o>>2]=0;t[c>>2]=(t[(t[u>>2]|0)+4>>2]|0)-1;t[k>>2]=t[(t[u>>2]|0)+12>>2];while(1){if((t[o>>2]|0)>(t[c>>2]|0))break e;t[l>>2]=((t[o>>2]|0)+(t[c>>2]|0)|0)/2|0;if((t[f>>2]|0)>>>0<(t[(t[k>>2]|0)+(t[l>>2]<<3)>>2]|0)>>>0){t[c>>2]=(t[l>>2]|0)-1;continue}if((t[f>>2]|0)>>>0<=(t[(t[k>>2]|0)+(t[l>>2]<<3)+4>>2]|0)>>>0)break;t[o>>2]=(t[l>>2]|0)+1}t[n>>2]=1;
	h=t[n>>2]|0;s=r;return h|0}while(0);t[n>>2]=0;h=t[n>>2]|0;s=r;return h|0}function vj(e){e=e|0;var i=0,r=0,n=0,f=0;i=s;s=s+16|0;r=i+8|0;n=i+4|0;f=i;t[r>>2]=e;if(!(t[r>>2]|0)){s=i;return}if(t[(t[r>>2]|0)+8>>2]|0)vj(t[(t[r>>2]|0)+8>>2]|0);if(t[(t[r>>2]|0)+32>>2]|0)Lj(t[(t[r>>2]|0)+32>>2]|0);if(t[(t[r>>2]|0)+12>>2]|0)pAi[t[135736>>2]&511](t[(t[r>>2]|0)+12>>2]|0);if(t[(t[r>>2]|0)+28>>2]|0){e:do if(!(t[(t[r>>2]|0)+4>>2]|0)){t[f>>2]=0;while(1){if((t[f>>2]|0)>=(t[(t[r>>2]|0)+20>>2]|0))break e;t[n>>2]=(t[(t[r>>2]|0)+28>>2]|0)+((t[f>>2]|0)*12|0);if(t[(t[n>>2]|0)+4>>2]|0)pAi[t[135736>>2]&511](t[(t[n>>2]|0)+4>>2]|0);if(t[(t[n>>2]|0)+8>>2]|0)pAi[t[135736>>2]&511](t[(t[n>>2]|0)+8>>2]|0);t[f>>2]=(t[f>>2]|0)+1}}while(0);pAi[t[135736>>2]&511](t[(t[r>>2]|0)+28>>2]|0)}if(t[(t[r>>2]|0)+4>>2]|0)bz(t[(t[r>>2]|0)+4>>2]|0);f=(t[r>>2]|0)+0|0;n=f+36|0;do{t[f>>2]=-1;f=f+4|0}while((f|0)<(n|0));pAi[t[135736>>2]&511](t[r>>2]|0);s=i;return}function mj(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i+4|0;n=i;t[r>>2]=e;while(1){if(!(t[r>>2]|0))break;t[n>>2]=t[r>>2];t[r>>2]=t[(t[r>>2]|0)+8>>2];t[(t[n>>2]|0)+8>>2]=0;vj(t[n>>2]|0)}s=i;return}function _j(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i+4|0;n=i;t[r>>2]=e;while(1){if(!(t[r>>2]|0))break;t[n>>2]=t[t[r>>2]>>2];if(t[(t[r>>2]|0)+20>>2]|0)pAi[t[135736>>2]&511](t[(t[r>>2]|0)+20>>2]|0);pAi[t[135736>>2]&511](t[r>>2]|0);t[r>>2]=t[n>>2]}s=i;return}function pj(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0;n=s;s=s+16|0;f=n+8|0;u=n+4|0;a=n;t[f>>2]=e;t[u>>2]=i;t[a>>2]=r;r=Dj(t[f>>2]|0,t[u>>2]|0,t[a>>2]|0,1)|0;s=n;return r|0}function Ej(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,u=0,a=0,o=0,c=0;f=s;s=s+16|0;u=f+12|0;a=f+8|0;o=f+4|0;c=f;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;t[c>>2]=n;n=Dj(t[u>>2]|0,t[a>>2]|0,t[o>>2]|0,t[c>>2]|0)|0;s=f;return n|0}function Sj(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0;n=s;s=s+16|0;f=n+8|0;u=n+4|0;a=n;t[f>>2]=e;t[u>>2]=i;t[a>>2]=r;r=Dj(t[f>>2]|0,t[u>>2]|0,t[a>>2]|0,2)|0;s=n;return r|0}function gj(e){e=e|0;var i=0,r=0,n=0,f=0,u=0,a=0;i=s;s=s+16|0;r=i+12|0;n=i+8|0;f=i+4|0;u=i;t[n>>2]=e;if(!(t[n>>2]|0)){t[r>>2]=-1;a=t[r>>2]|0;s=i;return a|0}while(1){if(!(t[n>>2]|0))break;if((t[(t[n>>2]|0)+28>>2]|0)==(t[(t[n>>2]|0)+16>>2]|0))t[(t[n>>2]|0)+28>>2]=-1;if(t[(t[n>>2]|0)+16>>2]|0){e=(t[n>>2]|0)+16|0;t[e>>2]=(t[e>>2]|0)+-1}t[f>>2]=(t[(t[n>>2]|0)+8>>2]|0)-1;while(1){if((t[f>>2]|0)<0)break;t[u>>2]=t[(t[(t[n>>2]|0)+20>>2]|0)+((t[f>>2]<<1)+1<<2)>>2];if((t[u>>2]|0)>(t[(t[n>>2]|0)+16>>2]|0)){e=(t[n>>2]|0)+8|0;t[e>>2]=(t[e>>2]|0)+-1}if((t[u>>2]|0)<=(t[(t[n>>2]|0)+16>>2]|0))break;t[f>>2]=(t[f>>2]|0)+-1}t[n>>2]=t[t[n>>2]>>2]}t[r>>2]=0;a=t[r>>2]|0;s=i;return a|0}function yj(e){e=e|0;var i=0,r=0,n=0,f=0;i=s;s=s+16|0;r=i+4|0;n=i;t[n>>2]=e;do if(t[n>>2]|0){while(1){if(!(t[n>>2]|0)){f=7;break}if(t[(t[(t[n>>2]|0)+4>>2]|0)+16>>2]&16384){f=5;break}t[n>>2]=t[t[n>>2]>>2]}if((f|0)==5){t[r>>2]=1;break}else if((f|0)==7){t[r>>2]=0;break}}else t[r>>2]=-1;while(0);s=i;return t[r>>2]|0}function Fj(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0,S=0,g=0,y=0;f=s;s=s+64|0;a=f+48|0;o=f+44|0;c=f+40|0;l=f+36|0;b=f+32|0;k=f+28|0;h=f+24|0;w=f+20|0;d=f+16|0;v=f+12|0;m=f+8|0;_=f+4|0;p=f;t[o>>2]=e;t[c>>2]=i;t[l>>2]=r;t[b>>2]=n;t[k>>2]=0;t[w>>2]=0;t[m>>2]=0;t[_>>2]=0;t[p>>2]=1;if(!(t[o>>2]|0)){t[a>>2]=0;E=t[a>>2]|0;s=f;return E|0}t[v>>2]=t[o>>2];t[d>>2]=t[v>>2];while(1){if(!(u[t[d>>2]>>0]|0)){S=41;break}t[m>>2]=0;while(1){if(u[t[d>>2]>>0]|0)g=(u[t[d>>2]>>0]|0|0)!=124;else g=0;y=t[d>>2]|0;if(!g)break;t[d>>2]=y+1}o=t[v>>2]|0;if(!(u[y>>0]|0))t[w>>2]=Cj(o,t[c>>2]|0,t[b>>2]|0)|0;else{t[m>>2]=ql(o,(t[d>>2]|0)-(t[v>>2]|0)|0)|0;if(t[m>>2]|0)t[w>>2]=Cj(t[m>>2]|0,t[c>>2]|0,t[b>>2]|0)|0;t[d>>2]=(t[d>>2]|0)+1}if(!(t[w>>2]|0)){S=48;break}t[h>>2]=Pj()|0;if(!(t[h>>2]|0)){S=48;break}if(t[c>>2]|0){t[(t[h>>2]|0)+4>>2]=t[c>>2];sz(t[c>>2]|0)|0}if(!(t[k>>2]|0))t[k>>2]=t[h>>2];else{t[(t[h>>2]|0)+8>>2]=t[(t[k>>2]|0)+8>>2];t[(t[k>>2]|0)+8>>2]=t[h>>2]}t[(t[h>>2]|0)+16>>2]=t[l>>2];t[(t[w>>2]|0)+16>>2]=t[h>>2];o=t[w>>2]|0;if(t[(t[h>>2]|0)+16>>2]&6)Bj(o);else Ij(o);if(t[(t[w>>2]|0)+8>>2]|0){S=48;break}Hj(t[w>>2]|0);t[w>>2]=0;do if(t[p>>2]|0){if(!(t[_>>2]|0)){t[_>>2]=t[(t[h>>2]|0)+16>>2]&768;break}if((t[_>>2]|0)==256){if(!(t[(t[h>>2]|0)+16>>2]&512))break;t[p>>2]=0;break}if((t[_>>2]|0)==512?(t[(t[h>>2]|0)+16>>2]&256|0)!=0:0)t[p>>2]=0}while(0);if(t[p>>2]|0)xj(t[h>>2]|0)|0;if((Uj(t[h>>2]|0)|0)<0){S=48;break}if(t[m>>2]|0){pAi[t[135736>>2]&511](t[m>>2]|0);t[m>>2]=0}t[v>>2]=t[d>>2]}if((S|0)==41){e:do if(!(t[p>>2]|0)){t[h>>2]=t[k>>2];while(1){if(!(t[h>>2]|0))break e;if(t[(t[h>>2]|0)+32>>2]|0){Lj(t[(t[h>>2]|0)+32>>2]|0);t[(t[h>>2]|0)+32>>2]=0}t[h>>2]=t[(t[h>>2]|0)+8>>2]}}while(0);t[a>>2]=t[k>>2];E=t[a>>2]|0;s=f;return E|0}else if((S|0)==48){if(t[w>>2]|0)Hj(t[w>>2]|0);if(t[k>>2]|0)vj(t[k>>2]|0);if(t[m>>2]|0)pAi[t[135736>>2]&511](t[m>>2]|0);t[a>>2]=0;E=t[a>>2]|0;s=f;return E|0}return 0}function Oj(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0;r=s;s=s+16|0;n=r+12|0;f=r+8|0;u=r+4|0;a=r;t[f>>2]=e;t[u>>2]=i;t[a>>2]=0;if((t[f>>2]|0)==0|(t[u>>2]|0)==0){t[n>>2]=-1;o=t[n>>2]|0;s=r;return o|0}while(1){if(!(t[f>>2]|0)){c=7;break}t[a>>2]=zj(t[f>>2]|0,t[u>>2]|0)|0;if(t[a>>2]|0){c=5;break}t[f>>2]=t[(t[f>>2]|0)+8>>2]}if((c|0)==5){t[n>>2]=t[a>>2];o=t[n>>2]|0;s=r;return o|0}else if((c|0)==7){t[n>>2]=t[a>>2];o=t[n>>2]|0;s=r;return o|0}return 0}function Aj(e){e=e|0;var i=0,r=0,n=0,f=0,u=0,a=0,o=0;i=s;s=s+16|0;r=i+12|0;n=i+8|0;f=i+4|0;u=i;t[n>>2]=e;t[f>>2]=0;if((t[n>>2]|0)!=0?(t[(t[n>>2]|0)+32>>2]|0)!=0:0){while(1){if(!(t[n>>2]|0)){a=11;break}if(!(t[(t[n>>2]|0)+32>>2]|0)){a=12;break}t[u>>2]=jj(t[(t[n>>2]|0)+32>>2]|0)|0;if(!(t[u>>2]|0)){a=12;break}if(!(t[f>>2]|0))t[f>>2]=t[u>>2];else{t[t[u>>2]>>2]=t[t[f>>2]>>2];t[t[f>>2]>>2]=t[u>>2]}t[(t[u>>2]|0)+24>>2]=t[(t[n>>2]|0)+16>>2];t[n>>2]=t[(t[n>>2]|0)+8>>2]}if((a|0)==11){t[r>>2]=t[f>>2];o=t[r>>2]|0;s=i;return o|0}else if((a|0)==12){_j(t[f>>2]|0);t[r>>2]=0;o=t[r>>2]|0;s=i;return o|0}}t[r>>2]=0;o=t[r>>2]|0;s=i;return o|0}function Mj(e){e=e|0;var i=0,r=0,n=0,f=0;i=s;s=s+16|0;r=i+4|0;n=i;t[n>>2]=e;do if(t[n>>2]|0){while(1){if(!(t[n>>2]|0)){f=7;break}if(!(t[(t[n>>2]|0)+32>>2]|0)){f=5;break}t[n>>2]=t[(t[n>>2]|0)+8>>2]}if((f|0)==5){t[r>>2]=0;break}else if((f|0)==7){t[r>>2]=1;break}}else t[r>>2]=-1;while(0);s=i;return t[r>>2]|0}function Rj(e){e=e|0;var i=0,r=0,n=0,f=0,u=0,a=0,o=0;i=s;s=s+16|0;r=i+12|0;n=i+8|0;f=i+4|0;u=i;t[n>>2]=e;t[f>>2]=0;if(!(t[n>>2]|0)){t[r>>2]=-1;a=t[r>>2]|0;s=i;return a|0}e:while(1){if(!(t[n>>2]|0)){o=14;break}if(!(t[(t[n>>2]|0)+32>>2]|0)){o=5;break}t[u>>2]=0;while(1){if((t[u>>2]|0)>=(t[(t[(t[n>>2]|0)+32>>2]|0)+4>>2]|0))break;if(t[(t[(t[(t[n>>2]|0)+32>>2]|0)+12>>2]|0)+(t[u>>2]<<4)>>2]&1){o=9;break e}t[u>>2]=(t[u>>2]|0)+1}if((t[(t[(t[n>>2]|0)+32>>2]|0)+4>>2]|0)>(t[f>>2]|0))t[f>>2]=t[(t[(t[n>>2]|0)+32>>2]|0)+4>>2];t[n>>2]=t[(t[n>>2]|0)+8>>2]}if((o|0)==5){t[r>>2]=-1;a=t[r>>2]|0;s=i;return a|0}else if((o|0)==9){t[r>>2]=-2;a=t[r>>2]|0;s=i;return a|0}else if((o|0)==14){t[r>>2]=t[f>>2];a=t[r>>2]|0;s=i;return a|0}return 0}function Nj(e){e=e|0;var i=0,r=0,n=0,f=0,u=0,a=0;i=s;s=s+16|0;r=i+8|0;n=i+4|0;f=i;t[n>>2]=e;t[f>>2]=12345678;if(!(t[n>>2]|0)){t[r>>2]=-1;u=t[r>>2]|0;s=i;return u|0}while(1){if(!(t[n>>2]|0)){a=11;break}if(!(t[(t[n>>2]|0)+32>>2]|0)){a=5;break}if((t[(t[(t[n>>2]|0)+32>>2]|0)+4>>2]|0)<(t[f>>2]|0))t[f>>2]=t[(t[(t[n>>2]|0)+32>>2]|0)+4>>2];if(!(t[f>>2]|0)){a=9;break}t[n>>2]=t[(t[n>>2]|0)+8>>2]}if((a|0)==5){t[r>>2]=-1;u=t[r>>2]|0;s=i;return u|0}else if((a|0)==9){t[r>>2]=0;u=t[r>>2]|0;s=i;return u|0}else if((a|0)==11){t[r>>2]=t[f>>2];u=t[r>>2]|0;s=i;return u|0}return 0}function Tj(e){e=e|0;var i=0,r=0,n=0,f=0;i=s;s=s+16|0;r=i+4|0;n=i;t[n>>2]=e;do if(t[n>>2]|0){while(1){if(!(t[n>>2]|0)){f=9;break}if(!(t[(t[n>>2]|0)+32>>2]|0)){f=5;break}if(t[(t[n>>2]|0)+16>>2]&256){f=7;break}t[n>>2]=t[(t[n>>2]|0)+8>>2]}if((f|0)==5){t[r>>2]=-1;break}else if((f|0)==7){t[r>>2]=1;break}else if((f|0)==9){t[r>>2]=0;break}}else t[r>>2]=-1;while(0);s=i;return t[r>>2]|0}function Lj(e){e=e|0;var i=0,r=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if(!(t[r>>2]|0)){s=i;return}if(t[(t[r>>2]|0)+12>>2]|0)pAi[t[135736>>2]&511](t[(t[r>>2]|0)+12>>2]|0);if(t[t[r>>2]>>2]|0)bz(t[t[r>>2]>>2]|0);pAi[t[135736>>2]&511](t[r>>2]|0);s=i;return}function Dj(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0,S=0,g=0,y=0,F=0;f=s;s=s+80|0;a=f+72|0;o=f+68|0;c=f+64|0;l=f+60|0;b=f+56|0;k=f+52|0;h=f+48|0;w=f+44|0;d=f+40|0;v=f+36|0;m=f+32|0;_=f+28|0;p=f+24|0;E=f+20|0;S=f+16|0;g=f;t[o>>2]=e;t[c>>2]=i;t[l>>2]=r;t[b>>2]=n;t[k>>2]=0;t[h>>2]=0;t[w>>2]=0;if((t[o>>2]|0)!=0?(t[(t[o>>2]|0)+8>>2]|0)>=0:0){e:while(1){if(!(t[o>>2]|0))break;t[S>>2]=t[(t[o>>2]|0)+4>>2];if((t[b>>2]|0)==1&(t[c>>2]|0)==0&(t[l>>2]|0)==0){t[(t[o>>2]|0)+8>>2]=0;t[(t[o>>2]|0)+16>>2]=0;t[(t[o>>2]|0)+28>>2]=-1;do if(t[(t[S>>2]|0)+16>>2]&32768){if(!(t[(t[S>>2]|0)+4>>2]|0)){t[k>>2]=1;break}if(((t[(t[S>>2]|0)+4>>2]|0)==1?(t[(t[(t[S>>2]|0)+12>>2]|0)+12>>2]|0)==100:0)?(t[t[(t[S>>2]|0)+12>>2]>>2]&1|0)!=0:0){t[k>>2]=1;break}if((t[t[(t[S>>2]|0)+12>>2]>>2]&4|0)!=0?(t[d>>2]=Vj(t[o>>2]|0,0,0)|0,(t[d>>2]|0)<0):0)t[h>>2]=(t[h>>2]|0)+1}while(0);t[o>>2]=t[t[o>>2]>>2];continue}n=t[o>>2]|0;i:do if(t[(t[S>>2]|0)+4>>2]|0){if((t[n+28>>2]|0)!=-1){r=(t[o>>2]|0)+16|0;t[r>>2]=(t[r>>2]|0)+1;break}if((t[b>>2]|0)!=1&(t[b>>2]|0)!=2?(t[(t[S>>2]|0)+16>>2]&16384|0)==0:0){r=(t[o>>2]|0)+16|0;t[r>>2]=(t[r>>2]|0)+1;break}t[v>>2]=0;t[m>>2]=t[(t[o>>2]|0)+8>>2];while(1){if((t[v>>2]|0)>=(t[m>>2]|0))break;if(t[(t[S>>2]|0)+16>>2]&65536){t[p>>2]=t[(t[(t[o>>2]|0)+20>>2]|0)+(t[v>>2]<<1<<2)>>2];if(((t[p>>2]|0)>=0?(t[d>>2]=t[(t[(t[o>>2]|0)+20>>2]|0)+((t[v>>2]<<1)+1<<2)>>2],(t[d>>2]|0)<=(t[(t[o>>2]|0)+16>>2]|0)):0)?(t[E>>2]=t[(t[(t[S>>2]|0)+12>>2]|0)+(t[p>>2]<<4)>>2]&1,(t[E>>2]|0)!=0?1:(t[d>>2]|0)>=(t[(t[o>>2]|0)+16>>2]|0)):0)y=39}else{t[p>>2]=t[(t[(t[o>>2]|0)+20>>2]|0)+((t[(t[o>>2]|0)+8>>2]|0)-1<<1<<2)>>2];if((t[(t[(t[o>>2]|0)+20>>2]|0)+(((t[(t[o>>2]|0)+8>>2]|0)-1<<1)+1<<2)>>2]|0)<(t[(t[o>>2]|0)+16>>2]|0)){y=34;break e}t[E>>2]=0;t[v>>2]=t[m>>2];y=39}r:do if((y|0)==39){y=0;r=(t[(t[S>>2]|0)+12>>2]|0)+(t[p>>2]<<4)|0;t[g+0>>2]=t[r+0>>2];t[g+4>>2]=t[r+4>>2];t[g+8>>2]=t[r+8>>2];t[g+12>>2]=t[r+12>>2];do if((t[g+12>>2]|0)!=(t[b>>2]|0)){if((t[g+12>>2]|0)!=2)if((t[g+12>>2]|0)!=100)break r;else break;if(t[(t[S>>2]|0)+16>>2]&65536)break r;t[(t[o>>2]|0)+28>>2]=(t[(t[o>>2]|0)+16>>2]|0)+1;break r}while(0);t[_>>2]=0;do if((t[g+12>>2]|0)!=100){r=t[g+8>>2]|0;if(!(t[g+4>>2]|0)){if(!r){t[_>>2]=1;break}if(!(t[l>>2]|0))break;t[_>>2]=Xl(t[g+8>>2]|0,t[l>>2]|0)|0;break}if(((t[c>>2]|0)!=0?((r|0)!=0|0)==((t[l>>2]|0)!=0|0):0)?(u[t[g+4>>2]>>0]|0|0)==(u[t[c>>2]>>0]|0|0):0){if(!(Xl(t[g+4>>2]|0,t[c>>2]|0)|0))break;if((t[g+8>>2]|0)!=(t[l>>2]|0)?(Xl(t[g+8>>2]|0,t[l>>2]|0)|0)==0:0)break;t[_>>2]=1}}else t[_>>2]=1;while(0);do if(t[_>>2]|0){t[w>>2]=t[g>>2]&2;r=(t[w>>2]|0)!=0;do if(t[E>>2]|0)if(r){t[k>>2]=1;break}else{Vj(t[o>>2]|0,(t[p>>2]|0)+1|0,(t[(t[o>>2]|0)+16>>2]|0)+1|0)|0;break}else if(r){t[k>>2]=1;break}else{Vj(t[o>>2]|0,(t[p>>2]|0)+1|0,(t[(t[o>>2]|0)+16>>2]|0)+1|0)|0;break}while(0);if((t[k>>2]|0)!=1){if(!(t[g>>2]&32))break;t[k>>2]=1}}while(0);if((t[(t[S>>2]|0)+16>>2]&65536|0)==0?(t[_>>2]|0)==0|(t[w>>2]|0)!=0:0)t[(t[o>>2]|0)+28>>2]=(t[(t[o>>2]|0)+16>>2]|0)+1}while(0);t[v>>2]=(t[v>>2]|0)+1}r=(t[o>>2]|0)+16|0;t[r>>2]=(t[r>>2]|0)+1;r=t[(t[S>>2]|0)+12>>2]|0;t[g+0>>2]=t[r+0>>2];t[g+4>>2]=t[r+4>>2];t[g+8>>2]=t[r+8>>2];t[g+12>>2]=t[r+12>>2];if(!(t[g>>2]&4)){t[E>>2]=t[g>>2]&1;do if(t[(t[o>>2]|0)+24>>2]&7){if((t[(t[o>>2]|0)+16>>2]|0)==1)if(t[(t[o>>2]|0)+24>>2]&6)break i;else break;if(!(t[E>>2]|0)){if((t[(t[o>>2]|0)+16>>2]|0)!=2)break i;if(!(t[(t[o>>2]|0)+24>>2]&6))break i}}while(0);if((t[g+12>>2]|0)!=(t[b>>2]|0)){if((t[b>>2]|0)==2)break;if((t[g+12>>2]|0)!=100)break}t[_>>2]=0;do if((t[g+12>>2]|0)!=100){r=t[g+8>>2]|0;if(!(t[g+4>>2]|0)){if(!r){t[_>>2]=1;break}if(!(t[l>>2]|0))break;t[_>>2]=Xl(t[g+8>>2]|0,t[l>>2]|0)|0;break}if((((t[c>>2]|0)!=0?((r|0)!=0|0)==((t[l>>2]|0)!=0|0):0)?(u[t[g+4>>2]>>0]|0|0)==(u[t[c>>2]>>0]|0|0):0)?(Xl(t[g+4>>2]|0,t[c>>2]|0)|0)!=0:0){if((t[g+8>>2]|0)!=(t[l>>2]|0)?(Xl(t[g+8>>2]|0,t[l>>2]|0)|0)==0:0)break;t[_>>2]=1}}else t[_>>2]=1;while(0);t[w>>2]=t[g>>2]&2;if(t[_>>2]|0){if(t[w>>2]|0)t[k>>2]=1;else Vj(t[o>>2]|0,1,t[(t[o>>2]|0)+16>>2]|0)|0;if((t[k>>2]|0)!=1?(t[g>>2]&32|0)!=0:0)t[k>>2]=1}if((t[(t[S>>2]|0)+16>>2]&65536|0)==0?(t[_>>2]|0)==0|(t[w>>2]|0)!=0:0)t[(t[o>>2]|0)+28>>2]=t[(t[o>>2]|0)+16>>2]}}else{if(t[n+24>>2]&1){t[o>>2]=t[t[o>>2]>>2];continue e}do if((t[b>>2]|0)!=2){if((t[(t[o>>2]|0)+24>>2]&7|0)!=0?(t[(t[o>>2]|0)+16>>2]|0)!=0:0)break;t[k>>2]=1}while(0);r=(t[o>>2]|0)+16|0;t[r>>2]=(t[r>>2]|0)+1}while(0);t[o>>2]=t[t[o>>2]>>2]}if((y|0)==34){t[a>>2]=-1;F=t[a>>2]|0;s=f;return F|0}if((t[h>>2]|0)>0)t[k>>2]=-1;t[a>>2]=t[k>>2];F=t[a>>2]|0;s=f;return F|0}t[a>>2]=-1;F=t[a>>2]|0;s=f;return F|0}function Cj(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0;n=s;s=s+32|0;f=n+20|0;u=n+16|0;a=n+12|0;o=n+8|0;c=n+4|0;l=n;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;if(!(t[u>>2]|0)){t[f>>2]=0;b=t[f>>2]|0;s=n;return b|0}t[c>>2]=gAi[t[135744>>2]&511](32)|0;if(!(t[c>>2]|0)){t[f>>2]=0;b=t[f>>2]|0;s=n;return b|0}r=t[c>>2]|0;t[r+0>>2]=0;t[r+4>>2]=0;t[r+8>>2]=0;t[r+12>>2]=0;t[r+16>>2]=0;t[r+20>>2]=0;t[r+24>>2]=0;t[r+28>>2]=0;t[(t[c>>2]|0)+12>>2]=t[a>>2];t[t[c>>2]>>2]=t[u>>2];t[(t[c>>2]|0)+4>>2]=t[u>>2];if(t[o>>2]|0){t[l>>2]=0;while(1){k=t[l>>2]|0;if(!(t[(t[o>>2]|0)+(t[l>>2]<<1<<2)>>2]|0))break;t[l>>2]=k+1}t[(t[c>>2]|0)+28>>2]=k}else t[(t[c>>2]|0)+28>>2]=0;t[(t[c>>2]|0)+24>>2]=t[o>>2];t[f>>2]=t[c>>2];b=t[f>>2]|0;s=n;return b|0}function Pj(){var e=0,i=0,r=0,n=0,f=0,u=0;e=s;s=s+16|0;i=e+4|0;r=e;t[r>>2]=gAi[t[135744>>2]&511](36)|0;if(!(t[r>>2]|0)){t[i>>2]=0;n=t[i>>2]|0;s=e;return n|0}f=(t[r>>2]|0)+0|0;u=f+36|0;do{t[f>>2]=0;f=f+4|0}while((f|0)<(u|0));t[(t[r>>2]|0)+24>>2]=10;f=gAi[t[135744>>2]&511]((t[(t[r>>2]|0)+24>>2]|0)*12|0)|0;t[(t[r>>2]|0)+28>>2]=f;if(!(t[(t[r>>2]|0)+28>>2]|0)){pAi[t[135736>>2]&511](t[r>>2]|0);t[i>>2]=0;n=t[i>>2]|0;s=e;return n|0}else{t[i>>2]=t[r>>2];n=t[i>>2]|0;s=e;return n|0}return 0}function Bj(e){e=e|0;var i=0,r=0,n=0,f=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0;i=s;s=s+16|0;r=i;t[r>>2]=e;while(1){do if((u[t[t[r>>2]>>2]>>0]|0|0)==32)n=1;else{if(9<=(u[t[t[r>>2]>>2]>>0]|0|0)?(u[t[t[r>>2]>>2]>>0]|0|0)<=10:0){n=1;break}n=(u[t[t[r>>2]>>2]>>0]|0|0)==13}while(0);f=u[t[t[r>>2]>>2]>>0]|0;if(!n)break;e=t[r>>2]|0;if(!f)continue;t[e>>2]=(t[e>>2]|0)+1}e:do if((f|0)!=47){n=(t[(t[r>>2]|0)+16>>2]|0)+16|0;t[n>>2]=t[n>>2]|512;if((u[t[t[r>>2]>>2]>>0]|0|0)==46){n=t[r>>2]|0;if(u[t[t[r>>2]>>2]>>0]|0)t[n>>2]=(t[n>>2]|0)+1;while(1){do if((u[t[t[r>>2]>>2]>>0]|0|0)==32)a=1;else{if(9<=(u[t[t[r>>2]>>2]>>0]|0|0)?(u[t[t[r>>2]>>2]>>0]|0|0)<=10:0){a=1;break}a=(u[t[t[r>>2]>>2]>>0]|0|0)==13}while(0);o=u[t[t[r>>2]>>2]>>0]|0;if(!a)break;n=t[r>>2]|0;if(!o)continue;t[n>>2]=(t[n>>2]|0)+1}n=t[r>>2]|0;if(!o){if(qj(n,t[(t[r>>2]|0)+16>>2]|0,2,0,0)|0)break;s=i;return}if((u[t[n>>2]>>0]|0|0)!=47)break;n=t[r>>2]|0;if(u[t[t[r>>2]>>2]>>0]|0)t[n>>2]=(t[n>>2]|0)+1;while(1){do if((u[t[t[r>>2]>>2]>>0]|0|0)==32)c=1;else{if(9<=(u[t[t[r>>2]>>2]>>0]|0|0)?(u[t[t[r>>2]>>2]>>0]|0|0)<=10:0){c=1;break}c=(u[t[t[r>>2]>>2]>>0]|0|0)==13}while(0);l=u[t[t[r>>2]>>2]>>0]|0;if(!c)break;n=t[r>>2]|0;if(!l)continue;t[n>>2]=(t[n>>2]|0)+1}i:do if((l|0)==47){if((u[(t[t[r>>2]>>2]|0)+-1>>0]|0|0)==32)break e;if(9<=(u[(t[t[r>>2]>>2]|0)+-1>>0]|0|0)?(u[(t[t[r>>2]>>2]|0)+-1>>0]|0|0)<=10:0)break e;if((u[(t[t[r>>2]>>2]|0)+-1>>0]|0|0)==13)break e;if(qj(t[r>>2]|0,t[(t[r>>2]|0)+16>>2]|0,6,0,0)|0)break e;n=t[r>>2]|0;if(u[t[t[r>>2]>>2]>>0]|0)t[n>>2]=(t[n>>2]|0)+1;while(1){do if((u[t[t[r>>2]>>2]>>0]|0|0)!=32){if(9<=(u[t[t[r>>2]>>2]>>0]|0|0)?(u[t[t[r>>2]>>2]>>0]|0|0)<=10:0)break;if((u[t[t[r>>2]>>2]>>0]|0|0)!=13)break i}while(0);n=t[r>>2]|0;if(!(u[t[t[r>>2]>>2]>>0]|0))continue;t[n>>2]=(t[n>>2]|0)+1}}while(0);if(u[t[t[r>>2]>>2]>>0]|0)b=47}else b=47;i:do if((b|0)==47){while(1){b=0;Yj(t[r>>2]|0);if(t[(t[r>>2]|0)+8>>2]|0)break e;while(1){do if((u[t[t[r>>2]>>2]>>0]|0|0)==32)k=1;else{if(9<=(u[t[t[r>>2]>>2]>>0]|0|0)?(u[t[t[r>>2]>>2]>>0]|0|0)<=10:0){k=1;break}k=(u[t[t[r>>2]>>2]>>0]|0|0)==13}while(0);h=u[t[t[r>>2]>>2]>>0]|0;if(!k)break;n=t[r>>2]|0;if(!h)continue;t[n>>2]=(t[n>>2]|0)+1}if((h|0)!=47)break;if(qj(t[r>>2]|0,t[(t[r>>2]|0)+16>>2]|0,5,0,0)|0)break e;n=t[r>>2]|0;if(u[t[t[r>>2]>>2]>>0]|0)t[n>>2]=(t[n>>2]|0)+1;while(1){do if((u[t[t[r>>2]>>2]>>0]|0|0)==32)w=1;else{if(9<=(u[t[t[r>>2]>>2]>>0]|0|0)?(u[t[t[r>>2]>>2]>>0]|0|0)<=10:0){w=1;break}w=(u[t[t[r>>2]>>2]>>0]|0|0)==13}while(0);d=u[t[t[r>>2]>>2]>>0]|0;if(!w)break;n=t[r>>2]|0;if(!d)continue;t[n>>2]=(t[n>>2]|0)+1}if((d|0)==47)break e;if(!(u[t[t[r>>2]>>2]>>0]|0))break i;if(u[t[t[r>>2]>>2]>>0]|0)b=47;else break}if(!(u[t[t[r>>2]>>2]>>0]|0)){s=i;return}t[(t[r>>2]|0)+8>>2]=1;s=i;return}while(0);t[(t[r>>2]|0)+8>>2]=1;s=i;return}while(0);t[(t[r>>2]|0)+8>>2]=1;s=i;return}function Ij(e){e=e|0;var i=0,r=0,n=0,f=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0;i=s;s=s+16|0;r=i;t[r>>2]=e;while(1){do if((u[t[t[r>>2]>>2]>>0]|0|0)==32)n=1;else{if(9<=(u[t[t[r>>2]>>2]>>0]|0|0)?(u[t[t[r>>2]>>2]>>0]|0|0)<=10:0){n=1;break}n=(u[t[t[r>>2]>>2]>>0]|0|0)==13}while(0);f=u[t[t[r>>2]>>2]>>0]|0;if(!n)break;e=t[r>>2]|0;if(!f)continue;t[e>>2]=(t[e>>2]|0)+1}n=t[r>>2]|0;do if((f|0)==47){e=(t[n+16>>2]|0)+16|0;t[e>>2]=t[e>>2]|256}else{if((u[t[n>>2]>>0]|0|0)!=46?(t[(t[(t[r>>2]|0)+16>>2]|0)+16>>2]&7|0)==0:0)break;e=(t[(t[r>>2]|0)+16>>2]|0)+16|0;t[e>>2]=t[e>>2]|512}while(0);if((u[t[t[r>>2]>>2]>>0]|0|0)==47?(u[(t[t[r>>2]>>2]|0)+1>>0]|0|0)==47:0){if(qj(t[r>>2]|0,t[(t[r>>2]|0)+16>>2]|0,6,0,0)|0){s=i;return}n=t[r>>2]|0;if(u[t[t[r>>2]>>2]>>0]|0)t[n>>2]=(t[n>>2]|0)+1;n=t[r>>2]|0;if(u[t[t[r>>2]>>2]>>0]|0)t[n>>2]=(t[n>>2]|0)+1}else a=21;if((((a|0)==21?(u[t[t[r>>2]>>2]>>0]|0|0)==46:0)?(u[(t[t[r>>2]>>2]|0)+1>>0]|0|0)==47:0)?(u[(t[t[r>>2]>>2]|0)+2>>0]|0|0)==47:0){if(qj(t[r>>2]|0,t[(t[r>>2]|0)+16>>2]|0,6,0,0)|0){s=i;return}n=t[r>>2]|0;if(u[t[t[r>>2]>>2]>>0]|0)t[n>>2]=(t[n>>2]|0)+1;n=t[r>>2]|0;if(u[t[t[r>>2]>>2]>>0]|0)t[n>>2]=(t[n>>2]|0)+1;n=t[r>>2]|0;if(u[t[t[r>>2]>>2]>>0]|0)t[n>>2]=(t[n>>2]|0)+1;while(1){do if((u[t[t[r>>2]>>2]>>0]|0|0)==32)o=1;else{if(9<=(u[t[t[r>>2]>>2]>>0]|0|0)?(u[t[t[r>>2]>>2]>>0]|0|0)<=10:0){o=1;break}o=(u[t[t[r>>2]>>2]>>0]|0|0)==13}while(0);c=u[t[t[r>>2]>>2]>>0]|0;if(!o)break;n=t[r>>2]|0;if(!c)continue;t[n>>2]=(t[n>>2]|0)+1}if(!c){t[(t[r>>2]|0)+8>>2]=1;s=i;return}}c=u[t[t[r>>2]>>2]>>0]|0;e:do if((u[t[t[r>>2]>>2]>>0]|0|0)==64){o=t[r>>2]|0;if(c)t[o>>2]=(t[o>>2]|0)+1;Gj(t[r>>2]|0);while(1){do if((u[t[t[r>>2]>>2]>>0]|0|0)==32)l=1;else{if(9<=(u[t[t[r>>2]>>2]>>0]|0|0)?(u[t[t[r>>2]>>2]>>0]|0|0)<=10:0){l=1;break}l=(u[t[t[r>>2]>>2]>>0]|0|0)==13}while(0);b=(u[t[t[r>>2]>>2]>>0]|0|0)!=0;if(!l)break;o=t[r>>2]|0;if(!b)continue;t[o>>2]=(t[o>>2]|0)+1}if(b?(Yj(t[r>>2]|0),(t[(t[r>>2]|0)+8>>2]|0)!=0):0){s=i;return}}else{if((c|0)==47){if(qj(t[r>>2]|0,t[(t[r>>2]|0)+16>>2]|0,1,0,0)|0){s=i;return}o=t[r>>2]|0;if(u[t[t[r>>2]>>2]>>0]|0)t[o>>2]=(t[o>>2]|0)+1;while(1){do if((u[t[t[r>>2]>>2]>>0]|0|0)==32)k=1;else{if(9<=(u[t[t[r>>2]>>2]>>0]|0|0)?(u[t[t[r>>2]>>2]>>0]|0|0)<=10:0){k=1;break}k=(u[t[t[r>>2]>>2]>>0]|0|0)==13}while(0);h=u[t[t[r>>2]>>2]>>0]|0;if(!k)break;o=t[r>>2]|0;if(!h)continue;t[o>>2]=(t[o>>2]|0)+1}if(!h){t[(t[r>>2]|0)+8>>2]=1;s=i;return}}Yj(t[r>>2]|0);if(t[(t[r>>2]|0)+8>>2]|0){s=i;return}i:while(1){do if((u[t[t[r>>2]>>2]>>0]|0|0)!=32){if(9<=(u[t[t[r>>2]>>2]>>0]|0|0)?(u[t[t[r>>2]>>2]>>0]|0|0)<=10:0)break;if((u[t[t[r>>2]>>2]>>0]|0|0)!=13)break i}while(0);o=t[r>>2]|0;if(!(u[t[t[r>>2]>>2]>>0]|0))continue;t[o>>2]=(t[o>>2]|0)+1}while(1){if((u[t[t[r>>2]>>2]>>0]|0|0)!=47)break e;o=t[r>>2]|0;n=t[(t[r>>2]|0)+16>>2]|0;if((u[(t[t[r>>2]>>2]|0)+1>>0]|0|0)!=47){if(qj(o,n,5,0,0)|0){a=103;break}f=t[r>>2]|0;if(u[t[t[r>>2]>>2]>>0]|0)t[f>>2]=(t[f>>2]|0)+1;while(1){do if((u[t[t[r>>2]>>2]>>0]|0|0)==32)w=1;else{if(9<=(u[t[t[r>>2]>>2]>>0]|0|0)?(u[t[t[r>>2]>>2]>>0]|0|0)<=10:0){w=1;break}w=(u[t[t[r>>2]>>2]>>0]|0|0)==13}while(0);d=u[t[t[r>>2]>>2]>>0]|0;if(!w)break;f=t[r>>2]|0;if(!d)continue;t[f>>2]=(t[f>>2]|0)+1}v=t[r>>2]|0;if(!d){a=99;break}Yj(v);if(t[(t[r>>2]|0)+8>>2]|0){a=103;break}else continue}if(qj(o,n,6,0,0)|0){a=103;break}f=t[r>>2]|0;if(u[t[t[r>>2]>>2]>>0]|0)t[f>>2]=(t[f>>2]|0)+1;f=t[r>>2]|0;if(u[t[t[r>>2]>>2]>>0]|0)t[f>>2]=(t[f>>2]|0)+1;while(1){do if((u[t[t[r>>2]>>2]>>0]|0|0)==32)m=1;else{if(9<=(u[t[t[r>>2]>>2]>>0]|0|0)?(u[t[t[r>>2]>>2]>>0]|0|0)<=10:0){m=1;break}m=(u[t[t[r>>2]>>2]>>0]|0|0)==13}while(0);_=t[r>>2]|0;if(!m)break;f=t[r>>2]|0;if(!(u[t[_>>2]>>0]|0))continue;t[f>>2]=(t[f>>2]|0)+1}Yj(_);if(t[(t[r>>2]|0)+8>>2]|0){a=103;break}}if((a|0)==99){t[v+8>>2]=1;s=i;return}else if((a|0)==103){s=i;return}}while(0);if(!(u[t[t[r>>2]>>2]>>0]|0)){s=i;return}t[(t[r>>2]|0)+8>>2]=1;s=i;return}function Hj(e){e=e|0;var i=0,r=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if(!(t[r>>2]|0)){s=i;return}e=t[r>>2]|0;t[e+0>>2]=-1;t[e+4>>2]=-1;t[e+8>>2]=-1;t[e+12>>2]=-1;t[e+16>>2]=-1;t[e+20>>2]=-1;t[e+24>>2]=-1;t[e+28>>2]=-1;pAi[t[135736>>2]&511](t[r>>2]|0);s=i;return}function xj(e){e=e|0;var i=0,r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0;i=s;s=s+48|0;r=i+40|0;n=i+36|0;f=i+32|0;u=i+28|0;a=i+24|0;o=i+20|0;c=i+16|0;l=i+12|0;b=i;t[n>>2]=e;t[a>>2]=0;t[o>>2]=0;t[c>>2]=0;t[l>>2]=-1;if((t[n>>2]|0)!=0?(t[(t[n>>2]|0)+28>>2]|0)!=0:0){if((((t[(t[n>>2]|0)+20>>2]|0)==1?(t[t[(t[n>>2]|0)+28>>2]>>2]|0)==2:0)?(t[(t[(t[n>>2]|0)+28>>2]|0)+4>>2]|0)==0:0)?(t[(t[(t[n>>2]|0)+28>>2]|0)+8>>2]|0)==0:0){t[f>>2]=Wj(0)|0;if(!(t[f>>2]|0)){t[r>>2]=-1;k=t[r>>2]|0;s=i;return k|0}else{e=(t[f>>2]|0)+16|0;t[e>>2]=t[e>>2]|16384;t[(t[n>>2]|0)+32>>2]=t[f>>2];t[r>>2]=0;k=t[r>>2]|0;s=i;return k|0}}t[f>>2]=Wj(((t[(t[n>>2]|0)+20>>2]|0)/2|0)+1|0)|0;if(!(t[f>>2]|0)){t[r>>2]=-1;k=t[r>>2]|0;s=i;return k|0}if(t[(t[n>>2]|0)+4>>2]|0){t[t[f>>2]>>2]=t[(t[n>>2]|0)+4>>2];sz(t[t[f>>2]>>2]|0)|0}t[u>>2]=0;if(t[(t[n>>2]|0)+16>>2]&256){e=(t[f>>2]|0)+16|0;t[e>>2]=t[e>>2]|32768}e:while(1){if((t[u>>2]|0)>=(t[(t[n>>2]|0)+20>>2]|0)){h=43;break}e=(t[(t[n>>2]|0)+28>>2]|0)+((t[u>>2]|0)*12|0)|0;t[b+0>>2]=t[e+0>>2];t[b+4>>2]=t[e+4>>2];t[b+8>>2]=t[e+8>>2];i:do switch(t[b>>2]|0){case 1:{if(t[u>>2]|0)break e;t[o>>2]=1;break}case 2:{if((t[b+4>>2]|0)==0?(t[b+8>>2]|0)==0:0){if((t[(t[n>>2]|0)+20>>2]|0)!=((t[u>>2]|0)+1|0))break i;if(!(t[c>>2]&1))break i;if((t[(t[n>>2]|0)+20>>2]|0)==((t[u>>2]|0)+1|0)){e=(t[f>>2]|0)+16|0;t[e>>2]=t[e>>2]|16384}t[c>>2]=t[c>>2]|16;t[a>>2]=Kj(t[f>>2]|0,0,0,100,t[c>>2]|0)|0;if((t[a>>2]|0)<0)break e;t[c>>2]=0;if((t[l>>2]|0)==-1)break i;e=(t[(t[f>>2]|0)+12>>2]|0)+(t[l>>2]<<4)|0;t[e>>2]=t[e>>2]|32;t[l>>2]=-1;break i}t[a>>2]=Kj(t[f>>2]|0,t[b+4>>2]|0,t[b+8>>2]|0,1,t[c>>2]|0)|0;if((t[a>>2]|0)<0)break e;t[l>>2]=t[a>>2];t[c>>2]=0;break}case 6:{if((t[c>>2]&1|0)==0?(t[c>>2]=t[c>>2]|1,(t[(t[f>>2]|0)+16>>2]&65536|0)==0):0){e=(t[f>>2]|0)+16|0;t[e>>2]=t[e>>2]|65536}break}case 4:{t[c>>2]=t[c>>2]|8;t[l>>2]=-1;t[a>>2]=Kj(t[f>>2]|0,t[b+4>>2]|0,t[b+8>>2]|0,2,t[c>>2]|0)|0;t[c>>2]=0;if((t[a>>2]|0)<0)break e;break}case 8:{t[a>>2]=Kj(t[f>>2]|0,0,0,1,t[c>>2]|0)|0;if((t[a>>2]|0)<0)break e;t[l>>2]=t[a>>2];t[c>>2]=0;break}case 7:{t[a>>2]=Kj(t[f>>2]|0,0,t[b+4>>2]|0,1,t[c>>2]|0)|0;if((t[a>>2]|0)<0)break e;t[l>>2]=t[a>>2];t[c>>2]=0;break}case 3:{t[a>>2]=Kj(t[f>>2]|0,t[b+4>>2]|0,t[b+8>>2]|0,1,t[c>>2]|0)|0;if((t[a>>2]|0)<0)break e;t[l>>2]=t[a>>2];t[c>>2]=0;break}default:{}}while(0);t[u>>2]=(t[u>>2]|0)+1}if((h|0)==43){if((t[o>>2]|0)==0?(t[(t[n>>2]|0)+16>>2]&7|0)==0:0){if(!(t[(t[f>>2]|0)+16>>2]&65536)){h=(t[f>>2]|0)+16|0;t[h>>2]=t[h>>2]|65536}if((t[(t[f>>2]|0)+4>>2]|0)>0?(t[t[(t[f>>2]|0)+12>>2]>>2]&1|0)==0:0){h=t[(t[f>>2]|0)+12>>2]|0;t[h>>2]=t[h>>2]|1}}if((t[(t[f>>2]|0)+4>>2]|0)>(t[a>>2]|0)){h=(t[(t[f>>2]|0)+12>>2]|0)+(t[a>>2]<<4)|0;t[h>>2]=t[h>>2]|2;if(t[o>>2]|0){o=t[(t[f>>2]|0)+12>>2]|0;t[o>>2]=t[o>>2]|4}t[(t[n>>2]|0)+32>>2]=t[f>>2];t[r>>2]=0;k=t[r>>2]|0;s=i;return k|0}}Lj(t[f>>2]|0);t[r>>2]=0;k=t[r>>2]|0;s=i;return k|0}t[r>>2]=-1;k=t[r>>2]|0;s=i;return k|0}function Uj(e){e=e|0;var i=0,r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0;i=s;s=s+32|0;r=i+24|0;n=i+20|0;f=i+16|0;u=i+12|0;a=i+8|0;o=i+4|0;c=i;t[n>>2]=e;if((t[(t[n>>2]|0)+20>>2]|0)>0?(t[t[(t[n>>2]|0)+28>>2]>>2]|0)==6:0){t[f>>2]=0;t[u>>2]=1;while(1){if((t[u>>2]|0)>=(t[(t[n>>2]|0)+20>>2]|0))break;t[(t[(t[n>>2]|0)+28>>2]|0)+((t[f>>2]|0)*12|0)+4>>2]=t[(t[(t[n>>2]|0)+28>>2]|0)+((t[u>>2]|0)*12|0)+4>>2];t[(t[(t[n>>2]|0)+28>>2]|0)+((t[f>>2]|0)*12|0)+8>>2]=t[(t[(t[n>>2]|0)+28>>2]|0)+((t[u>>2]|0)*12|0)+8>>2];t[(t[(t[n>>2]|0)+28>>2]|0)+((t[f>>2]|0)*12|0)>>2]=t[(t[(t[n>>2]|0)+28>>2]|0)+((t[u>>2]|0)*12|0)>>2];t[f>>2]=(t[f>>2]|0)+1;t[u>>2]=(t[u>>2]|0)+1}e=(t[n>>2]|0)+20|0;t[e>>2]=(t[e>>2]|0)+-1}do if((t[(t[n>>2]|0)+20>>2]|0)>=(t[(t[n>>2]|0)+24>>2]|0)){t[a>>2]=MAi[t[135760>>2]&511](t[(t[n>>2]|0)+28>>2]|0,(t[(t[n>>2]|0)+24>>2]<<1)*12|0)|0;if(t[a>>2]|0){t[(t[n>>2]|0)+28>>2]=t[a>>2];e=(t[n>>2]|0)+24|0;t[e>>2]=t[e>>2]<<1;break}t[r>>2]=-1;l=t[r>>2]|0;s=i;return l|0}while(0);t[f>>2]=0;t[u>>2]=(t[(t[n>>2]|0)+20>>2]|0)-1;while(1){if((t[u>>2]|0)<=(t[f>>2]|0))break;t[o>>2]=t[(t[(t[n>>2]|0)+28>>2]|0)+((t[f>>2]|0)*12|0)+4>>2];t[(t[(t[n>>2]|0)+28>>2]|0)+((t[f>>2]|0)*12|0)+4>>2]=t[(t[(t[n>>2]|0)+28>>2]|0)+((t[u>>2]|0)*12|0)+4>>2];t[(t[(t[n>>2]|0)+28>>2]|0)+((t[u>>2]|0)*12|0)+4>>2]=t[o>>2];t[o>>2]=t[(t[(t[n>>2]|0)+28>>2]|0)+((t[f>>2]|0)*12|0)+8>>2];t[(t[(t[n>>2]|0)+28>>2]|0)+((t[f>>2]|0)*12|0)+8>>2]=t[(t[(t[n>>2]|0)+28>>2]|0)+((t[u>>2]|0)*12|0)+8>>2];t[(t[(t[n>>2]|0)+28>>2]|0)+((t[u>>2]|0)*12|0)+8>>2]=t[o>>2];t[c>>2]=t[(t[(t[n>>2]|0)+28>>2]|0)+((t[f>>2]|0)*12|0)>>2];t[(t[(t[n>>2]|0)+28>>2]|0)+((t[f>>2]|0)*12|0)>>2]=t[(t[(t[n>>2]|0)+28>>2]|0)+((t[u>>2]|0)*12|0)>>2];t[(t[(t[n>>2]|0)+28>>2]|0)+((t[u>>2]|0)*12|0)>>2]=t[c>>2];t[u>>2]=(t[u>>2]|0)+-1;t[f>>2]=(t[f>>2]|0)+1}t[(t[(t[n>>2]|0)+28>>2]|0)+((t[(t[n>>2]|0)+20>>2]|0)*12|0)+4>>2]=0;t[(t[(t[n>>2]|0)+28>>2]|0)+((t[(t[n>>2]|0)+20>>2]|0)*12|0)+8>>2]=0;f=(t[n>>2]|0)+20|0;u=t[f>>2]|0;t[f>>2]=u+1;t[(t[(t[n>>2]|0)+28>>2]|0)+(u*12|0)>>2]=0;t[r>>2]=0;l=t[r>>2]|0;s=i;return l|0}function zj(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0;r=s;s=s+48|0;n=r+32|0;f=r+28|0;a=r+24|0;o=r+20|0;c=r+16|0;l=r+4|0;b=r;t[f>>2]=e;t[a>>2]=i;t[l+0>>2]=0;t[l+4>>2]=0;t[l+8>>2]=0;if((t[f>>2]|0)==0|(t[a>>2]|0)==0){t[n>>2]=-1;k=t[n>>2]|0;s=r;return k|0}t[o>>2]=0;e:while(1){if((t[o>>2]|0)>=(t[(t[f>>2]|0)+20>>2]|0)){h=84;break}t[c>>2]=(t[(t[f>>2]|0)+28>>2]|0)+((t[o>>2]|0)*12|0);i:do switch(t[t[c>>2]>>2]|0){case 8:{if((t[(t[a>>2]|0)+4>>2]|0)==1)h=83;break}case 3:{if((((t[(t[a>>2]|0)+4>>2]|0)!=1?(t[(t[a>>2]|0)+4>>2]|0)!=9:0)?(t[(t[a>>2]|0)+4>>2]|0)!=21:0)?(t[(t[a>>2]|0)+4>>2]|0)!=13:0)break i;t[b>>2]=t[(t[a>>2]|0)+12>>2];if(t[(t[c>>2]|0)+4>>2]|0){while(1){if(!(t[b>>2]|0))break;if(((t[(t[b>>2]|0)+4>>2]|0)==1?(u[t[(t[c>>2]|0)+4>>2]>>0]|0|0)==(u[t[(t[b>>2]|0)+8>>2]>>0]|0|0):0)?(Xl(t[(t[c>>2]|0)+4>>2]|0,t[(t[b>>2]|0)+8>>2]|0)|0)!=0:0)break;t[b>>2]=t[(t[b>>2]|0)+24>>2]}if(t[b>>2]|0)h=83}break}case 2:{if((t[(t[a>>2]|0)+4>>2]|0)==1)if(t[(t[c>>2]|0)+4>>2]|0){if((u[t[(t[c>>2]|0)+4>>2]>>0]|0|0)==(u[t[(t[a>>2]|0)+8>>2]>>0]|0|0)?(Xl(t[(t[c>>2]|0)+4>>2]|0,t[(t[a>>2]|0)+8>>2]|0)|0)!=0:0){if(!(t[(t[a>>2]|0)+36>>2]|0))if(t[(t[c>>2]|0)+8>>2]|0)break i;else{h=83;break i}if(t[(t[(t[a>>2]|0)+36>>2]|0)+8>>2]|0){if((t[(t[c>>2]|0)+8>>2]|0)!=0?(Xl(t[(t[c>>2]|0)+8>>2]|0,t[(t[(t[a>>2]|0)+36>>2]|0)+8>>2]|0)|0)!=0:0)h=83}else h=83}}else h=83;break}case 5:{if(((((t[(t[a>>2]|0)+4>>2]|0)!=9?(t[(t[a>>2]|0)+4>>2]|0)!=13:0)?(t[(t[a>>2]|0)+4>>2]|0)!=21:0)?(t[(t[a>>2]|0)+4>>2]|0)!=18:0)?(t[a>>2]=t[(t[a>>2]|0)+20>>2],(t[a>>2]|0)!=0):0)if(t[(t[c>>2]|0)+4>>2]|0){if((u[t[(t[c>>2]|0)+4>>2]>>0]|0|0)==(u[t[(t[a>>2]|0)+8>>2]>>0]|0|0)?(Xl(t[(t[c>>2]|0)+4>>2]|0,t[(t[a>>2]|0)+8>>2]|0)|0)!=0:0){if(!(t[(t[a>>2]|0)+36>>2]|0))if(t[(t[c>>2]|0)+8>>2]|0)break i;else{h=83;break i}if(t[(t[(t[a>>2]|0)+36>>2]|0)+8>>2]|0){if((t[(t[c>>2]|0)+8>>2]|0)!=0?(Xl(t[(t[c>>2]|0)+8>>2]|0,t[(t[(t[a>>2]|0)+36>>2]|0)+8>>2]|0)|0)!=0:0)h=83}else h=83}}else h=83;break}case 6:{if(!(t[(t[c>>2]|0)+4>>2]|0)){t[o>>2]=(t[o>>2]|0)+1;t[c>>2]=(t[(t[f>>2]|0)+28>>2]|0)+((t[o>>2]|0)*12|0);if((t[t[c>>2]>>2]|0)==1){h=84;break e}if((t[t[c>>2]>>2]|0)!=2)break i;if(!(t[(t[c>>2]|0)+4>>2]|0)){h=55;break e}}if(((((t[a>>2]|0)!=0?(t[(t[a>>2]|0)+4>>2]|0)!=9:0)?(t[(t[a>>2]|0)+4>>2]|0)!=13:0)?(t[(t[a>>2]|0)+4>>2]|0)!=21:0)?(t[(t[a>>2]|0)+4>>2]|0)!=18:0){t[a>>2]=t[(t[a>>2]|0)+20>>2];r:while(1){if(!(t[a>>2]|0))break;do if(((t[(t[a>>2]|0)+4>>2]|0)==1?(u[t[(t[c>>2]|0)+4>>2]>>0]|0|0)==(u[t[(t[a>>2]|0)+8>>2]>>0]|0|0):0)?(Xl(t[(t[c>>2]|0)+4>>2]|0,t[(t[a>>2]|0)+8>>2]|0)|0)!=0:0){if(!(t[(t[a>>2]|0)+36>>2]|0))if(!(t[(t[c>>2]|0)+8>>2]|0))break r;else break;if(((t[(t[(t[a>>2]|0)+36>>2]|0)+8>>2]|0)!=0?(t[(t[c>>2]|0)+8>>2]|0)!=0:0)?(Xl(t[(t[c>>2]|0)+8>>2]|0,t[(t[(t[a>>2]|0)+36>>2]|0)+8>>2]|0)|0)!=0:0)break r}while(0);t[a>>2]=t[(t[a>>2]|0)+20>>2]}if(t[a>>2]|0){i=t[o>>2]|0;if((t[t[c>>2]>>2]|0)==6){Xj(l,i,t[a>>2]|0)|0;h=83;break i}else{Xj(l,i-1|0,t[a>>2]|0)|0;h=83;break i}}}break}case 1:{if((t[(t[a>>2]|0)+4>>2]|0)!=18){t[a>>2]=t[(t[a>>2]|0)+20>>2];if(!(((t[(t[a>>2]|0)+4>>2]|0)!=9?(t[(t[a>>2]|0)+4>>2]|0)!=21:0)?(t[(t[a>>2]|0)+4>>2]|0)!=13:0))h=83}break}case 4:{if((t[(t[a>>2]|0)+4>>2]|0)==2){if(t[(t[c>>2]|0)+4>>2]|0){if((u[t[(t[c>>2]|0)+4>>2]>>0]|0|0)!=(u[t[(t[a>>2]|0)+8>>2]>>0]|0|0))break i;if(!(Xl(t[(t[c>>2]|0)+4>>2]|0,t[(t[a>>2]|0)+8>>2]|0)|0))break i}i=(t[(t[c>>2]|0)+8>>2]|0)!=0;if(!(t[(t[a>>2]|0)+36>>2]|0))if(i)break i;else{h=83;break i}if(!(i?(Xl(t[(t[c>>2]|0)+8>>2]|0,t[(t[(t[a>>2]|0)+36>>2]|0)+8>>2]|0)|0)==0:0))h=83}break}case 7:{if((t[(t[a>>2]|0)+4>>2]|0)==1){if(!(t[(t[a>>2]|0)+36>>2]|0))if(t[(t[c>>2]|0)+4>>2]|0)break i;else{h=83;break i}if(t[(t[(t[a>>2]|0)+36>>2]|0)+8>>2]|0){if((t[(t[c>>2]|0)+4>>2]|0)!=0?(Xl(t[(t[c>>2]|0)+4>>2]|0,t[(t[(t[a>>2]|0)+36>>2]|0)+8>>2]|0)|0)!=0:0)h=83}else h=83}break}case 0:{h=84;break e;break}default:h=83}while(0);if((h|0)==83){h=0;t[o>>2]=(t[o>>2]|0)+1;continue}if(!(t[l+8>>2]|0)){h=88;break}if((t[l>>2]|0)<=0){h=90;break}t[l>>2]=(t[l>>2]|0)+-1;t[o>>2]=t[(t[l+8>>2]|0)+(t[l>>2]<<3)>>2];t[a>>2]=t[(t[l+8>>2]|0)+(t[l>>2]<<3)+4>>2]}if((h|0)==55){t[n>>2]=-1;k=t[n>>2]|0;s=r;return k|0}else if((h|0)==84){if(t[l+8>>2]|0)pAi[t[135736>>2]&511](t[l+8>>2]|0);t[n>>2]=1;k=t[n>>2]|0;s=r;return k|0}else if((h|0)==88){t[n>>2]=0;k=t[n>>2]|0;s=r;return k|0}else if((h|0)==90){pAi[t[135736>>2]&511](t[l+8>>2]|0);t[n>>2]=0;k=t[n>>2]|0;s=r;return k|0}return 0}function jj(e){e=e|0;var i=0,r=0,n=0,f=0,u=0;i=s;s=s+16|0;r=i+8|0;n=i+4|0;f=i;t[n>>2]=e;t[f>>2]=gAi[t[135744>>2]&511](32)|0;if(!(t[f>>2]|0)){t[r>>2]=0;u=t[r>>2]|0;s=i;return u|0}e=t[f>>2]|0;t[e+0>>2]=0;t[e+4>>2]=0;t[e+8>>2]=0;t[e+12>>2]=0;t[e+16>>2]=0;t[e+20>>2]=0;t[e+24>>2]=0;t[e+28>>2]=0;e=gAi[t[135744>>2]&511](32)|0;t[(t[f>>2]|0)+20>>2]=e;if(!(t[(t[f>>2]|0)+20>>2]|0)){pAi[t[135736>>2]&511](t[f>>2]|0);t[r>>2]=0;u=t[r>>2]|0;s=i;return u|0}else{t[(t[f>>2]|0)+8>>2]=0;t[(t[f>>2]|0)+12>>2]=4;t[(t[f>>2]|0)+16>>2]=0;t[(t[f>>2]|0)+4>>2]=t[n>>2];t[(t[f>>2]|0)+28>>2]=-1;t[r>>2]=t[f>>2];u=t[r>>2]|0;s=i;return u|0}return 0}function Vj(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0;n=s;s=s+32|0;f=n+20|0;u=n+16|0;a=n+12|0;o=n+8|0;c=n+4|0;l=n;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;t[c>>2]=0;while(1){if((t[c>>2]|0)>=(t[(t[u>>2]|0)+8>>2]|0))break;if((t[(t[(t[u>>2]|0)+20>>2]|0)+(t[c>>2]<<1<<2)>>2]|0)<0){b=4;break}t[c>>2]=(t[c>>2]|0)+1}if((b|0)==4){t[(t[(t[u>>2]|0)+20>>2]|0)+(t[c>>2]<<1<<2)>>2]=t[a>>2];t[(t[(t[u>>2]|0)+20>>2]|0)+((t[c>>2]<<1)+1<<2)>>2]=t[o>>2];t[f>>2]=t[c>>2];k=t[f>>2]|0;s=n;return k|0}do if((t[(t[u>>2]|0)+8>>2]|0)>=(t[(t[u>>2]|0)+12>>2]|0)){t[l>>2]=MAi[t[135760>>2]&511](t[(t[u>>2]|0)+20>>2]|0,t[(t[u>>2]|0)+12>>2]<<2<<2)|0;if(t[l>>2]|0){t[(t[u>>2]|0)+20>>2]=t[l>>2];c=(t[u>>2]|0)+12|0;t[c>>2]=t[c>>2]<<1;break}t[f>>2]=-1;k=t[f>>2]|0;s=n;return k|0}while(0);t[(t[(t[u>>2]|0)+20>>2]|0)+(t[(t[u>>2]|0)+8>>2]<<1<<2)>>2]=t[a>>2];a=t[o>>2]|0;o=(t[u>>2]|0)+8|0;l=t[o>>2]|0;t[o>>2]=l+1;t[(t[(t[u>>2]|0)+20>>2]|0)+((l<<1)+1<<2)>>2]=a;t[f>>2]=(t[(t[u>>2]|0)+8>>2]|0)-1;k=t[f>>2]|0;s=n;return k|0}function qj(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;var u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0;u=s;s=s+32|0;a=u+24|0;o=u+16|0;c=u+12|0;l=u+8|0;b=u+4|0;k=u;t[u+20>>2]=e;t[o>>2]=i;t[c>>2]=r;t[l>>2]=n;t[b>>2]=f;do if((t[(t[o>>2]|0)+20>>2]|0)>=(t[(t[o>>2]|0)+24>>2]|0)){t[k>>2]=MAi[t[135760>>2]&511](t[(t[o>>2]|0)+28>>2]|0,(t[(t[o>>2]|0)+24>>2]<<1)*12|0)|0;if(t[k>>2]|0){
	t[(t[o>>2]|0)+28>>2]=t[k>>2];f=(t[o>>2]|0)+24|0;t[f>>2]=t[f>>2]<<1;break}t[a>>2]=-1;h=t[a>>2]|0;s=u;return h|0}while(0);t[(t[(t[o>>2]|0)+28>>2]|0)+((t[(t[o>>2]|0)+20>>2]|0)*12|0)>>2]=t[c>>2];t[(t[(t[o>>2]|0)+28>>2]|0)+((t[(t[o>>2]|0)+20>>2]|0)*12|0)+4>>2]=t[l>>2];t[(t[(t[o>>2]|0)+28>>2]|0)+((t[(t[o>>2]|0)+20>>2]|0)*12|0)+8>>2]=t[b>>2];b=(t[o>>2]|0)+20|0;t[b>>2]=(t[b>>2]|0)+1;t[a>>2]=0;h=t[a>>2]|0;s=u;return h|0}function Yj(e){e=e|0;var i=0,r=0,n=0,f=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0;i=s;s=s+48|0;r=i+32|0;n=i+28|0;f=i+24|0;a=i+20|0;o=i+16|0;c=i+12|0;l=i+8|0;b=i+4|0;k=i;t[r>>2]=e;t[n>>2]=0;t[f>>2]=0;t[a>>2]=0;t[o>>2]=0;while(1){do if((u[t[t[r>>2]>>2]>>0]|0|0)==32)h=1;else{if(9<=(u[t[t[r>>2]>>2]>>0]|0|0)?(u[t[t[r>>2]>>2]>>0]|0|0)<=10:0){h=1;break}h=(u[t[t[r>>2]>>2]>>0]|0|0)==13}while(0);w=u[t[t[r>>2]>>2]>>0]|0;if(!h)break;e=t[r>>2]|0;if(!w)continue;t[e>>2]=(t[e>>2]|0)+1}h=u[t[t[r>>2]>>2]>>0]|0;e:do if((w|0)==46){e=t[r>>2]|0;if(h)t[e>>2]=(t[e>>2]|0)+1;if(!(qj(t[r>>2]|0,t[(t[r>>2]|0)+16>>2]|0,2,0,0)|0)){s=i;return}}else{e=t[r>>2]|0;if((h|0)==64){d=t[r>>2]|0;if(t[(t[e+16>>2]|0)+16>>2]&2){t[d+8>>2]=1;s=i;return}v=t[r>>2]|0;if(u[t[d>>2]>>0]|0)t[v>>2]=(t[v>>2]|0)+1;Gj(t[r>>2]|0);if(t[(t[r>>2]|0)+8>>2]|0)break;s=i;return}t[f>>2]=Zj(e)|0;e=u[t[t[r>>2]>>2]>>0]|0;if(!(t[f>>2]|0)){v=t[r>>2]|0;if((e|0)!=42){t[v+8>>2]=1;s=i;return}d=t[r>>2]|0;if(u[t[v>>2]>>0]|0)t[d>>2]=(t[d>>2]|0)+1;if(qj(t[r>>2]|0,t[(t[r>>2]|0)+16>>2]|0,8,0,0)|0)break;s=i;return}do if((e|0)!=32){if(9<=(u[t[t[r>>2]>>2]>>0]|0|0)?(u[t[t[r>>2]>>2]>>0]|0|0)<=10:0){m=29;break}if((u[t[t[r>>2]>>2]>>0]|0|0)==13)m=29}else m=29;while(0);i:do if((m|0)==29){t[o>>2]=1;while(1){do if((u[t[t[r>>2]>>2]>>0]|0|0)!=32){if(9<=(u[t[t[r>>2]>>2]>>0]|0|0)?(u[t[t[r>>2]>>2]>>0]|0|0)<=10:0)break;if((u[t[t[r>>2]>>2]>>0]|0|0)!=13)break i}while(0);e=t[r>>2]|0;if(!(u[t[t[r>>2]>>2]>>0]|0))continue;t[e>>2]=(t[e>>2]|0)+1}}while(0);e=u[t[t[r>>2]>>2]>>0]|0;if((u[t[t[r>>2]>>2]>>0]|0|0)!=58){if((e|0)!=42){if(qj(t[r>>2]|0,t[(t[r>>2]|0)+16>>2]|0,2,t[f>>2]|0,0)|0)break;s=i;return}d=t[r>>2]|0;if(t[f>>2]|0){t[d+8>>2]=1;break}v=t[r>>2]|0;if(u[t[d>>2]>>0]|0)t[v>>2]=(t[v>>2]|0)+1;if(qj(t[r>>2]|0,t[(t[r>>2]|0)+16>>2]|0,8,t[n>>2]|0,0)|0)break;s=i;return}v=t[r>>2]|0;if(e)t[v>>2]=(t[v>>2]|0)+1;if((u[t[t[r>>2]>>2]>>0]|0|0)!=58){t[c>>2]=t[f>>2];do if((t[o>>2]|0)==0?(u[t[t[r>>2]>>2]>>0]|0|0)!=32:0){if(9<=(u[t[t[r>>2]>>2]>>0]|0|0)?(u[t[t[r>>2]>>2]>>0]|0|0)<=10:0)break;if((u[t[t[r>>2]>>2]>>0]|0|0)!=13){t[n>>2]=Jj(t[r>>2]|0)|0;do if((((u[t[c>>2]>>0]|0|0)==120?(u[(t[c>>2]|0)+1>>0]|0|0)==109:0)?(u[(t[c>>2]|0)+2>>0]|0|0)==108:0)?(u[(t[c>>2]|0)+3>>0]|0|0)==0:0)if(t[(t[(t[r>>2]|0)+16>>2]|0)+4>>2]|0){t[a>>2]=kz(t[(t[(t[r>>2]|0)+16>>2]|0)+4>>2]|0,200288,-1)|0;break}else{t[a>>2]=Yl(200288)|0;break}else m=53;while(0);if((m|0)==53){t[l>>2]=0;while(1){if((t[l>>2]|0)>=(t[(t[r>>2]|0)+28>>2]|0))break;if(Xl(t[(t[(t[r>>2]|0)+24>>2]|0)+((t[l>>2]<<1)+1<<2)>>2]|0,t[c>>2]|0)|0){m=56;break}t[l>>2]=(t[l>>2]|0)+1}do if((m|0)==56)if(t[(t[(t[r>>2]|0)+16>>2]|0)+4>>2]|0){t[a>>2]=kz(t[(t[(t[r>>2]|0)+16>>2]|0)+4>>2]|0,t[(t[(t[r>>2]|0)+24>>2]|0)+(t[l>>2]<<1<<2)>>2]|0,-1)|0;break}else{t[a>>2]=Yl(t[(t[(t[r>>2]|0)+24>>2]|0)+(t[l>>2]<<1<<2)>>2]|0)|0;break}while(0);if((t[l>>2]|0)>=(t[(t[r>>2]|0)+28>>2]|0)){t[(t[r>>2]|0)+8>>2]=1;break e}}if(!(t[(t[(t[r>>2]|0)+16>>2]|0)+4>>2]|0))pAi[t[135736>>2]&511](t[c>>2]|0);t[f>>2]=0;v=t[r>>2]|0;if(t[n>>2]|0){if(qj(v,t[(t[r>>2]|0)+16>>2]|0,2,t[n>>2]|0,t[a>>2]|0)|0)break e;s=i;return}e=t[r>>2]|0;if((u[t[v>>2]>>0]|0|0)!=42){t[e+8>>2]=1;break e}v=t[r>>2]|0;if(u[t[e>>2]>>0]|0)t[v>>2]=(t[v>>2]|0)+1;if(qj(t[r>>2]|0,t[(t[r>>2]|0)+16>>2]|0,7,t[a>>2]|0,0)|0)break e;s=i;return}}while(0);t[(t[r>>2]|0)+8>>2]=1;break}v=t[r>>2]|0;if(u[t[t[r>>2]>>2]>>0]|0)t[v>>2]=(t[v>>2]|0)+1;if(!(Xl(t[f>>2]|0,200328)|0)){v=(Xl(t[f>>2]|0,200336)|0)!=0;e=t[r>>2]|0;if(!v){t[e+8>>2]=1;break}if(!(t[(t[e+16>>2]|0)+4>>2]|0))pAi[t[135736>>2]&511](t[f>>2]|0);t[f>>2]=0;e=t[r>>2]|0;if(t[(t[(t[r>>2]|0)+16>>2]|0)+16>>2]&2){t[e+8>>2]=1;break}Gj(e);if(t[(t[r>>2]|0)+8>>2]|0)break;s=i;return}if(!(t[(t[(t[r>>2]|0)+16>>2]|0)+4>>2]|0))pAi[t[135736>>2]&511](t[f>>2]|0);t[f>>2]=Jj(t[r>>2]|0)|0;e=u[t[t[r>>2]>>2]>>0]|0;if(!(t[f>>2]|0)){v=t[r>>2]|0;if((e|0)!=42){t[v+8>>2]=1;break}d=t[r>>2]|0;if(u[t[v>>2]>>0]|0)t[d>>2]=(t[d>>2]|0)+1;if(qj(t[r>>2]|0,t[(t[r>>2]|0)+16>>2]|0,8,0,0)|0)break;s=i;return}if((e|0)!=58){if(qj(t[r>>2]|0,t[(t[r>>2]|0)+16>>2]|0,3,t[f>>2]|0,0)|0)break;s=i;return}t[b>>2]=t[f>>2];e=t[r>>2]|0;if(u[t[t[r>>2]>>2]>>0]|0)t[e>>2]=(t[e>>2]|0)+1;do if((u[t[t[r>>2]>>2]>>0]|0|0)!=32){if(9<=(u[t[t[r>>2]>>2]>>0]|0|0)?(u[t[t[r>>2]>>2]>>0]|0|0)<=10:0)break;if((u[t[t[r>>2]>>2]>>0]|0|0)!=13){t[n>>2]=Jj(t[r>>2]|0)|0;do if((u[t[b>>2]>>0]|0|0)==120){if((u[(t[b>>2]|0)+1>>0]|0|0)!=109){m=97;break}if((u[(t[b>>2]|0)+2>>0]|0|0)!=108){m=97;break}if(u[(t[b>>2]|0)+3>>0]|0){m=97;break}if(t[(t[(t[r>>2]|0)+16>>2]|0)+4>>2]|0){t[a>>2]=kz(t[(t[(t[r>>2]|0)+16>>2]|0)+4>>2]|0,200288,-1)|0;break}else{t[a>>2]=Yl(200288)|0;break}}else m=97;while(0);do if((m|0)==97){t[k>>2]=0;while(1){if((t[k>>2]|0)>=(t[(t[r>>2]|0)+28>>2]|0))break;if(Xl(t[(t[(t[r>>2]|0)+24>>2]|0)+((t[k>>2]<<1)+1<<2)>>2]|0,t[b>>2]|0)|0){m=100;break}t[k>>2]=(t[k>>2]|0)+1}do if((m|0)==100)if(t[(t[(t[r>>2]|0)+16>>2]|0)+4>>2]|0){t[a>>2]=kz(t[(t[(t[r>>2]|0)+16>>2]|0)+4>>2]|0,t[(t[(t[r>>2]|0)+24>>2]|0)+(t[k>>2]<<1<<2)>>2]|0,-1)|0;break}else{t[a>>2]=Yl(t[(t[(t[r>>2]|0)+24>>2]|0)+(t[k>>2]<<1<<2)>>2]|0)|0;break}while(0);if((t[k>>2]|0)<(t[(t[r>>2]|0)+28>>2]|0))break;t[(t[r>>2]|0)+8>>2]=1;break e}while(0);if(!(t[(t[(t[r>>2]|0)+16>>2]|0)+4>>2]|0))pAi[t[135736>>2]&511](t[b>>2]|0);t[f>>2]=0;e=t[r>>2]|0;if(t[n>>2]|0){if(qj(e,t[(t[r>>2]|0)+16>>2]|0,3,t[n>>2]|0,t[a>>2]|0)|0)break e;s=i;return}d=t[r>>2]|0;if((u[t[e>>2]>>0]|0|0)!=42){t[d+8>>2]=1;break e}e=t[r>>2]|0;if(u[t[d>>2]>>0]|0)t[e>>2]=(t[e>>2]|0)+1;if(qj(t[r>>2]|0,t[(t[r>>2]|0)+16>>2]|0,7,t[a>>2]|0,0)|0)break e;s=i;return}}while(0);t[(t[r>>2]|0)+8>>2]=1}while(0);if((t[a>>2]|0)!=0?(t[(t[(t[r>>2]|0)+16>>2]|0)+4>>2]|0)==0:0)pAi[t[135736>>2]&511](t[a>>2]|0);if((t[n>>2]|0)!=0?(t[(t[(t[r>>2]|0)+16>>2]|0)+4>>2]|0)==0:0)pAi[t[135736>>2]&511](t[n>>2]|0);if(!(t[f>>2]|0)){s=i;return}if(t[(t[(t[r>>2]|0)+16>>2]|0)+4>>2]|0){s=i;return}pAi[t[135736>>2]&511](t[f>>2]|0);s=i;return}function Gj(e){e=e|0;var i=0,r=0,n=0,f=0,a=0,o=0,c=0,l=0,b=0,k=0;i=s;s=s+32|0;r=i+20|0;n=i+16|0;f=i+12|0;a=i+8|0;o=i+4|0;c=i;t[r>>2]=e;t[n>>2]=0;t[f>>2]=0;t[a>>2]=0;while(1){do if((u[t[t[r>>2]>>2]>>0]|0|0)==32)l=1;else{if(9<=(u[t[t[r>>2]>>2]>>0]|0|0)?(u[t[t[r>>2]>>2]>>0]|0|0)<=10:0){l=1;break}l=(u[t[t[r>>2]>>2]>>0]|0|0)==13}while(0);b=t[r>>2]|0;if(!l)break;e=t[r>>2]|0;if(!(u[t[b>>2]>>0]|0))continue;t[e>>2]=(t[e>>2]|0)+1}t[f>>2]=Zj(b)|0;b=u[t[t[r>>2]>>2]>>0]|0;e:do if(!(t[f>>2]|0)){l=t[r>>2]|0;if((b|0)!=42){t[l+8>>2]=1;s=i;return}if(!(qj(l,t[(t[r>>2]|0)+16>>2]|0,4,0,0)|0)){l=t[r>>2]|0;if(!(u[t[t[r>>2]>>2]>>0]|0)){s=i;return}t[l>>2]=(t[l>>2]|0)+1;s=i;return}}else{if((b|0)!=58){if(qj(t[r>>2]|0,t[(t[r>>2]|0)+16>>2]|0,4,t[f>>2]|0,0)|0)break;s=i;return}t[c>>2]=t[f>>2];l=t[r>>2]|0;if(u[t[t[r>>2]>>2]>>0]|0)t[l>>2]=(t[l>>2]|0)+1;do if((u[t[t[r>>2]>>2]>>0]|0|0)!=32){if(9<=(u[t[t[r>>2]>>2]>>0]|0|0)?(u[t[t[r>>2]>>2]>>0]|0|0)<=10:0)break;if((u[t[t[r>>2]>>2]>>0]|0|0)!=13){t[n>>2]=Jj(t[r>>2]|0)|0;do if((((u[t[c>>2]>>0]|0|0)==120?(u[(t[c>>2]|0)+1>>0]|0|0)==109:0)?(u[(t[c>>2]|0)+2>>0]|0|0)==108:0)?(u[(t[c>>2]|0)+3>>0]|0|0)==0:0)if(t[(t[(t[r>>2]|0)+16>>2]|0)+4>>2]|0){t[a>>2]=kz(t[(t[(t[r>>2]|0)+16>>2]|0)+4>>2]|0,200288,-1)|0;break}else{t[a>>2]=Yl(200288)|0;break}else k=32;while(0);if((k|0)==32){t[o>>2]=0;while(1){if((t[o>>2]|0)>=(t[(t[r>>2]|0)+28>>2]|0))break;if(Xl(t[(t[(t[r>>2]|0)+24>>2]|0)+((t[o>>2]<<1)+1<<2)>>2]|0,t[c>>2]|0)|0){k=35;break}t[o>>2]=(t[o>>2]|0)+1}do if((k|0)==35)if(t[(t[(t[r>>2]|0)+16>>2]|0)+4>>2]|0){t[a>>2]=kz(t[(t[(t[r>>2]|0)+16>>2]|0)+4>>2]|0,t[(t[(t[r>>2]|0)+24>>2]|0)+(t[o>>2]<<1<<2)>>2]|0,-1)|0;break}else{t[a>>2]=Yl(t[(t[(t[r>>2]|0)+24>>2]|0)+(t[o>>2]<<1<<2)>>2]|0)|0;break}while(0);if((t[o>>2]|0)>=(t[(t[r>>2]|0)+28>>2]|0)){t[(t[r>>2]|0)+8>>2]=1;break e}}if(!(t[(t[(t[r>>2]|0)+16>>2]|0)+4>>2]|0))pAi[t[135736>>2]&511](t[c>>2]|0);l=t[r>>2]|0;if(t[n>>2]|0){if(qj(l,t[(t[r>>2]|0)+16>>2]|0,4,t[n>>2]|0,t[a>>2]|0)|0)break e;s=i;return}e=t[r>>2]|0;if((u[t[l>>2]>>0]|0|0)!=42){t[e+8>>2]=1;break e}l=t[r>>2]|0;if(u[t[e>>2]>>0]|0)t[l>>2]=(t[l>>2]|0)+1;if(qj(t[r>>2]|0,t[(t[r>>2]|0)+16>>2]|0,4,0,t[a>>2]|0)|0)break e;s=i;return}}while(0);if(!(t[(t[(t[r>>2]|0)+16>>2]|0)+4>>2]|0))pAi[t[135736>>2]&511](t[c>>2]|0);t[(t[r>>2]|0)+8>>2]=1}while(0);if((t[a>>2]|0)!=0?(t[(t[(t[r>>2]|0)+16>>2]|0)+4>>2]|0)==0:0)pAi[t[135736>>2]&511](t[a>>2]|0);if(!(t[n>>2]|0)){s=i;return}if(t[(t[(t[r>>2]|0)+16>>2]|0)+4>>2]|0){s=i;return}pAi[t[135736>>2]&511](t[n>>2]|0);s=i;return}function Wj(e){e=e|0;var i=0,r=0,n=0,f=0,u=0;i=s;s=s+16|0;r=i+8|0;n=i+4|0;f=i;t[n>>2]=e;t[n>>2]=(t[n>>2]|0)<4?4:e;t[f>>2]=gAi[t[135744>>2]&511](20)|0;if(!(t[f>>2]|0)){t[r>>2]=0;u=t[r>>2]|0;s=i;return u|0}e=t[f>>2]|0;t[e+0>>2]=0;t[e+4>>2]=0;t[e+8>>2]=0;t[e+12>>2]=0;t[e+16>>2]=0;e=gAi[t[135744>>2]&511](t[n>>2]<<4)|0;t[(t[f>>2]|0)+12>>2]=e;if(!(t[(t[f>>2]|0)+12>>2]|0)){pAi[t[135736>>2]&511](t[f>>2]|0);t[r>>2]=0;u=t[r>>2]|0;s=i;return u|0}else{t[(t[f>>2]|0)+4>>2]=0;t[(t[f>>2]|0)+8>>2]=t[n>>2];t[r>>2]=t[f>>2];u=t[r>>2]|0;s=i;return u|0}return 0}function Kj(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;var u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0;u=s;s=s+32|0;a=u+24|0;o=u+20|0;c=u+16|0;l=u+12|0;b=u+8|0;k=u+4|0;h=u;t[o>>2]=e;t[c>>2]=i;t[l>>2]=r;t[b>>2]=n;t[k>>2]=f;do if((t[(t[o>>2]|0)+4>>2]|0)>=(t[(t[o>>2]|0)+8>>2]|0)){t[h>>2]=MAi[t[135760>>2]&511](t[(t[o>>2]|0)+12>>2]|0,t[(t[o>>2]|0)+8>>2]<<1<<4)|0;if(t[h>>2]|0){t[(t[o>>2]|0)+12>>2]=t[h>>2];f=(t[o>>2]|0)+8|0;t[f>>2]=t[f>>2]<<1;break}t[a>>2]=-1;w=t[a>>2]|0;s=u;return w|0}while(0);f=(t[o>>2]|0)+4|0;n=t[f>>2]|0;t[f>>2]=n+1;t[h>>2]=(t[(t[o>>2]|0)+12>>2]|0)+(n<<4);t[t[h>>2]>>2]=t[k>>2];t[(t[h>>2]|0)+4>>2]=t[c>>2];t[(t[h>>2]|0)+8>>2]=t[l>>2];t[(t[h>>2]|0)+12>>2]=t[b>>2];t[a>>2]=(t[(t[o>>2]|0)+4>>2]|0)-1;w=t[a>>2]|0;s=u;return w|0}function Xj(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0;n=s;s=s+32|0;f=n+16|0;u=n+12|0;a=n+8|0;o=n+4|0;c=n;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;do if((t[(t[u>>2]|0)+8>>2]|0)!=0?(t[(t[u>>2]|0)+4>>2]|0)>0:0){if((t[(t[u>>2]|0)+4>>2]|0)<=(t[t[u>>2]>>2]|0)){t[c>>2]=MAi[t[135760>>2]&511](t[(t[u>>2]|0)+8>>2]|0,t[(t[u>>2]|0)+4>>2]<<1<<3)|0;if(t[c>>2]|0){t[(t[u>>2]|0)+8>>2]=t[c>>2];r=(t[u>>2]|0)+4|0;t[r>>2]=t[r>>2]<<1;break}t[f>>2]=-1;l=t[f>>2]|0;s=n;return l|0}}else b=3;while(0);if((b|0)==3){t[(t[u>>2]|0)+4>>2]=4;t[t[u>>2]>>2]=0;b=gAi[t[135744>>2]&511](32)|0;t[(t[u>>2]|0)+8>>2]=b}t[(t[(t[u>>2]|0)+8>>2]|0)+(t[t[u>>2]>>2]<<3)>>2]=t[a>>2];a=t[o>>2]|0;o=t[u>>2]|0;b=t[o>>2]|0;t[o>>2]=b+1;t[(t[(t[u>>2]|0)+8>>2]|0)+(b<<3)+4>>2]=a;t[f>>2]=0;l=t[f>>2]|0;s=n;return l|0}function Zj(e){e=e|0;var i=0,r=0,n=0,f=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0;i=s;s=s+32|0;r=i+24|0;n=i+20|0;f=i+16|0;a=i+12|0;o=i+8|0;c=i+4|0;l=i;t[n>>2]=e;t[o>>2]=0;while(1){do if((u[t[t[n>>2]>>2]>>0]|0|0)==32)b=1;else{if(9<=(u[t[t[n>>2]>>2]>>0]|0|0)?(u[t[t[n>>2]>>2]>>0]|0|0)<=10:0){b=1;break}b=(u[t[t[n>>2]>>2]>>0]|0|0)==13}while(0);k=t[t[n>>2]>>2]|0;if(!b)break;e=t[n>>2]|0;if(!(u[k>>0]|0))continue;t[e>>2]=(t[e>>2]|0)+1}t[f>>2]=k;t[a>>2]=k;t[c>>2]=Mp(0,t[a>>2]|0,l)|0;k=t[c>>2]|0;if((t[c>>2]|0)<256){if(((!(65<=(k|0)&(t[c>>2]|0)<=90)?!(97<=(t[c>>2]|0)&(t[c>>2]|0)<=122):0)?!(192<=(t[c>>2]|0)&(t[c>>2]|0)<=214):0)?!(216<=(t[c>>2]|0)&(t[c>>2]|0)<=246|248<=(t[c>>2]|0)):0)h=15}else if(!(dj(k,199744)|0))h=15;do if((h|0)==15){k=t[c>>2]|0;if((t[c>>2]|0)<256){if((k|0)==95)break}else{if(19968<=(k|0)&(t[c>>2]|0)<=40869|(t[c>>2]|0)==12295)break;if(!((12321<=(t[c>>2]|0)&(t[c>>2]|0)<=12329^1)&(t[c>>2]|0)!=95))break}t[r>>2]=0;w=t[r>>2]|0;s=i;return w|0}while(0);e:while(1){k=t[c>>2]|0;if((t[c>>2]|0)<256){if(((!(65<=(k|0)&(t[c>>2]|0)<=90)?!(97<=(t[c>>2]|0)&(t[c>>2]|0)<=122):0)?!(192<=(t[c>>2]|0)&(t[c>>2]|0)<=214):0)?!(216<=(t[c>>2]|0)&(t[c>>2]|0)<=246|248<=(t[c>>2]|0)):0)h=26}else if(!(dj(k,199744)|0))h=26;do if((h|0)==26){h=0;if((t[c>>2]|0)>=256){if(19968<=(t[c>>2]|0)&(t[c>>2]|0)<=40869|(t[c>>2]|0)==12295)break;if(12321<=(t[c>>2]|0)&(t[c>>2]|0)<=12329)break}k=t[c>>2]|0;if((t[c>>2]|0)<256){if(48<=(k|0)&(t[c>>2]|0)<=57|(t[c>>2]|0)==46|(t[c>>2]|0)==45|(t[c>>2]|0)==95)break}else{b=(dj(k,200216)|0)!=0;if(b|(t[c>>2]|0)==46|(t[c>>2]|0)==45|(t[c>>2]|0)==95)break}if((t[c>>2]|0)>=256?(dj(t[c>>2]|0,200144)|0)!=0:0)break;b=t[c>>2]|0;if((t[c>>2]|0)<256)d=(b|0)==183&1;else d=dj(b,200272)|0;if(!d)break e}while(0);t[a>>2]=(t[a>>2]|0)+(t[l>>2]|0);t[c>>2]=Mp(0,t[a>>2]|0,l)|0}if(t[(t[n>>2]|0)+12>>2]|0)t[o>>2]=kz(t[(t[n>>2]|0)+12>>2]|0,t[f>>2]|0,(t[a>>2]|0)-(t[f>>2]|0)|0)|0;else t[o>>2]=ql(t[f>>2]|0,(t[a>>2]|0)-(t[f>>2]|0)|0)|0;t[t[n>>2]>>2]=t[a>>2];t[r>>2]=t[o>>2];w=t[r>>2]|0;s=i;return w|0}function Jj(e){e=e|0;var i=0,r=0,n=0,f=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0;i=s;s=s+32|0;r=i+24|0;n=i+20|0;f=i+16|0;a=i+12|0;o=i+8|0;c=i+4|0;l=i;t[n>>2]=e;t[o>>2]=0;while(1){do if((u[t[t[n>>2]>>2]>>0]|0|0)==32)b=1;else{if(9<=(u[t[t[n>>2]>>2]>>0]|0|0)?(u[t[t[n>>2]>>2]>>0]|0|0)<=10:0){b=1;break}b=(u[t[t[n>>2]>>2]>>0]|0|0)==13}while(0);k=t[t[n>>2]>>2]|0;if(!b)break;e=t[n>>2]|0;if(!(u[k>>0]|0))continue;t[e>>2]=(t[e>>2]|0)+1}t[f>>2]=k;t[a>>2]=k;t[c>>2]=Mp(0,t[a>>2]|0,l)|0;k=t[c>>2]|0;if((t[c>>2]|0)<256){if(((!(65<=(k|0)&(t[c>>2]|0)<=90)?!(97<=(t[c>>2]|0)&(t[c>>2]|0)<=122):0)?!(192<=(t[c>>2]|0)&(t[c>>2]|0)<=214):0)?!(216<=(t[c>>2]|0)&(t[c>>2]|0)<=246|248<=(t[c>>2]|0)):0)h=15}else if(!(dj(k,199744)|0))h=15;do if((h|0)==15){k=t[c>>2]|0;if((t[c>>2]|0)<256){if(!((k|0)!=95&(t[c>>2]|0)!=58))break}else{if(19968<=(k|0)&(t[c>>2]|0)<=40869|(t[c>>2]|0)==12295)break;if(!((12321<=(t[c>>2]|0)&(t[c>>2]|0)<=12329^1)&(t[c>>2]|0)!=95&(t[c>>2]|0)!=58))break}t[r>>2]=0;w=t[r>>2]|0;s=i;return w|0}while(0);e:while(1){k=t[c>>2]|0;if((t[c>>2]|0)<256){if(((!(65<=(k|0)&(t[c>>2]|0)<=90)?!(97<=(t[c>>2]|0)&(t[c>>2]|0)<=122):0)?!(192<=(t[c>>2]|0)&(t[c>>2]|0)<=214):0)?!(216<=(t[c>>2]|0)&(t[c>>2]|0)<=246|248<=(t[c>>2]|0)):0)h=26}else if(!(dj(k,199744)|0))h=26;do if((h|0)==26){h=0;if((t[c>>2]|0)>=256){if(19968<=(t[c>>2]|0)&(t[c>>2]|0)<=40869|(t[c>>2]|0)==12295)break;if(12321<=(t[c>>2]|0)&(t[c>>2]|0)<=12329)break}k=t[c>>2]|0;if((t[c>>2]|0)<256){if(48<=(k|0)&(t[c>>2]|0)<=57|(t[c>>2]|0)==46|(t[c>>2]|0)==45|(t[c>>2]|0)==95)break}else{b=(dj(k,200216)|0)!=0;if(b|(t[c>>2]|0)==46|(t[c>>2]|0)==45|(t[c>>2]|0)==95)break}if((t[c>>2]|0)>=256?(dj(t[c>>2]|0,200144)|0)!=0:0)break;b=t[c>>2]|0;if((t[c>>2]|0)<256)d=(b|0)==183&1;else d=dj(b,200272)|0;if(!d)break e}while(0);t[a>>2]=(t[a>>2]|0)+(t[l>>2]|0);t[c>>2]=Mp(0,t[a>>2]|0,l)|0}if(t[(t[n>>2]|0)+12>>2]|0)t[o>>2]=kz(t[(t[n>>2]|0)+12>>2]|0,t[f>>2]|0,(t[a>>2]|0)-(t[f>>2]|0)|0)|0;else t[o>>2]=ql(t[f>>2]|0,(t[a>>2]|0)-(t[f>>2]|0)|0)|0;t[t[n>>2]>>2]=t[a>>2];t[r>>2]=t[o>>2];w=t[r>>2]|0;s=i;return w|0}function Qj(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0;r=s;s=s+16|0;n=r+8|0;f=r+4|0;u=r;t[f>>2]=e;t[u>>2]=i;do if((t[f>>2]|0)==0&(t[u>>2]|0)==0)t[n>>2]=-1;else{if(t[u>>2]|0){if(Xl(t[u>>2]|0,200352)|0){t[n>>2]=1;break}if(Xl(t[u>>2]|0,200392)|0){t[n>>2]=1;break}if(Xl(t[u>>2]|0,200432)|0){t[n>>2]=1;break}}if(t[f>>2]|0){if(Xl(t[f>>2]|0,200472)|0){t[n>>2]=1;break}if(Xl(t[f>>2]|0,200528)|0){t[n>>2]=1;break}if(Xl(t[f>>2]|0,200584)|0){t[n>>2]=1;break}}t[n>>2]=0}while(0);s=r;return t[n>>2]|0}function $j(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0;r=s;s=s+16|0;n=r+8|0;f=r+4|0;u=r;t[n>>2]=e;t[f>>2]=i;t[u>>2]=gF()|0;if(!(t[u>>2]|0)){s=r;return}UM(t[u>>2]|0,t[f>>2]|0);Us(t[n>>2]|0,t[u>>2]|0)|0;s=r;return}function eV(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0;r=s;s=s+16|0;n=r+8|0;f=r+4|0;u=r;t[n>>2]=e;t[f>>2]=i;t[u>>2]=gF()|0;if(!(t[u>>2]|0)){s=r;return}MM(t[u>>2]|0,t[f>>2]|0);Us(t[n>>2]|0,t[u>>2]|0)|0;s=r;return}function iV(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0;r=s;s=s+16|0;n=r+8|0;f=r+4|0;u=r;t[n>>2]=e;t[f>>2]=i;t[u>>2]=gF()|0;if(!(t[u>>2]|0)){s=r;return}PM(t[u>>2]|0,t[f>>2]|0);Us(t[n>>2]|0,t[u>>2]|0)|0;s=r;return}function rV(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0;r=s;s=s+16|0;n=r+8|0;f=r+4|0;u=r;t[n>>2]=e;t[f>>2]=i;t[u>>2]=gF()|0;if(!(t[u>>2]|0)){s=r;return}__(t[u>>2]|0,t[f>>2]|0);Us(t[n>>2]|0,t[u>>2]|0)|0;s=r;return}function nV(e,i){e=e|0;i=i|0;var r=0,n=0,f=0;r=s;s=s+16|0;n=r+4|0;f=r;t[n>>2]=e;t[f>>2]=i;while(1){if(!(t[f>>2]|0))break;gV(t[n>>2]|0,t[f>>2]|0,0);t[f>>2]=t[t[f>>2]>>2]}s=r;return}function fV(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,l=0;n=s;s=s+32|0;f=n+16|0;u=n+12|0;a=n+8|0;o=n+4|0;c=n;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;t[c>>2]=yV(t[a>>2]|0,t[o>>2]|0)|0;if(!(t[c>>2]|0)){t[f>>2]=0;l=t[f>>2]|0;s=n;return l|0}o=KO(t[u>>2]|0,t[(t[c>>2]|0)+20>>2]|0)|0;t[(t[c>>2]|0)+24>>2]=o;o=t[c>>2]|0;if(!(t[(t[c>>2]|0)+24>>2]|0)){FV(o);t[f>>2]=0;l=t[f>>2]|0;s=n;return l|0}else{t[f>>2]=o;l=t[f>>2]|0;s=n;return l|0}return 0}function tV(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0;n=s;s=s+32|0;f=n+20|0;u=n+16|0;a=n+12|0;o=n+8|0;c=n+4|0;l=n;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;t[l>>2]=0;t[c>>2]=yV(t[a>>2]|0,t[o>>2]|0)|0;if(!(t[c>>2]|0)){t[f>>2]=0;b=t[f>>2]|0;s=n;return b|0}o=VO(t[u>>2]|0,t[(t[c>>2]|0)+20>>2]|0,t[l>>2]|0)|0;t[(t[c>>2]|0)+24>>2]=o;o=t[c>>2]|0;if(!(t[(t[c>>2]|0)+24>>2]|0)){FV(o);t[f>>2]=0;b=t[f>>2]|0;s=n;return b|0}else{t[f>>2]=o;b=t[f>>2]|0;s=n;return b|0}return 0}function uV(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0;r=s;s=s+16|0;n=r+12|0;f=r+8|0;u=r+4|0;a=r;t[f>>2]=e;t[u>>2]=i;t[a>>2]=0;do if(!((t[f>>2]|0)==0|(t[u>>2]|0)==0))if((OV(t[f>>2]|0,t[u>>2]|0)|0)<0){t[n>>2]=-1;break}else{t[n>>2]=t[a>>2];break}else t[n>>2]=-1;while(0);s=r;return t[n>>2]|0}function aV(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0;r=s;s=s+16|0;n=r+12|0;f=r+8|0;u=r+4|0;a=r;t[f>>2]=e;t[u>>2]=i;t[a>>2]=0;if((t[f>>2]|0)==0|(t[u>>2]|0)==0){t[n>>2]=-1;o=t[n>>2]|0;s=r;return o|0}else{AV(t[f>>2]|0,t[u>>2]|0);t[n>>2]=t[a>>2];o=t[n>>2]|0;s=r;return o|0}return 0}function oV(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i+4|0;n=i;t[n>>2]=e;do if(t[n>>2]|0)if(!(t[(t[n>>2]|0)+24>>2]|0)){t[r>>2]=-1;break}else{t[r>>2]=xO(t[(t[n>>2]|0)+24>>2]|0)|0;break}else t[r>>2]=-1;while(0);s=i;return t[r>>2]|0}function cV(e){e=e|0;var i=0,r=0,n=0,f=0,u=0;i=s;s=s+16|0;r=i+8|0;n=i+4|0;f=i;t[n>>2]=e;if(!(t[n>>2]|0)){t[r>>2]=-1;u=t[r>>2]|0;s=i;return u|0}else{t[f>>2]=oV(t[n>>2]|0)|0;FV(t[n>>2]|0);t[r>>2]=t[f>>2];u=t[r>>2]|0;s=i;return u|0}return 0}function lV(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0;f=s;s=s+48|0;a=f+28|0;o=f+24|0;c=f+20|0;l=f+16|0;b=f+12|0;k=f+8|0;h=f+32|0;w=f+4|0;d=f;t[a>>2]=e;t[o>>2]=i;t[c>>2]=r;t[l>>2]=n;if(!(t[l>>2]|0)){s=f;return}n=t[l>>2]|0;t[k>>2]=n;t[b>>2]=n;e:while(1){if(!(u[t[k>>2]>>0]|0))break;if((u[t[k>>2]>>0]|0|0)==10){if((t[b>>2]|0)!=(t[k>>2]|0))Ps(t[a>>2]|0,t[b>>2]|0,(t[k>>2]|0)-(t[b>>2]|0)|0)|0;Ps(t[a>>2]|0,200640,5)|0;t[k>>2]=(t[k>>2]|0)+1;t[b>>2]=t[k>>2];continue}if((u[t[k>>2]>>0]|0|0)==13){if((t[b>>2]|0)!=(t[k>>2]|0))Ps(t[a>>2]|0,t[b>>2]|0,(t[k>>2]|0)-(t[b>>2]|0)|0)|0;Ps(t[a>>2]|0,200648,5)|0;t[k>>2]=(t[k>>2]|0)+1;t[b>>2]=t[k>>2];continue}if((u[t[k>>2]>>0]|0|0)==9){if((t[b>>2]|0)!=(t[k>>2]|0))Ps(t[a>>2]|0,t[b>>2]|0,(t[k>>2]|0)-(t[b>>2]|0)|0)|0;Ps(t[a>>2]|0,200656,4)|0;t[k>>2]=(t[k>>2]|0)+1;t[b>>2]=t[k>>2];continue}if((u[t[k>>2]>>0]|0|0)==34){if((t[b>>2]|0)!=(t[k>>2]|0))Ps(t[a>>2]|0,t[b>>2]|0,(t[k>>2]|0)-(t[b>>2]|0)|0)|0;Ps(t[a>>2]|0,200664,6)|0;t[k>>2]=(t[k>>2]|0)+1;t[b>>2]=t[k>>2];continue}if((u[t[k>>2]>>0]|0|0)==60){if((t[b>>2]|0)!=(t[k>>2]|0))Ps(t[a>>2]|0,t[b>>2]|0,(t[k>>2]|0)-(t[b>>2]|0)|0)|0;Ps(t[a>>2]|0,200672,4)|0;t[k>>2]=(t[k>>2]|0)+1;t[b>>2]=t[k>>2];continue}if((u[t[k>>2]>>0]|0|0)==62){if((t[b>>2]|0)!=(t[k>>2]|0))Ps(t[a>>2]|0,t[b>>2]|0,(t[k>>2]|0)-(t[b>>2]|0)|0)|0;Ps(t[a>>2]|0,200680,4)|0;t[k>>2]=(t[k>>2]|0)+1;t[b>>2]=t[k>>2];continue}if((u[t[k>>2]>>0]|0|0)==38){if((t[b>>2]|0)!=(t[k>>2]|0))Ps(t[a>>2]|0,t[b>>2]|0,(t[k>>2]|0)-(t[b>>2]|0)|0)|0;Ps(t[a>>2]|0,200688,5)|0;t[k>>2]=(t[k>>2]|0)+1;t[b>>2]=t[k>>2];continue}do if((u[t[k>>2]>>0]|0|0)>=128){if((t[o>>2]|0)!=0?(t[(t[o>>2]|0)+60>>2]|0)!=0:0)break;t[w>>2]=0;t[d>>2]=1;if((t[b>>2]|0)!=(t[k>>2]|0))Ps(t[a>>2]|0,t[b>>2]|0,(t[k>>2]|0)-(t[b>>2]|0)|0)|0;if((u[t[k>>2]>>0]|0|0)<192){MV(1400,t[c>>2]|0,0);if(t[o>>2]|0){n=Yl(200696)|0;t[(t[o>>2]|0)+60>>2]=n}RV(h,u[t[k>>2]>>0]|0)|0;Ps(t[a>>2]|0,h,-1)|0;t[k>>2]=(t[k>>2]|0)+1;t[b>>2]=t[k>>2];continue e}n=t[k>>2]|0;do if((u[t[k>>2]>>0]|0|0)>=224){l=t[k>>2]|0;if((u[n>>0]|0|0)<240){t[w>>2]=(u[l>>0]|0)&15;t[w>>2]=t[w>>2]<<6;t[w>>2]=t[w>>2]|(u[(t[k>>2]|0)+1>>0]|0)&63;t[w>>2]=t[w>>2]<<6;t[w>>2]=t[w>>2]|(u[(t[k>>2]|0)+2>>0]|0)&63;t[d>>2]=3;break}if((u[l>>0]|0|0)<248){t[w>>2]=(u[t[k>>2]>>0]|0)&7;t[w>>2]=t[w>>2]<<6;t[w>>2]=t[w>>2]|(u[(t[k>>2]|0)+1>>0]|0)&63;t[w>>2]=t[w>>2]<<6;t[w>>2]=t[w>>2]|(u[(t[k>>2]|0)+2>>0]|0)&63;t[w>>2]=t[w>>2]<<6;t[w>>2]=t[w>>2]|(u[(t[k>>2]|0)+3>>0]|0)&63;t[d>>2]=4}}else{t[w>>2]=(u[n>>0]|0)&31;t[w>>2]=t[w>>2]<<6;t[w>>2]=t[w>>2]|(u[(t[k>>2]|0)+1>>0]|0)&63;t[d>>2]=2}while(0);i:do if((t[d>>2]|0)!=1){n=t[w>>2]|0;do if((t[w>>2]|0)<256){if(!(9<=(n|0)&(t[w>>2]|0)<=10|(t[w>>2]|0)==13|32<=(t[w>>2]|0)))break i}else{if(256<=(n|0)&(t[w>>2]|0)<=55295)break;if(57344<=(t[w>>2]|0)&(t[w>>2]|0)<=65533)break;if(!(65536<=(t[w>>2]|0)&(t[w>>2]|0)<=1114111))break i}while(0);RV(h,t[w>>2]|0)|0;Ps(t[a>>2]|0,h,-1)|0;t[k>>2]=(t[k>>2]|0)+(t[d>>2]|0);t[b>>2]=t[k>>2];continue e}while(0);MV(1401,t[c>>2]|0,0);if(t[o>>2]|0){n=Yl(200696)|0;t[(t[o>>2]|0)+60>>2]=n}RV(h,u[t[k>>2]>>0]|0)|0;Ps(t[a>>2]|0,h,-1)|0;t[k>>2]=(t[k>>2]|0)+1;t[b>>2]=t[k>>2];continue e}while(0);t[k>>2]=(t[k>>2]|0)+1}if((t[b>>2]|0)==(t[k>>2]|0)){s=f;return}Ps(t[a>>2]|0,t[b>>2]|0,(t[k>>2]|0)-(t[b>>2]|0)|0)|0;s=f;return}function sV(e,i,r,n,f,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;u=u|0;var a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0;a=s;s=s+160|0;o=a+152|0;c=a+148|0;l=a+144|0;b=a+140|0;k=a+136|0;h=a+132|0;w=a+8|0;d=a+4|0;v=a;t[o>>2]=e;t[c>>2]=i;t[l>>2]=r;t[b>>2]=n;t[k>>2]=f;t[h>>2]=u;t[v>>2]=0;rS();if((t[o>>2]|0)==0|(t[l>>2]|0)==0){s=a;return}if(!(t[h>>2]|0))t[h>>2]=200728;u=w+0|0;f=u+124|0;do{t[u>>2]=0;u=u+4|0}while((u|0)<(f|0));t[w+28>>2]=t[c>>2];t[w+24>>2]=t[o>>2];t[w+36>>2]=t[b>>2];t[w+40>>2]=(t[k>>2]|0)!=0?1:0;t[w+16>>2]=t[h>>2];TV(w);h=w+32|0;t[h>>2]=t[h>>2]|32;t[d>>2]=Qg(t[c>>2]|0)|0;if(t[d>>2]|0){c=Qj(t[(t[d>>2]|0)+56>>2]|0,t[(t[d>>2]|0)+52>>2]|0)|0;t[v>>2]=c;t[v>>2]=(t[v>>2]|0)<0?0:c}c=t[l>>2]|0;if(t[v>>2]|0){LV(w,c);s=a;return}else{AV(w,c);s=a;return}}function bV(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0;n=s;s=s+16|0;f=n+12|0;u=n+8|0;a=n+4|0;o=n;t[f>>2]=e;t[u>>2]=i;t[a>>2]=r;rS();if(!(t[a>>2]|0)){s=n;return}t[o>>2]=qO(t[f>>2]|0,0)|0;if(!(t[o>>2]|0)){s=n;return}if((t[u>>2]|0)!=0?(t[(t[u>>2]|0)+4>>2]|0)==13:0)er(t[o>>2]|0,t[u>>2]|0,t[a>>2]|0,0);else sV(t[o>>2]|0,t[u>>2]|0,t[a>>2]|0,0,1,0);HO(t[o>>2]|0)|0;s=n;return}function kV(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;var u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0;u=s;s=s+160|0;a=u+152|0;o=u+148|0;c=u+144|0;l=u+140|0;b=u+136|0;k=u+12|0;h=u+8|0;w=u+4|0;d=u;t[a>>2]=e;t[o>>2]=i;t[c>>2]=r;t[l>>2]=n;t[b>>2]=f;t[h>>2]=0;t[w>>2]=0;t[d>>2]=0;if(!(t[c>>2]|0))t[c>>2]=h;if(!(t[o>>2]|0)){t[t[c>>2]>>2]=0;s=u;return}t[t[o>>2]>>2]=0;t[t[c>>2]>>2]=0;if(!(t[a>>2]|0)){s=u;return}if(!(t[l>>2]|0))t[l>>2]=t[(t[a>>2]|0)+60>>2];if((t[l>>2]|0)!=0?(t[d>>2]=V_(t[l>>2]|0)|0,(t[d>>2]|0)==0):0){MV(1403,t[a>>2]|0,t[l>>2]|0);s=u;return}h=PO(t[d>>2]|0)|0;t[w>>2]=h;if(!h){NV(200712);s=u;return}h=k+0|0;d=h+124|0;do{t[h>>2]=0;h=h+4|0}while((h|0)<(d|0));t[k+28>>2]=t[a>>2];t[k+24>>2]=t[w>>2];t[k+36>>2]=0;t[k+40>>2]=(t[b>>2]|0)!=0?1:0;t[k+16>>2]=t[l>>2];TV(k);l=k+32|0;t[l>>2]=t[l>>2]|32;OV(k,t[a>>2]|0)|0;xO(t[w>>2]|0)|0;a=t[w>>2]|0;if(t[(t[w>>2]|0)+20>>2]|0){k=Ts(t[a+20>>2]|0)|0;t[t[c>>2]>>2]=k;k=Os(t[(t[w>>2]|0)+20>>2]|0)|0;l=ql(k,t[t[c>>2]>>2]|0)|0;t[t[o>>2]>>2]=l}else{l=Ts(t[a+16>>2]|0)|0;t[t[c>>2]>>2]=l;l=Os(t[(t[w>>2]|0)+16>>2]|0)|0;a=ql(l,t[t[c>>2]>>2]|0)|0;t[t[o>>2]>>2]=a}HO(t[w>>2]|0)|0;if(t[t[o>>2]>>2]|0){s=u;return}if((t[t[c>>2]>>2]|0)<=0){s=u;return}t[t[c>>2]>>2]=0;NV(200736);s=u;return}function hV(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0;n=s;s=s+16|0;f=n+8|0;u=n+4|0;a=n;t[f>>2]=e;t[u>>2]=i;t[a>>2]=r;kV(t[f>>2]|0,t[u>>2]|0,t[a>>2]|0,0,0);s=n;return}function wV(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,u=0,a=0,o=0,c=0;f=s;s=s+16|0;u=f+12|0;a=f+8|0;o=f+4|0;c=f;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;t[c>>2]=n;kV(t[u>>2]|0,t[a>>2]|0,t[o>>2]|0,0,t[c>>2]|0);s=f;return}function dV(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,u=0,a=0,o=0,c=0;f=s;s=s+16|0;u=f+12|0;a=f+8|0;o=f+4|0;c=f;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;t[c>>2]=n;kV(t[u>>2]|0,t[a>>2]|0,t[o>>2]|0,t[c>>2]|0,0);s=f;return}function vV(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0;n=s;s=s+160|0;f=n+152|0;u=n+148|0;a=n+144|0;o=n+140|0;c=n+16|0;l=n+12|0;b=n+8|0;k=n+4|0;h=n;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;t[k>>2]=0;if(!(t[a>>2]|0)){t[f>>2]=-1;w=t[f>>2]|0;s=n;return w|0}t[b>>2]=t[(t[a>>2]|0)+60>>2];if((t[b>>2]|0)!=0?(t[k>>2]=V_(t[b>>2]|0)|0,(t[k>>2]|0)==0):0){pAi[t[135736>>2]&511](t[(t[a>>2]|0)+60>>2]|0);t[(t[a>>2]|0)+60>>2]=0;t[b>>2]=0}t[l>>2]=qO(t[u>>2]|0,t[k>>2]|0)|0;if(!(t[l>>2]|0)){t[f>>2]=-1;w=t[f>>2]|0;s=n;return w|0}else{k=c+0|0;u=k+124|0;do{t[k>>2]=0;k=k+4|0}while((k|0)<(u|0));t[c+28>>2]=t[a>>2];t[c+24>>2]=t[l>>2];t[c+36>>2]=0;t[c+40>>2]=(t[o>>2]|0)!=0?1:0;t[c+16>>2]=t[b>>2];TV(c);b=c+32|0;t[b>>2]=t[b>>2]|32;OV(c,t[a>>2]|0)|0;t[h>>2]=HO(t[l>>2]|0)|0;t[f>>2]=t[h>>2];w=t[f>>2]|0;s=n;return w|0}return 0}function mV(e,i){e=e|0;i=i|0;var r=0,n=0,f=0;r=s;s=s+16|0;n=r+4|0;f=r;t[n>>2]=e;t[f>>2]=i;i=vV(t[n>>2]|0,t[f>>2]|0,0)|0;s=r;return i|0}function _V(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0;f=s;s=s+160|0;u=f+152|0;a=f+148|0;o=f+144|0;c=f+140|0;l=f+136|0;b=f+12|0;k=f+8|0;h=f+4|0;w=f;t[a>>2]=e;t[o>>2]=i;t[c>>2]=r;t[l>>2]=n;t[h>>2]=0;if(!(t[o>>2]|0)){t[u>>2]=-1;d=t[u>>2]|0;s=f;return d|0}if(!(t[c>>2]|0))t[c>>2]=t[(t[o>>2]|0)+60>>2];if((t[c>>2]|0)!=0?(t[h>>2]=V_(t[c>>2]|0)|0,(t[h>>2]|0)==0):0){t[u>>2]=-1;d=t[u>>2]|0;s=f;return d|0}t[k>>2]=VO(t[a>>2]|0,t[h>>2]|0,t[(t[o>>2]|0)+36>>2]|0)|0;if(!(t[k>>2]|0)){t[u>>2]=-1;d=t[u>>2]|0;s=f;return d|0}else{h=b+0|0;a=h+124|0;do{t[h>>2]=0;h=h+4|0}while((h|0)<(a|0));t[b+28>>2]=t[o>>2];t[b+24>>2]=t[k>>2];t[b+36>>2]=0;t[b+40>>2]=(t[l>>2]|0)!=0?1:0;t[b+16>>2]=t[c>>2];TV(b);c=b+32|0;t[c>>2]=t[c>>2]|32;OV(b,t[o>>2]|0)|0;t[w>>2]=HO(t[k>>2]|0)|0;t[u>>2]=t[w>>2];d=t[u>>2]|0;s=f;return d|0}return 0}function pV(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0;n=s;s=s+16|0;f=n+8|0;u=n+4|0;a=n;t[f>>2]=e;t[u>>2]=i;t[a>>2]=r;r=_V(t[f>>2]|0,t[u>>2]|0,t[a>>2]|0,0)|0;s=n;return r|0}function EV(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0;n=s;s=s+16|0;f=n+8|0;u=n+4|0;a=n;t[f>>2]=e;t[u>>2]=i;t[a>>2]=r;r=_V(t[f>>2]|0,t[u>>2]|0,0,t[a>>2]|0)|0;s=n;return r|0}function SV(e,i){e=e|0;i=i|0;var r=0,n=0,f=0;r=s;s=s+16|0;n=r+4|0;f=r;t[n>>2]=e;t[f>>2]=i;i=_V(t[n>>2]|0,t[f>>2]|0,0,0)|0;s=r;return i|0}function gV(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0;n=s;s=s+16|0;f=n+8|0;u=n+4|0;a=n;t[f>>2]=e;t[u>>2]=i;t[a>>2]=r;if((t[u>>2]|0)==0|(t[f>>2]|0)==0){s=n;return}if((t[(t[u>>2]|0)+4>>2]|0)!=18){s=n;return}if(!(t[(t[u>>2]|0)+8>>2]|0)){s=n;return}if(Xl(t[(t[u>>2]|0)+12>>2]|0,201224)|0){s=n;return}if((t[a>>2]|0)!=0?(t[(t[a>>2]|0)+40>>2]|0)==2:0)DV(t[a>>2]|0,2);else $O(t[f>>2]|0,1,200760)|0;a=t[f>>2]|0;if(t[(t[u>>2]|0)+12>>2]|0){$O(a,6,201752)|0;iA(t[f>>2]|0,t[(t[u>>2]|0)+12>>2]|0)|0}else $O(a,5,201760)|0;$O(t[f>>2]|0,1,201768)|0;xs(t[(t[f>>2]|0)+16>>2]|0,t[(t[u>>2]|0)+8>>2]|0)|0;s=n;return}function yV(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0;r=s;s=s+16|0;n=r+12|0;f=r+8|0;u=r+4|0;a=r;t[f>>2]=e;t[u>>2]=i;t[a>>2]=gAi[t[135744>>2]&511](124)|0;if(!(t[a>>2]|0)){NV(201728);t[n>>2]=0;o=t[n>>2]|0;s=r;return o|0}i=(t[a>>2]|0)+0|0;e=i+124|0;do{t[i>>2]=0;i=i+4|0}while((i|0)<(e|0));do if(t[f>>2]|0){i=V_(t[f>>2]|0)|0;t[(t[a>>2]|0)+20>>2]=i;i=t[f>>2]|0;if(t[(t[a>>2]|0)+20>>2]|0){e=Yl(i)|0;t[(t[a>>2]|0)+16>>2]=e;t[(t[a>>2]|0)+116>>2]=0;break}MV(1403,0,i);FV(t[a>>2]|0);t[n>>2]=0;o=t[n>>2]|0;s=r;return o|0}while(0);TV(t[a>>2]|0);if((t[(t[a>>2]|0)+32>>2]&4|0)!=0?(t[u>>2]&4|0)==0:0)t[u>>2]=t[u>>2]|4;t[(t[a>>2]|0)+32>>2]=t[u>>2];if(!(t[u>>2]&1)){if(t[u>>2]&128)t[(t[a>>2]|0)+40>>2]=2}else t[(t[a>>2]|0)+40>>2]=1;t[n>>2]=t[a>>2];o=t[n>>2]|0;s=r;return o|0}function FV(e){e=e|0;var i=0,r=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if(!(t[r>>2]|0)){s=i;return}if(t[(t[r>>2]|0)+16>>2]|0)pAi[t[135736>>2]&511](t[(t[r>>2]|0)+16>>2]|0);if(t[(t[r>>2]|0)+24>>2]|0)HO(t[(t[r>>2]|0)+24>>2]|0)|0;pAi[t[135736>>2]&511](t[r>>2]|0);s=i;return}function OV(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0;r=s;s=s+64|0;n=r+52|0;f=r+48|0;u=r+44|0;a=r+40|0;o=r+36|0;c=r+32|0;l=r+28|0;b=r+24|0;k=r+20|0;h=r+16|0;w=r+12|0;d=r+8|0;v=r+4|0;m=r;t[f>>2]=e;t[u>>2]=i;t[o>>2]=0;t[c>>2]=t[(t[u>>2]|0)+60>>2];t[l>>2]=t[(t[f>>2]|0)+16>>2];t[b>>2]=t[(t[f>>2]|0)+16>>2];t[k>>2]=t[(t[f>>2]|0)+116>>2];t[h>>2]=t[(t[f>>2]|0)+120>>2];t[w>>2]=t[(t[f>>2]|0)+24>>2];t[v>>2]=0;rS();if((t[(t[u>>2]|0)+4>>2]|0)!=13?(t[(t[u>>2]|0)+4>>2]|0)!=9:0){t[n>>2]=-1;_=t[n>>2]|0;s=r;return _|0}do if(!(t[(t[f>>2]|0)+16>>2]|0)){i=t[u>>2]|0;if(t[(t[u>>2]|0)+60>>2]|0){t[b>>2]=t[i+60>>2];break}if((t[i+76>>2]|0)!=1)t[b>>2]=I_(t[(t[u>>2]|0)+76>>2]|0)|0}else t[(t[u>>2]|0)+60>>2]=t[(t[f>>2]|0)+16>>2];while(0);if(!(((t[(t[u>>2]|0)+4>>2]|0)==13?(t[(t[f>>2]|0)+32>>2]&32|0)==0:0)?(t[(t[f>>2]|0)+32>>2]&16|0)==0:0))p=13;if((p|0)==13?(t[(t[f>>2]|0)+32>>2]&64|0)==0:0){if(!(((t[(t[u>>2]|0)+4>>2]|0)!=9?(t[(t[f>>2]|0)+32>>2]&32|0)==0:0)?(t[(t[f>>2]|0)+32>>2]&16|0)==0:0))p=34;e:do if((p|0)==34){t[d>>2]=B_(t[b>>2]|0)|0;if((((t[b>>2]|0)!=0&(t[l>>2]|0)==0?(t[(t[w>>2]|0)+12>>2]|0)==0:0)?(t[(t[w>>2]|0)+20>>2]|0)==0:0)?(t[(t[f>>2]|0)+32>>2]&2|0)==0:0){do if((t[d>>2]|0)!=1&(t[d>>2]|0)!=0&(t[d>>2]|0)!=22){if((CV(t[f>>2]|0,t[b>>2]|0)|0)>=0){t[v>>2]=1;break}t[(t[u>>2]|0)+60>>2]=t[c>>2];t[n>>2]=-1;_=t[n>>2]|0;s=r;return _|0}while(0);if((t[(t[f>>2]|0)+116>>2]|0)==389)t[(t[f>>2]|0)+116>>2]=0;if((t[(t[f>>2]|0)+120>>2]|0)==389)t[(t[f>>2]|0)+120>>2]=0}if(!(t[(t[f>>2]|0)+32>>2]&2)){$O(t[w>>2]|0,14,201632)|0;i=t[w>>2]|0;if(t[(t[u>>2]|0)+56>>2]|0)xs(t[i+16>>2]|0,t[(t[u>>2]|0)+56>>2]|0)|0;else $O(i,5,201648)|0;if(t[b>>2]|0){$O(t[w>>2]|0,10,201656)|0;xs(t[(t[w>>2]|0)+16>>2]|0,t[b>>2]|0)|0}i=t[(t[u>>2]|0)+40>>2]|0;if((i|0)==1)$O(t[w>>2]|0,17,201696)|0;else if(!i)$O(t[w>>2]|0,16,201672)|0;$O(t[w>>2]|0,3,201720)|0}if(t[(t[f>>2]|0)+32>>2]&16)t[o>>2]=1;if((t[(t[f>>2]|0)+32>>2]&8|0)==0?(t[a>>2]=Qg(t[u>>2]|0)|0,(t[a>>2]|0)!=0):0){i=Qj(t[(t[a>>2]|0)+56>>2]|0,t[(t[a>>2]|0)+52>>2]|0)|0;t[o>>2]=i;t[o>>2]=(t[o>>2]|0)<0?0:i}if(t[(t[u>>2]|0)+12>>2]|0){t[m>>2]=t[(t[u>>2]|0)+12>>2];while(1){if(!(t[m>>2]|0))break e;t[(t[f>>2]|0)+36>>2]=0;i=t[f>>2]|0;e=t[m>>2]|0;if(t[o>>2]|0)LV(i,e);else AV(i,e);$O(t[w>>2]|0,1,200976)|0;t[m>>2]=t[(t[m>>2]|0)+24>>2]}}}while(0);if((t[v>>2]|0)!=0&(t[l>>2]|0)==0){BV(t[f>>2]|0)|0;t[(t[f>>2]|0)+116>>2]=t[k>>2];t[(t[f>>2]|0)+120>>2]=t[h>>2]}t[(t[u>>2]|0)+60>>2]=t[c>>2];t[n>>2]=0;_=t[n>>2]|0;s=r;return _|0}if(t[b>>2]|0)Wi(t[u>>2]|0,t[b>>2]|0)|0;if(!(t[b>>2]|0))t[b>>2]=Gi(t[u>>2]|0)|0;if(!(t[b>>2]|0))t[b>>2]=201592;if((((t[b>>2]|0)!=0&(t[l>>2]|0)==0?(t[(t[w>>2]|0)+12>>2]|0)==0:0)?(t[(t[w>>2]|0)+20>>2]|0)==0:0)?(CV(t[f>>2]|0,t[b>>2]|0)|0)<0:0){t[(t[u>>2]|0)+60>>2]=t[c>>2];t[n>>2]=-1;_=t[n>>2]|0;s=r;return _|0}l=t[w>>2]|0;w=t[u>>2]|0;h=t[b>>2]|0;if(t[(t[f>>2]|0)+32>>2]&1)Qi(l,w,h,1);else Qi(l,w,h,0);if(t[(t[f>>2]|0)+16>>2]|0)t[(t[u>>2]|0)+60>>2]=t[c>>2];t[n>>2]=0;_=t[n>>2]|0;s=r;return _|0}function AV(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0;r=s;s=s+32|0;n=r+24|0;f=r+20|0;a=r+16|0;o=r+12|0;c=r+8|0;l=r+4|0;b=r;t[n>>2]=e;t[f>>2]=i;if(!(t[f>>2]|0)){s=r;return}t[b>>2]=t[(t[n>>2]|0)+24>>2];if((t[(t[f>>2]|0)+4>>2]|0)==19){s=r;return}if((t[(t[f>>2]|0)+4>>2]|0)==20){s=r;return}if((t[(t[f>>2]|0)+4>>2]|0)!=9?(t[(t[f>>2]|0)+4>>2]|0)!=13:0){if(t[(t[n>>2]|0)+32>>2]&16){LV(t[n>>2]|0,t[f>>2]|0);s=r;return}if(!((((t[(t[f>>2]|0)+4>>2]|0)!=18?(t[(t[f>>2]|0)+32>>2]|0)!=0:0)?(t[(t[(t[f>>2]|0)+32>>2]|0)+4>>2]|0)==13:0)?(t[(t[n>>2]|0)+32>>2]&32|0)==0:0))k=13;if((k|0)==13?(t[(t[n>>2]|0)+32>>2]&64|0)==0:0){if((t[(t[f>>2]|0)+4>>2]|0)==14){HV(t[n>>2]|0,t[f>>2]|0);s=r;return}if((t[(t[f>>2]|0)+4>>2]|0)==11){xV(t[n>>2]|0,t[(t[f>>2]|0)+12>>2]|0);s=r;return}if((t[(t[f>>2]|0)+4>>2]|0)==15){
	eV(t[(t[b>>2]|0)+16>>2]|0,t[f>>2]|0);s=r;return}if((t[(t[f>>2]|0)+4>>2]|0)==16){iV(t[(t[b>>2]|0)+16>>2]|0,t[f>>2]|0);s=r;return}if((t[(t[f>>2]|0)+4>>2]|0)==17){rV(t[(t[b>>2]|0)+16>>2]|0,t[f>>2]|0);s=r;return}i=t[f>>2]|0;if((t[(t[f>>2]|0)+4>>2]|0)==3){if(!(t[i+40>>2]|0)){s=r;return}e=t[b>>2]|0;h=t[(t[f>>2]|0)+40>>2]|0;if((t[(t[f>>2]|0)+8>>2]|0)!=75112){eA(e,h,t[(t[n>>2]|0)+116>>2]|0)|0;s=r;return}else{iA(e,h)|0;s=r;return}}h=t[f>>2]|0;if((t[i+4>>2]|0)==7){i=(t[h+40>>2]|0)!=0;$O(t[b>>2]|0,2,200752)|0;iA(t[b>>2]|0,t[(t[f>>2]|0)+8>>2]|0)|0;if(!i){if((t[(t[n>>2]|0)+40>>2]|0)==2)DV(t[n>>2]|0,0);$O(t[b>>2]|0,2,200768)|0;s=r;return}if(t[(t[f>>2]|0)+40>>2]|0){if((t[(t[n>>2]|0)+40>>2]|0)==2)DV(t[n>>2]|0,0);else $O(t[b>>2]|0,1,200760)|0;iA(t[b>>2]|0,t[(t[f>>2]|0)+40>>2]|0)|0}$O(t[b>>2]|0,2,200768)|0;s=r;return}i=t[f>>2]|0;if((t[h+4>>2]|0)==8){if(!(t[i+40>>2]|0)){s=r;return}$O(t[b>>2]|0,4,200776)|0;iA(t[b>>2]|0,t[(t[f>>2]|0)+40>>2]|0)|0;$O(t[b>>2]|0,3,200784)|0;s=r;return}if((t[i+4>>2]|0)==5){$O(t[b>>2]|0,1,200792)|0;iA(t[b>>2]|0,t[(t[f>>2]|0)+8>>2]|0)|0;$O(t[b>>2]|0,1,200800)|0;s=r;return}i=t[f>>2]|0;if((t[(t[f>>2]|0)+4>>2]|0)==4){do if(t[i+40>>2]|0){if(!(u[t[(t[f>>2]|0)+40>>2]>>0]|0))break;h=t[(t[f>>2]|0)+40>>2]|0;t[l>>2]=h;t[c>>2]=h;while(1){if(!(u[t[l>>2]>>0]|0))break;do if((u[t[l>>2]>>0]|0|0)==93){if((u[(t[l>>2]|0)+1>>0]|0|0)!=93)break;if((u[(t[l>>2]|0)+2>>0]|0|0)!=62)break;t[l>>2]=(t[l>>2]|0)+2;$O(t[b>>2]|0,9,200824)|0;$O(t[b>>2]|0,(t[l>>2]|0)-(t[c>>2]|0)|0,t[c>>2]|0)|0;$O(t[b>>2]|0,3,200840)|0;t[c>>2]=t[l>>2]}while(0);t[l>>2]=(t[l>>2]|0)+1}if((t[c>>2]|0)==(t[l>>2]|0)){s=r;return}$O(t[b>>2]|0,9,200824)|0;iA(t[b>>2]|0,t[c>>2]|0)|0;$O(t[b>>2]|0,3,200840)|0;s=r;return}while(0);$O(t[b>>2]|0,12,200808)|0;s=r;return}if((t[i+4>>2]|0)==2){UV(t[n>>2]|0,t[f>>2]|0);s=r;return}i=t[n>>2]|0;if((t[(t[f>>2]|0)+4>>2]|0)==18){zV(i,t[f>>2]|0);s=r;return}t[a>>2]=t[i+40>>2];e:do if((t[a>>2]|0)==1){t[o>>2]=t[(t[f>>2]|0)+12>>2];while(1){if(!(t[o>>2]|0))break e;if((t[(t[o>>2]|0)+4>>2]|0)==3)break;if((t[(t[o>>2]|0)+4>>2]|0)==4)break;if((t[(t[o>>2]|0)+4>>2]|0)==5)break;t[o>>2]=t[(t[o>>2]|0)+24>>2]}t[(t[n>>2]|0)+40>>2]=0}while(0);$O(t[b>>2]|0,1,200848)|0;do if(t[(t[f>>2]|0)+36>>2]|0){if(!(t[(t[(t[f>>2]|0)+36>>2]|0)+12>>2]|0))break;iA(t[b>>2]|0,t[(t[(t[f>>2]|0)+36>>2]|0)+12>>2]|0)|0;$O(t[b>>2]|0,1,200856)|0}while(0);iA(t[b>>2]|0,t[(t[f>>2]|0)+8>>2]|0)|0;if(t[(t[f>>2]|0)+48>>2]|0)jV(t[n>>2]|0,t[(t[f>>2]|0)+48>>2]|0);if(t[(t[f>>2]|0)+44>>2]|0)VV(t[n>>2]|0,t[(t[f>>2]|0)+44>>2]|0);if(!((t[(t[f>>2]|0)+4>>2]|0)!=1?(t[(t[f>>2]|0)+40>>2]|0)!=0:0))k=80;do if((k|0)==80){if(t[(t[f>>2]|0)+12>>2]|0)break;if(t[(t[n>>2]|0)+32>>2]&4)break;if((t[(t[n>>2]|0)+40>>2]|0)==2)DV(t[n>>2]|0,0);$O(t[b>>2]|0,2,201584)|0;t[(t[n>>2]|0)+40>>2]=t[a>>2];s=r;return}while(0);if((t[(t[n>>2]|0)+40>>2]|0)==2)DV(t[n>>2]|0,1);$O(t[b>>2]|0,1,200968)|0;do if((t[(t[f>>2]|0)+4>>2]|0)!=1){if(!(t[(t[f>>2]|0)+40>>2]|0))break;eA(t[b>>2]|0,t[(t[f>>2]|0)+40>>2]|0,t[(t[n>>2]|0)+116>>2]|0)|0}while(0);do if(t[(t[f>>2]|0)+12>>2]|0){if((t[(t[n>>2]|0)+40>>2]|0)==1)$O(t[b>>2]|0,1,200976)|0;if((t[(t[n>>2]|0)+36>>2]|0)>=0){k=(t[n>>2]|0)+36|0;t[k>>2]=(t[k>>2]|0)+1}xV(t[n>>2]|0,t[(t[f>>2]|0)+12>>2]|0);if((t[(t[n>>2]|0)+36>>2]|0)>0){k=(t[n>>2]|0)+36|0;t[k>>2]=(t[k>>2]|0)+-1}if(!(t[33984]|0))break;if((t[(t[n>>2]|0)+40>>2]|0)!=1)break;k=t[n>>2]|0;if((t[(t[n>>2]|0)+36>>2]|0)>(t[(t[n>>2]|0)+108>>2]|0))w=t[k+108>>2]|0;else w=t[k+36>>2]|0;k=te(t[(t[n>>2]|0)+112>>2]|0,w)|0;$O(t[b>>2]|0,k,(t[n>>2]|0)+44|0)|0}while(0);$O(t[b>>2]|0,2,201056)|0;do if(t[(t[f>>2]|0)+36>>2]|0){if(!(t[(t[(t[f>>2]|0)+36>>2]|0)+12>>2]|0))break;iA(t[b>>2]|0,t[(t[(t[f>>2]|0)+36>>2]|0)+12>>2]|0)|0;$O(t[b>>2]|0,1,200856)|0}while(0);iA(t[b>>2]|0,t[(t[f>>2]|0)+8>>2]|0)|0;if((t[(t[n>>2]|0)+40>>2]|0)==2)DV(t[n>>2]|0,0);$O(t[b>>2]|0,1,200968)|0;t[(t[n>>2]|0)+40>>2]=t[a>>2];s=r;return}IV(t[n>>2]|0,t[f>>2]|0)|0;s=r;return}OV(t[n>>2]|0,t[f>>2]|0)|0;s=r;return}function MV(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0;n=s;s=s+16|0;f=n+12|0;u=n+8|0;a=n+4|0;o=n;t[f>>2]=e;t[u>>2]=i;t[a>>2]=r;t[o>>2]=0;r=t[f>>2]|0;if((r|0)==1400)t[o>>2]=201440;else if((r|0)==1403)t[o>>2]=201496;else if((r|0)==1401)t[o>>2]=201464;else if((r|0)==1402)t[o>>2]=201520;else t[o>>2]=201552;dp(7,t[f>>2]|0,t[u>>2]|0,t[o>>2]|0,t[a>>2]|0);s=n;return}function RV(e,i){e=e|0;i=i|0;var r=0,f=0,u=0,a=0;r=s;s=s+16|0;f=r+8|0;u=r+4|0;a=r;t[f>>2]=e;t[u>>2]=i;i=t[f>>2]|0;t[f>>2]=i+1;n[i>>0]=38;i=t[f>>2]|0;t[f>>2]=i+1;n[i>>0]=35;i=t[f>>2]|0;t[f>>2]=i+1;n[i>>0]=120;do if((t[u>>2]|0)>=16){if((t[u>>2]|0)<256){t[a>>2]=(t[f>>2]|0)+1;break}if((t[u>>2]|0)<4096){t[a>>2]=(t[f>>2]|0)+2;break}if((t[u>>2]|0)<65536){t[a>>2]=(t[f>>2]|0)+3;break}i=t[f>>2]|0;if((t[u>>2]|0)<1048576){t[a>>2]=i+4;break}else{t[a>>2]=i+5;break}}else t[a>>2]=t[f>>2];while(0);t[f>>2]=(t[a>>2]|0)+1;while(1){if((t[u>>2]|0)<=0)break;do switch(t[u>>2]&15|0){case 14:{i=t[a>>2]|0;t[a>>2]=i+-1;n[i>>0]=69;break}case 10:{i=t[a>>2]|0;t[a>>2]=i+-1;n[i>>0]=65;break}case 2:{i=t[a>>2]|0;t[a>>2]=i+-1;n[i>>0]=50;break}case 7:{i=t[a>>2]|0;t[a>>2]=i+-1;n[i>>0]=55;break}case 9:{i=t[a>>2]|0;t[a>>2]=i+-1;n[i>>0]=57;break}case 5:{i=t[a>>2]|0;t[a>>2]=i+-1;n[i>>0]=53;break}case 12:{i=t[a>>2]|0;t[a>>2]=i+-1;n[i>>0]=67;break}case 0:{i=t[a>>2]|0;t[a>>2]=i+-1;n[i>>0]=48;break}case 3:{i=t[a>>2]|0;t[a>>2]=i+-1;n[i>>0]=51;break}case 11:{i=t[a>>2]|0;t[a>>2]=i+-1;n[i>>0]=66;break}case 15:{i=t[a>>2]|0;t[a>>2]=i+-1;n[i>>0]=70;break}case 13:{i=t[a>>2]|0;t[a>>2]=i+-1;n[i>>0]=68;break}case 6:{i=t[a>>2]|0;t[a>>2]=i+-1;n[i>>0]=54;break}case 8:{i=t[a>>2]|0;t[a>>2]=i+-1;n[i>>0]=56;break}case 4:{i=t[a>>2]|0;t[a>>2]=i+-1;n[i>>0]=52;break}case 1:{i=t[a>>2]|0;t[a>>2]=i+-1;n[i>>0]=49;break}default:{i=t[a>>2]|0;t[a>>2]=i+-1;n[i>>0]=48}}while(0);t[u>>2]=t[u>>2]>>4}u=t[f>>2]|0;t[f>>2]=u+1;n[u>>0]=59;n[t[f>>2]>>0]=0;s=r;return t[f>>2]|0}function NV(e){e=e|0;var i=0,r=0;i=s;s=s+16|0;r=i;t[r>>2]=e;dp(7,2,0,0,t[r>>2]|0);s=i;return}function TV(e){e=e|0;var i=0,r=0,f=0,u=0,a=0;i=s;s=s+16|0;r=i+8|0;f=i+4|0;u=i;t[r>>2]=e;if(!(t[r>>2]|0)){s=i;return}if((t[(t[r>>2]|0)+16>>2]|0)==0?(t[(t[r>>2]|0)+116>>2]|0)==0:0)t[(t[r>>2]|0)+116>>2]=389;t[u>>2]=rs(t[33988]|0)|0;if((t[33988]|0)==0|(t[u>>2]|0)==0){e=(t[r>>2]|0)+44|0;a=e+61|0;do{n[e>>0]=0;e=e+1|0}while((e|0)<(a|0))}else{t[(t[r>>2]|0)+112>>2]=t[u>>2];t[(t[r>>2]|0)+108>>2]=60/(t[(t[r>>2]|0)+112>>2]|0)|0;t[f>>2]=0;while(1){if((t[f>>2]|0)>=(t[(t[r>>2]|0)+108>>2]|0))break;u=te(t[f>>2]|0,t[(t[r>>2]|0)+112>>2]|0)|0;YY((t[r>>2]|0)+44+u|0,t[33988]|0,t[(t[r>>2]|0)+112>>2]|0)|0;t[f>>2]=(t[f>>2]|0)+1}f=te(t[(t[r>>2]|0)+108>>2]|0,t[(t[r>>2]|0)+112>>2]|0)|0;n[(t[r>>2]|0)+44+f>>0]=0}if(!(t[33990]|0)){s=i;return}f=(t[r>>2]|0)+32|0;t[f>>2]=t[f>>2]|4;s=i;return}function LV(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0;r=s;s=s+48|0;n=r+36|0;f=r+32|0;a=r+28|0;o=r+24|0;c=r+20|0;l=r+16|0;b=r+12|0;k=r+8|0;h=r+4|0;w=r;t[n>>2]=e;t[f>>2]=i;t[o>>2]=0;if(!(t[f>>2]|0)){s=r;return}if((t[(t[f>>2]|0)+4>>2]|0)!=9?(t[(t[f>>2]|0)+4>>2]|0)!=13:0){if((t[(t[f>>2]|0)+4>>2]|0)==19){s=r;return}if((t[(t[f>>2]|0)+4>>2]|0)==20){s=r;return}if((t[(t[f>>2]|0)+4>>2]|0)==18){zV(t[n>>2]|0,t[f>>2]|0);s=r;return}if((t[(t[f>>2]|0)+4>>2]|0)==14){HV(t[n>>2]|0,t[f>>2]|0);s=r;return}i=t[n>>2]|0;if((t[(t[f>>2]|0)+4>>2]|0)==11){qV(i,t[(t[f>>2]|0)+12>>2]|0);s=r;return}t[k>>2]=t[i+24>>2];if((t[(t[f>>2]|0)+4>>2]|0)==15){eV(t[(t[k>>2]|0)+16>>2]|0,t[f>>2]|0);s=r;return}if((t[(t[f>>2]|0)+4>>2]|0)==16){iV(t[(t[k>>2]|0)+16>>2]|0,t[f>>2]|0);s=r;return}if((t[(t[f>>2]|0)+4>>2]|0)==17){rV(t[(t[k>>2]|0)+16>>2]|0,t[f>>2]|0);s=r;return}i=t[f>>2]|0;if((t[(t[f>>2]|0)+4>>2]|0)==3){if(!(t[i+40>>2]|0)){s=r;return}if((t[(t[f>>2]|0)+8>>2]|0)!=75104?(t[(t[f>>2]|0)+8>>2]|0)==75112:0){iA(t[k>>2]|0,t[(t[f>>2]|0)+40>>2]|0)|0;s=r;return}eA(t[k>>2]|0,t[(t[f>>2]|0)+40>>2]|0,t[(t[n>>2]|0)+116>>2]|0)|0;s=r;return}e=t[f>>2]|0;if((t[i+4>>2]|0)==7){i=(t[e+40>>2]|0)!=0;$O(t[k>>2]|0,2,200752)|0;iA(t[k>>2]|0,t[(t[f>>2]|0)+8>>2]|0)|0;if(!i){$O(t[k>>2]|0,2,200768)|0;s=r;return}if(t[(t[f>>2]|0)+40>>2]|0){$O(t[k>>2]|0,1,200760)|0;iA(t[k>>2]|0,t[(t[f>>2]|0)+40>>2]|0)|0}$O(t[k>>2]|0,2,200768)|0;s=r;return}i=t[f>>2]|0;if((t[e+4>>2]|0)==8){if(!(t[i+40>>2]|0)){s=r;return}$O(t[k>>2]|0,4,200776)|0;iA(t[k>>2]|0,t[(t[f>>2]|0)+40>>2]|0)|0;$O(t[k>>2]|0,3,200784)|0;s=r;return}if((t[i+4>>2]|0)==5){$O(t[k>>2]|0,1,200792)|0;iA(t[k>>2]|0,t[(t[f>>2]|0)+8>>2]|0)|0;$O(t[k>>2]|0,1,200800)|0;s=r;return}i=t[f>>2]|0;if((t[(t[f>>2]|0)+4>>2]|0)==4){do if(t[i+40>>2]|0){if(!(u[t[(t[f>>2]|0)+40>>2]>>0]|0))break;e=t[(t[f>>2]|0)+40>>2]|0;t[b>>2]=e;t[l>>2]=e;while(1){if(!(u[t[b>>2]>>0]|0))break;do if((u[t[b>>2]>>0]|0|0)==93){if((u[(t[b>>2]|0)+1>>0]|0|0)!=93)break;if((u[(t[b>>2]|0)+2>>0]|0|0)!=62)break;t[b>>2]=(t[b>>2]|0)+2;$O(t[k>>2]|0,9,200824)|0;$O(t[k>>2]|0,(t[b>>2]|0)-(t[l>>2]|0)|0,t[l>>2]|0)|0;$O(t[k>>2]|0,3,200840)|0;t[l>>2]=t[b>>2]}while(0);t[b>>2]=(t[b>>2]|0)+1}if((t[l>>2]|0)==(t[b>>2]|0)){s=r;return}$O(t[k>>2]|0,9,200824)|0;iA(t[k>>2]|0,t[l>>2]|0)|0;$O(t[k>>2]|0,3,200840)|0;s=r;return}while(0);$O(t[k>>2]|0,12,200808)|0;s=r;return}l=t[n>>2]|0;if((t[i+4>>2]|0)==2){UV(l,t[f>>2]|0);s=r;return}t[a>>2]=t[l+40>>2];e:do if((t[a>>2]|0)==1){t[c>>2]=t[(t[f>>2]|0)+12>>2];while(1){if(!(t[c>>2]|0))break e;if((t[(t[c>>2]|0)+4>>2]|0)==3)break;if((t[(t[c>>2]|0)+4>>2]|0)==5)break;t[c>>2]=t[(t[c>>2]|0)+24>>2]}t[a>>2]=0}while(0);$O(t[k>>2]|0,1,200848)|0;do if(t[(t[f>>2]|0)+36>>2]|0){if(!(t[(t[(t[f>>2]|0)+36>>2]|0)+12>>2]|0))break;iA(t[k>>2]|0,t[(t[(t[f>>2]|0)+36>>2]|0)+12>>2]|0)|0;$O(t[k>>2]|0,1,200856)|0}while(0);iA(t[k>>2]|0,t[(t[f>>2]|0)+8>>2]|0)|0;if(t[(t[f>>2]|0)+48>>2]|0)jV(t[n>>2]|0,t[(t[f>>2]|0)+48>>2]|0);do if(Xl(t[(t[f>>2]|0)+8>>2]|0,200864)|0){if(t[(t[f>>2]|0)+36>>2]|0)break;if(t[(t[f>>2]|0)+48>>2]|0)break;iA(t[k>>2]|0,200872)|0}while(0);if(t[(t[f>>2]|0)+44>>2]|0)YV(t[n>>2]|0,t[(t[f>>2]|0)+44>>2]|0);do if((t[(t[f>>2]|0)+4>>2]|0)==1){if(!(t[(t[f>>2]|0)+20>>2]|0))break;if((t[(t[(t[f>>2]|0)+20>>2]|0)+20>>2]|0)!=(t[(t[f>>2]|0)+32>>2]|0))break;if(!(Xl(t[(t[f>>2]|0)+8>>2]|0,200912)|0))break;if(!(Xl(t[(t[(t[f>>2]|0)+20>>2]|0)+8>>2]|0,200864)|0))break;t[c>>2]=t[(t[f>>2]|0)+12>>2];e:while(1){if(!(t[c>>2]|0))break;do if(Xl(t[(t[c>>2]|0)+8>>2]|0,200920)|0){t[h>>2]=cF(t[c>>2]|0,200928)|0;if(!(t[h>>2]|0))break;l=(Ql(t[h>>2]|0,200944)|0)==0;pAi[t[135736>>2]&511](t[h>>2]|0);if(l)break e}while(0);t[c>>2]=t[(t[c>>2]|0)+24>>2]}if(t[c>>2]|0)break;t[o>>2]=1}while(0);do if((t[(t[f>>2]|0)+4>>2]|0)==1){if(t[(t[f>>2]|0)+12>>2]|0)break;if(!((t[(t[f>>2]|0)+36>>2]|0)!=0?(t[(t[(t[f>>2]|0)+36>>2]|0)+12>>2]|0)!=0:0))d=86;do if((d|0)==86){c=(GV(t[f>>2]|0)|0)==1;if(!(c&(t[o>>2]|0)==0))break;$O(t[k>>2]|0,3,200960)|0;s=r;return}while(0);c=(t[o>>2]|0)==1;$O(t[k>>2]|0,1,200968)|0;do if(c){do if((t[(t[n>>2]|0)+40>>2]|0)==1){$O(t[k>>2]|0,1,200976)|0;if(!(t[33984]|0))break;h=t[n>>2]|0;if(((t[(t[n>>2]|0)+36>>2]|0)+1|0)>(t[(t[n>>2]|0)+108>>2]|0))v=t[h+108>>2]|0;else v=(t[h+36>>2]|0)+1|0;h=te(t[(t[n>>2]|0)+112>>2]|0,v)|0;$O(t[k>>2]|0,h,(t[n>>2]|0)+44|0)|0}while(0);iA(t[k>>2]|0,200984)|0;h=t[k>>2]|0;if(t[(t[n>>2]|0)+16>>2]|0)iA(h,t[(t[n>>2]|0)+16>>2]|0)|0;else $O(h,5,200728)|0;$O(t[k>>2]|0,4,201048)|0;if((t[(t[n>>2]|0)+40>>2]|0)!=1)break;$O(t[k>>2]|0,1,200976)|0}while(0);$O(t[k>>2]|0,2,201056)|0;do if(t[(t[f>>2]|0)+36>>2]|0){if(!(t[(t[(t[f>>2]|0)+36>>2]|0)+12>>2]|0))break;iA(t[k>>2]|0,t[(t[(t[f>>2]|0)+36>>2]|0)+12>>2]|0)|0;$O(t[k>>2]|0,1,200856)|0}while(0);iA(t[k>>2]|0,t[(t[f>>2]|0)+8>>2]|0)|0;$O(t[k>>2]|0,1,200968)|0;s=r;return}while(0);$O(t[k>>2]|0,1,200968)|0;if((t[o>>2]|0)==1){do if((t[(t[n>>2]|0)+40>>2]|0)==1){$O(t[k>>2]|0,1,200976)|0;if(!(t[33984]|0))break;o=t[n>>2]|0;if(((t[(t[n>>2]|0)+36>>2]|0)+1|0)>(t[(t[n>>2]|0)+108>>2]|0))m=t[o+108>>2]|0;else m=(t[o+36>>2]|0)+1|0;o=te(t[(t[n>>2]|0)+112>>2]|0,m)|0;$O(t[k>>2]|0,o,(t[n>>2]|0)+44|0)|0}while(0);iA(t[k>>2]|0,200984)|0;m=t[k>>2]|0;if(t[(t[n>>2]|0)+16>>2]|0)iA(m,t[(t[n>>2]|0)+16>>2]|0)|0;else $O(m,5,200728)|0;$O(t[k>>2]|0,4,201048)|0}do if((t[(t[f>>2]|0)+4>>2]|0)!=1){if(!(t[(t[f>>2]|0)+40>>2]|0))break;eA(t[k>>2]|0,t[(t[f>>2]|0)+40>>2]|0,t[(t[n>>2]|0)+116>>2]|0)|0}while(0);do if(t[(t[f>>2]|0)+12>>2]|0){t[w>>2]=t[(t[n>>2]|0)+40>>2];if((t[a>>2]|0)==1)$O(t[k>>2]|0,1,200976)|0;if((t[(t[n>>2]|0)+36>>2]|0)>=0){m=(t[n>>2]|0)+36|0;t[m>>2]=(t[m>>2]|0)+1}t[(t[n>>2]|0)+40>>2]=t[a>>2];qV(t[n>>2]|0,t[(t[f>>2]|0)+12>>2]|0);if((t[(t[n>>2]|0)+36>>2]|0)>0){m=(t[n>>2]|0)+36|0;t[m>>2]=(t[m>>2]|0)+-1}t[(t[n>>2]|0)+40>>2]=t[w>>2];if(!((t[33984]|0)!=0&(t[a>>2]|0)==1))break;m=t[n>>2]|0;if((t[(t[n>>2]|0)+36>>2]|0)>(t[(t[n>>2]|0)+108>>2]|0))_=t[m+108>>2]|0;else _=t[m+36>>2]|0;m=te(t[(t[n>>2]|0)+112>>2]|0,_)|0;$O(t[k>>2]|0,m,(t[n>>2]|0)+44|0)|0}while(0);$O(t[k>>2]|0,2,201056)|0;do if(t[(t[f>>2]|0)+36>>2]|0){if(!(t[(t[(t[f>>2]|0)+36>>2]|0)+12>>2]|0))break;iA(t[k>>2]|0,t[(t[(t[f>>2]|0)+36>>2]|0)+12>>2]|0)|0;$O(t[k>>2]|0,1,200856)|0}while(0);iA(t[k>>2]|0,t[(t[f>>2]|0)+8>>2]|0)|0;$O(t[k>>2]|0,1,200968)|0;s=r;return}OV(t[n>>2]|0,t[f>>2]|0)|0;s=r;return}function DV(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0;r=s;s=s+16|0;n=r+8|0;f=r+4|0;u=r;t[n>>2]=e;t[f>>2]=i;if(!(t[n>>2]|0)){s=r;return}if(!(t[(t[n>>2]|0)+24>>2]|0)){s=r;return}$O(t[(t[n>>2]|0)+24>>2]|0,1,200976)|0;t[u>>2]=0;while(1){if((t[u>>2]|0)>=((t[(t[n>>2]|0)+36>>2]|0)+(t[f>>2]|0)|0))break;i=t[n>>2]|0;if(((t[(t[n>>2]|0)+36>>2]|0)+(t[f>>2]|0)-(t[u>>2]|0)|0)>(t[(t[n>>2]|0)+108>>2]|0))a=t[i+108>>2]|0;else a=(t[i+36>>2]|0)+(t[f>>2]|0)-(t[u>>2]|0)|0;i=te(t[(t[n>>2]|0)+112>>2]|0,a)|0;$O(t[(t[n>>2]|0)+24>>2]|0,i,(t[n>>2]|0)+44|0)|0;t[u>>2]=(t[u>>2]|0)+(t[(t[n>>2]|0)+108>>2]|0)}s=r;return}function CV(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0;r=s;s=s+16|0;n=r+12|0;f=r+8|0;u=r+4|0;a=r;t[f>>2]=e;t[u>>2]=i;t[a>>2]=t[(t[f>>2]|0)+24>>2];do if(((t[u>>2]|0)!=0?(t[(t[a>>2]|0)+12>>2]|0)==0:0)?(t[(t[a>>2]|0)+20>>2]|0)==0:0){f=V_(t[u>>2]|0)|0;t[(t[a>>2]|0)+12>>2]=f;if(!(t[(t[a>>2]|0)+12>>2]|0)){MV(1403,0,t[u>>2]|0);t[n>>2]=-1;o=t[n>>2]|0;s=r;return o|0}f=ds()|0;t[(t[a>>2]|0)+20>>2]=f;f=t[a>>2]|0;if(t[(t[a>>2]|0)+20>>2]|0){G_(f,1)|0;break}W_(t[f+12>>2]|0)|0;NV(201600);t[n>>2]=-1;o=t[n>>2]|0;s=r;return o|0}while(0);t[n>>2]=0;o=t[n>>2]|0;s=r;return o|0}function PV(e,i,r,f){e=e|0;i=i|0;r=r|0;f=f|0;var a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0;a=s;s=s+48|0;o=a;c=a+40|0;l=a+36|0;b=a+32|0;k=a+28|0;h=a+24|0;w=a+20|0;d=a+16|0;v=a+12|0;m=a+8|0;_=a+4|0;t[l>>2]=e;t[b>>2]=i;t[k>>2]=r;t[h>>2]=f;t[w>>2]=t[l>>2];t[d>>2]=t[k>>2];t[v>>2]=(t[l>>2]|0)+(t[t[b>>2]>>2]|0);t[m>>2]=(t[k>>2]|0)+(t[t[h>>2]>>2]|0);e:while(1){if((t[k>>2]|0)>>>0>=(t[m>>2]|0)>>>0){p=46;break}if((t[l>>2]|0)>>>0>=(t[v>>2]|0)>>>0){p=46;break}if((u[t[k>>2]>>0]|0|0)==60){if(((t[v>>2]|0)-(t[l>>2]|0)|0)<4){p=46;break}f=t[l>>2]|0;t[l>>2]=f+1;n[f>>0]=38;f=t[l>>2]|0;t[l>>2]=f+1;n[f>>0]=108;f=t[l>>2]|0;t[l>>2]=f+1;n[f>>0]=116;f=t[l>>2]|0;t[l>>2]=f+1;n[f>>0]=59;t[k>>2]=(t[k>>2]|0)+1;continue}if((u[t[k>>2]>>0]|0|0)==62){if(((t[v>>2]|0)-(t[l>>2]|0)|0)<4){p=46;break}f=t[l>>2]|0;t[l>>2]=f+1;n[f>>0]=38;f=t[l>>2]|0;t[l>>2]=f+1;n[f>>0]=103;f=t[l>>2]|0;t[l>>2]=f+1;n[f>>0]=116;f=t[l>>2]|0;t[l>>2]=f+1;n[f>>0]=59;t[k>>2]=(t[k>>2]|0)+1;continue}if((u[t[k>>2]>>0]|0|0)==38){if(((t[v>>2]|0)-(t[l>>2]|0)|0)<5){p=46;break}f=t[l>>2]|0;t[l>>2]=f+1;n[f>>0]=38;f=t[l>>2]|0;t[l>>2]=f+1;n[f>>0]=97;f=t[l>>2]|0;t[l>>2]=f+1;n[f>>0]=109;f=t[l>>2]|0;t[l>>2]=f+1;n[f>>0]=112;f=t[l>>2]|0;t[l>>2]=f+1;n[f>>0]=59;t[k>>2]=(t[k>>2]|0)+1;continue}if(!((u[t[k>>2]>>0]|0|0)>=32?(u[t[k>>2]>>0]|0|0)<128:0))p=15;if(((p|0)==15?(p=0,(u[t[k>>2]>>0]|0|0)!=10):0)?(u[t[k>>2]>>0]|0|0)!=9:0){if((u[t[k>>2]>>0]|0|0)<128){if(!(9<=(u[t[k>>2]>>0]|0|0)?(u[t[k>>2]>>0]|0|0)<=10:0))p=41;if(((p|0)==41?(p=0,(u[t[k>>2]>>0]|0|0)!=13):0)?32>(u[t[k>>2]>>0]|0|0):0){p=45;break}if(((t[v>>2]|0)-(t[l>>2]|0)|0)<6){p=46;break}f=t[l>>2]|0;r=t[k>>2]|0;t[k>>2]=r+1;t[l>>2]=RV(f,u[r>>0]|0)|0;continue}if(((t[v>>2]|0)-(t[l>>2]|0)|0)<11){p=46;break}if((u[t[k>>2]>>0]|0|0)<192){p=21;break}do if((u[t[k>>2]>>0]|0|0)<224){if(((t[m>>2]|0)-(t[k>>2]|0)|0)<2){p=46;break e}t[_>>2]=(u[t[k>>2]>>0]|0)&31;t[_>>2]=t[_>>2]<<6;t[_>>2]=t[_>>2]|(u[(t[k>>2]|0)+1>>0]|0)&63;t[k>>2]=(t[k>>2]|0)+2}else{if((u[t[k>>2]>>0]|0|0)<240){if(((t[m>>2]|0)-(t[k>>2]|0)|0)<3){p=46;break e}t[_>>2]=(u[t[k>>2]>>0]|0)&15;t[_>>2]=t[_>>2]<<6;t[_>>2]=t[_>>2]|(u[(t[k>>2]|0)+1>>0]|0)&63;t[_>>2]=t[_>>2]<<6;t[_>>2]=t[_>>2]|(u[(t[k>>2]|0)+2>>0]|0)&63;t[k>>2]=(t[k>>2]|0)+3;break}if((u[t[k>>2]>>0]|0|0)>=248){p=31;break e}if(((t[m>>2]|0)-(t[k>>2]|0)|0)<4){p=46;break e}t[_>>2]=(u[t[k>>2]>>0]|0)&7;t[_>>2]=t[_>>2]<<6;t[_>>2]=t[_>>2]|(u[(t[k>>2]|0)+1>>0]|0)&63;t[_>>2]=t[_>>2]<<6;t[_>>2]=t[_>>2]|(u[(t[k>>2]|0)+2>>0]|0)&63;t[_>>2]=t[_>>2]<<6;t[_>>2]=t[_>>2]|(u[(t[k>>2]|0)+3>>0]|0)&63;t[k>>2]=(t[k>>2]|0)+4}while(0);r=t[_>>2]|0;if((t[_>>2]|0)<256){if(!(9<=(r|0)&(t[_>>2]|0)<=10|(t[_>>2]|0)==13|32<=(t[_>>2]|0))){p=37;break}}else if((!(256<=(r|0)&(t[_>>2]|0)<=55295)?!(57344<=(t[_>>2]|0)&(t[_>>2]|0)<=65533):0)?!(65536<=(t[_>>2]|0)&(t[_>>2]|0)<=1114111):0){p=37;break}t[l>>2]=RV(t[l>>2]|0,t[_>>2]|0)|0;continue}r=t[k>>2]|0;t[k>>2]=r+1;f=n[r>>0]|0;r=t[l>>2]|0;t[l>>2]=r+1;n[r>>0]=f}if((p|0)==21){MV(1400,0,0);t[k>>2]=(t[k>>2]|0)+1}else if((p|0)==31){MV(1401,0,0);t[k>>2]=(t[k>>2]|0)+1}else if((p|0)==37){MV(1401,0,0);t[k>>2]=(t[k>>2]|0)+1}else if((p|0)==45){yAi[t[135904>>2]&511](t[33980]|0,201400,o);t[k>>2]=(t[k>>2]|0)+1}else if((p|0)==46){t[t[b>>2]>>2]=(t[l>>2]|0)-(t[w>>2]|0);t[t[h>>2]>>2]=(t[k>>2]|0)-(t[d>>2]|0);t[c>>2]=0;E=t[c>>2]|0;s=a;return E|0}t[t[b>>2]>>2]=(t[l>>2]|0)-(t[w>>2]|0);t[t[h>>2]>>2]=(t[k>>2]|0)-(t[d>>2]|0);t[c>>2]=-1;E=t[c>>2]|0;s=a;return E|0}function BV(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i+4|0;n=i;t[r>>2]=e;t[n>>2]=t[(t[r>>2]|0)+24>>2];xO(t[n>>2]|0)|0;W_(t[(t[n>>2]|0)+12>>2]|0)|0;Ss(t[(t[n>>2]|0)+20>>2]|0);t[(t[n>>2]|0)+12>>2]=0;t[(t[n>>2]|0)+20>>2]=0;s=i;return 0}function IV(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0;r=s;s=s+48|0;n=r+32|0;f=r+28|0;u=r+24|0;a=r+20|0;o=r+16|0;c=r+12|0;l=r+8|0;b=r+4|0;k=r;t[f>>2]=e;t[u>>2]=i;t[a>>2]=0;t[o>>2]=t[(t[f>>2]|0)+16>>2];t[c>>2]=t[(t[f>>2]|0)+16>>2];t[l>>2]=t[(t[f>>2]|0)+24>>2];t[b>>2]=0;rS();t[k>>2]=t[(t[u>>2]|0)+32>>2];do if(t[k>>2]|0){t[a>>2]=t[(t[k>>2]|0)+60>>2];if(t[(t[f>>2]|0)+16>>2]|0){t[(t[k>>2]|0)+60>>2]=t[(t[f>>2]|0)+16>>2];break}if(t[(t[k>>2]|0)+60>>2]|0)t[c>>2]=t[(t[k>>2]|0)+60>>2]}while(0);if((t[c>>2]|0)!=0&(t[k>>2]|0)!=0)Wi(t[k>>2]|0,t[c>>2]|0)|0;if((t[c>>2]|0)==0&(t[k>>2]|0)!=0)t[c>>2]=Gi(t[k>>2]|0)|0;if(!(t[c>>2]|0))t[c>>2]=201592;do if(((t[c>>2]|0)!=0&(t[o>>2]|0)==0?(t[(t[l>>2]|0)+12>>2]|0)==0:0)?(t[(t[l>>2]|0)+20>>2]|0)==0:0){if((CV(t[f>>2]|0,t[c>>2]|0)|0)>=0){t[b>>2]=1;break}t[(t[k>>2]|0)+60>>2]=t[a>>2];t[n>>2]=-1;h=t[n>>2]|0;s=r;return h|0}while(0);i=t[l>>2]|0;l=t[k>>2]|0;e=t[u>>2]|0;u=t[c>>2]|0;if(t[(t[f>>2]|0)+32>>2]&1)Zi(i,l,e,u,1);else Zi(i,l,e,u,0);if((t[b>>2]|0)!=0&(t[o>>2]|0)==0)BV(t[f>>2]|0)|0;if(t[k>>2]|0)t[(t[k>>2]|0)+60>>2]=t[a>>2];t[n>>2]=0;h=t[n>>2]|0;s=r;return h|0}function HV(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0;r=s;s=s+32|0;n=r+20|0;f=r+16|0;u=r+12|0;a=r+8|0;o=r+4|0;c=r;t[n>>2]=e;t[f>>2]=i;if((t[f>>2]|0)==0|(t[n>>2]|0)==0){s=r;return}if(!(t[(t[n>>2]|0)+24>>2]|0)){s=r;return}t[u>>2]=t[(t[n>>2]|0)+24>>2];$O(t[u>>2]|0,10,201336)|0;iA(t[u>>2]|0,t[(t[f>>2]|0)+8>>2]|0)|0;if(!(t[(t[f>>2]|0)+52>>2]|0)){if(t[(t[f>>2]|0)+56>>2]|0){$O(t[u>>2]|0,8,201368)|0;xs(t[(t[u>>2]|0)+16>>2]|0,t[(t[f>>2]|0)+56>>2]|0)|0}}else{$O(t[u>>2]|0,8,201352)|0;xs(t[(t[u>>2]|0)+16>>2]|0,t[(t[f>>2]|0)+52>>2]|0)|0;$O(t[u>>2]|0,1,200760)|0;xs(t[(t[u>>2]|0)+16>>2]|0,t[(t[f>>2]|0)+56>>2]|0)|0}if(((((t[(t[f>>2]|0)+48>>2]|0)==0?(t[(t[f>>2]|0)+40>>2]|0)==0:0)?(t[(t[f>>2]|0)+44>>2]|0)==0:0)?(t[(t[f>>2]|0)+36>>2]|0)==0:0)?(t[(t[f>>2]|0)+60>>2]|0)==0:0){$O(t[u>>2]|0,1,200968)|0;s=r;return}$O(t[u>>2]|0,3,201384)|0;do if(t[(t[f>>2]|0)+36>>2]|0){if((t[(t[f>>2]|0)+32>>2]|0)!=0?(t[(t[(t[f>>2]|0)+32>>2]|0)+44>>2]|0)!=(t[f>>2]|0):0)break;$j(t[(t[u>>2]|0)+16>>2]|0,t[(t[f>>2]|0)+36>>2]|0)}while(0);t[a>>2]=t[(t[n>>2]|0)+40>>2];t[o>>2]=t[(t[n>>2]|0)+36>>2];t[c>>2]=t[(t[n>>2]|0)+28>>2];t[(t[n>>2]|0)+40>>2]=0;t[(t[n>>2]|0)+36>>2]=-1;t[(t[n>>2]|0)+28>>2]=t[(t[f>>2]|0)+32>>2];xV(t[n>>2]|0,t[(t[f>>2]|0)+12>>2]|0);t[(t[n>>2]|0)+40>>2]=t[a>>2];t[(t[n>>2]|0)+36>>2]=t[o>>2];t[(t[n>>2]|0)+28>>2]=t[c>>2];$O(t[u>>2]|0,2,201392)|0;s=r;return}function xV(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0;r=s;s=s+16|0;n=r+8|0;f=r+4|0;u=r;t[n>>2]=e;t[f>>2]=i;if(!(t[f>>2]|0)){s=r;return}t[u>>2]=t[(t[n>>2]|0)+24>>2];while(1){if(!(t[f>>2]|0))break;do if((t[33984]|0)!=0?(t[(t[n>>2]|0)+40>>2]|0)==1:0){if(((t[(t[f>>2]|0)+4>>2]|0)!=1?(t[(t[f>>2]|0)+4>>2]|0)!=8:0)?(t[(t[f>>2]|0)+4>>2]|0)!=7:0)break;i=t[n>>2]|0;if((t[(t[n>>2]|0)+36>>2]|0)>(t[(t[n>>2]|0)+108>>2]|0))a=t[i+108>>2]|0;else a=t[i+36>>2]|0;i=te(t[(t[n>>2]|0)+112>>2]|0,a)|0;$O(t[u>>2]|0,i,(t[n>>2]|0)+44|0)|0}while(0);AV(t[n>>2]|0,t[f>>2]|0);if((t[(t[n>>2]|0)+40>>2]|0)==1)$O(t[u>>2]|0,1,200976)|0;t[f>>2]=t[(t[f>>2]|0)+24>>2]}s=r;return}function UV(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0;r=s;s=s+16|0;n=r+8|0;f=r+4|0;u=r;t[n>>2]=e;t[f>>2]=i;if(!(t[f>>2]|0)){s=r;return}t[u>>2]=t[(t[n>>2]|0)+24>>2];if(!(t[u>>2]|0)){s=r;return}if((t[(t[n>>2]|0)+40>>2]|0)==2)DV(t[n>>2]|0,2);else $O(t[u>>2]|0,1,200760)|0;if((t[(t[f>>2]|0)+36>>2]|0)!=0?(t[(t[(t[f>>2]|0)+36>>2]|0)+12>>2]|0)!=0:0){iA(t[u>>2]|0,t[(t[(t[f>>2]|0)+36>>2]|0)+12>>2]|0)|0;$O(t[u>>2]|0,1,200856)|0}iA(t[u>>2]|0,t[(t[f>>2]|0)+8>>2]|0)|0;$O(t[u>>2]|0,2,201328)|0;WV(t[u>>2]|0,t[f>>2]|0);$O(t[u>>2]|0,1,201296)|0;s=r;return}function zV(e,i){e=e|0;i=i|0;var r=0,n=0,f=0;r=s;s=s+16|0;n=r+4|0;f=r;t[n>>2]=e;t[f>>2]=i;gV(t[(t[n>>2]|0)+24>>2]|0,t[f>>2]|0,t[n>>2]|0);s=r;return}function jV(e,i){e=e|0;i=i|0;var r=0,n=0,f=0;r=s;s=s+16|0;n=r+4|0;f=r;t[n>>2]=e;t[f>>2]=i;while(1){if(!(t[f>>2]|0))break;gV(t[(t[n>>2]|0)+24>>2]|0,t[f>>2]|0,t[n>>2]|0);t[f>>2]=t[t[f>>2]>>2]}s=r;return}function VV(e,i){e=e|0;i=i|0;var r=0,n=0,f=0;r=s;s=s+16|0;n=r+4|0;f=r;t[n>>2]=e;t[f>>2]=i;if(!((t[f>>2]|0)!=0&(t[f>>2]|0)!=0)){s=r;return}do{UV(t[n>>2]|0,t[f>>2]|0);t[f>>2]=t[(t[f>>2]|0)+24>>2]}while((t[f>>2]|0)!=0);s=r;return}function qV(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0;r=s;s=s+16|0;n=r+8|0;f=r+4|0;u=r;t[n>>2]=e;t[f>>2]=i;if(!(t[f>>2]|0)){s=r;return}t[u>>2]=t[(t[n>>2]|0)+24>>2];while(1){if(!(t[f>>2]|0))break;if(((t[33984]|0)!=0?(t[(t[n>>2]|0)+40>>2]|0)==1:0)?(t[(t[f>>2]|0)+4>>2]|0)==1:0){i=t[n>>2]|0;if((t[(t[n>>2]|0)+36>>2]|0)>(t[(t[n>>2]|0)+108>>2]|0))a=t[i+108>>2]|0;else a=t[i+36>>2]|0;i=te(t[(t[n>>2]|0)+112>>2]|0,a)|0;$O(t[u>>2]|0,i,(t[n>>2]|0)+44|0)|0}LV(t[n>>2]|0,t[f>>2]|0);if((t[(t[n>>2]|0)+40>>2]|0)==1)$O(t[u>>2]|0,1,200976)|0;t[f>>2]=t[(t[f>>2]|0)+24>>2]}s=r;return}function YV(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0;r=s;s=s+32|0;n=r+28|0;f=r+24|0;a=r+20|0;o=r+16|0;c=r+12|0;l=r+8|0;b=r+4|0;k=r;t[n>>2]=e;t[f>>2]=i;t[a>>2]=0;t[o>>2]=0;t[c>>2]=0;t[l>>2]=0;if(!(t[f>>2]|0)){s=r;return}t[k>>2]=t[(t[n>>2]|0)+24>>2];t[b>>2]=t[(t[f>>2]|0)+20>>2];while(1){if(!(t[f>>2]|0))break;if((t[(t[f>>2]|0)+36>>2]|0)==0?(Xl(t[(t[f>>2]|0)+8>>2]|0,201200)|0)!=0:0)t[l>>2]=t[f>>2];else h=7;do if((h|0)==7){h=0;if((t[(t[f>>2]|0)+36>>2]|0)==0?(Xl(t[(t[f>>2]|0)+8>>2]|0,201208)|0)!=0:0){t[c>>2]=t[f>>2];break}if((t[(t[f>>2]|0)+36>>2]|0)==0?(Xl(t[(t[f>>2]|0)+8>>2]|0,201216)|0)!=0:0){t[o>>2]=t[f>>2];break}if(((t[(t[f>>2]|0)+36>>2]|0)!=0?(Xl(t[(t[f>>2]|0)+8>>2]|0,201216)|0)!=0:0)?(Xl(t[(t[(t[f>>2]|0)+36>>2]|0)+12>>2]|0,201224)|0)!=0:0){t[a>>2]=t[f>>2];break}if(!(t[(t[f>>2]|0)+36>>2]|0)){if(((t[(t[f>>2]|0)+12>>2]|0)!=0?(t[(t[(t[f>>2]|0)+12>>2]|0)+40>>2]|0)!=0:0)?(u[t[(t[(t[f>>2]|0)+12>>2]|0)+40>>2]>>0]|0|0)!=0:0)break;if(Ki(t[(t[f>>2]|0)+8>>2]|0)|0){if(t[(t[f>>2]|0)+12>>2]|0)ry(t[(t[f>>2]|0)+12>>2]|0);i=yy(t[(t[f>>2]|0)+8>>2]|0)|0;t[(t[f>>2]|0)+12>>2]=i;if(t[(t[f>>2]|0)+12>>2]|0)t[(t[(t[f>>2]|0)+12>>2]|0)+20>>2]=t[f>>2]}}}while(0);UV(t[n>>2]|0,t[f>>2]|0);t[f>>2]=t[(t[f>>2]|0)+24>>2]}do if((t[c>>2]|0)!=0&(t[l>>2]|0)==0&(t[b>>2]|0)!=0?(t[(t[b>>2]|0)+8>>2]|0)!=0:0){if(((((((((Xl(t[(t[b>>2]|0)+8>>2]|0,201232)|0)==0?(Xl(t[(t[b>>2]|0)+8>>2]|0,201240)|0)==0:0)?(Xl(t[(t[b>>2]|0)+8>>2]|0,201248)|0)==0:0)?(Xl(t[(t[b>>2]|0)+8>>2]|0,201160)|0)==0:0)?(Xl(t[(t[b>>2]|0)+8>>2]|0,201256)|0)==0:0)?(Xl(t[(t[b>>2]|0)+8>>2]|0,201264)|0)==0:0)?(Xl(t[(t[b>>2]|0)+8>>2]|0,201272)|0)==0:0)?(Xl(t[(t[b>>2]|0)+8>>2]|0,201144)|0)==0:0)?(Xl(t[(t[b>>2]|0)+8>>2]|0,201280)|0)==0:0)break;$O(t[k>>2]|0,5,201288)|0;WV(t[k>>2]|0,t[c>>2]|0);$O(t[k>>2]|0,1,201296)|0}while(0);if((t[o>>2]|0)!=0&(t[a>>2]|0)==0){$O(t[k>>2]|0,11,201304)|0;WV(t[k>>2]|0,t[o>>2]|0);$O(t[k>>2]|0,1,201296)|0;s=r;return}if(!((t[a>>2]|0)!=0&(t[o>>2]|0)==0)){s=r;return}$O(t[k>>2]|0,7,201320)|0;WV(t[k>>2]|0,t[a>>2]|0);$O(t[k>>2]|0,1,201296)|0;s=r;return}function GV(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i+4|0;n=i;t[n>>2]=e;e:do if(!(t[n>>2]|0))t[r>>2]=-1;else{if((t[(t[n>>2]|0)+4>>2]|0)!=1){t[r>>2]=0;break}if((t[(t[n>>2]|0)+36>>2]|0)!=0?(Xl(t[(t[(t[n>>2]|0)+36>>2]|0)+8>>2]|0,201064)|0)==0:0){t[r>>2]=0;break}if(t[(t[n>>2]|0)+12>>2]|0){t[r>>2]=0;break}do switch(u[t[(t[n>>2]|0)+8>>2]>>0]|0|0){case 98:{if(Xl(t[(t[n>>2]|0)+8>>2]|0,201104)|0){t[r>>2]=1;break e}if(Xl(t[(t[n>>2]|0)+8>>2]|0,201112)|0){t[r>>2]=1;break e}if(Xl(t[(t[n>>2]|0)+8>>2]|0,201120)|0){t[r>>2]=1;break e}else{t[r>>2]=0;break e}break}case 99:{if(Xl(t[(t[n>>2]|0)+8>>2]|0,201136)|0){t[r>>2]=1;break e}else{t[r>>2]=0;break e}break}case 97:{if(Xl(t[(t[n>>2]|0)+8>>2]|0,201096)|0){t[r>>2]=1;break e}else{t[r>>2]=0;break e}break}case 109:{if(Xl(t[(t[n>>2]|0)+8>>2]|0,200920)|0){t[r>>2]=1;break e}else{t[r>>2]=0;break e}break}case 102:{if(Xl(t[(t[n>>2]|0)+8>>2]|0,201144)|0){t[r>>2]=1;break e}else{t[r>>2]=0;break e}break}case 105:{if(Xl(t[(t[n>>2]|0)+8>>2]|0,201160)|0){t[r>>2]=1;break e}if(Xl(t[(t[n>>2]|0)+8>>2]|0,201168)|0){t[r>>2]=1;break e}if(Xl(t[(t[n>>2]|0)+8>>2]|0,201176)|0){t[r>>2]=1;break e}else{t[r>>2]=0;break e}break}case 104:{if(Xl(t[(t[n>>2]|0)+8>>2]|0,201152)|0){t[r>>2]=1;break e}else{t[r>>2]=0;break e}break}case 112:{if(Xl(t[(t[n>>2]|0)+8>>2]|0,201192)|0){t[r>>2]=1;break e}else{t[r>>2]=0;break e}break}case 108:{if(Xl(t[(t[n>>2]|0)+8>>2]|0,201184)|0){t[r>>2]=1;break e}else{t[r>>2]=0;break e}break}default:{t[r>>2]=0;break e}}while(0)}while(0);s=i;return t[r>>2]|0}function WV(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0;r=s;s=s+16|0;n=r+8|0;f=r+4|0;u=r;t[n>>2]=e;t[f>>2]=i;t[u>>2]=t[(t[f>>2]|0)+12>>2];while(1){if(!(t[u>>2]|0))break;i=t[(t[u>>2]|0)+4>>2]|0;if((i|0)==5){Ps(t[(t[n>>2]|0)+16>>2]|0,200792,1)|0;e=t[(t[n>>2]|0)+16>>2]|0;a=t[(t[u>>2]|0)+8>>2]|0;Ps(e,a,rs(t[(t[u>>2]|0)+8>>2]|0)|0)|0;Ps(t[(t[n>>2]|0)+16>>2]|0,200800,1)|0}else if((i|0)==3)lV(t[(t[n>>2]|0)+16>>2]|0,t[(t[f>>2]|0)+32>>2]|0,t[f>>2]|0,t[(t[u>>2]|0)+40>>2]|0);t[u>>2]=t[(t[u>>2]|0)+24>>2]}s=r;return}function KV(e){e=e|0;var i=0,r=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if(!(t[r>>2]|0)){s=i;return}if((t[(t[r>>2]|0)+8>>2]|0)!=0?(t[(t[r>>2]|0)+4>>2]|0)==0:0)fy(t[(t[r>>2]|0)+8>>2]|0);if(t[(t[r>>2]|0)+52>>2]|0)pAi[t[135736>>2]&511](t[(t[r>>2]|0)+52>>2]|0);iq(t[(t[r>>2]|0)+40>>2]|0);rq(t[(t[r>>2]|0)+36>>2]|0);bz(t[(t[r>>2]|0)+20>>2]|0);pAi[t[135736>>2]&511](t[r>>2]|0);s=i;return}function XV(e){e=e|0;var i=0,r=0,n=0,f=0,u=0,a=0;i=s;s=s+16|0;r=i+8|0;n=i+4|0;f=i;t[n>>2]=e;if(!(t[n>>2]|0)){t[r>>2]=0;u=t[r>>2]|0;s=i;return u|0}t[f>>2]=gAi[t[135744>>2]&511](84)|0;if(!(t[f>>2]|0)){nq(0,201776,0);t[r>>2]=0;u=t[r>>2]|0;s=i;return u|0}e=(t[f>>2]|0)+0|0;a=e+84|0;do{t[e>>2]=0;e=e+4|0}while((e|0)<(a|0));t[t[f>>2]>>2]=1;e=lz()|0;t[(t[f>>2]|0)+24>>2]=e;e=kz(t[(t[f>>2]|0)+24>>2]|0,t[n>>2]|0,-1)|0;t[(t[f>>2]|0)+4>>2]=e;t[(t[f>>2]|0)+64>>2]=0;e=wf(0)|0;t[(t[f>>2]|0)+36>>2]=e;if(!(t[(t[f>>2]|0)+36>>2]|0)){nq(0,201816,0);ZV(t[f>>2]|0);t[r>>2]=0;u=t[r>>2]|0;s=i;return u|0}else{t[(t[(t[f>>2]|0)+36>>2]|0)+196>>2]=1;t[r>>2]=t[f>>2];u=t[r>>2]|0;s=i;return u|0}return 0}function ZV(e){e=e|0;var i=0,r=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if(!(t[r>>2]|0)){s=i;return}if((t[(t[r>>2]|0)+8>>2]|0)!=0?(t[(t[r>>2]|0)+12>>2]|0)==0:0)fy(t[(t[r>>2]|0)+8>>2]|0);if(t[(t[r>>2]|0)+36>>2]|0)vf(t[(t[r>>2]|0)+36>>2]|0);if(t[(t[r>>2]|0)+52>>2]|0)pAi[t[135736>>2]&511](t[(t[r>>2]|0)+52>>2]|0);bz(t[(t[r>>2]|0)+24>>2]|0);pAi[t[135736>>2]&511](t[r>>2]|0);s=i;return}function JV(e){e=e|0;var i=0,r=0,n=0,f=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0;i=s;s=s+48|0;r=i+36|0;n=i+32|0;f=i+28|0;a=i+24|0;o=i+20|0;c=i+16|0;l=i+12|0;b=i+8|0;k=i+4|0;h=i;t[n>>2]=e;t[f>>2]=0;t[l>>2]=0;if(!(t[n>>2]|0)){t[r>>2]=0;w=t[r>>2]|0;s=i;return w|0}t[(t[n>>2]|0)+28>>2]=0;e=t[n>>2]|0;do if(!(t[(t[n>>2]|0)+4>>2]|0)){d=t[n>>2]|0;if(t[e+16>>2]|0){t[a>>2]=pS(t[d+16>>2]|0,t[(t[n>>2]|0)+20>>2]|0,0,0,2)|0;if(t[a>>2]|0){v=Yl(201944)|0;t[(t[a>>2]|0)+72>>2]=v;v=kz(t[(t[n>>2]|0)+24>>2]|0,201944,-1)|0;t[(t[n>>2]|0)+4>>2]=v;t[(t[n>>2]|0)+12>>2]=0;break}fq(t[n>>2]|0,0,1766,201904,0,0);t[r>>2]=0;w=t[r>>2]|0;s=i;return w|0}else{v=t[n>>2]|0;if(t[d+8>>2]|0){t[a>>2]=t[v+8>>2];t[l>>2]=1;t[(t[n>>2]|0)+12>>2]=1;break}fq(v,0,1758,201904,0,0);t[r>>2]=0;w=t[r>>2]|0;s=i;return w|0}}else{t[a>>2]=_S(t[e+4>>2]|0,0,2)|0;v=t[n>>2]|0;if(t[a>>2]|0){t[v+12>>2]=0;break}fq(v,0,1757,201856,t[(t[n>>2]|0)+4>>2]|0,0);t[r>>2]=0;w=t[r>>2]|0;s=i;return w|0}while(0);t[o>>2]=eF(t[a>>2]|0)|0;if(!(t[o>>2]|0)){fq(t[n>>2]|0,t[a>>2]|0,1759,201968,0,0);if(!(t[l>>2]|0))fy(t[a>>2]|0);t[r>>2]=0;w=t[r>>2]|0;s=i;return w|0}do if((((t[o>>2]|0)!=0?(t[(t[o>>2]|0)+4>>2]|0)==1:0)?(t[(t[o>>2]|0)+36>>2]|0)!=0:0)?(Xl(t[(t[o>>2]|0)+8>>2]|0,202008)|0)!=0:0){if((Xl(t[(t[(t[o>>2]|0)+36>>2]|0)+8>>2]|0,t[50504]|0)|0)==0?(Xl(t[(t[(t[o>>2]|0)+36>>2]|0)+8>>2]|0,t[50506]|0)|0)==0:0){m=24;break}t[f>>2]=tq(t[n>>2]|0)|0;if(t[f>>2]|0){t[(t[n>>2]|0)+40>>2]=t[f>>2];t[c>>2]=t[(t[o>>2]|0)+12>>2];while(1){if(!(t[c>>2]|0))break;if((t[(t[c>>2]|0)+4>>2]|0)==1?(t[(t[c>>2]|0)+36>>2]|0)!=0:0){if(Xl(t[(t[(t[c>>2]|0)+36>>2]|0)+8>>2]|0,t[50504]|0)|0)break;if(Xl(t[(t[(t[c>>2]|0)+36>>2]|0)+8>>2]|0,t[50506]|0)|0)break}t[c>>2]=t[(t[c>>2]|0)+24>>2]}e:do if((((t[c>>2]|0)!=0?(t[(t[c>>2]|0)+4>>2]|0)==1:0)?(t[(t[c>>2]|0)+36>>2]|0)!=0:0)?(Xl(t[(t[c>>2]|0)+8>>2]|0,202088)|0)!=0:0){if((Xl(t[(t[(t[c>>2]|0)+36>>2]|0)+8>>2]|0,t[50504]|0)|0)==0?(Xl(t[(t[(t[c>>2]|0)+36>>2]|0)+8>>2]|0,t[50506]|0)|0)==0:0)break;t[b>>2]=sF(t[c>>2]|0)|0;if(t[b>>2]|0){e=kz(t[(t[f>>2]|0)+20>>2]|0,t[b>>2]|0,-1)|0;t[(t[f>>2]|0)+24>>2]=e;pAi[t[135736>>2]&511](t[b>>2]|0)}t[c>>2]=t[(t[c>>2]|0)+24>>2];while(1){if(!(t[c>>2]|0))break e;do if((t[(t[c>>2]|0)+4>>2]|0)==1){if(!(t[(t[c>>2]|0)+36>>2]|0))break;if(Xl(t[(t[(t[c>>2]|0)+36>>2]|0)+8>>2]|0,t[50504]|0)|0)break e;if(Xl(t[(t[(t[c>>2]|0)+36>>2]|0)+8>>2]|0,t[50506]|0)|0)break e}while(0);t[c>>2]=t[(t[c>>2]|0)+24>>2]}}while(0);e:while(1){if(!(t[c>>2]|0))break;if((t[(t[c>>2]|0)+4>>2]|0)!=1)break;if(!(t[(t[c>>2]|0)+36>>2]|0))break;if(!(Xl(t[(t[c>>2]|0)+8>>2]|0,202096)|0))break;if((Xl(t[(t[(t[c>>2]|0)+36>>2]|0)+8>>2]|0,t[50504]|0)|0)==0?(Xl(t[(t[(t[c>>2]|0)+36>>2]|0)+8>>2]|0,t[50506]|0)|0)==0:0)break;t[k>>2]=vF(t[c>>2]|0,202104)|0;t[h>>2]=vF(t[c>>2]|0,202112)|0;if(!((t[h>>2]|0)!=0?(u[t[h>>2]>>0]|0|0)!=0:0))fq(t[n>>2]|0,t[c>>2]|0,1759,202120,0,0);if(!((t[k>>2]|0)!=0?(u[t[k>>2]>>0]|0|0)!=0:0))fq(t[n>>2]|0,t[c>>2]|0,1759,202144,0,0);if((t[k>>2]|0)!=0&(t[h>>2]|0)!=0){Kn(t[(t[n>>2]|0)+36>>2]|0,t[k>>2]|0,t[h>>2]|0)|0;uq(t[n>>2]|0,t[k>>2]|0,t[h>>2]|0);e=(t[f>>2]|0)+28|0;t[e>>2]=(t[e>>2]|0)+1}if(t[h>>2]|0)pAi[t[135736>>2]&511](t[h>>2]|0);if(t[k>>2]|0)pAi[t[135736>>2]&511](t[k>>2]|0);t[c>>2]=t[(t[c>>2]|0)+24>>2];while(1){if(!(t[c>>2]|0))continue e;do if((t[(t[c>>2]|0)+4>>2]|0)==1){if(!(t[(t[c>>2]|0)+36>>2]|0))break;if(Xl(t[(t[(t[c>>2]|0)+36>>2]|0)+8>>2]|0,t[50504]|0)|0)continue e;if(Xl(t[(t[(t[c>>2]|0)+36>>2]|0)+8>>2]|0,t[50506]|0)|0)continue e}while(0);t[c>>2]=t[(t[c>>2]|0)+24>>2]}}e:while(1){if(!(t[c>>2]|0))break;do if((((t[c>>2]|0)!=0?(t[(t[c>>2]|0)+4>>2]|0)==1:0)?(t[(t[c>>2]|0)+36>>2]|0)!=0:0)?(Xl(t[(t[c>>2]|0)+8>>2]|0,202176)|0)!=0:0){if((Xl(t[(t[(t[c>>2]|0)+36>>2]|0)+8>>2]|0,t[50504]|0)|0)==0?(Xl(t[(t[(t[c>>2]|0)+36>>2]|0)+8>>2]|0,t[50506]|0)|0)==0:0){m=81;break}aq(t[n>>2]|0,t[c>>2]|0);e=(t[f>>2]|0)+32|0;t[e>>2]=(t[e>>2]|0)+1}else m=81;while(0);if((m|0)==81){m=0;fq(t[n>>2]|0,t[c>>2]|0,1759,202184,t[(t[c>>2]|0)+8>>2]|0,0)}t[c>>2]=t[(t[c>>2]|0)+24>>2];while(1){if(!(t[c>>2]|0))continue e;if((t[(t[c>>2]|0)+4>>2]|0)==1?(t[(t[c>>2]|0)+36>>2]|0)!=0:0){if(Xl(t[(t[(t[c>>2]|0)+36>>2]|0)+8>>2]|0,t[50504]|0)|0)continue e;if(Xl(t[(t[(t[c>>2]|0)+36>>2]|0)+8>>2]|0,t[50506]|0)|0)continue e;
	}t[c>>2]=t[(t[c>>2]|0)+24>>2]}}if(!(t[(t[f>>2]|0)+32>>2]|0)){fq(t[n>>2]|0,t[o>>2]|0,1759,202232,t[(t[n>>2]|0)+4>>2]|0,0);break}t[(t[f>>2]|0)+8>>2]=t[a>>2];if(t[l>>2]|0)t[(t[f>>2]|0)+4>>2]=1;t[l>>2]=1}}else m=24;while(0);if((m|0)==24)fq(t[n>>2]|0,t[o>>2]|0,1759,202032,t[(t[n>>2]|0)+4>>2]|0,0);if(!(t[l>>2]|0))fy(t[a>>2]|0);do if(t[f>>2]|0)if(t[(t[n>>2]|0)+28>>2]|0){KV(t[f>>2]|0);t[f>>2]=0;break}else{t[(t[f>>2]|0)+52>>2]=t[(t[n>>2]|0)+52>>2];t[(t[f>>2]|0)+44>>2]=t[(t[n>>2]|0)+44>>2];t[(t[n>>2]|0)+52>>2]=0;break}while(0);t[r>>2]=t[f>>2];w=t[r>>2]|0;s=i;return w|0}function QV(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0;r=s;s=s+32|0;n=r+16|0;f=r+12|0;u=r+8|0;a=r+4|0;o=r;t[f>>2]=e;t[u>>2]=i;t[o>>2]=gAi[t[135744>>2]&511](64)|0;if(!(t[o>>2]|0)){oq(0,202280,0);t[n>>2]=0;c=t[n>>2]|0;s=r;return c|0}i=(t[o>>2]|0)+0|0;e=i+64|0;do{t[i>>2]=0;i=i+4|0}while((i|0)<(e|0));t[t[o>>2]>>2]=2;t[(t[o>>2]|0)+20>>2]=t[f>>2];i=wf(0)|0;t[(t[o>>2]|0)+24>>2]=i;t[(t[o>>2]|0)+4>>2]=t[u>>2];if(!(t[(t[o>>2]|0)+24>>2]|0)){nq(0,201816,0);$V(t[o>>2]|0);t[n>>2]=0;c=t[n>>2]|0;s=r;return c|0}t[a>>2]=0;while(1){if((t[a>>2]|0)>=(t[(t[f>>2]|0)+44>>2]|0))break;if(!(t[(t[(t[f>>2]|0)+52>>2]|0)+(t[a>>2]<<1<<2)>>2]|0))break;if(!(t[(t[(t[f>>2]|0)+52>>2]|0)+((t[a>>2]<<1)+1<<2)>>2]|0))break;Kn(t[(t[o>>2]|0)+24>>2]|0,t[(t[(t[f>>2]|0)+52>>2]|0)+((t[a>>2]<<1)+1<<2)>>2]|0,t[(t[(t[f>>2]|0)+52>>2]|0)+(t[a>>2]<<1<<2)>>2]|0)|0;t[a>>2]=(t[a>>2]|0)+1}t[n>>2]=t[o>>2];c=t[n>>2]|0;s=r;return c|0}function $V(e){e=e|0;var i=0,r=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if(!(t[r>>2]|0)){s=i;return}if(t[(t[r>>2]|0)+24>>2]|0)vf(t[(t[r>>2]|0)+24>>2]|0);if(t[(t[r>>2]|0)+8>>2]|0)bz(t[(t[r>>2]|0)+8>>2]|0);pAi[t[135736>>2]&511](t[r>>2]|0);s=i;return}function eq(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0;r=s;s=s+48|0;n=r;f=r+36|0;u=r+32|0;a=r+28|0;o=r+24|0;c=r+20|0;l=r+16|0;b=r+12|0;k=r+8|0;t[u>>2]=e;t[a>>2]=i;if(((t[u>>2]|0)!=0?(t[(t[u>>2]|0)+20>>2]|0)!=0:0)?!((t[a>>2]|0)==0?1:(t[(t[(t[u>>2]|0)+20>>2]|0)+40>>2]|0)==0):0){t[(t[u>>2]|0)+12>>2]=0;t[c>>2]=eF(t[a>>2]|0)|0;if(!(t[c>>2]|0)){i=t[33976]|0;e=t[33980]|0;t[n>>2]=202344;t[n+4>>2]=1679;yAi[i&511](e,202312,n);n=(t[u>>2]|0)+12|0;t[n>>2]=(t[n>>2]|0)+1;t[f>>2]=1;h=t[f>>2]|0;s=r;return h|0}e:do if((t[(t[u>>2]|0)+4>>2]&1|0)==0?(t[(t[u>>2]|0)+4>>2]|0)!=0:0){t[l>>2]=t[(t[(t[u>>2]|0)+20>>2]|0)+36>>2];while(1){if(!(t[l>>2]|0))break e;sq(t[u>>2]|0,t[l>>2]|0);t[o>>2]=t[c>>2];while(1){w=t[l>>2]|0;if(!(t[o>>2]|0))break;t[b>>2]=t[w+4>>2];while(1){if(!(t[b>>2]|0))break;i:do if((Oj(t[(t[b>>2]|0)+20>>2]|0,t[o>>2]|0)|0)==1){t[k>>2]=t[(t[b>>2]|0)+16>>2];while(1){if(!(t[k>>2]|0))break i;cq(t[u>>2]|0,t[k>>2]|0,t[a>>2]|0,t[o>>2]|0,t[l>>2]|0)|0;t[k>>2]=t[t[k>>2]>>2]}}while(0);t[b>>2]=t[(t[b>>2]|0)+4>>2]}t[o>>2]=lq(t[o>>2]|0)|0}t[l>>2]=t[w>>2]}}else d=9;while(0);e:do if((d|0)==9){t[o>>2]=t[c>>2];while(1){if(!(t[o>>2]|0))break e;t[b>>2]=t[(t[(t[u>>2]|0)+20>>2]|0)+40>>2];while(1){if(!(t[b>>2]|0))break;i:do if((Oj(t[(t[b>>2]|0)+20>>2]|0,t[o>>2]|0)|0)==1){t[k>>2]=t[(t[b>>2]|0)+16>>2];while(1){if(!(t[k>>2]|0))break i;cq(t[u>>2]|0,t[k>>2]|0,t[a>>2]|0,t[o>>2]|0,t[(t[b>>2]|0)+20>>2]|0)|0;t[k>>2]=t[t[k>>2]>>2]}}while(0);t[b>>2]=t[t[b>>2]>>2]}t[o>>2]=lq(t[o>>2]|0)|0}}while(0);t[f>>2]=t[(t[u>>2]|0)+12>>2];h=t[f>>2]|0;s=r;return h|0}t[f>>2]=-1;h=t[f>>2]|0;s=r;return h|0}function iq(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i+4|0;n=i;t[r>>2]=e;while(1){if(!(t[r>>2]|0))break;t[n>>2]=t[t[r>>2]>>2];if(t[(t[r>>2]|0)+16>>2]|0)bq(t[(t[r>>2]|0)+16>>2]|0);if(t[(t[r>>2]|0)+12>>2]|0)pAi[t[135736>>2]&511](t[(t[r>>2]|0)+12>>2]|0);if(t[(t[r>>2]|0)+20>>2]|0)vj(t[(t[r>>2]|0)+20>>2]|0);if(t[(t[r>>2]|0)+24>>2]|0)pAi[t[135736>>2]&511](t[(t[r>>2]|0)+24>>2]|0);pAi[t[135736>>2]&511](t[r>>2]|0);t[r>>2]=t[n>>2]}s=i;return}function rq(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i+4|0;n=i;t[r>>2]=e;while(1){if(!(t[r>>2]|0))break;t[n>>2]=t[t[r>>2]>>2];if(t[(t[r>>2]|0)+8>>2]|0)pAi[t[135736>>2]&511](t[(t[r>>2]|0)+8>>2]|0);pAi[t[135736>>2]&511](t[r>>2]|0);t[r>>2]=t[n>>2]}s=i;return}function nq(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0;n=s;s=s+16|0;f=n+8|0;u=n+4|0;a=n;t[f>>2]=e;t[u>>2]=i;t[a>>2]=r;if(t[f>>2]|0){r=(t[f>>2]|0)+28|0;t[r>>2]=(t[r>>2]|0)+1}dp(16,2,t[a>>2]|0,0,t[u>>2]|0);s=n;return}function fq(e,i,r,n,f,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;u=u|0;var a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0;a=s;s=s+48|0;o=a;c=a+40|0;l=a+36|0;b=a+32|0;k=a+28|0;h=a+24|0;w=a+20|0;d=a+16|0;v=a+12|0;m=a+8|0;t[c>>2]=e;t[l>>2]=i;t[b>>2]=r;t[k>>2]=n;t[h>>2]=f;t[w>>2]=u;t[d>>2]=0;t[v>>2]=0;t[m>>2]=0;if(t[c>>2]|0){u=(t[c>>2]|0)+28|0;t[u>>2]=(t[u>>2]|0)+1;t[d>>2]=t[(t[c>>2]|0)+72>>2];t[m>>2]=t[(t[c>>2]|0)+68>>2];t[v>>2]=t[(t[c>>2]|0)+80>>2]}u=t[v>>2]|0;v=t[d>>2]|0;d=t[m>>2]|0;m=t[c>>2]|0;c=t[l>>2]|0;l=t[b>>2]|0;b=t[h>>2]|0;f=t[w>>2]|0;n=t[k>>2]|0;k=t[w>>2]|0;t[o>>2]=t[h>>2];t[o+4>>2]=k;cp(u,v,d,m,c,16,l,2,0,0,b,f,0,0,0,n,o);s=a;return}function tq(e){e=e|0;var i=0,r=0,n=0,f=0,u=0,a=0;i=s;s=s+16|0;r=i+8|0;n=i+4|0;f=i;t[n>>2]=e;t[f>>2]=gAi[t[135744>>2]&511](56)|0;if(!(t[f>>2]|0)){nq(t[n>>2]|0,203040,0);t[r>>2]=0;u=t[r>>2]|0;s=i;return u|0}else{e=(t[f>>2]|0)+0|0;a=e+56|0;do{t[e>>2]=0;e=e+4|0}while((e|0)<(a|0));t[(t[f>>2]|0)+20>>2]=t[(t[n>>2]|0)+24>>2];sz(t[(t[f>>2]|0)+20>>2]|0)|0;t[r>>2]=t[f>>2];u=t[r>>2]|0;s=i;return u|0}return 0}function uq(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0;n=s;s=s+16|0;f=n+12|0;u=n+8|0;a=n+4|0;o=n;t[f>>2]=e;t[u>>2]=i;t[a>>2]=r;r=t[f>>2]|0;do if(t[(t[f>>2]|0)+52>>2]|0){if(((t[r+44>>2]|0)+2|0)>=(t[(t[f>>2]|0)+48>>2]|0)){t[o>>2]=MAi[t[135760>>2]&511](t[(t[f>>2]|0)+52>>2]|0,t[(t[f>>2]|0)+48>>2]<<2<<2)|0;if(t[o>>2]|0){t[(t[f>>2]|0)+52>>2]=t[o>>2];i=(t[f>>2]|0)+48|0;t[i>>2]=t[i>>2]<<1;break}nq(0,203008,0);s=n;return}}else{t[r+48>>2]=10;i=gAi[t[135744>>2]&511](t[(t[f>>2]|0)+48>>2]<<1<<2)|0;t[(t[f>>2]|0)+52>>2]=i;if(t[(t[f>>2]|0)+52>>2]|0){t[(t[f>>2]|0)+44>>2]=0;break}nq(0,203008,0);s=n;return}while(0);r=kz(t[(t[f>>2]|0)+24>>2]|0,t[a>>2]|0,-1)|0;t[(t[(t[f>>2]|0)+52>>2]|0)+(t[(t[f>>2]|0)+44>>2]<<1<<2)>>2]=r;r=kz(t[(t[f>>2]|0)+24>>2]|0,t[u>>2]|0,-1)|0;t[(t[(t[f>>2]|0)+52>>2]|0)+((t[(t[f>>2]|0)+44>>2]<<1)+1<<2)>>2]=r;r=(t[f>>2]|0)+44|0;t[r>>2]=(t[r>>2]|0)+1;t[(t[(t[f>>2]|0)+52>>2]|0)+(t[(t[f>>2]|0)+44>>2]<<1<<2)>>2]=0;t[(t[(t[f>>2]|0)+52>>2]|0)+((t[(t[f>>2]|0)+44>>2]<<1)+1<<2)>>2]=0;s=n;return}function aq(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0;r=s;s=s+32|0;n=r+20|0;f=r+16|0;u=r+12|0;a=r+8|0;o=r+4|0;c=r;t[n>>2]=e;t[f>>2]=i;t[o>>2]=0;if((t[n>>2]|0)==0|(t[f>>2]|0)==0){s=r;return}t[c>>2]=vF(t[f>>2]|0,202488)|0;if(!(t[c>>2]|0))t[c>>2]=vF(t[f>>2]|0,202464)|0;t[a>>2]=kq(t[n>>2]|0,t[(t[n>>2]|0)+40>>2]|0,t[f>>2]|0,t[c>>2]|0)|0;if(!(t[a>>2]|0)){if(!(t[c>>2]|0)){s=r;return}pAi[t[135736>>2]&511](t[c>>2]|0);s=r;return}t[u>>2]=t[(t[f>>2]|0)+12>>2];while(1){if(!(t[u>>2]|0))break;if((t[(t[u>>2]|0)+4>>2]|0)==1?(t[(t[u>>2]|0)+36>>2]|0)!=0:0){if(Xl(t[(t[(t[u>>2]|0)+36>>2]|0)+8>>2]|0,t[50504]|0)|0)break;if(Xl(t[(t[(t[u>>2]|0)+36>>2]|0)+8>>2]|0,t[50506]|0)|0)break}t[u>>2]=t[(t[u>>2]|0)+24>>2]}e:while(1){if(!(t[u>>2]|0))break;do if((((t[u>>2]|0)!=0?(t[(t[u>>2]|0)+4>>2]|0)==1:0)?(t[(t[u>>2]|0)+36>>2]|0)!=0:0)?(Xl(t[(t[u>>2]|0)+8>>2]|0,202496)|0)!=0:0){if((Xl(t[(t[(t[u>>2]|0)+36>>2]|0)+8>>2]|0,t[50504]|0)|0)==0?(Xl(t[(t[(t[u>>2]|0)+36>>2]|0)+8>>2]|0,t[50506]|0)|0)==0:0){l=22;break}hq(t[n>>2]|0,t[a>>2]|0,t[u>>2]|0);t[o>>2]=(t[o>>2]|0)+1}else l=22;while(0);if((l|0)==22){l=0;fq(t[n>>2]|0,t[u>>2]|0,1759,202504,t[(t[u>>2]|0)+8>>2]|0,0)}t[u>>2]=t[(t[u>>2]|0)+24>>2];while(1){if(!(t[u>>2]|0))continue e;if((t[(t[u>>2]|0)+4>>2]|0)==1?(t[(t[u>>2]|0)+36>>2]|0)!=0:0){if(Xl(t[(t[(t[u>>2]|0)+36>>2]|0)+8>>2]|0,t[50504]|0)|0)continue e;if(Xl(t[(t[(t[u>>2]|0)+36>>2]|0)+8>>2]|0,t[50506]|0)|0)continue e}t[u>>2]=t[(t[u>>2]|0)+24>>2]}}if(t[o>>2]|0){s=r;return}fq(t[n>>2]|0,t[f>>2]|0,1759,202544,0,0);s=r;return}function oq(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0;n=s;s=s+16|0;f=n+8|0;u=n+4|0;a=n;t[f>>2]=e;t[u>>2]=i;t[a>>2]=r;if(t[f>>2]|0){r=(t[f>>2]|0)+12|0;t[r>>2]=(t[r>>2]|0)+1;t[(t[f>>2]|0)+16>>2]=1818}dp(17,2,t[a>>2]|0,0,t[u>>2]|0);s=n;return}function cq(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;var a=0,o=0,c=0,b=0,k=0,h=0,w=0,d=0,v=0;a=s;s=s+32|0;o=a+24|0;c=a+20|0;b=a+16|0;k=a+12|0;h=a+8|0;w=a+4|0;d=a;t[o>>2]=e;t[c>>2]=i;t[b>>2]=r;t[k>>2]=n;t[h>>2]=f;t[d>>2]=0;t[t[(t[o>>2]|0)+24>>2]>>2]=t[b>>2];t[(t[(t[o>>2]|0)+24>>2]|0)+4>>2]=t[k>>2];t[w>>2]=_t(t[(t[c>>2]|0)+16>>2]|0,t[(t[o>>2]|0)+24>>2]|0)|0;if(!(t[w>>2]|0))t[d>>2]=1;else{e:do switch(t[t[w>>2]>>2]|0){case 4:{if((t[(t[w>>2]|0)+24>>2]|0)!=0?(u[t[(t[w>>2]|0)+24>>2]>>0]|0|0)!=0:0)break e;t[d>>2]=1;break}case 3:{if((hn(+l[(t[w>>2]|0)+16>>3])|0)==0?!(+l[(t[w>>2]|0)+16>>3]==0):0)break e;t[d>>2]=1;break}case 8:case 7:case 6:case 5:case 0:{t[d>>2]=1;break}case 2:{t[d>>2]=((t[(t[w>>2]|0)+8>>2]|0)!=0^1)&1;break}case 1:case 9:{if((t[(t[w>>2]|0)+4>>2]|0)!=0?(t[t[(t[w>>2]|0)+4>>2]>>2]|0)!=0:0)break e;t[d>>2]=1;break}default:{}}while(0);_n(t[w>>2]|0)}if((t[d>>2]|0)!=0?(t[(t[c>>2]|0)+4>>2]|0)==1:0){w=(t[o>>2]|0)+12|0;t[w>>2]=(t[w>>2]|0)+1}else v=19;if(((v|0)==19?(t[d>>2]|0)==0:0)?(t[(t[c>>2]|0)+4>>2]|0)==2:0){v=(t[o>>2]|0)+12|0;t[v>>2]=(t[v>>2]|0)+1}wq(t[o>>2]|0,t[c>>2]|0,t[k>>2]|0,t[h>>2]|0,((t[d>>2]|0)!=0^1)&1);s=a;return((t[d>>2]|0)!=0^1)&1|0}function lq(e){e=e|0;var i=0,r=0,n=0,f=0,u=0,a=0;i=s;s=s+16|0;r=i+4|0;n=i;t[n>>2]=e;if(((t[(t[n>>2]|0)+12>>2]|0)!=0?(t[(t[(t[n>>2]|0)+12>>2]|0)+4>>2]|0)!=17:0)?(t[n>>2]=t[(t[n>>2]|0)+12>>2],(t[(t[n>>2]|0)+4>>2]|0)!=14):0){t[r>>2]=t[n>>2];f=t[r>>2]|0;s=i;return f|0}while(1){if(!(t[(t[n>>2]|0)+24>>2]|0))break;t[n>>2]=t[(t[n>>2]|0)+24>>2];if((t[(t[n>>2]|0)+4>>2]|0)==17)continue;if((t[(t[n>>2]|0)+4>>2]|0)!=14){u=8;break}}if((u|0)==8){t[r>>2]=t[n>>2];f=t[r>>2]|0;s=i;return f|0}while(1){t[n>>2]=t[(t[n>>2]|0)+20>>2];if(!(t[n>>2]|0)){u=15;break}if((t[(t[n>>2]|0)+4>>2]|0)==9){u=11;break}a=t[n>>2]|0;if(t[(t[n>>2]|0)+24>>2]|0){u=13;break}if(!a){u=15;break}}if((u|0)==11){t[r>>2]=0;f=t[r>>2]|0;s=i;return f|0}else if((u|0)==13){t[n>>2]=t[a+24>>2];t[r>>2]=t[n>>2];f=t[r>>2]|0;s=i;return f|0}else if((u|0)==15){t[r>>2]=t[n>>2];f=t[r>>2]|0;s=i;return f|0}return 0}function sq(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0;r=s;s=s+1024|0;n=r;f=r+12|0;u=r+8|0;a=r+16|0;t[f>>2]=e;t[u>>2]=i;if((t[f>>2]|0)==0|(t[u>>2]|0)==0){s=r;return}if(t[(t[f>>2]|0)+4>>2]&1){s=r;return}if(t[(t[f>>2]|0)+4>>2]&8){s=r;return}if(t[(t[f>>2]|0)+4>>2]&4){i=t[33976]|0;e=t[33980]|0;t[n>>2]=202344;t[n+4>>2]=1457;yAi[i&511](e,202312,n);s=r;return}if(!(t[(t[u>>2]|0)+8>>2]|0)){s=r;return}t[n>>2]=t[(t[u>>2]|0)+8>>2];SY(a,999,202368,n)|0;dq(t[f>>2]|0,0,a);s=r;return}function bq(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i+4|0;n=i;t[r>>2]=e;while(1){if(!(t[r>>2]|0))break;t[n>>2]=t[t[r>>2]>>2];if(t[(t[r>>2]|0)+12>>2]|0)pAi[t[135736>>2]&511](t[(t[r>>2]|0)+12>>2]|0);if(t[(t[r>>2]|0)+16>>2]|0)mn(t[(t[r>>2]|0)+16>>2]|0);if(t[(t[r>>2]|0)+20>>2]|0)pAi[t[135736>>2]&511](t[(t[r>>2]|0)+20>>2]|0);pAi[t[135736>>2]&511](t[r>>2]|0);t[r>>2]=t[n>>2]}s=i;return}function kq(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0;f=s;s=s+32|0;u=f+24|0;a=f+20|0;o=f+16|0;c=f+12|0;l=f+8|0;b=f+4|0;k=f;t[a>>2]=e;t[o>>2]=i;t[c>>2]=r;t[l>>2]=n;if((t[a>>2]|0)==0|(t[o>>2]|0)==0|(t[c>>2]|0)==0|(t[l>>2]|0)==0){t[u>>2]=0;h=t[u>>2]|0;s=f;return h|0}t[b>>2]=gAi[t[135744>>2]&511](12)|0;if(!(t[b>>2]|0)){nq(t[a>>2]|0,202976,t[c>>2]|0);t[u>>2]=0;h=t[u>>2]|0;s=f;return h|0}c=t[b>>2]|0;t[c+0>>2]=0;t[c+4>>2]=0;t[c+8>>2]=0;t[(t[b>>2]|0)+8>>2]=t[l>>2];t[t[b>>2]>>2]=0;if(!(t[(t[o>>2]|0)+36>>2]|0))t[(t[o>>2]|0)+36>>2]=t[b>>2];else{t[k>>2]=t[(t[o>>2]|0)+36>>2];while(1){if(!(t[t[k>>2]>>2]|0))break;t[k>>2]=t[t[k>>2]>>2]}t[t[k>>2]>>2]=t[b>>2]}t[u>>2]=t[b>>2];h=t[u>>2]|0;s=f;return h|0}function hq(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0;n=s;s=s+48|0;f=n+36|0;a=n+32|0;o=n+28|0;c=n+24|0;l=n+20|0;b=n+16|0;k=n+12|0;h=n+8|0;w=n+4|0;d=n;t[f>>2]=e;t[a>>2]=i;t[o>>2]=r;t[l>>2]=0;if((t[f>>2]|0)==0|(t[o>>2]|0)==0){s=n;return}t[k>>2]=vF(t[o>>2]|0,202576)|0;if(!(t[k>>2]|0)){fq(t[f>>2]|0,t[o>>2]|0,1759,202584,0,0);s=n;return}r=t[f>>2]|0;if(!(u[t[k>>2]>>0]|0)){fq(r,t[o>>2]|0,1759,202616,0,0);pAi[t[135736>>2]&511](t[k>>2]|0);s=n;return}t[w>>2]=vq(r,t[(t[f>>2]|0)+40>>2]|0,t[a>>2]|0,t[o>>2]|0,t[k>>2]|0,0)|0;if(!(t[w>>2]|0)){pAi[t[135736>>2]&511](t[k>>2]|0);s=n;return}t[c>>2]=t[(t[o>>2]|0)+12>>2];while(1){if(!(t[c>>2]|0))break;if((t[(t[c>>2]|0)+4>>2]|0)==1?(t[(t[c>>2]|0)+36>>2]|0)!=0:0){if(Xl(t[(t[(t[c>>2]|0)+36>>2]|0)+8>>2]|0,t[50504]|0)|0)break;if(Xl(t[(t[(t[c>>2]|0)+36>>2]|0)+8>>2]|0,t[50506]|0)|0)break}t[c>>2]=t[(t[c>>2]|0)+24>>2]}e:while(1){if(!(t[c>>2]|0))break;do if((((t[c>>2]|0)!=0?(t[(t[c>>2]|0)+4>>2]|0)==1:0)?(t[(t[c>>2]|0)+36>>2]|0)!=0:0)?(Xl(t[(t[c>>2]|0)+8>>2]|0,202656)|0)!=0:0){if((Xl(t[(t[(t[c>>2]|0)+36>>2]|0)+8>>2]|0,t[50504]|0)|0)==0?(Xl(t[(t[(t[c>>2]|0)+36>>2]|0)+8>>2]|0,t[50506]|0)|0)==0:0){v=28;break}t[l>>2]=(t[l>>2]|0)+1;t[b>>2]=vF(t[c>>2]|0,202664)|0;if(!(t[b>>2]|0)){fq(t[f>>2]|0,t[c>>2]|0,1759,202672,0,0);break}if(!(u[t[b>>2]>>0]|0)){fq(t[f>>2]|0,t[c>>2]|0,1759,202704,0,0);pAi[t[135736>>2]&511](t[b>>2]|0);break}t[h>>2]=sF(t[c>>2]|0)|0;t[d>>2]=mq(t[f>>2]|0,1,t[w>>2]|0,t[c>>2]|0,t[b>>2]|0,t[h>>2]|0)|0;if(!(t[d>>2]|0))pAi[t[135736>>2]&511](t[b>>2]|0)}else v=28;while(0);i:do if((v|0)==28){v=0;do if((((t[c>>2]|0)!=0?(t[(t[c>>2]|0)+4>>2]|0)==1:0)?(t[(t[c>>2]|0)+36>>2]|0)!=0:0)?(Xl(t[(t[c>>2]|0)+8>>2]|0,202744)|0)!=0:0){if((Xl(t[(t[(t[c>>2]|0)+36>>2]|0)+8>>2]|0,t[50504]|0)|0)==0?(Xl(t[(t[(t[c>>2]|0)+36>>2]|0)+8>>2]|0,t[50506]|0)|0)==0:0)break;t[l>>2]=(t[l>>2]|0)+1;t[b>>2]=vF(t[c>>2]|0,202664)|0;if(!(t[b>>2]|0)){fq(t[f>>2]|0,t[c>>2]|0,1759,202672,0,0);break i}if(!(u[t[b>>2]>>0]|0)){fq(t[f>>2]|0,t[c>>2]|0,1759,202704,0,0);pAi[t[135736>>2]&511](t[b>>2]|0);break i}t[h>>2]=sF(t[c>>2]|0)|0;t[d>>2]=mq(t[f>>2]|0,2,t[w>>2]|0,t[c>>2]|0,t[b>>2]|0,t[h>>2]|0)|0;if(t[d>>2]|0)break i;pAi[t[135736>>2]&511](t[b>>2]|0);break i}while(0);fq(t[f>>2]|0,t[c>>2]|0,1759,202752,t[(t[c>>2]|0)+8>>2]|0,0)}while(0);t[c>>2]=t[(t[c>>2]|0)+24>>2];while(1){if(!(t[c>>2]|0))continue e;if((t[(t[c>>2]|0)+4>>2]|0)==1?(t[(t[c>>2]|0)+36>>2]|0)!=0:0){if(Xl(t[(t[(t[c>>2]|0)+36>>2]|0)+8>>2]|0,t[50504]|0)|0)continue e;if(Xl(t[(t[(t[c>>2]|0)+36>>2]|0)+8>>2]|0,t[50506]|0)|0)continue e}t[c>>2]=t[(t[c>>2]|0)+24>>2]}}if(t[l>>2]|0){s=n;return}fq(t[f>>2]|0,t[o>>2]|0,1759,202808,0,0);s=n;return}function wq(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;var u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0;u=s;s=s+1056|0;a=u;o=u+52|0;c=u+48|0;l=u+44|0;b=u+40|0;k=u+36|0;h=u+32|0;w=u+56|0;d=u+28|0;v=u+24|0;m=u+20|0;_=u+16|0;p=u+12|0;t[o>>2]=e;t[c>>2]=i;t[l>>2]=r;t[b>>2]=n;t[k>>2]=f;if((t[o>>2]|0)==0|(t[l>>2]|0)==0|(t[c>>2]|0)==0){s=u;return}if(((t[(t[o>>2]|0)+4>>2]&1|0)!=0?(t[(t[o>>2]|0)+4>>2]&4|0)==0:0)?(t[(t[c>>2]|0)+4>>2]|0)==2:0){s=u;return}if(t[(t[o>>2]|0)+4>>2]&4){f=t[33976]|0;n=t[33980]|0;t[a>>2]=202344;t[a+4>>2]=1380;yAi[f&511](n,202312,a);s=u;return}t[v>>2]=0;if((t[(t[c>>2]|0)+4>>2]|0)==2&(((t[k>>2]|0)!=0^1)&1)){s=u;return}if((t[(t[c>>2]|0)+4>>2]|0)==1&t[k>>2]){s=u;return}t[d>>2]=Qy(t[l>>2]|0)|0;t[h>>2]=$y(t[l>>2]|0)|0;if(!(t[h>>2]|0))t[h>>2]=t[(t[l>>2]|0)+8>>2];if(t[(t[c>>2]|0)+8>>2]|0)t[v>>2]=_q(t[o>>2]|0,t[(t[c>>2]|0)+8>>2]|0,t[l>>2]|0)|0;do if(!(t[v>>2]|0))if((t[(t[c>>2]|0)+4>>2]|0)==1){t[v>>2]=Yl(202392)|0;break}else{t[v>>2]=Yl(202416)|0;break}while(0);k=t[d>>2]|0;n=t[v>>2]|0;t[a>>2]=t[h>>2];t[a+4>>2]=k;t[a+8>>2]=n;SY(w,999,202440,a)|0;if(t[(t[o>>2]|0)+4>>2]&8){t[m>>2]=0;t[_>>2]=0;t[p>>2]=0;if(t[o>>2]|0){n=t[o>>2]|0;if(t[(t[o>>2]|0)+60>>2]|0)t[m>>2]=t[n+60>>2];else t[_>>2]=t[n+52>>2];t[p>>2]=t[(t[o>>2]|0)+48>>2]}n=t[m>>2]|0;m=t[_>>2]|0;_=t[p>>2]|0;p=t[l>>2]|0;k=(t[(t[c>>2]|0)+4>>2]|0)==1?4e3:4001;c=t[d>>2]|0;if(!(t[b>>2]|0))E=0;else E=t[(t[b>>2]|0)+8>>2]|0;b=t[h>>2]|0;d=t[v>>2]|0;t[a>>2]=w;cp(n,m,_,0,p,28,k,2,0,c,E,b,d,0,0,202384,a)}else dq(t[o>>2]|0,t[l>>2]|0,w);pAi[t[135736>>2]&511](t[v>>2]|0);if(!(t[h>>2]|0)){s=u;return}if((t[h>>2]|0)==(t[(t[l>>2]|0)+8>>2]|0)){s=u;return}pAi[t[135736>>2]&511](t[h>>2]|0);s=u;return}function dq(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0;n=s;s=s+16|0;f=n;u=n+4|0;t[n+12>>2]=e;t[n+8>>2]=i;t[u>>2]=r;r=t[v>>2]|0;t[f>>2]=t[u>>2];xe(r|0,202384,f|0)|0;s=n;return}function vq(e,i,r,n,f,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;u=u|0;var a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0;a=s;s=s+48|0;o=a+40|0;c=a+36|0;l=a+32|0;b=a+28|0;k=a+24|0;h=a+20|0;w=a+16|0;d=a+12|0;v=a+8|0;m=a+4|0;_=a;t[c>>2]=e;t[l>>2]=i;t[b>>2]=r;t[k>>2]=n;t[h>>2]=f;t[w>>2]=u;if((t[c>>2]|0)==0|(t[l>>2]|0)==0|(t[k>>2]|0)==0|(t[h>>2]|0)==0){t[o>>2]=0;p=t[o>>2]|0;s=a;return p|0}t[v>>2]=Fj(t[h>>2]|0,t[(t[c>>2]|0)+24>>2]|0,1,t[(t[c>>2]|0)+52>>2]|0)|0;if(!(t[v>>2]|0))fq(t[c>>2]|0,t[k>>2]|0,1759,202912,t[h>>2]|0,0);t[d>>2]=gAi[t[135744>>2]&511](28)|0;if(!(t[d>>2]|0)){nq(t[c>>2]|0,202952,t[k>>2]|0);t[o>>2]=0;p=t[o>>2]|0;s=a;return p|0}c=t[d>>2]|0;t[c+0>>2]=0;t[c+4>>2]=0;t[c+8>>2]=0;t[c+12>>2]=0;t[c+16>>2]=0;t[c+20>>2]=0;t[c+24>>2]=0;t[(t[d>>2]|0)+8>>2]=t[k>>2];t[(t[d>>2]|0)+12>>2]=t[h>>2];t[(t[d>>2]|0)+20>>2]=t[v>>2];t[(t[d>>2]|0)+24>>2]=t[w>>2];t[t[d>>2]>>2]=0;if(!(t[(t[l>>2]|0)+40>>2]|0))t[(t[l>>2]|0)+40>>2]=t[d>>2];else{t[m>>2]=t[(t[l>>2]|0)+40>>2];while(1){if(!(t[t[m>>2]>>2]|0))break;t[m>>2]=t[t[m>>2]>>2]}t[t[m>>2]>>2]=t[d>>2]}t[(t[d>>2]|0)+4>>2]=0;if(!(t[(t[b>>2]|0)+4>>2]|0))t[(t[b>>2]|0)+4>>2]=t[d>>2];else{t[_>>2]=t[(t[b>>2]|0)+4>>2];while(1){if(!(t[(t[_>>2]|0)+4>>2]|0))break;t[_>>2]=t[(t[_>>2]|0)+4>>2]}t[(t[_>>2]|0)+4>>2]=t[d>>2]}t[o>>2]=t[d>>2];p=t[o>>2]|0;s=a;return p|0}function mq(e,i,r,n,f,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;u=u|0;var a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0;a=s;s=s+48|0;o=a+36|0;c=a+32|0;l=a+28|0;b=a+24|0;k=a+20|0;h=a+16|0;w=a+12|0;d=a+8|0;v=a+4|0;m=a;t[c>>2]=e;t[l>>2]=i;t[b>>2]=r;t[k>>2]=n;t[h>>2]=f;t[w>>2]=u;if((t[c>>2]|0)==0|(t[b>>2]|0)==0|(t[k>>2]|0)==0|(t[h>>2]|0)==0){t[o>>2]=0;_=t[o>>2]|0;s=a;return _|0}t[v>>2]=mt(t[(t[c>>2]|0)+36>>2]|0,t[h>>2]|0)|0;if(!(t[v>>2]|0)){fq(t[c>>2]|0,t[k>>2]|0,1759,202848,t[h>>2]|0,0);t[o>>2]=0;_=t[o>>2]|0;s=a;return _|0}t[d>>2]=gAi[t[135744>>2]&511](24)|0;if(!(t[d>>2]|0)){nq(t[c>>2]|0,202888,t[k>>2]|0);t[o>>2]=0;_=t[o>>2]|0;s=a;return _|0}c=t[d>>2]|0;t[c+0>>2]=0;t[c+4>>2]=0;t[c+8>>2]=0;t[c+12>>2]=0;t[c+16>>2]=0;t[c+20>>2]=0;t[(t[d>>2]|0)+4>>2]=t[l>>2];t[(t[d>>2]|0)+8>>2]=t[k>>2];t[(t[d>>2]|0)+12>>2]=t[h>>2];t[(t[d>>2]|0)+16>>2]=t[v>>2];t[(t[d>>2]|0)+20>>2]=t[w>>2];t[t[d>>2]>>2]=0;if(!(t[(t[b>>2]|0)+16>>2]|0))t[(t[b>>2]|0)+16>>2]=t[d>>2];else{t[m>>2]=t[(t[b>>2]|0)+16>>2];while(1){if(!(t[t[m>>2]>>2]|0))break;t[m>>2]=t[t[m>>2]>>2]}t[t[m>>2]>>2]=t[d>>2]}t[o>>2]=t[d>>2];_=t[o>>2]|0;s=a;return _|0}function _q(e,i,r){e=e|0;i=i|0;r=r|0;var f=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0;f=s;s=s+48|0;a=f+32|0;o=f+28|0;c=f+24|0;l=f+20|0;b=f+16|0;k=f+12|0;h=f+8|0;w=f+4|0;d=f;v=f+36|0;t[o>>2]=e;t[c>>2]=i;t[l>>2]=r;t[b>>2]=0;if((t[c>>2]|0)==0|(t[l>>2]|0)==0){t[a>>2]=t[b>>2];m=t[a>>2]|0;s=f;return m|0}t[k>>2]=t[(t[c>>2]|0)+12>>2];e:while(1){if(!(t[k>>2]|0))break;i:do if((t[(t[k>>2]|0)+4>>2]|0)!=3?(t[(t[k>>2]|0)+4>>2]|0)!=4:0){do if((((t[k>>2]|0)!=0?(t[(t[k>>2]|0)+4>>2]|0)==1:0)?(t[(t[k>>2]|0)+36>>2]|0)!=0:0)?(Xl(t[(t[k>>2]|0)+8>>2]|0,202464)|0)!=0:0){if((Xl(t[(t[(t[k>>2]|0)+36>>2]|0)+8>>2]|0,t[50504]|0)|0)==0?(Xl(t[(t[(t[k>>2]|0)+36>>2]|0)+8>>2]|0,t[50506]|0)|0)==0:0)break;t[w>>2]=vF(t[k>>2]|0,202472)|0;t[h>>2]=t[l>>2];if(t[w>>2]|0){t[h>>2]=pq(t[o>>2]|0,t[l>>2]|0,t[w>>2]|0)|0;if(!(t[h>>2]|0))t[h>>2]=t[l>>2];pAi[t[135736>>2]&511](t[w>>2]|0)}if((t[(t[h>>2]|0)+36>>2]|0)!=0?(t[(t[(t[h>>2]|0)+36>>2]|0)+12>>2]|0)!=0:0){t[b>>2]=us(t[b>>2]|0,t[(t[(t[h>>2]|0)+36>>2]|0)+12>>2]|0)|0;t[b>>2]=us(t[b>>2]|0,202480)|0;t[b>>2]=us(t[b>>2]|0,t[(t[h>>2]|0)+8>>2]|0)|0;break i}t[b>>2]=us(t[b>>2]|0,t[(t[h>>2]|0)+8>>2]|0)|0;break i}while(0);t[k>>2]=t[(t[k>>2]|0)+24>>2];continue e}else _=7;while(0);if((_|0)==7){_=0;t[b>>2]=us(t[b>>2]|0,t[(t[k>>2]|0)+40>>2]|0)|0}do if((t[b>>2]|0)!=0?(t[d>>2]=rs(t[b>>2]|0)|0,(t[d>>2]|0)>0):0){n[v>>0]=n[(t[b>>2]|0)+((t[d>>2]|0)-1)>>0]|0;if((((u[v>>0]|0|0)!=32?(u[v>>0]|0|0)!=10:0)?(u[v>>0]|0|0)!=13:0)?(u[v>>0]|0|0)!=9:0)break;while(1){if((((u[v>>0]|0|0)!=32?(u[v>>0]|0|0)!=10:0)?(u[v>>0]|0|0)!=13:0)?(u[v>>0]|0|0)!=9:0)break;t[d>>2]=(t[d>>2]|0)+-1;if(!(t[d>>2]|0))break;n[v>>0]=n[(t[b>>2]|0)+((t[d>>2]|0)-1)>>0]|0}n[(t[b>>2]|0)+(t[d>>2]|0)>>0]=32;n[(t[b>>2]|0)+((t[d>>2]|0)+1)>>0]=0}while(0);t[k>>2]=t[(t[k>>2]|0)+24>>2]}t[a>>2]=t[b>>2];m=t[a>>2]|0;s=f;return m|0}function pq(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0;n=s;s=s+32|0;f=n+20|0;u=n+16|0;a=n+12|0;o=n+8|0;c=n+4|0;l=n;t[u>>2]=e;t[a>>2]=i;t[o>>2]=r;t[c>>2]=0;if((t[u>>2]|0)==0|(t[a>>2]|0)==0|(t[o>>2]|0)==0){t[f>>2]=0;b=t[f>>2]|0;s=n;return b|0}t[t[(t[u>>2]|0)+24>>2]>>2]=t[(t[a>>2]|0)+32>>2];t[(t[(t[u>>2]|0)+24>>2]|0)+4>>2]=t[a>>2];t[l>>2]=Et(t[o>>2]|0,t[(t[u>>2]|0)+24>>2]|0)|0;if(!(t[l>>2]|0)){t[f>>2]=0;b=t[f>>2]|0;s=n;return b|0}if(((t[t[l>>2]>>2]|0)==1?(t[(t[l>>2]|0)+4>>2]|0)!=0:0)?(t[t[(t[l>>2]|0)+4>>2]>>2]|0)>0:0)t[c>>2]=t[t[(t[(t[l>>2]|0)+4>>2]|0)+8>>2]>>2];_n(t[l>>2]|0);t[f>>2]=t[c>>2];b=t[f>>2]|0;s=n;return b|0}function Eq(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0;r=s;s=s+32|0;n=r;f=r+16|0;u=r+12|0;a=r+8|0;o=r+4|0;t[u>>2]=e;t[a>>2]=i;i=gAi[t[135744>>2]&511](12)|0;t[o>>2]=i;if(!i){yAi[t[135904>>2]&511](t[33980]|0,203144,n);t[f>>2]=0;c=t[f>>2]|0;s=r;return c|0}i=t[o>>2]|0;t[i+0>>2]=0;t[i+4>>2]=0;t[i+8>>2]=0;i=gAi[t[135744>>2]&511](12)|0;t[t[o>>2]>>2]=i;if(!i){yAi[t[135904>>2]&511](t[33980]|0,203184,n);pAi[t[135736>>2]&511](t[o>>2]|0);t[f>>2]=0;c=t[f>>2]|0;s=r;return c|0}t[t[t[o>>2]>>2]>>2]=t[t[o>>2]>>2];t[(t[t[o>>2]>>2]|0)+4>>2]=t[t[o>>2]>>2];t[(t[t[o>>2]>>2]|0)+8>>2]=0;if(t[u>>2]|0)t[(t[o>>2]|0)+4>>2]=t[u>>2];if(t[a>>2]|0)t[(t[o>>2]|0)+8>>2]=t[a>>2];else t[(t[o>>2]|0)+8>>2]=390;t[f>>2]=t[o>>2];c=t[f>>2]|0;s=r;return c|0}function Sq(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0;r=s;s=s+16|0;n=r+12|0;f=r+8|0;u=r+4|0;a=r;t[f>>2]=e;t[u>>2]=i;do if(t[f>>2]|0){t[a>>2]=Nq(t[f>>2]|0,t[u>>2]|0)|0;if(t[a>>2]|0){t[n>>2]=t[(t[a>>2]|0)+8>>2];break}else{t[n>>2]=0;break}}else t[n>>2]=0;while(0);s=r;return t[n>>2]|0}function gq(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0;r=s;s=s+32|0;n=r+20|0;f=r+16|0;u=r+12|0;a=r+8|0;o=r+4|0;t[f>>2]=e;t[u>>2]=i;if(!(t[f>>2]|0)){t[n>>2]=1;c=t[n>>2]|0;s=r;return c|0}t[a>>2]=Tq(t[f>>2]|0,t[u>>2]|0)|0;t[o>>2]=gAi[t[135744>>2]&511](12)|0;if(!(t[o>>2]|0)){yAi[t[135904>>2]&511](t[33980]|0,203224,r);t[n>>2]=1;c=t[n>>2]|0;s=r;return c|0}else{t[(t[o>>2]|0)+8>>2]=t[u>>2];t[a>>2]=t[(t[a>>2]|0)+4>>2];t[t[o>>2]>>2]=t[t[a>>2]>>2];t[(t[t[a>>2]>>2]|0)+4>>2]=t[o>>2];t[t[a>>2]>>2]=t[o>>2];t[(t[o>>2]|0)+4>>2]=t[a>>2];t[n>>2]=0;c=t[n>>2]|0;s=r;return c|0}return 0}function yq(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0;r=s;s=s+32|0;n=r+20|0;f=r+16|0;u=r+12|0;a=r+8|0;o=r+4|0;t[f>>2]=e;t[u>>2]=i;if(!(t[f>>2]|0)){t[n>>2]=1;c=t[n>>2]|0;s=r;return c|0}t[a>>2]=Lq(t[f>>2]|0,t[u>>2]|0)|0;t[o>>2]=gAi[t[135744>>2]&511](12)|0;if(!(t[o>>2]|0)){yAi[t[135904>>2]&511](t[33980]|0,203224,r);t[n>>2]=1;c=t[n>>2]|0;s=r;return c|0}else{t[(t[o>>2]|0)+8>>2]=t[u>>2];t[t[o>>2]>>2]=t[t[a>>2]>>2];t[(t[t[a>>2]>>2]|0)+4>>2]=t[o>>2];t[t[a>>2]>>2]=t[o>>2];t[(t[o>>2]|0)+4>>2]=t[a>>2];t[n>>2]=0;c=t[n>>2]|0;s=r;return c|0}return 0}function Fq(e){e=e|0;var i=0,r=0;i=s;s=s+16|0;r=i;t[r>>2]=e;if(!(t[r>>2]|0)){s=i;return}Oq(t[r>>2]|0);pAi[t[135736>>2]&511](t[t[r>>2]>>2]|0);pAi[t[135736>>2]&511](t[r>>2]|0);s=i;return}function Oq(e){e=e|0;var i=0,r=0,n=0,f=0;i=s;s=s+16|0;r=i+8|0;n=i+4|0;f=i;t[r>>2]=e;if(!(t[r>>2]|0)){s=i;return}t[n>>2]=t[t[t[r>>2]>>2]>>2];while(1){if((t[n>>2]|0)==(t[t[r>>2]>>2]|0))break;t[f>>2]=t[t[n>>2]>>2];Dq(t[r>>2]|0,t[n>>2]|0);t[n>>2]=t[f>>2]}s=i;return}function Aq(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i+4|0;n=i;t[n>>2]=e;if(!(t[n>>2]|0))t[r>>2]=0;else t[r>>2]=t[(t[n>>2]|0)+8>>2];s=i;return t[r>>2]|0}function Mq(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0;n=s;s=s+16|0;f=n+12|0;u=n+8|0;a=n+4|0;o=n;t[f>>2]=e;t[u>>2]=i;t[a>>2]=r;if((t[f>>2]|0)==0|(t[u>>2]|0)==0){s=n;return}t[o>>2]=t[t[t[f>>2]>>2]>>2];while(1){if((t[o>>2]|0)==(t[t[f>>2]>>2]|0)){c=6;break}if(!(MAi[t[u>>2]&511](t[(t[o>>2]|0)+8>>2]|0,t[a>>2]|0)|0)){c=6;break}t[o>>2]=t[t[o>>2]>>2]}if((c|0)==6){s=n;return}}function Rq(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0;r=s;s=s+16|0;n=r+8|0;f=r+4|0;u=r;t[f>>2]=e;t[u>>2]=i;do if((t[f>>2]|0)>>>0>=(t[u>>2]|0)>>>0)if((t[f>>2]|0)==(t[u>>2]|0)){t[n>>2]=0;break}else{t[n>>2]=1;break}else t[n>>2]=-1;while(0);s=r;return t[n>>2]|0}function Nq(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0;r=s;s=s+16|0;n=r+12|0;f=r+8|0;u=r+4|0;a=r;t[f>>2]=e;t[u>>2]=i;do if(t[f>>2]|0){t[a>>2]=Tq(t[f>>2]|0,t[u>>2]|0)|0;if((t[a>>2]|0)==(t[t[f>>2]>>2]|0)){t[n>>2]=0;break}if(!(MAi[t[(t[f>>2]|0)+8>>2]&511](t[(t[a>>2]|0)+8>>2]|0,t[u>>2]|0)|0)){t[n>>2]=t[a>>2];break}else{t[n>>2]=0;break}}else t[n>>2]=0;while(0);s=r;return t[n>>2]|0}function Tq(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0;r=s;s=s+16|0;n=r+12|0;f=r+8|0;u=r+4|0;a=r;t[f>>2]=e;t[u>>2]=i;if(!(t[f>>2]|0)){t[n>>2]=0;o=t[n>>2]|0;s=r;return o|0}t[a>>2]=t[t[t[f>>2]>>2]>>2];while(1){if((t[a>>2]|0)==(t[t[f>>2]>>2]|0))break;if((MAi[t[(t[f>>2]|0)+8>>2]&511](t[(t[a>>2]|0)+8>>2]|0,t[u>>2]|0)|0)>=0)break;t[a>>2]=t[t[a>>2]>>2]}t[n>>2]=t[a>>2];o=t[n>>2]|0;s=r;return o|0}function Lq(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0;r=s;s=s+16|0;n=r+12|0;f=r+8|0;u=r+4|0;a=r;t[f>>2]=e;t[u>>2]=i;if(!(t[f>>2]|0)){t[n>>2]=0;o=t[n>>2]|0;s=r;return o|0}t[a>>2]=t[(t[t[f>>2]>>2]|0)+4>>2];while(1){if((t[a>>2]|0)==(t[t[f>>2]>>2]|0))break;if((MAi[t[(t[f>>2]|0)+8>>2]&511](t[(t[a>>2]|0)+8>>2]|0,t[u>>2]|0)|0)<=0)break;t[a>>2]=t[(t[a>>2]|0)+4>>2]}t[n>>2]=t[a>>2];o=t[n>>2]|0;s=r;return o|0}function Dq(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0;r=s;s=s+16|0;n=r+4|0;f=r;t[n>>2]=e;t[f>>2]=i;t[t[(t[f>>2]|0)+4>>2]>>2]=t[t[f>>2]>>2];t[(t[t[f>>2]>>2]|0)+4>>2]=t[(t[f>>2]|0)+4>>2];if(!(t[(t[n>>2]|0)+4>>2]|0)){u=t[33934]|0;a=t[f>>2]|0;pAi[u&511](a);s=r;return}pAi[t[(t[n>>2]|0)+4>>2]&511](t[f>>2]|0);u=t[33934]|0;a=t[f>>2]|0;pAi[u&511](a);s=r;return}function Cq(e){e=e|0;return(e+-97|0)>>>0<26|0}function Pq(e){e=e|0;var i=0,r=0;i=s;r=(Cq(e)|0)==0;s=i;return(r?e:e&95)|0}function Bq(e,i){e=e|0;i=i|0;var r=0,n=0,f=0;r=s;n=Wq(e)|0;if(((n|0)!=-1?(e=Wq(i)|0,(e|0)!=-1):0)?(u[203264+n>>0]|0)<=207:0){f=e<<16|n;s=r;return f|0}t[(ii()|0)>>2]=22;f=-1;s=r;return f|0}function Iq(e){e=e|0;return 0}function Hq(e,i,r,o,c){e=e|0;i=i|0;r=r|0;o=o|0;c=c|0;var l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0,S=0,g=0,y=0,F=0,O=0,A=0,M=0,R=0,N=0,T=0,L=0,D=0,C=0,P=0,B=0,I=0,H=0,x=0,U=0,z=0,j=0,V=0,q=0,Y=0,G=0,W=0,K=0,X=0,Z=0,J=0,Q=0,$=0,ee=0,ie=0,re=0,ne=0,fe=0,te=0,ue=0,ae=0,oe=0,ce=0,le=0,se=0,be=0,ke=0,he=0,we=0,de=0,ve=0,me=0,_e=0,pe=0,Ee=0,Se=0,ge=0,ye=0,Fe=0,Oe=0,Ae=0,Me=0,Re=0,Ne=0,Te=0,Le=0,De=0,Ce=0;l=s;s=s+32|0;b=l;k=l+16|0;h=l+12|0;w=l+8|0;d=l+20|0;v=e;e=v&65535;m=v>>>16;v=m+1|0;_=e+1|0;p=b;t[p>>2]=0;t[p+4>>2]=0;p=n[203264+m>>0]|0;E=n[203264+e>>0]|0;if(!i){S=0;s=l;return S|0}g=t[i>>2]|0;if(!g){S=0;s=l;return S|0}y=t[r>>2]|0;if(!y){S=0;s=l;return S|0}F=p&255;O=F+128|0;A=m+2|0;m=F&3;M=m^1;R=m^2;N=m^3;T=F&1;L=T^1;D=(F&254|0)==196;C=T|2;P=L|2;B=p<<24>>24==-38;I=p<<24>>24==-40;H=E&255;x=H+-192|0;U=x>>>0>8;z=e;j=281312+x|0;x=H+128|0;V=128-H|0;q=E<<24>>24==-128;E=e+2|0;e=(p&-2)<<24>>24==-60;p=H&1;Y=p^1;G=p|2;W=Y|2;K=H&3;X=K^1;Z=K^2;J=K^3;Q=(F+-192|0)>>>0<7;$=g;g=y;y=0;e:while(1){ee=n[$>>0]|0;ie=ee&255;i:do if(ee<<24>>24<0|Q){do switch(F|0){case 208:{if(g>>>0<2){re=22;break e}ne=u[$+1>>0]|0;if(ee<<24>>24!=-114){fe=ie+-161|0;te=ne+-161|0;if(fe>>>0>83|te>>>0>93){ue=84;ae=114;break e}oe=f[207296+(fe*188|0)+(te<<1)>>1]|0;if(!(oe<<16>>16)){ue=84;ae=114;break e}else{ce=oe&65535;le=2;ae=89;break i}}else{if((ne+-161|0)>>>0>62){ue=84;ae=114;break e}ce=ne+65216|0;le=2;ae=89;break i}break}case 198:{if(g>>>0<4){re=22;break e}se=t[$>>2]|0;ae=14;break}case 200:{ne=xq(k,$,g,b)|0;if(!ne)be=1;else if((ne|0)==-1){ue=84;ae=114;break e}else if((ne|0)==-2){re=22;break e}else be=ne;ce=t[k>>2]|0;le=be;ae=89;break i;break}case 224:{if(g>>>0<2){re=22;break e}ne=u[$+1>>0]|0;oe=ne+-64|0;if(oe>>>0>190|(ne+-127|0)>>>0<34){ue=84;ae=114;break e}te=oe>>>0>62?ne+-98|0:oe;oe=ie+-161|0;if(oe>>>0<=88){ne=a[281352+(oe*314|0)+(te<<1)>>1]|0;if((oe|0)==39?(te|0)==66|(te|0)==58|(te|0)==60:0)ke=131072;else ke=0;oe=ke|ne;if(!oe){ue=84;ae=114;break e}else{ce=oe;le=2;ae=89;break i}}oe=ie+-135|0;if(oe>>>0>119){ue=84;ae=114;break e}ne=te+(((ee&255)<161?oe:ie+-224|0)*157|0)|0;oe=a[270968+(ne<<1)>>1]|0;te=oe|(((a[270968+((ne>>>4)+4867<<1)>>1]|0)>>>(ne&15)|0)%2|0)<<17;if((te&-65792|0)!=56320)if(!te){ue=84;ae=114;break e}else{ce=te;le=2;ae=89;break i}if(U)he=2;else he=n[j>>0]|0;if(he>>>0>(t[c>>2]|0)>>>0){ue=7;ae=114;break e}t[h>>2]=281328+(oe&255);t[w>>2]=4;we=2;de=(Hq(z,h,w,o,c)|0)+y|0;break i;break}case 218:{if((ee&255)<161){ue=84;ae=114;break e}break}case 216:case 217:break;case 193:case 194:case 197:case 196:{if(g>>>0<2){re=22;break e}oe=u[$+T>>0]<<8;te=oe|u[$+L>>0];ne=oe&64512;if((ne|0)==56320){ue=84;ae=114;break e}else if((ne|0)!=55296){ce=te;le=2;ae=89;break i}if(D){ue=84;ae=114;break e}if(g>>>0<4){re=22;break e}ne=(u[$+C>>0]<<8|u[$+P>>0])+-56320|0;if(ne>>>0>1023){ue=84;ae=114;break e}ce=(te<<10)+-56557568+ne|0;le=4;ae=89;break i;break}case 195:case 192:{if(g>>>0<4){re=22;break e}se=u[$+M>>0]<<16|u[$+m>>0]<<24|u[$+R>>0]<<8|u[$+N>>0];ae=14;break}case 232:{if(g>>>0<2){re=22;break e}ne=n[$+1>>0]|0;te=ne&255;oe=ie+-161|0;fe=te+-161|0;if(!(oe>>>0>92|fe>>>0>93)){ve=f[309304+(oe*188|0)+(fe<<1)>>1]|0;if(!(ve<<16>>16)){ue=84;ae=114;break e}else{ce=ve&65535;le=2;ae=89;break i}}ve=ie+-129|0;if(ve>>>0>92){ue=84;ae=114;break e}if(ve>>>0>68&(ne&255)>82){ue=84;ae=114;break e}ne=te+-65|0;do if(ne>>>0<26)me=ne;else{if((te+-97|0)>>>0<26){me=te+-71|0;break}if((te+-129|0)>>>0>=126){ue=84;ae=114;break e}me=te+-77|0}while(0);if(ve>>>0<32)_e=ve*178|0;else _e=(oe*84|0)+5696|0;te=me+44032+_e|0;if(te>>>0<44032){ce=te;le=2;ae=89;break i}else{pe=te;Ee=44032}while(1){te=pe-Ee|0;ne=0;fe=0;while(1){Se=0;ge=fe;do{ge=(((a[309304+(ne*188|0)+(Se<<1)>>1]|0)-Ee|0)>>>0<=te>>>0&1)+ge|0;Se=Se+1|0}while((Se|0)!=94);ne=ne+1|0;if((ne|0)==93)break;else fe=ge}Ee=pe+1|0;fe=ge+pe|0;if(fe>>>0<Ee>>>0){ce=fe;le=2;ae=89;break i}else pe=fe}break}case 209:{if((ie+-161|0)>>>0<63){ce=ie+65216|0;le=1;ae=89;break i}if(g>>>0<2){re=22;break e}oe=n[$+1>>0]|0;ve=oe&255;fe=ie+-129|0;if(fe>>>0<31)ye=fe;else{if((ie&240|0)!=224){ue=84;ae=114;break e}ye=ie+-193|0}fe=ye<<1;ne=ve+-64|0;if(ne>>>0<95){if(oe<<24>>24==127){ue=84;ae=114;break e}Fe=fe;Oe=ne+(oe<<24>>24>>7<<24>>24)|0}else{oe=ve+-159|0;ne=oe>>>0<94;Fe=fe|ne&1;Oe=ne?oe:ve}ve=f[207296+(Fe*188|0)+(Oe<<1)>>1]|0;if(!(ve<<16>>16)){ue=84;ae=114;break e}else{ce=ve&65535;le=2;ae=89;break i}break}case 199:{ue=84;ae=114;break e;break}default:{if(ie>>>0<O>>>0){ce=ie;le=1;ae=89;break i}ve=ie-O|0;oe=(ve*5|0)>>>2;ne=ve<<1&6;ve=u[203264+(A+oe)>>0]<<8-ne&1023|(u[203264+(oe+v)>>0]|0)>>>ne;ne=(ve|0)==0?ie:a[326792+(ve<<1)>>1]|0;if((ne|0)==1){ue=84;ae=114;break e}else{ce=ne;le=1;ae=89;break i}}}while(0);if((ae|0)==14){ae=0;if((se&-2048|0)==55296|se>>>0>1114111){ue=84;ae=114;break e}else{ce=se;le=4;ae=89;break}}ne=ie+-129|0;if(ne>>>0>125){ue=84;ae=114;break e}if(g>>>0<2){re=22;break e}ve=n[$+1>>0]|0;oe=ve&255;if((ve&255)<161&B){ue=84;ae=114;break e}fe=oe+-64|0;if(!(fe>>>0>190|ve<<24>>24==127)){ce=a[223088+(ne*380|0)+((fe>>>0>63?oe+-65|0:fe)<<1)>>1]|0;le=2;ae=89;break}if(!((oe+-48|0)>>>0<10&I)){ue=84;ae=114;break e}if(g>>>0<4){re=22;break e}fe=(u[$+2>>0]|0)+-129|0;if(fe>>>0>126){ue=84;ae=114;break e}ve=(u[$+3>>0]|0)+-48|0;if(ve>>>0>9){ue=84;ae=114;break e}te=((oe+(ne*10|0)|0)*1260|0)+-60352+(fe*10|0)+ve|0;ve=0;while(1){fe=te-ve|0;ne=0;oe=0;while(1){Se=0;Ae=oe;do{Ae=(((a[223088+(ne*380|0)+(Se<<1)>>1]|0)-ve|0)>>>0<=fe>>>0&1)+Ae|0;Se=Se+1|0}while((Se|0)!=190);ne=ne+1|0;if((ne|0)==126)break;else oe=Ae}ve=te+1|0;oe=Ae+te|0;if(oe>>>0<ve>>>0){ce=oe;le=4;ae=89;break}else te=oe}}else{ce=ie;le=1;ae=89}while(0);i:do if((ae|0)==89){ae=0;switch(H|0){case 195:case 192:{if((t[c>>2]|0)>>>0<4){ue=7;ae=114;break e}ie=t[o>>2]|0;n[ie+K>>0]=ce>>>24;n[ie+X>>0]=ce>>>16;n[ie+Z>>0]=ce>>>8;n[ie+J>>0]=ce;t[o>>2]=ie+4;t[c>>2]=(t[c>>2]|0)+-4;we=le;de=y;break i;break}case 199:{if(ce>>>0>127){Me=y;ae=98}else{Re=ce;Ne=y}break}case 200:{if((t[c>>2]|0)>>>0<4){
	ie=wY(d,ce)|0;if((t[c>>2]|0)>>>0<ie>>>0){ue=7;ae=114;break e}ee=t[o>>2]|0;YY(ee|0,d|0,ie|0)|0;Te=ee;Le=ie}else{ie=t[o>>2]|0;Te=ie;Le=wY(ie,ce)|0}t[o>>2]=Te+Le;t[c>>2]=(t[c>>2]|0)-Le;we=le;de=y;break i;break}case 193:case 194:case 197:case 196:{if(ce>>>0<65536|e){ie=ce>>>0>65535?65533:ce;if((t[c>>2]|0)>>>0<2){ue=7;ae=114;break e}ee=t[o>>2]|0;n[ee+p>>0]=ie>>>8;n[ee+Y>>0]=ie;t[o>>2]=ee+2;t[c>>2]=(t[c>>2]|0)+-2;we=le;de=y;break i}else{if((t[c>>2]|0)>>>0<4){ue=7;ae=114;break e}ee=ce+-65536|0;ie=t[o>>2]|0;n[ie+p>>0]=ee>>>18|216;n[ie+Y>>0]=ee>>>10;n[ie+G>>0]=ee>>>8&3|220;n[ie+W>>0]=ee;t[o>>2]=ie+4;t[c>>2]=(t[c>>2]|0)+-4;we=le;de=y;break i}break}case 198:{if((t[c>>2]|0)>>>0<4){ue=7;ae=114;break e}ie=t[o>>2]|0;t[ie>>2]=ce;t[o>>2]=ie+4;t[c>>2]=(t[c>>2]|0)+-4;we=le;de=y;break i;break}default:{Re=ce;Ne=y}}r:while(1){if((ae|0)==98){ae=0;Re=42;Ne=Me+1|0}if(!(t[c>>2]|0)){ue=7;ae=114;break e}if(Re>>>0<x>>>0){De=Re;break}if(q){Me=Ne;ae=98;continue}else Ce=0;while(1){ie=(Ce*5|0)>>>2;ee=Ce<<1&6;te=Ce+1|0;if((Re|0)==(a[326792+((u[203264+(E+ie)>>0]<<8-ee&1023|(u[203264+(ie+_)>>0]|0)>>>ee)<<1)>>1]|0)){ae=105;break r}if(te>>>0<V>>>0)Ce=te;else{Me=Ne;ae=98;continue r}}}if((ae|0)==105){ae=0;De=Ce+128|0}te=t[o>>2]|0;t[o>>2]=te+1;n[te>>0]=De;t[c>>2]=(t[c>>2]|0)+-1;we=le;de=Ne}while(0);$=(t[i>>2]|0)+we|0;t[i>>2]=$;te=g;g=g-we|0;t[r>>2]=g;if((te|0)==(we|0)){S=de;ae=116;break}else y=de}if((ae|0)==114)re=ue;else if((ae|0)==116){s=l;return S|0}t[(ii()|0)>>2]=re;S=-1;s=l;return S|0}function xq(e,i,r,f){e=e|0;i=i|0;r=r|0;f=f|0;var u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0;u=s;s=s+16|0;a=u;t[a>>2]=e;o=(f|0)==0?328248:f;f=t[o>>2]|0;e:do if(!i){if(!f){c=0;s=u;return c|0}}else{if(!e){t[a>>2]=a;l=a}else l=e;if(!r){c=-2;s=u;return c|0}do if(!f){b=n[i>>0]|0;k=b&255;if(b<<24>>24>-1){t[l>>2]=k;c=b<<24>>24!=0&1;s=u;return c|0}else{b=k+-194|0;if(b>>>0>50)break e;h=r+-1|0;w=t[328040+(b<<2)>>2]|0;d=i+1|0;break}}else{h=r;w=f;d=i}while(0);i:do if(!h)v=w;else{b=n[d>>0]|0;k=(b&255)>>>3;if((k+-16|k+(w>>26))>>>0>7)break e;else{m=h;_=b;p=w;E=d}while(1){E=E+1|0;p=(_&255)+-128|p<<6;m=m+-1|0;if((p|0)>=0)break;if(!m){v=p;break i}_=n[E>>0]|0;if((_&-64)<<24>>24!=-128)break e}t[o>>2]=0;t[l>>2]=p;c=r-m|0;s=u;return c|0}while(0);t[o>>2]=v;c=-2;s=u;return c|0}while(0);t[o>>2]=0;t[(ii()|0)>>2]=84;c=-1;s=u;return c|0}function Uq(e){e=e|0;var i=0;if(!e)i=1;else i=(t[e>>2]|0)==0;return i&1|0}function zq(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0;n=s;f=e+84|0;u=t[f>>2]|0;a=r+256|0;o=OY(u,0,a)|0;if(!o)c=a;else c=o-u|0;o=c>>>0<r>>>0?c:r;YY(i|0,u|0,o|0)|0;t[e+4>>2]=u+o;i=u+c|0;t[e+8>>2]=i;t[f>>2]=i;s=n;return o|0}function jq(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0;n=s;s=s+16|0;f=n;t[f>>2]=r;r=qq(e,i,f)|0;s=n;return r|0}function Vq(e,i,r){e=e|0;i=i|0;r=r|0;var a=0,o=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0,S=0,g=0,y=0,F=0,O=0,A=0,M=0,R=0,N=0,T=0,L=0,D=0,C=0,B=0,I=0,H=0,x=0,U=0,z=0,j=0,V=0,q=0,Y=0,G=0,W=0,K=0,X=0,Z=0,J=0,Q=0,$=0,ee=0,ie=0,re=0,ne=0,fe=0,te=0,ue=0,ae=0,oe=0,ce=0,le=0,se=0,be=0,ke=0,he=0,we=0,de=0,ve=0,me=0,_e=0,pe=0,Ee=0,Se=0,ge=0,ye=0,Fe=0,Oe=0,Ae=0,Me=0,Re=0,Ne=0,Te=0,Le=0,De=0,Ce=0,Pe=0,Be=0,Ie=0,He=0,xe=0,Ue=0,ze=0,je=0,Ve=0,qe=0,Ye=0,Ge=0,We=0,Ke=0,Xe=0,Ze=0,Je=0,Qe=0,$e=0,ei=0,ii=0,ri=0,ni=0;a=s;s=s+304|0;o=a+16|0;b=a+8|0;k=a+33|0;h=a;w=a+32|0;d=n[i>>0]|0;if(!(d<<24>>24)){v=0;s=a;return v|0}m=e+4|0;_=e+100|0;p=e+108|0;E=e+8|0;S=k+10|0;g=k+33|0;y=b+4|0;F=k+46|0;O=k+94|0;A=d;d=0;M=i;i=0;R=0;N=0;e:while(1){i:do if(!($q(A&255)|0)){T=(n[M>>0]|0)==37;r:do if(T){L=M+1|0;D=n[L>>0]|0;do if(D<<24>>24==37)break r;else if(D<<24>>24==42){C=0;B=M+2|0}else{I=(D&255)+-48|0;if(I>>>0<10?(n[M+2>>0]|0)==36:0){t[o>>2]=t[r>>2];H=I;while(1){I=t[o>>2]|0;x=t[I>>2]|0;t[o>>2]=I+4;if(H>>>0>1)H=H+-1|0;else break}C=x;B=M+3|0;break}H=t[r>>2]|0;I=t[H>>2]|0;t[r>>2]=H+4;C=I;B=L}while(0);L=n[B>>0]|0;D=L&255;if((D+-48|0)>>>0<10){I=D;D=B;H=0;while(1){U=(H*10|0)+-48+I|0;z=D+1|0;j=n[z>>0]|0;I=j&255;if((I+-48|0)>>>0>=10){V=j;q=z;Y=U;break}else{D=z;H=U}}}else{V=L;q=B;Y=0}if(V<<24>>24==109){H=q+1|0;G=n[H>>0]|0;W=(C|0)!=0&1;K=H;X=0;Z=0}else{G=V;W=0;K=q;X=R;Z=N}H=K+1|0;switch(G&255|0){case 76:{J=H;Q=2;break}case 110:case 112:case 67:case 83:case 91:case 99:case 115:case 88:case 71:case 70:case 69:case 65:case 103:case 102:case 101:case 97:case 120:case 117:case 111:case 105:case 100:{J=K;Q=0;break}case 108:{D=(n[H>>0]|0)==108;J=D?K+2|0:H;Q=D?3:1;break}case 104:{D=(n[H>>0]|0)==104;J=D?K+2|0:H;Q=D?-2:-1;break}case 116:case 122:{J=H;Q=1;break}case 106:{J=H;Q=3;break}default:{$=W;ee=X;ie=Z;re=162;break e}}H=u[J>>0]|0;D=(H&47|0)==3;I=D?H|32:H;H=D?1:Q;if((I|0)==91){ne=i;fe=Y}else if((I|0)==99){ne=i;fe=(Y|0)<1?1:Y}else if((I|0)==110){if(!C){te=d;ue=J;ae=i;oe=X;ce=Z;break i}switch(H|0){case-1:{f[C>>1]=i;te=d;ue=J;ae=i;oe=X;ce=Z;break i;break}case-2:{n[C>>0]=i;te=d;ue=J;ae=i;oe=X;ce=Z;break i;break}case 3:{D=C;t[D>>2]=i;t[D+4>>2]=((i|0)<0)<<31>>31;te=d;ue=J;ae=i;oe=X;ce=Z;break i;break}case 0:{t[C>>2]=i;te=d;ue=J;ae=i;oe=X;ce=Z;break i;break}case 1:{t[C>>2]=i;te=d;ue=J;ae=i;oe=X;ce=Z;break i;break}default:{te=d;ue=J;ae=i;oe=X;ce=Z;break i}}}else{rY(e,0);do{D=t[m>>2]|0;if(D>>>0<(t[_>>2]|0)>>>0){t[m>>2]=D+1;le=u[D>>0]|0}else le=nY(e)|0}while(($q(le)|0)!=0);L=t[m>>2]|0;if(!(t[_>>2]|0))se=L;else{D=L+-1|0;t[m>>2]=D;se=D}ne=(t[p>>2]|0)+i+se-(t[E>>2]|0)|0;fe=Y}rY(e,fe);D=t[m>>2]|0;L=t[_>>2]|0;if(D>>>0<L>>>0){t[m>>2]=D+1;be=L}else{if((nY(e)|0)<0){$=W;ee=X;ie=Z;re=162;break e}be=t[_>>2]|0}if(be)t[m>>2]=(t[m>>2]|0)+-1;n:do switch(I|0){case 71:case 103:case 70:case 102:case 69:case 101:case 65:case 97:{ke=+iY(e,H,0);if((t[p>>2]|0)==((t[E>>2]|0)-(t[m>>2]|0)|0)){he=W;we=d;de=X;ve=Z;break e}if(C)if(!H){c[C>>2]=ke;me=J;_e=X;pe=Z;break n}else if((H|0)==1){l[C>>3]=ke;me=J;_e=X;pe=Z;break n}else if((H|0)==2){l[C>>3]=ke;me=J;_e=X;pe=Z;break n}else{me=J;_e=X;pe=Z;break n}else{me=J;_e=X;pe=Z}break}case 111:{Ee=8;re=144;break}case 117:case 100:{Ee=10;re=144;break}case 105:{Ee=0;re=144;break}case 91:case 99:case 115:{L=(I|0)==99;f:do if((I&239|0)==99){VY(k|0,-1,257)|0;n[k>>0]=0;if((I|0)==115){n[g>>0]=0;n[S+0>>0]=0;n[S+1>>0]=0;n[S+2>>0]=0;n[S+3>>0]=0;n[S+4>>0]=0;Se=J}else Se=J}else{D=J+1|0;U=(n[D>>0]|0)==94;z=U&1;j=U?J+2|0:D;VY(k|0,U&1|0,257)|0;n[k>>0]=0;U=n[j>>0]|0;if(U<<24>>24==45){D=(z^1)&255;n[F>>0]=D;ge=D;ye=j+1|0}else if(U<<24>>24==93){U=(z^1)&255;n[O>>0]=U;ge=U;ye=j+1|0}else{ge=(z^1)&255;ye=j}j=ye;while(1){z=n[j>>0]|0;if(!(z<<24>>24)){$=W;ee=X;ie=Z;re=162;break e}else if(z<<24>>24==93){Se=j;break f}else if(z<<24>>24==45){U=j+1|0;D=n[U>>0]|0;if(!(D<<24>>24==93|D<<24>>24==0)){Fe=n[j+-1>>0]|0;if((Fe&255)<(D&255)){Oe=Fe&255;do{Oe=Oe+1|0;n[k+Oe>>0]=ge;Fe=n[U>>0]|0}while((Oe|0)<(Fe&255|0));Ae=Fe;Me=U}else{Ae=D;Me=U}}else{Ae=45;Me=j}}else{Ae=z;Me=j}n[k+((Ae&255)+1)>>0]=ge;j=Me+1|0}}while(0);j=L?fe+1|0:31;Oe=(H|0)==1;Fe=(W|0)!=0;f:do if(Oe){if(Fe){Re=Xq(j<<2)|0;if(!Re){$=W;ee=0;ie=Re;re=162;break e}else Ne=Re}else Ne=C;t[b>>2]=0;t[y>>2]=0;Re=0;Te=j;Le=Ne;t:while(1){if(!Le)while(1){De=t[m>>2]|0;if(De>>>0<(t[_>>2]|0)>>>0){t[m>>2]=De+1;Ce=u[De>>0]|0}else Ce=nY(e)|0;if(!(n[k+(Ce+1)>>0]|0)){Pe=Re;Be=0;break t}n[w>>0]=Ce;De=xq(h,w,1,b)|0;if((De|0)==-2)continue;else if((De|0)==-1){$=W;ee=0;ie=0;re=162;break e}if(Fe&(Re|0)==(Te|0)){Ie=Re;break}}else{if(Fe)He=Re;else{xe=Re;re=98;break}while(1){while(1){z=t[m>>2]|0;if(z>>>0<(t[_>>2]|0)>>>0){t[m>>2]=z+1;Ue=u[z>>0]|0}else Ue=nY(e)|0;if(!(n[k+(Ue+1)>>0]|0)){Pe=He;Be=Le;break t}n[w>>0]=Ue;z=xq(h,w,1,b)|0;if((z|0)==-1){$=W;ee=0;ie=Le;re=162;break e}else if((z|0)!=-2)break}t[Le+(He<<2)>>2]=t[h>>2];He=He+1|0;if((He|0)==(Te|0)){Ie=Te;break}}}z=Te<<1|1;U=Jq(Le,z<<2)|0;if(!U){$=W;ee=0;ie=Le;re=162;break e}Re=Ie;Te=z;Le=U}t:do if((re|0)==98)while(1){re=0;while(1){Te=t[m>>2]|0;if(Te>>>0<(t[_>>2]|0)>>>0){t[m>>2]=Te+1;ze=u[Te>>0]|0}else ze=nY(e)|0;if(!(n[k+(ze+1)>>0]|0)){Pe=xe;Be=Le;break t}n[w>>0]=ze;Te=xq(h,w,1,b)|0;if((Te|0)==-1){$=0;ee=0;ie=Le;re=162;break e}else if((Te|0)!=-2)break}t[Le+(xe<<2)>>2]=t[h>>2];xe=xe+1|0;re=98}while(0);if(!(Uq(b)|0)){$=W;ee=0;ie=Be;re=162;break e}else{je=Pe;Ve=0;qe=Be}}else{if(Fe){Le=Xq(j)|0;if(!Le){$=W;ee=0;ie=0;re=162;break e}else{Ye=0;Ge=j;We=Le}while(1){Le=Ye;do{Te=t[m>>2]|0;if(Te>>>0<(t[_>>2]|0)>>>0){t[m>>2]=Te+1;Ke=u[Te>>0]|0}else Ke=nY(e)|0;if(!(n[k+(Ke+1)>>0]|0)){je=Le;Ve=We;qe=0;break f}n[We+Le>>0]=Ke;Le=Le+1|0}while((Le|0)!=(Ge|0));Le=Ge<<1|1;Te=Jq(We,Le)|0;if(!Te){$=W;ee=We;ie=0;re=162;break e}else{Re=Ge;Ge=Le;We=Te;Ye=Re}}}if(!C){Re=be;while(1){Te=t[m>>2]|0;if(Te>>>0<Re>>>0){t[m>>2]=Te+1;Xe=u[Te>>0]|0}else Xe=nY(e)|0;if(!(n[k+(Xe+1)>>0]|0)){je=0;Ve=0;qe=0;break f}Re=t[_>>2]|0}}else{Re=be;Te=0;while(1){Le=t[m>>2]|0;if(Le>>>0<Re>>>0){t[m>>2]=Le+1;Ze=u[Le>>0]|0}else Ze=nY(e)|0;if(!(n[k+(Ze+1)>>0]|0)){je=Te;Ve=C;qe=0;break f}n[C+Te>>0]=Ze;Re=t[_>>2]|0;Te=Te+1|0}}}while(0);j=t[m>>2]|0;if(!(t[_>>2]|0))Je=j;else{Te=j+-1|0;t[m>>2]=Te;Je=Te}Te=Je-(t[E>>2]|0)+(t[p>>2]|0)|0;if(!Te){he=W;we=d;de=Ve;ve=qe;break e}if(!((Te|0)==(fe|0)|L^1)){he=W;we=d;de=Ve;ve=qe;break e}do if(Fe)if(Oe){t[C>>2]=qe;break}else{t[C>>2]=Ve;break}while(0);if(!L){if(qe)t[qe+(je<<2)>>2]=0;if(!Ve){me=Se;_e=0;pe=qe}else{n[Ve+je>>0]=0;me=Se;_e=Ve;pe=qe}}else{me=Se;_e=Ve;pe=qe}break}case 120:case 88:case 112:{Ee=16;re=144;break}default:{me=J;_e=X;pe=Z}}while(0);n:do if((re|0)==144){re=0;Oe=eY(e,Ee,0,-1,-1)|0;if((t[p>>2]|0)==((t[E>>2]|0)-(t[m>>2]|0)|0)){he=W;we=d;de=X;ve=Z;break e}if((I|0)==112&(C|0)!=0){t[C>>2]=Oe;me=J;_e=X;pe=Z;break}if(!C){me=J;_e=X;pe=Z}else switch(H|0){case-2:{n[C>>0]=Oe;me=J;_e=X;pe=Z;break n;break}case-1:{f[C>>1]=Oe;me=J;_e=X;pe=Z;break n;break}case 0:{t[C>>2]=Oe;me=J;_e=X;pe=Z;break n;break}case 1:{t[C>>2]=Oe;me=J;_e=X;pe=Z;break n;break}case 3:{Fe=C;t[Fe>>2]=Oe;t[Fe+4>>2]=P;me=J;_e=X;pe=Z;break n;break}default:{me=J;_e=X;pe=Z;break n}}}while(0);te=((C|0)!=0&1)+d|0;ue=me;ae=(t[p>>2]|0)+ne+(t[m>>2]|0)-(t[E>>2]|0)|0;oe=_e;ce=pe;break i}while(0);H=M+(T&1)|0;rY(e,0);I=t[m>>2]|0;if(I>>>0<(t[_>>2]|0)>>>0){t[m>>2]=I+1;Qe=u[I>>0]|0}else Qe=nY(e)|0;if((Qe|0)!=(u[H>>0]|0)){re=19;break e}te=d;ue=H;ae=i+1|0;oe=R;ce=N}else{H=M;while(1){I=H+1|0;if(!($q(u[I>>0]|0)|0))break;else H=I}rY(e,0);do{T=t[m>>2]|0;if(T>>>0<(t[_>>2]|0)>>>0){t[m>>2]=T+1;$e=u[T>>0]|0}else $e=nY(e)|0}while(($q($e)|0)!=0);T=t[m>>2]|0;if(!(t[_>>2]|0))ei=T;else{I=T+-1|0;t[m>>2]=I;ei=I}te=d;ue=H;ae=(t[p>>2]|0)+i+ei-(t[E>>2]|0)|0;oe=R;ce=N}while(0);M=ue+1|0;A=n[M>>0]|0;if(!(A<<24>>24)){v=te;re=166;break}else{d=te;i=ae;R=oe;N=ce}}if((re|0)==19){if(t[_>>2]|0)t[m>>2]=(t[m>>2]|0)+-1;if((Qe|0)>-1|(d|0)!=0){v=d;s=a;return v|0}else{ii=0;ri=R;ni=N;re=163}}else if((re|0)==162)if(!d){ii=$;ri=ee;ni=ie;re=163}else{he=$;we=d;de=ee;ve=ie}else if((re|0)==166){s=a;return v|0}if((re|0)==163){he=ii;we=-1;de=ri;ve=ni}if(!he){v=we;s=a;return v|0}Zq(de);Zq(ve);v=we;s=a;return v|0}function qq(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0;n=s;s=s+112|0;f=n;u=f+0|0;a=u+112|0;do{t[u>>2]=0;u=u+4|0}while((u|0)<(a|0));t[f+32>>2]=391;t[f+44>>2]=e;t[f+76>>2]=-1;t[f+84>>2]=e;e=Vq(f,i,r)|0;s=n;return e|0}function Yq(e,i){e=e|0;i=i|0;var r=0,f=0;r=s;f=Gq(e,i)|0;s=r;return((n[f>>0]|0)==(i&255)<<24>>24?f:0)|0}function Gq(e,i){e=e|0;i=i|0;var r=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0;r=s;f=i&255;if(!f){u=e+(HY(e|0)|0)|0;s=r;return u|0}e:do if(!(e&3))a=e;else{o=i&255;c=e;while(1){l=n[c>>0]|0;b=c+1|0;if(l<<24>>24==0?1:l<<24>>24==o<<24>>24){u=c;break}if(!(b&3)){a=b;break e}else c=b}s=r;return u|0}while(0);e=te(f,16843009)|0;f=t[a>>2]|0;e:do if(!((f&-2139062144^-2139062144)&f+-16843009)){c=f;o=a;while(1){b=c^e;l=o+4|0;if((b&-2139062144^-2139062144)&b+-16843009){k=o;break e}c=t[l>>2]|0;if((c&-2139062144^-2139062144)&c+-16843009){k=l;break}else o=l}}else k=a;while(0);a=i&255;i=k;while(1){k=n[i>>0]|0;if(k<<24>>24==0?1:k<<24>>24==a<<24>>24){u=i;break}else i=i+1|0}s=r;return u|0}function Wq(e){e=e|0;var i=0,r=0,f=0,t=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0,S=0,g=0;i=s;r=n[e>>0]|0;e:do if(r<<24>>24){f=203264;while(1){t=e;u=f;a=r;while(1){o=n[u>>0]|0;if(!(o<<24>>24)){c=u;l=a;b=16;break}i:do if(!(a<<24>>24)){k=t;h=0}else{w=t;d=a&255;v=a;while(1){m=w+1|0;if(!(((d|32)+-97|0)>>>0>26&(d+-48|0)>>>0>10)){k=w;h=v;break i}_=n[m>>0]|0;if(!(_<<24>>24)){k=m;h=0;break}else{w=m;d=_&255;v=_}}}while(0);if((h&255|32|0)!=(o&255|0))break;t=k+1|0;v=u+1|0;a=n[t>>0]|0;if(!(a<<24>>24)){c=v;l=0;b=16;break}else u=v}if((b|0)==16?(b=0,l<<24>>24==(n[c>>0]|0)):0)break;u=HY(f|0)|0;a=f+(u+1)|0;do if(!(n[a>>0]|0)){t=n[f+(u+2)>>0]|0;if((t&255)>128){p=f+(u+3)|0;break}else{p=f+(u+3+(((128-(t&255)|0)>>>2)*5|0))|0;break}}else p=a;while(0);if(!(n[p>>0]|0)){E=-1;b=25;break}else f=p}if((b|0)==25){s=i;return E|0}if(!(n[f>>0]|0))S=f;else{a=f;while(1){u=a+((HY(a|0)|0)+1)|0;if(!(n[u>>0]|0)){S=u;break}else a=u}}}else{a=203264;while(1){if(!(n[a>>0]|0)){S=a;break e}f=HY(a|0)|0;u=a+(f+1)|0;do if(!(n[u>>0]|0)){t=n[a+(f+2)>>0]|0;if((t&255)>128){g=a+(f+3)|0;break}else{g=a+(f+3+(((128-(t&255)|0)>>>2)*5|0))|0;break}}else g=u;while(0);if(!(n[g>>0]|0)){E=-1;break}else a=g}s=i;return E|0}while(0);E=S+1-203264|0;s=i;return E|0}function Kq(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0;n=s;f=zq(e,i,r)|0;s=n;return f|0}function Xq(e){e=e|0;var i=0,r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0,S=0,g=0,y=0,F=0,O=0,A=0,M=0,R=0,N=0,T=0,L=0,D=0,C=0,P=0,B=0,I=0,H=0,x=0,U=0,z=0,j=0,V=0,q=0,Y=0,G=0,W=0,K=0,X=0,Z=0,J=0,Q=0,$=0,ee=0,ie=0,re=0,ne=0,fe=0,te=0,ue=0,ae=0,oe=0,ce=0,le=0,se=0,be=0,ke=0,he=0,we=0,de=0,ve=0,me=0,_e=0,pe=0,Ee=0,Se=0,ge=0,ye=0,Fe=0,Oe=0,Ae=0,Me=0,Re=0,Ne=0,Te=0,Le=0,De=0,Ce=0,Pe=0,Be=0,Ie=0;i=s;do if(e>>>0<245){if(e>>>0<11)r=16;else r=e+11&-8;n=r>>>3;f=t[82064]|0;u=f>>>n;if(u&3){a=(u&1^1)+n|0;o=a<<1;c=328296+(o<<2)|0;l=328296+(o+2<<2)|0;o=t[l>>2]|0;b=o+8|0;k=t[b>>2]|0;do if((c|0)!=(k|0)){if(k>>>0<(t[82068]|0)>>>0)li();h=k+12|0;if((t[h>>2]|0)==(o|0)){t[h>>2]=c;t[l>>2]=k;break}else li()}else t[82064]=f&~(1<<a);while(0);k=a<<3;t[o+4>>2]=k|3;l=o+(k|4)|0;t[l>>2]=t[l>>2]|1;w=b;s=i;return w|0}l=t[82066]|0;if(r>>>0>l>>>0){if(u){k=2<<n;c=u<<n&(k|0-k);k=(c&0-c)+-1|0;c=k>>>12&16;h=k>>>c;k=h>>>5&8;d=h>>>k;h=d>>>2&4;v=d>>>h;d=v>>>1&2;m=v>>>d;v=m>>>1&1;_=(k|c|h|d|v)+(m>>>v)|0;v=_<<1;m=328296+(v<<2)|0;d=328296+(v+2<<2)|0;v=t[d>>2]|0;h=v+8|0;c=t[h>>2]|0;do if((m|0)!=(c|0)){if(c>>>0<(t[82068]|0)>>>0)li();k=c+12|0;if((t[k>>2]|0)==(v|0)){t[k>>2]=m;t[d>>2]=c;p=t[82066]|0;break}else li()}else{t[82064]=f&~(1<<_);p=l}while(0);l=_<<3;f=l-r|0;t[v+4>>2]=r|3;c=v+r|0;t[v+(r|4)>>2]=f|1;t[v+l>>2]=f;if(p){l=t[82069]|0;d=p>>>3;m=d<<1;n=328296+(m<<2)|0;u=t[82064]|0;b=1<<d;if(u&b){d=328296+(m+2<<2)|0;o=t[d>>2]|0;if(o>>>0<(t[82068]|0)>>>0)li();else{E=d;S=o}}else{t[82064]=u|b;E=328296+(m+2<<2)|0;S=n}t[E>>2]=l;t[S+12>>2]=l;t[l+8>>2]=S;t[l+12>>2]=n}t[82066]=f;t[82069]=c;w=h;s=i;return w|0}c=t[82065]|0;if(c){f=(c&0-c)+-1|0;c=f>>>12&16;n=f>>>c;f=n>>>5&8;l=n>>>f;n=l>>>2&4;m=l>>>n;l=m>>>1&2;b=m>>>l;m=b>>>1&1;u=t[328560+((f|c|n|l|m)+(b>>>m)<<2)>>2]|0;m=(t[u+4>>2]&-8)-r|0;b=u;l=u;while(1){u=t[b+16>>2]|0;if(!u){n=t[b+20>>2]|0;if(!n)break;else g=n}else g=u;u=(t[g+4>>2]&-8)-r|0;n=u>>>0<m>>>0;m=n?u:m;b=g;l=n?g:l}b=t[82068]|0;if(l>>>0<b>>>0)li();h=l+r|0;if(l>>>0>=h>>>0)li();v=t[l+24>>2]|0;_=t[l+12>>2]|0;do if((_|0)==(l|0)){n=l+20|0;u=t[n>>2]|0;if(!u){c=l+16|0;f=t[c>>2]|0;if(!f){y=0;break}else{F=f;O=c}}else{F=u;O=n}while(1){n=F+20|0;u=t[n>>2]|0;if(u){F=u;O=n;continue}n=F+16|0;u=t[n>>2]|0;if(!u)break;else{F=u;O=n}}if(O>>>0<b>>>0)li();else{t[O>>2]=0;y=F;break}}else{n=t[l+8>>2]|0;if(n>>>0<b>>>0)li();u=n+12|0;if((t[u>>2]|0)!=(l|0))li();c=_+8|0;if((t[c>>2]|0)==(l|0)){t[u>>2]=_;t[c>>2]=n;y=_;break}else li()}while(0);do if(v){_=t[l+28>>2]|0;b=328560+(_<<2)|0;if((l|0)==(t[b>>2]|0)){t[b>>2]=y;if(!y){t[82065]=t[82065]&~(1<<_);break}}else{if(v>>>0<(t[82068]|0)>>>0)li();_=v+16|0;if((t[_>>2]|0)==(l|0))t[_>>2]=y;else t[v+20>>2]=y;if(!y)break}_=t[82068]|0;if(y>>>0<_>>>0)li();t[y+24>>2]=v;b=t[l+16>>2]|0;do if(b)if(b>>>0<_>>>0)li();else{t[y+16>>2]=b;t[b+24>>2]=y;break}while(0);b=t[l+20>>2]|0;if(b)if(b>>>0<(t[82068]|0)>>>0)li();else{t[y+20>>2]=b;t[b+24>>2]=y;break}}while(0);if(m>>>0<16){v=m+r|0;t[l+4>>2]=v|3;b=l+(v+4)|0;t[b>>2]=t[b>>2]|1}else{t[l+4>>2]=r|3;t[l+(r|4)>>2]=m|1;t[l+(m+r)>>2]=m;b=t[82066]|0;if(b){v=t[82069]|0;_=b>>>3;b=_<<1;n=328296+(b<<2)|0;c=t[82064]|0;u=1<<_;if(c&u){_=328296+(b+2<<2)|0;f=t[_>>2]|0;if(f>>>0<(t[82068]|0)>>>0)li();else{A=_;M=f}}else{t[82064]=c|u;A=328296+(b+2<<2)|0;M=n}t[A>>2]=v;t[M+12>>2]=v;t[v+8>>2]=M;t[v+12>>2]=n}t[82066]=m;t[82069]=h}w=l+8|0;s=i;return w|0}else R=r}else R=r}else if(e>>>0<=4294967231){n=e+11|0;v=n&-8;b=t[82065]|0;if(b){u=0-v|0;c=n>>>8;if(c)if(v>>>0>16777215)N=31;else{n=(c+1048320|0)>>>16&8;f=c<<n;c=(f+520192|0)>>>16&4;_=f<<c;f=(_+245760|0)>>>16&2;o=14-(c|n|f)+(_<<f>>>15)|0;N=v>>>(o+7|0)&1|o<<1}else N=0;o=t[328560+(N<<2)>>2]|0;e:do if(!o){T=u;L=0;D=0}else{if((N|0)==31)C=0;else C=25-(N>>>1)|0;f=u;_=0;n=v<<C;c=o;d=0;while(1){a=t[c+4>>2]&-8;k=a-v|0;if(k>>>0<f>>>0)if((a|0)==(v|0)){T=k;L=c;D=c;break e}else{P=k;B=c}else{P=f;B=d}k=t[c+20>>2]|0;c=t[c+(n>>>31<<2)+16>>2]|0;a=(k|0)==0|(k|0)==(c|0)?_:k;if(!c){T=P;L=a;D=B;break}else{f=P;_=a;n=n<<1;d=B}}}while(0);if((L|0)==0&(D|0)==0){o=2<<N;u=b&(o|0-o);if(!u){R=v;break}o=(u&0-u)+-1|0;u=o>>>12&16;l=o>>>u;o=l>>>5&8;h=l>>>o;l=h>>>2&4;m=h>>>l;h=m>>>1&2;d=m>>>h;m=d>>>1&1;I=t[328560+((o|u|l|h|m)+(d>>>m)<<2)>>2]|0}else I=L;if(!I){H=T;x=D}else{m=T;d=I;h=D;while(1){l=(t[d+4>>2]&-8)-v|0;u=l>>>0<m>>>0;o=u?l:m;l=u?d:h;u=t[d+16>>2]|0;if(u){m=o;d=u;h=l;continue}d=t[d+20>>2]|0;if(!d){H=o;x=l;break}else{m=o;h=l}}}if((x|0)!=0?H>>>0<((t[82066]|0)-v|0)>>>0:0){h=t[82068]|0;if(x>>>0<h>>>0)li();m=x+v|0;if(x>>>0>=m>>>0)li();d=t[x+24>>2]|0;b=t[x+12>>2]|0;do if((b|0)==(x|0)){l=x+20|0;o=t[l>>2]|0;if(!o){u=x+16|0;n=t[u>>2]|0;if(!n){U=0;break}else{z=n;j=u}}else{z=o;j=l}while(1){l=z+20|0;o=t[l>>2]|0;if(o){z=o;j=l;continue}l=z+16|0;o=t[l>>2]|0;if(!o)break;else{z=o;j=l}}if(j>>>0<h>>>0)li();else{t[j>>2]=0;U=z;break}}else{l=t[x+8>>2]|0;if(l>>>0<h>>>0)li();o=l+12|0;if((t[o>>2]|0)!=(x|0))li();u=b+8|0;if((t[u>>2]|0)==(x|0)){t[o>>2]=b;t[u>>2]=l;U=b;break}else li()}while(0);do if(d){b=t[x+28>>2]|0;h=328560+(b<<2)|0;if((x|0)==(t[h>>2]|0)){t[h>>2]=U;if(!U){t[82065]=t[82065]&~(1<<b);break}}else{if(d>>>0<(t[82068]|0)>>>0)li();b=d+16|0;if((t[b>>2]|0)==(x|0))t[b>>2]=U;else t[d+20>>2]=U;if(!U)break}b=t[82068]|0;if(U>>>0<b>>>0)li();t[U+24>>2]=d;h=t[x+16>>2]|0;do if(h)if(h>>>0<b>>>0)li();else{t[U+16>>2]=h;t[h+24>>2]=U;break}while(0);h=t[x+20>>2]|0;if(h)if(h>>>0<(t[82068]|0)>>>0)li();else{t[U+20>>2]=h;t[h+24>>2]=U;break}}while(0);e:do if(H>>>0>=16){t[x+4>>2]=v|3;t[x+(v|4)>>2]=H|1;t[x+(H+v)>>2]=H;d=H>>>3;if(H>>>0<256){h=d<<1;b=328296+(h<<2)|0;l=t[82064]|0;u=1<<d;do if(!(l&u)){t[82064]=l|u;V=328296+(h+2<<2)|0;q=b}else{d=328296+(h+2<<2)|0;o=t[d>>2]|0;if(o>>>0>=(t[82068]|0)>>>0){V=d;q=o;break}li()}while(0);t[V>>2]=m;t[q+12>>2]=m;t[x+(v+8)>>2]=q;t[x+(v+12)>>2]=b;break}h=H>>>8;if(h)if(H>>>0>16777215)Y=31;else{u=(h+1048320|0)>>>16&8;l=h<<u;h=(l+520192|0)>>>16&4;o=l<<h;l=(o+245760|0)>>>16&2;d=14-(h|u|l)+(o<<l>>>15)|0;Y=H>>>(d+7|0)&1|d<<1}else Y=0;d=328560+(Y<<2)|0;t[x+(v+28)>>2]=Y;t[x+(v+20)>>2]=0;t[x+(v+16)>>2]=0;l=t[82065]|0;o=1<<Y;if(!(l&o)){t[82065]=l|o;t[d>>2]=m;t[x+(v+24)>>2]=d;t[x+(v+12)>>2]=m;t[x+(v+8)>>2]=m;break}o=t[d>>2]|0;if((Y|0)==31)G=0;else G=25-(Y>>>1)|0;i:do if((t[o+4>>2]&-8|0)!=(H|0)){d=H<<G;l=o;while(1){W=l+(d>>>31<<2)+16|0;u=t[W>>2]|0;if(!u)break;if((t[u+4>>2]&-8|0)==(H|0)){K=u;break i}else{d=d<<1;l=u}}if(W>>>0<(t[82068]|0)>>>0)li();else{t[W>>2]=m;t[x+(v+24)>>2]=l;t[x+(v+12)>>2]=m;t[x+(v+8)>>2]=m;break e}}else K=o;while(0);o=K+8|0;b=t[o>>2]|0;d=t[82068]|0;if(K>>>0>=d>>>0&b>>>0>=d>>>0){t[b+12>>2]=m;t[o>>2]=m;t[x+(v+8)>>2]=b;t[x+(v+12)>>2]=K;t[x+(v+24)>>2]=0;break}else li()}else{b=H+v|0;t[x+4>>2]=b|3;o=x+(b+4)|0;t[o>>2]=t[o>>2]|1}while(0);w=x+8|0;s=i;return w|0}else R=v}else R=v}else R=-1;while(0);x=t[82066]|0;if(x>>>0>=R>>>0){H=x-R|0;K=t[82069]|0;if(H>>>0>15){t[82069]=K+R;t[82066]=H;t[K+(R+4)>>2]=H|1;t[K+x>>2]=H;t[K+4>>2]=R|3}else{t[82066]=0;t[82069]=0;t[K+4>>2]=x|3;H=K+(x+4)|0;t[H>>2]=t[H>>2]|1}w=K+8|0;s=i;return w|0}K=t[82067]|0;if(K>>>0>R>>>0){H=K-R|0;t[82067]=H;K=t[82070]|0;t[82070]=K+R;t[K+(R+4)>>2]=H|1;t[K+4>>2]=R|3;w=K+8|0;s=i;return w|0}do if(!(t[82182]|0)){K=ui(30)|0;if(!(K+-1&K)){t[82184]=K;t[82183]=K;t[82185]=-1;t[82186]=-1;t[82187]=0;t[82175]=0;t[82182]=(bi(0)|0)&-16^1431655768;break}else li()}while(0);K=R+48|0;H=t[82184]|0;x=R+47|0;W=H+x|0;G=0-H|0;H=W&G;if(H>>>0<=R>>>0){w=0;s=i;return w|0}Y=t[82174]|0;if((Y|0)!=0?(q=t[82172]|0,V=q+H|0,V>>>0<=q>>>0|V>>>0>Y>>>0):0){w=0;s=i;return w|0}e:do if(!(t[82175]&4)){Y=t[82070]|0;i:do if(Y){V=328704|0;while(1){q=t[V>>2]|0;if(q>>>0<=Y>>>0?(X=V+4|0,(q+(t[X>>2]|0)|0)>>>0>Y>>>0):0)break;q=t[V+8>>2]|0;if(!q){Z=181;break i}else V=q}if(V){q=W-(t[82067]|0)&G;if(q>>>0<2147483647){U=ze(q|0)|0;if((U|0)==((t[V>>2]|0)+(t[X>>2]|0)|0)){J=U;Q=q;Z=190}else{$=U;ee=q;Z=191}}else ie=0}else Z=181}else Z=181;while(0);do if((Z|0)==181){Y=ze(0)|0;if((Y|0)!=(-1|0)){v=Y;q=t[82183]|0;U=q+-1|0;if(!(U&v))re=H;else re=H-v+(U+v&0-q)|0;q=t[82172]|0;v=q+re|0;if(re>>>0>R>>>0&re>>>0<2147483647){U=t[82174]|0;if((U|0)!=0?v>>>0<=q>>>0|v>>>0>U>>>0:0){ie=0;break}U=ze(re|0)|0;if((U|0)==(Y|0)){J=Y;Q=re;Z=190}else{$=U;ee=re;Z=191}}else ie=0}else ie=0}while(0);i:do if((Z|0)==190)if((J|0)==(-1|0))ie=Q;else{ne=J;fe=Q;Z=201;break e}else if((Z|0)==191){U=0-ee|0;do if(($|0)!=(-1|0)&ee>>>0<2147483647&K>>>0>ee>>>0?(Y=t[82184]|0,v=x-ee+Y&0-Y,v>>>0<2147483647):0)if((ze(v|0)|0)==(-1|0)){ze(U|0)|0;ie=0;break i}else{te=v+ee|0;break}else te=ee;while(0);if(($|0)==(-1|0))ie=0;else{ne=$;fe=te;Z=201;break e}}while(0);t[82175]=t[82175]|4;ue=ie;Z=198}else{ue=0;Z=198}while(0);if((((Z|0)==198?H>>>0<2147483647:0)?(ie=ze(H|0)|0,H=ze(0)|0,(ie|0)!=(-1|0)&(H|0)!=(-1|0)&ie>>>0<H>>>0):0)?(te=H-ie|0,H=te>>>0>(R+40|0)>>>0,H):0){ne=ie;fe=H?te:ue;Z=201}if((Z|0)==201){ue=(t[82172]|0)+fe|0;t[82172]=ue;if(ue>>>0>(t[82173]|0)>>>0)t[82173]=ue;ue=t[82070]|0;e:do if(ue){te=328704|0;while(1){ae=t[te>>2]|0;oe=te+4|0;ce=t[oe>>2]|0;if((ne|0)==(ae+ce|0)){Z=213;break}H=t[te+8>>2]|0;if(!H)break;else te=H}if(((Z|0)==213?(t[te+12>>2]&8|0)==0:0)?ue>>>0>=ae>>>0&ue>>>0<ne>>>0:0){t[oe>>2]=ce+fe;H=(t[82067]|0)+fe|0;ie=ue+8|0;if(!(ie&7))le=0;else le=0-ie&7;ie=H-le|0;t[82070]=ue+le;t[82067]=ie;t[ue+(le+4)>>2]=ie|1;t[ue+(H+4)>>2]=40;t[82071]=t[82186];break}H=t[82068]|0;if(ne>>>0<H>>>0){t[82068]=ne;se=ne}else se=H;H=ne+fe|0;ie=328704|0;while(1){if((t[ie>>2]|0)==(H|0)){Z=223;break}$=t[ie+8>>2]|0;if(!$)break;else ie=$}if((Z|0)==223?(t[ie+12>>2]&8|0)==0:0){t[ie>>2]=ne;H=ie+4|0;t[H>>2]=(t[H>>2]|0)+fe;H=ne+8|0;if(!(H&7))be=0;else be=0-H&7;H=ne+(fe+8)|0;if(!(H&7))ke=0;else ke=0-H&7;H=ne+(ke+fe)|0;te=be+R|0;$=ne+te|0;ee=H-(ne+be)-R|0;t[ne+(be+4)>>2]=R|3;i:do if((H|0)!=(ue|0)){if((H|0)==(t[82069]|0)){x=(t[82066]|0)+ee|0;t[82066]=x;t[82069]=$;t[ne+(te+4)>>2]=x|1;t[ne+(x+te)>>2]=x;break}x=fe+4|0;K=t[ne+(x+ke)>>2]|0;if((K&3|0)==1){Q=K&-8;J=K>>>3;r:do if(K>>>0>=256){re=t[ne+((ke|24)+fe)>>2]|0;X=t[ne+(fe+12+ke)>>2]|0;do if((X|0)==(H|0)){G=ke|16;W=ne+(x+G)|0;U=t[W>>2]|0;if(!U){V=ne+(G+fe)|0;G=t[V>>2]|0;if(!G){he=0;break}else{we=G;de=V}}else{we=U;de=W}while(1){W=we+20|0;U=t[W>>2]|0;if(U){we=U;de=W;continue}W=we+16|0;U=t[W>>2]|0;if(!U)break;else{we=U;de=W}}if(de>>>0<se>>>0)li();else{t[de>>2]=0;he=we;break}}else{W=t[ne+((ke|8)+fe)>>2]|0;if(W>>>0<se>>>0)li();U=W+12|0;if((t[U>>2]|0)!=(H|0))li();V=X+8|0;if((t[V>>2]|0)==(H|0)){t[U>>2]=X;t[V>>2]=W;he=X;break}else li()}while(0);if(!re)break;X=t[ne+(fe+28+ke)>>2]|0;l=328560+(X<<2)|0;do if((H|0)!=(t[l>>2]|0)){if(re>>>0<(t[82068]|0)>>>0)li();W=re+16|0;if((t[W>>2]|0)==(H|0))t[W>>2]=he;else t[re+20>>2]=he;if(!he)break r}else{t[l>>2]=he;if(he)break;t[82065]=t[82065]&~(1<<X);break r}while(0);X=t[82068]|0;if(he>>>0<X>>>0)li();t[he+24>>2]=re;l=ke|16;W=t[ne+(l+fe)>>2]|0;do if(W)if(W>>>0<X>>>0)li();else{t[he+16>>2]=W;t[W+24>>2]=he;break}while(0);W=t[ne+(x+l)>>2]|0;if(!W)break;if(W>>>0<(t[82068]|0)>>>0)li();else{t[he+20>>2]=W;t[W+24>>2]=he;break}}else{W=t[ne+((ke|8)+fe)>>2]|0;X=t[ne+(fe+12+ke)>>2]|0;re=328296+(J<<1<<2)|0;do if((W|0)!=(re|0)){if(W>>>0<se>>>0)li();if((t[W+12>>2]|0)==(H|0))break;li()}while(0);if((X|0)==(W|0)){t[82064]=t[82064]&~(1<<J);break}do if((X|0)==(re|0))ve=X+8|0;else{if(X>>>0<se>>>0)li();l=X+8|0;if((t[l>>2]|0)==(H|0)){ve=l;break}li()}while(0);t[W+12>>2]=X;t[ve>>2]=W}while(0);me=ne+((Q|ke)+fe)|0;_e=Q+ee|0}else{me=H;_e=ee}J=me+4|0;t[J>>2]=t[J>>2]&-2;t[ne+(te+4)>>2]=_e|1;t[ne+(_e+te)>>2]=_e;J=_e>>>3;if(_e>>>0<256){x=J<<1;K=328296+(x<<2)|0;re=t[82064]|0;l=1<<J;do if(!(re&l)){t[82064]=re|l;pe=328296+(x+2<<2)|0;Ee=K}else{J=328296+(x+2<<2)|0;V=t[J>>2]|0;if(V>>>0>=(t[82068]|0)>>>0){pe=J;Ee=V;break}li()}while(0);t[pe>>2]=$;t[Ee+12>>2]=$;t[ne+(te+8)>>2]=Ee;t[ne+(te+12)>>2]=K;break}x=_e>>>8;do if(!x)Se=0;else{if(_e>>>0>16777215){Se=31;break}l=(x+1048320|0)>>>16&8;re=x<<l;Q=(re+520192|0)>>>16&4;V=re<<Q;re=(V+245760|0)>>>16&2;J=14-(Q|l|re)+(V<<re>>>15)|0;Se=_e>>>(J+7|0)&1|J<<1}while(0);x=328560+(Se<<2)|0;t[ne+(te+28)>>2]=Se;t[ne+(te+20)>>2]=0;t[ne+(te+16)>>2]=0;K=t[82065]|0;J=1<<Se;if(!(K&J)){t[82065]=K|J;t[x>>2]=$;t[ne+(te+24)>>2]=x;t[ne+(te+12)>>2]=$;t[ne+(te+8)>>2]=$;break}J=t[x>>2]|0;if((Se|0)==31)ge=0;else ge=25-(Se>>>1)|0;r:do if((t[J+4>>2]&-8|0)!=(_e|0)){x=_e<<ge;K=J;while(1){ye=K+(x>>>31<<2)+16|0;re=t[ye>>2]|0;if(!re)break;if((t[re+4>>2]&-8|0)==(_e|0)){Fe=re;break r}else{x=x<<1;K=re}}if(ye>>>0<(t[82068]|0)>>>0)li();else{t[ye>>2]=$;t[ne+(te+24)>>2]=K;t[ne+(te+12)>>2]=$;t[ne+(te+8)>>2]=$;break i}}else Fe=J;while(0);J=Fe+8|0;x=t[J>>2]|0;W=t[82068]|0;if(Fe>>>0>=W>>>0&x>>>0>=W>>>0){t[x+12>>2]=$;t[J>>2]=$;t[ne+(te+8)>>2]=x;t[ne+(te+12)>>2]=Fe;t[ne+(te+24)>>2]=0;break}else li()}else{x=(t[82067]|0)+ee|0;t[82067]=x;t[82070]=$;t[ne+(te+4)>>2]=x|1}while(0);w=ne+(be|8)|0;s=i;return w|0}te=328704|0;while(1){Oe=t[te>>2]|0;if(Oe>>>0<=ue>>>0?(Ae=t[te+4>>2]|0,Me=Oe+Ae|0,Me>>>0>ue>>>0):0)break;te=t[te+8>>2]|0}te=Oe+(Ae+-39)|0;if(!(te&7))Re=0;else Re=0-te&7;te=Oe+(Ae+-47+Re)|0;$=te>>>0<(ue+16|0)>>>0?ue:te;te=$+8|0;ee=ne+8|0;if(!(ee&7))Ne=0;else Ne=0-ee&7;ee=fe+-40-Ne|0;t[82070]=ne+Ne;t[82067]=ee;t[ne+(Ne+4)>>2]=ee|1;t[ne+(fe+-36)>>2]=40;t[82071]=t[82186];t[$+4>>2]=27;t[te+0>>2]=t[82176];t[te+4>>2]=t[82177];t[te+8>>2]=t[82178];t[te+12>>2]=t[82179];t[82176]=ne;t[82177]=fe;t[82179]=0;t[82178]=te;te=$+28|0;t[te>>2]=7;if(($+32|0)>>>0<Me>>>0){ee=te;do{te=ee;ee=ee+4|0;t[ee>>2]=7}while((te+8|0)>>>0<Me>>>0)}if(($|0)!=(ue|0)){ee=$-ue|0;te=ue+(ee+4)|0;t[te>>2]=t[te>>2]&-2;t[ue+4>>2]=ee|1;t[ue+ee>>2]=ee;te=ee>>>3;if(ee>>>0<256){H=te<<1;ie=328296+(H<<2)|0;x=t[82064]|0;J=1<<te;do if(!(x&J)){t[82064]=x|J;Te=328296+(H+2<<2)|0;Le=ie}else{te=328296+(H+2<<2)|0;W=t[te>>2]|0;if(W>>>0>=(t[82068]|0)>>>0){Te=te;Le=W;break}li()}while(0);t[Te>>2]=ue;t[Le+12>>2]=ue;t[ue+8>>2]=Le;t[ue+12>>2]=ie;break}H=ee>>>8;if(H)if(ee>>>0>16777215)De=31;else{J=(H+1048320|0)>>>16&8;x=H<<J;H=(x+520192|0)>>>16&4;$=x<<H;x=($+245760|0)>>>16&2;W=14-(H|J|x)+($<<x>>>15)|0;De=ee>>>(W+7|0)&1|W<<1}else De=0;W=328560+(De<<2)|0;t[ue+28>>2]=De;t[ue+20>>2]=0;t[ue+16>>2]=0;x=t[82065]|0;$=1<<De;if(!(x&$)){t[82065]=x|$;t[W>>2]=ue;t[ue+24>>2]=W;t[ue+12>>2]=ue;t[ue+8>>2]=ue;break}$=t[W>>2]|0;if((De|0)==31)Ce=0;else Ce=25-(De>>>1)|0;i:do if((t[$+4>>2]&-8|0)!=(ee|0)){W=ee<<Ce;x=$;while(1){Pe=x+(W>>>31<<2)+16|0;J=t[Pe>>2]|0;if(!J)break;if((t[J+4>>2]&-8|0)==(ee|0)){Be=J;break i}else{W=W<<1;x=J}}if(Pe>>>0<(t[82068]|0)>>>0)li();else{t[Pe>>2]=ue;t[ue+24>>2]=x;t[ue+12>>2]=ue;t[ue+8>>2]=ue;break e}}else Be=$;while(0);$=Be+8|0;ee=t[$>>2]|0;ie=t[82068]|0;if(Be>>>0>=ie>>>0&ee>>>0>=ie>>>0){t[ee+12>>2]=ue;t[$>>2]=ue;t[ue+8>>2]=ee;t[ue+12>>2]=Be;t[ue+24>>2]=0;break}else li()}}else{ee=t[82068]|0;if((ee|0)==0|ne>>>0<ee>>>0)t[82068]=ne;t[82176]=ne;t[82177]=fe;t[82179]=0;t[82073]=t[82182];t[82072]=-1;ee=0;do{$=ee<<1;ie=328296+($<<2)|0;t[328296+($+3<<2)>>2]=ie;t[328296+($+2<<2)>>2]=ie;ee=ee+1|0}while((ee|0)!=32);ee=ne+8|0;if(!(ee&7))Ie=0;else Ie=0-ee&7;ee=fe+-40-Ie|0;t[82070]=ne+Ie;t[82067]=ee;t[ne+(Ie+4)>>2]=ee|1;t[ne+(fe+-36)>>2]=40;t[82071]=t[82186]}while(0);fe=t[82067]|0;if(fe>>>0>R>>>0){ne=fe-R|0;t[82067]=ne;fe=t[82070]|0;t[82070]=fe+R;t[fe+(R+4)>>2]=ne|1;t[fe+4>>2]=R|3;w=fe+8|0;s=i;return w|0}}t[(ii()|0)>>2]=12;w=0;s=i;return w|0}function Zq(e){e=e|0;var i=0,r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0,S=0,g=0,y=0,F=0,O=0,A=0,M=0,R=0,N=0,T=0,L=0,D=0,C=0,P=0,B=0;i=s;if(!e){s=i;return}r=e+-8|0;n=t[82068]|0;if(r>>>0<n>>>0)li();f=t[e+-4>>2]|0;u=f&3;if((u|0)==1)li();a=f&-8;o=e+(a+-8)|0;do if(!(f&1)){c=t[r>>2]|0;if(!u){s=i;return}l=-8-c|0;b=e+l|0;k=c+a|0;if(b>>>0<n>>>0)li();if((b|0)==(t[82069]|0)){h=e+(a+-4)|0;w=t[h>>2]|0;if((w&3|0)!=3){d=b;v=k;break}t[82066]=k;t[h>>2]=w&-2;t[e+(l+4)>>2]=k|1;t[o>>2]=k;s=i;return}w=c>>>3;if(c>>>0<256){c=t[e+(l+8)>>2]|0;h=t[e+(l+12)>>2]|0;m=328296+(w<<1<<2)|0;if((c|0)!=(m|0)){if(c>>>0<n>>>0)li();if((t[c+12>>2]|0)!=(b|0))li()}if((h|0)==(c|0)){t[82064]=t[82064]&~(1<<w);d=b;v=k;break}if((h|0)!=(m|0)){if(h>>>0<n>>>0)li();m=h+8|0;if((t[m>>2]|0)==(b|0))_=m;else li()}else _=h+8|0;t[c+12>>2]=h;t[_>>2]=c;d=b;v=k;break}c=t[e+(l+24)>>2]|0;h=t[e+(l+12)>>2]|0;do if((h|0)==(b|0)){m=e+(l+20)|0;w=t[m>>2]|0;if(!w){p=e+(l+16)|0;E=t[p>>2]|0;if(!E){S=0;break}else{g=E;y=p}}else{g=w;y=m}while(1){m=g+20|0;w=t[m>>2]|0;if(w){g=w;y=m;continue}m=g+16|0;w=t[m>>2]|0;if(!w)break;else{g=w;y=m}}if(y>>>0<n>>>0)li();else{t[y>>2]=0;S=g;break}}else{m=t[e+(l+8)>>2]|0;if(m>>>0<n>>>0)li();w=m+12|0;if((t[w>>2]|0)!=(b|0))li();p=h+8|0;if((t[p>>2]|0)==(b|0)){t[w>>2]=h;t[p>>2]=m;S=h;break}else li()}while(0);if(c){h=t[e+(l+28)>>2]|0;m=328560+(h<<2)|0;if((b|0)==(t[m>>2]|0)){t[m>>2]=S;if(!S){t[82065]=t[82065]&~(1<<h);d=b;v=k;break}}else{if(c>>>0<(t[82068]|0)>>>0)li();h=c+16|0;if((t[h>>2]|0)==(b|0))t[h>>2]=S;else t[c+20>>2]=S;if(!S){d=b;v=k;break}}h=t[82068]|0;if(S>>>0<h>>>0)li();t[S+24>>2]=c;m=t[e+(l+16)>>2]|0;do if(m)if(m>>>0<h>>>0)li();else{t[S+16>>2]=m;t[m+24>>2]=S;break}while(0);m=t[e+(l+20)>>2]|0;if(m)if(m>>>0<(t[82068]|0)>>>0)li();else{t[S+20>>2]=m;t[m+24>>2]=S;d=b;v=k;break}else{d=b;v=k}}else{d=b;v=k}}else{d=r;v=a}while(0);if(d>>>0>=o>>>0)li();r=e+(a+-4)|0;S=t[r>>2]|0;if(!(S&1))li();if(!(S&2)){if((o|0)==(t[82070]|0)){n=(t[82067]|0)+v|0;t[82067]=n;t[82070]=d;t[d+4>>2]=n|1;if((d|0)!=(t[82069]|0)){s=i;return}t[82069]=0;t[82066]=0;s=i;return}if((o|0)==(t[82069]|0)){n=(t[82066]|0)+v|0;t[82066]=n;t[82069]=d;t[d+4>>2]=n|1;t[d+n>>2]=n;s=i;return}n=(S&-8)+v|0;g=S>>>3;do if(S>>>0>=256){y=t[e+(a+16)>>2]|0;_=t[e+(a|4)>>2]|0;do if((_|0)==(o|0)){u=e+(a+12)|0;f=t[u>>2]|0;if(!f){m=e+(a+8)|0;h=t[m>>2]|0;if(!h){F=0;break}else{O=h;A=m}}else{O=f;A=u}while(1){u=O+20|0;f=t[u>>2]|0;if(f){O=f;A=u;continue}u=O+16|0;f=t[u>>2]|0;if(!f)break;else{O=f;A=u}}if(A>>>0<(t[82068]|0)>>>0)li();else{t[A>>2]=0;F=O;break}}else{u=t[e+a>>2]|0;if(u>>>0<(t[82068]|0)>>>0)li();f=u+12|0;if((t[f>>2]|0)!=(o|0))li();m=_+8|0;if((t[m>>2]|0)==(o|0)){t[f>>2]=_;t[m>>2]=u;F=_;break}else li()}while(0);if(y){_=t[e+(a+20)>>2]|0;k=328560+(_<<2)|0;if((o|0)==(t[k>>2]|0)){t[k>>2]=F;if(!F){t[82065]=t[82065]&~(1<<_);break}}else{if(y>>>0<(t[82068]|0)>>>0)li();_=y+16|0;if((t[_>>2]|0)==(o|0))t[_>>2]=F;else t[y+20>>2]=F;if(!F)break}_=t[82068]|0;if(F>>>0<_>>>0)li();t[F+24>>2]=y;k=t[e+(a+8)>>2]|0;do if(k)if(k>>>0<_>>>0)li();else{t[F+16>>2]=k;t[k+24>>2]=F;break}while(0);k=t[e+(a+12)>>2]|0;if(k)if(k>>>0<(t[82068]|0)>>>0)li();else{t[F+20>>2]=k;t[k+24>>2]=F;break}}}else{k=t[e+a>>2]|0;_=t[e+(a|4)>>2]|0;y=328296+(g<<1<<2)|0;if((k|0)!=(y|0)){if(k>>>0<(t[82068]|0)>>>0)li();if((t[k+12>>2]|0)!=(o|0))li()}if((_|0)==(k|0)){t[82064]=t[82064]&~(1<<g);break}if((_|0)!=(y|0)){if(_>>>0<(t[82068]|0)>>>0)li();y=_+8|0;if((t[y>>2]|0)==(o|0))M=y;else li()}else M=_+8|0;t[k+12>>2]=_;t[M>>2]=k}while(0);t[d+4>>2]=n|1;t[d+n>>2]=n;if((d|0)==(t[82069]|0)){t[82066]=n;s=i;return}else R=n}else{t[r>>2]=S&-2;t[d+4>>2]=v|1;t[d+v>>2]=v;R=v}v=R>>>3;if(R>>>0<256){S=v<<1;r=328296+(S<<2)|0;n=t[82064]|0;M=1<<v;if(n&M){v=328296+(S+2<<2)|0;o=t[v>>2]|0;if(o>>>0<(t[82068]|0)>>>0)li();else{N=v;T=o}}else{t[82064]=n|M;N=328296+(S+2<<2)|0;T=r}t[N>>2]=d;t[T+12>>2]=d;t[d+8>>2]=T;t[d+12>>2]=r;s=i;return}r=R>>>8;if(r)if(R>>>0>16777215)L=31;else{T=(r+1048320|0)>>>16&8;N=r<<T;r=(N+520192|0)>>>16&4;S=N<<r;N=(S+245760|0)>>>16&2;M=14-(r|T|N)+(S<<N>>>15)|0;L=R>>>(M+7|0)&1|M<<1}else L=0;M=328560+(L<<2)|0;t[d+28>>2]=L;t[d+20>>2]=0;t[d+16>>2]=0;N=t[82065]|0;S=1<<L;e:do if(N&S){T=t[M>>2]|0;
	if((L|0)==31)D=0;else D=25-(L>>>1)|0;i:do if((t[T+4>>2]&-8|0)!=(R|0)){r=R<<D;n=T;while(1){C=n+(r>>>31<<2)+16|0;o=t[C>>2]|0;if(!o)break;if((t[o+4>>2]&-8|0)==(R|0)){P=o;break i}else{r=r<<1;n=o}}if(C>>>0<(t[82068]|0)>>>0)li();else{t[C>>2]=d;t[d+24>>2]=n;t[d+12>>2]=d;t[d+8>>2]=d;break e}}else P=T;while(0);T=P+8|0;r=t[T>>2]|0;o=t[82068]|0;if(P>>>0>=o>>>0&r>>>0>=o>>>0){t[r+12>>2]=d;t[T>>2]=d;t[d+8>>2]=r;t[d+12>>2]=P;t[d+24>>2]=0;break}else li()}else{t[82065]=N|S;t[M>>2]=d;t[d+24>>2]=M;t[d+12>>2]=d;t[d+8>>2]=d}while(0);d=(t[82072]|0)+-1|0;t[82072]=d;if(!d)B=328712|0;else{s=i;return}while(1){d=t[B>>2]|0;if(!d)break;else B=d+8|0}t[82072]=-1;s=i;return}function Jq(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0;r=s;do if(e){if(i>>>0>4294967231){t[(ii()|0)>>2]=12;n=0;break}if(i>>>0<11)f=16;else f=i+11&-8;u=TY(e+-8|0,f)|0;if(u){n=u+8|0;break}u=Xq(i)|0;if(!u)n=0;else{a=t[e+-4>>2]|0;o=(a&-8)-((a&3|0)==0?8:4)|0;YY(u|0,e|0,(o>>>0<i>>>0?o:i)|0)|0;Zq(e);n=u}}else n=Xq(i)|0;while(0);s=r;return n|0}function Qq(e){e=e|0;return(e+-48|0)>>>0<10|0}function $q(e){e=e|0;var i=0;if((e|0)==32)i=1;else i=(e+-9|0)>>>0<5;return i&1|0}function eY(e,i,r,f,a){e=e|0;i=i|0;r=r|0;f=f|0;a=a|0;var o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0,S=0,g=0,y=0,F=0,O=0,A=0,M=0,R=0,N=0,T=0,L=0,D=0,C=0,B=0,I=0,H=0,x=0,U=0,z=0,j=0,V=0,q=0,Y=0,G=0,W=0,K=0,X=0,Z=0,J=0,Q=0,$=0,ee=0,ie=0,re=0,ne=0,fe=0,ue=0;o=s;if(i>>>0>36){t[(ii()|0)>>2]=22;c=0;l=0;P=c;s=o;return l|0}b=e+4|0;k=e+100|0;do{h=t[b>>2]|0;if(h>>>0<(t[k>>2]|0)>>>0){t[b>>2]=h+1;w=u[h>>0]|0}else w=nY(e)|0}while(($q(w)|0)!=0);do if((w|0)==43|(w|0)==45){h=((w|0)==45)<<31>>31;d=t[b>>2]|0;if(d>>>0<(t[k>>2]|0)>>>0){t[b>>2]=d+1;v=u[d>>0]|0;m=h;break}else{v=nY(e)|0;m=h;break}}else{v=w;m=0}while(0);w=(i|0)==0;do if((i&-17|0)==0&(v|0)==48){h=t[b>>2]|0;if(h>>>0<(t[k>>2]|0)>>>0){t[b>>2]=h+1;_=u[h>>0]|0}else _=nY(e)|0;if((_|32|0)!=120)if(w){p=8;E=_;S=46;break}else{g=i;y=_;S=32;break}h=t[b>>2]|0;if(h>>>0<(t[k>>2]|0)>>>0){t[b>>2]=h+1;F=u[h>>0]|0}else F=nY(e)|0;if((u[F+328753>>0]|0)>15){h=(t[k>>2]|0)==0;if(!h)t[b>>2]=(t[b>>2]|0)+-1;if(!r){rY(e,0);c=0;l=0;P=c;s=o;return l|0}if(h){c=0;l=0;P=c;s=o;return l|0}t[b>>2]=(t[b>>2]|0)+-1;c=0;l=0;P=c;s=o;return l|0}else{p=16;E=F;S=46}}else{h=w?10:i;if((u[v+328753>>0]|0)>>>0<h>>>0){g=h;y=v;S=32}else{if(t[k>>2]|0)t[b>>2]=(t[b>>2]|0)+-1;rY(e,0);t[(ii()|0)>>2]=22;c=0;l=0;P=c;s=o;return l|0}}while(0);if((S|0)==32)if((g|0)==10){v=y+-48|0;if(v>>>0<10){i=v;v=0;do{v=(v*10|0)+i|0;w=t[b>>2]|0;if(w>>>0<(t[k>>2]|0)>>>0){t[b>>2]=w+1;O=u[w>>0]|0}else O=nY(e)|0;i=O+-48|0}while(i>>>0<10&v>>>0<429496729);A=v;M=0;R=O}else{A=0;M=0;R=y}O=R+-48|0;if(O>>>0<10){v=A;i=M;w=O;O=R;while(1){R=$Y(v|0,i|0,10,0)|0;F=P;r=((w|0)<0)<<31>>31;_=~r;if(F>>>0>_>>>0|(F|0)==(_|0)&R>>>0>~w>>>0){N=w;T=v;L=i;D=O;break}_=jY(R|0,F|0,w|0,r|0)|0;r=P;F=t[b>>2]|0;if(F>>>0<(t[k>>2]|0)>>>0){t[b>>2]=F+1;C=u[F>>0]|0}else C=nY(e)|0;F=C+-48|0;if(F>>>0<10&(r>>>0<429496729|(r|0)==429496729&_>>>0<2576980378)){v=_;i=r;w=F;O=C}else{N=F;T=_;L=r;D=C;break}}if(N>>>0>9){B=L;I=T}else{H=10;x=T;U=L;z=D;S=72}}else{B=M;I=A}}else{p=g;E=y;S=46}e:do if((S|0)==46){if(!(p+-1&p)){y=n[329016+((p*23|0)>>>5&7)>>0]|0;g=n[E+328753>>0]|0;A=g&255;if(A>>>0<p>>>0){M=A;A=0;do{A=M|A<<y;D=t[b>>2]|0;if(D>>>0<(t[k>>2]|0)>>>0){t[b>>2]=D+1;j=u[D>>0]|0}else j=nY(e)|0;V=n[j+328753>>0]|0;M=V&255}while(M>>>0<p>>>0&A>>>0<134217728);q=V;Y=0;G=A;W=j}else{q=g;Y=0;G=0;W=E}M=qY(-1,-1,y|0)|0;D=P;if((q&255)>>>0>=p>>>0|(Y>>>0>D>>>0|(Y|0)==(D|0)&G>>>0>M>>>0)){H=p;x=G;U=Y;z=W;S=72;break}else{K=G;X=Y;Z=q}while(1){L=UY(K|0,X|0,y|0)|0;T=P;N=Z&255|L;L=t[b>>2]|0;if(L>>>0<(t[k>>2]|0)>>>0){t[b>>2]=L+1;J=u[L>>0]|0}else J=nY(e)|0;Z=n[J+328753>>0]|0;if((Z&255)>>>0>=p>>>0|(T>>>0>D>>>0|(T|0)==(D|0)&N>>>0>M>>>0)){H=p;x=N;U=T;z=J;S=72;break e}else{K=N;X=T}}}M=n[E+328753>>0]|0;D=M&255;if(D>>>0<p>>>0){y=D;D=0;do{D=y+(te(D,p)|0)|0;g=t[b>>2]|0;if(g>>>0<(t[k>>2]|0)>>>0){t[b>>2]=g+1;Q=u[g>>0]|0}else Q=nY(e)|0;$=n[Q+328753>>0]|0;y=$&255}while(y>>>0<p>>>0&D>>>0<119304647);ee=$;ie=D;re=0;ne=Q}else{ee=M;ie=0;re=0;ne=E}if((ee&255)>>>0<p>>>0){y=eG(-1,-1,p|0,0)|0;g=P;A=re;T=ie;N=ee;L=ne;while(1){if(A>>>0>g>>>0|(A|0)==(g|0)&T>>>0>y>>>0){H=p;x=T;U=A;z=L;S=72;break e}C=$Y(T|0,A|0,p|0,0)|0;O=P;w=N&255;if(O>>>0>4294967295|(O|0)==-1&C>>>0>~w>>>0){H=p;x=T;U=A;z=L;S=72;break e}i=jY(w|0,0,C|0,O|0)|0;O=P;C=t[b>>2]|0;if(C>>>0<(t[k>>2]|0)>>>0){t[b>>2]=C+1;fe=u[C>>0]|0}else fe=nY(e)|0;N=n[fe+328753>>0]|0;if((N&255)>>>0>=p>>>0){H=p;x=i;U=O;z=fe;S=72;break}else{A=O;T=i;L=fe}}}else{H=p;x=ie;U=re;z=ne;S=72}}while(0);if((S|0)==72)if((u[z+328753>>0]|0)>>>0<H>>>0){do{z=t[b>>2]|0;if(z>>>0<(t[k>>2]|0)>>>0){t[b>>2]=z+1;ue=u[z>>0]|0}else ue=nY(e)|0}while((u[ue+328753>>0]|0)>>>0<H>>>0);t[(ii()|0)>>2]=34;B=a;I=f}else{B=U;I=x}if(t[k>>2]|0)t[b>>2]=(t[b>>2]|0)+-1;if(!(B>>>0<a>>>0|(B|0)==(a|0)&I>>>0<f>>>0)){if(!((f&1|0)!=0|0!=0|(m|0)!=0)){t[(ii()|0)>>2]=34;b=jY(f|0,a|0,-1,-1)|0;c=P;l=b;P=c;s=o;return l|0}if(B>>>0>a>>>0|(B|0)==(a|0)&I>>>0>f>>>0){t[(ii()|0)>>2]=34;c=a;l=f;P=c;s=o;return l|0}}f=((m|0)<0)<<31>>31;a=BY(I^m|0,B^f|0,m|0,f|0)|0;c=P;l=a;P=c;s=o;return l|0}function iY(e,i,r){e=e|0;i=i|0;r=r|0;var f=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0,S=0,g=0,O=0,A=0,M=0,R=0,N=0,T=0,L=0,D=0,C=0,B=0,I=0,H=0,x=0,U=0,z=0,j=0,V=0,q=0,Y=0,W=0,K=0,X=0,Z=0,J=0,Q=0,$=0,ee=0,ie=0,re=0,ne=0,fe=0,ue=0,ae=0,oe=0,ce=0,le=0,se=0,be=0,ke=0,he=0,we=0,de=0,ve=0,me=0,_e=0,pe=0,Ee=0,Se=0,ge=0,ye=0,Fe=0,Oe=0,Ae=0,Me=0,Re=0,Ne=0,Te=0,Le=0,De=0,Ce=0,Pe=0,Be=0,Ie=0,He=0,xe=0,Ue=0,ze=0,je=0,Ve=0,qe=0,Ye=0,Ge=0,We=0,Ke=0,Xe=0,Ze=0,Je=0,Qe=0,$e=0,ei=0,ri=0,ni=0,fi=0,ti=0,ui=0,ai=0,oi=0,ci=0,li=0,si=0,bi=0,ki=0,hi=0,wi=0,di=0,vi=0,mi=0,_i=0,pi=0,Ei=0,Si=0,gi=0,yi=0,Fi=0,Oi=0,Ai=0,Mi=0,Ri=0,Ni=0,Ti=0,Li=0,Di=0,Ci=0,Pi=0,Bi=0,Ii=0,Hi=0,xi=0,Ui=0,zi=0,ji=0,Vi=0,qi=0,Yi=0,Gi=0,Wi=0,Ki=0,Xi=0,Zi=0,Ji=0,Qi=0,$i=0,er=0,ir=0,rr=0,nr=0,fr=0,tr=0,ur=0,ar=0,or=0,cr=0,lr=0,sr=0,br=0,kr=0,hr=0,wr=0,dr=0,vr=0,mr=0,_r=0,pr=0,Er=0,Sr=0,gr=0,yr=0,Fr=0,Or=0,Ar=0,Mr=0,Rr=0,Nr=0,Tr=0,Lr=0,Dr=0,Cr=0,Pr=0,Br=0,Ir=0,Hr=0,xr=0,Ur=0,zr=0,jr=0,Vr=0,qr=0,Yr=0,Gr=0,Wr=0,Kr=0;f=s;s=s+512|0;a=f;if(!i){o=24;c=-149}else if((i|0)==1){o=53;c=-1074}else if((i|0)==2){o=53;c=-1074}else{l=0;s=f;return+l}i=e+4|0;b=e+100|0;do{k=t[i>>2]|0;if(k>>>0<(t[b>>2]|0)>>>0){t[i>>2]=k+1;h=u[k>>0]|0}else h=nY(e)|0}while(($q(h)|0)!=0);do if((h|0)==43|(h|0)==45){k=1-(((h|0)==45&1)<<1)|0;w=t[i>>2]|0;if(w>>>0<(t[b>>2]|0)>>>0){t[i>>2]=w+1;d=u[w>>0]|0;v=k;break}else{d=nY(e)|0;v=k;break}}else{d=h;v=1}while(0);h=d;d=0;while(1){if((h|32|0)!=(n[329032+d>>0]|0)){m=h;_=d;break}do if(d>>>0<7){k=t[i>>2]|0;if(k>>>0<(t[b>>2]|0)>>>0){t[i>>2]=k+1;p=u[k>>0]|0;break}else{p=nY(e)|0;break}}else p=h;while(0);k=d+1|0;if(k>>>0<8){h=p;d=k}else{m=p;_=k;break}}do if((_|0)==3)E=23;else if((_|0)!=8){p=(r|0)!=0;if(_>>>0>3&p)if((_|0)==8)break;else{E=23;break}e:do if(!_){d=m;h=0;while(1){if((d|32|0)!=(n[329048+h>>0]|0)){S=d;g=h;break e}do if(h>>>0<2){k=t[i>>2]|0;if(k>>>0<(t[b>>2]|0)>>>0){t[i>>2]=k+1;O=u[k>>0]|0;break}else{O=nY(e)|0;break}}else O=d;while(0);k=h+1|0;if(k>>>0<3){d=O;h=k}else{S=O;g=k;break}}}else{S=m;g=_}while(0);if((g|0)==3){h=t[i>>2]|0;if(h>>>0<(t[b>>2]|0)>>>0){t[i>>2]=h+1;A=u[h>>0]|0}else A=nY(e)|0;if((A|0)==40)M=1;else{if(!(t[b>>2]|0)){l=y;s=f;return+l}t[i>>2]=(t[i>>2]|0)+-1;l=y;s=f;return+l}while(1){h=t[i>>2]|0;if(h>>>0<(t[b>>2]|0)>>>0){t[i>>2]=h+1;R=u[h>>0]|0}else R=nY(e)|0;if(!((R+-48|0)>>>0<10|(R+-65|0)>>>0<26)?!((R+-97|0)>>>0<26|(R|0)==95):0)break;M=M+1|0}if((R|0)==41){l=y;s=f;return+l}h=(t[b>>2]|0)==0;if(!h)t[i>>2]=(t[i>>2]|0)+-1;if(!p){t[(ii()|0)>>2]=22;rY(e,0);l=0;s=f;return+l}if((M|0)==0|h){l=y;s=f;return+l}else N=M;do{N=N+-1|0;t[i>>2]=(t[i>>2]|0)+-1}while((N|0)!=0);l=y;s=f;return+l}else if(!g){do if((S|0)==48){p=t[i>>2]|0;if(p>>>0<(t[b>>2]|0)>>>0){t[i>>2]=p+1;T=u[p>>0]|0}else T=nY(e)|0;if((T|32|0)!=120){if(!(t[b>>2]|0)){L=48;break}t[i>>2]=(t[i>>2]|0)+-1;L=48;break}p=t[i>>2]|0;if(p>>>0<(t[b>>2]|0)>>>0){t[i>>2]=p+1;D=u[p>>0]|0;C=0}else{D=nY(e)|0;C=0}while(1){if((D|0)==46){E=70;break}else if((D|0)!=48){B=0;I=0;H=0;x=0;U=D;z=C;j=0;V=0;q=1;Y=0;W=0;break}p=t[i>>2]|0;if(p>>>0<(t[b>>2]|0)>>>0){t[i>>2]=p+1;D=u[p>>0]|0;C=1;continue}else{D=nY(e)|0;C=1;continue}}if((E|0)==70){p=t[i>>2]|0;if(p>>>0<(t[b>>2]|0)>>>0){t[i>>2]=p+1;K=u[p>>0]|0}else K=nY(e)|0;if((K|0)==48){p=0;h=0;while(1){d=t[i>>2]|0;if(d>>>0<(t[b>>2]|0)>>>0){t[i>>2]=d+1;X=u[d>>0]|0}else X=nY(e)|0;d=jY(p|0,h|0,-1,-1)|0;k=P;if((X|0)==48){p=d;h=k}else{B=0;I=0;H=d;x=k;U=X;z=1;j=1;V=0;q=1;Y=0;W=0;break}}}else{B=0;I=0;H=0;x=0;U=K;z=C;j=1;V=0;q=1;Y=0;W=0}}e:while(1){h=U+-48|0;do if(h>>>0>=10){p=U|32;k=(U|0)==46;if(!((p+-97|0)>>>0<6|k)){Z=U;break e}if(k)if(!j){J=I;Q=B;$=I;ee=B;ie=z;re=1;ne=V;fe=q;ue=Y;ae=W;break}else{Z=46;break e}else{oe=(U|0)>57?p+-87|0:h;E=83;break}}else{oe=h;E=83}while(0);if((E|0)==83){E=0;do if(!((B|0)<0|(B|0)==0&I>>>0<8)){if((B|0)<0|(B|0)==0&I>>>0<14){ce=q*.0625;le=V;se=ce;be=Y;ke=W+ce*+(oe|0);break}if((oe|0)==0|(V|0)!=0){le=V;se=q;be=Y;ke=W}else{le=1;se=q;be=Y;ke=W+q*.5}}else{le=V;se=q;be=oe+(Y<<4)|0;ke=W}while(0);h=jY(I|0,B|0,1,0)|0;J=H;Q=x;$=h;ee=P;ie=1;re=j;ne=le;fe=se;ue=be;ae=ke}h=t[i>>2]|0;if(h>>>0<(t[b>>2]|0)>>>0){t[i>>2]=h+1;B=ee;I=$;H=J;x=Q;U=u[h>>0]|0;z=ie;j=re;V=ne;q=fe;Y=ue;W=ae;continue}else{B=ee;I=$;H=J;x=Q;U=nY(e)|0;z=ie;j=re;V=ne;q=fe;Y=ue;W=ae;continue}}if(!z){h=(t[b>>2]|0)==0;if(!h)t[i>>2]=(t[i>>2]|0)+-1;if(r){if(!h?(h=t[i>>2]|0,t[i>>2]=h+-1,(j|0)!=0):0)t[i>>2]=h+-2}else rY(e,0);l=+(v|0)*0;s=f;return+l}h=(j|0)==0;p=h?I:H;k=h?B:x;if((B|0)<0|(B|0)==0&I>>>0<8){h=I;d=B;w=Y;while(1){he=w<<4;h=jY(h|0,d|0,1,0)|0;d=P;if(!((d|0)<0|(d|0)==0&h>>>0<8)){we=he;break}else w=he}}else we=Y;do if((Z|32|0)==112){w=DY(e,r)|0;h=P;if((w|0)==0&(h|0)==-2147483648)if(!r){rY(e,0);l=0;s=f;return+l}else{if(!(t[b>>2]|0)){de=0;ve=0;break}t[i>>2]=(t[i>>2]|0)+-1;de=0;ve=0;break}else{de=w;ve=h}}else if(!(t[b>>2]|0)){de=0;ve=0}else{t[i>>2]=(t[i>>2]|0)+-1;de=0;ve=0}while(0);h=UY(p|0,k|0,2)|0;w=jY(h|0,P|0,-32,-1)|0;h=jY(w|0,P|0,de|0,ve|0)|0;w=P;if(!we){l=+(v|0)*0;s=f;return+l}if((w|0)>0|(w|0)==0&h>>>0>(0-c|0)>>>0){t[(ii()|0)>>2]=34;l=+(v|0)*1.7976931348623157e308*1.7976931348623157e308;s=f;return+l}d=c+-106|0;he=((d|0)<0)<<31>>31;if((w|0)<(he|0)|(w|0)==(he|0)&h>>>0<d>>>0){t[(ii()|0)>>2]=34;l=+(v|0)*2.2250738585072014e-308*2.2250738585072014e-308;s=f;return+l}if((we|0)>-1){d=h;he=w;me=we;ce=W;while(1){_e=me<<1;if(!(ce>=.5)){pe=ce;Ee=_e}else{pe=ce+-1;Ee=_e|1}Se=ce+pe;_e=jY(d|0,he|0,-1,-1)|0;ge=P;if((Ee|0)>-1){d=_e;he=ge;me=Ee;ce=Se}else{ye=_e;Fe=ge;Oe=Ee;Ae=Se;break}}}else{ye=h;Fe=w;Oe=we;Ae=W}me=BY(32,0,c|0,((c|0)<0)<<31>>31|0)|0;he=jY(ye|0,Fe|0,me|0,P|0)|0;me=P;if(0>(me|0)|0==(me|0)&o>>>0>he>>>0)if((he|0)<0){Me=0;E=126}else{Re=he;E=124}else{Re=o;E=124}if((E|0)==124)if((Re|0)<53){Me=Re;E=126}else{Ne=Re;Te=+(v|0);Le=0}if((E|0)==126){ce=+(v|0);Ne=Me;Te=ce;Le=+uY(+kY(1,84-Me|0),ce)}he=(Ne|0)<32&Ae!=0&(Oe&1|0)==0;ce=Te*(he?0:Ae)+(Le+Te*+(((he&1)+Oe|0)>>>0))-Le;if(!(ce!=0))t[(ii()|0)>>2]=34;l=+hY(ce,ye);s=f;return+l}else L=S;while(0);he=c+o|0;me=0-he|0;d=L;k=0;while(1){if((d|0)==46){E=137;break}else if((d|0)!=48){De=d;Ce=0;Pe=0;Be=k;Ie=0;break}p=t[i>>2]|0;if(p>>>0<(t[b>>2]|0)>>>0){t[i>>2]=p+1;d=u[p>>0]|0;k=1;continue}else{d=nY(e)|0;k=1;continue}}if((E|0)==137){d=t[i>>2]|0;if(d>>>0<(t[b>>2]|0)>>>0){t[i>>2]=d+1;He=u[d>>0]|0}else He=nY(e)|0;if((He|0)==48){d=0;p=0;while(1){ge=jY(d|0,p|0,-1,-1)|0;_e=P;xe=t[i>>2]|0;if(xe>>>0<(t[b>>2]|0)>>>0){t[i>>2]=xe+1;Ue=u[xe>>0]|0}else Ue=nY(e)|0;if((Ue|0)==48){d=ge;p=_e}else{De=Ue;Ce=ge;Pe=_e;Be=1;Ie=1;break}}}else{De=He;Ce=0;Pe=0;Be=k;Ie=1}}t[a>>2]=0;p=De+-48|0;d=(De|0)==46;e:do if(p>>>0<10|d){_e=a+496|0;ge=De;xe=0;ze=0;je=d;Ve=p;qe=Ce;Ye=Pe;Ge=Be;We=Ie;Ke=0;Xe=0;Ze=0;i:while(1){do if(je)if(!We){Je=xe;Qe=ze;$e=xe;ei=ze;ri=Ge;ni=1;fi=Ke;ti=Xe;ui=Ze}else break i;else{ai=jY(xe|0,ze|0,1,0)|0;oi=P;ci=(ge|0)!=48;if((Xe|0)>=125){if(!ci){Je=qe;Qe=Ye;$e=ai;ei=oi;ri=Ge;ni=We;fi=Ke;ti=Xe;ui=Ze;break}t[_e>>2]=t[_e>>2]|1;Je=qe;Qe=Ye;$e=ai;ei=oi;ri=Ge;ni=We;fi=Ke;ti=Xe;ui=Ze;break}li=a+(Xe<<2)|0;if(!Ke)si=Ve;else si=ge+-48+((t[li>>2]|0)*10|0)|0;t[li>>2]=si;li=Ke+1|0;bi=(li|0)==9;Je=qe;Qe=Ye;$e=ai;ei=oi;ri=1;ni=We;fi=bi?0:li;ti=(bi&1)+Xe|0;ui=ci?ai:Ze}while(0);ai=t[i>>2]|0;if(ai>>>0<(t[b>>2]|0)>>>0){t[i>>2]=ai+1;ki=u[ai>>0]|0}else ki=nY(e)|0;Ve=ki+-48|0;je=(ki|0)==46;if(!(Ve>>>0<10|je)){hi=ki;wi=Je;di=$e;vi=Qe;mi=ei;_i=ri;pi=ni;Ei=fi;Si=ti;gi=ui;E=160;break e}else{ge=ki;xe=$e;ze=ei;qe=Je;Ye=Qe;Ge=ri;We=ni;Ke=fi;Xe=ti;Ze=ui}}yi=xe;Fi=ze;Oi=qe;Ai=Ye;Mi=(Ge|0)!=0;Ri=Ke;Ni=Xe;Ti=Ze;E=168}else{hi=De;wi=Ce;di=0;vi=Pe;mi=0;_i=Be;pi=Ie;Ei=0;Si=0;gi=0;E=160}while(0);do if((E|0)==160){p=(pi|0)==0;d=p?di:wi;k=p?mi:vi;p=(_i|0)!=0;if(!(p&(hi|32|0)==101))if((hi|0)>-1){yi=di;Fi=mi;Oi=d;Ai=k;Mi=p;Ri=Ei;Ni=Si;Ti=gi;E=168;break}else{Li=di;Di=mi;Ci=p;Pi=d;Bi=k;Ii=Ei;Hi=Si;xi=gi;E=170;break}p=DY(e,r)|0;We=P;do if((p|0)==0&(We|0)==-2147483648)if(!r){rY(e,0);l=0;s=f;return+l}else{if(!(t[b>>2]|0)){Ui=0;zi=0;break}t[i>>2]=(t[i>>2]|0)+-1;Ui=0;zi=0;break}else{Ui=p;zi=We}while(0);We=jY(Ui|0,zi|0,d|0,k|0)|0;ji=We;Vi=di;qi=P;Yi=mi;Gi=Ei;Wi=Si;Ki=gi}while(0);if((E|0)==168)if(t[b>>2]|0){t[i>>2]=(t[i>>2]|0)+-1;if(Mi){ji=Oi;Vi=yi;qi=Ai;Yi=Fi;Gi=Ri;Wi=Ni;Ki=Ti}else E=171}else{Li=yi;Di=Fi;Ci=Mi;Pi=Oi;Bi=Ai;Ii=Ri;Hi=Ni;xi=Ti;E=170}if((E|0)==170)if(Ci){ji=Pi;Vi=Li;qi=Bi;Yi=Di;Gi=Ii;Wi=Hi;Ki=xi}else E=171;if((E|0)==171){t[(ii()|0)>>2]=22;rY(e,0);l=0;s=f;return+l}We=t[a>>2]|0;if(!We){l=+(v|0)*0;s=f;return+l}if((ji|0)==(Vi|0)&(qi|0)==(Yi|0)&((Yi|0)<0|(Yi|0)==0&Vi>>>0<10)?o>>>0>30|(We>>>o|0)==0:0){l=+(v|0)*+(We>>>0);s=f;return+l}We=(c|0)/-2|0;p=((We|0)<0)<<31>>31;if((qi|0)>(p|0)|(qi|0)==(p|0)&ji>>>0>We>>>0){t[(ii()|0)>>2]=34;l=+(v|0)*1.7976931348623157e308*1.7976931348623157e308;s=f;return+l}We=c+-106|0;p=((We|0)<0)<<31>>31;if((qi|0)<(p|0)|(qi|0)==(p|0)&ji>>>0<We>>>0){t[(ii()|0)>>2]=34;l=+(v|0)*2.2250738585072014e-308*2.2250738585072014e-308;s=f;return+l}if(!Gi)Xi=Wi;else{if((Gi|0)<9){We=a+(Wi<<2)|0;p=t[We>>2]|0;Ze=Gi;do{p=p*10|0;Ze=Ze+1|0}while((Ze|0)!=9);t[We>>2]=p}Xi=Wi+1|0}if((Ki|0)<9?(Ki|0)<=(ji|0)&(ji|0)<18:0){if((ji|0)==9){l=+(v|0)*+((t[a>>2]|0)>>>0);s=f;return+l}if((ji|0)<9){l=+(v|0)*+((t[a>>2]|0)>>>0)/+(t[329064+(8-ji<<2)>>2]|0);s=f;return+l}Ze=o+27+(te(ji,-3)|0)|0;Xe=t[a>>2]|0;if((Ze|0)>30|(Xe>>>Ze|0)==0){l=+(v|0)*+(Xe>>>0)*+(t[329064+(ji+-10<<2)>>2]|0);s=f;return+l}}Xe=(ji|0)%9|0;if(!Xe){Zi=0;Ji=0;Qi=ji;$i=Xi}else{Ze=(ji|0)>-1?Xe:Xe+9|0;Xe=t[329064+(8-Ze<<2)>>2]|0;if(Xi){Ke=1e9/(Xe|0)|0;Ge=0;Ye=0;qe=0;ze=ji;while(1){xe=a+(qe<<2)|0;ge=t[xe>>2]|0;je=((ge>>>0)/(Xe>>>0)|0)+Ye|0;t[xe>>2]=je;Ye=te((ge>>>0)%(Xe>>>0)|0,Ke)|0;ge=qe;qe=qe+1|0;if((ge|0)==(Ge|0)&(je|0)==0){er=qe&127;ir=ze+-9|0}else{er=Ge;ir=ze}if((qe|0)==(Xi|0))break;else{Ge=er;ze=ir}}if(!Ye){rr=er;nr=ir;fr=Xi}else{t[a+(Xi<<2)>>2]=Ye;rr=er;nr=ir;fr=Xi+1|0}}else{rr=0;nr=ji;fr=0}Zi=rr;Ji=0;Qi=9-Ze+nr|0;$i=fr}e:while(1){ze=a+(Zi<<2)|0;if((Qi|0)<18){Ge=Ji;qe=$i;while(1){Ke=0;Xe=qe+127|0;p=qe;while(1){We=Xe&127;je=a+(We<<2)|0;ge=UY(t[je>>2]|0,0,29)|0;xe=jY(ge|0,P|0,Ke|0,0)|0;ge=P;if(ge>>>0>0|(ge|0)==0&xe>>>0>1e9){Ve=eG(xe|0,ge|0,1e9,0)|0;_e=iG(xe|0,ge|0,1e9,0)|0;tr=_e;ur=Ve}else{tr=xe;ur=0}t[je>>2]=tr;je=(We|0)==(Zi|0);if((We|0)!=(p+127&127|0)|je)ar=p;else ar=(tr|0)==0?We:p;if(je)break;else{Ke=ur;Xe=We+-1|0;p=ar}}p=Ge+-29|0;if(!ur){Ge=p;qe=ar}else{or=p;cr=ur;lr=ar;break}}}else{if((Qi|0)==18){sr=Ji;br=$i}else{kr=Zi;hr=Ji;wr=Qi;dr=$i;break}while(1){if((t[ze>>2]|0)>>>0>=9007199){kr=Zi;hr=sr;wr=18;dr=br;break e}qe=0;Ge=br+127|0;k=br;while(1){d=Ge&127;p=a+(d<<2)|0;Xe=UY(t[p>>2]|0,0,29)|0;Ke=jY(Xe|0,P|0,qe|0,0)|0;Xe=P;if(Xe>>>0>0|(Xe|0)==0&Ke>>>0>1e9){We=eG(Ke|0,Xe|0,1e9,0)|0;je=iG(Ke|0,Xe|0,1e9,0)|0;vr=je;mr=We}else{vr=Ke;mr=0}t[p>>2]=vr;p=(d|0)==(Zi|0);if((d|0)!=(k+127&127|0)|p)_r=k;else _r=(vr|0)==0?d:k;if(p)break;else{qe=mr;Ge=d+-1|0;k=_r}}k=sr+-29|0;if(!mr){sr=k;br=_r}else{or=k;cr=mr;lr=_r;break}}}ze=Zi+127&127;if((ze|0)==(lr|0)){k=lr+127&127;Ge=a+((lr+126&127)<<2)|0;t[Ge>>2]=t[Ge>>2]|t[a+(k<<2)>>2];pr=k}else pr=lr;t[a+(ze<<2)>>2]=cr;Zi=ze;Ji=or;Qi=Qi+9|0;$i=pr}e:while(1){Er=dr+1&127;Ze=a+((dr+127&127)<<2)|0;Ye=kr;ze=hr;k=wr;while(1){Ge=(k|0)==18;qe=(k|0)>27?9:1;Sr=Ye;gr=ze;while(1){d=0;while(1){p=d+Sr&127;if((p|0)==(dr|0)){yr=2;break}Ke=t[a+(p<<2)>>2]|0;p=t[329056+(d<<2)>>2]|0;if(Ke>>>0<p>>>0){yr=2;break}We=d+1|0;if(Ke>>>0>p>>>0){yr=d;break}if((We|0)<2)d=We;else{yr=We;break}}if((yr|0)==2&Ge)break e;Fr=qe+gr|0;if((Sr|0)==(dr|0)){Sr=dr;gr=Fr}else break}Ge=(1<<qe)+-1|0;d=1e9>>>qe;Or=Sr;Ar=0;We=Sr;Mr=k;do{p=a+(We<<2)|0;Ke=t[p>>2]|0;je=(Ke>>>qe)+Ar|0;t[p>>2]=je;Ar=te(Ke&Ge,d)|0;Ke=(We|0)==(Or|0)&(je|0)==0;We=We+1&127;Mr=Ke?Mr+-9|0:Mr;Or=Ke?We:Or}while((We|0)!=(dr|0));if(!Ar){Ye=Or;ze=Fr;k=Mr;continue}if((Er|0)!=(Or|0))break;t[Ze>>2]=t[Ze>>2]|1;Ye=Or;ze=Fr;k=Mr}t[a+(dr<<2)>>2]=Ar;kr=Or;hr=Fr;wr=Mr;dr=Er}k=Sr&127;if((k|0)==(dr|0)){t[a+(Er+-1<<2)>>2]=0;Rr=Er}else Rr=dr;ce=+((t[a+(k<<2)>>2]|0)>>>0);k=Sr+1&127;if((k|0)==(Rr|0)){ze=Rr+1&127;t[a+(ze+-1<<2)>>2]=0;Nr=ze}else Nr=Rr;Se=+(v|0);Tr=Se*(ce*1e9+ +((t[a+(k<<2)>>2]|0)>>>0));k=gr+53|0;ze=k-c|0;if((ze|0)<(o|0))if((ze|0)<0){Lr=0;Dr=1;E=244}else{Cr=ze;Pr=1;E=243}else{Cr=o;Pr=0;E=243}if((E|0)==243)if((Cr|0)<53){Lr=Cr;Dr=Pr;E=244}else{Br=Cr;Ir=0;Hr=Pr;xr=0;Ur=Tr}if((E|0)==244){ce=+uY(+kY(1,105-Lr|0),Tr);zr=+oY(Tr,+kY(1,53-Lr|0));Br=Lr;Ir=ce;Hr=Dr;xr=zr;Ur=ce+(Tr-zr)}Ye=Sr+2&127;do if((Ye|0)==(Nr|0))jr=xr;else{Ze=t[a+(Ye<<2)>>2]|0;do if(Ze>>>0>=5e8){if(Ze>>>0>5e8){Vr=Se*.75+xr;break}if((Sr+3&127|0)==(Nr|0)){Vr=Se*.5+xr;break}else{Vr=Se*.75+xr;break}}else{if((Ze|0)==0?(Sr+3&127|0)==(Nr|0):0){Vr=xr;break}Vr=Se*.25+xr}while(0);if((53-Br|0)<=1){jr=Vr;break}if(+oY(Vr,1)!=0){jr=Vr;break}jr=Vr+1}while(0);Se=Ur+jr-Ir;do if((k&2147483647|0)>(-2-he|0)){if(!(+G(+Se)>=9007199254740992)){qr=Hr;Yr=gr;Gr=Se}else{qr=(Hr|0)!=0&(Br|0)==(ze|0)?0:Hr;Yr=gr+1|0;Gr=Se*.5}if((Yr+50|0)<=(me|0)?!((qr|0)!=0&jr!=0):0){Wr=Yr;Kr=Gr;break}t[(ii()|0)>>2]=34;Wr=Yr;Kr=Gr}else{Wr=gr;Kr=Se}while(0);l=+hY(Kr,Wr);s=f;return+l}else{if(t[b>>2]|0)t[i>>2]=(t[i>>2]|0)+-1;t[(ii()|0)>>2]=22;rY(e,0);l=0;s=f;return+l}}while(0);if((E|0)==23){E=(t[b>>2]|0)==0;if(!E)t[i>>2]=(t[i>>2]|0)+-1;if(!(_>>>0<4|(r|0)==0|E)){E=_;do{t[i>>2]=(t[i>>2]|0)+-1;E=E+-1|0}while(E>>>0>3)}}l=+(v|0)*F;s=f;return+l}function rY(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0;r=s;t[e+104>>2]=i;n=t[e+8>>2]|0;f=t[e+4>>2]|0;u=n-f|0;t[e+108>>2]=u;if((i|0)!=0&(u|0)>(i|0)){t[e+100>>2]=f+i;s=r;return}else{t[e+100>>2]=n;s=r;return}}function nY(e){e=e|0;var i=0,r=0,f=0,a=0,o=0,c=0,l=0;i=s;r=e+104|0;f=t[r>>2]|0;if(!((f|0)!=0?(t[e+108>>2]|0)>=(f|0):0))a=3;if((a|0)==3?(a=pY(e)|0,(a|0)>=0):0){f=t[r>>2]|0;r=t[e+8>>2]|0;if((f|0)!=0?(o=t[e+4>>2]|0,c=f-(t[e+108>>2]|0)+-1|0,(r-o|0)>(c|0)):0)t[e+100>>2]=o+c;else t[e+100>>2]=r;c=t[e+4>>2]|0;if(r){o=e+108|0;t[o>>2]=r+1-c+(t[o>>2]|0)}o=c+-1|0;if((u[o>>0]|0|0)==(a|0)){l=a;s=i;return l|0}n[o>>0]=a;l=a;s=i;return l|0}t[e+100>>2]=0;l=-1;s=i;return l|0}function fY(e){e=+e;var i=0,r=0,n=0,f=0,u=0,a=0;i=s;l[k>>3]=e;r=t[k>>2]|0;n=t[k+4>>2]|0;f=qY(r|0,n|0,52)|0;u=f&2047;if((u|0)==2047){a=(r|0)==0&(n&1048575|0)==0&1;s=i;return a|0}else if(!u){a=(r|0)!=0|(n&2147483647|0)!=0?3:2;s=i;return a|0}else{a=4;s=i;return a|0}return 0}function tY(e,i){e=+e;i=+i;var r=0,n=0,f=0,u=0;r=s;l[k>>3]=e;n=t[k>>2]|0;f=t[k+4>>2]|0;l[k>>3]=i;u=t[k+4>>2]&-2147483648|f&2147483647;t[k>>2]=n;t[k+4>>2]=u;i=+l[k>>3];s=r;return+i}function uY(e,i){e=+e;i=+i;var r=0,n=0;r=s;n=+tY(e,i);s=r;return+n}function aY(e,i){e=+e;i=+i;var r=0,n=0,f=0,u=0,a=0,o=0,c=0,b=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0,S=0,g=0,y=0,F=0,O=0,A=0,M=0,R=0,N=0,T=0,L=0,D=0,C=0,B=0,I=0,H=0,x=0,U=0,z=0,j=0,V=0,q=0,Y=0,G=0;r=s;l[k>>3]=e;n=t[k>>2]|0;f=t[k+4>>2]|0;l[k>>3]=i;u=t[k>>2]|0;a=t[k+4>>2]|0;o=qY(n|0,f|0,52)|0;c=o&2047;o=qY(u|0,a|0,52)|0;b=o&2047;o=f&-2147483648;h=UY(u|0,a|0,1)|0;w=P;if(!((h|0)==0&(w|0)==0)?(d=a&2147483647,!(d>>>0>2146435072|(d|0)==2146435072&u>>>0>0|(c|0)==2047)):0){d=UY(n|0,f|0,1)|0;v=P;if(!(v>>>0>w>>>0|(v|0)==(w|0)&d>>>0>h>>>0)){if(!((d|0)==(h|0)&(v|0)==(w|0))){m=e;s=r;return+m}m=e*0;s=r;return+m}if(!c){w=UY(n|0,f|0,12)|0;v=P;if((v|0)>-1|(v|0)==-1&w>>>0>4294967295){h=w;w=v;v=0;while(1){d=v+-1|0;h=UY(h|0,w|0,1)|0;w=P;if(!((w|0)>-1|(w|0)==-1&h>>>0>4294967295)){_=d;break}else v=d}}else _=0;v=UY(n|0,f|0,1-_|0)|0;p=v;E=P;S=_}else{p=n;E=f&1048575|1048576;S=c}if(!b){c=UY(u|0,a|0,12)|0;f=P;if((f|0)>-1|(f|0)==-1&c>>>0>4294967295){n=c;c=f;f=0;while(1){_=f+-1|0;n=UY(n|0,c|0,1)|0;c=P;if(!((c|0)>-1|(c|0)==-1&n>>>0>4294967295)){g=_;break}else f=_}}else g=0;f=UY(u|0,a|0,1-g|0)|0;y=f;F=P;O=g}else{y=u;F=a&1048575|1048576;O=b}b=BY(p|0,E|0,y|0,F|0)|0;a=P;u=(a|0)>-1|(a|0)==-1&b>>>0>4294967295;e:do if((S|0)>(O|0)){g=u;f=b;n=a;c=p;_=E;v=S;while(1){if(g)if((c|0)==(y|0)&(_|0)==(F|0))break;else{A=f;M=n}else{A=c;M=_}h=UY(A|0,M|0,1)|0;w=P;d=v+-1|0;R=BY(h|0,w|0,y|0,F|0)|0;N=P;T=(N|0)>-1|(N|0)==-1&R>>>0>4294967295;if((d|0)>(O|0)){g=T;f=R;n=N;c=h;_=w;v=d}else{L=T;D=h;C=w;B=R;I=N;H=d;break e}}m=e*0;s=r;return+m}else{L=u;D=p;C=E;B=b;I=a;H=S}while(0);if(L)if((D|0)==(y|0)&(C|0)==(F|0)){m=e*0;s=r;return+m}else{x=I;U=B}else{x=C;U=D}if(x>>>0<1048576|(x|0)==1048576&U>>>0<0){D=U;C=x;B=H;while(1){I=UY(D|0,C|0,1)|0;F=P;y=B+-1|0;if(F>>>0<1048576|(F|0)==1048576&I>>>0<0){D=I;C=F;B=y}else{z=I;j=F;V=y;break}}}else{z=U;j=x;V=H}if((V|0)>0){H=jY(z|0,j|0,0,-1048576)|0;x=P;U=UY(V|0,0,52)|0;q=x|P;Y=H|U}else{U=qY(z|0,j|0,1-V|0)|0;q=P;Y=U}t[k>>2]=Y;t[k+4>>2]=q|o;m=+l[k>>3];s=r;return+m}G=e*i;m=G/G;s=r;return+m}function oY(e,i){e=+e;i=+i;var r=0,n=0;r=s;n=+aY(e,i);s=r;return+n}function cY(e,i){e=+e;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0,b=0,h=0;r=s;l[k>>3]=e;n=t[k>>2]|0;f=t[k+4>>2]|0;u=qY(n|0,f|0,52)|0;a=u&2047;if(!a){if(e!=0){o=+cY(e*0x10000000000000000,i);c=o;b=(t[i>>2]|0)+-64|0}else{c=e;b=0}t[i>>2]=b;h=c;s=r;return+h}else if((a|0)==2047){h=e;s=r;return+h}else{t[i>>2]=a+-1022;t[k>>2]=n;t[k+4>>2]=f&-2146435073|1071644672;h=+l[k>>3];s=r;return+h}return+0}function lY(e,i){e=+e;i=i|0;var r=0,n=0;r=s;n=+cY(e,i);s=r;return+n}function sY(e){e=+e;var i=0,r=0,n=0,f=0,u=0,a=0,o=0,c=0,b=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0;i=s;l[k>>3]=e;r=t[k>>2]|0;n=t[k+4>>2]|0;f=(n|0)<0;do if(!(n>>>0<1048576|f)){if(n>>>0>2146435071){u=e;s=i;return+u}if((n|0)==1072693248&((r|0)==0&0==0)){u=0;s=i;return+u}else{a=r;o=n;c=n;b=-1023}}else{if((r|0)==0&(n&2147483647|0)==0){u=-1/(e*e);s=i;return+u}if(!f){l[k>>3]=e*0x40000000000000;h=t[k+4>>2]|0;a=t[k>>2]|0;o=h;c=h;b=-1077;break}u=(e-e)/0;s=i;return+u}while(0);o=c+614242|0;t[k>>2]=a;t[k+4>>2]=(o&1048575)+1072079006;e=+l[k>>3]+-1;w=e*(e*.5);d=e/(e+2);v=d*d;m=v*v;l[k>>3]=e-w;a=t[k+4>>2]|0;t[k>>2]=0;t[k+4>>2]=a;_=+l[k>>3];p=d*(w+(m*(m*(m*.15313837699209373+.22222198432149784)+.3999999999940942)+v*(m*(m*(m*.14798198605116586+.1818357216161805)+.2857142874366239)+.6666666666666735)))+(e-_-w);w=_*.4342944818781689;e=+(b+(o>>>20)|0);m=e*.30102999566361177;v=m+w;u=v+(w+(m-v)+(p*.4342944818781689+(e*3.694239077158931e-13+(_+p)*2.5082946711645275e-11)));s=i;return+u}function bY(e){e=e|0;return+y}function kY(e,i){e=+e;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0;r=s;if((i|0)>1023){n=e*8.98846567431158e307;f=i+-1023|0;if((f|0)>1023){u=i+-2046|0;a=(u|0)>1023?1023:u;o=n*8.98846567431158e307}else{a=f;o=n}}else if((i|0)<-1022){n=e*2.2250738585072014e-308;f=i+1022|0;if((f|0)<-1022){u=i+2044|0;a=(u|0)<-1022?-1022:u;o=n*2.2250738585072014e-308}else{a=f;o=n}}else{a=i;o=e}i=UY(a+1023|0,0,52)|0;a=P;t[k>>2]=i;t[k+4>>2]=a;e=o*+l[k>>3];s=r;return+e}function hY(e,i){e=+e;i=i|0;var r=0,n=0;r=s;n=+kY(e,i);s=r;return+n}function wY(e,i){e=e|0;i=i|0;var r=0,n=0;r=s;if(!e)n=0;else n=dY(e,i,0)|0;s=r;return n|0}function dY(e,i,r){e=e|0;i=i|0;r=r|0;var f=0;r=s;if(!e){f=1;s=r;return f|0}if(i>>>0<128){n[e>>0]=i;f=1;s=r;return f|0}if(i>>>0<2048){n[e>>0]=i>>>6|192;n[e+1>>0]=i&63|128;f=2;s=r;return f|0}if(i>>>0<55296|(i&-8192|0)==57344){n[e>>0]=i>>>12|224;n[e+1>>0]=i>>>6&63|128;n[e+2>>0]=i&63|128;f=3;s=r;return f|0}if((i+-65536|0)>>>0<1048576){n[e>>0]=i>>>18|240;n[e+1>>0]=i>>>12&63|128;n[e+2>>0]=i>>>6&63|128;n[e+3>>0]=i&63|128;f=4;s=r;return f|0}else{t[(ii()|0)>>2]=84;f=-1;s=r;return f|0}return 0}function vY(e){e=e|0;var i=0;i=(te(t[e>>2]|0,1103515245)|0)+12345|0;t[e>>2]=i;e=i>>>11^i;i=e<<7&-1658038656^e;e=i<<15&-272236544^i;return(e>>>18^e)>>>1|0}function mY(e){e=e|0;var i=0,r=0,f=0,u=0,a=0;i=s;r=e+74|0;f=n[r>>0]|0;n[r>>0]=f+255|f;f=e+20|0;r=e+44|0;if((t[f>>2]|0)>>>0>(t[r>>2]|0)>>>0)dAi[t[e+36>>2]&511](e,0,0)|0;t[e+16>>2]=0;t[e+28>>2]=0;t[f>>2]=0;f=t[e>>2]|0;if(!(f&20)){u=t[r>>2]|0;t[e+8>>2]=u;t[e+4>>2]=u;a=0;s=i;return a|0}if(!(f&4)){a=-1;s=i;return a|0}t[e>>2]=f|32;a=-1;s=i;return a|0}function _Y(e){e=e|0;var i=0,r=0,f=0,u=0;i=s;r=e+74|0;f=n[r>>0]|0;n[r>>0]=f+255|f;f=t[e>>2]|0;if(!(f&8)){t[e+8>>2]=0;t[e+4>>2]=0;r=t[e+44>>2]|0;t[e+28>>2]=r;t[e+20>>2]=r;t[e+16>>2]=r+(t[e+48>>2]|0);u=0;s=i;return u|0}else{t[e>>2]=f|32;u=-1;s=i;return u|0}return 0}function pY(e){e=e|0;var i=0,r=0,n=0;i=s;s=s+16|0;r=i;if((t[e+8>>2]|0)==0?(mY(e)|0)!=0:0)n=-1;else if((dAi[t[e+32>>2]&511](e,r,1)|0)==1)n=u[r>>0]|0;else n=-1;s=i;return n|0}function EY(e,i,r){e=e|0;i=i|0;r=r|0;var f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0;f=s;u=r+16|0;a=t[u>>2]|0;do if(!a)if(!(_Y(r)|0)){o=t[u>>2]|0;break}else{c=0;s=f;return c|0}else o=a;while(0);a=r+20|0;u=t[a>>2]|0;if((o-u|0)>>>0<i>>>0){c=dAi[t[r+36>>2]&511](r,e,i)|0;s=f;return c|0}e:do if((n[r+75>>0]|0)>-1){o=i;while(1){if(!o){l=i;b=e;k=u;h=0;break e}w=o+-1|0;if((n[e+w>>0]|0)==10)break;else o=w}if((dAi[t[r+36>>2]&511](r,e,o)|0)>>>0<o>>>0){c=o;s=f;return c|0}else{l=i-o|0;b=e+o|0;k=t[a>>2]|0;h=o;break}}else{l=i;b=e;k=u;h=0}while(0);YY(k|0,b|0,l|0)|0;t[a>>2]=(t[a>>2]|0)+l;c=h+l|0;s=f;return c|0}function SY(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,u=0;f=s;s=s+16|0;u=f;t[u>>2]=n;n=yY(e,i,r,u)|0;s=f;return n|0}function gY(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0;n=s;s=s+224|0;f=n+120|0;u=n+80|0;a=n;o=n+136|0;c=u+0|0;l=c+40|0;do{t[c>>2]=0;c=c+4|0}while((c|0)<(l|0));t[f>>2]=t[r>>2];if((CY(0,i,f,a,u)|0)<0){b=-1;s=n;return b|0}r=e+48|0;if(!(t[r>>2]|0)){c=e+44|0;l=t[c>>2]|0;t[c>>2]=o;k=e+28|0;t[k>>2]=o;h=e+20|0;t[h>>2]=o;t[r>>2]=80;w=e+16|0;t[w>>2]=o+80;o=CY(e,i,f,a,u)|0;if(!l)d=o;else{dAi[t[e+36>>2]&511](e,0,0)|0;v=(t[h>>2]|0)==0?-1:o;t[c>>2]=l;t[r>>2]=0;t[w>>2]=0;t[k>>2]=0;t[h>>2]=0;d=v}}else d=CY(e,i,f,a,u)|0;b=d;s=n;return b|0}function yY(e,i,r,f){e=e|0;i=i|0;r=r|0;f=f|0;var u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0;u=s;s=s+128|0;a=u+112|0;o=u;c=o+0|0;l=329664|0;b=c+112|0;do{t[c>>2]=t[l>>2];c=c+4|0;l=l+4|0}while((c|0)<(b|0));if((i+-1|0)>>>0>2147483646)if(!i){k=a;h=1}else{t[(ii()|0)>>2]=75;w=-1;s=u;return w|0}else{k=e;h=i}i=-2-k|0;e=h>>>0>i>>>0?i:h;t[o+48>>2]=e;h=o+20|0;t[h>>2]=k;t[o+44>>2]=k;i=k+e|0;k=o+16|0;t[k>>2]=i;t[o+28>>2]=i;i=gY(o,r,f)|0;if(!e){w=i;s=u;return w|0}e=t[h>>2]|0;n[e+(((e|0)==(t[k>>2]|0))<<31>>31)>>0]=0;w=i;s=u;return w|0}function FY(e){e=e|0;var i=0,r=0,f=0,t=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0;i=s;r=e;while(1){f=r+1|0;if(!($q(n[r>>0]|0)|0))break;else r=f}e=n[r>>0]|0;t=e<<24>>24;if((t|0)==43){u=0;a=5}else if((t|0)==45){u=1;a=5}else{o=r;c=e;l=0}if((a|0)==5){o=f;c=n[f>>0]|0;l=u}if(!(Qq(c<<24>>24)|0)){b=0;k=(l|0)!=0;h=0-b|0;w=k?b:h;s=i;return w|0}else{d=o;v=0}while(1){o=(v*10|0)+48-(n[d>>0]|0)|0;d=d+1|0;if(!(Qq(n[d>>0]|0)|0)){b=o;break}else v=o}k=(l|0)!=0;h=0-b|0;w=k?b:h;s=i;return w|0}function OY(e,i,r){e=e|0;i=i|0;r=r|0;var f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0,S=0,g=0,y=0;f=s;u=i&255;a=(r|0)!=0;e:do if((e&3|0)!=0&a){o=i&255;c=r;l=e;while(1){if((n[l>>0]|0)==o<<24>>24){b=c;k=l;h=6;break e}w=l+1|0;d=c+-1|0;v=(d|0)!=0;if((w&3|0)!=0&v){c=d;l=w}else{m=d;_=v;p=w;h=5;break}}}else{m=r;_=a;p=e;h=5}while(0);if((h|0)==5)if(_){b=m;k=p;h=6}else{E=0;S=p}e:do if((h|0)==6){p=i&255;if((n[k>>0]|0)!=p<<24>>24){m=te(u,16843009)|0;i:do if(b>>>0>3){_=b;e=k;while(1){a=t[e>>2]^m;if((a&-2139062144^-2139062144)&a+-16843009){g=_;y=e;break i}a=e+4|0;r=_+-4|0;if(r>>>0>3){_=r;e=a}else{g=r;y=a;break}}}else{g=b;y=k}while(0);if(!g){E=0;S=y}else{m=g;e=y;while(1){if((n[e>>0]|0)==p<<24>>24){E=m;S=e;break e}_=e+1|0;m=m+-1|0;if(!m){E=0;S=_;break}else e=_}}}else{E=b;S=k}}while(0);s=f;return((E|0)!=0?S:0)|0}function AY(e,i,r){e=e|0;i=i|0;r=r|0;var f=0,t=0,u=0,a=0,o=0,c=0,l=0;f=s;e:do if(!r)t=0;else{u=r;a=e;o=i;while(1){c=n[a>>0]|0;l=n[o>>0]|0;if(c<<24>>24!=l<<24>>24)break;u=u+-1|0;if(!u){t=0;break e}else{a=a+1|0;o=o+1|0}}t=(c&255)-(l&255)|0}while(0);s=f;return t|0}function MY(e,i){e=e|0;i=i|0;var r=0,f=0,t=0,u=0,a=0;r=s;f=n[e>>0]|0;t=n[i>>0]|0;if(f<<24>>24==0?1:f<<24>>24!=t<<24>>24){u=f;a=t}else{t=e;e=i;do{t=t+1|0;e=e+1|0;i=n[t>>0]|0;f=n[e>>0]|0}while(!(i<<24>>24==0?1:i<<24>>24!=f<<24>>24));u=i;a=f}s=r;return(u&255)-(a&255)|0}function RY(e,i,r){e=e|0;i=i|0;r=r|0;var f=0,t=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0;f=s;if(!r){t=0;s=f;return t|0}a=n[e>>0]|0;e:do if(!(a<<24>>24)){o=0;c=i}else{l=r;b=a;k=e;h=i;while(1){l=l+-1|0;w=n[h>>0]|0;if(!(w<<24>>24!=0&(l|0)!=0&b<<24>>24==w<<24>>24)){o=b;c=h;break e}k=k+1|0;w=h+1|0;b=n[k>>0]|0;if(!(b<<24>>24)){o=0;c=w;break}else h=w}}while(0);t=(o&255)-(u[c>>0]|0)|0;s=f;return t|0}function NY(e,i,r){e=e|0;i=i|0;r=r|0;var n=0,f=0,u=0,a=0;n=s;f=e+20|0;u=t[f>>2]|0;a=(t[e+16>>2]|0)-u|0;e=a>>>0>r>>>0?r:a;YY(u|0,i|0,e|0)|0;t[f>>2]=(t[f>>2]|0)+e;s=n;return r|0}function TY(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0,S=0,g=0,y=0;r=s;n=e+4|0;f=t[n>>2]|0;u=f&-8;a=e+u|0;o=t[82068]|0;c=f&3;if(!((c|0)!=1&e>>>0>=o>>>0&e>>>0<a>>>0))li();l=e+(u|4)|0;b=t[l>>2]|0;if(!(b&1))li();if(!c){if(i>>>0<256){k=0;s=r;return k|0}if(u>>>0>=(i+4|0)>>>0?(u-i|0)>>>0<=t[82184]<<1>>>0:0){k=e;s=r;return k|0}k=0;s=r;return k|0}if(u>>>0>=i>>>0){c=u-i|0;if(c>>>0<=15){k=e;s=r;return k|0}t[n>>2]=f&1|i|2;t[e+(i+4)>>2]=c|3;t[l>>2]=t[l>>2]|1;LY(e+i|0,c);k=e;s=r;return k|0}if((a|0)==(t[82070]|0)){c=(t[82067]|0)+u|0;if(c>>>0<=i>>>0){k=0;s=r;return k|0}l=c-i|0;t[n>>2]=f&1|i|2;t[e+(i+4)>>2]=l|1;t[82070]=e+i;t[82067]=l;k=e;s=r;return k|0}if((a|0)==(t[82069]|0)){l=(t[82066]|0)+u|0;if(l>>>0<i>>>0){k=0;s=r;return k|0}c=l-i|0;if(c>>>0>15){t[n>>2]=f&1|i|2;t[e+(i+4)>>2]=c|1;t[e+l>>2]=c;h=e+(l+4)|0;t[h>>2]=t[h>>2]&-2;w=e+i|0;d=c}else{t[n>>2]=f&1|l|2;c=e+(l+4)|0;t[c>>2]=t[c>>2]|1;w=0;d=0}t[82066]=d;t[82069]=w;k=e;s=r;return k|0}if(b&2){k=0;s=r;return k|0}w=(b&-8)+u|0;if(w>>>0<i>>>0){k=0;s=r;return k|0}d=w-i|0;c=b>>>3;do if(b>>>0>=256){l=t[e+(u+24)>>2]|0;h=t[e+(u+12)>>2]|0;do if((h|0)==(a|0)){v=e+(u+20)|0;m=t[v>>2]|0;if(!m){_=e+(u+16)|0;p=t[_>>2]|0;if(!p){E=0;break}else{S=p;g=_}}else{S=m;g=v}while(1){v=S+20|0;m=t[v>>2]|0;if(m){S=m;g=v;continue}v=S+16|0;m=t[v>>2]|0;if(!m)break;else{S=m;g=v}}if(g>>>0<o>>>0)li();else{t[g>>2]=0;E=S;break}}else{v=t[e+(u+8)>>2]|0;if(v>>>0<o>>>0)li();m=v+12|0;if((t[m>>2]|0)!=(a|0))li();_=h+8|0;if((t[_>>2]|0)==(a|0)){t[m>>2]=h;t[_>>2]=v;E=h;break}else li()}while(0);if(l){h=t[e+(u+28)>>2]|0;v=328560+(h<<2)|0;if((a|0)==(t[v>>2]|0)){t[v>>2]=E;if(!E){t[82065]=t[82065]&~(1<<h);break}}else{if(l>>>0<(t[82068]|0)>>>0)li();h=l+16|0;if((t[h>>2]|0)==(a|0))t[h>>2]=E;else t[l+20>>2]=E;if(!E)break}h=t[82068]|0;if(E>>>0<h>>>0)li();t[E+24>>2]=l;v=t[e+(u+16)>>2]|0;do if(v)if(v>>>0<h>>>0)li();else{t[E+16>>2]=v;t[v+24>>2]=E;break}while(0);v=t[e+(u+20)>>2]|0;if(v)if(v>>>0<(t[82068]|0)>>>0)li();else{t[E+20>>2]=v;t[v+24>>2]=E;break}}}else{v=t[e+(u+8)>>2]|0;h=t[e+(u+12)>>2]|0;l=328296+(c<<1<<2)|0;if((v|0)!=(l|0)){if(v>>>0<o>>>0)li();if((t[v+12>>2]|0)!=(a|0))li()}if((h|0)==(v|0)){t[82064]=t[82064]&~(1<<c);break}if((h|0)!=(l|0)){if(h>>>0<o>>>0)li();l=h+8|0;if((t[l>>2]|0)==(a|0))y=l;else li()}else y=h+8|0;t[v+12>>2]=h;t[y>>2]=v}while(0);if(d>>>0<16){t[n>>2]=w|f&1|2;y=e+(w|4)|0;t[y>>2]=t[y>>2]|1;k=e;s=r;return k|0}else{t[n>>2]=f&1|i|2;t[e+(i+4)>>2]=d|3;f=e+(w|4)|0;t[f>>2]=t[f>>2]|1;LY(e+i|0,d);k=e;s=r;return k|0}return 0}function LY(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,u=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0,S=0,g=0,y=0,F=0,O=0,A=0,M=0,R=0,N=0,T=0,L=0,D=0;r=s;n=e+i|0;f=t[e+4>>2]|0;do if(!(f&1)){u=t[e>>2]|0;if(!(f&3)){s=r;return}a=e+(0-u)|0;o=u+i|0;c=t[82068]|0;if(a>>>0<c>>>0)li();if((a|0)==(t[82069]|0)){l=e+(i+4)|0;b=t[l>>2]|0;if((b&3|0)!=3){k=a;h=o;break}t[82066]=o;t[l>>2]=b&-2;t[e+(4-u)>>2]=o|1;t[n>>2]=o;s=r;return}b=u>>>3;if(u>>>0<256){l=t[e+(8-u)>>2]|0;w=t[e+(12-u)>>2]|0;d=328296+(b<<1<<2)|0;if((l|0)!=(d|0)){if(l>>>0<c>>>0)li();if((t[l+12>>2]|0)!=(a|0))li()}if((w|0)==(l|0)){t[82064]=t[82064]&~(1<<b);
	k=a;h=o;break}if((w|0)!=(d|0)){if(w>>>0<c>>>0)li();d=w+8|0;if((t[d>>2]|0)==(a|0))v=d;else li()}else v=w+8|0;t[l+12>>2]=w;t[v>>2]=l;k=a;h=o;break}l=t[e+(24-u)>>2]|0;w=t[e+(12-u)>>2]|0;do if((w|0)==(a|0)){d=16-u|0;b=e+(d+4)|0;m=t[b>>2]|0;if(!m){_=e+d|0;d=t[_>>2]|0;if(!d){p=0;break}else{E=d;S=_}}else{E=m;S=b}while(1){b=E+20|0;m=t[b>>2]|0;if(m){E=m;S=b;continue}b=E+16|0;m=t[b>>2]|0;if(!m)break;else{E=m;S=b}}if(S>>>0<c>>>0)li();else{t[S>>2]=0;p=E;break}}else{b=t[e+(8-u)>>2]|0;if(b>>>0<c>>>0)li();m=b+12|0;if((t[m>>2]|0)!=(a|0))li();_=w+8|0;if((t[_>>2]|0)==(a|0)){t[m>>2]=w;t[_>>2]=b;p=w;break}else li()}while(0);if(l){w=t[e+(28-u)>>2]|0;c=328560+(w<<2)|0;if((a|0)==(t[c>>2]|0)){t[c>>2]=p;if(!p){t[82065]=t[82065]&~(1<<w);k=a;h=o;break}}else{if(l>>>0<(t[82068]|0)>>>0)li();w=l+16|0;if((t[w>>2]|0)==(a|0))t[w>>2]=p;else t[l+20>>2]=p;if(!p){k=a;h=o;break}}w=t[82068]|0;if(p>>>0<w>>>0)li();t[p+24>>2]=l;c=16-u|0;b=t[e+c>>2]|0;do if(b)if(b>>>0<w>>>0)li();else{t[p+16>>2]=b;t[b+24>>2]=p;break}while(0);b=t[e+(c+4)>>2]|0;if(b)if(b>>>0<(t[82068]|0)>>>0)li();else{t[p+20>>2]=b;t[b+24>>2]=p;k=a;h=o;break}else{k=a;h=o}}else{k=a;h=o}}else{k=e;h=i}while(0);p=t[82068]|0;if(n>>>0<p>>>0)li();E=e+(i+4)|0;S=t[E>>2]|0;if(!(S&2)){if((n|0)==(t[82070]|0)){v=(t[82067]|0)+h|0;t[82067]=v;t[82070]=k;t[k+4>>2]=v|1;if((k|0)!=(t[82069]|0)){s=r;return}t[82069]=0;t[82066]=0;s=r;return}if((n|0)==(t[82069]|0)){v=(t[82066]|0)+h|0;t[82066]=v;t[82069]=k;t[k+4>>2]=v|1;t[k+v>>2]=v;s=r;return}v=(S&-8)+h|0;f=S>>>3;do if(S>>>0>=256){b=t[e+(i+24)>>2]|0;w=t[e+(i+12)>>2]|0;do if((w|0)==(n|0)){u=e+(i+20)|0;l=t[u>>2]|0;if(!l){_=e+(i+16)|0;m=t[_>>2]|0;if(!m){g=0;break}else{y=m;F=_}}else{y=l;F=u}while(1){u=y+20|0;l=t[u>>2]|0;if(l){y=l;F=u;continue}u=y+16|0;l=t[u>>2]|0;if(!l)break;else{y=l;F=u}}if(F>>>0<p>>>0)li();else{t[F>>2]=0;g=y;break}}else{u=t[e+(i+8)>>2]|0;if(u>>>0<p>>>0)li();l=u+12|0;if((t[l>>2]|0)!=(n|0))li();_=w+8|0;if((t[_>>2]|0)==(n|0)){t[l>>2]=w;t[_>>2]=u;g=w;break}else li()}while(0);if(b){w=t[e+(i+28)>>2]|0;o=328560+(w<<2)|0;if((n|0)==(t[o>>2]|0)){t[o>>2]=g;if(!g){t[82065]=t[82065]&~(1<<w);break}}else{if(b>>>0<(t[82068]|0)>>>0)li();w=b+16|0;if((t[w>>2]|0)==(n|0))t[w>>2]=g;else t[b+20>>2]=g;if(!g)break}w=t[82068]|0;if(g>>>0<w>>>0)li();t[g+24>>2]=b;o=t[e+(i+16)>>2]|0;do if(o)if(o>>>0<w>>>0)li();else{t[g+16>>2]=o;t[o+24>>2]=g;break}while(0);o=t[e+(i+20)>>2]|0;if(o)if(o>>>0<(t[82068]|0)>>>0)li();else{t[g+20>>2]=o;t[o+24>>2]=g;break}}}else{o=t[e+(i+8)>>2]|0;w=t[e+(i+12)>>2]|0;b=328296+(f<<1<<2)|0;if((o|0)!=(b|0)){if(o>>>0<p>>>0)li();if((t[o+12>>2]|0)!=(n|0))li()}if((w|0)==(o|0)){t[82064]=t[82064]&~(1<<f);break}if((w|0)!=(b|0)){if(w>>>0<p>>>0)li();b=w+8|0;if((t[b>>2]|0)==(n|0))O=b;else li()}else O=w+8|0;t[o+12>>2]=w;t[O>>2]=o}while(0);t[k+4>>2]=v|1;t[k+v>>2]=v;if((k|0)==(t[82069]|0)){t[82066]=v;s=r;return}else A=v}else{t[E>>2]=S&-2;t[k+4>>2]=h|1;t[k+h>>2]=h;A=h}h=A>>>3;if(A>>>0<256){S=h<<1;E=328296+(S<<2)|0;v=t[82064]|0;O=1<<h;if(v&O){h=328296+(S+2<<2)|0;n=t[h>>2]|0;if(n>>>0<(t[82068]|0)>>>0)li();else{M=h;R=n}}else{t[82064]=v|O;M=328296+(S+2<<2)|0;R=E}t[M>>2]=k;t[R+12>>2]=k;t[k+8>>2]=R;t[k+12>>2]=E;s=r;return}E=A>>>8;if(E)if(A>>>0>16777215)N=31;else{R=(E+1048320|0)>>>16&8;M=E<<R;E=(M+520192|0)>>>16&4;S=M<<E;M=(S+245760|0)>>>16&2;O=14-(E|R|M)+(S<<M>>>15)|0;N=A>>>(O+7|0)&1|O<<1}else N=0;O=328560+(N<<2)|0;t[k+28>>2]=N;t[k+20>>2]=0;t[k+16>>2]=0;M=t[82065]|0;S=1<<N;if(!(M&S)){t[82065]=M|S;t[O>>2]=k;t[k+24>>2]=O;t[k+12>>2]=k;t[k+8>>2]=k;s=r;return}S=t[O>>2]|0;if((N|0)==31)T=0;else T=25-(N>>>1)|0;e:do if((t[S+4>>2]&-8|0)==(A|0))L=S;else{N=A<<T;O=S;while(1){D=O+(N>>>31<<2)+16|0;M=t[D>>2]|0;if(!M)break;if((t[M+4>>2]&-8|0)==(A|0)){L=M;break e}else{N=N<<1;O=M}}if(D>>>0<(t[82068]|0)>>>0)li();t[D>>2]=k;t[k+24>>2]=O;t[k+12>>2]=k;t[k+8>>2]=k;s=r;return}while(0);D=L+8|0;A=t[D>>2]|0;S=t[82068]|0;if(!(L>>>0>=S>>>0&A>>>0>=S>>>0))li();t[A+12>>2]=k;t[D>>2]=k;t[k+8>>2]=A;t[k+12>>2]=L;t[k+24>>2]=0;s=r;return}function DY(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,a=0,o=0,c=0,l=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0,S=0,g=0,y=0;r=s;n=e+4|0;f=t[n>>2]|0;a=e+100|0;if(f>>>0<(t[a>>2]|0)>>>0){t[n>>2]=f+1;o=u[f>>0]|0}else o=nY(e)|0;if((o|0)==43|(o|0)==45){f=t[n>>2]|0;c=(o|0)==45&1;if(f>>>0<(t[a>>2]|0)>>>0){t[n>>2]=f+1;l=u[f>>0]|0}else l=nY(e)|0;if((l+-48|0)>>>0>9&(i|0)!=0?(t[a>>2]|0)!=0:0){t[n>>2]=(t[n>>2]|0)+-1;b=l;k=c}else{b=l;k=c}}else{b=o;k=0}if((b+-48|0)>>>0>9){if(!(t[a>>2]|0)){h=-2147483648;w=0;P=h;s=r;return w|0}t[n>>2]=(t[n>>2]|0)+-1;h=-2147483648;w=0;P=h;s=r;return w|0}else{d=b;v=0}while(1){v=d+-48+(v*10|0)|0;b=t[n>>2]|0;if(b>>>0<(t[a>>2]|0)>>>0){t[n>>2]=b+1;m=u[b>>0]|0}else m=nY(e)|0;if(!((m+-48|0)>>>0<10&(v|0)<214748364))break;else d=m}d=((v|0)<0)<<31>>31;if((m+-48|0)>>>0<10){b=v;o=d;c=m;while(1){l=$Y(b|0,o|0,10,0)|0;i=P;f=jY(c|0,((c|0)<0)<<31>>31|0,-48,-1)|0;_=jY(f|0,P|0,l|0,i|0)|0;i=P;l=t[n>>2]|0;if(l>>>0<(t[a>>2]|0)>>>0){t[n>>2]=l+1;p=u[l>>0]|0}else p=nY(e)|0;if((p+-48|0)>>>0<10&((i|0)<21474836|(i|0)==21474836&_>>>0<2061584302)){b=_;o=i;c=p}else{E=_;S=i;g=p;break}}}else{E=v;S=d;g=m}if((g+-48|0)>>>0<10)do{g=t[n>>2]|0;if(g>>>0<(t[a>>2]|0)>>>0){t[n>>2]=g+1;y=u[g>>0]|0}else y=nY(e)|0}while((y+-48|0)>>>0<10);if(t[a>>2]|0)t[n>>2]=(t[n>>2]|0)+-1;n=(k|0)!=0;k=BY(0,0,E|0,S|0)|0;h=n?P:S;w=n?k:E;P=h;s=r;return w|0}function CY(e,i,r,a,o){e=e|0;i=i|0;r=r|0;a=a|0;o=o|0;var c=0,b=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0,S=0,g=0,y=0,F=0,O=0,A=0,M=0,R=0,N=0,T=0,L=0,D=0,C=0,B=0,I=0,H=0,x=0,U=0,z=0,j=0,V=0,q=0,Y=0,G=0,W=0,K=0,X=0,Z=0,J=0,Q=0,$=0,ee=0,ie=0,re=0,ne=0,fe=0,ue=0,ae=0,oe=0,ce=0,le=0,se=0,be=0,ke=0,he=0,we=0,de=0,ve=0,me=0,_e=0,pe=0,Ee=0,Se=0,ge=0,ye=0,Fe=0,Oe=0,Ae=0,Me=0,Re=0,Ne=0,Te=0,Le=0,De=0,Ce=0,Pe=0,Be=0,Ie=0,He=0,xe=0,Ue=0,ze=0,je=0,Ve=0,qe=0,Ye=0,Ge=0,We=0,Ke=0,Xe=0,Ze=0,Je=0,Qe=0,$e=0,ei=0,ri=0,ni=0,fi=0,ti=0,ui=0,ai=0,oi=0,ci=0,li=0,si=0,bi=0,ki=0,wi=0,di=0,vi=0,mi=0,_i=0,pi=0,Ei=0,Si=0,gi=0,yi=0,Fi=0,Oi=0,Ai=0,Mi=0,Ri=0,Ni=0,Ti=0,Li=0,Di=0,Ci=0,Pi=0,Bi=0,Ii=0,Hi=0,xi=0,Ui=0,zi=0,ji=0,Vi=0,qi=0,Yi=0,Gi=0,Wi=0,Ki=0,Xi=0,Zi=0,Ji=0,Qi=0,$i=0,er=0,ir=0,rr=0,nr=0,fr=0,tr=0,ur=0,ar=0,or=0,cr=0,lr=0,sr=0,br=0,kr=0,hr=0,wr=0,dr=0,vr=0,mr=0,_r=0,pr=0,Er=0,Sr=0,gr=0,yr=0,Fr=0,Or=0,Ar=0,Mr=0,Rr=0,Nr=0,Tr=0,Lr=0,Dr=0,Cr=0,Pr=0,Br=0,Ir=0,Hr=0,xr=0,Ur=0,zr=0,jr=0,Vr=0,qr=0,Yr=0,Gr=0,Wr=0,Kr=0,Xr=0,Zr=0,Jr=0,Qr=0,$r=0,en=0,rn=0,nn=0,fn=0,tn=0,un=0,an=0,on=0,cn=0,ln=0,sn=0,bn=0,kn=0,hn=0,wn=0,dn=0,vn=0,mn=0,_n=0,pn=0,En=0,Sn=0,gn=0;c=s;s=s+864|0;b=c+16|0;h=c+8|0;w=c+836|0;d=w;v=c+824|0;m=c+568|0;_=c+528|0;p=c;E=c+520|0;S=(e|0)!=0;g=_+40|0;y=g;F=_+39|0;_=p+4|0;O=p;A=v+12|0;M=v+11|0;v=A;R=v-d|0;N=-2-d|0;T=v+2|0;L=b+288|0;D=w+9|0;C=D;B=w+8|0;I=0;H=0;x=i;i=0;U=0;z=0;e:while(1){do if((i|0)>-1)if((U|0)>(2147483647-i|0)){t[(ii()|0)>>2]=75;j=-1;break}else{j=U+i|0;break}else j=i;while(0);V=n[x>>0]|0;if(!(V<<24>>24)){q=352;break}else{Y=V;G=x}while(1){if(Y<<24>>24==37){W=G;K=G;q=9;break}else if(!(Y<<24>>24)){X=G;Z=G;break}V=G+1|0;Y=n[V>>0]|0;G=V}i:do if((q|0)==9)while(1){q=0;if((n[W+1>>0]|0)!=37){X=W;Z=K;break i}V=K+1|0;J=W+2|0;if((n[J>>0]|0)==37){W=J;K=V;q=9}else{X=J;Z=V;break}}while(0);V=Z-x|0;if(S)EY(x,V,e)|0;if((Z|0)!=(x|0)){x=X;i=j;U=V;continue}J=X+1|0;Q=n[J>>0]|0;$=(Q<<24>>24)+-48|0;if($>>>0<10?(n[X+2>>0]|0)==36:0){ee=X+3|0;ie=n[ee>>0]|0;re=$;ne=1;fe=ee}else{ie=Q;re=-1;ne=z;fe=J}J=ie<<24>>24;i:do if((J&-32|0)==32){Q=ie;ee=J;$=0;ue=fe;while(1){ae=1<<ee+-32;if(!(ae&75913)){oe=Q;ce=$;le=ue;break i}se=ae|$;ae=ue+1|0;be=n[ae>>0]|0;ee=be<<24>>24;if((ee&-32|0)!=32){oe=be;ce=se;le=ae;break}else{Q=be;$=se;ue=ae}}}else{oe=ie;ce=0;le=fe}while(0);do if(oe<<24>>24==42){J=le+1|0;ue=(n[J>>0]|0)+-48|0;if(ue>>>0<10?(n[le+2>>0]|0)==36:0){t[o+(ue<<2)>>2]=10;ke=1;he=le+3|0;we=t[a+((n[J>>0]|0)+-48<<3)>>2]|0}else{if(ne){de=-1;q=370;break e}if(!S){ve=J;me=ce;_e=0;pe=0;break}ue=t[r>>2]|0;$=t[ue>>2]|0;t[r>>2]=ue+4;ke=0;he=J;we=$}if((we|0)<0){ve=he;me=ce|8192;_e=ke;pe=0-we|0}else{ve=he;me=ce;_e=ke;pe=we}}else{$=oe<<24>>24;if(($+-48|0)>>>0<10){J=$;$=le;ue=0;do{ue=J+-48+(ue*10|0)|0;$=$+1|0;J=n[$>>0]|0}while((J+-48|0)>>>0<10);if((ue|0)<0){de=-1;q=370;break e}else{ve=$;me=ce;_e=ne;pe=ue}}else{ve=le;me=ce;_e=ne;pe=0}}while(0);i:do if((n[ve>>0]|0)==46){J=ve+1|0;Q=n[J>>0]|0;if(Q<<24>>24!=42){ee=Q<<24>>24;if((ee+-48|0)>>>0<10){Ee=ee;Se=J;ge=0}else{ye=J;Fe=0;break}while(1){J=Ee+-48+(ge*10|0)|0;ee=Se+1|0;Ee=n[ee>>0]|0;if((Ee+-48|0)>>>0>=10){ye=ee;Fe=J;break i}else{Se=ee;ge=J}}}ue=ve+2|0;$=(n[ue>>0]|0)+-48|0;if($>>>0<10?(n[ve+3>>0]|0)==36:0){t[o+($<<2)>>2]=10;ye=ve+4|0;Fe=t[a+((n[ue>>0]|0)+-48<<3)>>2]|0;break}if(_e){de=-1;q=370;break e}if(S){$=t[r>>2]|0;J=t[$>>2]|0;t[r>>2]=$+4;ye=ue;Fe=J}else{ye=ue;Fe=0}}else{ye=ve;Fe=-1}while(0);ue=ye;J=0;while(1){Oe=n[ue>>0]|0;$=(Oe<<24>>24)+-65|0;if($>>>0>57){de=-1;q=370;break e}Ae=ue+1|0;Me=n[329096+(J*58|0)+$>>0]|0;Re=Me&255;if((Re+-1|0)>>>0<8){ue=Ae;J=Re}else break}if(!(Me<<24>>24)){de=-1;q=370;break}$=(re|0)>-1;i:do if(Me<<24>>24==19)if($){de=-1;q=370;break e}else{Ne=I;Te=H;q=63}else{if($){t[o+(re<<2)>>2]=Re;ee=a+(re<<3)|0;Ne=t[ee>>2]|0;Te=t[ee+4>>2]|0;q=63;break}if(!S){de=0;q=370;break e}if((Me&255)>20){Le=Oe;De=I;Ce=H}else do switch(Re|0){case 16:{ee=t[r>>2]|0;Q=t[ee>>2]|0;t[r>>2]=ee+4;Pe=0;Be=Q&255;q=64;break i;break}case 11:{Q=t[r>>2]|0;ee=t[Q>>2]|0;t[r>>2]=Q+4;Pe=0;Be=ee;q=64;break i;break}case 12:{ee=t[r>>2]|0;Q=ee;ae=t[Q>>2]|0;se=t[Q+4>>2]|0;t[r>>2]=ee+8;Pe=se;Be=ae;q=64;break i;break}case 14:{ae=t[r>>2]|0;se=t[ae>>2]|0;t[r>>2]=ae+4;Pe=0;Be=se&65535;q=64;break i;break}case 13:{se=t[r>>2]|0;ae=t[se>>2]|0;t[r>>2]=se+4;Pe=(((ae&65535)<<16>>16|0)<0)<<31>>31;Be=ae<<16>>16;q=64;break i;break}case 17:{ae=t[r>>2]|0;t[k>>2]=t[ae>>2];t[k+4>>2]=t[ae+4>>2];Ie=+l[k>>3];t[r>>2]=ae+8;l[k>>3]=Ie;Pe=t[k+4>>2]|0;Be=t[k>>2]|0;q=64;break i;break}case 10:{ae=t[r>>2]|0;se=t[ae>>2]|0;t[r>>2]=ae+4;Pe=((se|0)<0)<<31>>31;Be=se;q=64;break i;break}case 15:{se=t[r>>2]|0;ae=t[se>>2]|0;t[r>>2]=se+4;Pe=(((ae&255)<<24>>24|0)<0)<<31>>31;Be=ae<<24>>24;q=64;break i;break}case 18:{ae=t[r>>2]|0;t[k>>2]=t[ae>>2];t[k+4>>2]=t[ae+4>>2];Ie=+l[k>>3];t[r>>2]=ae+8;l[k>>3]=Ie;Ne=t[k>>2]|0;Te=t[k+4>>2]|0;q=63;break i;break}case 9:{ae=t[r>>2]|0;se=t[ae>>2]|0;t[r>>2]=ae+4;Pe=H;Be=se;q=64;break i;break}default:{Pe=H;Be=I;q=64;break i}}while(0)}while(0);if((q|0)==63){q=0;if(S){Pe=Te;Be=Ne;q=64}else{I=Ne;H=Te;x=Ae;i=j;U=V;z=_e;continue}}if((q|0)==64){q=0;Le=n[ue>>0]|0;De=Be;Ce=Pe}$=Le<<24>>24;se=(J|0)!=0&($&15|0)==3?$&-33:$;$=me&-65537;ae=(me&8192|0)==0?me:$;i:do switch(se|0){case 110:{switch(J|0){case 7:{ee=De;t[ee>>2]=j;t[ee+4>>2]=((j|0)<0)<<31>>31;I=De;H=Ce;x=Ae;i=j;U=V;z=_e;continue e;break}case 3:{f[De>>1]=j;I=De;H=Ce;x=Ae;i=j;U=V;z=_e;continue e;break}case 4:{n[De>>0]=j;I=De;H=Ce;x=Ae;i=j;U=V;z=_e;continue e;break}case 6:{t[De>>2]=j;I=De;H=Ce;x=Ae;i=j;U=V;z=_e;continue e;break}case 1:{t[De>>2]=j;I=De;H=Ce;x=Ae;i=j;U=V;z=_e;continue e;break}case 0:{t[De>>2]=j;I=De;H=Ce;x=Ae;i=j;U=V;z=_e;continue e;break}case 2:{ee=De;t[ee>>2]=j;t[ee+4>>2]=((j|0)<0)<<31>>31;I=De;H=Ce;x=Ae;i=j;U=V;z=_e;continue e;break}default:{I=De;H=Ce;x=Ae;i=j;U=V;z=_e;continue e}}break}case 109:{He=hi(t[(ii()|0)>>2]|0)|0;q=96;break}case 105:case 100:{if((Ce|0)<0){ee=BY(0,0,De|0,Ce|0)|0;xe=P;Ue=ee;ze=1;je=329560;q=86;break i}if(!(ae&2048)){ee=ae&1;xe=Ce;Ue=De;ze=ee;je=(ee|0)==0?329560:329562;q=86}else{xe=Ce;Ue=De;ze=1;je=329561;q=86}break}case 65:case 71:case 70:case 69:case 97:case 103:case 102:case 101:{t[k>>2]=De;t[k+4>>2]=Ce;Ie=+l[k>>3];t[h>>2]=0;if((Ce|0)>=0)if(!(ae&2048)){ee=ae&1;Ve=Ie;qe=ee;Ye=(ee|0)==0?329585:329590}else{Ve=Ie;qe=1;Ye=329587}else{Ve=-Ie;qe=1;Ye=329584}l[k>>3]=Ve;ee=t[k+4>>2]&2146435072;if(!(ee>>>0<2146435072|(ee|0)==2146435072&0<0)){ee=(se&32|0)!=0;if(Ve!=Ve|0!=0){Ge=0;We=ee?329624:329632}else{Ge=qe;We=ee?329608:329616}ee=Ge+3|0;Q=(pe|0)>(ee|0);if((ae&8192|0)==0&Q){be=pe-ee|0;VY(m|0,32,(be>>>0>256?256:be)|0)|0;if(be>>>0>255){Ke=be;do{EY(m,256,e)|0;Ke=Ke+-256|0}while(Ke>>>0>255);Xe=be&255}else Xe=be;EY(m,Xe,e)|0}EY(Ye,Ge,e)|0;EY(We,3,e)|0;if((ae&73728|0)==8192&Q){Ke=pe-ee|0;VY(m|0,32,(Ke>>>0>256?256:Ke)|0)|0;if(Ke>>>0>255){Ze=Ke;do{EY(m,256,e)|0;Ze=Ze+-256|0}while(Ze>>>0>255);Je=Ke&255}else Je=Ke;EY(m,Je,e)|0}I=De;H=Ce;x=Ae;i=j;U=Q?pe:ee;z=_e;continue e}Ie=+lY(Ve,h)*2;Ze=Ie!=0;if(Ze)t[h>>2]=(t[h>>2]|0)+-1;be=se|32;if((be|0)==97){Qe=se&32;$e=(Qe|0)==0?Ye:Ye+9|0;ei=qe|2;ri=Fe>>>0>11?0:12-Fe|0;do if(ri){ni=ri;fi=8;do{ni=ni+-1|0;fi=fi*16}while((ni|0)!=0);if((n[$e>>0]|0)==45){ti=-(fi+(-Ie-fi));break}else{ti=Ie+fi-fi;break}}else ti=Ie;while(0);ri=t[h>>2]|0;ee=(ri|0)<0?0-ri|0:ri;if((ee|0)<0){ri=A;Q=ee;Ke=((ee|0)<0)<<31>>31;while(1){ni=iG(Q|0,Ke|0,10,0)|0;ri=ri+-1|0;n[ri>>0]=ni|48;ni=Q;Q=eG(Q|0,Ke|0,10,0)|0;if(!(Ke>>>0>9|(Ke|0)==9&ni>>>0>4294967295))break;else Ke=P}ui=ri;ai=Q}else{ui=A;ai=ee}if(!ai)oi=ui;else{Ke=ui;ni=ai;while(1){ci=Ke+-1|0;n[ci>>0]=(ni>>>0)%10|0|48;if(ni>>>0<10){oi=ci;break}else{Ke=ci;ni=(ni>>>0)/10|0}}}if((oi|0)==(A|0)){n[M>>0]=48;li=M}else li=oi;n[li+-1>>0]=(t[h>>2]>>31&2)+43;ni=li+-2|0;n[ni>>0]=se+15;if((Fe|0)<1)if(!(ae&8)){si=ti;Ke=w;while(1){ee=~~si;Q=Ke+1|0;n[Ke>>0]=u[329640+ee>>0]|Qe;si=(si-+(ee|0))*16;if((Q-d|0)!=1|si==0)bi=Q;else{n[Q>>0]=46;bi=Ke+2|0}if(!(si!=0)){ki=bi;break}else Ke=bi}}else{si=ti;Ke=w;while(1){Q=~~si;ee=Ke+1|0;n[Ke>>0]=u[329640+Q>>0]|Qe;si=(si-+(Q|0))*16;if((ee-d|0)==1){n[ee>>0]=46;wi=Ke+2|0}else wi=ee;if(!(si!=0)){ki=wi;break}else Ke=wi}}else{si=ti;Ke=w;while(1){ee=~~si;Q=Ke+1|0;n[Ke>>0]=u[329640+ee>>0]|Qe;si=(si-+(ee|0))*16;if((Q-d|0)==1){n[Q>>0]=46;di=Ke+2|0}else di=Q;if(!(si!=0)){ki=di;break}else Ke=di}}Ke=ki;Qe=ni;if((Fe|0)!=0&(N+Ke|0)<(Fe|0))vi=T+Fe-Qe|0;else vi=R-Qe+Ke|0;Qe=vi+ei|0;Q=ae&73728;ee=(pe|0)>(Qe|0);if((Q|0)==0&ee){ri=pe-Qe|0;VY(m|0,32,(ri>>>0>256?256:ri)|0)|0;if(ri>>>0>255){ci=ri;do{EY(m,256,e)|0;ci=ci+-256|0}while(ci>>>0>255);mi=ri&255}else mi=ri;EY(m,mi,e)|0}EY($e,ei,e)|0;if((Q|0)==65536&ee){ci=pe-Qe|0;VY(m|0,48,(ci>>>0>256?256:ci)|0)|0;if(ci>>>0>255){_i=ci;do{EY(m,256,e)|0;_i=_i+-256|0}while(_i>>>0>255);pi=ci&255}else pi=ci;EY(m,pi,e)|0}_i=Ke-d|0;EY(w,_i,e)|0;ei=v-ni|0;$e=vi-ei-_i|0;if(($e|0)>0){VY(m|0,48,($e>>>0>256?256:$e)|0)|0;if($e>>>0>255){_i=$e;do{EY(m,256,e)|0;_i=_i+-256|0}while(_i>>>0>255);Ei=$e&255}else Ei=$e;EY(m,Ei,e)|0}EY(ni,ei,e)|0;if((Q|0)==8192&ee){_i=pe-Qe|0;VY(m|0,32,(_i>>>0>256?256:_i)|0)|0;if(_i>>>0>255){Ke=_i;do{EY(m,256,e)|0;Ke=Ke+-256|0}while(Ke>>>0>255);Si=_i&255}else Si=_i;EY(m,Si,e)|0}I=De;H=Ce;x=Ae;i=j;U=ee?pe:Qe;z=_e;continue e}Ke=(Fe|0)<0?6:Fe;if(Ze){Q=(t[h>>2]|0)+-28|0;t[h>>2]=Q;gi=Ie*268435456;yi=Q}else{gi=Ie;yi=t[h>>2]|0}Q=(yi|0)<0?b:L;ei=Q;si=gi;ni=Q;do{$e=~~si>>>0;t[ni>>2]=$e;ni=ni+4|0;si=(si-+($e>>>0))*1e9}while(si!=0);Ze=t[h>>2]|0;if((Ze|0)>0){Qe=Ze;ee=Q;_i=ni;while(1){$e=(Qe|0)>29?29:Qe;ci=_i+-4|0;do if(ci>>>0<ee>>>0)Fi=ee;else{ri=0;Oi=ci;do{Ai=UY(t[Oi>>2]|0,0,$e|0)|0;Mi=jY(Ai|0,P|0,ri|0,0)|0;Ai=P;Ri=iG(Mi|0,Ai|0,1e9,0)|0;t[Oi>>2]=Ri;ri=eG(Mi|0,Ai|0,1e9,0)|0;Oi=Oi+-4|0}while(Oi>>>0>=ee>>>0);if(!ri){Fi=ee;break}Oi=ee+-4|0;t[Oi>>2]=ri;Fi=Oi}while(0);ci=_i;while(1){if(ci>>>0<=Fi>>>0)break;Oi=ci+-4|0;if(!(t[Oi>>2]|0))ci=Oi;else break}Oi=(t[h>>2]|0)-$e|0;t[h>>2]=Oi;if((Oi|0)>0){Qe=Oi;ee=Fi;_i=ci}else{Ni=Oi;Ti=Fi;Li=ci;break}}}else{Ni=Ze;Ti=Q;Li=ni}r:do if((Ni|0)<0){_i=((Ke+25|0)/9|0)+1|0;if((be|0)==102){ee=Q+(_i<<2)|0;Qe=Ni;Oi=Ti;Ai=Li;while(1){Mi=0-Qe|0;Ri=(Mi|0)>9?9:Mi;do if(Oi>>>0<Ai>>>0){Mi=(1<<Ri)+-1|0;Di=1e9>>>Ri;Ci=0;Pi=Oi;do{Bi=t[Pi>>2]|0;t[Pi>>2]=(Bi>>>Ri)+Ci;Ci=te(Bi&Mi,Di)|0;Pi=Pi+4|0}while(Pi>>>0<Ai>>>0);Pi=(t[Oi>>2]|0)==0?Oi+4|0:Oi;if(!Ci){Ii=Pi;Hi=Ai;break}t[Ai>>2]=Ci;Ii=Pi;Hi=Ai+4|0}else{Ii=(t[Oi>>2]|0)==0?Oi+4|0:Oi;Hi=Ai}while(0);ri=(Hi-ei>>2|0)>(_i|0)?ee:Hi;Qe=(t[h>>2]|0)+Ri|0;t[h>>2]=Qe;if((Qe|0)>=0){xi=Ii;Ui=ri;break r}else{Oi=Ii;Ai=ri}}}else{zi=Ni;ji=Ti;Vi=Li}while(1){Ai=0-zi|0;Oi=(Ai|0)>9?9:Ai;do if(ji>>>0<Vi>>>0){Ai=(1<<Oi)+-1|0;Qe=1e9>>>Oi;ee=0;ci=ji;do{$e=t[ci>>2]|0;t[ci>>2]=($e>>>Oi)+ee;ee=te($e&Ai,Qe)|0;ci=ci+4|0}while(ci>>>0<Vi>>>0);ci=(t[ji>>2]|0)==0?ji+4|0:ji;if(!ee){qi=ci;Yi=Vi;break}t[Vi>>2]=ee;qi=ci;Yi=Vi+4|0}else{qi=(t[ji>>2]|0)==0?ji+4|0:ji;Yi=Vi}while(0);if((Yi-qi>>2|0)>(_i|0))Gi=qi+(_i<<2)|0;else Gi=Yi;zi=(t[h>>2]|0)+Oi|0;t[h>>2]=zi;if((zi|0)>=0){xi=qi;Ui=Gi;break}else{ji=qi;Vi=Gi}}}else{xi=Ti;Ui=Li}while(0);do if(xi>>>0<Ui>>>0){ni=(ei-xi>>2)*9|0;Ze=t[xi>>2]|0;if(Ze>>>0<10){Wi=ni;break}else{Ki=ni;Xi=10}while(1){Xi=Xi*10|0;ni=Ki+1|0;if(Ze>>>0<Xi>>>0){Wi=ni;break}else Ki=ni}}else Wi=0;while(0);Ze=(be|0)==103;ni=Ke-((be|0)!=102?Wi:0)+((Ze&(Ke|0)!=0)<<31>>31)|0;if((ni|0)<(((Ui-ei>>2)*9|0)+-9|0)){_i=ni+9216|0;ni=(_i|0)/9|0;Ri=Q+(ni+-1023<<2)|0;ci=((_i|0)%9|0)+1|0;if((ci|0)<9){_i=10;Qe=ci;while(1){ci=_i*10|0;Qe=Qe+1|0;if((Qe|0)==9){Zi=ci;break}else _i=ci}}else Zi=10;_i=t[Ri>>2]|0;Qe=(_i>>>0)%(Zi>>>0)|0;if((Qe|0)==0?(Q+(ni+-1022<<2)|0)==(Ui|0):0){Ji=xi;Qi=Ri;$i=Wi}else q=232;do if((q|0)==232){q=0;fi=(((_i>>>0)/(Zi>>>0)|0)&1|0)==0?9007199254740992:9007199254740994;be=(Zi|0)/2|0;do if(Qe>>>0<be>>>0)er=.5;else{if((Qe|0)==(be|0)?(Q+(ni+-1022<<2)|0)==(Ui|0):0){er=1;break}er=1.5}while(0);do if(!qe){ir=fi;rr=er}else{if((n[Ye>>0]|0)!=45){ir=fi;rr=er;break}ir=fi*-1;rr=er*-1}while(0);be=_i-Qe|0;t[Ri>>2]=be;if(!(ir+rr!=ir)){Ji=xi;Qi=Ri;$i=Wi;break}ci=be+Zi|0;t[Ri>>2]=ci;if(ci>>>0>999999999){ci=xi;be=Ri;while(1){Ai=be+-4|0;t[be>>2]=0;if(Ai>>>0<ci>>>0){Ci=ci+-4|0;t[Ci>>2]=0;nr=Ci}else nr=ci;Ci=(t[Ai>>2]|0)+1|0;t[Ai>>2]=Ci;if(Ci>>>0>999999999){ci=nr;be=Ai}else{fr=nr;tr=Ai;break}}}else{fr=xi;tr=Ri}be=(ei-fr>>2)*9|0;ci=t[fr>>2]|0;if(ci>>>0<10){Ji=fr;Qi=tr;$i=be;break}else{ur=be;ar=10}while(1){ar=ar*10|0;be=ur+1|0;if(ci>>>0<ar>>>0){Ji=fr;Qi=tr;$i=be;break}else ur=be}}while(0);Ri=Qi+4|0;or=Ji;cr=$i;lr=Ui>>>0>Ri>>>0?Ri:Ui}else{or=xi;cr=Wi;lr=Ui}Ri=0-cr|0;Qe=lr;while(1){if(Qe>>>0<=or>>>0){sr=0;break}_i=Qe+-4|0;if(!(t[_i>>2]|0))Qe=_i;else{sr=1;break}}do if(Ze){_i=((Ke|0)==0&1)+Ke|0;if((_i|0)>(cr|0)&(cr|0)>-5){br=se+-1|0;kr=_i+-1-cr|0}else{br=se+-2|0;kr=_i+-1|0}if(ae&8){hr=br;wr=kr;break}do if(sr){_i=t[Qe+-4>>2]|0;if(!_i){dr=9;break}if(!((_i>>>0)%10|0)){vr=10;mr=0}else{dr=0;break}while(1){vr=vr*10|0;ni=mr+1|0;if((_i>>>0)%(vr>>>0)|0){dr=ni;break}else mr=ni}}else dr=9;while(0);_i=((Qe-ei>>2)*9|0)+-9|0;if((br|32|0)==102){Oi=_i-dr|0;ni=(Oi|0)<0?0:Oi;hr=br;wr=(kr|0)<(ni|0)?kr:ni;break}else{ni=_i+cr-dr|0;_i=(ni|0)<0?0:ni;hr=br;wr=(kr|0)<(_i|0)?kr:_i;break}}else{hr=se;wr=Ke}while(0);Ke=(wr|0)!=0;if(Ke)_r=1;else _r=(ae&8|0)!=0;ei=_r&1;Ze=(hr|32|0)==102;if(Ze){pr=(cr|0)>0?cr:0;Er=0}else{_i=(cr|0)<0?Ri:cr;if((_i|0)<0){ni=A;Oi=_i;ci=((_i|0)<0)<<31>>31;while(1){be=iG(Oi|0,ci|0,10,0)|0;ni=ni+-1|0;n[ni>>0]=be|48;be=Oi;Oi=eG(Oi|0,ci|0,10,0)|0;if(!(ci>>>0>9|(ci|0)==9&be>>>0>4294967295))break;else ci=P}Sr=ni;gr=Oi}else{Sr=A;gr=_i}if(!gr)yr=Sr;else{ci=Sr;Ri=gr;while(1){be=ci+-1|0;n[be>>0]=(Ri>>>0)%10|0|48;if(Ri>>>0<10){yr=be;break}else{ci=be;Ri=(Ri>>>0)/10|0}}}if((v-yr|0)<2){Ri=yr;while(1){ci=Ri+-1|0;n[ci>>0]=48;if((v-ci|0)<2)Ri=ci;else{Fr=ci;break}}}else Fr=yr;n[Fr+-1>>0]=(cr>>31&2)+43;Ri=Fr+-2|0;n[Ri>>0]=hr;pr=v-Ri|0;Er=Ri}Ri=qe+1+wr+ei+pr|0;ci=ae&73728;_i=(pe|0)>(Ri|0);if((ci|0)==0&_i){Oi=pe-Ri|0;VY(m|0,32,(Oi>>>0>256?256:Oi)|0)|0;if(Oi>>>0>255){ni=Oi;do{EY(m,256,e)|0;ni=ni+-256|0}while(ni>>>0>255);Or=Oi&255}else Or=Oi;EY(m,Or,e)|0}EY(Ye,qe,e)|0;if((ci|0)==65536&_i){ni=pe-Ri|0;VY(m|0,48,(ni>>>0>256?256:ni)|0)|0;if(ni>>>0>255){ei=ni;do{EY(m,256,e)|0;ei=ei+-256|0}while(ei>>>0>255);Ar=ni&255}else Ar=ni;EY(m,Ar,e)|0}do if(Ze){ei=or>>>0>Q>>>0?Q:or;Oi=ei;do{be=t[Oi>>2]|0;if(!be)Mr=D;else{Ai=D;Ci=be;while(1){be=Ai+-1|0;n[be>>0]=(Ci>>>0)%10|0|48;if(Ci>>>0<10){Mr=be;break}else{Ai=be;Ci=(Ci>>>0)/10|0}}}do if((Oi|0)==(ei|0)){if((Mr|0)!=(D|0)){Rr=Mr;break}n[B>>0]=48;Rr=B}else{if(Mr>>>0>w>>>0)Nr=Mr;else{Rr=Mr;break}while(1){Ci=Nr+-1|0;n[Ci>>0]=48;if(Ci>>>0>w>>>0)Nr=Ci;else{Rr=Ci;break}}}while(0);EY(Rr,C-Rr|0,e)|0;Oi=Oi+4|0}while(Oi>>>0<=Q>>>0);if(!((ae&8|0)==0&(Ke^1)))EY(329656,1,e)|0;if(Oi>>>0<Qe>>>0&(wr|0)>0){ei=wr;ee=Oi;while(1){Ci=t[ee>>2]|0;if(Ci){Ai=D;be=Ci;while(1){Ai=Ai+-1|0;n[Ai>>0]=(be>>>0)%10|0|48;if(be>>>0<10)break;else be=(be>>>0)/10|0}if(Ai>>>0>w>>>0){Tr=Ai;q=301}else Lr=Ai}else{Tr=D;q=301}if((q|0)==301)while(1){q=0;be=Tr+-1|0;n[be>>0]=48;if(be>>>0>w>>>0){Tr=be;q=301}else{Lr=be;break}}EY(Lr,(ei|0)>9?9:ei,e)|0;ee=ee+4|0;Ai=ei+-9|0;if(!(ee>>>0<Qe>>>0&(Ai|0)>0)){Dr=Ai;break}else ei=Ai}}else Dr=wr;if((Dr|0)<=0)break;VY(m|0,48,(Dr>>>0>256?256:Dr)|0)|0;if(Dr>>>0>255){ei=Dr;do{EY(m,256,e)|0;ei=ei+-256|0}while(ei>>>0>255);Cr=Dr&255}else Cr=Dr;EY(m,Cr,e)|0}else{ei=sr?Qe:or+4|0;do if((wr|0)>-1){ee=(ae&8|0)==0;Oi=wr;Ai=or;do{be=t[Ai>>2]|0;if(be){Ci=D;$e=be;while(1){Ci=Ci+-1|0;n[Ci>>0]=($e>>>0)%10|0|48;if($e>>>0<10)break;else $e=($e>>>0)/10|0}if((Ci|0)!=(D|0))Pr=Ci;else q=313}else q=313;if((q|0)==313){q=0;n[B>>0]=48;Pr=B}do if((Ai|0)==(or|0)){$e=Pr+1|0;EY(Pr,1,e)|0;if((Oi|0)<1&ee){Br=$e;break}EY(329656,1,e)|0;Br=$e}else{if(Pr>>>0>w>>>0)Ir=Pr;else{Br=Pr;break}while(1){$e=Ir+-1|0;n[$e>>0]=48;if($e>>>0>w>>>0)Ir=$e;else{Br=$e;break}}}while(0);Ci=C-Br|0;EY(Br,(Oi|0)>(Ci|0)?Ci:Oi,e)|0;Oi=Oi-Ci|0;Ai=Ai+4|0}while(Ai>>>0<ei>>>0&(Oi|0)>-1);if((Oi|0)<=0)break;VY(m|0,48,(Oi>>>0>256?256:Oi)|0)|0;if(Oi>>>0>255){Ai=Oi;do{EY(m,256,e)|0;Ai=Ai+-256|0}while(Ai>>>0>255);Hr=Oi&255}else Hr=Oi;EY(m,Hr,e)|0}while(0);EY(Er,v-Er|0,e)|0}while(0);if((ci|0)==8192&_i){Qe=pe-Ri|0;VY(m|0,32,(Qe>>>0>256?256:Qe)|0)|0;if(Qe>>>0>255){Ke=Qe;do{EY(m,256,e)|0;Ke=Ke+-256|0}while(Ke>>>0>255);xr=Qe&255}else xr=Qe;EY(m,xr,e)|0}I=De;H=Ce;x=Ae;i=j;U=_i?pe:Ri;z=_e;continue e;break}case 117:{xe=Ce;Ue=De;ze=0;je=329560;q=86;break}case 88:case 120:{Ur=ae;zr=Fe;jr=se;q=75;break}case 99:{n[F>>0]=De;Vr=De;qr=Ce;Yr=F;Gr=$;Wr=1;Kr=0;Xr=329560;Zr=g;break}case 111:{Ke=(De|0)==0&(Ce|0)==0;if(Ke)Jr=g;else{ci=g;Q=De;Ze=Ce;while(1){ni=ci+-1|0;n[ni>>0]=Q&7|48;Q=qY(Q|0,Ze|0,3)|0;Ze=P;if((Q|0)==0&(Ze|0)==0){Jr=ni;break}else ci=ni}}ci=(ae&8|0)==0|Ke;Qr=De;$r=Ce;en=Jr;rn=ae;nn=Fe;fn=ci&1^1;tn=ci?329560:329565;q=91;break}case 67:{t[p>>2]=De;t[_>>2]=0;un=p;an=O;on=-1;q=101;break}case 83:{ci=De;if(!Fe){cn=De;ln=ci;sn=0;q=106}else{un=ci;an=De;on=Fe;q=101}break}case 112:{Ur=ae|8;zr=Fe>>>0>8?Fe:8;jr=120;q=75;break}case 115:{He=(De|0)==0?329576:De;q=96;break}default:{Vr=De;qr=Ce;Yr=x;Gr=ae;Wr=Fe;Kr=0;Xr=329560;Zr=g}}while(0);do if((q|0)==75){q=0;se=jr&32;if(!((De|0)==0&(Ce|0)==0)){V=g;J=De;ue=Ce;do{V=V+-1|0;n[V>>0]=u[329640+(J&15)>>0]|se;J=qY(J|0,ue|0,4)|0;ue=P}while(!((J|0)==0&(ue|0)==0));if(!(Ur&8)){Qr=De;$r=Ce;en=V;rn=Ur;nn=zr;fn=0;tn=329560;q=91}else{Qr=De;$r=Ce;en=V;rn=Ur;nn=zr;fn=2;tn=329560+(jr>>4)|0;q=91}}else{Qr=De;$r=Ce;en=g;rn=Ur;nn=zr;fn=0;tn=329560;q=91}}else if((q|0)==86){q=0;if(xe>>>0>0|(xe|0)==0&Ue>>>0>4294967295){ue=g;J=Ue;se=xe;while(1){Ke=iG(J|0,se|0,10,0)|0;ue=ue+-1|0;n[ue>>0]=Ke|48;Ke=J;J=eG(J|0,se|0,10,0)|0;if(!(se>>>0>9|(se|0)==9&Ke>>>0>4294967295))break;else se=P}bn=ue;kn=J}else{bn=g;kn=Ue}if(!kn){Qr=Ue;$r=xe;en=bn;rn=ae;nn=Fe;fn=ze;tn=je;q=91}else{se=bn;V=kn;while(1){Ke=se+-1|0;n[Ke>>0]=(V>>>0)%10|0|48;if(V>>>0<10){Qr=Ue;$r=xe;en=Ke;rn=ae;nn=Fe;fn=ze;tn=je;q=91;break}else{se=Ke;V=(V>>>0)/10|0}}}}else if((q|0)==96){q=0;V=OY(He,0,Fe)|0;if(!V){Vr=De;qr=Ce;Yr=He;Gr=$;Wr=Fe;Kr=0;Xr=329560;Zr=He+Fe|0;break}else{Vr=De;qr=Ce;Yr=He;Gr=$;Wr=V-He|0;Kr=0;Xr=329560;Zr=V;break}}else if((q|0)==101){q=0;V=0;se=0;J=un;while(1){ue=t[J>>2]|0;if(!ue){hn=V;wn=se;break}Ke=wY(E,ue)|0;if((Ke|0)<0|Ke>>>0>(on-V|0)>>>0){hn=V;wn=Ke;break}ue=Ke+V|0;if(on>>>0>ue>>>0){V=ue;se=Ke;J=J+4|0}else{hn=ue;wn=Ke;break}}if((wn|0)<0){de=-1;q=370;break e}else{cn=an;ln=un;sn=hn;q=106}}while(0);if((q|0)==91){q=0;$=(nn|0)>-1?rn&-65537:rn;J=(Qr|0)!=0|($r|0)!=0;if(J|(nn|0)!=0){se=(J&1^1)+(y-en)|0;Vr=Qr;qr=$r;Yr=en;Gr=$;Wr=(nn|0)>(se|0)?nn:se;Kr=fn;Xr=tn;Zr=g}else{Vr=Qr;qr=$r;Yr=g;Gr=$;Wr=0;Kr=fn;Xr=tn;Zr=g}}else if((q|0)==106){q=0;$=ae&73728;se=(pe|0)>(sn|0);if(($|0)==0&se){J=pe-sn|0;VY(m|0,32,(J>>>0>256?256:J)|0)|0;if(J>>>0>255){V=J;do{EY(m,256,e)|0;V=V+-256|0}while(V>>>0>255);dn=J&255}else dn=J;EY(m,dn,e)|0}i:do if(sn){V=0;ae=ln;while(1){Ke=t[ae>>2]|0;if(!Ke)break i;ue=wY(E,Ke)|0;V=ue+V|0;if((V|0)>(sn|0))break i;EY(E,ue,e)|0;if(V>>>0>=sn>>>0)break;else ae=ae+4|0}}while(0);if(($|0)==8192&se){J=pe-sn|0;VY(m|0,32,(J>>>0>256?256:J)|0)|0;if(J>>>0>255){ae=J;do{EY(m,256,e)|0;ae=ae+-256|0}while(ae>>>0>255);vn=J&255}else vn=J;EY(m,vn,e)|0}I=cn;H=Ce;x=Ae;i=j;U=se?pe:sn;z=_e;continue}ae=Zr-Yr|0;$=(Wr|0)<(ae|0)?ae:Wr;V=Kr+$|0;ue=(pe|0)<(V|0)?V:pe;Ke=Gr&73728;ci=(ue|0)>(V|0);if((Ke|0)==0&ci){Ze=ue-V|0;VY(m|0,32,(Ze>>>0>256?256:Ze)|0)|0;if(Ze>>>0>255){Q=Ze;do{EY(m,256,e)|0;Q=Q+-256|0}while(Q>>>0>255);mn=Ze&255}else mn=Ze;EY(m,mn,e)|0}EY(Xr,Kr,e)|0;if((Ke|0)==65536&ci){Q=ue-V|0;VY(m|0,48,(Q>>>0>256?256:Q)|0)|0;if(Q>>>0>255){se=Q;do{EY(m,256,e)|0;se=se+-256|0}while(se>>>0>255);_n=Q&255}else _n=Q;EY(m,_n,e)|0}if(($|0)>(ae|0)){se=$-ae|0;VY(m|0,48,(se>>>0>256?256:se)|0)|0;if(se>>>0>255){Ze=se;do{EY(m,256,e)|0;Ze=Ze+-256|0}while(Ze>>>0>255);pn=se&255}else pn=se;EY(m,pn,e)|0}EY(Yr,ae,e)|0;if(!((Ke|0)==8192&ci)){I=Vr;H=qr;x=Ae;i=j;U=ue;z=_e;continue}Ze=ue-V|0;VY(m|0,32,(Ze>>>0>256?256:Ze)|0)|0;if(Ze>>>0>255){$=Ze;do{EY(m,256,e)|0;$=$+-256|0}while($>>>0>255);En=Ze&255}else En=Ze;EY(m,En,e)|0;I=Vr;H=qr;x=Ae;i=j;U=ue;z=_e}if((q|0)==352){if(e){de=j;s=c;return de|0}if(!z){de=0;s=c;return de|0}else Sn=1;while(1){z=t[o+(Sn<<2)>>2]|0;if(!z){gn=Sn;break}j=a+(Sn<<3)|0;e:do if(z>>>0<=20)do switch(z|0){case 9:{e=t[r>>2]|0;_e=t[e>>2]|0;t[r>>2]=e+4;t[j>>2]=_e;break e;break}case 10:{_e=t[r>>2]|0;e=t[_e>>2]|0;t[r>>2]=_e+4;_e=j;t[_e>>2]=e;t[_e+4>>2]=((e|0)<0)<<31>>31;break e;break}case 11:{e=t[r>>2]|0;_e=t[e>>2]|0;t[r>>2]=e+4;e=j;t[e>>2]=_e;t[e+4>>2]=0;break e;break}case 12:{e=t[r>>2]|0;_e=e;U=t[_e>>2]|0;i=t[_e+4>>2]|0;t[r>>2]=e+8;e=j;t[e>>2]=U;t[e+4>>2]=i;break e;break}case 13:{i=t[r>>2]|0;e=t[i>>2]|0;t[r>>2]=i+4;i=(e&65535)<<16>>16;e=j;t[e>>2]=i;t[e+4>>2]=((i|0)<0)<<31>>31;break e;break}case 14:{i=t[r>>2]|0;e=t[i>>2]|0;t[r>>2]=i+4;i=j;t[i>>2]=e&65535;t[i+4>>2]=0;break e;break}case 15:{i=t[r>>2]|0;e=t[i>>2]|0;t[r>>2]=i+4;i=(e&255)<<24>>24;e=j;t[e>>2]=i;t[e+4>>2]=((i|0)<0)<<31>>31;break e;break}case 16:{i=t[r>>2]|0;e=t[i>>2]|0;t[r>>2]=i+4;i=j;t[i>>2]=e&255;t[i+4>>2]=0;break e;break}case 17:{i=t[r>>2]|0;t[k>>2]=t[i>>2];t[k+4>>2]=t[i+4>>2];ir=+l[k>>3];t[r>>2]=i+8;l[j>>3]=ir;break e;break}case 18:{i=t[r>>2]|0;t[k>>2]=t[i>>2];t[k+4>>2]=t[i+4>>2];ir=+l[k>>3];t[r>>2]=i+8;l[j>>3]=ir;break e;break}default:break e}while(0);while(0);Sn=Sn+1|0;if((Sn|0)>=10){de=1;q=370;break}}if((q|0)==370){s=c;return de|0}while(1){if(t[o+(gn<<2)>>2]|0){de=-1;q=370;break}gn=gn+1|0;if((gn|0)>=10){de=1;q=370;break}}if((q|0)==370){s=c;return de|0}}else if((q|0)==370){s=c;return de|0}return 0}function PY(){}function BY(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0;f=i-n>>>0;f=i-n-(r>>>0>e>>>0|0)>>>0;return(P=f,e-r>>>0|0)|0}function IY(e,i,r){e=e|0;i=i|0;r=r|0;if((r|0)<32){P=i>>r;return e>>>r|(i&(1<<r)-1)<<32-r}P=(i|0)<0?-1:0;return i>>r-32|0}function HY(e){e=e|0;var i=0;i=e;while(n[i>>0]|0)i=i+1|0;return i-e|0}function xY(e,i){e=e|0;i=i|0;var r=0,f=0;r=e+(HY(e)|0)|0;do{n[r+f>>0]=n[i+f>>0];f=f+1|0}while(n[i+(f-1)>>0]|0);return e|0}function UY(e,i,r){e=e|0;i=i|0;r=r|0;if((r|0)<32){P=i<<r|(e&(1<<r)-1<<32-r)>>>32-r;return e<<r}P=e<<r-32;return 0}function zY(e,i,r){e=e|0;i=i|0;r=r|0;var f=0,t=0;while((f|0)<(r|0)){n[e+f>>0]=t?0:n[i+f>>0]|0;t=t?1:(n[i+f>>0]|0)==0;f=f+1|0}return e|0}function jY(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0;f=e+r>>>0;return(P=i+n+(f>>>0<e>>>0|0)>>>0,f|0)|0}function VY(e,i,r){e=e|0;i=i|0;r=r|0;var f=0,u=0,a=0,o=0;f=e+r|0;if((r|0)>=20){i=i&255;u=e&3;a=i|i<<8|i<<16|i<<24;o=f&~3;if(u){u=e+4-u|0;while((e|0)<(u|0)){n[e>>0]=i;e=e+1|0}}while((e|0)<(o|0)){t[e>>2]=a;e=e+4|0}}while((e|0)<(f|0)){n[e>>0]=i;e=e+1|0}return e-r|0}function qY(e,i,r){e=e|0;i=i|0;r=r|0;if((r|0)<32){P=i>>>r;return e>>>r|(i&(1<<r)-1)<<32-r}P=0;return i>>>r-32|0}function YY(e,i,r){e=e|0;i=i|0;r=r|0;var f=0;if((r|0)>=4096)return je(e|0,i|0,r|0)|0;f=e|0;if((e&3)==(i&3)){while(e&3){if(!r)return f|0;n[e>>0]=n[i>>0]|0;e=e+1|0;i=i+1|0;r=r-1|0}while((r|0)>=4){t[e>>2]=t[i>>2];e=e+4|0;i=i+4|0;r=r-4|0}}while((r|0)>0){n[e>>0]=n[i>>0]|0;e=e+1|0;i=i+1|0;r=r-1|0}return f|0}function GY(e,i,r){e=e|0;i=i|0;r=r|0;var f=0;if((i|0)<(e|0)&(e|0)<(i+r|0)){f=e;i=i+r|0;e=e+r|0;while((r|0)>0){e=e-1|0;i=i-1|0;r=r-1|0;n[e>>0]=n[i>>0]|0}e=f}else YY(e,i,r)|0;return e|0}function WY(e,i){e=e|0;i=i|0;var r=0;do{n[e+r>>0]=n[i+r>>0];r=r+1|0}while(n[i+(r-1)>>0]|0);return e|0}function KY(e){e=e|0;var i=0;i=n[d+(e>>>24)>>0]|0;if((i|0)<8)return i|0;i=n[d+(e>>16&255)>>0]|0;if((i|0)<8)return i+8|0;i=n[d+(e>>8&255)>>0]|0;if((i|0)<8)return i+16|0;return(n[d+(e&255)>>0]|0)+24|0}function XY(e){e=e|0;var i=0;i=n[w+(e&255)>>0]|0;if((i|0)<8)return i|0;i=n[w+(e>>8&255)>>0]|0;if((i|0)<8)return i+8|0;i=n[w+(e>>16&255)>>0]|0;if((i|0)<8)return i+16|0;return(n[w+(e>>>24)>>0]|0)+24|0}function ZY(e,i){e=e|0;i=i|0;var r=0,n=0,f=0,t=0;r=e&65535;n=i&65535;f=te(n,r)|0;t=e>>>16;e=(f>>>16)+(te(n,t)|0)|0;n=i>>>16;i=te(n,r)|0;return(P=(e>>>16)+(te(n,t)|0)+(((e&65535)+i|0)>>>16)|0,e+i<<16|f&65535|0)|0}function JY(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,t=0,u=0,a=0,o=0;f=i>>31|((i|0)<0?-1:0)<<1;t=((i|0)<0?-1:0)>>31|((i|0)<0?-1:0)<<1;u=n>>31|((n|0)<0?-1:0)<<1;a=((n|0)<0?-1:0)>>31|((n|0)<0?-1:0)<<1;o=BY(f^e,t^i,f,t)|0;i=P;e=u^f;f=a^t;t=BY((rG(o,i,BY(u^r,a^n,u,a)|0,P,0)|0)^e,P^f,e,f)|0;return t|0}function QY(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,u=0,a=0,o=0,c=0,l=0,b=0;f=s;s=s+8|0;u=f|0;a=i>>31|((i|0)<0?-1:0)<<1;o=((i|0)<0?-1:0)>>31|((i|0)<0?-1:0)<<1;c=n>>31|((n|0)<0?-1:0)<<1;l=((n|0)<0?-1:0)>>31|((n|0)<0?-1:0)<<1;b=BY(a^e,o^i,a,o)|0;i=P;rG(b,i,BY(c^r,l^n,c,l)|0,P,u)|0;l=BY(t[u>>2]^a,t[u+4>>2]^o,a,o)|0;o=P;s=f;return(P=o,l)|0}function $Y(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,t=0;f=e;e=r;r=ZY(f,e)|0;t=P;return(P=(te(i,e)|0)+(te(n,f)|0)+t|t&0,r|0|0)|0}function eG(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0;f=rG(e,i,r,n,0)|0;return f|0}function iG(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;var f=0,u=0;f=s;s=s+8|0;u=f|0;rG(e,i,r,n,u)|0;s=f;return(P=t[u+4>>2]|0,t[u>>2]|0)|0}function rG(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;var u=0,a=0,o=0,c=0,l=0,s=0,b=0,k=0,h=0,w=0,d=0,v=0,m=0,_=0,p=0,E=0,S=0,g=0,y=0,F=0,O=0,A=0,M=0,R=0,N=0,T=0,L=0;u=e;a=i;o=a;c=r;l=n;s=l;if(!o){b=(f|0)!=0;if(!s){if(b){t[f>>2]=(u>>>0)%(c>>>0);t[f+4>>2]=0}k=0;h=(u>>>0)/(c>>>0)>>>0;return(P=k,h)|0}else{if(!b){k=0;h=0;return(P=k,h)|0}t[f>>2]=e|0;t[f+4>>2]=i&0;k=0;h=0;return(P=k,h)|0}}b=(s|0)==0;do if(c){if(!b){w=(KY(s|0)|0)-(KY(o|0)|0)|0;if(w>>>0<=31){d=w+1|0;v=31-w|0;m=w-31>>31;_=d;p=u>>>(d>>>0)&m|o<<v;E=o>>>(d>>>0)&m;S=0;g=u<<v;break}if(!f){k=0;h=0;return(P=k,h)|0}t[f>>2]=e|0;t[f+4>>2]=a|i&0;k=0;h=0;return(P=k,h)|0}v=c-1|0;if(v&c){m=(KY(c|0)|0)+33-(KY(o|0)|0)|0;d=64-m|0;w=32-m|0;y=w>>31;F=m-32|0;O=F>>31;_=m;p=w-1>>31&o>>>(F>>>0)|(o<<w|u>>>(m>>>0))&O;E=O&o>>>(m>>>0);S=u<<d&y;g=(o<<d|u>>>(F>>>0))&y|u<<w&m-33>>31;break}if(f){t[f>>2]=v&u;t[f+4>>2]=0}if((c|0)==1){k=a|i&0;h=e|0|0;return(P=k,h)|0}else{v=XY(c|0)|0;k=o>>>(v>>>0)|0;h=o<<32-v|u>>>(v>>>0)|0;return(P=k,h)|0}}else{if(b){if(f){t[f>>2]=(o>>>0)%(c>>>0);t[f+4>>2]=0}k=0;h=(o>>>0)/(c>>>0)>>>0;return(P=k,h)|0}if(!u){if(f){t[f>>2]=0;t[f+4>>2]=(o>>>0)%(s>>>0)}k=0;h=(o>>>0)/(s>>>0)>>>0;return(P=k,h)|0}v=s-1|0;if(!(v&s)){if(f){t[f>>2]=e|0;t[f+4>>2]=v&o|i&0}k=0;h=o>>>((XY(s|0)|0)>>>0);return(P=k,h)|0}v=(KY(s|0)|0)-(KY(o|0)|0)|0;if(v>>>0<=30){m=v+1|0;w=31-v|0;_=m;p=o<<w|u>>>(m>>>0);E=o>>>(m>>>0);S=0;g=u<<w;break}if(!f){k=0;h=0;return(P=k,h)|0}t[f>>2]=e|0;t[f+4>>2]=a|i&0;k=0;h=0;return(P=k,h)|0}while(0);if(!_){A=g;M=S;R=E;N=p;T=0;L=0}else{i=r|0|0;r=l|n&0;n=jY(i,r,-1,-1)|0;l=P;a=g;g=S;S=E;E=p;p=_;_=0;do{e=a;a=g>>>31|a<<1;g=_|g<<1;u=E<<1|e>>>31|0;e=E>>>31|S<<1|0;BY(n,l,u,e)|0;o=P;s=o>>31|((o|0)<0?-1:0)<<1;_=s&1;E=BY(u,e,s&i,(((o|0)<0?-1:0)>>31|((o|0)<0?-1:0)<<1)&r)|0;S=P;p=p-1|0}while((p|0)!=0);A=a;M=g;R=S;N=E;T=0;L=_}_=M;M=0;if(f){t[f>>2]=N;t[f+4>>2]=R}k=(_|0)>>>31|(A|M)<<1|(M<<1|_>>>31)&0|T;h=(_<<1|0>>>31)&-2|L;return(P=k,h)|0}function nG(e,i,r,n,f,t,u,a){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;return wAi[e&511](i|0,r|0,n|0,f|0,t|0,u|0,a|0)|0}function fG(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return dAi[e&511](i|0,r|0,n|0)|0}function tG(e,i,r,n,f,t,u,a){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;vAi[e&511](i|0,r|0,n|0,f|0,t|0,u|0,a|0)}function uG(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;mAi[e&511](i|0,r|0,n|0,f|0,t|0)}function aG(e){e=e|0;return _Ai[e&511]()|0}function oG(e,i){e=e|0;i=i|0;pAi[e&511](i|0);
	}function cG(e,i,r){e=e|0;i=i|0;r=r|0;EAi[e&511](i|0,r|0)}function lG(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return SAi[e&511](i|0,r|0,n|0,f|0,t|0,u|0)|0}function sG(e,i){e=e|0;i=i|0;return gAi[e&511](i|0)|0}function bG(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;yAi[e&511](i|0,r|0,n|0)}function kG(e,i,r,n,f,t,u,a,o,c){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;c=c|0;FAi[e&511](i|0,r|0,n|0,f|0,t|0,u|0,a|0,o|0,c|0)}function hG(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return OAi[e&511](i|0,r|0,n|0,f|0)|0}function wG(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;AAi[e&511](i|0,r|0,n|0,f|0,t|0,u|0)}function dG(e,i,r){e=e|0;i=i|0;r=r|0;return MAi[e&511](i|0,r|0)|0}function vG(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return RAi[e&511](i|0,r|0,n|0,f|0,t|0)|0}function mG(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;NAi[e&511](i|0,r|0,n|0,f|0)}function _G(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;ue(0);return 0}function pG(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return 0}function EG(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return Pm(e|0)|0}function SG(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return Bm(e|0)|0}function gG(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return Im(e|0)|0}function yG(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return Hm(e|0,i|0,r|0)|0}function FG(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return xm(e|0,i|0)|0}function OG(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return 0}function AG(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return 0}function MG(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return 0}function RG(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return 0}function NG(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return 0}function TG(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return 0}function LG(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return 0}function DG(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return 0}function CG(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return 0}function PG(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return 0}function BG(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return 0}function IG(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return 0}function HG(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return 0}function xG(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return 0}function UG(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return 0}function zG(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return 0}function jG(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return 0}function VG(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return 0}function qG(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return r_(e|0,i|0)|0}function YG(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return 0}function GG(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return 0}function WG(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return 0}function KG(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return 0}function XG(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return oA(e|0,i|0,r|0)|0}function ZG(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return 0}function JG(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return Xq(e|0)|0}function QG(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return Jq(e|0,i|0)|0}function $G(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return Yl(e|0)|0}function eW(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return 0}function iW(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return 0}function rW(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return Mz(e|0)|0}function nW(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return Rz(e|0)|0}function fW(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return Nz(e|0)|0}function tW(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return Dz(e|0,i|0,r|0)|0}function uW(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return Cz(e|0,i|0)|0}function aW(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return 0}function oW(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return 0}function cW(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return 0}function lW(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return 0}function sW(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return 0}function bW(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return 0}function kW(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return 0}function hW(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return 0}function wW(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return 0}function dW(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return 0}function vW(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return 0}function mW(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return 0}function _W(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return 0}function pW(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return 0}function EW(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return 0}function SW(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return 0}function gW(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return Pz(e|0,i|0)|0}function yW(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return 0}function FW(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return 0}function OW(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return yz(e|0)|0}function AW(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return Fz(e|0)|0}function MW(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return Oz(e|0)|0}function RW(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return Az(e|0)|0}function NW(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return 0}function TW(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return OC(e|0)|0}function LW(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return AC(e|0)|0}function DW(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return MC(e|0)|0}function CW(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return RC(e|0)|0}function PW(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return NC(e|0)|0}function BW(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return TC(e|0)|0}function IW(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return LC(e|0)|0}function HW(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return DC(e|0)|0}function xW(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return CC(e|0)|0}function UW(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return PC(e|0)|0}function zW(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return BC(e|0)|0}function jW(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return IC(e|0)|0}function VW(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return HC(e|0)|0}function qW(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return xC(e|0)|0}function YW(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return UC(e|0)|0}function GW(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return zC(e|0)|0}function WW(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return jC(e|0)|0}function KW(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return VC(e|0)|0}function XW(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return qC(e|0)|0}function ZW(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return YC(e|0)|0}function JW(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return GC(e|0)|0}function QW(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return WC(e|0)|0}function $W(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return KC(e|0)|0}function eK(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return XC(e|0)|0}function iK(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return ZC(e|0)|0}function rK(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return JC(e|0)|0}function nK(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return QC(e|0)|0}function fK(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return $C(e|0)|0}function tK(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return eP(e|0)|0}function uK(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return iP(e|0)|0}function aK(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return rP(e|0)|0}function oK(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return nP(e|0)|0}function cK(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return fP(e|0)|0}function lK(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return tP(e|0)|0}function sK(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return uP(e|0)|0}function bK(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return aP(e|0)|0}function kK(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return oP(e|0)|0}function hK(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return cP(e|0)|0}function wK(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return lP(e|0)|0}function dK(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return sP(e|0)|0}function vK(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return bP(e|0)|0}function mK(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return kP(e|0)|0}function _K(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return hP(e|0)|0}function pK(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return wP(e|0)|0}function EK(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return dP(e|0)|0}function SK(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return vP(e|0)|0}function gK(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return mP(e|0)|0}function yK(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return _P(e|0)|0}function FK(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return pP(e|0)|0}function OK(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return EP(e|0)|0}function AK(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return SP(e|0)|0}function MK(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return gP(e|0)|0}function RK(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return yP(e|0)|0}function NK(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return FP(e|0)|0}function TK(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return OP(e|0)|0}function LK(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return AP(e|0)|0}function DK(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return MP(e|0)|0}function CK(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return RP(e|0)|0}function PK(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return NP(e|0)|0}function BK(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return TP(e|0)|0}function IK(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return LP(e|0)|0}function HK(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return DP(e|0)|0}function xK(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return CP(e|0)|0}function UK(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return PP(e|0)|0}function zK(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return BP(e|0)|0}function jK(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return IP(e|0)|0}function VK(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return HP(e|0)|0}function qK(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return xP(e|0)|0}function YK(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return UP(e|0)|0}function GK(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return zP(e|0)|0}function WK(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return jP(e|0)|0}function KK(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return VP(e|0)|0}function XK(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return qP(e|0)|0}function ZK(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return YP(e|0)|0}function JK(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return GP(e|0)|0}function QK(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return WP(e|0)|0}function $K(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return KP(e|0)|0}function eX(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return XP(e|0)|0}function iX(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return ZP(e|0)|0}function rX(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return JP(e|0)|0}function nX(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return QP(e|0)|0}function fX(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return $P(e|0)|0}function tX(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return eB(e|0)|0}function uX(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return iB(e|0)|0}function aX(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return rB(e|0)|0}function oX(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return nB(e|0)|0}function cX(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return fB(e|0)|0}function lX(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return tB(e|0)|0}function sX(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return uB(e|0)|0}function bX(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return aB(e|0)|0}function kX(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return oB(e|0)|0}function hX(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return cB(e|0)|0}function wX(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return lB(e|0)|0}function dX(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return sB(e|0)|0}function vX(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return bB(e|0)|0}function mX(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return kB(e|0)|0}function _X(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return hB(e|0)|0}function pX(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return wB(e|0)|0}function EX(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return dB(e|0)|0}function SX(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return vB(e|0)|0}function gX(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return mB(e|0)|0}function yX(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return _B(e|0)|0}function FX(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return pB(e|0)|0}function OX(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return EB(e|0)|0}function AX(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return SB(e|0)|0}function MX(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return gB(e|0)|0}function RX(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return yB(e|0)|0}function NX(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return FB(e|0)|0}function TX(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return OB(e|0)|0}function LX(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return AB(e|0)|0}function DX(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return MB(e|0)|0}function CX(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return RB(e|0)|0}function PX(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return NB(e|0)|0}function BX(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return TB(e|0)|0}function IX(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return LB(e|0)|0}function HX(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return DB(e|0)|0}function xX(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return CB(e|0)|0}function UX(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return PB(e|0)|0}function zX(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return BB(e|0)|0}function jX(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return IB(e|0)|0}function VX(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return HB(e|0)|0}function qX(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return xB(e|0)|0}function YX(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return UB(e|0)|0}function GX(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return zB(e|0)|0}function WX(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return jB(e|0)|0}function KX(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return VB(e|0)|0}function XX(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return qB(e|0)|0}function ZX(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return YB(e|0)|0}function JX(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return NY(e|0,i|0,r|0)|0}function QX(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return 0}function $X(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return om(e|0)|0}function eZ(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return cm(e|0,i|0)|0}function iZ(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return lm(e|0)|0}function rZ(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return aA(e|0,i|0,r|0)|0}function nZ(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return 0}function fZ(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return 0}function tZ(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return hm(e|0,i|0,r|0)|0}function uZ(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return xe(e|0,i|0,r|0)|0}function aZ(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return pm(e|0,i|0,r|0)|0}function oZ(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return 0}function cZ(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return 0}function lZ(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return 0}function sZ(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return 0}function bZ(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return 0}function kZ(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return Am(e|0)|0}function hZ(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return 0}function wZ(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return A_(e|0)|0}function dZ(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return Z_(e|0,i|0,r|0,n|0)|0}function vZ(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return J_(e|0,i|0,r|0,n|0)|0}function mZ(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return Q_(e|0,i|0,r|0,n|0)|0}function _Z(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return $_(e|0,i|0,r|0,n|0)|0}function pZ(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return ep(e|0,i|0,r|0,n|0)|0}function EZ(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return ip(e|0,i|0,r|0,n|0)|0}function SZ(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return N_(e|0,i|0,r|0,n|0)|0}function gZ(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return T_(e|0,i|0,r|0,n|0)|0}function yZ(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return rp(e|0,i|0,r|0,n|0)|0}function FZ(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return np(e|0,i|0,r|0,n|0)|0}function OZ(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return dN(e|0,i|0,r|0,n|0)|0}function AZ(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return 0}function MZ(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return 0}function RZ(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return 0}function NZ(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return FO()|0}function TZ(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return 0}function LZ(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return 0}function DZ(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return OO(e|0)|0}function CZ(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return AO(e|0)|0}function PZ(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return MO(e|0,i|0,r|0)|0}function BZ(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return RO(e|0)|0}function IZ(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return sA(e|0)|0}function HZ(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return bA(e|0,i|0,r|0)|0}function xZ(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return hA(e|0)|0}function UZ(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return wA(e|0,i|0,r|0)|0}function zZ(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return dA(e|0)|0}function jZ(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return vA(e|0,i|0,r|0)|0}function VZ(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return mA(e|0,i|0,r|0)|0}function qZ(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return _A(e|0,i|0,r|0,n|0)|0}function YZ(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return 0}function GZ(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return OR(e|0)|0}function WZ(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return 0}function KZ(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return DR(e|0)|0}function XZ(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return 0}function ZZ(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return BR(e|0)|0}function JZ(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return 0}function QZ(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return 0}function $Z(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return 0}function eJ(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return UR(e|0,i|0)|0}function iJ(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return 0}function rJ(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return 0}function nJ(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return 0}function fJ(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return 0}function tJ(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return 0}function uJ(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return 0}function aJ(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return lN(e|0,i|0)|0}function oJ(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return 0}function cJ(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return 0}function lJ(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return 0}function sJ(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return 0}function bJ(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return 0}function kJ(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return 0}function hJ(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return 0}function wJ(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return 0}function dJ(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return 0}function vJ(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return 0}function mJ(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return 0}function _J(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return 0}function pJ(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return 0}function EJ(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return 0}function SJ(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return 0}function gJ(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return 0}function yJ(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return 0}function FJ(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return 0}function OJ(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return 0}function AJ(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return 0}function MJ(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return 0}function RJ(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return 0}function NJ(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return 0}function TJ(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return 0}function LJ(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return 0}function DJ(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return 0}function CJ(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return 0}function PJ(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return 0}function BJ(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return 0}function IJ(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return 0}function HJ(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return Qu(e|0,i|0,r|0)|0}function xJ(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return Pf(e|0,i|0)|0}function UJ(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return Bf(e|0,i|0)|0}function zJ(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return zf(e|0,i|0)|0}function jJ(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return $u(e|0,i|0,r|0)|0}function VJ(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return ea(e|0,i|0)|0}function qJ(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return Tf(e|0,i|0)|0}function YJ(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return Lf(e|0,i|0)|0}function GJ(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return Df(e|0,i|0)|0}function WJ(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return xf(e|0,i|0)|0}function KJ(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return If(e|0,i|0)|0}function XJ(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return Uf(e|0,i|0)|0}function ZJ(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return Cf(e|0,i|0)|0}function JJ(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return ia(e|0,i|0)|0}function QJ(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return Hf(e|0,i|0)|0}function $J(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return Nf(e|0,i|0)|0}function eQ(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return Cn(e|0,i|0)|0}function iQ(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return 0}function rQ(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return 0}function nQ(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return 0}function fQ(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return 0}function tQ(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return 0}function uQ(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return 0}function aQ(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return 0}function oQ(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return 0}function cQ(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return 0}function lQ(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return 0}function sQ(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return 0}function bQ(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return wl(e|0,i|0,r|0)|0}function kQ(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return Ll(e|0,i|0)|0}function hQ(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return Bl(e|0,i|0)|0}function wQ(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return Hl(e|0,i|0)|0}function dQ(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return jl(e|0,i|0)|0}function vQ(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return 0}function mQ(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return 0}function _Q(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return 0}function pQ(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return 0}function EQ(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return 0}function SQ(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return 0}function gQ(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return 0}function yQ(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return Sh(e|0)|0}function FQ(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return gh(e|0)|0}function OQ(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return yh(e|0)|0}function AQ(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return Fh(e|0,i|0,r|0)|0}function MQ(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return Oh(e|0,i|0)|0}function RQ(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return 0}function NQ(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return 0}function TQ(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return 0}function LQ(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return 0}function DQ(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return 0}function CQ(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return 0}function PQ(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return 0}function BQ(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return 0}function IQ(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return 0}function HQ(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return 0}function xQ(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return 0}function UQ(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return 0}function zQ(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return 0}function jQ(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return Uh(e|0,i|0)|0}function VQ(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return 0}function qQ(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return 0}function YQ(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return 0}function GQ(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return 0}function WQ(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return 0}function KQ(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return 0}function XQ(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return 0}function ZQ(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return Zh(e|0,i|0,r|0)|0}function JQ(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return 0}function QQ(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return 0}function $Q(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return 0}function e$(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return 0}function i$(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return 0}function r$(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return 0}function n$(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return 0}function f$(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return 0}function t$(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return 0}function u$(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return 0}function a$(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return 0}function o$(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return 0}function c$(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return 0}function l$(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return _H(e|0,i|0,r|0)|0}function s$(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return 0}function b$(e,i,r,n,f,t,u){e=e|0;
	i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return 0}function k$(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return ex(e|0,i|0)|0}function h$(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return ix(e|0,i|0,r|0,n|0,f|0)|0}function w$(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return nx(e|0,i|0,r|0,n|0,f|0,t|0)|0}function d$(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return 0}function v$(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return ux(e|0,i|0)|0}function m$(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return ax(e|0,i|0,r|0,n|0,f|0)|0}function _$(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return 0}function p$(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return 0}function E$(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return 0}function S$(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return 0}function g$(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return 0}function y$(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return 0}function F$(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return 0}function O$(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return 0}function A$(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return 0}function M$(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return PV(e|0,i|0,r|0,n|0)|0}function R$(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return Rq(e|0,i|0)|0}function N$(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;return Kq(e|0,i|0,r|0)|0}function T$(e,i,r){e=e|0;i=i|0;r=r|0;ue(1);return 0}function L$(e,i,r){e=e|0;i=i|0;r=r|0;return 0}function D$(e,i,r){e=e|0;i=i|0;r=r|0;return Pm(e|0)|0}function C$(e,i,r){e=e|0;i=i|0;r=r|0;return Bm(e|0)|0}function P$(e,i,r){e=e|0;i=i|0;r=r|0;return Im(e|0)|0}function B$(e,i,r){e=e|0;i=i|0;r=r|0;return xm(e|0,i|0)|0}function I$(e,i,r){e=e|0;i=i|0;r=r|0;return 0}function H$(e,i,r){e=e|0;i=i|0;r=r|0;return 0}function x$(e,i,r){e=e|0;i=i|0;r=r|0;return 0}function U$(e,i,r){e=e|0;i=i|0;r=r|0;return 0}function z$(e,i,r){e=e|0;i=i|0;r=r|0;return 0}function j$(e,i,r){e=e|0;i=i|0;r=r|0;return 0}function V$(e,i,r){e=e|0;i=i|0;r=r|0;return 0}function q$(e,i,r){e=e|0;i=i|0;r=r|0;return 0}function Y$(e,i,r){e=e|0;i=i|0;r=r|0;return 0}function G$(e,i,r){e=e|0;i=i|0;r=r|0;return 0}function W$(e,i,r){e=e|0;i=i|0;r=r|0;return 0}function K$(e,i,r){e=e|0;i=i|0;r=r|0;return 0}function X$(e,i,r){e=e|0;i=i|0;r=r|0;return 0}function Z$(e,i,r){e=e|0;i=i|0;r=r|0;return 0}function J$(e,i,r){e=e|0;i=i|0;r=r|0;return 0}function Q$(e,i,r){e=e|0;i=i|0;r=r|0;return 0}function $$(e,i,r){e=e|0;i=i|0;r=r|0;return 0}function e0(e,i,r){e=e|0;i=i|0;r=r|0;return 0}function i0(e,i,r){e=e|0;i=i|0;r=r|0;return r_(e|0,i|0)|0}function r0(e,i,r){e=e|0;i=i|0;r=r|0;return 0}function n0(e,i,r){e=e|0;i=i|0;r=r|0;return 0}function f0(e,i,r){e=e|0;i=i|0;r=r|0;return 0}function t0(e,i,r){e=e|0;i=i|0;r=r|0;return 0}function u0(e,i,r){e=e|0;i=i|0;r=r|0;return 0}function a0(e,i,r){e=e|0;i=i|0;r=r|0;return Xq(e|0)|0}function o0(e,i,r){e=e|0;i=i|0;r=r|0;return Jq(e|0,i|0)|0}function c0(e,i,r){e=e|0;i=i|0;r=r|0;return Yl(e|0)|0}function l0(e,i,r){e=e|0;i=i|0;r=r|0;return 0}function s0(e,i,r){e=e|0;i=i|0;r=r|0;return 0}function b0(e,i,r){e=e|0;i=i|0;r=r|0;return Mz(e|0)|0}function k0(e,i,r){e=e|0;i=i|0;r=r|0;return Rz(e|0)|0}function h0(e,i,r){e=e|0;i=i|0;r=r|0;return Nz(e|0)|0}function w0(e,i,r){e=e|0;i=i|0;r=r|0;return Cz(e|0,i|0)|0}function d0(e,i,r){e=e|0;i=i|0;r=r|0;return 0}function v0(e,i,r){e=e|0;i=i|0;r=r|0;return 0}function m0(e,i,r){e=e|0;i=i|0;r=r|0;return 0}function _0(e,i,r){e=e|0;i=i|0;r=r|0;return 0}function p0(e,i,r){e=e|0;i=i|0;r=r|0;return 0}function E0(e,i,r){e=e|0;i=i|0;r=r|0;return 0}function S0(e,i,r){e=e|0;i=i|0;r=r|0;return 0}function g0(e,i,r){e=e|0;i=i|0;r=r|0;return 0}function y0(e,i,r){e=e|0;i=i|0;r=r|0;return 0}function F0(e,i,r){e=e|0;i=i|0;r=r|0;return 0}function O0(e,i,r){e=e|0;i=i|0;r=r|0;return 0}function A0(e,i,r){e=e|0;i=i|0;r=r|0;return 0}function M0(e,i,r){e=e|0;i=i|0;r=r|0;return 0}function R0(e,i,r){e=e|0;i=i|0;r=r|0;return 0}function N0(e,i,r){e=e|0;i=i|0;r=r|0;return 0}function T0(e,i,r){e=e|0;i=i|0;r=r|0;return 0}function L0(e,i,r){e=e|0;i=i|0;r=r|0;return Pz(e|0,i|0)|0}function D0(e,i,r){e=e|0;i=i|0;r=r|0;return 0}function C0(e,i,r){e=e|0;i=i|0;r=r|0;return 0}function P0(e,i,r){e=e|0;i=i|0;r=r|0;return yz(e|0)|0}function B0(e,i,r){e=e|0;i=i|0;r=r|0;return Fz(e|0)|0}function I0(e,i,r){e=e|0;i=i|0;r=r|0;return Oz(e|0)|0}function H0(e,i,r){e=e|0;i=i|0;r=r|0;return Az(e|0)|0}function x0(e,i,r){e=e|0;i=i|0;r=r|0;return 0}function U0(e,i,r){e=e|0;i=i|0;r=r|0;return OC(e|0)|0}function z0(e,i,r){e=e|0;i=i|0;r=r|0;return AC(e|0)|0}function j0(e,i,r){e=e|0;i=i|0;r=r|0;return MC(e|0)|0}function V0(e,i,r){e=e|0;i=i|0;r=r|0;return RC(e|0)|0}function q0(e,i,r){e=e|0;i=i|0;r=r|0;return NC(e|0)|0}function Y0(e,i,r){e=e|0;i=i|0;r=r|0;return TC(e|0)|0}function G0(e,i,r){e=e|0;i=i|0;r=r|0;return LC(e|0)|0}function W0(e,i,r){e=e|0;i=i|0;r=r|0;return DC(e|0)|0}function K0(e,i,r){e=e|0;i=i|0;r=r|0;return CC(e|0)|0}function X0(e,i,r){e=e|0;i=i|0;r=r|0;return PC(e|0)|0}function Z0(e,i,r){e=e|0;i=i|0;r=r|0;return BC(e|0)|0}function J0(e,i,r){e=e|0;i=i|0;r=r|0;return IC(e|0)|0}function Q0(e,i,r){e=e|0;i=i|0;r=r|0;return HC(e|0)|0}function $0(e,i,r){e=e|0;i=i|0;r=r|0;return xC(e|0)|0}function e1(e,i,r){e=e|0;i=i|0;r=r|0;return UC(e|0)|0}function i1(e,i,r){e=e|0;i=i|0;r=r|0;return zC(e|0)|0}function r1(e,i,r){e=e|0;i=i|0;r=r|0;return jC(e|0)|0}function n1(e,i,r){e=e|0;i=i|0;r=r|0;return VC(e|0)|0}function f1(e,i,r){e=e|0;i=i|0;r=r|0;return qC(e|0)|0}function t1(e,i,r){e=e|0;i=i|0;r=r|0;return YC(e|0)|0}function u1(e,i,r){e=e|0;i=i|0;r=r|0;return GC(e|0)|0}function a1(e,i,r){e=e|0;i=i|0;r=r|0;return WC(e|0)|0}function o1(e,i,r){e=e|0;i=i|0;r=r|0;return KC(e|0)|0}function c1(e,i,r){e=e|0;i=i|0;r=r|0;return XC(e|0)|0}function l1(e,i,r){e=e|0;i=i|0;r=r|0;return ZC(e|0)|0}function s1(e,i,r){e=e|0;i=i|0;r=r|0;return JC(e|0)|0}function b1(e,i,r){e=e|0;i=i|0;r=r|0;return QC(e|0)|0}function k1(e,i,r){e=e|0;i=i|0;r=r|0;return $C(e|0)|0}function h1(e,i,r){e=e|0;i=i|0;r=r|0;return eP(e|0)|0}function w1(e,i,r){e=e|0;i=i|0;r=r|0;return iP(e|0)|0}function d1(e,i,r){e=e|0;i=i|0;r=r|0;return rP(e|0)|0}function v1(e,i,r){e=e|0;i=i|0;r=r|0;return nP(e|0)|0}function m1(e,i,r){e=e|0;i=i|0;r=r|0;return fP(e|0)|0}function _1(e,i,r){e=e|0;i=i|0;r=r|0;return tP(e|0)|0}function p1(e,i,r){e=e|0;i=i|0;r=r|0;return uP(e|0)|0}function E1(e,i,r){e=e|0;i=i|0;r=r|0;return aP(e|0)|0}function S1(e,i,r){e=e|0;i=i|0;r=r|0;return oP(e|0)|0}function g1(e,i,r){e=e|0;i=i|0;r=r|0;return cP(e|0)|0}function y1(e,i,r){e=e|0;i=i|0;r=r|0;return lP(e|0)|0}function F1(e,i,r){e=e|0;i=i|0;r=r|0;return sP(e|0)|0}function O1(e,i,r){e=e|0;i=i|0;r=r|0;return bP(e|0)|0}function A1(e,i,r){e=e|0;i=i|0;r=r|0;return kP(e|0)|0}function M1(e,i,r){e=e|0;i=i|0;r=r|0;return hP(e|0)|0}function R1(e,i,r){e=e|0;i=i|0;r=r|0;return wP(e|0)|0}function N1(e,i,r){e=e|0;i=i|0;r=r|0;return dP(e|0)|0}function T1(e,i,r){e=e|0;i=i|0;r=r|0;return vP(e|0)|0}function L1(e,i,r){e=e|0;i=i|0;r=r|0;return mP(e|0)|0}function D1(e,i,r){e=e|0;i=i|0;r=r|0;return _P(e|0)|0}function C1(e,i,r){e=e|0;i=i|0;r=r|0;return pP(e|0)|0}function P1(e,i,r){e=e|0;i=i|0;r=r|0;return EP(e|0)|0}function B1(e,i,r){e=e|0;i=i|0;r=r|0;return SP(e|0)|0}function I1(e,i,r){e=e|0;i=i|0;r=r|0;return gP(e|0)|0}function H1(e,i,r){e=e|0;i=i|0;r=r|0;return yP(e|0)|0}function x1(e,i,r){e=e|0;i=i|0;r=r|0;return FP(e|0)|0}function U1(e,i,r){e=e|0;i=i|0;r=r|0;return OP(e|0)|0}function z1(e,i,r){e=e|0;i=i|0;r=r|0;return AP(e|0)|0}function j1(e,i,r){e=e|0;i=i|0;r=r|0;return MP(e|0)|0}function V1(e,i,r){e=e|0;i=i|0;r=r|0;return RP(e|0)|0}function q1(e,i,r){e=e|0;i=i|0;r=r|0;return NP(e|0)|0}function Y1(e,i,r){e=e|0;i=i|0;r=r|0;return TP(e|0)|0}function G1(e,i,r){e=e|0;i=i|0;r=r|0;return LP(e|0)|0}function W1(e,i,r){e=e|0;i=i|0;r=r|0;return DP(e|0)|0}function K1(e,i,r){e=e|0;i=i|0;r=r|0;return CP(e|0)|0}function X1(e,i,r){e=e|0;i=i|0;r=r|0;return PP(e|0)|0}function Z1(e,i,r){e=e|0;i=i|0;r=r|0;return BP(e|0)|0}function J1(e,i,r){e=e|0;i=i|0;r=r|0;return IP(e|0)|0}function Q1(e,i,r){e=e|0;i=i|0;r=r|0;return HP(e|0)|0}function $1(e,i,r){e=e|0;i=i|0;r=r|0;return xP(e|0)|0}function e2(e,i,r){e=e|0;i=i|0;r=r|0;return UP(e|0)|0}function i2(e,i,r){e=e|0;i=i|0;r=r|0;return zP(e|0)|0}function r2(e,i,r){e=e|0;i=i|0;r=r|0;return jP(e|0)|0}function n2(e,i,r){e=e|0;i=i|0;r=r|0;return VP(e|0)|0}function f2(e,i,r){e=e|0;i=i|0;r=r|0;return qP(e|0)|0}function t2(e,i,r){e=e|0;i=i|0;r=r|0;return YP(e|0)|0}function u2(e,i,r){e=e|0;i=i|0;r=r|0;return GP(e|0)|0}function a2(e,i,r){e=e|0;i=i|0;r=r|0;return WP(e|0)|0}function o2(e,i,r){e=e|0;i=i|0;r=r|0;return KP(e|0)|0}function c2(e,i,r){e=e|0;i=i|0;r=r|0;return XP(e|0)|0}function l2(e,i,r){e=e|0;i=i|0;r=r|0;return ZP(e|0)|0}function s2(e,i,r){e=e|0;i=i|0;r=r|0;return JP(e|0)|0}function b2(e,i,r){e=e|0;i=i|0;r=r|0;return QP(e|0)|0}function k2(e,i,r){e=e|0;i=i|0;r=r|0;return $P(e|0)|0}function h2(e,i,r){e=e|0;i=i|0;r=r|0;return eB(e|0)|0}function w2(e,i,r){e=e|0;i=i|0;r=r|0;return iB(e|0)|0}function d2(e,i,r){e=e|0;i=i|0;r=r|0;return rB(e|0)|0}function v2(e,i,r){e=e|0;i=i|0;r=r|0;return nB(e|0)|0}function m2(e,i,r){e=e|0;i=i|0;r=r|0;return fB(e|0)|0}function _2(e,i,r){e=e|0;i=i|0;r=r|0;return tB(e|0)|0}function p2(e,i,r){e=e|0;i=i|0;r=r|0;return uB(e|0)|0}function E2(e,i,r){e=e|0;i=i|0;r=r|0;return aB(e|0)|0}function S2(e,i,r){e=e|0;i=i|0;r=r|0;return oB(e|0)|0}function g2(e,i,r){e=e|0;i=i|0;r=r|0;return cB(e|0)|0}function y2(e,i,r){e=e|0;i=i|0;r=r|0;return lB(e|0)|0}function F2(e,i,r){e=e|0;i=i|0;r=r|0;return sB(e|0)|0}function O2(e,i,r){e=e|0;i=i|0;r=r|0;return bB(e|0)|0}function A2(e,i,r){e=e|0;i=i|0;r=r|0;return kB(e|0)|0}function M2(e,i,r){e=e|0;i=i|0;r=r|0;return hB(e|0)|0}function R2(e,i,r){e=e|0;i=i|0;r=r|0;return wB(e|0)|0}function N2(e,i,r){e=e|0;i=i|0;r=r|0;return dB(e|0)|0}function T2(e,i,r){e=e|0;i=i|0;r=r|0;return vB(e|0)|0}function L2(e,i,r){e=e|0;i=i|0;r=r|0;return mB(e|0)|0}function D2(e,i,r){e=e|0;i=i|0;r=r|0;return _B(e|0)|0}function C2(e,i,r){e=e|0;i=i|0;r=r|0;return pB(e|0)|0}function P2(e,i,r){e=e|0;i=i|0;r=r|0;return EB(e|0)|0}function B2(e,i,r){e=e|0;i=i|0;r=r|0;return SB(e|0)|0}function I2(e,i,r){e=e|0;i=i|0;r=r|0;return gB(e|0)|0}function H2(e,i,r){e=e|0;i=i|0;r=r|0;return yB(e|0)|0}function x2(e,i,r){e=e|0;i=i|0;r=r|0;return FB(e|0)|0}function U2(e,i,r){e=e|0;i=i|0;r=r|0;return OB(e|0)|0}function z2(e,i,r){e=e|0;i=i|0;r=r|0;return AB(e|0)|0}function j2(e,i,r){e=e|0;i=i|0;r=r|0;return MB(e|0)|0}function V2(e,i,r){e=e|0;i=i|0;r=r|0;return RB(e|0)|0}function q2(e,i,r){e=e|0;i=i|0;r=r|0;return NB(e|0)|0}function Y2(e,i,r){e=e|0;i=i|0;r=r|0;return TB(e|0)|0}function G2(e,i,r){e=e|0;i=i|0;r=r|0;return LB(e|0)|0}function W2(e,i,r){e=e|0;i=i|0;r=r|0;return DB(e|0)|0}function K2(e,i,r){e=e|0;i=i|0;r=r|0;return CB(e|0)|0}function X2(e,i,r){e=e|0;i=i|0;r=r|0;return PB(e|0)|0}function Z2(e,i,r){e=e|0;i=i|0;r=r|0;return BB(e|0)|0}function J2(e,i,r){e=e|0;i=i|0;r=r|0;return IB(e|0)|0}function Q2(e,i,r){e=e|0;i=i|0;r=r|0;return HB(e|0)|0}function $2(e,i,r){e=e|0;i=i|0;r=r|0;return xB(e|0)|0}function e3(e,i,r){e=e|0;i=i|0;r=r|0;return UB(e|0)|0}function i3(e,i,r){e=e|0;i=i|0;r=r|0;return zB(e|0)|0}function r3(e,i,r){e=e|0;i=i|0;r=r|0;return jB(e|0)|0}function n3(e,i,r){e=e|0;i=i|0;r=r|0;return VB(e|0)|0}function f3(e,i,r){e=e|0;i=i|0;r=r|0;return qB(e|0)|0}function t3(e,i,r){e=e|0;i=i|0;r=r|0;return YB(e|0)|0}function u3(e,i,r){e=e|0;i=i|0;r=r|0;return 0}function a3(e,i,r){e=e|0;i=i|0;r=r|0;return om(e|0)|0}function o3(e,i,r){e=e|0;i=i|0;r=r|0;return cm(e|0,i|0)|0}function c3(e,i,r){e=e|0;i=i|0;r=r|0;return lm(e|0)|0}function l3(e,i,r){e=e|0;i=i|0;r=r|0;return 0}function s3(e,i,r){e=e|0;i=i|0;r=r|0;return 0}function b3(e,i,r){e=e|0;i=i|0;r=r|0;return xe(e|0,i|0,r|0)|0}function k3(e,i,r){e=e|0;i=i|0;r=r|0;return 0}function h3(e,i,r){e=e|0;i=i|0;r=r|0;return 0}function w3(e,i,r){e=e|0;i=i|0;r=r|0;return 0}function d3(e,i,r){e=e|0;i=i|0;r=r|0;return 0}function v3(e,i,r){e=e|0;i=i|0;r=r|0;return 0}function m3(e,i,r){e=e|0;i=i|0;r=r|0;return Am(e|0)|0}function _3(e,i,r){e=e|0;i=i|0;r=r|0;return 0}function p3(e,i,r){e=e|0;i=i|0;r=r|0;return A_(e|0)|0}function E3(e,i,r){e=e|0;i=i|0;r=r|0;return Z_(e|0,i|0,r|0,0)|0}function S3(e,i,r){e=e|0;i=i|0;r=r|0;return J_(e|0,i|0,r|0,0)|0}function g3(e,i,r){e=e|0;i=i|0;r=r|0;return Q_(e|0,i|0,r|0,0)|0}function y3(e,i,r){e=e|0;i=i|0;r=r|0;return $_(e|0,i|0,r|0,0)|0}function F3(e,i,r){e=e|0;i=i|0;r=r|0;return ep(e|0,i|0,r|0,0)|0}function O3(e,i,r){e=e|0;i=i|0;r=r|0;return ip(e|0,i|0,r|0,0)|0}function A3(e,i,r){e=e|0;i=i|0;r=r|0;return N_(e|0,i|0,r|0,0)|0}function M3(e,i,r){e=e|0;i=i|0;r=r|0;return T_(e|0,i|0,r|0,0)|0}function R3(e,i,r){e=e|0;i=i|0;r=r|0;return rp(e|0,i|0,r|0,0)|0}function N3(e,i,r){e=e|0;i=i|0;r=r|0;return np(e|0,i|0,r|0,0)|0}function T3(e,i,r){e=e|0;i=i|0;r=r|0;return dN(e|0,i|0,r|0,0)|0}function L3(e,i,r){e=e|0;i=i|0;r=r|0;return 0}function D3(e,i,r){e=e|0;i=i|0;r=r|0;return 0}function C3(e,i,r){e=e|0;i=i|0;r=r|0;return 0}function P3(e,i,r){e=e|0;i=i|0;r=r|0;return FO()|0}function B3(e,i,r){e=e|0;i=i|0;r=r|0;return 0}function I3(e,i,r){e=e|0;i=i|0;r=r|0;return 0}function H3(e,i,r){e=e|0;i=i|0;r=r|0;return OO(e|0)|0}function x3(e,i,r){e=e|0;i=i|0;r=r|0;return AO(e|0)|0}function U3(e,i,r){e=e|0;i=i|0;r=r|0;return RO(e|0)|0}function z3(e,i,r){e=e|0;i=i|0;r=r|0;return sA(e|0)|0}function j3(e,i,r){e=e|0;i=i|0;r=r|0;return hA(e|0)|0}function V3(e,i,r){e=e|0;i=i|0;r=r|0;return dA(e|0)|0}function q3(e,i,r){e=e|0;i=i|0;r=r|0;return _A(e|0,i|0,r|0,0)|0}function Y3(e,i,r){e=e|0;i=i|0;r=r|0;return 0}function G3(e,i,r){e=e|0;i=i|0;r=r|0;return OR(e|0)|0}function W3(e,i,r){e=e|0;i=i|0;r=r|0;return 0}function K3(e,i,r){e=e|0;i=i|0;r=r|0;return DR(e|0)|0}function X3(e,i,r){e=e|0;i=i|0;r=r|0;return 0}function Z3(e,i,r){e=e|0;i=i|0;r=r|0;return BR(e|0)|0}function J3(e,i,r){e=e|0;i=i|0;r=r|0;return 0}function Q3(e,i,r){e=e|0;i=i|0;r=r|0;return 0}function $3(e,i,r){e=e|0;i=i|0;r=r|0;return 0}function e4(e,i,r){e=e|0;i=i|0;r=r|0;return UR(e|0,i|0)|0}function i4(e,i,r){e=e|0;i=i|0;r=r|0;return 0}function r4(e,i,r){e=e|0;i=i|0;r=r|0;return 0}function n4(e,i,r){e=e|0;i=i|0;r=r|0;return 0}function f4(e,i,r){e=e|0;i=i|0;r=r|0;return 0}function t4(e,i,r){e=e|0;i=i|0;r=r|0;return 0}function u4(e,i,r){e=e|0;i=i|0;r=r|0;return 0}function a4(e,i,r){e=e|0;i=i|0;r=r|0;return lN(e|0,i|0)|0}function o4(e,i,r){e=e|0;i=i|0;r=r|0;return 0}function c4(e,i,r){e=e|0;i=i|0;r=r|0;return 0}function l4(e,i,r){e=e|0;i=i|0;r=r|0;return 0}function s4(e,i,r){e=e|0;i=i|0;r=r|0;return 0}function b4(e,i,r){e=e|0;i=i|0;r=r|0;return 0}function k4(e,i,r){e=e|0;i=i|0;r=r|0;return 0}function h4(e,i,r){e=e|0;i=i|0;r=r|0;return 0}function w4(e,i,r){e=e|0;i=i|0;r=r|0;return 0}function d4(e,i,r){e=e|0;i=i|0;r=r|0;return 0}function v4(e,i,r){e=e|0;i=i|0;r=r|0;return 0}function m4(e,i,r){e=e|0;i=i|0;r=r|0;return 0}function _4(e,i,r){e=e|0;i=i|0;r=r|0;return 0}function p4(e,i,r){e=e|0;i=i|0;r=r|0;return 0}function E4(e,i,r){e=e|0;i=i|0;r=r|0;return 0}function S4(e,i,r){e=e|0;i=i|0;r=r|0;return 0}function g4(e,i,r){e=e|0;i=i|0;r=r|0;return 0}function y4(e,i,r){e=e|0;i=i|0;r=r|0;return 0}function F4(e,i,r){e=e|0;i=i|0;r=r|0;return 0}function O4(e,i,r){e=e|0;i=i|0;r=r|0;return 0}function A4(e,i,r){e=e|0;i=i|0;r=r|0;return 0}function M4(e,i,r){e=e|0;i=i|0;r=r|0;return 0}function R4(e,i,r){e=e|0;i=i|0;r=r|0;return 0}function N4(e,i,r){e=e|0;i=i|0;r=r|0;return 0}function T4(e,i,r){e=e|0;i=i|0;r=r|0;return 0}function L4(e,i,r){e=e|0;i=i|0;r=r|0;return 0}function D4(e,i,r){e=e|0;i=i|0;r=r|0;return 0}function C4(e,i,r){e=e|0;i=i|0;r=r|0;return 0}function P4(e,i,r){e=e|0;i=i|0;r=r|0;return 0}function B4(e,i,r){e=e|0;i=i|0;r=r|0;return 0}function I4(e,i,r){e=e|0;i=i|0;r=r|0;return 0}function H4(e,i,r){e=e|0;i=i|0;r=r|0;return Pf(e|0,i|0)|0}function x4(e,i,r){e=e|0;i=i|0;r=r|0;return Bf(e|0,i|0)|0}function U4(e,i,r){e=e|0;i=i|0;r=r|0;return zf(e|0,i|0)|0}function z4(e,i,r){e=e|0;i=i|0;r=r|0;return ea(e|0,i|0)|0}function j4(e,i,r){e=e|0;i=i|0;r=r|0;return Tf(e|0,i|0)|0}function V4(e,i,r){e=e|0;i=i|0;r=r|0;return Lf(e|0,i|0)|0}function q4(e,i,r){e=e|0;i=i|0;r=r|0;return Df(e|0,i|0)|0}function Y4(e,i,r){e=e|0;i=i|0;r=r|0;return xf(e|0,i|0)|0}function G4(e,i,r){e=e|0;i=i|0;r=r|0;return If(e|0,i|0)|0}function W4(e,i,r){e=e|0;i=i|0;r=r|0;return Uf(e|0,i|0)|0}function K4(e,i,r){e=e|0;i=i|0;r=r|0;return Cf(e|0,i|0)|0}function X4(e,i,r){e=e|0;i=i|0;r=r|0;return ia(e|0,i|0)|0}function Z4(e,i,r){e=e|0;i=i|0;r=r|0;return Hf(e|0,i|0)|0}function J4(e,i,r){e=e|0;i=i|0;r=r|0;return Nf(e|0,i|0)|0}function Q4(e,i,r){e=e|0;i=i|0;r=r|0;return Cn(e|0,i|0)|0}function $4(e,i,r){e=e|0;i=i|0;r=r|0;return 0}function e8(e,i,r){e=e|0;i=i|0;r=r|0;return 0}function i8(e,i,r){e=e|0;i=i|0;r=r|0;return 0}function r8(e,i,r){e=e|0;i=i|0;r=r|0;return 0}function n8(e,i,r){e=e|0;i=i|0;r=r|0;return 0}function f8(e,i,r){e=e|0;i=i|0;r=r|0;return 0}function t8(e,i,r){e=e|0;i=i|0;r=r|0;return 0}function u8(e,i,r){e=e|0;i=i|0;r=r|0;return 0}function a8(e,i,r){e=e|0;i=i|0;r=r|0;return 0}function o8(e,i,r){e=e|0;i=i|0;r=r|0;return 0}function c8(e,i,r){e=e|0;i=i|0;r=r|0;return 0}function l8(e,i,r){e=e|0;i=i|0;r=r|0;return Ll(e|0,i|0)|0}function s8(e,i,r){e=e|0;i=i|0;r=r|0;return Bl(e|0,i|0)|0}function b8(e,i,r){e=e|0;i=i|0;r=r|0;return Hl(e|0,i|0)|0}function k8(e,i,r){e=e|0;i=i|0;r=r|0;return jl(e|0,i|0)|0}function h8(e,i,r){e=e|0;i=i|0;r=r|0;return 0}function w8(e,i,r){e=e|0;i=i|0;r=r|0;return 0}function d8(e,i,r){e=e|0;i=i|0;r=r|0;return 0}function v8(e,i,r){e=e|0;i=i|0;r=r|0;return 0}function m8(e,i,r){e=e|0;i=i|0;r=r|0;return 0}function _8(e,i,r){e=e|0;i=i|0;r=r|0;return 0}function p8(e,i,r){e=e|0;i=i|0;r=r|0;return 0}function E8(e,i,r){e=e|0;i=i|0;r=r|0;return Sh(e|0)|0}function S8(e,i,r){e=e|0;i=i|0;r=r|0;return gh(e|0)|0}function g8(e,i,r){e=e|0;i=i|0;r=r|0;return yh(e|0)|0}function y8(e,i,r){e=e|0;i=i|0;r=r|0;return Oh(e|0,i|0)|0}function F8(e,i,r){e=e|0;i=i|0;r=r|0;return 0}function O8(e,i,r){e=e|0;i=i|0;r=r|0;return 0}function A8(e,i,r){e=e|0;i=i|0;r=r|0;return 0}function M8(e,i,r){e=e|0;i=i|0;r=r|0;return 0}function R8(e,i,r){e=e|0;i=i|0;r=r|0;return 0}function N8(e,i,r){e=e|0;i=i|0;r=r|0;return 0}function T8(e,i,r){e=e|0;i=i|0;r=r|0;return 0}function L8(e,i,r){e=e|0;i=i|0;r=r|0;return 0}function D8(e,i,r){e=e|0;i=i|0;r=r|0;return 0}function C8(e,i,r){e=e|0;i=i|0;r=r|0;return 0}function P8(e,i,r){e=e|0;i=i|0;r=r|0;return 0}function B8(e,i,r){e=e|0;i=i|0;r=r|0;return 0}function I8(e,i,r){e=e|0;i=i|0;r=r|0;return 0}function H8(e,i,r){e=e|0;i=i|0;r=r|0;return Uh(e|0,i|0)|0}function x8(e,i,r){e=e|0;i=i|0;r=r|0;return 0}function U8(e,i,r){e=e|0;i=i|0;r=r|0;return 0}function z8(e,i,r){e=e|0;i=i|0;r=r|0;return 0}function j8(e,i,r){e=e|0;i=i|0;r=r|0;return 0}function V8(e,i,r){e=e|0;i=i|0;r=r|0;return 0}function q8(e,i,r){e=e|0;i=i|0;r=r|0;return 0}function Y8(e,i,r){e=e|0;i=i|0;r=r|0;return 0}function G8(e,i,r){e=e|0;i=i|0;r=r|0;return 0}function W8(e,i,r){e=e|0;i=i|0;r=r|0;return 0}function K8(e,i,r){e=e|0;i=i|0;r=r|0;return 0}function X8(e,i,r){e=e|0;i=i|0;r=r|0;return 0}function Z8(e,i,r){e=e|0;i=i|0;r=r|0;return 0}function J8(e,i,r){e=e|0;i=i|0;r=r|0;return 0}function Q8(e,i,r){e=e|0;i=i|0;r=r|0;return 0}function $8(e,i,r){e=e|0;i=i|0;r=r|0;return 0}function e6(e,i,r){e=e|0;i=i|0;r=r|0;return 0}function i6(e,i,r){e=e|0;i=i|0;r=r|0;return 0}function r6(e,i,r){e=e|0;i=i|0;r=r|0;return 0}function n6(e,i,r){e=e|0;i=i|0;r=r|0;return 0}function f6(e,i,r){e=e|0;i=i|0;r=r|0;return 0}function t6(e,i,r){e=e|0;i=i|0;r=r|0;return 0}function u6(e,i,r){e=e|0;i=i|0;r=r|0;return 0}function a6(e,i,r){e=e|0;i=i|0;r=r|0;return ex(e|0,i|0)|0}function o6(e,i,r){e=e|0;i=i|0;r=r|0;return ix(e|0,i|0,r|0,0,0)|0}function c6(e,i,r){e=e|0;i=i|0;r=r|0;return rx(e|0,i|0,r|0,0,0,0,0)|0}function l6(e,i,r){e=e|0;i=i|0;r=r|0;return nx(e|0,i|0,r|0,0,0,0)|0}function s6(e,i,r){e=e|0;i=i|0;r=r|0;return 0}function b6(e,i,r){e=e|0;i=i|0;r=r|0;return ux(e|0,i|0)|0}function k6(e,i,r){e=e|0;i=i|0;r=r|0;return ax(e|0,i|0,r|0,0,0)|0}function h6(e,i,r){e=e|0;i=i|0;r=r|0;return ox(e|0,i|0,r|0,0,0,0,0)|0}function w6(e,i,r){e=e|0;i=i|0;r=r|0;return 0}function d6(e,i,r){e=e|0;i=i|0;r=r|0;return 0}function v6(e,i,r){e=e|0;i=i|0;r=r|0;return 0}function m6(e,i,r){e=e|0;i=i|0;r=r|0;return 0}function _6(e,i,r){e=e|0;i=i|0;r=r|0;return 0}function p6(e,i,r){e=e|0;i=i|0;r=r|0;return 0}function E6(e,i,r){e=e|0;i=i|0;r=r|0;return 0}function S6(e,i,r){e=e|0;i=i|0;r=r|0;return 0}function g6(e,i,r){e=e|0;i=i|0;r=r|0;return 0}function y6(e,i,r){e=e|0;i=i|0;r=r|0;return PV(e|0,i|0,r|0,0)|0}function F6(e,i,r){e=e|0;i=i|0;r=r|0;return Rq(e|0,i|0)|0}function O6(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;ue(2)}function A6(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;Cm(e|0,i|0,r|0,n|0)}function M6(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;Pm(e|0)|0}function R6(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;Bm(e|0)|0}function N6(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;Im(e|0)|0}function T6(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;Hm(e|0,i|0,r|0)|0}function L6(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;xm(e|0,i|0)|0}function D6(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;Um(e|0,i|0,r|0,n|0,f|0,t|0)}function C6(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;zm(e|0,i|0,r|0,n|0)}function P6(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;Vm(e|0,i|0,r|0,n|0)}function B6(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;qm(e|0,i|0,r|0,n|0,f|0)}function I6(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;Ym(e|0,i|0)}function H6(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;Gm(e|0)}function x6(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;Wm(e|0)}function U6(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;o_(e|0,i|0,r|0)}function z6(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;c_(e|0,i|0)}function j6(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;Km(e|0,i|0)}function V6(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;Xm(e|0,i|0,r|0)}function q6(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;Zm(e|0,i|0,r|0)}function Y6(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;Jm(e|0,i|0,r|0)}function G6(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;Qm(e|0,i|0)}function W6(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;$m(e|0,i|0,r|0)}function K6(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;e_(e|0,i|0,r|0)}function X6(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;i_(e|0,i|0,r|0)}function Z6(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;r_(e|0,i|0)|0}function J6(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;n_(e|0,i|0,r|0)}function Q6(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;f_(e|0,i|0,r|0,n|0)}function $6(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;t_(e|0,i|0,r|0,n|0,f|0,t|0,u|0,0,0)}function e5(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;u_(e|0,i|0,r|0,n|0)}function i5(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;oA(e|0,i|0,r|0)|0}function r5(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;Zq(e|0)}function n5(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;Xq(e|0)|0}function f5(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;Jq(e|0,i|0)|0}function t5(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;Yl(e|0)|0}function u5(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;tp(e|0,i|0,r|0)}function a5(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;Tz(e|0,i|0,r|0,n|0)}function o5(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;Mz(e|0)|0}function c5(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;Rz(e|0)|0}function l5(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;Nz(e|0)|0}function s5(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;Dz(e|0,i|0,r|0)|0}function b5(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;Cz(e|0,i|0)|0}function k5(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;Bz(e|0,i|0,r|0,n|0,f|0,t|0)}function h5(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;xz(e|0,i|0,r|0,n|0)}function w5(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;Hz(e|0,i|0,r|0,n|0)}function d5(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;Uz(e|0,i|0,r|0,n|0,f|0)}function v5(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;zz(e|0,i|0)}function m5(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;jz(e|0)}function _5(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;Vz(e|0)}function p5(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;qz(e|0,i|0,r|0)}function E5(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;Yz(e|0,i|0)}function S5(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;Kz(e|0,i|0)}function g5(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;Xz(e|0,i|0,r|0)}function y5(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;Jz(e|0,i|0,r|0)}function F5(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;Qz(e|0,i|0)}function O5(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;kp(e|0,i|0,r|0)}function A5(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;bp(e|0,i|0,r|0)}function M5(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;Pz(e|0,i|0)|0}function R5(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;$z(e|0,i|0,r|0)}function N5(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;Lz(e|0,i|0,r|0,n|0)}function T5(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;yz(e|0)|0}function L5(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;Fz(e|0)|0}function D5(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;Oz(e|0)|0}function C5(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;Az(e|0)|0}function P5(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;Zz(e|0,i|0,r|0)}function B5(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;OC(e|0)|0}function I5(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;AC(e|0)|0}function H5(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;MC(e|0)|0}function x5(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;RC(e|0)|0}function U5(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;NC(e|0)|0}function z5(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;TC(e|0)|0}function j5(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;LC(e|0)|0}function V5(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;DC(e|0)|0}function q5(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;CC(e|0)|0}function Y5(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;PC(e|0)|0}function G5(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;BC(e|0)|0}function W5(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;IC(e|0)|0}function K5(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;HC(e|0)|0}function X5(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;xC(e|0)|0}function Z5(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;UC(e|0)|0}function J5(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;zC(e|0)|0}function Q5(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;jC(e|0)|0}function $5(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;VC(e|0)|0}function e9(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;qC(e|0)|0}function i9(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;YC(e|0)|0}function r9(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;GC(e|0)|0}function n9(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;WC(e|0)|0}function f9(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;KC(e|0)|0}function t9(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;XC(e|0)|0}function u9(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;ZC(e|0)|0}function a9(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;JC(e|0)|0}function o9(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;QC(e|0)|0}function c9(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;$C(e|0)|0}function l9(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;eP(e|0)|0}function s9(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;iP(e|0)|0}function b9(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;rP(e|0)|0}function k9(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;nP(e|0)|0}function h9(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;fP(e|0)|0}function w9(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;tP(e|0)|0}function d9(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;uP(e|0)|0}function v9(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;aP(e|0)|0}function m9(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;oP(e|0)|0}function _9(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;cP(e|0)|0}function p9(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;lP(e|0)|0}function E9(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;sP(e|0)|0}function S9(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;bP(e|0)|0}function g9(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;kP(e|0)|0}function y9(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;hP(e|0)|0}function F9(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;wP(e|0)|0}function O9(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;dP(e|0)|0}function A9(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;vP(e|0)|0}function M9(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;mP(e|0)|0}function R9(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;_P(e|0)|0}function N9(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;pP(e|0)|0}function T9(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;EP(e|0)|0}function L9(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;SP(e|0)|0}function D9(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;gP(e|0)|0}function C9(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;yP(e|0)|0}function P9(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;FP(e|0)|0}function B9(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;OP(e|0)|0}function I9(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;AP(e|0)|0}function H9(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;MP(e|0)|0}function x9(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;RP(e|0)|0}function U9(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;NP(e|0)|0}function z9(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;TP(e|0)|0}function j9(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;LP(e|0)|0}function V9(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;DP(e|0)|0}function q9(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;CP(e|0)|0}function Y9(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;PP(e|0)|0}function G9(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;BP(e|0)|0}function W9(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;IP(e|0)|0}function K9(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;HP(e|0)|0}function X9(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;xP(e|0)|0}function Z9(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;UP(e|0)|0}function J9(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;zP(e|0)|0}function Q9(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;jP(e|0)|0}function $9(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;VP(e|0)|0}function e7(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;qP(e|0)|0}function i7(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;YP(e|0)|0}function r7(e,i,r,n,f,t,u){
	e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;GP(e|0)|0}function n7(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;WP(e|0)|0}function f7(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;KP(e|0)|0}function t7(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;XP(e|0)|0}function u7(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;ZP(e|0)|0}function a7(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;JP(e|0)|0}function o7(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;QP(e|0)|0}function c7(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;$P(e|0)|0}function l7(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;eB(e|0)|0}function s7(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;iB(e|0)|0}function b7(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;rB(e|0)|0}function k7(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;nB(e|0)|0}function h7(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;fB(e|0)|0}function w7(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;tB(e|0)|0}function d7(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;uB(e|0)|0}function v7(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;aB(e|0)|0}function m7(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;oB(e|0)|0}function _7(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;cB(e|0)|0}function p7(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;lB(e|0)|0}function E7(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;sB(e|0)|0}function S7(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;bB(e|0)|0}function g7(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;kB(e|0)|0}function y7(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;hB(e|0)|0}function F7(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;wB(e|0)|0}function O7(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;dB(e|0)|0}function A7(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;vB(e|0)|0}function M7(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;mB(e|0)|0}function R7(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;_B(e|0)|0}function N7(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;pB(e|0)|0}function T7(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;EB(e|0)|0}function L7(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;SB(e|0)|0}function D7(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;gB(e|0)|0}function C7(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;yB(e|0)|0}function P7(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;FB(e|0)|0}function B7(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;OB(e|0)|0}function I7(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;AB(e|0)|0}function H7(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;MB(e|0)|0}function x7(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;RB(e|0)|0}function U7(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;NB(e|0)|0}function z7(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;TB(e|0)|0}function j7(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;LB(e|0)|0}function V7(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;DB(e|0)|0}function q7(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;CB(e|0)|0}function Y7(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;PB(e|0)|0}function G7(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;BB(e|0)|0}function W7(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;IB(e|0)|0}function K7(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;HB(e|0)|0}function X7(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;xB(e|0)|0}function Z7(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;UB(e|0)|0}function J7(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;zB(e|0)|0}function Q7(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;jB(e|0)|0}function $7(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;VB(e|0)|0}function eee(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;qB(e|0)|0}function iee(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;YB(e|0)|0}function ree(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;NY(e|0,i|0,r|0)|0}function nee(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;am(e|0)}function fee(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;om(e|0)|0}function tee(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;cm(e|0,i|0)|0}function uee(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;lm(e|0)|0}function aee(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;aA(e|0,i|0,r|0)|0}function oee(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;bm(e|0)}function cee(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;km(e|0)}function lee(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;hm(e|0,i|0,r|0)|0}function see(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;xe(e|0,i|0,r|0)|0}function bee(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;pm(e|0,i|0,r|0)|0}function kee(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;Em(e|0)}function hee(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;Sm(e|0,i|0,r|0)}function wee(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;gm(e|0,i|0,r|0)}function dee(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;ym(e|0,i|0,r|0)}function vee(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;Fm(e|0,i|0,r|0)}function mee(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;Am(e|0)|0}function _ee(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;O_(e|0,i|0)}function pee(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;A_(e|0)|0}function Eee(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;Z_(e|0,i|0,r|0,n|0)|0}function See(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;J_(e|0,i|0,r|0,n|0)|0}function gee(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;Q_(e|0,i|0,r|0,n|0)|0}function yee(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;$_(e|0,i|0,r|0,n|0)|0}function Fee(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;ep(e|0,i|0,r|0,n|0)|0}function Oee(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;ip(e|0,i|0,r|0,n|0)|0}function Aee(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;N_(e|0,i|0,r|0,n|0)|0}function Mee(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;T_(e|0,i|0,r|0,n|0)|0}function Ree(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;rp(e|0,i|0,r|0,n|0)|0}function Nee(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;np(e|0,i|0,r|0,n|0)|0}function Tee(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;dN(e|0,i|0,r|0,n|0)|0}function Lee(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;hp(e|0,i|0,r|0)}function Dee(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;wp(e|0,i|0,r|0)}function Cee(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;LS(e|0)}function Pee(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;FO()|0}function Bee(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;Tg(e|0,i|0,r|0,n|0,f|0)}function Iee(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;_O(e|0,i|0,r|0,n|0,f|0)}function Hee(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;OO(e|0)|0}function xee(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;AO(e|0)|0}function Uee(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;MO(e|0,i|0,r|0)|0}function zee(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;RO(e|0)|0}function jee(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;sA(e|0)|0}function Vee(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;bA(e|0,i|0,r|0)|0}function qee(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;hA(e|0)|0}function Yee(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;wA(e|0,i|0,r|0)|0}function Gee(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;dA(e|0)|0}function Wee(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;vA(e|0,i|0,r|0)|0}function Kee(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;mA(e|0,i|0,r|0)|0}function Xee(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;_A(e|0,i|0,r|0,n|0)|0}function Zee(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;FR(e|0)}function Jee(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;OR(e|0)|0}function Qee(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;NR(e|0)}function $ee(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;DR(e|0)|0}function eie(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;PR(e|0)}function iie(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;BR(e|0)|0}function rie(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;IR(e|0,i|0)}function nie(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;HR(e|0)}function fie(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;xR(e|0)}function tie(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;UR(e|0,i|0)|0}function uie(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;zR(e|0)}function aie(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;GR(e|0,i|0,r|0)}function oie(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;iN(e|0,i|0,r|0)}function cie(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;rN(e|0,i|0,r|0)}function lie(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;nN(e|0,i|0,r|0)}function sie(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;fN(e|0,i|0,r|0)}function bie(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;lN(e|0,i|0)|0}function kie(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;Xr(e|0,i|0)}function hie(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;_n(e|0)}function wie(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;tt(e|0,i|0)}function die(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;bt(e|0,i|0)}function vie(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;Yf(e|0,i|0)}function mie(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;Jf(e|0,i|0)}function _ie(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;Qf(e|0,i|0)}function pie(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;Gf(e|0,i|0)}function Eie(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;ot(e|0,i|0)}function Sie(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;st(e|0,i|0)}function gie(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;Vf(e|0,i|0)}function yie(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;ct(e|0,i|0)}function Fie(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;Wf(e|0,i|0)}function Oie(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;ut(e|0,i|0)}function Aie(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;Yt(e|0,i|0)}function Mie(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;Kf(e|0,i|0)}function Rie(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;nt(e|0,i|0)}function Nie(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;gf(e|0,i|0)}function Tie(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;qf(e|0,i|0)}function Lie(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;kt(e|0,i|0)}function Die(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;Xf(e|0,i|0)}function Cie(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;Zf(e|0,i|0)}function Pie(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;$f(e|0,i|0)}function Bie(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;et(e|0,i|0)}function Iie(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;it(e|0,i|0)}function Hie(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;rt(e|0,i|0)}function xie(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;lt(e|0,i|0)}function Uie(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;at(e|0,i|0)}function zie(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;ft(e|0,i|0)}function jie(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;Gt(e|0,i|0)}function Vie(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;Qu(e|0,i|0,r|0)|0}function qie(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;Pf(e|0,i|0)|0}function Yie(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;Bf(e|0,i|0)|0}function Gie(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;zf(e|0,i|0)|0}function Wie(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;$u(e|0,i|0,r|0)|0}function Kie(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;ea(e|0,i|0)|0}function Xie(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;Tf(e|0,i|0)|0}function Zie(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;Lf(e|0,i|0)|0}function Jie(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;Df(e|0,i|0)|0}function Qie(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;xf(e|0,i|0)|0}function $ie(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;If(e|0,i|0)|0}function ere(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;Uf(e|0,i|0)|0}function ire(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;Cf(e|0,i|0)|0}function rre(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;ia(e|0,i|0)|0}function nre(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;Hf(e|0,i|0)|0}function fre(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;Nf(e|0,i|0)|0}function tre(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;Cn(e|0,i|0)|0}function ure(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;za(e|0,i|0)}function are(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;Wa(e|0,i|0)}function ore(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;Ka(e|0,i|0)}function cre(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;Xa(e|0,i|0)}function lre(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;Za(e|0,i|0)}function sre(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;Ja(e|0,i|0)}function bre(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;Qa(e|0,i|0)}function kre(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;$a(e|0,i|0)}function hre(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;Qo(e|0,i|0,r|0)}function wre(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;vc(e|0)}function dre(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;Rc(e|0)}function vre(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;wl(e|0,i|0,r|0)|0}function mre(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;Ll(e|0,i|0)|0}function _re(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;Bl(e|0,i|0)|0}function pre(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;Hl(e|0,i|0)|0}function Ere(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;jl(e|0,i|0)|0}function Sre(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;Xk(e|0)}function gre(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;dh(e|0,i|0,r|0,n|0,f|0,t|0,u|0,0,0)}function yre(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;vh(e|0,i|0,r|0,n|0)}function Fre(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;mh(e|0,i|0,r|0)}function Ore(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;_h(e|0,i|0,r|0)}function Are(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;ph(e|0,i|0)}function Mre(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;Eh(e|0,i|0,r|0,n|0)}function Rre(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;Sh(e|0)|0}function Nre(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;gh(e|0)|0}function Tre(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;yh(e|0)|0}function Lre(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;Fh(e|0,i|0,r|0)|0}function Dre(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;Oh(e|0,i|0)|0}function Cre(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;Ah(e|0,i|0,r|0,n|0,f|0,t|0)}function Pre(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;Mh(e|0,i|0,r|0,n|0)}function Bre(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;Nh(e|0,i|0,r|0,n|0)}function Ire(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;Th(e|0,i|0,r|0,n|0,f|0)}function Hre(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;Lh(e|0,i|0)}function xre(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;Dh(e|0)}function Ure(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;Ch(e|0)}function zre(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;Ph(e|0,i|0,r|0)}function jre(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;Bh(e|0,i|0)}function Vre(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;Ih(e|0,i|0,r|0)}function qre(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;Hh(e|0,i|0,r|0)}function Yre(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;xh(e|0,i|0,r|0)}function Gre(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;Uh(e|0,i|0)|0}function Wre(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;zh(e|0,i|0,r|0,n|0)}function Kre(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;jh(e|0,i|0,r|0)}function Xre(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;Vh(e|0,i|0,r|0)}function Zre(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;qh(e|0,i|0,r|0)}function Jre(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;Yh(e|0,i|0)}function Qre(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;Gh(e|0,i|0,r|0,n|0,f|0,t|0,u|0,0,0)}function $re(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;Wh(e|0,i|0,r|0,n|0)}function ene(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;Zh(e|0,i|0,r|0)|0}function ine(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;$h(e|0)}function rne(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;td(e|0,i|0)}function nne(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;qv(e|0,i|0,r|0,n|0)}function fne(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;aT(e|0,i|0)}function tne(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;Ok(e|0)}function une(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;cH(e|0,i|0,r|0)}function ane(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;lH(e|0,i|0)}function one(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;sH(e|0,i|0,r|0,n|0,f|0,t|0,u|0,0,0)}function cne(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;bH(e|0,i|0,r|0,n|0)}function lne(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;kH(e|0,i|0,r|0)}function sne(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;hH(e|0,i|0,r|0)}function bne(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;dH(e|0,i|0,r|0)}function kne(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;vH(e|0,i|0,r|0)}function hne(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;_H(e|0,i|0,r|0)|0}function wne(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;mH(e|0,i|0)}function dne(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;DH(e|0)}function vne(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;ex(e|0,i|0)|0}function mne(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;ix(e|0,i|0,r|0,n|0,f|0)|0}function _ne(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;rx(e|0,i|0,r|0,n|0,f|0,t|0,u|0)|0}function pne(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;nx(e|0,i|0,r|0,n|0,f|0,t|0)|0}function Ene(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;fx(e|0,i|0)}function Sne(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;ux(e|0,i|0)|0}function gne(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;ax(e|0,i|0,r|0,n|0,f|0)|0}function yne(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;ox(e|0,i|0,r|0,n|0,f|0,t|0,u|0)|0}function Fne(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;cx(e|0,i|0)}function One(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;wx(e|0,i|0,r|0)}function Ane(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;_x(e|0,i|0,r|0,n|0)}function Mne(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;oU(e|0,i|0,r|0)}function Rne(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;cU(e|0,i|0,r|0)}function Nne(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;GU(e|0,i|0,r|0,n|0)}function Tne(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;tz(e|0,i|0,r|0)}function Lne(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;Gz(e|0,i|0,r|0,n|0,f|0,t|0,u|0,0,0)}function Dne(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;Wz(e|0,i|0,r|0,n|0)}function Cne(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;PV(e|0,i|0,r|0,n|0)|0}function Pne(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;Rq(e|0,i|0)|0}function Bne(e,i,r,n,f,t,u){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;Kq(e|0,i|0,r|0)|0}function Ine(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;ue(3)}function Hne(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;Cm(e|0,i|0,r|0,n|0)}function xne(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;Pm(e|0)|0}function Une(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;Bm(e|0)|0}function zne(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;Im(e|0)|0}function jne(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;Hm(e|0,i|0,r|0)|0}function Vne(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;xm(e|0,i|0)|0}function qne(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;Um(e|0,i|0,r|0,n|0,f|0,0)}function Yne(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;zm(e|0,i|0,r|0,n|0)}function Gne(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;jm(e|0,i|0,r|0,n|0,f|0,0,0)}function Wne(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;Vm(e|0,i|0,r|0,n|0)}function Kne(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;Ym(e|0,i|0)}function Xne(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;Gm(e|0)}function Zne(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;Wm(e|0)}function Jne(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;o_(e|0,i|0,r|0)}function Qne(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;c_(e|0,i|0)}function $ne(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;Km(e|0,i|0)}function efe(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;Xm(e|0,i|0,r|0)}function ife(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;Zm(e|0,i|0,r|0)}function rfe(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;Jm(e|0,i|0,r|0)}function nfe(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;Qm(e|0,i|0)}function ffe(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;$m(e|0,i|0,r|0)}function tfe(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;e_(e|0,i|0,r|0)}function ufe(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;i_(e|0,i|0,r|0)}function afe(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;r_(e|0,i|0)|0}function ofe(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;n_(e|0,i|0,r|0)}function cfe(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;f_(e|0,i|0,r|0,n|0)}function lfe(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t_(e|0,i|0,r|0,n|0,f|0,0,0,0,0)}function sfe(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;u_(e|0,i|0,r|0,n|0)}function bfe(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;oA(e|0,i|0,r|0)|0}function kfe(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;Zq(e|0)}function hfe(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;Xq(e|0)|0}function wfe(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;Jq(e|0,i|0)|0}function dfe(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;Yl(e|0)|0}function vfe(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;tp(e|0,i|0,r|0)}function mfe(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;Tz(e|0,i|0,r|0,n|0)}function _fe(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;Mz(e|0)|0}function pfe(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;Rz(e|0)|0}function Efe(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;Nz(e|0)|0}function Sfe(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;Dz(e|0,i|0,r|0)|0}function gfe(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;Cz(e|0,i|0)|0}function yfe(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;Bz(e|0,i|0,r|0,n|0,f|0,0)}function Ffe(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;xz(e|0,i|0,r|0,n|0)}function Ofe(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;Iz(e|0,i|0,r|0,n|0,f|0,0,0)}function Afe(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;Hz(e|0,i|0,r|0,n|0)}function Mfe(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;zz(e|0,i|0)}function Rfe(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;jz(e|0)}function Nfe(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;Vz(e|0)}function Tfe(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;qz(e|0,i|0,r|0)}function Lfe(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;Yz(e|0,i|0)}function Dfe(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;Kz(e|0,i|0)}function Cfe(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;Xz(e|0,i|0,r|0)}function Pfe(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;Jz(e|0,i|0,r|0)}function Bfe(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;Qz(e|0,i|0)}function Ife(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;kp(e|0,i|0,r|0)}function Hfe(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;bp(e|0,i|0,r|0)}function xfe(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;Pz(e|0,i|0)|0}function Ufe(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;$z(e|0,i|0,r|0)}function zfe(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;Lz(e|0,i|0,r|0,n|0)}function jfe(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;yz(e|0)|0}function Vfe(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;Fz(e|0)|0}function qfe(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;Oz(e|0)|0}function Yfe(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;Az(e|0)|0}function Gfe(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;Zz(e|0,i|0,r|0)}function Wfe(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;OC(e|0)|0}function Kfe(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;AC(e|0)|0}function Xfe(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;MC(e|0)|0}function Zfe(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;RC(e|0)|0}function Jfe(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;NC(e|0)|0}function Qfe(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;TC(e|0)|0}function $fe(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;LC(e|0)|0}function ete(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;DC(e|0)|0}function ite(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;CC(e|0)|0}function rte(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;PC(e|0)|0}function nte(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;BC(e|0)|0}function fte(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;IC(e|0)|0}function tte(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;HC(e|0)|0}function ute(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;xC(e|0)|0}function ate(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;UC(e|0)|0}function ote(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;zC(e|0)|0}function cte(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;jC(e|0)|0}function lte(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;VC(e|0)|0}function ste(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;qC(e|0)|0}function bte(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;YC(e|0)|0}function kte(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;GC(e|0)|0}function hte(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;WC(e|0)|0}function wte(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;KC(e|0)|0}function dte(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;XC(e|0)|0}function vte(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;ZC(e|0)|0}function mte(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;JC(e|0)|0}function _te(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;QC(e|0)|0}function pte(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;$C(e|0)|0}function Ete(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;eP(e|0)|0}function Ste(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;iP(e|0)|0}function gte(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;rP(e|0)|0}function yte(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;nP(e|0)|0}function Fte(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;fP(e|0)|0}function Ote(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;tP(e|0)|0}function Ate(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;uP(e|0)|0}function Mte(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;aP(e|0)|0}function Rte(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;oP(e|0)|0}function Nte(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;cP(e|0)|0}function Tte(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;lP(e|0)|0}function Lte(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;sP(e|0)|0}function Dte(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;bP(e|0)|0}function Cte(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;kP(e|0)|0}function Pte(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;hP(e|0)|0}function Bte(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;wP(e|0)|0}function Ite(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;dP(e|0)|0}function Hte(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;vP(e|0)|0}function xte(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;mP(e|0)|0}function Ute(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;_P(e|0)|0}function zte(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;pP(e|0)|0}function jte(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;EP(e|0)|0}function Vte(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;SP(e|0)|0}function qte(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;gP(e|0)|0}function Yte(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;yP(e|0)|0}function Gte(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;FP(e|0)|0}function Wte(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;OP(e|0)|0}function Kte(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;AP(e|0)|0}function Xte(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;MP(e|0)|0}function Zte(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;RP(e|0)|0}function Jte(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;NP(e|0)|0}function Qte(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;TP(e|0)|0}function $te(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;LP(e|0)|0}function eue(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;DP(e|0)|0}function iue(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;CP(e|0)|0}function rue(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;PP(e|0)|0}function nue(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;BP(e|0)|0}function fue(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;IP(e|0)|0}function tue(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;HP(e|0)|0}function uue(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;xP(e|0)|0}function aue(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;UP(e|0)|0}function oue(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;zP(e|0)|0}function cue(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;jP(e|0)|0}function lue(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;VP(e|0)|0}function sue(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;qP(e|0)|0}function bue(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;YP(e|0)|0}function kue(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;GP(e|0)|0}function hue(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;WP(e|0)|0}function wue(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;KP(e|0)|0}function due(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;XP(e|0)|0}function vue(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;ZP(e|0)|0}function mue(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;JP(e|0)|0}function _ue(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;QP(e|0)|0}function pue(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;$P(e|0)|0}function Eue(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;eB(e|0)|0}function Sue(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;iB(e|0)|0}function gue(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;rB(e|0)|0}function yue(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;nB(e|0)|0}function Fue(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;fB(e|0)|0}function Oue(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;tB(e|0)|0}function Aue(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;uB(e|0)|0}function Mue(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;aB(e|0)|0}function Rue(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;oB(e|0)|0}function Nue(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;cB(e|0)|0}function Tue(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;lB(e|0)|0}function Lue(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;sB(e|0)|0}function Due(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;bB(e|0)|0}function Cue(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;kB(e|0)|0}function Pue(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;hB(e|0)|0}function Bue(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;wB(e|0)|0}function Iue(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;dB(e|0)|0}function Hue(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;vB(e|0)|0}function xue(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;mB(e|0)|0}function Uue(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;_B(e|0)|0}function zue(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;
	f=f|0;pB(e|0)|0}function jue(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;EB(e|0)|0}function Vue(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;SB(e|0)|0}function que(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;gB(e|0)|0}function Yue(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;yB(e|0)|0}function Gue(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;FB(e|0)|0}function Wue(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;OB(e|0)|0}function Kue(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;AB(e|0)|0}function Xue(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;MB(e|0)|0}function Zue(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;RB(e|0)|0}function Jue(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;NB(e|0)|0}function Que(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;TB(e|0)|0}function $ue(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;LB(e|0)|0}function eae(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;DB(e|0)|0}function iae(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;CB(e|0)|0}function rae(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;PB(e|0)|0}function nae(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;BB(e|0)|0}function fae(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;IB(e|0)|0}function tae(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;HB(e|0)|0}function uae(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;xB(e|0)|0}function aae(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;UB(e|0)|0}function oae(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;zB(e|0)|0}function cae(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;jB(e|0)|0}function lae(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;VB(e|0)|0}function sae(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;qB(e|0)|0}function bae(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;YB(e|0)|0}function kae(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;NY(e|0,i|0,r|0)|0}function hae(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;am(e|0)}function wae(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;om(e|0)|0}function dae(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;cm(e|0,i|0)|0}function vae(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;lm(e|0)|0}function mae(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;aA(e|0,i|0,r|0)|0}function _ae(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;bm(e|0)}function pae(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;km(e|0)}function Eae(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;hm(e|0,i|0,r|0)|0}function Sae(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;xe(e|0,i|0,r|0)|0}function gae(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;pm(e|0,i|0,r|0)|0}function yae(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;Em(e|0)}function Fae(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;Sm(e|0,i|0,r|0)}function Oae(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;gm(e|0,i|0,r|0)}function Aae(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;ym(e|0,i|0,r|0)}function Mae(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;Fm(e|0,i|0,r|0)}function Rae(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;Am(e|0)|0}function Nae(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;O_(e|0,i|0)}function Tae(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;A_(e|0)|0}function Lae(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;Z_(e|0,i|0,r|0,n|0)|0}function Dae(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;J_(e|0,i|0,r|0,n|0)|0}function Cae(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;Q_(e|0,i|0,r|0,n|0)|0}function Pae(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;$_(e|0,i|0,r|0,n|0)|0}function Bae(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;ep(e|0,i|0,r|0,n|0)|0}function Iae(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;ip(e|0,i|0,r|0,n|0)|0}function Hae(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;N_(e|0,i|0,r|0,n|0)|0}function xae(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;T_(e|0,i|0,r|0,n|0)|0}function Uae(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;rp(e|0,i|0,r|0,n|0)|0}function zae(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;np(e|0,i|0,r|0,n|0)|0}function jae(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;dN(e|0,i|0,r|0,n|0)|0}function Vae(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;hp(e|0,i|0,r|0)}function qae(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;wp(e|0,i|0,r|0)}function Yae(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;LS(e|0)}function Gae(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;FO()|0}function Wae(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;OO(e|0)|0}function Kae(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;AO(e|0)|0}function Xae(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;MO(e|0,i|0,r|0)|0}function Zae(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;RO(e|0)|0}function Jae(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;sA(e|0)|0}function Qae(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;bA(e|0,i|0,r|0)|0}function $ae(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;hA(e|0)|0}function eoe(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;wA(e|0,i|0,r|0)|0}function ioe(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;dA(e|0)|0}function roe(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;vA(e|0,i|0,r|0)|0}function noe(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;mA(e|0,i|0,r|0)|0}function foe(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;_A(e|0,i|0,r|0,n|0)|0}function toe(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;FR(e|0)}function uoe(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;OR(e|0)|0}function aoe(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;NR(e|0)}function ooe(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;DR(e|0)|0}function coe(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;PR(e|0)}function loe(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;BR(e|0)|0}function soe(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;IR(e|0,i|0)}function boe(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;HR(e|0)}function koe(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;xR(e|0)}function hoe(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;UR(e|0,i|0)|0}function woe(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;zR(e|0)}function doe(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;GR(e|0,i|0,r|0)}function voe(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;iN(e|0,i|0,r|0)}function moe(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;rN(e|0,i|0,r|0)}function _oe(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;nN(e|0,i|0,r|0)}function poe(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;fN(e|0,i|0,r|0)}function Eoe(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;lN(e|0,i|0)|0}function Soe(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;Xr(e|0,i|0)}function goe(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;_n(e|0)}function yoe(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;tt(e|0,i|0)}function Foe(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;bt(e|0,i|0)}function Ooe(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;Yf(e|0,i|0)}function Aoe(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;Jf(e|0,i|0)}function Moe(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;Qf(e|0,i|0)}function Roe(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;Gf(e|0,i|0)}function Noe(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;ot(e|0,i|0)}function Toe(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;st(e|0,i|0)}function Loe(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;Vf(e|0,i|0)}function Doe(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;ct(e|0,i|0)}function Coe(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;Wf(e|0,i|0)}function Poe(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;ut(e|0,i|0)}function Boe(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;Yt(e|0,i|0)}function Ioe(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;Kf(e|0,i|0)}function Hoe(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;nt(e|0,i|0)}function xoe(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;gf(e|0,i|0)}function Uoe(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;qf(e|0,i|0)}function zoe(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;kt(e|0,i|0)}function joe(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;Xf(e|0,i|0)}function Voe(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;Zf(e|0,i|0)}function qoe(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;$f(e|0,i|0)}function Yoe(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;et(e|0,i|0)}function Goe(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;it(e|0,i|0)}function Woe(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;rt(e|0,i|0)}function Koe(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;lt(e|0,i|0)}function Xoe(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;at(e|0,i|0)}function Zoe(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;ft(e|0,i|0)}function Joe(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;Gt(e|0,i|0)}function Qoe(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;Qu(e|0,i|0,r|0)|0}function $oe(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;Pf(e|0,i|0)|0}function ece(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;Bf(e|0,i|0)|0}function ice(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;zf(e|0,i|0)|0}function rce(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;$u(e|0,i|0,r|0)|0}function nce(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;ea(e|0,i|0)|0}function fce(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;Tf(e|0,i|0)|0}function tce(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;Lf(e|0,i|0)|0}function uce(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;Df(e|0,i|0)|0}function ace(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;xf(e|0,i|0)|0}function oce(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;If(e|0,i|0)|0}function cce(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;Uf(e|0,i|0)|0}function lce(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;Cf(e|0,i|0)|0}function sce(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;ia(e|0,i|0)|0}function bce(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;Hf(e|0,i|0)|0}function kce(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;Nf(e|0,i|0)|0}function hce(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;Cn(e|0,i|0)|0}function wce(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;za(e|0,i|0)}function dce(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;Wa(e|0,i|0)}function vce(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;Ka(e|0,i|0)}function mce(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;Xa(e|0,i|0)}function _ce(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;Za(e|0,i|0)}function pce(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;Ja(e|0,i|0)}function Ece(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;Qa(e|0,i|0)}function Sce(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;$a(e|0,i|0)}function gce(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;Qo(e|0,i|0,r|0)}function yce(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;vc(e|0)}function Fce(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;Rc(e|0)}function Oce(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;wl(e|0,i|0,r|0)|0}function Ace(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;Ll(e|0,i|0)|0}function Mce(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;Bl(e|0,i|0)|0}function Rce(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;Hl(e|0,i|0)|0}function Nce(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;jl(e|0,i|0)|0}function Tce(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;Xk(e|0)}function Lce(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;dh(e|0,i|0,r|0,n|0,f|0,0,0,0,0)}function Dce(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;vh(e|0,i|0,r|0,n|0)}function Cce(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;mh(e|0,i|0,r|0)}function Pce(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;_h(e|0,i|0,r|0)}function Bce(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;ph(e|0,i|0)}function Ice(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;Eh(e|0,i|0,r|0,n|0)}function Hce(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;Sh(e|0)|0}function xce(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;gh(e|0)|0}function Uce(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;yh(e|0)|0}function zce(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;Fh(e|0,i|0,r|0)|0}function jce(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;Oh(e|0,i|0)|0}function Vce(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;Ah(e|0,i|0,r|0,n|0,f|0,0)}function qce(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;Mh(e|0,i|0,r|0,n|0)}function Yce(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;Rh(e|0,i|0,r|0,n|0,f|0,0,0)}function Gce(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;Nh(e|0,i|0,r|0,n|0)}function Wce(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;Lh(e|0,i|0)}function Kce(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;Dh(e|0)}function Xce(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;Ch(e|0)}function Zce(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;Ph(e|0,i|0,r|0)}function Jce(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;Bh(e|0,i|0)}function Qce(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;Ih(e|0,i|0,r|0)}function $ce(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;Hh(e|0,i|0,r|0)}function ele(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;xh(e|0,i|0,r|0)}function ile(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;Uh(e|0,i|0)|0}function rle(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;zh(e|0,i|0,r|0,n|0)}function nle(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;jh(e|0,i|0,r|0)}function fle(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;Vh(e|0,i|0,r|0)}function tle(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;qh(e|0,i|0,r|0)}function ule(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;Yh(e|0,i|0)}function ale(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;Gh(e|0,i|0,r|0,n|0,f|0,0,0,0,0)}function ole(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;Wh(e|0,i|0,r|0,n|0)}function cle(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;Zh(e|0,i|0,r|0)|0}function lle(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;$h(e|0)}function sle(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;td(e|0,i|0)}function ble(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;qv(e|0,i|0,r|0,n|0)}function kle(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;aT(e|0,i|0)}function hle(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;Ok(e|0)}function wle(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;cH(e|0,i|0,r|0)}function dle(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;lH(e|0,i|0)}function vle(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;sH(e|0,i|0,r|0,n|0,f|0,0,0,0,0)}function mle(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;bH(e|0,i|0,r|0,n|0)}function _le(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;kH(e|0,i|0,r|0)}function ple(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;hH(e|0,i|0,r|0)}function Ele(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;dH(e|0,i|0,r|0)}function Sle(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;vH(e|0,i|0,r|0)}function gle(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;_H(e|0,i|0,r|0)|0}function yle(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;mH(e|0,i|0)}function Fle(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;DH(e|0)}function Ole(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;ex(e|0,i|0)|0}function Ale(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;ix(e|0,i|0,r|0,n|0,f|0)|0}function Mle(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;rx(e|0,i|0,r|0,n|0,f|0,0,0)|0}function Rle(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;nx(e|0,i|0,r|0,n|0,f|0,0)|0}function Nle(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;fx(e|0,i|0)}function Tle(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;ux(e|0,i|0)|0}function Lle(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;ax(e|0,i|0,r|0,n|0,f|0)|0}function Dle(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;ox(e|0,i|0,r|0,n|0,f|0,0,0)|0}function Cle(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;cx(e|0,i|0)}function Ple(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;wx(e|0,i|0,r|0)}function Ble(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;_x(e|0,i|0,r|0,n|0)}function Ile(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;oU(e|0,i|0,r|0)}function Hle(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;cU(e|0,i|0,r|0)}function xle(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;GU(e|0,i|0,r|0,n|0)}function Ule(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;tz(e|0,i|0,r|0)}function zle(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;Gz(e|0,i|0,r|0,n|0,f|0,0,0,0,0)}function jle(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;Wz(e|0,i|0,r|0,n|0)}function Vle(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;PV(e|0,i|0,r|0,n|0)|0}function qle(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;Rq(e|0,i|0)|0}function Yle(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;Kq(e|0,i|0,r|0)|0}function Gle(){ue(4);return 0}function Wle(){return 0}function Kle(){return Pm(0)|0}function Xle(){return Bm(0)|0}function Zle(){return Im(0)|0}function Jle(){return Hm(0,0,0)|0}function Qle(){return xm(0,0)|0}function $le(){return 0}function ese(){return 0}function ise(){return 0}function rse(){return 0}function nse(){return 0}function fse(){return 0}function tse(){return 0}function use(){return 0}function ase(){return 0}function ose(){return 0}function cse(){return 0}function lse(){return 0}function sse(){return 0}function bse(){return 0}function kse(){return 0}function hse(){return 0}function wse(){return 0}function dse(){return 0}function vse(){return r_(0,0)|0}function mse(){return 0}function _se(){return 0}function pse(){return 0}function Ese(){return 0}function Sse(){return oA(0,0,0)|0}function gse(){return 0}function yse(){return Xq(0)|0}function Fse(){return Jq(0,0)|0}function Ose(){return Yl(0)|0}function Ase(){return 0}function Mse(){return 0}function Rse(){return Mz(0)|0}function Nse(){return Rz(0)|0}function Tse(){return Nz(0)|0}function Lse(){return Dz(0,0,0)|0}function Dse(){return Cz(0,0)|0}function Cse(){return 0}function Pse(){return 0}function Bse(){return 0}function Ise(){return 0}function Hse(){return 0}function xse(){return 0}function Use(){return 0}function zse(){return 0}function jse(){return 0}function Vse(){return 0}function qse(){return 0}function Yse(){return 0}function Gse(){return 0}function Wse(){return 0}function Kse(){return 0}function Xse(){return 0}function Zse(){return Pz(0,0)|0}function Jse(){return 0}function Qse(){return 0}function $se(){return yz(0)|0}function ebe(){return Fz(0)|0}function ibe(){return Oz(0)|0}function rbe(){return Az(0)|0}function nbe(){return 0}function fbe(){return OC(0)|0}function tbe(){return AC(0)|0}function ube(){return MC(0)|0}function abe(){return RC(0)|0}function obe(){return NC(0)|0}function cbe(){return TC(0)|0}function lbe(){return LC(0)|0}function sbe(){return DC(0)|0}function bbe(){return CC(0)|0}function kbe(){return PC(0)|0}function hbe(){return BC(0)|0}function wbe(){return IC(0)|0}function dbe(){return HC(0)|0}function vbe(){return xC(0)|0}function mbe(){return UC(0)|0}function _be(){return zC(0)|0}function pbe(){return jC(0)|0}function Ebe(){return VC(0)|0}function Sbe(){return qC(0)|0}function gbe(){return YC(0)|0}function ybe(){return GC(0)|0}function Fbe(){return WC(0)|0}function Obe(){return KC(0)|0}function Abe(){return XC(0)|0}function Mbe(){return ZC(0)|0}function Rbe(){return JC(0)|0}function Nbe(){return QC(0)|0}function Tbe(){return $C(0)|0}function Lbe(){return eP(0)|0}function Dbe(){return iP(0)|0}function Cbe(){return rP(0)|0}function Pbe(){return nP(0)|0}function Bbe(){return fP(0)|0}function Ibe(){return tP(0)|0}function Hbe(){return uP(0)|0}function xbe(){return aP(0)|0}function Ube(){return oP(0)|0}function zbe(){return cP(0)|0}function jbe(){return lP(0)|0}function Vbe(){return sP(0)|0}function qbe(){return bP(0)|0}function Ybe(){return kP(0)|0}function Gbe(){return hP(0)|0}function Wbe(){return wP(0)|0}function Kbe(){return dP(0)|0}function Xbe(){return vP(0)|0}function Zbe(){return mP(0)|0}function Jbe(){return _P(0)|0}function Qbe(){return pP(0)|0}function $be(){return EP(0)|0}function eke(){return SP(0)|0}function ike(){return gP(0)|0}function rke(){return yP(0)|0}function nke(){return FP(0)|0}function fke(){return OP(0)|0}function tke(){return AP(0)|0}function uke(){return MP(0)|0}function ake(){return RP(0)|0}function oke(){return NP(0)|0}function cke(){return TP(0)|0}function lke(){return LP(0)|0}function ske(){return DP(0)|0}function bke(){return CP(0)|0}function kke(){return PP(0)|0}function hke(){return BP(0)|0}function wke(){return IP(0)|0}function dke(){return HP(0)|0}function vke(){return xP(0)|0}function mke(){return UP(0)|0}function _ke(){return zP(0)|0}function pke(){return jP(0)|0}function Eke(){return VP(0)|0}function Ske(){return qP(0)|0}function gke(){return YP(0)|0}function yke(){return GP(0)|0}function Fke(){return WP(0)|0}function Oke(){return KP(0)|0}function Ake(){return XP(0)|0}function Mke(){return ZP(0)|0}function Rke(){return JP(0)|0}function Nke(){return QP(0)|0}function Tke(){return $P(0)|0}function Lke(){return eB(0)|0}function Dke(){return iB(0)|0}function Cke(){return rB(0)|0}function Pke(){return nB(0)|0}function Bke(){return fB(0)|0}function Ike(){return tB(0)|0}function Hke(){return uB(0)|0}function xke(){return aB(0)|0}function Uke(){return oB(0)|0}function zke(){return cB(0)|0}function jke(){return lB(0)|0}function Vke(){return sB(0)|0}function qke(){return bB(0)|0}function Yke(){return kB(0)|0}function Gke(){return hB(0)|0}function Wke(){return wB(0)|0}function Kke(){return dB(0)|0}function Xke(){return vB(0)|0}function Zke(){return mB(0)|0}function Jke(){return _B(0)|0}function Qke(){return pB(0)|0}function $ke(){return EB(0)|0}function ehe(){return SB(0)|0}function ihe(){return gB(0)|0}function rhe(){return yB(0)|0}function nhe(){return FB(0)|0}function fhe(){return OB(0)|0}function the(){return AB(0)|0}function uhe(){return MB(0)|0}function ahe(){return RB(0)|0}function ohe(){return NB(0)|0}function che(){return TB(0)|0}function lhe(){return LB(0)|0}function she(){return DB(0)|0}function bhe(){return CB(0)|0}function khe(){return PB(0)|0}function hhe(){return BB(0)|0}function whe(){return IB(0)|0}function dhe(){return HB(0)|0}function vhe(){return xB(0)|0}function mhe(){return UB(0)|0}function _he(){return zB(0)|0}function phe(){return jB(0)|0}function Ehe(){return VB(0)|0}function She(){return qB(0)|0}function ghe(){return YB(0)|0}function yhe(){return NY(0,0,0)|0}function Fhe(){return 0}function Ohe(){return om(0)|0}function Ahe(){return cm(0,0)|0}function Mhe(){return lm(0)|0}function Rhe(){return aA(0,0,0)|0}function Nhe(){return 0}function The(){return 0}function Lhe(){return hm(0,0,0)|0}function Dhe(){return xe(0,0,0)|0}function Che(){return pm(0,0,0)|0}function Phe(){return 0}function Bhe(){return 0}function Ihe(){return 0}function Hhe(){return 0}function xhe(){return 0}function Uhe(){return Am(0)|0}function zhe(){return 0}function jhe(){return A_(0)|0}function Vhe(){return Z_(0,0,0,0)|0}function qhe(){return J_(0,0,0,0)|0}function Yhe(){return Q_(0,0,0,0)|0}function Ghe(){return $_(0,0,0,0)|0}function Whe(){return ep(0,0,0,0)|0}function Khe(){return ip(0,0,0,0)|0}function Xhe(){return N_(0,0,0,0)|0}function Zhe(){return T_(0,0,0,0)|0}function Jhe(){return rp(0,0,0,0)|0}function Qhe(){return np(0,0,0,0)|0}function $he(){return dN(0,0,0,0)|0}function ewe(){return 0}function iwe(){return 0}function rwe(){return 0}function nwe(){return 0}function fwe(){return 0}function twe(){return OO(0)|0}function uwe(){return AO(0)|0}function awe(){return MO(0,0,0)|0}function owe(){return RO(0)|0}function cwe(){return sA(0)|0}function lwe(){return bA(0,0,0)|0}function swe(){return hA(0)|0}function bwe(){return wA(0,0,0)|0}function kwe(){return dA(0)|0}function hwe(){return vA(0,0,0)|0}function wwe(){return mA(0,0,0)|0}function dwe(){return _A(0,0,0,0)|0}function vwe(){return 0}function mwe(){return OR(0)|0}function _we(){return 0}function pwe(){return DR(0)|0}function Ewe(){return 0}function Swe(){return BR(0)|0}function gwe(){return 0}function ywe(){return 0}function Fwe(){return 0}function Owe(){return UR(0,0)|0}function Awe(){return 0}function Mwe(){return 0}function Rwe(){return 0}function Nwe(){return 0}function Twe(){return 0}function Lwe(){return 0}function Dwe(){return lN(0,0)|0}function Cwe(){return 0}function Pwe(){return 0}function Bwe(){return 0}function Iwe(){return 0}function Hwe(){return 0}function xwe(){return 0}function Uwe(){return 0}function zwe(){return 0}function jwe(){return 0}function Vwe(){return 0}function qwe(){return 0}function Ywe(){return 0}function Gwe(){return 0}function Wwe(){return 0}function Kwe(){return 0}function Xwe(){return 0}function Zwe(){return 0}function Jwe(){return 0}function Qwe(){return 0}function $we(){return 0}function ede(){return 0}function ide(){return 0}function rde(){return 0}function nde(){return 0}function fde(){return 0}function tde(){return 0}function ude(){return 0}function ade(){return 0}function ode(){return 0}function cde(){return 0}function lde(){return Qu(0,0,0)|0}function sde(){return Pf(0,0)|0}function bde(){return Bf(0,0)|0}function kde(){return zf(0,0)|0}function hde(){return $u(0,0,0)|0}function wde(){return ea(0,0)|0}function dde(){return Tf(0,0)|0}function vde(){return Lf(0,0)|0}function mde(){return Df(0,0)|0}function _de(){return xf(0,0)|0}function pde(){return If(0,0)|0}function Ede(){return Uf(0,0)|0}function Sde(){return Cf(0,0)|0}function gde(){return ia(0,0)|0}function yde(){return Hf(0,0)|0}function Fde(){return Nf(0,0)|0}function Ode(){return Cn(0,0)|0}function Ade(){return 0}function Mde(){return 0}function Rde(){return 0}function Nde(){return 0}function Tde(){return 0}function Lde(){return 0}function Dde(){return 0}function Cde(){return 0}function Pde(){return 0}function Bde(){return 0}function Ide(){return 0}function Hde(){return wl(0,0,0)|0}function xde(){return Ll(0,0)|0}function Ude(){return Bl(0,0)|0}function zde(){return Hl(0,0)|0}function jde(){return jl(0,0)|0}function Vde(){return 0}function qde(){return 0}function Yde(){return 0}function Gde(){return 0}function Wde(){return 0}function Kde(){return 0}function Xde(){return 0}function Zde(){return Sh(0)|0}function Jde(){return gh(0)|0}function Qde(){return yh(0)|0}function $de(){return Fh(0,0,0)|0}function eve(){return Oh(0,0)|0}function ive(){return 0}function rve(){return 0}function nve(){return 0}function fve(){return 0}function tve(){return 0}function uve(){return 0}function ave(){return 0}function ove(){return 0}function cve(){return 0}function lve(){return 0}function sve(){return 0}function bve(){return 0}function kve(){return 0}function hve(){return Uh(0,0)|0}function wve(){return 0}function dve(){return 0}function vve(){return 0}function mve(){return 0}function _ve(){return 0}function pve(){return 0}function Eve(){return 0}function Sve(){return Zh(0,0,0)|0}function gve(){return 0}function yve(){return 0}function Fve(){return 0}function Ove(){return 0}function Ave(){return 0}function Mve(){return 0}function Rve(){return 0}function Nve(){return 0}function Tve(){return 0}function Lve(){return 0}function Dve(){return 0}function Cve(){return 0}function Pve(){return 0}function Bve(){return _H(0,0,0)|0}function Ive(){return 0}function Hve(){return 0}function xve(){return ex(0,0)|0}function Uve(){return ix(0,0,0,0,0)|0}function zve(){return rx(0,0,0,0,0,0,0)|0}function jve(){return nx(0,0,0,0,0,0)|0}function Vve(){return 0}function qve(){return ux(0,0)|0}function Yve(){return ax(0,0,0,0,0)|0}function Gve(){return ox(0,0,0,0,0,0,0)|0}function Wve(){return 0}function Kve(){return 0}function Xve(){return 0}function Zve(){return 0}function Jve(){return 0}function Qve(){return 0}function $ve(){return 0}function eme(){return 0}function ime(){return 0}function rme(){return PV(0,0,0,0)|0}function nme(){return Rq(0,0)|0}function fme(){return Kq(0,0,0)|0}function tme(e){e=e|0;ue(5)}function ume(e){e=e|0;Cm(e|0,0,0,0)}function ame(e){e=e|0;Pm(e|0)|0}function ome(e){e=e|0;Bm(e|0)|0}function cme(e){e=e|0;Im(e|0)|0}function lme(e){e=e|0;Hm(e|0,0,0)|0}function sme(e){e=e|0;xm(e|0,0)|0}function bme(e){e=e|0;Um(e|0,0,0,0,0,0)}function kme(e){e=e|0;zm(e|0,0,0,0)}function hme(e){e=e|0;jm(e|0,0,0,0,0,0,0)}function wme(e){e=e|0;Vm(e|0,0,0,0)}function dme(e){e=e|0;qm(e|0,0,0,0,0)}function vme(e){e=e|0;Ym(e|0,0)}function mme(e){e=e|0;o_(e|0,0,0)}function _me(e){e=e|0;c_(e|0,0)}function pme(e){e=e|0;Km(e|0,0)}function Eme(e){e=e|0;Xm(e|0,0,0)}function Sme(e){e=e|0;Zm(e|0,0,0)}function gme(e){e=e|0;Jm(e|0,0,0)}function yme(e){e=e|0;Qm(e|0,0)}function Fme(e){e=e|0;$m(e|0,0,0)}function Ome(e){e=e|0;e_(e|0,0,0)}function Ame(e){e=e|0;i_(e|0,0,0)}function Mme(e){e=e|0;r_(e|0,0)|0}function Rme(e){e=e|0;n_(e|0,0,0)}function Nme(e){e=e|0;f_(e|0,0,0,0)}function Tme(e){e=e|0;t_(e|0,0,0,0,0,0,0,0,0)}function Lme(e){e=e|0;u_(e|0,0,0,0)}function Dme(e){e=e|0;oA(e|0,0,0)|0}function Cme(e){e=e|0;Xq(e|0)|0}function Pme(e){e=e|0;Jq(e|0,0)|0}function Bme(e){e=e|0;Yl(e|0)|0}function Ime(e){e=e|0;tp(e|0,0,0)}function Hme(e){e=e|0;Tz(e|0,0,0,0)}function xme(e){e=e|0;Mz(e|0)|0}function Ume(e){e=e|0;Rz(e|0)|0}function zme(e){e=e|0;Nz(e|0)|0}function jme(e){e=e|0;Dz(e|0,0,0)|0}function Vme(e){e=e|0;Cz(e|0,0)|0}function qme(e){e=e|0;Bz(e|0,0,0,0,0,0)}function Yme(e){e=e|0;xz(e|0,0,0,0)}function Gme(e){e=e|0;Iz(e|0,0,0,0,0,0,0)}function Wme(e){e=e|0;Hz(e|0,0,0,0)}function Kme(e){e=e|0;Uz(e|0,0,0,0,0)}function Xme(e){e=e|0;zz(e|0,0)}function Zme(e){e=e|0;qz(e|0,0,0)}function Jme(e){e=e|0;Yz(e|0,0)}function Qme(e){e=e|0;Kz(e|0,0)}function $me(e){e=e|0;Xz(e|0,0,0)}function e_e(e){e=e|0;Jz(e|0,0,0)}function i_e(e){e=e|0;Qz(e|0,0)}function r_e(e){e=e|0;kp(e|0,0,0)}function n_e(e){e=e|0;bp(e|0,0,0)}function f_e(e){e=e|0;Pz(e|0,0)|0}function t_e(e){e=e|0;$z(e|0,0,0)}function u_e(e){e=e|0;Lz(e|0,0,0,0)}function a_e(e){e=e|0;yz(e|0)|0}function o_e(e){e=e|0;Fz(e|0)|0}function c_e(e){e=e|0;Oz(e|0)|0}function l_e(e){e=e|0;Az(e|0)|0}function s_e(e){e=e|0;Zz(e|0,0,0)}function b_e(e){e=e|0;OC(e|0)|0}function k_e(e){e=e|0;AC(e|0)|0}function h_e(e){e=e|0;MC(e|0)|0}function w_e(e){e=e|0;RC(e|0)|0}function d_e(e){e=e|0;NC(e|0)|0}function v_e(e){e=e|0;TC(e|0)|0}function m_e(e){e=e|0;LC(e|0)|0}function __e(e){e=e|0;DC(e|0)|0}function p_e(e){e=e|0;CC(e|0)|0}function E_e(e){e=e|0;PC(e|0)|0}function S_e(e){e=e|0;BC(e|0)|0}function g_e(e){e=e|0;IC(e|0)|0}function y_e(e){e=e|0;HC(e|0)|0}function F_e(e){e=e|0;xC(e|0)|0}function O_e(e){e=e|0;UC(e|0)|0}function A_e(e){e=e|0;zC(e|0)|0}function M_e(e){e=e|0;jC(e|0)|0}function R_e(e){e=e|0;VC(e|0)|0}function N_e(e){e=e|0;qC(e|0)|0}function T_e(e){e=e|0;YC(e|0)|0}function L_e(e){e=e|0;GC(e|0)|0}function D_e(e){e=e|0;WC(e|0)|0}function C_e(e){e=e|0;KC(e|0)|0}function P_e(e){e=e|0;XC(e|0)|0}function B_e(e){e=e|0;ZC(e|0)|0}function I_e(e){e=e|0;JC(e|0)|0}function H_e(e){e=e|0;QC(e|0)|0}function x_e(e){e=e|0;$C(e|0)|0}function U_e(e){e=e|0;eP(e|0)|0}function z_e(e){e=e|0;iP(e|0)|0}function j_e(e){e=e|0;rP(e|0)|0}function V_e(e){e=e|0;nP(e|0)|0}function q_e(e){e=e|0;fP(e|0)|0}function Y_e(e){e=e|0;tP(e|0)|0}function G_e(e){e=e|0;uP(e|0)|0}function W_e(e){e=e|0;aP(e|0)|0}function K_e(e){e=e|0;oP(e|0)|0}function X_e(e){e=e|0;cP(e|0)|0}function Z_e(e){e=e|0;lP(e|0)|0}function J_e(e){e=e|0;sP(e|0)|0}function Q_e(e){e=e|0;bP(e|0)|0}function $_e(e){e=e|0;kP(e|0)|0}function epe(e){e=e|0;hP(e|0)|0}function ipe(e){e=e|0;wP(e|0)|0}function rpe(e){e=e|0;dP(e|0)|0}function npe(e){e=e|0;vP(e|0)|0}function fpe(e){e=e|0;mP(e|0)|0}function tpe(e){e=e|0;_P(e|0)|0}function upe(e){e=e|0;pP(e|0)|0}function ape(e){e=e|0;EP(e|0)|0}function ope(e){e=e|0;SP(e|0)|0}function cpe(e){e=e|0;gP(e|0)|0}function lpe(e){e=e|0;yP(e|0)|0}function spe(e){e=e|0;FP(e|0)|0}function bpe(e){e=e|0;OP(e|0)|0}function kpe(e){e=e|0;AP(e|0)|0}function hpe(e){e=e|0;MP(e|0)|0}function wpe(e){e=e|0;RP(e|0)|0}function dpe(e){e=e|0;NP(e|0)|0}function vpe(e){e=e|0;TP(e|0)|0}function mpe(e){e=e|0;LP(e|0)|0}function _pe(e){e=e|0;DP(e|0)|0}function ppe(e){e=e|0;CP(e|0)|0}function Epe(e){e=e|0;PP(e|0)|0}function Spe(e){e=e|0;BP(e|0)|0}function gpe(e){e=e|0;IP(e|0)|0}function ype(e){e=e|0;HP(e|0)|0}function Fpe(e){e=e|0;xP(e|0)|0}function Ope(e){e=e|0;UP(e|0)|0}function Ape(e){e=e|0;zP(e|0)|0}function Mpe(e){e=e|0;jP(e|0)|0}function Rpe(e){e=e|0;VP(e|0)|0}function Npe(e){e=e|0;qP(e|0)|0}function Tpe(e){e=e|0;YP(e|0)|0}function Lpe(e){e=e|0;GP(e|0)|0}function Dpe(e){e=e|0;WP(e|0)|0}function Cpe(e){e=e|0;KP(e|0)|0}function Ppe(e){e=e|0;XP(e|0)|0}function Bpe(e){e=e|0;ZP(e|0)|0}function Ipe(e){e=e|0;JP(e|0)|0}function Hpe(e){e=e|0;QP(e|0)|0}function xpe(e){e=e|0;$P(e|0)|0}function Upe(e){e=e|0;eB(e|0)|0}function zpe(e){e=e|0;iB(e|0)|0}function jpe(e){e=e|0;rB(e|0)|0}function Vpe(e){e=e|0;nB(e|0)|0}function qpe(e){e=e|0;fB(e|0)|0}function Ype(e){e=e|0;tB(e|0)|0}function Gpe(e){e=e|0;uB(e|0)|0}function Wpe(e){e=e|0;aB(e|0)|0}function Kpe(e){e=e|0;oB(e|0)|0}function Xpe(e){e=e|0;cB(e|0)|0}function Zpe(e){e=e|0;lB(e|0)|0}function Jpe(e){e=e|0;sB(e|0)|0}function Qpe(e){e=e|0;bB(e|0)|0}function $pe(e){e=e|0;kB(e|0)|0}function eEe(e){e=e|0;hB(e|0)|0}function iEe(e){e=e|0;wB(e|0)|0}function rEe(e){e=e|0;dB(e|0)|0}function nEe(e){e=e|0;vB(e|0)|0}function fEe(e){e=e|0;mB(e|0)|0}function tEe(e){e=e|0;_B(e|0)|0}function uEe(e){e=e|0;pB(e|0)|0}function aEe(e){e=e|0;EB(e|0)|0}function oEe(e){e=e|0;SB(e|0)|0}function cEe(e){e=e|0;gB(e|0)|0}function lEe(e){e=e|0;yB(e|0)|0}function sEe(e){e=e|0;FB(e|0)|0}function bEe(e){e=e|0;OB(e|0)|0}function kEe(e){e=e|0;AB(e|0)|0}function hEe(e){e=e|0;MB(e|0)|0}function wEe(e){e=e|0;RB(e|0)|0}function dEe(e){e=e|0;NB(e|0)|0}function vEe(e){e=e|0;TB(e|0)|0}function mEe(e){e=e|0;LB(e|0)|0}function _Ee(e){e=e|0;DB(e|0)|0}function pEe(e){e=e|0;CB(e|0)|0}function EEe(e){e=e|0;PB(e|0)|0}function SEe(e){e=e|0;BB(e|0)|0}function gEe(e){e=e|0;IB(e|0)|0;
	}function yEe(e){e=e|0;HB(e|0)|0}function FEe(e){e=e|0;xB(e|0)|0}function OEe(e){e=e|0;UB(e|0)|0}function AEe(e){e=e|0;zB(e|0)|0}function MEe(e){e=e|0;jB(e|0)|0}function REe(e){e=e|0;VB(e|0)|0}function NEe(e){e=e|0;qB(e|0)|0}function TEe(e){e=e|0;YB(e|0)|0}function LEe(e){e=e|0;NY(e|0,0,0)|0}function DEe(e){e=e|0;om(e|0)|0}function CEe(e){e=e|0;cm(e|0,0)|0}function PEe(e){e=e|0;lm(e|0)|0}function BEe(e){e=e|0;aA(e|0,0,0)|0}function IEe(e){e=e|0;hm(e|0,0,0)|0}function HEe(e){e=e|0;xe(e|0,0,0)|0}function xEe(e){e=e|0;pm(e|0,0,0)|0}function UEe(e){e=e|0;Sm(e|0,0,0)}function zEe(e){e=e|0;gm(e|0,0,0)}function jEe(e){e=e|0;ym(e|0,0,0)}function VEe(e){e=e|0;Fm(e|0,0,0)}function qEe(e){e=e|0;Am(e|0)|0}function YEe(e){e=e|0;O_(e|0,0)}function GEe(e){e=e|0;A_(e|0)|0}function WEe(e){e=e|0;Z_(e|0,0,0,0)|0}function KEe(e){e=e|0;J_(e|0,0,0,0)|0}function XEe(e){e=e|0;Q_(e|0,0,0,0)|0}function ZEe(e){e=e|0;$_(e|0,0,0,0)|0}function JEe(e){e=e|0;ep(e|0,0,0,0)|0}function QEe(e){e=e|0;ip(e|0,0,0,0)|0}function $Ee(e){e=e|0;N_(e|0,0,0,0)|0}function eSe(e){e=e|0;T_(e|0,0,0,0)|0}function iSe(e){e=e|0;rp(e|0,0,0,0)|0}function rSe(e){e=e|0;np(e|0,0,0,0)|0}function nSe(e){e=e|0;dN(e|0,0,0,0)|0}function fSe(e){e=e|0;hp(e|0,0,0)}function tSe(e){e=e|0;wp(e|0,0,0)}function uSe(e){e=e|0;FO()|0}function aSe(e){e=e|0;Tg(e|0,0,0,0,0)}function oSe(e){e=e|0;_O(e|0,0,0,0,0)}function cSe(e){e=e|0;OO(e|0)|0}function lSe(e){e=e|0;AO(e|0)|0}function sSe(e){e=e|0;MO(e|0,0,0)|0}function bSe(e){e=e|0;RO(e|0)|0}function kSe(e){e=e|0;sA(e|0)|0}function hSe(e){e=e|0;bA(e|0,0,0)|0}function wSe(e){e=e|0;hA(e|0)|0}function dSe(e){e=e|0;wA(e|0,0,0)|0}function vSe(e){e=e|0;dA(e|0)|0}function mSe(e){e=e|0;vA(e|0,0,0)|0}function _Se(e){e=e|0;mA(e|0,0,0)|0}function pSe(e){e=e|0;_A(e|0,0,0,0)|0}function ESe(e){e=e|0;OR(e|0)|0}function SSe(e){e=e|0;DR(e|0)|0}function gSe(e){e=e|0;BR(e|0)|0}function ySe(e){e=e|0;IR(e|0,0)}function FSe(e){e=e|0;UR(e|0,0)|0}function OSe(e){e=e|0;GR(e|0,0,0)}function ASe(e){e=e|0;iN(e|0,0,0)}function MSe(e){e=e|0;rN(e|0,0,0)}function RSe(e){e=e|0;nN(e|0,0,0)}function NSe(e){e=e|0;fN(e|0,0,0)}function TSe(e){e=e|0;lN(e|0,0)|0}function LSe(e){e=e|0;Xr(e|0,0)}function DSe(e){e=e|0;tt(e|0,0)}function CSe(e){e=e|0;bt(e|0,0)}function PSe(e){e=e|0;Yf(e|0,0)}function BSe(e){e=e|0;Jf(e|0,0)}function ISe(e){e=e|0;Qf(e|0,0)}function HSe(e){e=e|0;Gf(e|0,0)}function xSe(e){e=e|0;ot(e|0,0)}function USe(e){e=e|0;st(e|0,0)}function zSe(e){e=e|0;Vf(e|0,0)}function jSe(e){e=e|0;ct(e|0,0)}function VSe(e){e=e|0;Wf(e|0,0)}function qSe(e){e=e|0;ut(e|0,0)}function YSe(e){e=e|0;Yt(e|0,0)}function GSe(e){e=e|0;Kf(e|0,0)}function WSe(e){e=e|0;nt(e|0,0)}function KSe(e){e=e|0;gf(e|0,0)}function XSe(e){e=e|0;qf(e|0,0)}function ZSe(e){e=e|0;kt(e|0,0)}function JSe(e){e=e|0;Xf(e|0,0)}function QSe(e){e=e|0;Zf(e|0,0)}function $Se(e){e=e|0;$f(e|0,0)}function ege(e){e=e|0;et(e|0,0)}function ige(e){e=e|0;it(e|0,0)}function rge(e){e=e|0;rt(e|0,0)}function nge(e){e=e|0;lt(e|0,0)}function fge(e){e=e|0;at(e|0,0)}function tge(e){e=e|0;ft(e|0,0)}function uge(e){e=e|0;Gt(e|0,0)}function age(e){e=e|0;Qu(e|0,0,0)|0}function oge(e){e=e|0;Pf(e|0,0)|0}function cge(e){e=e|0;Bf(e|0,0)|0}function lge(e){e=e|0;zf(e|0,0)|0}function sge(e){e=e|0;$u(e|0,0,0)|0}function bge(e){e=e|0;ea(e|0,0)|0}function kge(e){e=e|0;Tf(e|0,0)|0}function hge(e){e=e|0;Lf(e|0,0)|0}function wge(e){e=e|0;Df(e|0,0)|0}function dge(e){e=e|0;xf(e|0,0)|0}function vge(e){e=e|0;If(e|0,0)|0}function mge(e){e=e|0;Uf(e|0,0)|0}function _ge(e){e=e|0;Cf(e|0,0)|0}function pge(e){e=e|0;ia(e|0,0)|0}function Ege(e){e=e|0;Hf(e|0,0)|0}function Sge(e){e=e|0;Nf(e|0,0)|0}function gge(e){e=e|0;Cn(e|0,0)|0}function yge(e){e=e|0;za(e|0,0)}function Fge(e){e=e|0;Wa(e|0,0)}function Oge(e){e=e|0;Ka(e|0,0)}function Age(e){e=e|0;Xa(e|0,0)}function Mge(e){e=e|0;Za(e|0,0)}function Rge(e){e=e|0;Ja(e|0,0)}function Nge(e){e=e|0;Qa(e|0,0)}function Tge(e){e=e|0;$a(e|0,0)}function Lge(e){e=e|0;Qo(e|0,0,0)}function Dge(e){e=e|0;wl(e|0,0,0)|0}function Cge(e){e=e|0;Ll(e|0,0)|0}function Pge(e){e=e|0;Bl(e|0,0)|0}function Bge(e){e=e|0;Hl(e|0,0)|0}function Ige(e){e=e|0;jl(e|0,0)|0}function Hge(e){e=e|0;dh(e|0,0,0,0,0,0,0,0,0)}function xge(e){e=e|0;vh(e|0,0,0,0)}function Uge(e){e=e|0;mh(e|0,0,0)}function zge(e){e=e|0;_h(e|0,0,0)}function jge(e){e=e|0;ph(e|0,0)}function Vge(e){e=e|0;Eh(e|0,0,0,0)}function qge(e){e=e|0;Sh(e|0)|0}function Yge(e){e=e|0;gh(e|0)|0}function Gge(e){e=e|0;yh(e|0)|0}function Wge(e){e=e|0;Fh(e|0,0,0)|0}function Kge(e){e=e|0;Oh(e|0,0)|0}function Xge(e){e=e|0;Ah(e|0,0,0,0,0,0)}function Zge(e){e=e|0;Mh(e|0,0,0,0)}function Jge(e){e=e|0;Rh(e|0,0,0,0,0,0,0)}function Qge(e){e=e|0;Nh(e|0,0,0,0)}function $ge(e){e=e|0;Th(e|0,0,0,0,0)}function eye(e){e=e|0;Lh(e|0,0)}function iye(e){e=e|0;Ph(e|0,0,0)}function rye(e){e=e|0;Bh(e|0,0)}function nye(e){e=e|0;Ih(e|0,0,0)}function fye(e){e=e|0;Hh(e|0,0,0)}function tye(e){e=e|0;xh(e|0,0,0)}function uye(e){e=e|0;Uh(e|0,0)|0}function aye(e){e=e|0;zh(e|0,0,0,0)}function oye(e){e=e|0;jh(e|0,0,0)}function cye(e){e=e|0;Vh(e|0,0,0)}function lye(e){e=e|0;qh(e|0,0,0)}function sye(e){e=e|0;Yh(e|0,0)}function bye(e){e=e|0;Gh(e|0,0,0,0,0,0,0,0,0)}function kye(e){e=e|0;Wh(e|0,0,0,0)}function hye(e){e=e|0;Zh(e|0,0,0)|0}function wye(e){e=e|0;td(e|0,0)}function dye(e){e=e|0;qv(e|0,0,0,0)}function vye(e){e=e|0;aT(e|0,0)}function mye(e){e=e|0;cH(e|0,0,0)}function _ye(e){e=e|0;lH(e|0,0)}function pye(e){e=e|0;sH(e|0,0,0,0,0,0,0,0,0)}function Eye(e){e=e|0;bH(e|0,0,0,0)}function Sye(e){e=e|0;kH(e|0,0,0)}function gye(e){e=e|0;hH(e|0,0,0)}function yye(e){e=e|0;dH(e|0,0,0)}function Fye(e){e=e|0;vH(e|0,0,0)}function Oye(e){e=e|0;_H(e|0,0,0)|0}function Aye(e){e=e|0;mH(e|0,0)}function Mye(e){e=e|0;ex(e|0,0)|0}function Rye(e){e=e|0;ix(e|0,0,0,0,0)|0}function Nye(e){e=e|0;rx(e|0,0,0,0,0,0,0)|0}function Tye(e){e=e|0;nx(e|0,0,0,0,0,0)|0}function Lye(e){e=e|0;fx(e|0,0)}function Dye(e){e=e|0;ux(e|0,0)|0}function Cye(e){e=e|0;ax(e|0,0,0,0,0)|0}function Pye(e){e=e|0;ox(e|0,0,0,0,0,0,0)|0}function Bye(e){e=e|0;cx(e|0,0)}function Iye(e){e=e|0;wx(e|0,0,0)}function Hye(e){e=e|0;_x(e|0,0,0,0)}function xye(e){e=e|0;oU(e|0,0,0)}function Uye(e){e=e|0;cU(e|0,0,0)}function zye(e){e=e|0;GU(e|0,0,0,0)}function jye(e){e=e|0;tz(e|0,0,0)}function Vye(e){e=e|0;Gz(e|0,0,0,0,0,0,0,0,0)}function qye(e){e=e|0;Wz(e|0,0,0,0)}function Yye(e){e=e|0;PV(e|0,0,0,0)|0}function Gye(e){e=e|0;Rq(e|0,0)|0}function Wye(e){e=e|0;Kq(e|0,0,0)|0}function Kye(e,i){e=e|0;i=i|0;ue(6)}function Xye(e,i){e=e|0;i=i|0;Cm(e|0,i|0,0,0)}function Zye(e,i){e=e|0;i=i|0;Pm(e|0)|0}function Jye(e,i){e=e|0;i=i|0;Bm(e|0)|0}function Qye(e,i){e=e|0;i=i|0;Im(e|0)|0}function $ye(e,i){e=e|0;i=i|0;Hm(e|0,i|0,0)|0}function eFe(e,i){e=e|0;i=i|0;xm(e|0,i|0)|0}function iFe(e,i){e=e|0;i=i|0;Um(e|0,i|0,0,0,0,0)}function rFe(e,i){e=e|0;i=i|0;zm(e|0,i|0,0,0)}function nFe(e,i){e=e|0;i=i|0;jm(e|0,i|0,0,0,0,0,0)}function fFe(e,i){e=e|0;i=i|0;Vm(e|0,i|0,0,0)}function tFe(e,i){e=e|0;i=i|0;qm(e|0,i|0,0,0,0)}function uFe(e,i){e=e|0;i=i|0;Gm(e|0)}function aFe(e,i){e=e|0;i=i|0;Wm(e|0)}function oFe(e,i){e=e|0;i=i|0;o_(e|0,i|0,0)}function cFe(e,i){e=e|0;i=i|0;Xm(e|0,i|0,0)}function lFe(e,i){e=e|0;i=i|0;Zm(e|0,i|0,0)}function sFe(e,i){e=e|0;i=i|0;Jm(e|0,i|0,0)}function bFe(e,i){e=e|0;i=i|0;$m(e|0,i|0,0)}function kFe(e,i){e=e|0;i=i|0;e_(e|0,i|0,0)}function hFe(e,i){e=e|0;i=i|0;i_(e|0,i|0,0)}function wFe(e,i){e=e|0;i=i|0;r_(e|0,i|0)|0}function dFe(e,i){e=e|0;i=i|0;n_(e|0,i|0,0)}function vFe(e,i){e=e|0;i=i|0;f_(e|0,i|0,0,0)}function mFe(e,i){e=e|0;i=i|0;t_(e|0,i|0,0,0,0,0,0,0,0)}function _Fe(e,i){e=e|0;i=i|0;u_(e|0,i|0,0,0)}function pFe(e,i){e=e|0;i=i|0;oA(e|0,i|0,0)|0}function EFe(e,i){e=e|0;i=i|0;Zq(e|0)}function SFe(e,i){e=e|0;i=i|0;Xq(e|0)|0}function gFe(e,i){e=e|0;i=i|0;Jq(e|0,i|0)|0}function yFe(e,i){e=e|0;i=i|0;Yl(e|0)|0}function FFe(e,i){e=e|0;i=i|0;tp(e|0,i|0,0)}function OFe(e,i){e=e|0;i=i|0;Tz(e|0,i|0,0,0)}function AFe(e,i){e=e|0;i=i|0;Mz(e|0)|0}function MFe(e,i){e=e|0;i=i|0;Rz(e|0)|0}function RFe(e,i){e=e|0;i=i|0;Nz(e|0)|0}function NFe(e,i){e=e|0;i=i|0;Dz(e|0,i|0,0)|0}function TFe(e,i){e=e|0;i=i|0;Cz(e|0,i|0)|0}function LFe(e,i){e=e|0;i=i|0;Bz(e|0,i|0,0,0,0,0)}function DFe(e,i){e=e|0;i=i|0;xz(e|0,i|0,0,0)}function CFe(e,i){e=e|0;i=i|0;Iz(e|0,i|0,0,0,0,0,0)}function PFe(e,i){e=e|0;i=i|0;Hz(e|0,i|0,0,0)}function BFe(e,i){e=e|0;i=i|0;Uz(e|0,i|0,0,0,0)}function IFe(e,i){e=e|0;i=i|0;jz(e|0)}function HFe(e,i){e=e|0;i=i|0;Vz(e|0)}function xFe(e,i){e=e|0;i=i|0;qz(e|0,i|0,0)}function UFe(e,i){e=e|0;i=i|0;Xz(e|0,i|0,0)}function zFe(e,i){e=e|0;i=i|0;Jz(e|0,i|0,0)}function jFe(e,i){e=e|0;i=i|0;kp(e|0,i|0,0)}function VFe(e,i){e=e|0;i=i|0;bp(e|0,i|0,0)}function qFe(e,i){e=e|0;i=i|0;Pz(e|0,i|0)|0}function YFe(e,i){e=e|0;i=i|0;$z(e|0,i|0,0)}function GFe(e,i){e=e|0;i=i|0;Lz(e|0,i|0,0,0)}function WFe(e,i){e=e|0;i=i|0;yz(e|0)|0}function KFe(e,i){e=e|0;i=i|0;Fz(e|0)|0}function XFe(e,i){e=e|0;i=i|0;Oz(e|0)|0}function ZFe(e,i){e=e|0;i=i|0;Az(e|0)|0}function JFe(e,i){e=e|0;i=i|0;Zz(e|0,i|0,0)}function QFe(e,i){e=e|0;i=i|0;OC(e|0)|0}function $Fe(e,i){e=e|0;i=i|0;AC(e|0)|0}function eOe(e,i){e=e|0;i=i|0;MC(e|0)|0}function iOe(e,i){e=e|0;i=i|0;RC(e|0)|0}function rOe(e,i){e=e|0;i=i|0;NC(e|0)|0}function nOe(e,i){e=e|0;i=i|0;TC(e|0)|0}function fOe(e,i){e=e|0;i=i|0;LC(e|0)|0}function tOe(e,i){e=e|0;i=i|0;DC(e|0)|0}function uOe(e,i){e=e|0;i=i|0;CC(e|0)|0}function aOe(e,i){e=e|0;i=i|0;PC(e|0)|0}function oOe(e,i){e=e|0;i=i|0;BC(e|0)|0}function cOe(e,i){e=e|0;i=i|0;IC(e|0)|0}function lOe(e,i){e=e|0;i=i|0;HC(e|0)|0}function sOe(e,i){e=e|0;i=i|0;xC(e|0)|0}function bOe(e,i){e=e|0;i=i|0;UC(e|0)|0}function kOe(e,i){e=e|0;i=i|0;zC(e|0)|0}function hOe(e,i){e=e|0;i=i|0;jC(e|0)|0}function wOe(e,i){e=e|0;i=i|0;VC(e|0)|0}function dOe(e,i){e=e|0;i=i|0;qC(e|0)|0}function vOe(e,i){e=e|0;i=i|0;YC(e|0)|0}function mOe(e,i){e=e|0;i=i|0;GC(e|0)|0}function _Oe(e,i){e=e|0;i=i|0;WC(e|0)|0}function pOe(e,i){e=e|0;i=i|0;KC(e|0)|0}function EOe(e,i){e=e|0;i=i|0;XC(e|0)|0}function SOe(e,i){e=e|0;i=i|0;ZC(e|0)|0}function gOe(e,i){e=e|0;i=i|0;JC(e|0)|0}function yOe(e,i){e=e|0;i=i|0;QC(e|0)|0}function FOe(e,i){e=e|0;i=i|0;$C(e|0)|0}function OOe(e,i){e=e|0;i=i|0;eP(e|0)|0}function AOe(e,i){e=e|0;i=i|0;iP(e|0)|0}function MOe(e,i){e=e|0;i=i|0;rP(e|0)|0}function ROe(e,i){e=e|0;i=i|0;nP(e|0)|0}function NOe(e,i){e=e|0;i=i|0;fP(e|0)|0}function TOe(e,i){e=e|0;i=i|0;tP(e|0)|0}function LOe(e,i){e=e|0;i=i|0;uP(e|0)|0}function DOe(e,i){e=e|0;i=i|0;aP(e|0)|0}function COe(e,i){e=e|0;i=i|0;oP(e|0)|0}function POe(e,i){e=e|0;i=i|0;cP(e|0)|0}function BOe(e,i){e=e|0;i=i|0;lP(e|0)|0}function IOe(e,i){e=e|0;i=i|0;sP(e|0)|0}function HOe(e,i){e=e|0;i=i|0;bP(e|0)|0}function xOe(e,i){e=e|0;i=i|0;kP(e|0)|0}function UOe(e,i){e=e|0;i=i|0;hP(e|0)|0}function zOe(e,i){e=e|0;i=i|0;wP(e|0)|0}function jOe(e,i){e=e|0;i=i|0;dP(e|0)|0}function VOe(e,i){e=e|0;i=i|0;vP(e|0)|0}function qOe(e,i){e=e|0;i=i|0;mP(e|0)|0}function YOe(e,i){e=e|0;i=i|0;_P(e|0)|0}function GOe(e,i){e=e|0;i=i|0;pP(e|0)|0}function WOe(e,i){e=e|0;i=i|0;EP(e|0)|0}function KOe(e,i){e=e|0;i=i|0;SP(e|0)|0}function XOe(e,i){e=e|0;i=i|0;gP(e|0)|0}function ZOe(e,i){e=e|0;i=i|0;yP(e|0)|0}function JOe(e,i){e=e|0;i=i|0;FP(e|0)|0}function QOe(e,i){e=e|0;i=i|0;OP(e|0)|0}function $Oe(e,i){e=e|0;i=i|0;AP(e|0)|0}function eAe(e,i){e=e|0;i=i|0;MP(e|0)|0}function iAe(e,i){e=e|0;i=i|0;RP(e|0)|0}function rAe(e,i){e=e|0;i=i|0;NP(e|0)|0}function nAe(e,i){e=e|0;i=i|0;TP(e|0)|0}function fAe(e,i){e=e|0;i=i|0;LP(e|0)|0}function tAe(e,i){e=e|0;i=i|0;DP(e|0)|0}function uAe(e,i){e=e|0;i=i|0;CP(e|0)|0}function aAe(e,i){e=e|0;i=i|0;PP(e|0)|0}function oAe(e,i){e=e|0;i=i|0;BP(e|0)|0}function cAe(e,i){e=e|0;i=i|0;IP(e|0)|0}function lAe(e,i){e=e|0;i=i|0;HP(e|0)|0}function sAe(e,i){e=e|0;i=i|0;xP(e|0)|0}function bAe(e,i){e=e|0;i=i|0;UP(e|0)|0}function kAe(e,i){e=e|0;i=i|0;zP(e|0)|0}function hAe(e,i){e=e|0;i=i|0;jP(e|0)|0}function wAe(e,i){e=e|0;i=i|0;VP(e|0)|0}function dAe(e,i){e=e|0;i=i|0;qP(e|0)|0}function vAe(e,i){e=e|0;i=i|0;YP(e|0)|0}function mAe(e,i){e=e|0;i=i|0;GP(e|0)|0}function _Ae(e,i){e=e|0;i=i|0;WP(e|0)|0}function pAe(e,i){e=e|0;i=i|0;KP(e|0)|0}function EAe(e,i){e=e|0;i=i|0;XP(e|0)|0}function SAe(e,i){e=e|0;i=i|0;ZP(e|0)|0}function gAe(e,i){e=e|0;i=i|0;JP(e|0)|0}function yAe(e,i){e=e|0;i=i|0;QP(e|0)|0}function FAe(e,i){e=e|0;i=i|0;$P(e|0)|0}function OAe(e,i){e=e|0;i=i|0;eB(e|0)|0}function AAe(e,i){e=e|0;i=i|0;iB(e|0)|0}function MAe(e,i){e=e|0;i=i|0;rB(e|0)|0}function RAe(e,i){e=e|0;i=i|0;nB(e|0)|0}function NAe(e,i){e=e|0;i=i|0;fB(e|0)|0}function TAe(e,i){e=e|0;i=i|0;tB(e|0)|0}function LAe(e,i){e=e|0;i=i|0;uB(e|0)|0}function DAe(e,i){e=e|0;i=i|0;aB(e|0)|0}function CAe(e,i){e=e|0;i=i|0;oB(e|0)|0}function PAe(e,i){e=e|0;i=i|0;cB(e|0)|0}function BAe(e,i){e=e|0;i=i|0;lB(e|0)|0}function IAe(e,i){e=e|0;i=i|0;sB(e|0)|0}function HAe(e,i){e=e|0;i=i|0;bB(e|0)|0}function xAe(e,i){e=e|0;i=i|0;kB(e|0)|0}function UAe(e,i){e=e|0;i=i|0;hB(e|0)|0}function zAe(e,i){e=e|0;i=i|0;wB(e|0)|0}function jAe(e,i){e=e|0;i=i|0;dB(e|0)|0}function VAe(e,i){e=e|0;i=i|0;vB(e|0)|0}function qAe(e,i){e=e|0;i=i|0;mB(e|0)|0}function YAe(e,i){e=e|0;i=i|0;_B(e|0)|0}function GAe(e,i){e=e|0;i=i|0;pB(e|0)|0}function WAe(e,i){e=e|0;i=i|0;EB(e|0)|0}function KAe(e,i){e=e|0;i=i|0;SB(e|0)|0}function XAe(e,i){e=e|0;i=i|0;gB(e|0)|0}function ZAe(e,i){e=e|0;i=i|0;yB(e|0)|0}function JAe(e,i){e=e|0;i=i|0;FB(e|0)|0}function QAe(e,i){e=e|0;i=i|0;OB(e|0)|0}function $Ae(e,i){e=e|0;i=i|0;AB(e|0)|0}function eMe(e,i){e=e|0;i=i|0;MB(e|0)|0}function iMe(e,i){e=e|0;i=i|0;RB(e|0)|0}function rMe(e,i){e=e|0;i=i|0;NB(e|0)|0}function nMe(e,i){e=e|0;i=i|0;TB(e|0)|0}function fMe(e,i){e=e|0;i=i|0;LB(e|0)|0}function tMe(e,i){e=e|0;i=i|0;DB(e|0)|0}function uMe(e,i){e=e|0;i=i|0;CB(e|0)|0}function aMe(e,i){e=e|0;i=i|0;PB(e|0)|0}function oMe(e,i){e=e|0;i=i|0;BB(e|0)|0}function cMe(e,i){e=e|0;i=i|0;IB(e|0)|0}function lMe(e,i){e=e|0;i=i|0;HB(e|0)|0}function sMe(e,i){e=e|0;i=i|0;xB(e|0)|0}function bMe(e,i){e=e|0;i=i|0;UB(e|0)|0}function kMe(e,i){e=e|0;i=i|0;zB(e|0)|0}function hMe(e,i){e=e|0;i=i|0;jB(e|0)|0}function wMe(e,i){e=e|0;i=i|0;VB(e|0)|0}function dMe(e,i){e=e|0;i=i|0;qB(e|0)|0}function vMe(e,i){e=e|0;i=i|0;YB(e|0)|0}function mMe(e,i){e=e|0;i=i|0;NY(e|0,i|0,0)|0}function _Me(e,i){e=e|0;i=i|0;am(e|0)}function pMe(e,i){e=e|0;i=i|0;om(e|0)|0}function EMe(e,i){e=e|0;i=i|0;cm(e|0,i|0)|0}function SMe(e,i){e=e|0;i=i|0;lm(e|0)|0}function gMe(e,i){e=e|0;i=i|0;aA(e|0,i|0,0)|0}function yMe(e,i){e=e|0;i=i|0;bm(e|0)}function FMe(e,i){e=e|0;i=i|0;km(e|0)}function OMe(e,i){e=e|0;i=i|0;hm(e|0,i|0,0)|0}function AMe(e,i){e=e|0;i=i|0;xe(e|0,i|0,0)|0}function MMe(e,i){e=e|0;i=i|0;pm(e|0,i|0,0)|0}function RMe(e,i){e=e|0;i=i|0;Em(e|0)}function NMe(e,i){e=e|0;i=i|0;Sm(e|0,i|0,0)}function TMe(e,i){e=e|0;i=i|0;gm(e|0,i|0,0)}function LMe(e,i){e=e|0;i=i|0;ym(e|0,i|0,0)}function DMe(e,i){e=e|0;i=i|0;Fm(e|0,i|0,0)}function CMe(e,i){e=e|0;i=i|0;Am(e|0)|0}function PMe(e,i){e=e|0;i=i|0;A_(e|0)|0}function BMe(e,i){e=e|0;i=i|0;Z_(e|0,i|0,0,0)|0}function IMe(e,i){e=e|0;i=i|0;J_(e|0,i|0,0,0)|0}function HMe(e,i){e=e|0;i=i|0;Q_(e|0,i|0,0,0)|0}function xMe(e,i){e=e|0;i=i|0;$_(e|0,i|0,0,0)|0}function UMe(e,i){e=e|0;i=i|0;ep(e|0,i|0,0,0)|0}function zMe(e,i){e=e|0;i=i|0;ip(e|0,i|0,0,0)|0}function jMe(e,i){e=e|0;i=i|0;N_(e|0,i|0,0,0)|0}function VMe(e,i){e=e|0;i=i|0;T_(e|0,i|0,0,0)|0}function qMe(e,i){e=e|0;i=i|0;rp(e|0,i|0,0,0)|0}function YMe(e,i){e=e|0;i=i|0;np(e|0,i|0,0,0)|0}function GMe(e,i){e=e|0;i=i|0;dN(e|0,i|0,0,0)|0}function WMe(e,i){e=e|0;i=i|0;hp(e|0,i|0,0)}function KMe(e,i){e=e|0;i=i|0;wp(e|0,i|0,0)}function XMe(e,i){e=e|0;i=i|0;LS(e|0)}function ZMe(e,i){e=e|0;i=i|0;FO()|0}function JMe(e,i){e=e|0;i=i|0;Tg(e|0,i|0,0,0,0)}function QMe(e,i){e=e|0;i=i|0;_O(e|0,i|0,0,0,0)}function $Me(e,i){e=e|0;i=i|0;OO(e|0)|0}function eRe(e,i){e=e|0;i=i|0;AO(e|0)|0}function iRe(e,i){e=e|0;i=i|0;MO(e|0,i|0,0)|0}function rRe(e,i){e=e|0;i=i|0;RO(e|0)|0}function nRe(e,i){e=e|0;i=i|0;sA(e|0)|0}function fRe(e,i){e=e|0;i=i|0;bA(e|0,i|0,0)|0}function tRe(e,i){e=e|0;i=i|0;hA(e|0)|0}function uRe(e,i){e=e|0;i=i|0;wA(e|0,i|0,0)|0}function aRe(e,i){e=e|0;i=i|0;dA(e|0)|0}function oRe(e,i){e=e|0;i=i|0;vA(e|0,i|0,0)|0}function cRe(e,i){e=e|0;i=i|0;mA(e|0,i|0,0)|0}function lRe(e,i){e=e|0;i=i|0;_A(e|0,i|0,0,0)|0}function sRe(e,i){e=e|0;i=i|0;FR(e|0)}function bRe(e,i){e=e|0;i=i|0;OR(e|0)|0}function kRe(e,i){e=e|0;i=i|0;NR(e|0)}function hRe(e,i){e=e|0;i=i|0;DR(e|0)|0}function wRe(e,i){e=e|0;i=i|0;PR(e|0)}function dRe(e,i){e=e|0;i=i|0;BR(e|0)|0}function vRe(e,i){e=e|0;i=i|0;HR(e|0)}function mRe(e,i){e=e|0;i=i|0;xR(e|0)}function _Re(e,i){e=e|0;i=i|0;UR(e|0,i|0)|0}function pRe(e,i){e=e|0;i=i|0;zR(e|0)}function ERe(e,i){e=e|0;i=i|0;GR(e|0,i|0,0)}function SRe(e,i){e=e|0;i=i|0;iN(e|0,i|0,0)}function gRe(e,i){e=e|0;i=i|0;rN(e|0,i|0,0)}function yRe(e,i){e=e|0;i=i|0;nN(e|0,i|0,0)}function FRe(e,i){e=e|0;i=i|0;fN(e|0,i|0,0)}function ORe(e,i){e=e|0;i=i|0;lN(e|0,i|0)|0}function ARe(e,i){e=e|0;i=i|0;_n(e|0)}function MRe(e,i){e=e|0;i=i|0;Qu(e|0,i|0,0)|0}function RRe(e,i){e=e|0;i=i|0;Pf(e|0,i|0)|0}function NRe(e,i){e=e|0;i=i|0;Bf(e|0,i|0)|0}function TRe(e,i){e=e|0;i=i|0;zf(e|0,i|0)|0}function LRe(e,i){e=e|0;i=i|0;$u(e|0,i|0,0)|0}function DRe(e,i){e=e|0;i=i|0;ea(e|0,i|0)|0}function CRe(e,i){e=e|0;i=i|0;Tf(e|0,i|0)|0}function PRe(e,i){e=e|0;i=i|0;Lf(e|0,i|0)|0}function BRe(e,i){e=e|0;i=i|0;Df(e|0,i|0)|0}function IRe(e,i){e=e|0;i=i|0;xf(e|0,i|0)|0}function HRe(e,i){e=e|0;i=i|0;If(e|0,i|0)|0}function xRe(e,i){e=e|0;i=i|0;Uf(e|0,i|0)|0}function URe(e,i){e=e|0;i=i|0;Cf(e|0,i|0)|0}function zRe(e,i){e=e|0;i=i|0;ia(e|0,i|0)|0}function jRe(e,i){e=e|0;i=i|0;Hf(e|0,i|0)|0}function VRe(e,i){e=e|0;i=i|0;Nf(e|0,i|0)|0}function qRe(e,i){e=e|0;i=i|0;Cn(e|0,i|0)|0}function YRe(e,i){e=e|0;i=i|0;Qo(e|0,i|0,0)}function GRe(e,i){e=e|0;i=i|0;vc(e|0)}function WRe(e,i){e=e|0;i=i|0;Rc(e|0)}function KRe(e,i){e=e|0;i=i|0;wl(e|0,i|0,0)|0}function XRe(e,i){e=e|0;i=i|0;Ll(e|0,i|0)|0}function ZRe(e,i){e=e|0;i=i|0;Bl(e|0,i|0)|0}function JRe(e,i){e=e|0;i=i|0;Hl(e|0,i|0)|0}function QRe(e,i){e=e|0;i=i|0;jl(e|0,i|0)|0}function $Re(e,i){e=e|0;i=i|0;Xk(e|0)}function eNe(e,i){e=e|0;i=i|0;dh(e|0,i|0,0,0,0,0,0,0,0)}function iNe(e,i){e=e|0;i=i|0;vh(e|0,i|0,0,0)}function rNe(e,i){e=e|0;i=i|0;mh(e|0,i|0,0)}function nNe(e,i){e=e|0;i=i|0;_h(e|0,i|0,0)}function fNe(e,i){e=e|0;i=i|0;Eh(e|0,i|0,0,0)}function tNe(e,i){e=e|0;i=i|0;Sh(e|0)|0}function uNe(e,i){e=e|0;i=i|0;gh(e|0)|0}function aNe(e,i){e=e|0;i=i|0;yh(e|0)|0}function oNe(e,i){e=e|0;i=i|0;Fh(e|0,i|0,0)|0}function cNe(e,i){e=e|0;i=i|0;Oh(e|0,i|0)|0}function lNe(e,i){e=e|0;i=i|0;Ah(e|0,i|0,0,0,0,0)}function sNe(e,i){e=e|0;i=i|0;Mh(e|0,i|0,0,0)}function bNe(e,i){e=e|0;i=i|0;Rh(e|0,i|0,0,0,0,0,0)}function kNe(e,i){e=e|0;i=i|0;Nh(e|0,i|0,0,0)}function hNe(e,i){e=e|0;i=i|0;Th(e|0,i|0,0,0,0)}function wNe(e,i){e=e|0;i=i|0;Dh(e|0)}function dNe(e,i){e=e|0;i=i|0;Ch(e|0)}function vNe(e,i){e=e|0;i=i|0;Ph(e|0,i|0,0)}function mNe(e,i){e=e|0;i=i|0;Ih(e|0,i|0,0)}function _Ne(e,i){e=e|0;i=i|0;Hh(e|0,i|0,0)}function pNe(e,i){e=e|0;i=i|0;xh(e|0,i|0,0)}function ENe(e,i){e=e|0;i=i|0;Uh(e|0,i|0)|0}function SNe(e,i){e=e|0;i=i|0;zh(e|0,i|0,0,0)}function gNe(e,i){e=e|0;i=i|0;jh(e|0,i|0,0)}function yNe(e,i){e=e|0;i=i|0;Vh(e|0,i|0,0)}function FNe(e,i){e=e|0;i=i|0;qh(e|0,i|0,0)}function ONe(e,i){e=e|0;i=i|0;Gh(e|0,i|0,0,0,0,0,0,0,0)}function ANe(e,i){e=e|0;i=i|0;Wh(e|0,i|0,0,0)}function MNe(e,i){e=e|0;i=i|0;Zh(e|0,i|0,0)|0}function RNe(e,i){e=e|0;i=i|0;$h(e|0)}function NNe(e,i){e=e|0;i=i|0;qv(e|0,i|0,0,0)}function TNe(e,i){e=e|0;i=i|0;Ok(e|0)}function LNe(e,i){e=e|0;i=i|0;cH(e|0,i|0,0)}function DNe(e,i){e=e|0;i=i|0;sH(e|0,i|0,0,0,0,0,0,0,0)}function CNe(e,i){e=e|0;i=i|0;bH(e|0,i|0,0,0)}function PNe(e,i){e=e|0;i=i|0;kH(e|0,i|0,0)}function BNe(e,i){e=e|0;i=i|0;hH(e|0,i|0,0)}function INe(e,i){e=e|0;i=i|0;dH(e|0,i|0,0)}function HNe(e,i){e=e|0;i=i|0;vH(e|0,i|0,0)}function xNe(e,i){e=e|0;i=i|0;_H(e|0,i|0,0)|0}function UNe(e,i){e=e|0;i=i|0;DH(e|0)}function zNe(e,i){e=e|0;i=i|0;ex(e|0,i|0)|0}function jNe(e,i){e=e|0;i=i|0;ix(e|0,i|0,0,0,0)|0}function VNe(e,i){e=e|0;i=i|0;rx(e|0,i|0,0,0,0,0,0)|0}function qNe(e,i){e=e|0;i=i|0;nx(e|0,i|0,0,0,0,0)|0}function YNe(e,i){e=e|0;i=i|0;ux(e|0,i|0)|0}function GNe(e,i){e=e|0;i=i|0;ax(e|0,i|0,0,0,0)|0}function WNe(e,i){e=e|0;i=i|0;ox(e|0,i|0,0,0,0,0,0)|0}function KNe(e,i){e=e|0;i=i|0;wx(e|0,i|0,0)}function XNe(e,i){e=e|0;i=i|0;_x(e|0,i|0,0,0)}function ZNe(e,i){e=e|0;i=i|0;oU(e|0,i|0,0)}function JNe(e,i){e=e|0;i=i|0;cU(e|0,i|0,0)}function QNe(e,i){e=e|0;i=i|0;GU(e|0,i|0,0,0)}function $Ne(e,i){e=e|0;i=i|0;tz(e|0,i|0,0)}function eTe(e,i){e=e|0;i=i|0;Gz(e|0,i|0,0,0,0,0,0,0,0)}function iTe(e,i){e=e|0;i=i|0;Wz(e|0,i|0,0,0)}function rTe(e,i){e=e|0;i=i|0;PV(e|0,i|0,0,0)|0}function nTe(e,i){e=e|0;i=i|0;Rq(e|0,i|0)|0}function fTe(e,i){e=e|0;i=i|0;Kq(e|0,i|0,0)|0}function tTe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;ue(7);return 0}function uTe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return 0}function aTe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return Pm(e|0)|0}function oTe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return Bm(e|0)|0}function cTe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return Im(e|0)|0}function lTe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return Hm(e|0,i|0,r|0)|0}function sTe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return xm(e|0,i|0)|0}function bTe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return 0}function kTe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return 0}function hTe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return 0}function wTe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return 0}function dTe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return 0}function vTe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return 0}function mTe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return 0}function _Te(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return 0}function pTe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return 0}function ETe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return 0}function STe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return 0}function gTe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return 0}function yTe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return 0}function FTe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return 0}function OTe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return 0}function ATe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return 0}function MTe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return 0}function RTe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return 0}function NTe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return r_(e|0,i|0)|0}function TTe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return 0}function LTe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return 0}function DTe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return 0}function CTe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return 0}function PTe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return oA(e|0,i|0,r|0)|0}function BTe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return 0}function ITe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return Xq(e|0)|0}function HTe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return Jq(e|0,i|0)|0}function xTe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return Yl(e|0)|0}function UTe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return 0}function zTe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return 0}function jTe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return Mz(e|0)|0}function VTe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return Rz(e|0)|0}function qTe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return Nz(e|0)|0}function YTe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return Dz(e|0,i|0,r|0)|0}function GTe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return Cz(e|0,i|0)|0}function WTe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return 0}function KTe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return 0}function XTe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return 0}function ZTe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return 0}function JTe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return 0}function QTe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return 0}function $Te(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return 0}function eLe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return 0}function iLe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return 0}function rLe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return 0}function nLe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return 0}function fLe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return 0}function tLe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return 0}function uLe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return 0}function aLe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return 0}function oLe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return 0}function cLe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return Pz(e|0,i|0)|0}function lLe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return 0}function sLe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return 0}function bLe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return yz(e|0)|0}function kLe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return Fz(e|0)|0}function hLe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return Oz(e|0)|0}function wLe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return Az(e|0)|0}function dLe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return 0}function vLe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return OC(e|0)|0}function mLe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return AC(e|0)|0}function _Le(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return MC(e|0)|0}function pLe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return RC(e|0)|0}function ELe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return NC(e|0)|0}function SLe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return TC(e|0)|0}function gLe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return LC(e|0)|0}function yLe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return DC(e|0)|0}function FLe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return CC(e|0)|0}function OLe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return PC(e|0)|0}function ALe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return BC(e|0)|0}function MLe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return IC(e|0)|0}function RLe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return HC(e|0)|0}function NLe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return xC(e|0)|0}function TLe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return UC(e|0)|0}function LLe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return zC(e|0)|0}function DLe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return jC(e|0)|0}function CLe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return VC(e|0)|0}function PLe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return qC(e|0)|0}function BLe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return YC(e|0)|0}function ILe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return GC(e|0)|0}function HLe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return WC(e|0)|0}function xLe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return KC(e|0)|0}function ULe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return XC(e|0)|0}function zLe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return ZC(e|0)|0}function jLe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return JC(e|0)|0}function VLe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return QC(e|0)|0}function qLe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return $C(e|0)|0}function YLe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return eP(e|0)|0}function GLe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return iP(e|0)|0}function WLe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return rP(e|0)|0}function KLe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return nP(e|0)|0}function XLe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return fP(e|0)|0}function ZLe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return tP(e|0)|0}function JLe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return uP(e|0)|0}function QLe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return aP(e|0)|0}function $Le(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return oP(e|0)|0}function eDe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return cP(e|0)|0}function iDe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return lP(e|0)|0}function rDe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return sP(e|0)|0}function nDe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return bP(e|0)|0}function fDe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return kP(e|0)|0}function tDe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return hP(e|0)|0}function uDe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return wP(e|0)|0}function aDe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return dP(e|0)|0}function oDe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return vP(e|0)|0}function cDe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return mP(e|0)|0}function lDe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return _P(e|0)|0}function sDe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return pP(e|0)|0}function bDe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return EP(e|0)|0}function kDe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return SP(e|0)|0}function hDe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return gP(e|0)|0}function wDe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return yP(e|0)|0}function dDe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return FP(e|0)|0}function vDe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return OP(e|0)|0}function mDe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return AP(e|0)|0}function _De(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return MP(e|0)|0}function pDe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return RP(e|0)|0}function EDe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return NP(e|0)|0}function SDe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return TP(e|0)|0}function gDe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return LP(e|0)|0}function yDe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return DP(e|0)|0}function FDe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return CP(e|0)|0}function ODe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return PP(e|0)|0}function ADe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return BP(e|0)|0}function MDe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return IP(e|0)|0}function RDe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return HP(e|0)|0}function NDe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return xP(e|0)|0}function TDe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return UP(e|0)|0}function LDe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return zP(e|0)|0}function DDe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return jP(e|0)|0}function CDe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return VP(e|0)|0}function PDe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return qP(e|0)|0}function BDe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return YP(e|0)|0}function IDe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return GP(e|0)|0}function HDe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return WP(e|0)|0}function xDe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return KP(e|0)|0}function UDe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return XP(e|0)|0}function zDe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return ZP(e|0)|0}function jDe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return JP(e|0)|0}function VDe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return QP(e|0)|0}function qDe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return $P(e|0)|0;
	}function YDe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return eB(e|0)|0}function GDe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return iB(e|0)|0}function WDe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return rB(e|0)|0}function KDe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return nB(e|0)|0}function XDe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return fB(e|0)|0}function ZDe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return tB(e|0)|0}function JDe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return uB(e|0)|0}function QDe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return aB(e|0)|0}function $De(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return oB(e|0)|0}function eCe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return cB(e|0)|0}function iCe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return lB(e|0)|0}function rCe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return sB(e|0)|0}function nCe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return bB(e|0)|0}function fCe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return kB(e|0)|0}function tCe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return hB(e|0)|0}function uCe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return wB(e|0)|0}function aCe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return dB(e|0)|0}function oCe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return vB(e|0)|0}function cCe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return mB(e|0)|0}function lCe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return _B(e|0)|0}function sCe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return pB(e|0)|0}function bCe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return EB(e|0)|0}function kCe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return SB(e|0)|0}function hCe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return gB(e|0)|0}function wCe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return yB(e|0)|0}function dCe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return FB(e|0)|0}function vCe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return OB(e|0)|0}function mCe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return AB(e|0)|0}function _Ce(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return MB(e|0)|0}function pCe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return RB(e|0)|0}function ECe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return NB(e|0)|0}function SCe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return TB(e|0)|0}function gCe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return LB(e|0)|0}function yCe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return DB(e|0)|0}function FCe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return CB(e|0)|0}function OCe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return PB(e|0)|0}function ACe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return BB(e|0)|0}function MCe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return IB(e|0)|0}function RCe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return HB(e|0)|0}function NCe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return xB(e|0)|0}function TCe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return UB(e|0)|0}function LCe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return zB(e|0)|0}function DCe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return jB(e|0)|0}function CCe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return VB(e|0)|0}function PCe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return qB(e|0)|0}function BCe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return YB(e|0)|0}function ICe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return NY(e|0,i|0,r|0)|0}function HCe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return 0}function xCe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return om(e|0)|0}function UCe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return cm(e|0,i|0)|0}function zCe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return lm(e|0)|0}function jCe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return aA(e|0,i|0,r|0)|0}function VCe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return 0}function qCe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return 0}function YCe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return hm(e|0,i|0,r|0)|0}function GCe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return xe(e|0,i|0,r|0)|0}function WCe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return pm(e|0,i|0,r|0)|0}function KCe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return 0}function XCe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return 0}function ZCe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return 0}function JCe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return 0}function QCe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return 0}function $Ce(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return Am(e|0)|0}function ePe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return 0}function iPe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return A_(e|0)|0}function rPe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return Z_(e|0,i|0,r|0,n|0)|0}function nPe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return J_(e|0,i|0,r|0,n|0)|0}function fPe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return Q_(e|0,i|0,r|0,n|0)|0}function tPe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return $_(e|0,i|0,r|0,n|0)|0}function uPe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return ep(e|0,i|0,r|0,n|0)|0}function aPe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return ip(e|0,i|0,r|0,n|0)|0}function oPe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return N_(e|0,i|0,r|0,n|0)|0}function cPe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return T_(e|0,i|0,r|0,n|0)|0}function lPe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return rp(e|0,i|0,r|0,n|0)|0}function sPe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return np(e|0,i|0,r|0,n|0)|0}function bPe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return dN(e|0,i|0,r|0,n|0)|0}function kPe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return 0}function hPe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return 0}function wPe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return 0}function dPe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return FO()|0}function vPe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return 0}function mPe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return 0}function _Pe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return OO(e|0)|0}function pPe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return AO(e|0)|0}function EPe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return MO(e|0,i|0,r|0)|0}function SPe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return RO(e|0)|0}function gPe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return sA(e|0)|0}function yPe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return bA(e|0,i|0,r|0)|0}function FPe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return hA(e|0)|0}function OPe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return wA(e|0,i|0,r|0)|0}function APe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return dA(e|0)|0}function MPe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return vA(e|0,i|0,r|0)|0}function RPe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return mA(e|0,i|0,r|0)|0}function NPe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return _A(e|0,i|0,r|0,n|0)|0}function TPe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return 0}function LPe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return OR(e|0)|0}function DPe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return 0}function CPe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return DR(e|0)|0}function PPe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return 0}function BPe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return BR(e|0)|0}function IPe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return 0}function HPe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return 0}function xPe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return 0}function UPe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return UR(e|0,i|0)|0}function zPe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return 0}function jPe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return 0}function VPe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return 0}function qPe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return 0}function YPe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return 0}function GPe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return 0}function WPe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return lN(e|0,i|0)|0}function KPe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return 0}function XPe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return 0}function ZPe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return 0}function JPe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return 0}function QPe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return 0}function $Pe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return 0}function eBe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return 0}function iBe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return 0}function rBe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return 0}function nBe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return 0}function fBe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return 0}function tBe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return 0}function uBe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return 0}function aBe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return 0}function oBe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return 0}function cBe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return 0}function lBe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return 0}function sBe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return 0}function bBe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return 0}function kBe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return 0}function hBe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return 0}function wBe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return 0}function dBe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return 0}function vBe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return 0}function mBe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return 0}function _Be(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return 0}function pBe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return 0}function EBe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return 0}function SBe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return 0}function gBe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return 0}function yBe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return Qu(e|0,i|0,r|0)|0}function FBe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return Pf(e|0,i|0)|0}function OBe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return Bf(e|0,i|0)|0}function ABe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return zf(e|0,i|0)|0}function MBe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return $u(e|0,i|0,r|0)|0}function RBe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return ea(e|0,i|0)|0}function NBe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return Tf(e|0,i|0)|0}function TBe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return Lf(e|0,i|0)|0}function LBe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return Df(e|0,i|0)|0}function DBe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return xf(e|0,i|0)|0}function CBe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return If(e|0,i|0)|0}function PBe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return Uf(e|0,i|0)|0}function BBe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return Cf(e|0,i|0)|0}function IBe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return ia(e|0,i|0)|0}function HBe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return Hf(e|0,i|0)|0}function xBe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return Nf(e|0,i|0)|0}function UBe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return Cn(e|0,i|0)|0}function zBe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return 0}function jBe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return 0}function VBe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return 0}function qBe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return 0}function YBe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return 0}function GBe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return 0}function WBe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return 0}function KBe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return 0}function XBe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return 0}function ZBe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return 0}function JBe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return 0}function QBe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return wl(e|0,i|0,r|0)|0}function $Be(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return Ll(e|0,i|0)|0}function eIe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return Bl(e|0,i|0)|0}function iIe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return Hl(e|0,i|0)|0}function rIe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return jl(e|0,i|0)|0}function nIe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return 0}function fIe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return 0}function tIe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return 0}function uIe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return 0}function aIe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return 0}function oIe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return 0}function cIe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return 0}function lIe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return Sh(e|0)|0}function sIe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return gh(e|0)|0}function bIe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return yh(e|0)|0}function kIe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return Fh(e|0,i|0,r|0)|0}function hIe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return Oh(e|0,i|0)|0}function wIe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return 0}function dIe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return 0}function vIe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return 0}function mIe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return 0}function _Ie(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return 0}function pIe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return 0}function EIe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return 0}function SIe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return 0}function gIe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return 0}function yIe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return 0}function FIe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return 0}function OIe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return 0}function AIe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return 0}function MIe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return Uh(e|0,i|0)|0}function RIe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return 0}function NIe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return 0}function TIe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return 0}function LIe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return 0}function DIe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return 0}function CIe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return 0}function PIe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return 0}function BIe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return Zh(e|0,i|0,r|0)|0}function IIe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return 0}function HIe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return 0}function xIe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return 0}function UIe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return 0}function zIe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return 0}function jIe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return 0}function VIe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return 0}function qIe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return 0}function YIe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return 0}function GIe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return 0}function WIe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return 0}function KIe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return 0}function XIe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return 0}function ZIe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return _H(e|0,i|0,r|0)|0}function JIe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return 0}function QIe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return 0}function $Ie(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return ex(e|0,i|0)|0}function eHe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return ix(e|0,i|0,r|0,n|0,f|0)|0}function iHe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return rx(e|0,i|0,r|0,n|0,f|0,t|0,0)|0}function rHe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return 0}function nHe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return ux(e|0,i|0)|0}function fHe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return ax(e|0,i|0,r|0,n|0,f|0)|0}function tHe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return ox(e|0,i|0,r|0,n|0,f|0,t|0,0)|0}function uHe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return 0}function aHe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return 0}function oHe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return 0}function cHe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return 0}function lHe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return 0}function sHe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return 0}function bHe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return 0}function kHe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return 0}function hHe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return 0}function wHe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return PV(e|0,i|0,r|0,n|0)|0}function dHe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return Rq(e|0,i|0)|0}function vHe(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;return Kq(e|0,i|0,r|0)|0}function mHe(e){e=e|0;ue(8);return 0}function _He(e){e=e|0;return 0}function pHe(e){e=e|0;return Hm(e|0,0,0)|0}function EHe(e){e=e|0;return xm(e|0,0)|0}function SHe(e){e=e|0;return 0}function gHe(e){e=e|0;return 0}function yHe(e){e=e|0;return 0}function FHe(e){e=e|0;return 0}function OHe(e){e=e|0;return 0}function AHe(e){e=e|0;return 0}function MHe(e){e=e|0;return 0}function RHe(e){e=e|0;return 0}function NHe(e){e=e|0;return 0}function THe(e){e=e|0;return 0}function LHe(e){e=e|0;return 0}function DHe(e){e=e|0;return 0}function CHe(e){e=e|0;return 0}function PHe(e){e=e|0;return 0}function BHe(e){e=e|0;return 0}function IHe(e){e=e|0;return 0}function HHe(e){e=e|0;return 0}function xHe(e){e=e|0;return 0}function UHe(e){e=e|0;return r_(e|0,0)|0}function zHe(e){e=e|0;return 0}function jHe(e){e=e|0;return 0}function VHe(e){e=e|0;return 0}function qHe(e){e=e|0;return 0}function YHe(e){e=e|0;return oA(e|0,0,0)|0}function GHe(e){e=e|0;return 0}function WHe(e){e=e|0;return Jq(e|0,0)|0}function KHe(e){e=e|0;return 0}function XHe(e){e=e|0;return 0}function ZHe(e){e=e|0;return Dz(e|0,0,0)|0}function JHe(e){e=e|0;return Cz(e|0,0)|0}function QHe(e){e=e|0;return 0}function $He(e){e=e|0;return 0}function exe(e){e=e|0;return 0}function ixe(e){e=e|0;return 0}function rxe(e){e=e|0;return 0}function nxe(e){e=e|0;return 0}function fxe(e){e=e|0;return 0}function txe(e){e=e|0;return 0}function uxe(e){e=e|0;return 0}function axe(e){e=e|0;return 0}function oxe(e){e=e|0;return 0}function cxe(e){e=e|0;return 0}function lxe(e){e=e|0;return 0}function sxe(e){e=e|0;return 0}function bxe(e){e=e|0;return 0}function kxe(e){e=e|0;return 0}function hxe(e){e=e|0;return Pz(e|0,0)|0}function wxe(e){e=e|0;return 0}function dxe(e){e=e|0;return 0}function vxe(e){e=e|0;return 0}function mxe(e){e=e|0;return NY(e|0,0,0)|0}function _xe(e){e=e|0;return 0}function pxe(e){e=e|0;return cm(e|0,0)|0}function Exe(e){e=e|0;return aA(e|0,0,0)|0}function Sxe(e){e=e|0;return 0}function gxe(e){e=e|0;return 0}function yxe(e){e=e|0;return hm(e|0,0,0)|0}function Fxe(e){e=e|0;return xe(e|0,0,0)|0}function Oxe(e){e=e|0;return pm(e|0,0,0)|0}function Axe(e){e=e|0;return 0}function Mxe(e){e=e|0;return 0}function Rxe(e){e=e|0;return 0}function Nxe(e){e=e|0;return 0}function Txe(e){e=e|0;return 0}function Lxe(e){e=e|0;return 0}function Dxe(e){e=e|0;return Z_(e|0,0,0,0)|0}function Cxe(e){e=e|0;return J_(e|0,0,0,0)|0}function Pxe(e){e=e|0;return Q_(e|0,0,0,0)|0}function Bxe(e){e=e|0;return $_(e|0,0,0,0)|0}function Ixe(e){e=e|0;return ep(e|0,0,0,0)|0}function Hxe(e){e=e|0;return ip(e|0,0,0,0)|0}function xxe(e){e=e|0;return N_(e|0,0,0,0)|0}function Uxe(e){e=e|0;return T_(e|0,0,0,0)|0}function zxe(e){e=e|0;return rp(e|0,0,0,0)|0}function jxe(e){e=e|0;return np(e|0,0,0,0)|0}function Vxe(e){e=e|0;return dN(e|0,0,0,0)|0}function qxe(e){e=e|0;return 0}function Yxe(e){e=e|0;return 0}function Gxe(e){e=e|0;return 0}function Wxe(e){e=e|0;return FO()|0}function Kxe(e){e=e|0;return 0}function Xxe(e){e=e|0;return 0}function Zxe(e){e=e|0;return MO(e|0,0,0)|0}function Jxe(e){e=e|0;return bA(e|0,0,0)|0}function Qxe(e){e=e|0;return wA(e|0,0,0)|0}function $xe(e){e=e|0;return vA(e|0,0,0)|0}function eUe(e){e=e|0;return mA(e|0,0,0)|0}function iUe(e){e=e|0;return _A(e|0,0,0,0)|0}function rUe(e){e=e|0;return 0}function nUe(e){e=e|0;return 0}function fUe(e){e=e|0;return 0}function tUe(e){e=e|0;return 0}function uUe(e){e=e|0;return 0}function aUe(e){e=e|0;return 0}function oUe(e){e=e|0;return UR(e|0,0)|0}function cUe(e){e=e|0;return 0}function lUe(e){e=e|0;return 0}function sUe(e){e=e|0;return 0}function bUe(e){e=e|0;return 0}function kUe(e){e=e|0;return 0}function hUe(e){e=e|0;return 0}function wUe(e){e=e|0;return lN(e|0,0)|0}function dUe(e){e=e|0;return 0}function vUe(e){e=e|0;return 0}function mUe(e){e=e|0;return 0}function _Ue(e){e=e|0;return 0}function pUe(e){e=e|0;return 0}function EUe(e){e=e|0;return 0}function SUe(e){e=e|0;return 0}function gUe(e){e=e|0;return 0}function yUe(e){e=e|0;return 0}function FUe(e){e=e|0;return 0}function OUe(e){e=e|0;return 0}function AUe(e){e=e|0;return 0}function MUe(e){e=e|0;return 0}function RUe(e){e=e|0;return 0}function NUe(e){e=e|0;return 0}function TUe(e){e=e|0;return 0}function LUe(e){e=e|0;return 0}function DUe(e){e=e|0;return 0}function CUe(e){e=e|0;return 0}function PUe(e){e=e|0;return 0}function BUe(e){e=e|0;return 0}function IUe(e){e=e|0;return 0}function HUe(e){e=e|0;return 0}function xUe(e){e=e|0;return 0}function UUe(e){e=e|0;return 0}function zUe(e){e=e|0;return 0}function jUe(e){e=e|0;return 0}function VUe(e){e=e|0;return 0}function qUe(e){e=e|0;return 0}function YUe(e){e=e|0;return 0}function GUe(e){e=e|0;return Qu(e|0,0,0)|0}function WUe(e){e=e|0;return Pf(e|0,0)|0}function KUe(e){e=e|0;return Bf(e|0,0)|0}function XUe(e){e=e|0;return zf(e|0,0)|0}function ZUe(e){e=e|0;return $u(e|0,0,0)|0}function JUe(e){e=e|0;return ea(e|0,0)|0}function QUe(e){e=e|0;return Tf(e|0,0)|0}function $Ue(e){e=e|0;return Lf(e|0,0)|0}function eze(e){e=e|0;return Df(e|0,0)|0}function ize(e){e=e|0;return xf(e|0,0)|0}function rze(e){e=e|0;return If(e|0,0)|0}function nze(e){e=e|0;return Uf(e|0,0)|0}function fze(e){e=e|0;return Cf(e|0,0)|0}function tze(e){e=e|0;return ia(e|0,0)|0}function uze(e){e=e|0;return Hf(e|0,0)|0}function aze(e){e=e|0;return Nf(e|0,0)|0}function oze(e){e=e|0;return Cn(e|0,0)|0}function cze(e){e=e|0;return 0}function lze(e){e=e|0;return 0}function sze(e){e=e|0;return 0}function bze(e){e=e|0;return 0}function kze(e){e=e|0;return 0}function hze(e){e=e|0;return 0}function wze(e){e=e|0;return 0}function dze(e){e=e|0;return 0}function vze(e){e=e|0;return 0}function mze(e){e=e|0;return 0}function _ze(e){e=e|0;return 0}function pze(e){e=e|0;return wl(e|0,0,0)|0}function Eze(e){e=e|0;return Ll(e|0,0)|0}function Sze(e){e=e|0;return Bl(e|0,0)|0}function gze(e){e=e|0;return Hl(e|0,0)|0}function yze(e){e=e|0;return jl(e|0,0)|0}function Fze(e){e=e|0;return 0}function Oze(e){e=e|0;return 0}function Aze(e){e=e|0;return 0}function Mze(e){e=e|0;return 0}function Rze(e){e=e|0;return 0}function Nze(e){e=e|0;return 0}function Tze(e){e=e|0;return 0}function Lze(e){e=e|0;return Fh(e|0,0,0)|0}function Dze(e){e=e|0;return Oh(e|0,0)|0}function Cze(e){e=e|0;return 0}function Pze(e){e=e|0;return 0}function Bze(e){e=e|0;return 0}function Ize(e){e=e|0;return 0}function Hze(e){e=e|0;return 0}function xze(e){e=e|0;return 0}function Uze(e){e=e|0;return 0}function zze(e){e=e|0;return 0}function jze(e){e=e|0;return 0}function Vze(e){e=e|0;return 0}function qze(e){e=e|0;return 0}function Yze(e){e=e|0;return 0}function Gze(e){e=e|0;return 0}function Wze(e){e=e|0;return Uh(e|0,0)|0}function Kze(e){e=e|0;return 0}function Xze(e){e=e|0;return 0}function Zze(e){e=e|0;return 0}function Jze(e){e=e|0;return 0}function Qze(e){e=e|0;return 0}function $ze(e){e=e|0;return 0}function eje(e){e=e|0;return 0}function ije(e){e=e|0;return Zh(e|0,0,0)|0}function rje(e){e=e|0;return 0}function nje(e){e=e|0;return 0}function fje(e){e=e|0;return 0}function tje(e){e=e|0;return 0}function uje(e){e=e|0;return 0}function aje(e){e=e|0;return 0}function oje(e){e=e|0;return 0}function cje(e){e=e|0;return 0}function lje(e){e=e|0;return 0}function sje(e){e=e|0;return 0}function bje(e){e=e|0;return 0}function kje(e){e=e|0;return 0}function hje(e){e=e|0;return 0}function wje(e){e=e|0;return _H(e|0,0,0)|0}function dje(e){e=e|0;return 0}function vje(e){e=e|0;return 0}function mje(e){e=e|0;return ex(e|0,0)|0}function _je(e){e=e|0;return ix(e|0,0,0,0,0)|0}function pje(e){e=e|0;return rx(e|0,0,0,0,0,0,0)|0}function Eje(e){e=e|0;return nx(e|0,0,0,0,0,0)|0}function Sje(e){e=e|0;return 0}function gje(e){e=e|0;return ux(e|0,0)|0}function yje(e){e=e|0;return ax(e|0,0,0,0,0)|0}function Fje(e){e=e|0;return ox(e|0,0,0,0,0,0,0)|0}function Oje(e){e=e|0;return 0}function Aje(e){e=e|0;return 0}function Mje(e){e=e|0;return 0}function Rje(e){e=e|0;return 0}function Nje(e){e=e|0;return 0}function Tje(e){e=e|0;return 0}function Lje(e){e=e|0;return 0}function Dje(e){e=e|0;return 0}function Cje(e){e=e|0;return 0}function Pje(e){e=e|0;return PV(e|0,0,0,0)|0}function Bje(e){e=e|0;return Rq(e|0,0)|0}function Ije(e){e=e|0;return Kq(e|0,0,0)|0}function Hje(e,i,r){e=e|0;i=i|0;r=r|0;ue(9)}function xje(e,i,r){e=e|0;i=i|0;r=r|0;Cm(e|0,i|0,r|0,0)}function Uje(e,i,r){e=e|0;i=i|0;r=r|0;Pm(e|0)|0}function zje(e,i,r){e=e|0;i=i|0;r=r|0;Bm(e|0)|0}function jje(e,i,r){e=e|0;i=i|0;r=r|0;Im(e|0)|0}function Vje(e,i,r){e=e|0;i=i|0;r=r|0;Hm(e|0,i|0,r|0)|0}function qje(e,i,r){e=e|0;i=i|0;r=r|0;xm(e|0,i|0)|0}function Yje(e,i,r){e=e|0;i=i|0;r=r|0;Um(e|0,i|0,r|0,0,0,0)}function Gje(e,i,r){e=e|0;i=i|0;r=r|0;zm(e|0,i|0,r|0,0)}function Wje(e,i,r){e=e|0;i=i|0;r=r|0;jm(e|0,i|0,r|0,0,0,0,0)}function Kje(e,i,r){e=e|0;i=i|0;r=r|0;Vm(e|0,i|0,r|0,0)}function Xje(e,i,r){e=e|0;i=i|0;r=r|0;qm(e|0,i|0,r|0,0,0)}function Zje(e,i,r){e=e|0;i=i|0;r=r|0;Ym(e|0,i|0)}function Jje(e,i,r){e=e|0;i=i|0;r=r|0;Gm(e|0)}function Qje(e,i,r){e=e|0;i=i|0;r=r|0;Wm(e|0)}function $je(e,i,r){e=e|0;i=i|0;r=r|0;c_(e|0,i|0)}function eVe(e,i,r){e=e|0;i=i|0;r=r|0;Km(e|0,i|0)}function iVe(e,i,r){e=e|0;i=i|0;r=r|0;Qm(e|0,i|0)}function rVe(e,i,r){e=e|0;i=i|0;r=r|0;r_(e|0,i|0)|0}function nVe(e,i,r){e=e|0;i=i|0;r=r|0;f_(e|0,i|0,r|0,0)}function fVe(e,i,r){e=e|0;i=i|0;r=r|0;t_(e|0,i|0,r|0,0,0,0,0,0,0)}function tVe(e,i,r){e=e|0;i=i|0;r=r|0;u_(e|0,i|0,r|0,0)}function uVe(e,i,r){e=e|0;i=i|0;r=r|0;oA(e|0,i|0,r|0)|0}function aVe(e,i,r){e=e|0;i=i|0;r=r|0;Zq(e|0)}function oVe(e,i,r){e=e|0;i=i|0;r=r|0;Xq(e|0)|0}function cVe(e,i,r){e=e|0;i=i|0;r=r|0;Jq(e|0,i|0)|0}function lVe(e,i,r){e=e|0;i=i|0;r=r|0;Yl(e|0)|0}function sVe(e,i,r){e=e|0;i=i|0;r=r|0;Tz(e|0,i|0,r|0,0)}function bVe(e,i,r){e=e|0;i=i|0;r=r|0;Mz(e|0)|0}function kVe(e,i,r){e=e|0;i=i|0;r=r|0;Rz(e|0)|0}function hVe(e,i,r){e=e|0;i=i|0;r=r|0;Nz(e|0)|0}function wVe(e,i,r){e=e|0;i=i|0;r=r|0;Dz(e|0,i|0,r|0)|0}function dVe(e,i,r){e=e|0;i=i|0;r=r|0;Cz(e|0,i|0)|0}function vVe(e,i,r){e=e|0;i=i|0;r=r|0;Bz(e|0,i|0,r|0,0,0,0)}function mVe(e,i,r){e=e|0;i=i|0;r=r|0;xz(e|0,i|0,r|0,0)}function _Ve(e,i,r){e=e|0;i=i|0;r=r|0;Iz(e|0,i|0,r|0,0,0,0,0)}function pVe(e,i,r){e=e|0;i=i|0;r=r|0;Hz(e|0,i|0,r|0,0)}function EVe(e,i,r){e=e|0;i=i|0;r=r|0;Uz(e|0,i|0,r|0,0,0)}function SVe(e,i,r){e=e|0;i=i|0;r=r|0;zz(e|0,i|0)}function gVe(e,i,r){e=e|0;i=i|0;r=r|0;jz(e|0)}function yVe(e,i,r){e=e|0;i=i|0;r=r|0;Vz(e|0)}function FVe(e,i,r){e=e|0;i=i|0;r=r|0;Yz(e|0,i|0)}function OVe(e,i,r){e=e|0;i=i|0;r=r|0;Kz(e|0,i|0)}function AVe(e,i,r){e=e|0;i=i|0;r=r|0;Qz(e|0,i|0)}function MVe(e,i,r){e=e|0;i=i|0;r=r|0;Pz(e|0,i|0)|0}function RVe(e,i,r){e=e|0;i=i|0;r=r|0;Lz(e|0,i|0,r|0,0)}function NVe(e,i,r){e=e|0;i=i|0;r=r|0;yz(e|0)|0}function TVe(e,i,r){e=e|0;i=i|0;r=r|0;Fz(e|0)|0}function LVe(e,i,r){e=e|0;i=i|0;r=r|0;Oz(e|0)|0}function DVe(e,i,r){e=e|0;i=i|0;r=r|0;Az(e|0)|0}function CVe(e,i,r){e=e|0;i=i|0;r=r|0;OC(e|0)|0}function PVe(e,i,r){e=e|0;i=i|0;r=r|0;AC(e|0)|0}function BVe(e,i,r){e=e|0;i=i|0;r=r|0;MC(e|0)|0}function IVe(e,i,r){e=e|0;i=i|0;r=r|0;RC(e|0)|0}function HVe(e,i,r){e=e|0;i=i|0;r=r|0;NC(e|0)|0}function xVe(e,i,r){e=e|0;i=i|0;r=r|0;TC(e|0)|0}function UVe(e,i,r){e=e|0;i=i|0;r=r|0;LC(e|0)|0}function zVe(e,i,r){e=e|0;i=i|0;r=r|0;DC(e|0)|0}function jVe(e,i,r){e=e|0;i=i|0;r=r|0;CC(e|0)|0}function VVe(e,i,r){e=e|0;i=i|0;r=r|0;PC(e|0)|0}function qVe(e,i,r){e=e|0;i=i|0;r=r|0;BC(e|0)|0}function YVe(e,i,r){e=e|0;i=i|0;r=r|0;IC(e|0)|0}function GVe(e,i,r){e=e|0;i=i|0;r=r|0;HC(e|0)|0}function WVe(e,i,r){e=e|0;i=i|0;r=r|0;xC(e|0)|0}function KVe(e,i,r){e=e|0;i=i|0;r=r|0;UC(e|0)|0}function XVe(e,i,r){e=e|0;i=i|0;r=r|0;zC(e|0)|0}function ZVe(e,i,r){e=e|0;i=i|0;r=r|0;jC(e|0)|0}function JVe(e,i,r){e=e|0;i=i|0;r=r|0;VC(e|0)|0}function QVe(e,i,r){e=e|0;i=i|0;r=r|0;qC(e|0)|0}function $Ve(e,i,r){e=e|0;i=i|0;r=r|0;YC(e|0)|0}function eqe(e,i,r){e=e|0;i=i|0;r=r|0;GC(e|0)|0}function iqe(e,i,r){e=e|0;i=i|0;r=r|0;WC(e|0)|0}function rqe(e,i,r){e=e|0;i=i|0;r=r|0;KC(e|0)|0}function nqe(e,i,r){e=e|0;i=i|0;r=r|0;XC(e|0)|0}function fqe(e,i,r){e=e|0;i=i|0;r=r|0;ZC(e|0)|0}function tqe(e,i,r){e=e|0;i=i|0;r=r|0;JC(e|0)|0}function uqe(e,i,r){e=e|0;i=i|0;r=r|0;QC(e|0)|0}function aqe(e,i,r){e=e|0;i=i|0;r=r|0;$C(e|0)|0}function oqe(e,i,r){e=e|0;i=i|0;r=r|0;eP(e|0)|0}function cqe(e,i,r){e=e|0;i=i|0;r=r|0;iP(e|0)|0}function lqe(e,i,r){e=e|0;i=i|0;r=r|0;rP(e|0)|0}function sqe(e,i,r){e=e|0;i=i|0;r=r|0;nP(e|0)|0}function bqe(e,i,r){e=e|0;i=i|0;r=r|0;fP(e|0)|0}function kqe(e,i,r){e=e|0;i=i|0;r=r|0;tP(e|0)|0}function hqe(e,i,r){e=e|0;i=i|0;r=r|0;uP(e|0)|0}function wqe(e,i,r){e=e|0;i=i|0;r=r|0;aP(e|0)|0}function dqe(e,i,r){e=e|0;i=i|0;r=r|0;oP(e|0)|0}function vqe(e,i,r){e=e|0;i=i|0;r=r|0;cP(e|0)|0}function mqe(e,i,r){e=e|0;i=i|0;r=r|0;lP(e|0)|0}function _qe(e,i,r){e=e|0;i=i|0;r=r|0;sP(e|0)|0}function pqe(e,i,r){e=e|0;i=i|0;r=r|0;bP(e|0)|0}function Eqe(e,i,r){e=e|0;i=i|0;r=r|0;kP(e|0)|0}function Sqe(e,i,r){e=e|0;i=i|0;r=r|0;hP(e|0)|0}function gqe(e,i,r){e=e|0;i=i|0;r=r|0;wP(e|0)|0}function yqe(e,i,r){e=e|0;i=i|0;r=r|0;dP(e|0)|0}function Fqe(e,i,r){e=e|0;i=i|0;r=r|0;vP(e|0)|0}function Oqe(e,i,r){e=e|0;i=i|0;r=r|0;mP(e|0)|0}function Aqe(e,i,r){e=e|0;i=i|0;r=r|0;_P(e|0)|0}function Mqe(e,i,r){e=e|0;i=i|0;r=r|0;pP(e|0)|0}function Rqe(e,i,r){e=e|0;i=i|0;r=r|0;EP(e|0)|0}function Nqe(e,i,r){e=e|0;i=i|0;r=r|0;SP(e|0)|0}function Tqe(e,i,r){e=e|0;i=i|0;r=r|0;gP(e|0)|0}function Lqe(e,i,r){
	e=e|0;i=i|0;r=r|0;yP(e|0)|0}function Dqe(e,i,r){e=e|0;i=i|0;r=r|0;FP(e|0)|0}function Cqe(e,i,r){e=e|0;i=i|0;r=r|0;OP(e|0)|0}function Pqe(e,i,r){e=e|0;i=i|0;r=r|0;AP(e|0)|0}function Bqe(e,i,r){e=e|0;i=i|0;r=r|0;MP(e|0)|0}function Iqe(e,i,r){e=e|0;i=i|0;r=r|0;RP(e|0)|0}function Hqe(e,i,r){e=e|0;i=i|0;r=r|0;NP(e|0)|0}function xqe(e,i,r){e=e|0;i=i|0;r=r|0;TP(e|0)|0}function Uqe(e,i,r){e=e|0;i=i|0;r=r|0;LP(e|0)|0}function zqe(e,i,r){e=e|0;i=i|0;r=r|0;DP(e|0)|0}function jqe(e,i,r){e=e|0;i=i|0;r=r|0;CP(e|0)|0}function Vqe(e,i,r){e=e|0;i=i|0;r=r|0;PP(e|0)|0}function qqe(e,i,r){e=e|0;i=i|0;r=r|0;BP(e|0)|0}function Yqe(e,i,r){e=e|0;i=i|0;r=r|0;IP(e|0)|0}function Gqe(e,i,r){e=e|0;i=i|0;r=r|0;HP(e|0)|0}function Wqe(e,i,r){e=e|0;i=i|0;r=r|0;xP(e|0)|0}function Kqe(e,i,r){e=e|0;i=i|0;r=r|0;UP(e|0)|0}function Xqe(e,i,r){e=e|0;i=i|0;r=r|0;zP(e|0)|0}function Zqe(e,i,r){e=e|0;i=i|0;r=r|0;jP(e|0)|0}function Jqe(e,i,r){e=e|0;i=i|0;r=r|0;VP(e|0)|0}function Qqe(e,i,r){e=e|0;i=i|0;r=r|0;qP(e|0)|0}function $qe(e,i,r){e=e|0;i=i|0;r=r|0;YP(e|0)|0}function eYe(e,i,r){e=e|0;i=i|0;r=r|0;GP(e|0)|0}function iYe(e,i,r){e=e|0;i=i|0;r=r|0;WP(e|0)|0}function rYe(e,i,r){e=e|0;i=i|0;r=r|0;KP(e|0)|0}function nYe(e,i,r){e=e|0;i=i|0;r=r|0;XP(e|0)|0}function fYe(e,i,r){e=e|0;i=i|0;r=r|0;ZP(e|0)|0}function tYe(e,i,r){e=e|0;i=i|0;r=r|0;JP(e|0)|0}function uYe(e,i,r){e=e|0;i=i|0;r=r|0;QP(e|0)|0}function aYe(e,i,r){e=e|0;i=i|0;r=r|0;$P(e|0)|0}function oYe(e,i,r){e=e|0;i=i|0;r=r|0;eB(e|0)|0}function cYe(e,i,r){e=e|0;i=i|0;r=r|0;iB(e|0)|0}function lYe(e,i,r){e=e|0;i=i|0;r=r|0;rB(e|0)|0}function sYe(e,i,r){e=e|0;i=i|0;r=r|0;nB(e|0)|0}function bYe(e,i,r){e=e|0;i=i|0;r=r|0;fB(e|0)|0}function kYe(e,i,r){e=e|0;i=i|0;r=r|0;tB(e|0)|0}function hYe(e,i,r){e=e|0;i=i|0;r=r|0;uB(e|0)|0}function wYe(e,i,r){e=e|0;i=i|0;r=r|0;aB(e|0)|0}function dYe(e,i,r){e=e|0;i=i|0;r=r|0;oB(e|0)|0}function vYe(e,i,r){e=e|0;i=i|0;r=r|0;cB(e|0)|0}function mYe(e,i,r){e=e|0;i=i|0;r=r|0;lB(e|0)|0}function _Ye(e,i,r){e=e|0;i=i|0;r=r|0;sB(e|0)|0}function pYe(e,i,r){e=e|0;i=i|0;r=r|0;bB(e|0)|0}function EYe(e,i,r){e=e|0;i=i|0;r=r|0;kB(e|0)|0}function SYe(e,i,r){e=e|0;i=i|0;r=r|0;hB(e|0)|0}function gYe(e,i,r){e=e|0;i=i|0;r=r|0;wB(e|0)|0}function yYe(e,i,r){e=e|0;i=i|0;r=r|0;dB(e|0)|0}function FYe(e,i,r){e=e|0;i=i|0;r=r|0;vB(e|0)|0}function OYe(e,i,r){e=e|0;i=i|0;r=r|0;mB(e|0)|0}function AYe(e,i,r){e=e|0;i=i|0;r=r|0;_B(e|0)|0}function MYe(e,i,r){e=e|0;i=i|0;r=r|0;pB(e|0)|0}function RYe(e,i,r){e=e|0;i=i|0;r=r|0;EB(e|0)|0}function NYe(e,i,r){e=e|0;i=i|0;r=r|0;SB(e|0)|0}function TYe(e,i,r){e=e|0;i=i|0;r=r|0;gB(e|0)|0}function LYe(e,i,r){e=e|0;i=i|0;r=r|0;yB(e|0)|0}function DYe(e,i,r){e=e|0;i=i|0;r=r|0;FB(e|0)|0}function CYe(e,i,r){e=e|0;i=i|0;r=r|0;OB(e|0)|0}function PYe(e,i,r){e=e|0;i=i|0;r=r|0;AB(e|0)|0}function BYe(e,i,r){e=e|0;i=i|0;r=r|0;MB(e|0)|0}function IYe(e,i,r){e=e|0;i=i|0;r=r|0;RB(e|0)|0}function HYe(e,i,r){e=e|0;i=i|0;r=r|0;NB(e|0)|0}function xYe(e,i,r){e=e|0;i=i|0;r=r|0;TB(e|0)|0}function UYe(e,i,r){e=e|0;i=i|0;r=r|0;LB(e|0)|0}function zYe(e,i,r){e=e|0;i=i|0;r=r|0;DB(e|0)|0}function jYe(e,i,r){e=e|0;i=i|0;r=r|0;CB(e|0)|0}function VYe(e,i,r){e=e|0;i=i|0;r=r|0;PB(e|0)|0}function qYe(e,i,r){e=e|0;i=i|0;r=r|0;BB(e|0)|0}function YYe(e,i,r){e=e|0;i=i|0;r=r|0;IB(e|0)|0}function GYe(e,i,r){e=e|0;i=i|0;r=r|0;HB(e|0)|0}function WYe(e,i,r){e=e|0;i=i|0;r=r|0;xB(e|0)|0}function KYe(e,i,r){e=e|0;i=i|0;r=r|0;UB(e|0)|0}function XYe(e,i,r){e=e|0;i=i|0;r=r|0;zB(e|0)|0}function ZYe(e,i,r){e=e|0;i=i|0;r=r|0;jB(e|0)|0}function JYe(e,i,r){e=e|0;i=i|0;r=r|0;VB(e|0)|0}function QYe(e,i,r){e=e|0;i=i|0;r=r|0;qB(e|0)|0}function $Ye(e,i,r){e=e|0;i=i|0;r=r|0;YB(e|0)|0}function eGe(e,i,r){e=e|0;i=i|0;r=r|0;NY(e|0,i|0,r|0)|0}function iGe(e,i,r){e=e|0;i=i|0;r=r|0;am(e|0)}function rGe(e,i,r){e=e|0;i=i|0;r=r|0;om(e|0)|0}function nGe(e,i,r){e=e|0;i=i|0;r=r|0;cm(e|0,i|0)|0}function fGe(e,i,r){e=e|0;i=i|0;r=r|0;lm(e|0)|0}function tGe(e,i,r){e=e|0;i=i|0;r=r|0;aA(e|0,i|0,r|0)|0}function uGe(e,i,r){e=e|0;i=i|0;r=r|0;bm(e|0)}function aGe(e,i,r){e=e|0;i=i|0;r=r|0;km(e|0)}function oGe(e,i,r){e=e|0;i=i|0;r=r|0;hm(e|0,i|0,r|0)|0}function cGe(e,i,r){e=e|0;i=i|0;r=r|0;xe(e|0,i|0,r|0)|0}function lGe(e,i,r){e=e|0;i=i|0;r=r|0;pm(e|0,i|0,r|0)|0}function sGe(e,i,r){e=e|0;i=i|0;r=r|0;Em(e|0)}function bGe(e,i,r){e=e|0;i=i|0;r=r|0;Am(e|0)|0}function kGe(e,i,r){e=e|0;i=i|0;r=r|0;O_(e|0,i|0)}function hGe(e,i,r){e=e|0;i=i|0;r=r|0;A_(e|0)|0}function wGe(e,i,r){e=e|0;i=i|0;r=r|0;Z_(e|0,i|0,r|0,0)|0}function dGe(e,i,r){e=e|0;i=i|0;r=r|0;J_(e|0,i|0,r|0,0)|0}function vGe(e,i,r){e=e|0;i=i|0;r=r|0;Q_(e|0,i|0,r|0,0)|0}function mGe(e,i,r){e=e|0;i=i|0;r=r|0;$_(e|0,i|0,r|0,0)|0}function _Ge(e,i,r){e=e|0;i=i|0;r=r|0;ep(e|0,i|0,r|0,0)|0}function pGe(e,i,r){e=e|0;i=i|0;r=r|0;ip(e|0,i|0,r|0,0)|0}function EGe(e,i,r){e=e|0;i=i|0;r=r|0;N_(e|0,i|0,r|0,0)|0}function SGe(e,i,r){e=e|0;i=i|0;r=r|0;T_(e|0,i|0,r|0,0)|0}function gGe(e,i,r){e=e|0;i=i|0;r=r|0;rp(e|0,i|0,r|0,0)|0}function yGe(e,i,r){e=e|0;i=i|0;r=r|0;np(e|0,i|0,r|0,0)|0}function FGe(e,i,r){e=e|0;i=i|0;r=r|0;dN(e|0,i|0,r|0,0)|0}function OGe(e,i,r){e=e|0;i=i|0;r=r|0;LS(e|0)}function AGe(e,i,r){e=e|0;i=i|0;r=r|0;FO()|0}function MGe(e,i,r){e=e|0;i=i|0;r=r|0;Tg(e|0,i|0,r|0,0,0)}function RGe(e,i,r){e=e|0;i=i|0;r=r|0;_O(e|0,i|0,r|0,0,0)}function NGe(e,i,r){e=e|0;i=i|0;r=r|0;OO(e|0)|0}function TGe(e,i,r){e=e|0;i=i|0;r=r|0;AO(e|0)|0}function LGe(e,i,r){e=e|0;i=i|0;r=r|0;MO(e|0,i|0,r|0)|0}function DGe(e,i,r){e=e|0;i=i|0;r=r|0;RO(e|0)|0}function CGe(e,i,r){e=e|0;i=i|0;r=r|0;sA(e|0)|0}function PGe(e,i,r){e=e|0;i=i|0;r=r|0;bA(e|0,i|0,r|0)|0}function BGe(e,i,r){e=e|0;i=i|0;r=r|0;hA(e|0)|0}function IGe(e,i,r){e=e|0;i=i|0;r=r|0;wA(e|0,i|0,r|0)|0}function HGe(e,i,r){e=e|0;i=i|0;r=r|0;dA(e|0)|0}function xGe(e,i,r){e=e|0;i=i|0;r=r|0;vA(e|0,i|0,r|0)|0}function UGe(e,i,r){e=e|0;i=i|0;r=r|0;mA(e|0,i|0,r|0)|0}function zGe(e,i,r){e=e|0;i=i|0;r=r|0;_A(e|0,i|0,r|0,0)|0}function jGe(e,i,r){e=e|0;i=i|0;r=r|0;FR(e|0)}function VGe(e,i,r){e=e|0;i=i|0;r=r|0;OR(e|0)|0}function qGe(e,i,r){e=e|0;i=i|0;r=r|0;NR(e|0)}function YGe(e,i,r){e=e|0;i=i|0;r=r|0;DR(e|0)|0}function GGe(e,i,r){e=e|0;i=i|0;r=r|0;PR(e|0)}function WGe(e,i,r){e=e|0;i=i|0;r=r|0;BR(e|0)|0}function KGe(e,i,r){e=e|0;i=i|0;r=r|0;IR(e|0,i|0)}function XGe(e,i,r){e=e|0;i=i|0;r=r|0;HR(e|0)}function ZGe(e,i,r){e=e|0;i=i|0;r=r|0;xR(e|0)}function JGe(e,i,r){e=e|0;i=i|0;r=r|0;UR(e|0,i|0)|0}function QGe(e,i,r){e=e|0;i=i|0;r=r|0;zR(e|0)}function $Ge(e,i,r){e=e|0;i=i|0;r=r|0;lN(e|0,i|0)|0}function eWe(e,i,r){e=e|0;i=i|0;r=r|0;Xr(e|0,i|0)}function iWe(e,i,r){e=e|0;i=i|0;r=r|0;_n(e|0)}function rWe(e,i,r){e=e|0;i=i|0;r=r|0;tt(e|0,i|0)}function nWe(e,i,r){e=e|0;i=i|0;r=r|0;bt(e|0,i|0)}function fWe(e,i,r){e=e|0;i=i|0;r=r|0;Yf(e|0,i|0)}function tWe(e,i,r){e=e|0;i=i|0;r=r|0;Jf(e|0,i|0)}function uWe(e,i,r){e=e|0;i=i|0;r=r|0;Qf(e|0,i|0)}function aWe(e,i,r){e=e|0;i=i|0;r=r|0;Gf(e|0,i|0)}function oWe(e,i,r){e=e|0;i=i|0;r=r|0;ot(e|0,i|0)}function cWe(e,i,r){e=e|0;i=i|0;r=r|0;st(e|0,i|0)}function lWe(e,i,r){e=e|0;i=i|0;r=r|0;Vf(e|0,i|0)}function sWe(e,i,r){e=e|0;i=i|0;r=r|0;ct(e|0,i|0)}function bWe(e,i,r){e=e|0;i=i|0;r=r|0;Wf(e|0,i|0)}function kWe(e,i,r){e=e|0;i=i|0;r=r|0;ut(e|0,i|0)}function hWe(e,i,r){e=e|0;i=i|0;r=r|0;Yt(e|0,i|0)}function wWe(e,i,r){e=e|0;i=i|0;r=r|0;Kf(e|0,i|0)}function dWe(e,i,r){e=e|0;i=i|0;r=r|0;nt(e|0,i|0)}function vWe(e,i,r){e=e|0;i=i|0;r=r|0;gf(e|0,i|0)}function mWe(e,i,r){e=e|0;i=i|0;r=r|0;qf(e|0,i|0)}function _We(e,i,r){e=e|0;i=i|0;r=r|0;kt(e|0,i|0)}function pWe(e,i,r){e=e|0;i=i|0;r=r|0;Xf(e|0,i|0)}function EWe(e,i,r){e=e|0;i=i|0;r=r|0;Zf(e|0,i|0)}function SWe(e,i,r){e=e|0;i=i|0;r=r|0;$f(e|0,i|0)}function gWe(e,i,r){e=e|0;i=i|0;r=r|0;et(e|0,i|0)}function yWe(e,i,r){e=e|0;i=i|0;r=r|0;it(e|0,i|0)}function FWe(e,i,r){e=e|0;i=i|0;r=r|0;rt(e|0,i|0)}function OWe(e,i,r){e=e|0;i=i|0;r=r|0;lt(e|0,i|0)}function AWe(e,i,r){e=e|0;i=i|0;r=r|0;at(e|0,i|0)}function MWe(e,i,r){e=e|0;i=i|0;r=r|0;ft(e|0,i|0)}function RWe(e,i,r){e=e|0;i=i|0;r=r|0;Gt(e|0,i|0)}function NWe(e,i,r){e=e|0;i=i|0;r=r|0;Qu(e|0,i|0,r|0)|0}function TWe(e,i,r){e=e|0;i=i|0;r=r|0;Pf(e|0,i|0)|0}function LWe(e,i,r){e=e|0;i=i|0;r=r|0;Bf(e|0,i|0)|0}function DWe(e,i,r){e=e|0;i=i|0;r=r|0;zf(e|0,i|0)|0}function CWe(e,i,r){e=e|0;i=i|0;r=r|0;$u(e|0,i|0,r|0)|0}function PWe(e,i,r){e=e|0;i=i|0;r=r|0;ea(e|0,i|0)|0}function BWe(e,i,r){e=e|0;i=i|0;r=r|0;Tf(e|0,i|0)|0}function IWe(e,i,r){e=e|0;i=i|0;r=r|0;Lf(e|0,i|0)|0}function HWe(e,i,r){e=e|0;i=i|0;r=r|0;Df(e|0,i|0)|0}function xWe(e,i,r){e=e|0;i=i|0;r=r|0;xf(e|0,i|0)|0}function UWe(e,i,r){e=e|0;i=i|0;r=r|0;If(e|0,i|0)|0}function zWe(e,i,r){e=e|0;i=i|0;r=r|0;Uf(e|0,i|0)|0}function jWe(e,i,r){e=e|0;i=i|0;r=r|0;Cf(e|0,i|0)|0}function VWe(e,i,r){e=e|0;i=i|0;r=r|0;ia(e|0,i|0)|0}function qWe(e,i,r){e=e|0;i=i|0;r=r|0;Hf(e|0,i|0)|0}function YWe(e,i,r){e=e|0;i=i|0;r=r|0;Nf(e|0,i|0)|0}function GWe(e,i,r){e=e|0;i=i|0;r=r|0;Cn(e|0,i|0)|0}function WWe(e,i,r){e=e|0;i=i|0;r=r|0;za(e|0,i|0)}function KWe(e,i,r){e=e|0;i=i|0;r=r|0;Wa(e|0,i|0)}function XWe(e,i,r){e=e|0;i=i|0;r=r|0;Ka(e|0,i|0)}function ZWe(e,i,r){e=e|0;i=i|0;r=r|0;Xa(e|0,i|0)}function JWe(e,i,r){e=e|0;i=i|0;r=r|0;Za(e|0,i|0)}function QWe(e,i,r){e=e|0;i=i|0;r=r|0;Ja(e|0,i|0)}function $We(e,i,r){e=e|0;i=i|0;r=r|0;Qa(e|0,i|0)}function eKe(e,i,r){e=e|0;i=i|0;r=r|0;$a(e|0,i|0)}function iKe(e,i,r){e=e|0;i=i|0;r=r|0;vc(e|0)}function rKe(e,i,r){e=e|0;i=i|0;r=r|0;Rc(e|0)}function nKe(e,i,r){e=e|0;i=i|0;r=r|0;wl(e|0,i|0,r|0)|0}function fKe(e,i,r){e=e|0;i=i|0;r=r|0;Ll(e|0,i|0)|0}function tKe(e,i,r){e=e|0;i=i|0;r=r|0;Bl(e|0,i|0)|0}function uKe(e,i,r){e=e|0;i=i|0;r=r|0;Hl(e|0,i|0)|0}function aKe(e,i,r){e=e|0;i=i|0;r=r|0;jl(e|0,i|0)|0}function oKe(e,i,r){e=e|0;i=i|0;r=r|0;Xk(e|0)}function cKe(e,i,r){e=e|0;i=i|0;r=r|0;dh(e|0,i|0,r|0,0,0,0,0,0,0)}function lKe(e,i,r){e=e|0;i=i|0;r=r|0;vh(e|0,i|0,r|0,0)}function sKe(e,i,r){e=e|0;i=i|0;r=r|0;ph(e|0,i|0)}function bKe(e,i,r){e=e|0;i=i|0;r=r|0;Eh(e|0,i|0,r|0,0)}function kKe(e,i,r){e=e|0;i=i|0;r=r|0;Sh(e|0)|0}function hKe(e,i,r){e=e|0;i=i|0;r=r|0;gh(e|0)|0}function wKe(e,i,r){e=e|0;i=i|0;r=r|0;yh(e|0)|0}function dKe(e,i,r){e=e|0;i=i|0;r=r|0;Fh(e|0,i|0,r|0)|0}function vKe(e,i,r){e=e|0;i=i|0;r=r|0;Oh(e|0,i|0)|0}function mKe(e,i,r){e=e|0;i=i|0;r=r|0;Ah(e|0,i|0,r|0,0,0,0)}function _Ke(e,i,r){e=e|0;i=i|0;r=r|0;Mh(e|0,i|0,r|0,0)}function pKe(e,i,r){e=e|0;i=i|0;r=r|0;Rh(e|0,i|0,r|0,0,0,0,0)}function EKe(e,i,r){e=e|0;i=i|0;r=r|0;Nh(e|0,i|0,r|0,0)}function SKe(e,i,r){e=e|0;i=i|0;r=r|0;Th(e|0,i|0,r|0,0,0)}function gKe(e,i,r){e=e|0;i=i|0;r=r|0;Lh(e|0,i|0)}function yKe(e,i,r){e=e|0;i=i|0;r=r|0;Dh(e|0)}function FKe(e,i,r){e=e|0;i=i|0;r=r|0;Ch(e|0)}function OKe(e,i,r){e=e|0;i=i|0;r=r|0;Bh(e|0,i|0)}function AKe(e,i,r){e=e|0;i=i|0;r=r|0;Uh(e|0,i|0)|0}function MKe(e,i,r){e=e|0;i=i|0;r=r|0;zh(e|0,i|0,r|0,0)}function RKe(e,i,r){e=e|0;i=i|0;r=r|0;Yh(e|0,i|0)}function NKe(e,i,r){e=e|0;i=i|0;r=r|0;Gh(e|0,i|0,r|0,0,0,0,0,0,0)}function TKe(e,i,r){e=e|0;i=i|0;r=r|0;Wh(e|0,i|0,r|0,0)}function LKe(e,i,r){e=e|0;i=i|0;r=r|0;Zh(e|0,i|0,r|0)|0}function DKe(e,i,r){e=e|0;i=i|0;r=r|0;$h(e|0)}function CKe(e,i,r){e=e|0;i=i|0;r=r|0;td(e|0,i|0)}function PKe(e,i,r){e=e|0;i=i|0;r=r|0;qv(e|0,i|0,r|0,0)}function BKe(e,i,r){e=e|0;i=i|0;r=r|0;aT(e|0,i|0)}function IKe(e,i,r){e=e|0;i=i|0;r=r|0;Ok(e|0)}function HKe(e,i,r){e=e|0;i=i|0;r=r|0;lH(e|0,i|0)}function xKe(e,i,r){e=e|0;i=i|0;r=r|0;sH(e|0,i|0,r|0,0,0,0,0,0,0)}function UKe(e,i,r){e=e|0;i=i|0;r=r|0;bH(e|0,i|0,r|0,0)}function zKe(e,i,r){e=e|0;i=i|0;r=r|0;_H(e|0,i|0,r|0)|0}function jKe(e,i,r){e=e|0;i=i|0;r=r|0;mH(e|0,i|0)}function VKe(e,i,r){e=e|0;i=i|0;r=r|0;DH(e|0)}function qKe(e,i,r){e=e|0;i=i|0;r=r|0;ex(e|0,i|0)|0}function YKe(e,i,r){e=e|0;i=i|0;r=r|0;ix(e|0,i|0,r|0,0,0)|0}function GKe(e,i,r){e=e|0;i=i|0;r=r|0;rx(e|0,i|0,r|0,0,0,0,0)|0}function WKe(e,i,r){e=e|0;i=i|0;r=r|0;nx(e|0,i|0,r|0,0,0,0)|0}function KKe(e,i,r){e=e|0;i=i|0;r=r|0;fx(e|0,i|0)}function XKe(e,i,r){e=e|0;i=i|0;r=r|0;ux(e|0,i|0)|0}function ZKe(e,i,r){e=e|0;i=i|0;r=r|0;ax(e|0,i|0,r|0,0,0)|0}function JKe(e,i,r){e=e|0;i=i|0;r=r|0;ox(e|0,i|0,r|0,0,0,0,0)|0}function QKe(e,i,r){e=e|0;i=i|0;r=r|0;cx(e|0,i|0)}function $Ke(e,i,r){e=e|0;i=i|0;r=r|0;_x(e|0,i|0,r|0,0)}function eXe(e,i,r){e=e|0;i=i|0;r=r|0;GU(e|0,i|0,r|0,0)}function iXe(e,i,r){e=e|0;i=i|0;r=r|0;Gz(e|0,i|0,r|0,0,0,0,0,0,0)}function rXe(e,i,r){e=e|0;i=i|0;r=r|0;Wz(e|0,i|0,r|0,0)}function nXe(e,i,r){e=e|0;i=i|0;r=r|0;PV(e|0,i|0,r|0,0)|0}function fXe(e,i,r){e=e|0;i=i|0;r=r|0;Rq(e|0,i|0)|0}function tXe(e,i,r){e=e|0;i=i|0;r=r|0;Kq(e|0,i|0,r|0)|0}function uXe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;ue(10)}function aXe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;Cm(e|0,i|0,r|0,n|0)}function oXe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;Pm(e|0)|0}function cXe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;Bm(e|0)|0}function lXe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;Im(e|0)|0}function sXe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;Hm(e|0,i|0,r|0)|0}function bXe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;xm(e|0,i|0)|0}function kXe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;Um(e|0,i|0,r|0,n|0,f|0,t|0)}function hXe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;zm(e|0,i|0,r|0,n|0)}function wXe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;jm(e|0,i|0,r|0,n|0,f|0,t|0,u|0)}function dXe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;Vm(e|0,i|0,r|0,n|0)}function vXe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;qm(e|0,i|0,r|0,n|0,f|0)}function mXe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;Ym(e|0,i|0)}function _Xe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;Gm(e|0)}function pXe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;Wm(e|0)}function EXe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;o_(e|0,i|0,r|0)}function SXe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;c_(e|0,i|0)}function gXe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;Km(e|0,i|0)}function yXe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;Xm(e|0,i|0,r|0)}function FXe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;Zm(e|0,i|0,r|0)}function OXe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;Jm(e|0,i|0,r|0)}function AXe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;Qm(e|0,i|0)}function MXe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;$m(e|0,i|0,r|0)}function RXe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;e_(e|0,i|0,r|0)}function NXe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;i_(e|0,i|0,r|0)}function TXe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;r_(e|0,i|0)|0}function LXe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;n_(e|0,i|0,r|0)}function DXe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;f_(e|0,i|0,r|0,n|0)}function CXe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;u_(e|0,i|0,r|0,n|0)}function PXe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;oA(e|0,i|0,r|0)|0}function BXe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;Zq(e|0)}function IXe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;Xq(e|0)|0}function HXe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;Jq(e|0,i|0)|0}function xXe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;Yl(e|0)|0}function UXe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;tp(e|0,i|0,r|0)}function zXe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;Tz(e|0,i|0,r|0,n|0)}function jXe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;Mz(e|0)|0}function VXe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;Rz(e|0)|0}function qXe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;Nz(e|0)|0}function YXe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;Dz(e|0,i|0,r|0)|0}function GXe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;Cz(e|0,i|0)|0}function WXe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;Bz(e|0,i|0,r|0,n|0,f|0,t|0)}function KXe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;xz(e|0,i|0,r|0,n|0)}function XXe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;Iz(e|0,i|0,r|0,n|0,f|0,t|0,u|0)}function ZXe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;Hz(e|0,i|0,r|0,n|0)}function JXe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;Uz(e|0,i|0,r|0,n|0,f|0)}function QXe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;zz(e|0,i|0)}function $Xe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;jz(e|0)}function eZe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;Vz(e|0)}function iZe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;qz(e|0,i|0,r|0)}function rZe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;Yz(e|0,i|0)}function nZe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;Kz(e|0,i|0)}function fZe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;Xz(e|0,i|0,r|0)}function tZe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;Jz(e|0,i|0,r|0)}function uZe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;Qz(e|0,i|0)}function aZe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;kp(e|0,i|0,r|0)}function oZe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;bp(e|0,i|0,r|0)}function cZe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;Pz(e|0,i|0)|0}function lZe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;$z(e|0,i|0,r|0)}function sZe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;Lz(e|0,i|0,r|0,n|0)}function bZe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;yz(e|0)|0}function kZe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;Fz(e|0)|0}function hZe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;Oz(e|0)|0}function wZe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;Az(e|0)|0}function dZe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;Zz(e|0,i|0,r|0)}function vZe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;OC(e|0)|0}function mZe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;AC(e|0)|0}function _Ze(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;MC(e|0)|0}function pZe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;RC(e|0)|0}function EZe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;NC(e|0)|0}function SZe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;TC(e|0)|0}function gZe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;LC(e|0)|0}function yZe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;DC(e|0)|0}function FZe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;CC(e|0)|0}function OZe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;PC(e|0)|0}function AZe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;BC(e|0)|0}function MZe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;IC(e|0)|0}function RZe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;HC(e|0)|0}function NZe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;xC(e|0)|0}function TZe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;UC(e|0)|0}function LZe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;zC(e|0)|0}function DZe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;jC(e|0)|0}function CZe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;VC(e|0)|0}function PZe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;qC(e|0)|0}function BZe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;YC(e|0)|0}function IZe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;GC(e|0)|0}function HZe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;WC(e|0)|0}function xZe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;KC(e|0)|0}function UZe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;XC(e|0)|0}function zZe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;ZC(e|0)|0}function jZe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;JC(e|0)|0}function VZe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;QC(e|0)|0}function qZe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;$C(e|0)|0}function YZe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;eP(e|0)|0}function GZe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;iP(e|0)|0}function WZe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;rP(e|0)|0}function KZe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;nP(e|0)|0}function XZe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;fP(e|0)|0}function ZZe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;tP(e|0)|0}function JZe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;uP(e|0)|0}function QZe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;aP(e|0)|0}function $Ze(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;oP(e|0)|0}function eJe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;cP(e|0)|0}function iJe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;lP(e|0)|0}function rJe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;sP(e|0)|0}function nJe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;bP(e|0)|0}function fJe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;kP(e|0)|0}function tJe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;hP(e|0)|0}function uJe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;wP(e|0)|0}function aJe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;dP(e|0)|0}function oJe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;vP(e|0)|0}function cJe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;mP(e|0)|0}function lJe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;_P(e|0)|0}function sJe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;pP(e|0)|0}function bJe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;EP(e|0)|0}function kJe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;SP(e|0)|0}function hJe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;gP(e|0)|0}function wJe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;yP(e|0)|0}function dJe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;FP(e|0)|0}function vJe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;OP(e|0)|0}function mJe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;AP(e|0)|0}function _Je(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;MP(e|0)|0}function pJe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;RP(e|0)|0}function EJe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;NP(e|0)|0}function SJe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;TP(e|0)|0}function gJe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;LP(e|0)|0}function yJe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;DP(e|0)|0}function FJe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;CP(e|0)|0}function OJe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;PP(e|0)|0}function AJe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;BP(e|0)|0}function MJe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;IP(e|0)|0}function RJe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;HP(e|0)|0}function NJe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;xP(e|0)|0}function TJe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;UP(e|0)|0}function LJe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;zP(e|0)|0}function DJe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;jP(e|0)|0}function CJe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;VP(e|0)|0}function PJe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;qP(e|0)|0}function BJe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;YP(e|0)|0}function IJe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;GP(e|0)|0}function HJe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;WP(e|0)|0}function xJe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;KP(e|0)|0}function UJe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;XP(e|0)|0}function zJe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;ZP(e|0)|0}function jJe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;JP(e|0)|0}function VJe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;QP(e|0)|0}function qJe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;$P(e|0)|0}function YJe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;eB(e|0)|0}function GJe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;iB(e|0)|0}function WJe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;rB(e|0)|0}function KJe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;nB(e|0)|0}function XJe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;fB(e|0)|0}function ZJe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;tB(e|0)|0}function JJe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;uB(e|0)|0}function QJe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;aB(e|0)|0}function $Je(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;oB(e|0)|0}function eQe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;cB(e|0)|0}function iQe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;lB(e|0)|0}function rQe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;sB(e|0)|0}function nQe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;bB(e|0)|0}function fQe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;kB(e|0)|0}function tQe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;hB(e|0)|0}function uQe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;wB(e|0)|0}function aQe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;dB(e|0)|0}function oQe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;vB(e|0)|0}function cQe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;mB(e|0)|0}function lQe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;_B(e|0)|0}function sQe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;pB(e|0)|0}function bQe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;EB(e|0)|0}function kQe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;SB(e|0)|0}function hQe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;gB(e|0)|0}function wQe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;yB(e|0)|0}function dQe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;FB(e|0)|0}function vQe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;OB(e|0)|0}function mQe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;AB(e|0)|0}function _Qe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;MB(e|0)|0}function pQe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;RB(e|0)|0}function EQe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;NB(e|0)|0}function SQe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;TB(e|0)|0}function gQe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;LB(e|0)|0}function yQe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;DB(e|0)|0}function FQe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;CB(e|0)|0}function OQe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;PB(e|0)|0}function AQe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;BB(e|0)|0}function MQe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;IB(e|0)|0}function RQe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;HB(e|0)|0}function NQe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;xB(e|0)|0}function TQe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;UB(e|0)|0}function LQe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;zB(e|0)|0}function DQe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;jB(e|0)|0}function CQe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;VB(e|0)|0}function PQe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;qB(e|0)|0}function BQe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;YB(e|0)|0}function IQe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;NY(e|0,i|0,r|0)|0}function HQe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;am(e|0)}function xQe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;om(e|0)|0}function UQe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;cm(e|0,i|0)|0}function zQe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;lm(e|0)|0}function jQe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;aA(e|0,i|0,r|0)|0}function VQe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;bm(e|0)}function qQe(e,i,r,n,f,t,u,a,o){e=e|0;
	i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;km(e|0)}function YQe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;hm(e|0,i|0,r|0)|0}function GQe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;xe(e|0,i|0,r|0)|0}function WQe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;pm(e|0,i|0,r|0)|0}function KQe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;Em(e|0)}function XQe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;Sm(e|0,i|0,r|0)}function ZQe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;gm(e|0,i|0,r|0)}function JQe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;ym(e|0,i|0,r|0)}function QQe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;Fm(e|0,i|0,r|0)}function $Qe(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;Am(e|0)|0}function e$e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;O_(e|0,i|0)}function i$e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;A_(e|0)|0}function r$e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;Z_(e|0,i|0,r|0,n|0)|0}function n$e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;J_(e|0,i|0,r|0,n|0)|0}function f$e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;Q_(e|0,i|0,r|0,n|0)|0}function t$e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;$_(e|0,i|0,r|0,n|0)|0}function u$e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;ep(e|0,i|0,r|0,n|0)|0}function a$e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;ip(e|0,i|0,r|0,n|0)|0}function o$e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;N_(e|0,i|0,r|0,n|0)|0}function c$e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;T_(e|0,i|0,r|0,n|0)|0}function l$e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;rp(e|0,i|0,r|0,n|0)|0}function s$e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;np(e|0,i|0,r|0,n|0)|0}function b$e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;dN(e|0,i|0,r|0,n|0)|0}function k$e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;hp(e|0,i|0,r|0)}function h$e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;wp(e|0,i|0,r|0)}function w$e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;LS(e|0)}function d$e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;FO()|0}function v$e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;Tg(e|0,i|0,r|0,n|0,f|0)}function m$e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;_O(e|0,i|0,r|0,n|0,f|0)}function _$e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;OO(e|0)|0}function p$e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;AO(e|0)|0}function E$e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;MO(e|0,i|0,r|0)|0}function S$e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;RO(e|0)|0}function g$e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;sA(e|0)|0}function y$e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;bA(e|0,i|0,r|0)|0}function F$e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;hA(e|0)|0}function O$e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;wA(e|0,i|0,r|0)|0}function A$e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;dA(e|0)|0}function M$e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;vA(e|0,i|0,r|0)|0}function R$e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;mA(e|0,i|0,r|0)|0}function N$e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;_A(e|0,i|0,r|0,n|0)|0}function T$e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;FR(e|0)}function L$e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;OR(e|0)|0}function D$e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;NR(e|0)}function C$e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;DR(e|0)|0}function P$e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;PR(e|0)}function B$e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;BR(e|0)|0}function I$e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;IR(e|0,i|0)}function H$e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;HR(e|0)}function x$e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;xR(e|0)}function U$e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;UR(e|0,i|0)|0}function z$e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;zR(e|0)}function j$e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;GR(e|0,i|0,r|0)}function V$e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;iN(e|0,i|0,r|0)}function q$e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;rN(e|0,i|0,r|0)}function Y$e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;nN(e|0,i|0,r|0)}function G$e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;fN(e|0,i|0,r|0)}function W$e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;lN(e|0,i|0)|0}function K$e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;Xr(e|0,i|0)}function X$e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;_n(e|0)}function Z$e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;tt(e|0,i|0)}function J$e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;bt(e|0,i|0)}function Q$e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;Yf(e|0,i|0)}function $$e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;Jf(e|0,i|0)}function e0e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;Qf(e|0,i|0)}function i0e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;Gf(e|0,i|0)}function r0e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;ot(e|0,i|0)}function n0e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;st(e|0,i|0)}function f0e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;Vf(e|0,i|0)}function t0e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;ct(e|0,i|0)}function u0e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;Wf(e|0,i|0)}function a0e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;ut(e|0,i|0)}function o0e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;Yt(e|0,i|0)}function c0e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;Kf(e|0,i|0)}function l0e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;nt(e|0,i|0)}function s0e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;gf(e|0,i|0)}function b0e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;qf(e|0,i|0)}function k0e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;kt(e|0,i|0)}function h0e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;Xf(e|0,i|0)}function w0e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;Zf(e|0,i|0)}function d0e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;$f(e|0,i|0)}function v0e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;et(e|0,i|0)}function m0e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;it(e|0,i|0)}function _0e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;rt(e|0,i|0)}function p0e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;lt(e|0,i|0)}function E0e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;at(e|0,i|0)}function S0e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;ft(e|0,i|0)}function g0e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;Gt(e|0,i|0)}function y0e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;Qu(e|0,i|0,r|0)|0}function F0e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;Pf(e|0,i|0)|0}function O0e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;Bf(e|0,i|0)|0}function A0e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;zf(e|0,i|0)|0}function M0e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;$u(e|0,i|0,r|0)|0}function R0e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;ea(e|0,i|0)|0}function N0e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;Tf(e|0,i|0)|0}function T0e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;Lf(e|0,i|0)|0}function L0e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;Df(e|0,i|0)|0}function D0e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;xf(e|0,i|0)|0}function C0e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;If(e|0,i|0)|0}function P0e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;Uf(e|0,i|0)|0}function B0e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;Cf(e|0,i|0)|0}function I0e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;ia(e|0,i|0)|0}function H0e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;Hf(e|0,i|0)|0}function x0e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;Nf(e|0,i|0)|0}function U0e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;Cn(e|0,i|0)|0}function z0e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;za(e|0,i|0)}function j0e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;Wa(e|0,i|0)}function V0e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;Ka(e|0,i|0)}function q0e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;Xa(e|0,i|0)}function Y0e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;Za(e|0,i|0)}function G0e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;Ja(e|0,i|0)}function W0e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;Qa(e|0,i|0)}function K0e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;$a(e|0,i|0)}function X0e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;Qo(e|0,i|0,r|0)}function Z0e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;vc(e|0)}function J0e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;Rc(e|0)}function Q0e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;wl(e|0,i|0,r|0)|0}function $0e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;Ll(e|0,i|0)|0}function e1e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;Bl(e|0,i|0)|0}function i1e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;Hl(e|0,i|0)|0}function r1e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;jl(e|0,i|0)|0}function n1e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;Xk(e|0)}function f1e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;vh(e|0,i|0,r|0,n|0)}function t1e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;mh(e|0,i|0,r|0)}function u1e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;_h(e|0,i|0,r|0)}function a1e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;ph(e|0,i|0)}function o1e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;Eh(e|0,i|0,r|0,n|0)}function c1e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;Sh(e|0)|0}function l1e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;gh(e|0)|0}function s1e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;yh(e|0)|0}function b1e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;Fh(e|0,i|0,r|0)|0}function k1e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;Oh(e|0,i|0)|0}function h1e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;Ah(e|0,i|0,r|0,n|0,f|0,t|0)}function w1e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;Mh(e|0,i|0,r|0,n|0)}function d1e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;Rh(e|0,i|0,r|0,n|0,f|0,t|0,u|0)}function v1e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;Nh(e|0,i|0,r|0,n|0)}function m1e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;Th(e|0,i|0,r|0,n|0,f|0)}function _1e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;Lh(e|0,i|0)}function p1e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;Dh(e|0)}function E1e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;Ch(e|0)}function S1e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;Ph(e|0,i|0,r|0)}function g1e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;Bh(e|0,i|0)}function y1e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;Ih(e|0,i|0,r|0)}function F1e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;Hh(e|0,i|0,r|0)}function O1e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;xh(e|0,i|0,r|0)}function A1e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;Uh(e|0,i|0)|0}function M1e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;zh(e|0,i|0,r|0,n|0)}function R1e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;jh(e|0,i|0,r|0)}function N1e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;Vh(e|0,i|0,r|0)}function T1e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;qh(e|0,i|0,r|0)}function L1e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;Yh(e|0,i|0)}function D1e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;Wh(e|0,i|0,r|0,n|0)}function C1e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;Zh(e|0,i|0,r|0)|0}function P1e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;$h(e|0)}function B1e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;td(e|0,i|0)}function I1e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;qv(e|0,i|0,r|0,n|0)}function H1e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;aT(e|0,i|0)}function x1e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;Ok(e|0)}function U1e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;cH(e|0,i|0,r|0)}function z1e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;lH(e|0,i|0)}function j1e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;bH(e|0,i|0,r|0,n|0)}function V1e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;kH(e|0,i|0,r|0)}function q1e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;hH(e|0,i|0,r|0)}function Y1e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;dH(e|0,i|0,r|0)}function G1e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;vH(e|0,i|0,r|0)}function W1e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;_H(e|0,i|0,r|0)|0}function K1e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;mH(e|0,i|0)}function X1e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;DH(e|0)}function Z1e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;ex(e|0,i|0)|0}function J1e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;ix(e|0,i|0,r|0,n|0,f|0)|0}function Q1e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;rx(e|0,i|0,r|0,n|0,f|0,t|0,u|0)|0}function $1e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;nx(e|0,i|0,r|0,n|0,f|0,t|0)|0}function e2e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;fx(e|0,i|0)}function i2e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;ux(e|0,i|0)|0}function r2e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;ax(e|0,i|0,r|0,n|0,f|0)|0}function n2e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;ox(e|0,i|0,r|0,n|0,f|0,t|0,u|0)|0}function f2e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;cx(e|0,i|0)}function t2e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;wx(e|0,i|0,r|0)}function u2e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;_x(e|0,i|0,r|0,n|0)}function a2e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;oU(e|0,i|0,r|0)}function o2e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;cU(e|0,i|0,r|0)}function c2e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;GU(e|0,i|0,r|0,n|0)}function l2e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;tz(e|0,i|0,r|0)}function s2e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;Wz(e|0,i|0,r|0,n|0)}function b2e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;PV(e|0,i|0,r|0,n|0)|0}function k2e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;Rq(e|0,i|0)|0}function h2e(e,i,r,n,f,t,u,a,o){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u=u|0;a=a|0;o=o|0;Kq(e|0,i|0,r|0)|0}function w2e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;ue(11);return 0}function d2e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return 0}function v2e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return Pm(e|0)|0}function m2e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return Bm(e|0)|0}function _2e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return Im(e|0)|0}function p2e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return Hm(e|0,i|0,r|0)|0}function E2e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return xm(e|0,i|0)|0}function S2e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return 0}function g2e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return 0}function y2e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return 0}function F2e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return 0}function O2e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return 0}function A2e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return 0}function M2e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return 0}function R2e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return 0}function N2e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return 0}function T2e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return 0}function L2e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return 0}function D2e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return 0}function C2e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return 0}function P2e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return 0}function B2e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return 0}function I2e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return 0}function H2e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return 0}function x2e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return 0}function U2e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return r_(e|0,i|0)|0}function z2e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return 0}function j2e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return 0}function V2e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return 0}function q2e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return 0}function Y2e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return oA(e|0,i|0,r|0)|0}function G2e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return 0}function W2e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return Xq(e|0)|0}function K2e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return Jq(e|0,i|0)|0}function X2e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return Yl(e|0)|0}function Z2e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return 0}function J2e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return 0}function Q2e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return Mz(e|0)|0}function $2e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return Rz(e|0)|0}function e3e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return Nz(e|0)|0}function i3e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return Dz(e|0,i|0,r|0)|0}function r3e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return Cz(e|0,i|0)|0}function n3e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return 0}function f3e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return 0}function t3e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return 0}function u3e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return 0}function a3e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return 0}function o3e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return 0}function c3e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return 0}function l3e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return 0}function s3e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return 0}function b3e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return 0}function k3e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return 0}function h3e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return 0}function w3e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return 0}function d3e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return 0}function v3e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return 0}function m3e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return 0}function _3e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return Pz(e|0,i|0)|0}function p3e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return 0}function E3e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return 0}function S3e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return yz(e|0)|0}function g3e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return Fz(e|0)|0}function y3e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return Oz(e|0)|0}function F3e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return Az(e|0)|0}function O3e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return 0}function A3e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return OC(e|0)|0}function M3e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return AC(e|0)|0}function R3e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return MC(e|0)|0}function N3e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return RC(e|0)|0}function T3e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return NC(e|0)|0}function L3e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return TC(e|0)|0}function D3e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return LC(e|0)|0}function C3e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return DC(e|0)|0}function P3e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return CC(e|0)|0}function B3e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return PC(e|0)|0}function I3e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return BC(e|0)|0}function H3e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return IC(e|0)|0}function x3e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return HC(e|0)|0}function U3e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return xC(e|0)|0}function z3e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return UC(e|0)|0}function j3e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return zC(e|0)|0}function V3e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return jC(e|0)|0}function q3e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return VC(e|0)|0}function Y3e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return qC(e|0)|0}function G3e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return YC(e|0)|0}function W3e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return GC(e|0)|0}function K3e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return WC(e|0)|0}function X3e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return KC(e|0)|0}function Z3e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return XC(e|0)|0}function J3e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return ZC(e|0)|0}function Q3e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return JC(e|0)|0}function $3e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return QC(e|0)|0}function e4e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return $C(e|0)|0}function i4e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return eP(e|0)|0}function r4e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return iP(e|0)|0}function n4e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return rP(e|0)|0}function f4e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return nP(e|0)|0}function t4e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return fP(e|0)|0}function u4e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return tP(e|0)|0}function a4e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return uP(e|0)|0}function o4e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return aP(e|0)|0}function c4e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return oP(e|0)|0}function l4e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return cP(e|0)|0}function s4e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return lP(e|0)|0}function b4e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return sP(e|0)|0}function k4e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return bP(e|0)|0}function h4e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return kP(e|0)|0}function w4e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return hP(e|0)|0}function d4e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return wP(e|0)|0}function v4e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return dP(e|0)|0}function m4e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return vP(e|0)|0}function _4e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return mP(e|0)|0}function p4e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return _P(e|0)|0}function E4e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return pP(e|0)|0}function S4e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return EP(e|0)|0}function g4e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return SP(e|0)|0}function y4e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return gP(e|0)|0}function F4e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return yP(e|0)|0}function O4e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return FP(e|0)|0}function A4e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return OP(e|0)|0}function M4e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return AP(e|0)|0}function R4e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return MP(e|0)|0}function N4e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return RP(e|0)|0}function T4e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return NP(e|0)|0}function L4e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return TP(e|0)|0}function D4e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return LP(e|0)|0}function C4e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return DP(e|0)|0}function P4e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return CP(e|0)|0}function B4e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return PP(e|0)|0}function I4e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return BP(e|0)|0}function H4e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return IP(e|0)|0}function x4e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return HP(e|0)|0}function U4e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return xP(e|0)|0}function z4e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return UP(e|0)|0}function j4e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return zP(e|0)|0}function V4e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return jP(e|0)|0}function q4e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return VP(e|0)|0}function Y4e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return qP(e|0)|0}function G4e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return YP(e|0)|0}function W4e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return GP(e|0)|0}function K4e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return WP(e|0)|0}function X4e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return KP(e|0)|0}function Z4e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return XP(e|0)|0}function J4e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return ZP(e|0)|0}function Q4e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return JP(e|0)|0}function $4e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return QP(e|0)|0}function e8e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return $P(e|0)|0}function i8e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return eB(e|0)|0}function r8e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return iB(e|0)|0}function n8e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return rB(e|0)|0}function f8e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return nB(e|0)|0}function t8e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return fB(e|0)|0}function u8e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return tB(e|0)|0}function a8e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return uB(e|0)|0}function o8e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return aB(e|0)|0}function c8e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return oB(e|0)|0}function l8e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return cB(e|0)|0}function s8e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return lB(e|0)|0}function b8e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return sB(e|0)|0}function k8e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return bB(e|0)|0}function h8e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return kB(e|0)|0}function w8e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return hB(e|0)|0}function d8e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return wB(e|0)|0}function v8e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return dB(e|0)|0}function m8e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return vB(e|0)|0}function _8e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return mB(e|0)|0}function p8e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return _B(e|0)|0}function E8e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return pB(e|0)|0}function S8e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return EB(e|0)|0}function g8e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return SB(e|0)|0}function y8e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return gB(e|0)|0}function F8e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return yB(e|0)|0}function O8e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return FB(e|0)|0}function A8e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return OB(e|0)|0}function M8e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return AB(e|0)|0}function R8e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return MB(e|0)|0}function N8e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return RB(e|0)|0}function T8e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return NB(e|0)|0}function L8e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return TB(e|0)|0}function D8e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return LB(e|0)|0}function C8e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return DB(e|0)|0}function P8e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return CB(e|0)|0}function B8e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return PB(e|0)|0}function I8e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return BB(e|0)|0}function H8e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return IB(e|0)|0}function x8e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return HB(e|0)|0}function U8e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return xB(e|0)|0}function z8e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return UB(e|0)|0}function j8e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return zB(e|0)|0}function V8e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return jB(e|0)|0}function q8e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return VB(e|0)|0}function Y8e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return qB(e|0)|0}function G8e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return YB(e|0)|0}function W8e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return NY(e|0,i|0,r|0)|0}function K8e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return 0}function X8e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return om(e|0)|0}function Z8e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return cm(e|0,i|0)|0}function J8e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return lm(e|0)|0}function Q8e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return aA(e|0,i|0,r|0)|0}function $8e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return 0}function e6e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return 0}function i6e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return hm(e|0,i|0,r|0)|0}function r6e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return xe(e|0,i|0,r|0)|0}function n6e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return pm(e|0,i|0,r|0)|0}function f6e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return 0}function t6e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return 0}function u6e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return 0}function a6e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return 0}function o6e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return 0}function c6e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return Am(e|0)|0}function l6e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return 0}function s6e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return A_(e|0)|0}function b6e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return 0}function k6e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return 0;
	}function h6e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return 0}function w6e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return FO()|0}function d6e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return 0}function v6e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return 0}function m6e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return OO(e|0)|0}function _6e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return AO(e|0)|0}function p6e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return MO(e|0,i|0,r|0)|0}function E6e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return RO(e|0)|0}function S6e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return sA(e|0)|0}function g6e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return bA(e|0,i|0,r|0)|0}function y6e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return hA(e|0)|0}function F6e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return wA(e|0,i|0,r|0)|0}function O6e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return dA(e|0)|0}function A6e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return vA(e|0,i|0,r|0)|0}function M6e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return mA(e|0,i|0,r|0)|0}function R6e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return 0}function N6e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return OR(e|0)|0}function T6e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return 0}function L6e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return DR(e|0)|0}function D6e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return 0}function C6e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return BR(e|0)|0}function P6e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return 0}function B6e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return 0}function I6e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return 0}function H6e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return UR(e|0,i|0)|0}function x6e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return 0}function U6e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return 0}function z6e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return 0}function j6e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return 0}function V6e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return 0}function q6e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return 0}function Y6e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return lN(e|0,i|0)|0}function G6e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return 0}function W6e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return 0}function K6e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return 0}function X6e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return 0}function Z6e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return 0}function J6e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return 0}function Q6e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return 0}function $6e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return 0}function e5e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return 0}function i5e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return 0}function r5e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return 0}function n5e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return 0}function f5e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return 0}function t5e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return 0}function u5e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return 0}function a5e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return 0}function o5e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return 0}function c5e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return 0}function l5e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return 0}function s5e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return 0}function b5e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return 0}function k5e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return 0}function h5e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return 0}function w5e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return 0}function d5e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return 0}function v5e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return 0}function m5e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return 0}function _5e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return 0}function p5e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return 0}function E5e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return 0}function S5e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return Qu(e|0,i|0,r|0)|0}function g5e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return Pf(e|0,i|0)|0}function y5e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return Bf(e|0,i|0)|0}function F5e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return zf(e|0,i|0)|0}function O5e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return $u(e|0,i|0,r|0)|0}function A5e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return ea(e|0,i|0)|0}function M5e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return Tf(e|0,i|0)|0}function R5e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return Lf(e|0,i|0)|0}function N5e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return Df(e|0,i|0)|0}function T5e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return xf(e|0,i|0)|0}function L5e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return If(e|0,i|0)|0}function D5e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return Uf(e|0,i|0)|0}function C5e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return Cf(e|0,i|0)|0}function P5e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return ia(e|0,i|0)|0}function B5e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return Hf(e|0,i|0)|0}function I5e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return Nf(e|0,i|0)|0}function H5e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return Cn(e|0,i|0)|0}function x5e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return 0}function U5e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return 0}function z5e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return 0}function j5e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return 0}function V5e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return 0}function q5e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return 0}function Y5e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return 0}function G5e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return 0}function W5e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return 0}function K5e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return 0}function X5e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return 0}function Z5e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return wl(e|0,i|0,r|0)|0}function J5e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return Ll(e|0,i|0)|0}function Q5e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return Bl(e|0,i|0)|0}function $5e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return Hl(e|0,i|0)|0}function e9e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return jl(e|0,i|0)|0}function i9e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return 0}function r9e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return 0}function n9e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return 0}function f9e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return 0}function t9e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return 0}function u9e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return 0}function a9e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return 0}function o9e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return Sh(e|0)|0}function c9e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return gh(e|0)|0}function l9e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return yh(e|0)|0}function s9e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return Fh(e|0,i|0,r|0)|0}function b9e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return Oh(e|0,i|0)|0}function k9e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return 0}function h9e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return 0}function w9e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return 0}function d9e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return 0}function v9e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return 0}function m9e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return 0}function _9e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return 0}function p9e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return 0}function E9e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return 0}function S9e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return 0}function g9e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return 0}function y9e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return 0}function F9e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return 0}function O9e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return Uh(e|0,i|0)|0}function A9e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return 0}function M9e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return 0}function R9e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return 0}function N9e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return 0}function T9e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return 0}function L9e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return 0}function D9e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return 0}function C9e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return Zh(e|0,i|0,r|0)|0}function P9e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return 0}function B9e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return 0}function I9e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return 0}function H9e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return 0}function x9e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return 0}function U9e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return 0}function z9e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return 0}function j9e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return 0}function V9e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return 0}function q9e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return 0}function Y9e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return 0}function G9e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return 0}function W9e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return 0}function K9e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return _H(e|0,i|0,r|0)|0}function X9e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return 0}function Z9e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return 0}function J9e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return ex(e|0,i|0)|0}function Q9e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return ix(e|0,i|0,r|0,n|0,0)|0}function $9e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return rx(e|0,i|0,r|0,n|0,0,0,0)|0}function e7e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return nx(e|0,i|0,r|0,n|0,0,0)|0}function i7e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return 0}function r7e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return ux(e|0,i|0)|0}function n7e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return ax(e|0,i|0,r|0,n|0,0)|0}function f7e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return ox(e|0,i|0,r|0,n|0,0,0,0)|0}function t7e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return 0}function u7e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return 0}function a7e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return 0}function o7e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return 0}function c7e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return 0}function l7e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return 0}function s7e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return 0}function b7e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return 0}function k7e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return 0}function h7e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return Rq(e|0,i|0)|0}function w7e(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;return Kq(e|0,i|0,r|0)|0}function d7e(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;ue(12)}function v7e(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;Cm(e|0,i|0,r|0,n|0)}function m7e(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;Pm(e|0)|0}function _7e(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;Bm(e|0)|0}function p7e(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;Im(e|0)|0}function E7e(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;Hm(e|0,i|0,r|0)|0}function S7e(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;xm(e|0,i|0)|0}function g7e(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;zm(e|0,i|0,r|0,n|0)}function y7e(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;jm(e|0,i|0,r|0,n|0,f|0,t|0,0)}function F7e(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;Vm(e|0,i|0,r|0,n|0)}function O7e(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;qm(e|0,i|0,r|0,n|0,f|0)}function A7e(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;Ym(e|0,i|0)}function M7e(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;Gm(e|0)}function R7e(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;Wm(e|0)}function N7e(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;o_(e|0,i|0,r|0)}function T7e(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;c_(e|0,i|0)}function L7e(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;Km(e|0,i|0)}function D7e(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;Xm(e|0,i|0,r|0)}function C7e(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;Zm(e|0,i|0,r|0)}function P7e(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;Jm(e|0,i|0,r|0)}function B7e(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;Qm(e|0,i|0)}function I7e(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;$m(e|0,i|0,r|0)}function H7e(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;e_(e|0,i|0,r|0)}function x7e(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;i_(e|0,i|0,r|0)}function U7e(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;r_(e|0,i|0)|0}function z7e(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;n_(e|0,i|0,r|0)}function j7e(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;f_(e|0,i|0,r|0,n|0)}function V7e(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;t_(e|0,i|0,r|0,n|0,f|0,t|0,0,0,0)}function q7e(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;u_(e|0,i|0,r|0,n|0)}function Y7e(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;oA(e|0,i|0,r|0)|0}function G7e(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;Zq(e|0)}function W7e(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;Xq(e|0)|0}function K7e(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;Jq(e|0,i|0)|0}function X7e(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;Yl(e|0)|0}function Z7e(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;tp(e|0,i|0,r|0)}function J7e(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;Tz(e|0,i|0,r|0,n|0)}function Q7e(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;Mz(e|0)|0}function $7e(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;Rz(e|0)|0}function eei(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;Nz(e|0)|0}function iei(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;Dz(e|0,i|0,r|0)|0}function rei(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;Cz(e|0,i|0)|0}function nei(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;xz(e|0,i|0,r|0,n|0)}function fei(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;Iz(e|0,i|0,r|0,n|0,f|0,t|0,0)}function tei(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;Hz(e|0,i|0,r|0,n|0)}function uei(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;Uz(e|0,i|0,r|0,n|0,f|0)}function aei(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;zz(e|0,i|0)}function oei(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;jz(e|0)}function cei(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;Vz(e|0)}function lei(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;qz(e|0,i|0,r|0)}function sei(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;Yz(e|0,i|0)}function bei(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;Kz(e|0,i|0)}function kei(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;Xz(e|0,i|0,r|0)}function hei(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;Jz(e|0,i|0,r|0)}function wei(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;Qz(e|0,i|0)}function dei(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;kp(e|0,i|0,r|0)}function vei(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;bp(e|0,i|0,r|0)}function mei(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;Pz(e|0,i|0)|0}function _ei(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;$z(e|0,i|0,r|0)}function pei(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;Lz(e|0,i|0,r|0,n|0)}function Eei(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;yz(e|0)|0}function Sei(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;Fz(e|0)|0}function gei(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;Oz(e|0)|0}function yei(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;Az(e|0)|0}function Fei(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;Zz(e|0,i|0,r|0)}function Oei(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;OC(e|0)|0}function Aei(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;AC(e|0)|0}function Mei(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;MC(e|0)|0}function Rei(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;RC(e|0)|0}function Nei(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;NC(e|0)|0}function Tei(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;TC(e|0)|0}function Lei(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;LC(e|0)|0}function Dei(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;DC(e|0)|0}function Cei(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;CC(e|0)|0}function Pei(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;PC(e|0)|0}function Bei(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;BC(e|0)|0}function Iei(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;IC(e|0)|0}function Hei(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;HC(e|0)|0}function xei(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;xC(e|0)|0}function Uei(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;UC(e|0)|0}function zei(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;zC(e|0)|0}function jei(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;jC(e|0)|0}function Vei(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;VC(e|0)|0}function qei(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;qC(e|0)|0}function Yei(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;YC(e|0)|0}function Gei(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;GC(e|0)|0}function Wei(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;WC(e|0)|0}function Kei(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;KC(e|0)|0}function Xei(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;XC(e|0)|0}function Zei(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;ZC(e|0)|0}function Jei(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;JC(e|0)|0}function Qei(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;QC(e|0)|0}function $ei(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;$C(e|0)|0}function eii(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;eP(e|0)|0}function iii(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;iP(e|0)|0}function rii(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;rP(e|0)|0}function nii(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;nP(e|0)|0}function fii(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;fP(e|0)|0}function tii(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;tP(e|0)|0}function uii(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;uP(e|0)|0}function aii(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;aP(e|0)|0}function oii(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;oP(e|0)|0}function cii(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;cP(e|0)|0}function lii(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;lP(e|0)|0}function sii(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;sP(e|0)|0}function bii(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;bP(e|0)|0}function kii(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;kP(e|0)|0}function hii(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;hP(e|0)|0}function wii(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;wP(e|0)|0}function dii(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;dP(e|0)|0}function vii(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;vP(e|0)|0}function mii(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;mP(e|0)|0}function _ii(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;_P(e|0)|0}function pii(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;pP(e|0)|0}function Eii(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;EP(e|0)|0}function Sii(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;SP(e|0)|0}function gii(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;gP(e|0)|0}function yii(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;yP(e|0)|0}function Fii(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;FP(e|0)|0}function Oii(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;OP(e|0)|0}function Aii(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;AP(e|0)|0}function Mii(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;MP(e|0)|0}function Rii(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;RP(e|0)|0}function Nii(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;NP(e|0)|0}function Tii(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;TP(e|0)|0}function Lii(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;LP(e|0)|0}function Dii(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;DP(e|0)|0}function Cii(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;CP(e|0)|0}function Pii(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;PP(e|0)|0}function Bii(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;BP(e|0)|0}function Iii(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;IP(e|0)|0}function Hii(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;HP(e|0)|0}function xii(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;xP(e|0)|0}function Uii(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;UP(e|0)|0}function zii(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;zP(e|0)|0}function jii(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;jP(e|0)|0}function Vii(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;VP(e|0)|0}function qii(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;qP(e|0)|0}function Yii(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;YP(e|0)|0}function Gii(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;GP(e|0)|0}function Wii(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;WP(e|0)|0}function Kii(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;KP(e|0)|0}function Xii(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;XP(e|0)|0}function Zii(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;ZP(e|0)|0}function Jii(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;JP(e|0)|0}function Qii(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;QP(e|0)|0}function $ii(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;$P(e|0)|0}function eri(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;eB(e|0)|0}function iri(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;iB(e|0)|0}function rri(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;rB(e|0)|0}function nri(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;nB(e|0)|0}function fri(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;fB(e|0)|0}function tri(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;tB(e|0)|0}function uri(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;uB(e|0)|0}function ari(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;aB(e|0)|0}function ori(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;oB(e|0)|0}function cri(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;cB(e|0)|0}function lri(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;lB(e|0)|0}function sri(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;sB(e|0)|0}function bri(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;bB(e|0)|0}function kri(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;kB(e|0)|0}function hri(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;hB(e|0)|0}function wri(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;wB(e|0)|0}function dri(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;dB(e|0)|0}function vri(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;vB(e|0)|0}function mri(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;mB(e|0)|0}function _ri(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;_B(e|0)|0}function pri(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;pB(e|0)|0}function Eri(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;EB(e|0)|0}function Sri(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;SB(e|0)|0}function gri(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;gB(e|0)|0}function yri(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;yB(e|0)|0}function Fri(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;FB(e|0)|0}function Ori(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;OB(e|0)|0}function Ari(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;AB(e|0)|0}function Mri(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;MB(e|0)|0}function Rri(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;RB(e|0)|0}function Nri(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;NB(e|0)|0}function Tri(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;TB(e|0)|0}function Lri(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;LB(e|0)|0}function Dri(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;DB(e|0)|0}function Cri(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;CB(e|0)|0}function Pri(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;PB(e|0)|0}function Bri(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;BB(e|0)|0}function Iri(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;IB(e|0)|0}function Hri(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;HB(e|0)|0}function xri(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;xB(e|0)|0}function Uri(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;UB(e|0)|0}function zri(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;zB(e|0)|0}function jri(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;jB(e|0)|0}function Vri(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;VB(e|0)|0}function qri(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;qB(e|0)|0}function Yri(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;YB(e|0)|0}function Gri(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;NY(e|0,i|0,r|0)|0}function Wri(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;am(e|0)}function Kri(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;om(e|0)|0}function Xri(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;cm(e|0,i|0)|0}function Zri(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;lm(e|0)|0}function Jri(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;aA(e|0,i|0,r|0)|0}function Qri(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;bm(e|0)}function $ri(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;km(e|0)}function eni(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;hm(e|0,i|0,r|0)|0}function ini(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;xe(e|0,i|0,r|0)|0}function rni(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;pm(e|0,i|0,r|0)|0}function nni(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;Em(e|0)}function fni(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;Sm(e|0,i|0,r|0)}function tni(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;gm(e|0,i|0,r|0)}function uni(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;ym(e|0,i|0,r|0)}function ani(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;Fm(e|0,i|0,r|0)}function oni(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;Am(e|0)|0}function cni(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;O_(e|0,i|0)}function lni(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;A_(e|0)|0}function sni(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;Z_(e|0,i|0,r|0,n|0)|0}function bni(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;J_(e|0,i|0,r|0,n|0)|0}function kni(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;Q_(e|0,i|0,r|0,n|0)|0}function hni(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;$_(e|0,i|0,r|0,n|0)|0}function wni(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;ep(e|0,i|0,r|0,n|0)|0}function dni(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;ip(e|0,i|0,r|0,n|0)|0}function vni(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;N_(e|0,i|0,r|0,n|0)|0}function mni(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;T_(e|0,i|0,r|0,n|0)|0}function _ni(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;rp(e|0,i|0,r|0,n|0)|0}function pni(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;np(e|0,i|0,r|0,n|0)|0}function Eni(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;dN(e|0,i|0,r|0,n|0)|0}function Sni(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;hp(e|0,i|0,r|0)}function gni(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;wp(e|0,i|0,r|0)}function yni(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;LS(e|0)}function Fni(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;FO()|0}function Oni(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;Tg(e|0,i|0,r|0,n|0,f|0)}function Ani(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;_O(e|0,i|0,r|0,n|0,f|0)}function Mni(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;OO(e|0)|0}function Rni(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;AO(e|0)|0}function Nni(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;MO(e|0,i|0,r|0)|0}function Tni(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;RO(e|0)|0}function Lni(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;sA(e|0)|0}function Dni(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;bA(e|0,i|0,r|0)|0}function Cni(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;hA(e|0)|0}function Pni(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;wA(e|0,i|0,r|0)|0}function Bni(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;dA(e|0)|0}function Ini(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;vA(e|0,i|0,r|0)|0}function Hni(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;mA(e|0,i|0,r|0)|0}function xni(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;_A(e|0,i|0,r|0,n|0)|0}function Uni(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;FR(e|0)}function zni(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;OR(e|0)|0}function jni(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;NR(e|0)}function Vni(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;DR(e|0)|0}function qni(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;PR(e|0)}function Yni(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;BR(e|0)|0}function Gni(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;IR(e|0,i|0)}function Wni(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;HR(e|0)}function Kni(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;xR(e|0)}function Xni(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;UR(e|0,i|0)|0}function Zni(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;zR(e|0)}function Jni(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;GR(e|0,i|0,r|0)}function Qni(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;iN(e|0,i|0,r|0)}function $ni(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;rN(e|0,i|0,r|0)}function efi(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;nN(e|0,i|0,r|0)}function ifi(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;fN(e|0,i|0,r|0)}function rfi(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;lN(e|0,i|0)|0}function nfi(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;Xr(e|0,i|0)}function ffi(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;_n(e|0)}function tfi(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;tt(e|0,i|0)}function ufi(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;bt(e|0,i|0)}function afi(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;Yf(e|0,i|0)}function ofi(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;Jf(e|0,i|0)}function cfi(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;Qf(e|0,i|0)}function lfi(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;Gf(e|0,i|0)}function sfi(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;ot(e|0,i|0)}function bfi(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;st(e|0,i|0)}function kfi(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;Vf(e|0,i|0)}function hfi(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;ct(e|0,i|0)}function wfi(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;Wf(e|0,i|0)}function dfi(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;ut(e|0,i|0)}function vfi(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;Yt(e|0,i|0)}function mfi(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;Kf(e|0,i|0)}function _fi(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;nt(e|0,i|0)}function pfi(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;gf(e|0,i|0)}function Efi(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;qf(e|0,i|0)}function Sfi(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;kt(e|0,i|0)}function gfi(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;Xf(e|0,i|0)}function yfi(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;Zf(e|0,i|0)}function Ffi(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;$f(e|0,i|0)}function Ofi(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;et(e|0,i|0)}function Afi(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;it(e|0,i|0)}function Mfi(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;rt(e|0,i|0)}function Rfi(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;lt(e|0,i|0)}function Nfi(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;at(e|0,i|0)}function Tfi(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;ft(e|0,i|0)}function Lfi(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;Gt(e|0,i|0)}function Dfi(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;Qu(e|0,i|0,r|0)|0}function Cfi(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;Pf(e|0,i|0)|0}function Pfi(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;Bf(e|0,i|0)|0}function Bfi(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;zf(e|0,i|0)|0}function Ifi(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;$u(e|0,i|0,r|0)|0}function Hfi(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;ea(e|0,i|0)|0}function xfi(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;Tf(e|0,i|0)|0}function Ufi(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;Lf(e|0,i|0)|0}function zfi(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;Df(e|0,i|0)|0}function jfi(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;xf(e|0,i|0)|0}function Vfi(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;If(e|0,i|0)|0}function qfi(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;
	Uf(e|0,i|0)|0}function Yfi(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;Cf(e|0,i|0)|0}function Gfi(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;ia(e|0,i|0)|0}function Wfi(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;Hf(e|0,i|0)|0}function Kfi(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;Nf(e|0,i|0)|0}function Xfi(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;Cn(e|0,i|0)|0}function Zfi(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;za(e|0,i|0)}function Jfi(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;Wa(e|0,i|0)}function Qfi(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;Ka(e|0,i|0)}function $fi(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;Xa(e|0,i|0)}function eti(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;Za(e|0,i|0)}function iti(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;Ja(e|0,i|0)}function rti(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;Qa(e|0,i|0)}function nti(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;$a(e|0,i|0)}function fti(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;Qo(e|0,i|0,r|0)}function tti(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;vc(e|0)}function uti(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;Rc(e|0)}function ati(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;wl(e|0,i|0,r|0)|0}function oti(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;Ll(e|0,i|0)|0}function cti(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;Bl(e|0,i|0)|0}function lti(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;Hl(e|0,i|0)|0}function sti(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;jl(e|0,i|0)|0}function bti(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;Xk(e|0)}function kti(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;dh(e|0,i|0,r|0,n|0,f|0,t|0,0,0,0)}function hti(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;vh(e|0,i|0,r|0,n|0)}function wti(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;mh(e|0,i|0,r|0)}function dti(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;_h(e|0,i|0,r|0)}function vti(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;ph(e|0,i|0)}function mti(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;Eh(e|0,i|0,r|0,n|0)}function _ti(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;Sh(e|0)|0}function pti(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;gh(e|0)|0}function Eti(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;yh(e|0)|0}function Sti(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;Fh(e|0,i|0,r|0)|0}function gti(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;Oh(e|0,i|0)|0}function yti(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;Mh(e|0,i|0,r|0,n|0)}function Fti(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;Rh(e|0,i|0,r|0,n|0,f|0,t|0,0)}function Oti(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;Nh(e|0,i|0,r|0,n|0)}function Ati(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;Th(e|0,i|0,r|0,n|0,f|0)}function Mti(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;Lh(e|0,i|0)}function Rti(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;Dh(e|0)}function Nti(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;Ch(e|0)}function Tti(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;Ph(e|0,i|0,r|0)}function Lti(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;Bh(e|0,i|0)}function Dti(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;Ih(e|0,i|0,r|0)}function Cti(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;Hh(e|0,i|0,r|0)}function Pti(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;xh(e|0,i|0,r|0)}function Bti(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;Uh(e|0,i|0)|0}function Iti(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;zh(e|0,i|0,r|0,n|0)}function Hti(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;jh(e|0,i|0,r|0)}function xti(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;Vh(e|0,i|0,r|0)}function Uti(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;qh(e|0,i|0,r|0)}function zti(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;Yh(e|0,i|0)}function jti(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;Gh(e|0,i|0,r|0,n|0,f|0,t|0,0,0,0)}function Vti(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;Wh(e|0,i|0,r|0,n|0)}function qti(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;Zh(e|0,i|0,r|0)|0}function Yti(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;$h(e|0)}function Gti(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;td(e|0,i|0)}function Wti(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;qv(e|0,i|0,r|0,n|0)}function Kti(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;aT(e|0,i|0)}function Xti(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;Ok(e|0)}function Zti(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;cH(e|0,i|0,r|0)}function Jti(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;lH(e|0,i|0)}function Qti(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;sH(e|0,i|0,r|0,n|0,f|0,t|0,0,0,0)}function $ti(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;bH(e|0,i|0,r|0,n|0)}function eui(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;kH(e|0,i|0,r|0)}function iui(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;hH(e|0,i|0,r|0)}function rui(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;dH(e|0,i|0,r|0)}function nui(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;vH(e|0,i|0,r|0)}function fui(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;_H(e|0,i|0,r|0)|0}function tui(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;mH(e|0,i|0)}function uui(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;DH(e|0)}function aui(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;ex(e|0,i|0)|0}function oui(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;ix(e|0,i|0,r|0,n|0,f|0)|0}function cui(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;rx(e|0,i|0,r|0,n|0,f|0,t|0,0)|0}function lui(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;nx(e|0,i|0,r|0,n|0,f|0,t|0)|0}function sui(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;fx(e|0,i|0)}function bui(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;ux(e|0,i|0)|0}function kui(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;ax(e|0,i|0,r|0,n|0,f|0)|0}function hui(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;ox(e|0,i|0,r|0,n|0,f|0,t|0,0)|0}function wui(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;cx(e|0,i|0)}function dui(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;wx(e|0,i|0,r|0)}function vui(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;_x(e|0,i|0,r|0,n|0)}function mui(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;oU(e|0,i|0,r|0)}function _ui(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;cU(e|0,i|0,r|0)}function pui(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;GU(e|0,i|0,r|0,n|0)}function Eui(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;tz(e|0,i|0,r|0)}function Sui(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;Gz(e|0,i|0,r|0,n|0,f|0,t|0,0,0,0)}function gui(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;Wz(e|0,i|0,r|0,n|0)}function yui(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;PV(e|0,i|0,r|0,n|0)|0}function Fui(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;Rq(e|0,i|0)|0}function Oui(e,i,r,n,f,t){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;t=t|0;Kq(e|0,i|0,r|0)|0}function Aui(e,i){e=e|0;i=i|0;ue(13);return 0}function Mui(e,i){e=e|0;i=i|0;return 0}function Rui(e,i){e=e|0;i=i|0;return Pm(e|0)|0}function Nui(e,i){e=e|0;i=i|0;return Bm(e|0)|0}function Tui(e,i){e=e|0;i=i|0;return Im(e|0)|0}function Lui(e,i){e=e|0;i=i|0;return Hm(e|0,i|0,0)|0}function Dui(e,i){e=e|0;i=i|0;return 0}function Cui(e,i){e=e|0;i=i|0;return 0}function Pui(e,i){e=e|0;i=i|0;return 0}function Bui(e,i){e=e|0;i=i|0;return 0}function Iui(e,i){e=e|0;i=i|0;return 0}function Hui(e,i){e=e|0;i=i|0;return 0}function xui(e,i){e=e|0;i=i|0;return 0}function Uui(e,i){e=e|0;i=i|0;return 0}function zui(e,i){e=e|0;i=i|0;return 0}function jui(e,i){e=e|0;i=i|0;return 0}function Vui(e,i){e=e|0;i=i|0;return 0}function qui(e,i){e=e|0;i=i|0;return 0}function Yui(e,i){e=e|0;i=i|0;return 0}function Gui(e,i){e=e|0;i=i|0;return 0}function Wui(e,i){e=e|0;i=i|0;return 0}function Kui(e,i){e=e|0;i=i|0;return 0}function Xui(e,i){e=e|0;i=i|0;return 0}function Zui(e,i){e=e|0;i=i|0;return 0}function Jui(e,i){e=e|0;i=i|0;return 0}function Qui(e,i){e=e|0;i=i|0;return 0}function $ui(e,i){e=e|0;i=i|0;return 0}function eai(e,i){e=e|0;i=i|0;return 0}function iai(e,i){e=e|0;i=i|0;return oA(e|0,i|0,0)|0}function rai(e,i){e=e|0;i=i|0;return 0}function nai(e,i){e=e|0;i=i|0;return Xq(e|0)|0}function fai(e,i){e=e|0;i=i|0;return Yl(e|0)|0}function tai(e,i){e=e|0;i=i|0;return 0}function uai(e,i){e=e|0;i=i|0;return 0}function aai(e,i){e=e|0;i=i|0;return Mz(e|0)|0}function oai(e,i){e=e|0;i=i|0;return Rz(e|0)|0}function cai(e,i){e=e|0;i=i|0;return Nz(e|0)|0}function lai(e,i){e=e|0;i=i|0;return Dz(e|0,i|0,0)|0}function sai(e,i){e=e|0;i=i|0;return 0}function bai(e,i){e=e|0;i=i|0;return 0}function kai(e,i){e=e|0;i=i|0;return 0}function hai(e,i){e=e|0;i=i|0;return 0}function wai(e,i){e=e|0;i=i|0;return 0}function dai(e,i){e=e|0;i=i|0;return 0}function vai(e,i){e=e|0;i=i|0;return 0}function mai(e,i){e=e|0;i=i|0;return 0}function _ai(e,i){e=e|0;i=i|0;return 0}function pai(e,i){e=e|0;i=i|0;return 0}function Eai(e,i){e=e|0;i=i|0;return 0}function Sai(e,i){e=e|0;i=i|0;return 0}function gai(e,i){e=e|0;i=i|0;return 0}function yai(e,i){e=e|0;i=i|0;return 0}function Fai(e,i){e=e|0;i=i|0;return 0}function Oai(e,i){e=e|0;i=i|0;return 0}function Aai(e,i){e=e|0;i=i|0;return 0}function Mai(e,i){e=e|0;i=i|0;return 0}function Rai(e,i){e=e|0;i=i|0;return yz(e|0)|0}function Nai(e,i){e=e|0;i=i|0;return Fz(e|0)|0}function Tai(e,i){e=e|0;i=i|0;return Oz(e|0)|0}function Lai(e,i){e=e|0;i=i|0;return Az(e|0)|0}function Dai(e,i){e=e|0;i=i|0;return 0}function Cai(e,i){e=e|0;i=i|0;return OC(e|0)|0}function Pai(e,i){e=e|0;i=i|0;return AC(e|0)|0}function Bai(e,i){e=e|0;i=i|0;return MC(e|0)|0}function Iai(e,i){e=e|0;i=i|0;return RC(e|0)|0}function Hai(e,i){e=e|0;i=i|0;return NC(e|0)|0}function xai(e,i){e=e|0;i=i|0;return TC(e|0)|0}function Uai(e,i){e=e|0;i=i|0;return LC(e|0)|0}function zai(e,i){e=e|0;i=i|0;return DC(e|0)|0}function jai(e,i){e=e|0;i=i|0;return CC(e|0)|0}function Vai(e,i){e=e|0;i=i|0;return PC(e|0)|0}function qai(e,i){e=e|0;i=i|0;return BC(e|0)|0}function Yai(e,i){e=e|0;i=i|0;return IC(e|0)|0}function Gai(e,i){e=e|0;i=i|0;return HC(e|0)|0}function Wai(e,i){e=e|0;i=i|0;return xC(e|0)|0}function Kai(e,i){e=e|0;i=i|0;return UC(e|0)|0}function Xai(e,i){e=e|0;i=i|0;return zC(e|0)|0}function Zai(e,i){e=e|0;i=i|0;return jC(e|0)|0}function Jai(e,i){e=e|0;i=i|0;return VC(e|0)|0}function Qai(e,i){e=e|0;i=i|0;return qC(e|0)|0}function $ai(e,i){e=e|0;i=i|0;return YC(e|0)|0}function eoi(e,i){e=e|0;i=i|0;return GC(e|0)|0}function ioi(e,i){e=e|0;i=i|0;return WC(e|0)|0}function roi(e,i){e=e|0;i=i|0;return KC(e|0)|0}function noi(e,i){e=e|0;i=i|0;return XC(e|0)|0}function foi(e,i){e=e|0;i=i|0;return ZC(e|0)|0}function toi(e,i){e=e|0;i=i|0;return JC(e|0)|0}function uoi(e,i){e=e|0;i=i|0;return QC(e|0)|0}function aoi(e,i){e=e|0;i=i|0;return $C(e|0)|0}function ooi(e,i){e=e|0;i=i|0;return eP(e|0)|0}function coi(e,i){e=e|0;i=i|0;return iP(e|0)|0}function loi(e,i){e=e|0;i=i|0;return rP(e|0)|0}function soi(e,i){e=e|0;i=i|0;return nP(e|0)|0}function boi(e,i){e=e|0;i=i|0;return fP(e|0)|0}function koi(e,i){e=e|0;i=i|0;return tP(e|0)|0}function hoi(e,i){e=e|0;i=i|0;return uP(e|0)|0}function woi(e,i){e=e|0;i=i|0;return aP(e|0)|0}function doi(e,i){e=e|0;i=i|0;return oP(e|0)|0}function voi(e,i){e=e|0;i=i|0;return cP(e|0)|0}function moi(e,i){e=e|0;i=i|0;return lP(e|0)|0}function _oi(e,i){e=e|0;i=i|0;return sP(e|0)|0}function poi(e,i){e=e|0;i=i|0;return bP(e|0)|0}function Eoi(e,i){e=e|0;i=i|0;return kP(e|0)|0}function Soi(e,i){e=e|0;i=i|0;return hP(e|0)|0}function goi(e,i){e=e|0;i=i|0;return wP(e|0)|0}function yoi(e,i){e=e|0;i=i|0;return dP(e|0)|0}function Foi(e,i){e=e|0;i=i|0;return vP(e|0)|0}function Ooi(e,i){e=e|0;i=i|0;return mP(e|0)|0}function Aoi(e,i){e=e|0;i=i|0;return _P(e|0)|0}function Moi(e,i){e=e|0;i=i|0;return pP(e|0)|0}function Roi(e,i){e=e|0;i=i|0;return EP(e|0)|0}function Noi(e,i){e=e|0;i=i|0;return SP(e|0)|0}function Toi(e,i){e=e|0;i=i|0;return gP(e|0)|0}function Loi(e,i){e=e|0;i=i|0;return yP(e|0)|0}function Doi(e,i){e=e|0;i=i|0;return FP(e|0)|0}function Coi(e,i){e=e|0;i=i|0;return OP(e|0)|0}function Poi(e,i){e=e|0;i=i|0;return AP(e|0)|0}function Boi(e,i){e=e|0;i=i|0;return MP(e|0)|0}function Ioi(e,i){e=e|0;i=i|0;return RP(e|0)|0}function Hoi(e,i){e=e|0;i=i|0;return NP(e|0)|0}function xoi(e,i){e=e|0;i=i|0;return TP(e|0)|0}function Uoi(e,i){e=e|0;i=i|0;return LP(e|0)|0}function zoi(e,i){e=e|0;i=i|0;return DP(e|0)|0}function joi(e,i){e=e|0;i=i|0;return CP(e|0)|0}function Voi(e,i){e=e|0;i=i|0;return PP(e|0)|0}function qoi(e,i){e=e|0;i=i|0;return BP(e|0)|0}function Yoi(e,i){e=e|0;i=i|0;return IP(e|0)|0}function Goi(e,i){e=e|0;i=i|0;return HP(e|0)|0}function Woi(e,i){e=e|0;i=i|0;return xP(e|0)|0}function Koi(e,i){e=e|0;i=i|0;return UP(e|0)|0}function Xoi(e,i){e=e|0;i=i|0;return zP(e|0)|0}function Zoi(e,i){e=e|0;i=i|0;return jP(e|0)|0}function Joi(e,i){e=e|0;i=i|0;return VP(e|0)|0}function Qoi(e,i){e=e|0;i=i|0;return qP(e|0)|0}function $oi(e,i){e=e|0;i=i|0;return YP(e|0)|0}function eci(e,i){e=e|0;i=i|0;return GP(e|0)|0}function ici(e,i){e=e|0;i=i|0;return WP(e|0)|0}function rci(e,i){e=e|0;i=i|0;return KP(e|0)|0}function nci(e,i){e=e|0;i=i|0;return XP(e|0)|0}function fci(e,i){e=e|0;i=i|0;return ZP(e|0)|0}function tci(e,i){e=e|0;i=i|0;return JP(e|0)|0}function uci(e,i){e=e|0;i=i|0;return QP(e|0)|0}function aci(e,i){e=e|0;i=i|0;return $P(e|0)|0}function oci(e,i){e=e|0;i=i|0;return eB(e|0)|0}function cci(e,i){e=e|0;i=i|0;return iB(e|0)|0}function lci(e,i){e=e|0;i=i|0;return rB(e|0)|0}function sci(e,i){e=e|0;i=i|0;return nB(e|0)|0}function bci(e,i){e=e|0;i=i|0;return fB(e|0)|0}function kci(e,i){e=e|0;i=i|0;return tB(e|0)|0}function hci(e,i){e=e|0;i=i|0;return uB(e|0)|0}function wci(e,i){e=e|0;i=i|0;return aB(e|0)|0}function dci(e,i){e=e|0;i=i|0;return oB(e|0)|0}function vci(e,i){e=e|0;i=i|0;return cB(e|0)|0}function mci(e,i){e=e|0;i=i|0;return lB(e|0)|0}function _ci(e,i){e=e|0;i=i|0;return sB(e|0)|0}function pci(e,i){e=e|0;i=i|0;return bB(e|0)|0}function Eci(e,i){e=e|0;i=i|0;return kB(e|0)|0}function Sci(e,i){e=e|0;i=i|0;return hB(e|0)|0}function gci(e,i){e=e|0;i=i|0;return wB(e|0)|0}function yci(e,i){e=e|0;i=i|0;return dB(e|0)|0}function Fci(e,i){e=e|0;i=i|0;return vB(e|0)|0}function Oci(e,i){e=e|0;i=i|0;return mB(e|0)|0}function Aci(e,i){e=e|0;i=i|0;return _B(e|0)|0}function Mci(e,i){e=e|0;i=i|0;return pB(e|0)|0}function Rci(e,i){e=e|0;i=i|0;return EB(e|0)|0}function Nci(e,i){e=e|0;i=i|0;return SB(e|0)|0}function Tci(e,i){e=e|0;i=i|0;return gB(e|0)|0}function Lci(e,i){e=e|0;i=i|0;return yB(e|0)|0}function Dci(e,i){e=e|0;i=i|0;return FB(e|0)|0}function Cci(e,i){e=e|0;i=i|0;return OB(e|0)|0}function Pci(e,i){e=e|0;i=i|0;return AB(e|0)|0}function Bci(e,i){e=e|0;i=i|0;return MB(e|0)|0}function Ici(e,i){e=e|0;i=i|0;return RB(e|0)|0}function Hci(e,i){e=e|0;i=i|0;return NB(e|0)|0}function xci(e,i){e=e|0;i=i|0;return TB(e|0)|0}function Uci(e,i){e=e|0;i=i|0;return LB(e|0)|0}function zci(e,i){e=e|0;i=i|0;return DB(e|0)|0}function jci(e,i){e=e|0;i=i|0;return CB(e|0)|0}function Vci(e,i){e=e|0;i=i|0;return PB(e|0)|0}function qci(e,i){e=e|0;i=i|0;return BB(e|0)|0}function Yci(e,i){e=e|0;i=i|0;return IB(e|0)|0}function Gci(e,i){e=e|0;i=i|0;return HB(e|0)|0}function Wci(e,i){e=e|0;i=i|0;return xB(e|0)|0}function Kci(e,i){e=e|0;i=i|0;return UB(e|0)|0}function Xci(e,i){e=e|0;i=i|0;return zB(e|0)|0}function Zci(e,i){e=e|0;i=i|0;return jB(e|0)|0}function Jci(e,i){e=e|0;i=i|0;return VB(e|0)|0}function Qci(e,i){e=e|0;i=i|0;return qB(e|0)|0}function $ci(e,i){e=e|0;i=i|0;return YB(e|0)|0}function eli(e,i){e=e|0;i=i|0;return NY(e|0,i|0,0)|0}function ili(e,i){e=e|0;i=i|0;return 0}function rli(e,i){e=e|0;i=i|0;return om(e|0)|0}function nli(e,i){e=e|0;i=i|0;return lm(e|0)|0}function fli(e,i){e=e|0;i=i|0;return aA(e|0,i|0,0)|0}function tli(e,i){e=e|0;i=i|0;return 0}function uli(e,i){e=e|0;i=i|0;return 0}function ali(e,i){e=e|0;i=i|0;return hm(e|0,i|0,0)|0}function oli(e,i){e=e|0;i=i|0;return xe(e|0,i|0,0)|0}function cli(e,i){e=e|0;i=i|0;return pm(e|0,i|0,0)|0}function lli(e,i){e=e|0;i=i|0;return 0}function sli(e,i){e=e|0;i=i|0;return 0}function bli(e,i){e=e|0;i=i|0;return 0}function kli(e,i){e=e|0;i=i|0;return 0}function hli(e,i){e=e|0;i=i|0;return 0}function wli(e,i){e=e|0;i=i|0;return Am(e|0)|0}function dli(e,i){e=e|0;i=i|0;return 0}function vli(e,i){e=e|0;i=i|0;return A_(e|0)|0}function mli(e,i){e=e|0;i=i|0;return Z_(e|0,i|0,0,0)|0}function _li(e,i){e=e|0;i=i|0;return J_(e|0,i|0,0,0)|0}function pli(e,i){e=e|0;i=i|0;return Q_(e|0,i|0,0,0)|0}function Eli(e,i){e=e|0;i=i|0;return $_(e|0,i|0,0,0)|0}function Sli(e,i){e=e|0;i=i|0;return ep(e|0,i|0,0,0)|0}function gli(e,i){e=e|0;i=i|0;return ip(e|0,i|0,0,0)|0}function yli(e,i){e=e|0;i=i|0;return N_(e|0,i|0,0,0)|0}function Fli(e,i){e=e|0;i=i|0;return T_(e|0,i|0,0,0)|0}function Oli(e,i){e=e|0;i=i|0;return rp(e|0,i|0,0,0)|0}function Ali(e,i){e=e|0;i=i|0;return np(e|0,i|0,0,0)|0}function Mli(e,i){e=e|0;i=i|0;return dN(e|0,i|0,0,0)|0}function Rli(e,i){e=e|0;i=i|0;return 0}function Nli(e,i){e=e|0;i=i|0;return 0}function Tli(e,i){e=e|0;i=i|0;return 0}function Lli(e,i){e=e|0;i=i|0;return FO()|0}function Dli(e,i){e=e|0;i=i|0;return 0}function Cli(e,i){e=e|0;i=i|0;return 0}function Pli(e,i){e=e|0;i=i|0;return OO(e|0)|0}function Bli(e,i){e=e|0;i=i|0;return AO(e|0)|0}function Ili(e,i){e=e|0;i=i|0;return MO(e|0,i|0,0)|0}function Hli(e,i){e=e|0;i=i|0;return RO(e|0)|0}function xli(e,i){e=e|0;i=i|0;return sA(e|0)|0}function Uli(e,i){e=e|0;i=i|0;return bA(e|0,i|0,0)|0}function zli(e,i){e=e|0;i=i|0;return hA(e|0)|0}function jli(e,i){e=e|0;i=i|0;return wA(e|0,i|0,0)|0}function Vli(e,i){e=e|0;i=i|0;return dA(e|0)|0}function qli(e,i){e=e|0;i=i|0;return vA(e|0,i|0,0)|0}function Yli(e,i){e=e|0;i=i|0;return mA(e|0,i|0,0)|0}function Gli(e,i){e=e|0;i=i|0;return _A(e|0,i|0,0,0)|0}function Wli(e,i){e=e|0;i=i|0;return 0}function Kli(e,i){e=e|0;i=i|0;return OR(e|0)|0}function Xli(e,i){e=e|0;i=i|0;return 0}function Zli(e,i){e=e|0;i=i|0;return DR(e|0)|0}function Jli(e,i){e=e|0;i=i|0;return 0}function Qli(e,i){e=e|0;i=i|0;return BR(e|0)|0}function $li(e,i){e=e|0;i=i|0;return 0}function esi(e,i){e=e|0;i=i|0;return 0}function isi(e,i){e=e|0;i=i|0;return 0}function rsi(e,i){e=e|0;i=i|0;return 0}function nsi(e,i){e=e|0;i=i|0;return 0}function fsi(e,i){e=e|0;i=i|0;return 0}function tsi(e,i){e=e|0;i=i|0;return 0}function usi(e,i){e=e|0;i=i|0;return 0}function asi(e,i){e=e|0;i=i|0;return 0}function osi(e,i){e=e|0;i=i|0;return 0}function csi(e,i){e=e|0;i=i|0;return 0}function lsi(e,i){e=e|0;i=i|0;return 0}function ssi(e,i){e=e|0;i=i|0;return 0}function bsi(e,i){e=e|0;i=i|0;return 0}function ksi(e,i){e=e|0;i=i|0;return 0}function hsi(e,i){e=e|0;i=i|0;return 0}function wsi(e,i){e=e|0;i=i|0;return 0}function dsi(e,i){e=e|0;i=i|0;return 0}function vsi(e,i){e=e|0;i=i|0;return 0}function msi(e,i){e=e|0;i=i|0;return 0}function _si(e,i){e=e|0;i=i|0;return 0}function psi(e,i){e=e|0;i=i|0;return 0}function Esi(e,i){e=e|0;i=i|0;return 0}function Ssi(e,i){e=e|0;i=i|0;return 0}function gsi(e,i){e=e|0;i=i|0;return 0}function ysi(e,i){e=e|0;i=i|0;return 0}function Fsi(e,i){e=e|0;i=i|0;return 0}function Osi(e,i){e=e|0;i=i|0;return 0}function Asi(e,i){e=e|0;i=i|0;return 0}function Msi(e,i){e=e|0;i=i|0;return 0}function Rsi(e,i){e=e|0;i=i|0;return 0}function Nsi(e,i){e=e|0;i=i|0;return 0}function Tsi(e,i){e=e|0;i=i|0;return 0}function Lsi(e,i){e=e|0;i=i|0;return 0}function Dsi(e,i){e=e|0;i=i|0;return 0}function Csi(e,i){e=e|0;i=i|0;return 0}function Psi(e,i){e=e|0;i=i|0;return 0}function Bsi(e,i){e=e|0;i=i|0;return 0}function Isi(e,i){e=e|0;i=i|0;return 0}function Hsi(e,i){e=e|0;i=i|0;return Qu(e|0,i|0,0)|0}function xsi(e,i){e=e|0;i=i|0;return $u(e|0,i|0,0)|0}function Usi(e,i){e=e|0;i=i|0;return 0}function zsi(e,i){e=e|0;i=i|0;return 0}function jsi(e,i){e=e|0;i=i|0;return 0}function Vsi(e,i){e=e|0;i=i|0;return 0}function qsi(e,i){e=e|0;i=i|0;return 0}function Ysi(e,i){e=e|0;i=i|0;return 0}function Gsi(e,i){e=e|0;i=i|0;return 0}function Wsi(e,i){e=e|0;i=i|0;return 0}function Ksi(e,i){e=e|0;i=i|0;return 0}function Xsi(e,i){e=e|0;i=i|0;return 0}function Zsi(e,i){e=e|0;i=i|0;return 0}function Jsi(e,i){e=e|0;i=i|0;return wl(e|0,i|0,0)|0}function Qsi(e,i){e=e|0;i=i|0;return 0}function $si(e,i){e=e|0;i=i|0;return 0}function ebi(e,i){e=e|0;i=i|0;return 0}function ibi(e,i){e=e|0;i=i|0;return 0}function rbi(e,i){e=e|0;i=i|0;return 0}function nbi(e,i){e=e|0;i=i|0;return 0}function fbi(e,i){e=e|0;i=i|0;return 0}function tbi(e,i){e=e|0;i=i|0;return Sh(e|0)|0}function ubi(e,i){e=e|0;i=i|0;return gh(e|0)|0}function abi(e,i){e=e|0;i=i|0;return yh(e|0)|0}function obi(e,i){e=e|0;i=i|0;return Fh(e|0,i|0,0)|0}function cbi(e,i){e=e|0;i=i|0;return 0}function lbi(e,i){e=e|0;i=i|0;return 0}function sbi(e,i){e=e|0;i=i|0;return 0}function bbi(e,i){e=e|0;i=i|0;return 0}function kbi(e,i){e=e|0;i=i|0;return 0}function hbi(e,i){e=e|0;i=i|0;return 0}function wbi(e,i){e=e|0;i=i|0;return 0}function dbi(e,i){e=e|0;i=i|0;return 0}function vbi(e,i){e=e|0;i=i|0;return 0}function mbi(e,i){e=e|0;i=i|0;return 0}function _bi(e,i){e=e|0;i=i|0;return 0}function pbi(e,i){e=e|0;i=i|0;return 0}function Ebi(e,i){e=e|0;i=i|0;return 0}function Sbi(e,i){e=e|0;i=i|0;return 0}function gbi(e,i){e=e|0;i=i|0;return 0}function ybi(e,i){e=e|0;i=i|0;return 0}function Fbi(e,i){e=e|0;i=i|0;return 0}function Obi(e,i){e=e|0;i=i|0;return 0}function Abi(e,i){e=e|0;i=i|0;return 0}function Mbi(e,i){e=e|0;i=i|0;return 0}function Rbi(e,i){e=e|0;i=i|0;return Zh(e|0,i|0,0)|0}function Nbi(e,i){e=e|0;i=i|0;return 0}function Tbi(e,i){e=e|0;i=i|0;return 0}function Lbi(e,i){e=e|0;i=i|0;return 0}function Dbi(e,i){e=e|0;i=i|0;return 0}function Cbi(e,i){e=e|0;i=i|0;return 0}function Pbi(e,i){e=e|0;i=i|0;return 0}function Bbi(e,i){e=e|0;i=i|0;return 0}function Ibi(e,i){e=e|0;i=i|0;return 0}function Hbi(e,i){e=e|0;i=i|0;return 0}function xbi(e,i){e=e|0;i=i|0;return 0}function Ubi(e,i){e=e|0;i=i|0;return 0}function zbi(e,i){e=e|0;i=i|0;return 0}function jbi(e,i){e=e|0;i=i|0;return 0}function Vbi(e,i){e=e|0;i=i|0;return _H(e|0,i|0,0)|0}function qbi(e,i){e=e|0;i=i|0;return 0}function Ybi(e,i){e=e|0;i=i|0;return 0}function Gbi(e,i){e=e|0;i=i|0;return ix(e|0,i|0,0,0,0)|0}function Wbi(e,i){e=e|0;i=i|0;return rx(e|0,i|0,0,0,0,0,0)|0}function Kbi(e,i){e=e|0;i=i|0;return nx(e|0,i|0,0,0,0,0)|0}function Xbi(e,i){e=e|0;i=i|0;return 0}function Zbi(e,i){e=e|0;i=i|0;return ax(e|0,i|0,0,0,0)|0}function Jbi(e,i){e=e|0;i=i|0;return ox(e|0,i|0,0,0,0,0,0)|0}function Qbi(e,i){e=e|0;i=i|0;return 0}function $bi(e,i){e=e|0;i=i|0;return 0}function eki(e,i){e=e|0;i=i|0;return 0}function iki(e,i){e=e|0;i=i|0;return 0}function rki(e,i){e=e|0;i=i|0;return 0}function nki(e,i){e=e|0;i=i|0;return 0}function fki(e,i){e=e|0;i=i|0;return 0}function tki(e,i){e=e|0;i=i|0;return 0}function uki(e,i){e=e|0;i=i|0;return 0}function aki(e,i){e=e|0;i=i|0;return PV(e|0,i|0,0,0)|0}function oki(e,i){e=e|0;i=i|0;return Kq(e|0,i|0,0)|0}function cki(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;ue(14);return 0}function lki(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return 0}function ski(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return Pm(e|0)|0}function bki(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return Bm(e|0)|0}function kki(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return Im(e|0)|0}function hki(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return Hm(e|0,i|0,r|0)|0}function wki(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return xm(e|0,i|0)|0}function dki(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return 0}function vki(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return 0}function mki(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return 0}function _ki(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return 0}function pki(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return 0}function Eki(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return 0}function Ski(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return 0}function gki(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return 0}function yki(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return 0}function Fki(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return 0}function Oki(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return 0}function Aki(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return 0}function Mki(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return 0}function Rki(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return 0}function Nki(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return 0}function Tki(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return 0}function Lki(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return 0}function Dki(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return 0}function Cki(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return r_(e|0,i|0)|0}function Pki(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return 0}function Bki(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return 0}function Iki(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return 0}function Hki(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return 0}function xki(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return oA(e|0,i|0,r|0)|0}function Uki(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return 0}function zki(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return Xq(e|0)|0}function jki(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return Jq(e|0,i|0)|0}function Vki(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return Yl(e|0)|0}function qki(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return 0}function Yki(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return 0}function Gki(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return Mz(e|0)|0}function Wki(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return Rz(e|0)|0}function Kki(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return Nz(e|0)|0}function Xki(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return Dz(e|0,i|0,r|0)|0}function Zki(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return Cz(e|0,i|0)|0}function Jki(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return 0}function Qki(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return 0}function $ki(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return 0}function ehi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return 0}function ihi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return 0}function rhi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return 0}function nhi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return 0}function fhi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return 0}function thi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return 0}function uhi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return 0}function ahi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return 0}function ohi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return 0}function chi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return 0}function lhi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return 0}function shi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return 0}function bhi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return 0}function khi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return Pz(e|0,i|0)|0}function hhi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return 0}function whi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return 0}function dhi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return yz(e|0)|0}function vhi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return Fz(e|0)|0}function mhi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return Oz(e|0)|0}function _hi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return Az(e|0)|0}function phi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return 0}function Ehi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return OC(e|0)|0}function Shi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return AC(e|0)|0}function ghi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return MC(e|0)|0}function yhi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return RC(e|0)|0}function Fhi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return NC(e|0)|0}function Ohi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return TC(e|0)|0}function Ahi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return LC(e|0)|0}function Mhi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return DC(e|0)|0}function Rhi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return CC(e|0)|0}function Nhi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return PC(e|0)|0}function Thi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return BC(e|0)|0}function Lhi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return IC(e|0)|0}function Dhi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return HC(e|0)|0}function Chi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return xC(e|0)|0}function Phi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return UC(e|0)|0}function Bhi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return zC(e|0)|0}function Ihi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return jC(e|0)|0}function Hhi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return VC(e|0)|0}function xhi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return qC(e|0)|0}function Uhi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return YC(e|0)|0}function zhi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return GC(e|0)|0}function jhi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return WC(e|0)|0}function Vhi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return KC(e|0)|0}function qhi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return XC(e|0)|0}function Yhi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return ZC(e|0)|0}function Ghi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return JC(e|0)|0}function Whi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return QC(e|0)|0}function Khi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return $C(e|0)|0}function Xhi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return eP(e|0)|0}function Zhi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return iP(e|0)|0}function Jhi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return rP(e|0)|0}function Qhi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return nP(e|0)|0}function $hi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return fP(e|0)|0}function ewi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return tP(e|0)|0}function iwi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return uP(e|0)|0}function rwi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return aP(e|0)|0}function nwi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return oP(e|0)|0}function fwi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return cP(e|0)|0}function twi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return lP(e|0)|0}function uwi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return sP(e|0)|0}function awi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return bP(e|0)|0}function owi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return kP(e|0)|0}function cwi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return hP(e|0)|0}function lwi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return wP(e|0)|0}function swi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return dP(e|0)|0}function bwi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return vP(e|0)|0}function kwi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return mP(e|0)|0}function hwi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return _P(e|0)|0}function wwi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return pP(e|0)|0}function dwi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return EP(e|0)|0}function vwi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return SP(e|0)|0}function mwi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return gP(e|0)|0}function _wi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return yP(e|0)|0}function pwi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return FP(e|0)|0}function Ewi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return OP(e|0)|0}function Swi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return AP(e|0)|0}function gwi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return MP(e|0)|0}function ywi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return RP(e|0)|0}function Fwi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return NP(e|0)|0}function Owi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return TP(e|0)|0}function Awi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return LP(e|0)|0}function Mwi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return DP(e|0)|0}function Rwi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return CP(e|0)|0}function Nwi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return PP(e|0)|0}function Twi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return BP(e|0)|0}function Lwi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return IP(e|0)|0;
	}function Dwi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return HP(e|0)|0}function Cwi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return xP(e|0)|0}function Pwi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return UP(e|0)|0}function Bwi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return zP(e|0)|0}function Iwi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return jP(e|0)|0}function Hwi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return VP(e|0)|0}function xwi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return qP(e|0)|0}function Uwi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return YP(e|0)|0}function zwi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return GP(e|0)|0}function jwi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return WP(e|0)|0}function Vwi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return KP(e|0)|0}function qwi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return XP(e|0)|0}function Ywi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return ZP(e|0)|0}function Gwi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return JP(e|0)|0}function Wwi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return QP(e|0)|0}function Kwi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return $P(e|0)|0}function Xwi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return eB(e|0)|0}function Zwi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return iB(e|0)|0}function Jwi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return rB(e|0)|0}function Qwi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return nB(e|0)|0}function $wi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return fB(e|0)|0}function edi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return tB(e|0)|0}function idi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return uB(e|0)|0}function rdi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return aB(e|0)|0}function ndi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return oB(e|0)|0}function fdi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return cB(e|0)|0}function tdi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return lB(e|0)|0}function udi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return sB(e|0)|0}function adi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return bB(e|0)|0}function odi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return kB(e|0)|0}function cdi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return hB(e|0)|0}function ldi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return wB(e|0)|0}function sdi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return dB(e|0)|0}function bdi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return vB(e|0)|0}function kdi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return mB(e|0)|0}function hdi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return _B(e|0)|0}function wdi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return pB(e|0)|0}function ddi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return EB(e|0)|0}function vdi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return SB(e|0)|0}function mdi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return gB(e|0)|0}function _di(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return yB(e|0)|0}function pdi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return FB(e|0)|0}function Edi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return OB(e|0)|0}function Sdi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return AB(e|0)|0}function gdi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return MB(e|0)|0}function ydi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return RB(e|0)|0}function Fdi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return NB(e|0)|0}function Odi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return TB(e|0)|0}function Adi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return LB(e|0)|0}function Mdi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return DB(e|0)|0}function Rdi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return CB(e|0)|0}function Ndi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return PB(e|0)|0}function Tdi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return BB(e|0)|0}function Ldi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return IB(e|0)|0}function Ddi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return HB(e|0)|0}function Cdi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return xB(e|0)|0}function Pdi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return UB(e|0)|0}function Bdi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return zB(e|0)|0}function Idi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return jB(e|0)|0}function Hdi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return VB(e|0)|0}function xdi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return qB(e|0)|0}function Udi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return YB(e|0)|0}function zdi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return NY(e|0,i|0,r|0)|0}function jdi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return 0}function Vdi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return om(e|0)|0}function qdi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return cm(e|0,i|0)|0}function Ydi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return lm(e|0)|0}function Gdi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return aA(e|0,i|0,r|0)|0}function Wdi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return 0}function Kdi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return 0}function Xdi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return hm(e|0,i|0,r|0)|0}function Zdi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return xe(e|0,i|0,r|0)|0}function Jdi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return pm(e|0,i|0,r|0)|0}function Qdi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return 0}function $di(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return 0}function evi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return 0}function ivi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return 0}function rvi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return 0}function nvi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return Am(e|0)|0}function fvi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return 0}function tvi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return A_(e|0)|0}function uvi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return Z_(e|0,i|0,r|0,n|0)|0}function avi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return J_(e|0,i|0,r|0,n|0)|0}function ovi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return Q_(e|0,i|0,r|0,n|0)|0}function cvi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return $_(e|0,i|0,r|0,n|0)|0}function lvi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return ep(e|0,i|0,r|0,n|0)|0}function svi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return ip(e|0,i|0,r|0,n|0)|0}function bvi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return N_(e|0,i|0,r|0,n|0)|0}function kvi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return T_(e|0,i|0,r|0,n|0)|0}function hvi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return rp(e|0,i|0,r|0,n|0)|0}function wvi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return np(e|0,i|0,r|0,n|0)|0}function dvi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return dN(e|0,i|0,r|0,n|0)|0}function vvi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return 0}function mvi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return 0}function _vi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return 0}function pvi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return FO()|0}function Evi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return 0}function Svi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return 0}function gvi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return OO(e|0)|0}function yvi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return AO(e|0)|0}function Fvi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return MO(e|0,i|0,r|0)|0}function Ovi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return RO(e|0)|0}function Avi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return sA(e|0)|0}function Mvi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return bA(e|0,i|0,r|0)|0}function Rvi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return hA(e|0)|0}function Nvi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return wA(e|0,i|0,r|0)|0}function Tvi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return dA(e|0)|0}function Lvi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return vA(e|0,i|0,r|0)|0}function Dvi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return mA(e|0,i|0,r|0)|0}function Cvi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return _A(e|0,i|0,r|0,n|0)|0}function Pvi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return 0}function Bvi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return OR(e|0)|0}function Ivi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return 0}function Hvi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return DR(e|0)|0}function xvi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return 0}function Uvi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return BR(e|0)|0}function zvi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return 0}function jvi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return 0}function Vvi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return 0}function qvi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return UR(e|0,i|0)|0}function Yvi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return 0}function Gvi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return 0}function Wvi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return 0}function Kvi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return 0}function Xvi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return 0}function Zvi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return 0}function Jvi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return lN(e|0,i|0)|0}function Qvi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return 0}function $vi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return 0}function emi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return 0}function imi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return 0}function rmi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return 0}function nmi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return 0}function fmi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return 0}function tmi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return 0}function umi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return 0}function ami(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return 0}function omi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return 0}function cmi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return 0}function lmi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return 0}function smi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return 0}function bmi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return 0}function kmi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return 0}function hmi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return 0}function wmi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return 0}function dmi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return 0}function vmi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return 0}function mmi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return 0}function _mi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return 0}function pmi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return 0}function Emi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return 0}function Smi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return 0}function gmi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return 0}function ymi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return 0}function Fmi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return 0}function Omi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return 0}function Ami(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return 0}function Mmi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return Qu(e|0,i|0,r|0)|0}function Rmi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return Pf(e|0,i|0)|0}function Nmi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return Bf(e|0,i|0)|0}function Tmi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return zf(e|0,i|0)|0}function Lmi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return $u(e|0,i|0,r|0)|0}function Dmi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return ea(e|0,i|0)|0}function Cmi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return Tf(e|0,i|0)|0}function Pmi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return Lf(e|0,i|0)|0}function Bmi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return Df(e|0,i|0)|0}function Imi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return xf(e|0,i|0)|0}function Hmi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return If(e|0,i|0)|0}function xmi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return Uf(e|0,i|0)|0}function Umi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return Cf(e|0,i|0)|0}function zmi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return ia(e|0,i|0)|0}function jmi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return Hf(e|0,i|0)|0}function Vmi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return Nf(e|0,i|0)|0}function qmi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return Cn(e|0,i|0)|0}function Ymi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return 0}function Gmi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return 0}function Wmi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return 0}function Kmi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return 0}function Xmi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return 0}function Zmi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return 0}function Jmi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return 0}function Qmi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return 0}function $mi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return 0}function e_i(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return 0}function i_i(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return 0}function r_i(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return wl(e|0,i|0,r|0)|0}function n_i(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return Ll(e|0,i|0)|0}function f_i(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return Bl(e|0,i|0)|0}function t_i(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return Hl(e|0,i|0)|0}function u_i(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return jl(e|0,i|0)|0}function a_i(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return 0}function o_i(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return 0}function c_i(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return 0}function l_i(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return 0}function s_i(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return 0}function b_i(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return 0}function k_i(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return 0}function h_i(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return Sh(e|0)|0}function w_i(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return gh(e|0)|0}function d_i(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return yh(e|0)|0}function v_i(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return Fh(e|0,i|0,r|0)|0}function m_i(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return Oh(e|0,i|0)|0}function __i(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return 0}function p_i(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return 0}function E_i(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return 0}function S_i(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return 0}function g_i(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return 0}function y_i(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return 0}function F_i(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return 0}function O_i(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return 0}function A_i(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return 0}function M_i(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return 0}function R_i(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return 0}function N_i(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return 0}function T_i(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return 0}function L_i(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return Uh(e|0,i|0)|0}function D_i(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return 0}function C_i(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return 0}function P_i(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return 0}function B_i(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return 0}function I_i(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return 0}function H_i(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return 0}function x_i(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return 0}function U_i(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return Zh(e|0,i|0,r|0)|0}function z_i(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return 0}function j_i(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return 0}function V_i(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return 0}function q_i(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return 0}function Y_i(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return 0}function G_i(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return 0}function W_i(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return 0}function K_i(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return 0}function X_i(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return 0}function Z_i(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return 0}function J_i(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return 0}function Q_i(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return 0}function $_i(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return 0}function epi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return _H(e|0,i|0,r|0)|0}function ipi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return 0}function rpi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return 0}function npi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return ex(e|0,i|0)|0}function fpi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return rx(e|0,i|0,r|0,n|0,f|0,0,0)|0}function tpi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return nx(e|0,i|0,r|0,n|0,f|0,0)|0}function upi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return 0}function api(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return ux(e|0,i|0)|0}function opi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return ox(e|0,i|0,r|0,n|0,f|0,0,0)|0}function cpi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return 0}function lpi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return 0}function spi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return 0}function bpi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return 0}function kpi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return 0}function hpi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return 0}function wpi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return 0}function dpi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return 0}function vpi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return 0}function mpi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return PV(e|0,i|0,r|0,n|0)|0}function _pi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return Rq(e|0,i|0)|0}function ppi(e,i,r,n,f){e=e|0;i=i|0;r=r|0;n=n|0;f=f|0;return Kq(e|0,i|0,r|0)|0}function Epi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;ue(15)}function Spi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;Pm(e|0)|0}function gpi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;Bm(e|0)|0}function ypi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;Im(e|0)|0}function Fpi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;Hm(e|0,i|0,r|0)|0}function Opi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;xm(e|0,i|0)|0}function Api(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;Um(e|0,i|0,r|0,n|0,0,0)}function Mpi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;jm(e|0,i|0,r|0,n|0,0,0,0)}function Rpi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;qm(e|0,i|0,r|0,n|0,0)}function Npi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;Ym(e|0,i|0)}function Tpi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;Gm(e|0)}function Lpi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;Wm(e|0)}function Dpi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;o_(e|0,i|0,r|0)}function Cpi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;c_(e|0,i|0)}function Ppi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;Km(e|0,i|0)}function Bpi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;Xm(e|0,i|0,r|0)}function Ipi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;Zm(e|0,i|0,r|0)}function Hpi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;Jm(e|0,i|0,r|0)}function xpi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;Qm(e|0,i|0)}function Upi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;$m(e|0,i|0,r|0)}function zpi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;e_(e|0,i|0,r|0)}function jpi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;i_(e|0,i|0,r|0)}function Vpi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;r_(e|0,i|0)|0}function qpi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;n_(e|0,i|0,r|0)}function Ypi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;t_(e|0,i|0,r|0,n|0,0,0,0,0,0)}function Gpi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;oA(e|0,i|0,r|0)|0}function Wpi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;Zq(e|0)}function Kpi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;Xq(e|0)|0}function Xpi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;Jq(e|0,i|0)|0}function Zpi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;Yl(e|0)|0}function Jpi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;tp(e|0,i|0,r|0)}function Qpi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;Mz(e|0)|0}function $pi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;Rz(e|0)|0}function eEi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;Nz(e|0)|0}function iEi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;Dz(e|0,i|0,r|0)|0}function rEi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;Cz(e|0,i|0)|0}function nEi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;Bz(e|0,i|0,r|0,n|0,0,0)}function fEi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;Iz(e|0,i|0,r|0,n|0,0,0,0)}function tEi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;Uz(e|0,i|0,r|0,n|0,0)}function uEi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;zz(e|0,i|0)}function aEi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;jz(e|0)}function oEi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;Vz(e|0)}function cEi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;qz(e|0,i|0,r|0)}function lEi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;Yz(e|0,i|0)}function sEi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;Kz(e|0,i|0)}function bEi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;Xz(e|0,i|0,r|0)}function kEi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;Jz(e|0,i|0,r|0)}function hEi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;Qz(e|0,i|0)}function wEi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;kp(e|0,i|0,r|0)}function dEi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;bp(e|0,i|0,r|0)}function vEi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;Pz(e|0,i|0)|0}function mEi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;$z(e|0,i|0,r|0)}function _Ei(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;yz(e|0)|0}function pEi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;Fz(e|0)|0}function EEi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;Oz(e|0)|0}function SEi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;Az(e|0)|0}function gEi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;Zz(e|0,i|0,r|0)}function yEi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;OC(e|0)|0}function FEi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;AC(e|0)|0}function OEi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;MC(e|0)|0}function AEi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;RC(e|0)|0}function MEi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;NC(e|0)|0}function REi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;TC(e|0)|0}function NEi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;LC(e|0)|0}function TEi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;DC(e|0)|0}function LEi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;CC(e|0)|0}function DEi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;PC(e|0)|0}function CEi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;BC(e|0)|0}function PEi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;IC(e|0)|0}function BEi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;HC(e|0)|0}function IEi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;xC(e|0)|0}function HEi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;UC(e|0)|0}function xEi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;zC(e|0)|0}function UEi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;jC(e|0)|0}function zEi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;VC(e|0)|0}function jEi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;qC(e|0)|0}function VEi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;YC(e|0)|0}function qEi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;GC(e|0)|0}function YEi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;WC(e|0)|0}function GEi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;KC(e|0)|0}function WEi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;XC(e|0)|0}function KEi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;ZC(e|0)|0}function XEi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;JC(e|0)|0}function ZEi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;QC(e|0)|0}function JEi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;$C(e|0)|0}function QEi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;eP(e|0)|0}function $Ei(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;iP(e|0)|0}function eSi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;rP(e|0)|0}function iSi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;nP(e|0)|0}function rSi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;fP(e|0)|0}function nSi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;tP(e|0)|0}function fSi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;uP(e|0)|0}function tSi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;aP(e|0)|0}function uSi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;oP(e|0)|0}function aSi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;cP(e|0)|0}function oSi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;lP(e|0)|0}function cSi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;sP(e|0)|0}function lSi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;bP(e|0)|0}function sSi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;kP(e|0)|0}function bSi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;hP(e|0)|0}function kSi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;wP(e|0)|0}function hSi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;dP(e|0)|0}function wSi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;vP(e|0)|0}function dSi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;mP(e|0)|0}function vSi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;_P(e|0)|0}function mSi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;pP(e|0)|0}function _Si(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;EP(e|0)|0}function pSi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;SP(e|0)|0}function ESi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;gP(e|0)|0}function SSi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;yP(e|0)|0}function gSi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;FP(e|0)|0}function ySi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;OP(e|0)|0}function FSi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;AP(e|0)|0}function OSi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;MP(e|0)|0}function ASi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;RP(e|0)|0}function MSi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;NP(e|0)|0}function RSi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;TP(e|0)|0}function NSi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;LP(e|0)|0}function TSi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;DP(e|0)|0}function LSi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;CP(e|0)|0}function DSi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;PP(e|0)|0}function CSi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;BP(e|0)|0}function PSi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;IP(e|0)|0}function BSi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;HP(e|0)|0}function ISi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;xP(e|0)|0}function HSi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;UP(e|0)|0}function xSi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;zP(e|0)|0}function USi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;jP(e|0)|0}function zSi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;VP(e|0)|0}function jSi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;qP(e|0)|0}function VSi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;YP(e|0)|0}function qSi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;GP(e|0)|0}function YSi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;WP(e|0)|0}function GSi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;KP(e|0)|0}function WSi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;XP(e|0)|0}function KSi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;ZP(e|0)|0}function XSi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;JP(e|0)|0}function ZSi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;QP(e|0)|0}function JSi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;$P(e|0)|0}function QSi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;eB(e|0)|0}function $Si(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;iB(e|0)|0}function egi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;rB(e|0)|0}function igi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;nB(e|0)|0}function rgi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;fB(e|0)|0}function ngi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;tB(e|0)|0}function fgi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;uB(e|0)|0}function tgi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;aB(e|0)|0}function ugi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;oB(e|0)|0}function agi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;cB(e|0)|0}function ogi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;lB(e|0)|0}function cgi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;sB(e|0)|0}function lgi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;bB(e|0)|0}function sgi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;kB(e|0)|0}function bgi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;hB(e|0)|0}function kgi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;wB(e|0)|0}function hgi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;dB(e|0)|0}function wgi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;vB(e|0)|0}function dgi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;mB(e|0)|0}function vgi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;_B(e|0)|0}function mgi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;pB(e|0)|0}function _gi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;EB(e|0)|0}function pgi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;SB(e|0)|0}function Egi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;gB(e|0)|0}function Sgi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;yB(e|0)|0}function ggi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;FB(e|0)|0}function ygi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;OB(e|0)|0}function Fgi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;AB(e|0)|0}function Ogi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;MB(e|0)|0}function Agi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;RB(e|0)|0}function Mgi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;NB(e|0)|0}function Rgi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;TB(e|0)|0}function Ngi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;LB(e|0)|0}function Tgi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;DB(e|0)|0}function Lgi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;CB(e|0)|0}function Dgi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;PB(e|0)|0}function Cgi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;BB(e|0)|0}function Pgi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;IB(e|0)|0}function Bgi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;HB(e|0)|0}function Igi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;xB(e|0)|0}function Hgi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;UB(e|0)|0}function xgi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;zB(e|0)|0}function Ugi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;jB(e|0)|0}function zgi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;VB(e|0)|0}function jgi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;qB(e|0)|0}function Vgi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;YB(e|0)|0}function qgi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;NY(e|0,i|0,r|0)|0}function Ygi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;am(e|0)}function Ggi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;om(e|0)|0}function Wgi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;cm(e|0,i|0)|0}function Kgi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;lm(e|0)|0}function Xgi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;aA(e|0,i|0,r|0)|0}function Zgi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;bm(e|0)}function Jgi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;km(e|0)}function Qgi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;hm(e|0,i|0,r|0)|0}function $gi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;xe(e|0,i|0,r|0)|0}function eyi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;pm(e|0,i|0,r|0)|0}function iyi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;Em(e|0)}function ryi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;Sm(e|0,i|0,r|0)}function nyi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;gm(e|0,i|0,r|0)}function fyi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;ym(e|0,i|0,r|0)}function tyi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;Fm(e|0,i|0,r|0)}function uyi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;Am(e|0)|0}function ayi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;O_(e|0,i|0)}function oyi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;A_(e|0)|0}function cyi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;Z_(e|0,i|0,r|0,n|0)|0}function lyi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;J_(e|0,i|0,r|0,n|0)|0}function syi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;Q_(e|0,i|0,r|0,n|0)|0}function byi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;$_(e|0,i|0,r|0,n|0)|0}function kyi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;ep(e|0,i|0,r|0,n|0)|0}function hyi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;ip(e|0,i|0,r|0,n|0)|0}function wyi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;N_(e|0,i|0,r|0,n|0)|0}function dyi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;T_(e|0,i|0,r|0,n|0)|0}function vyi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;rp(e|0,i|0,r|0,n|0)|0}function myi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;np(e|0,i|0,r|0,n|0)|0}function _yi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;dN(e|0,i|0,r|0,n|0)|0}function pyi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;hp(e|0,i|0,r|0)}function Eyi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;wp(e|0,i|0,r|0)}function Syi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;LS(e|0)}function gyi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;FO()|0}function yyi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;Tg(e|0,i|0,r|0,n|0,0)}function Fyi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;_O(e|0,i|0,r|0,n|0,0)}function Oyi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;OO(e|0)|0}function Ayi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;AO(e|0)|0}function Myi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;MO(e|0,i|0,r|0)|0}function Ryi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;RO(e|0)|0}function Nyi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;sA(e|0)|0}function Tyi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;bA(e|0,i|0,r|0)|0}function Lyi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;hA(e|0)|0}function Dyi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;wA(e|0,i|0,r|0)|0}function Cyi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;dA(e|0)|0}function Pyi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;vA(e|0,i|0,r|0)|0}function Byi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;mA(e|0,i|0,r|0)|0}function Iyi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;_A(e|0,i|0,r|0,n|0)|0}function Hyi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;FR(e|0)}function xyi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;OR(e|0)|0}function Uyi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;NR(e|0)}function zyi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;DR(e|0)|0}function jyi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;PR(e|0)}function Vyi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;BR(e|0)|0}function qyi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;IR(e|0,i|0)}function Yyi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;HR(e|0)}function Gyi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;xR(e|0)}function Wyi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;UR(e|0,i|0)|0}function Kyi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;zR(e|0);
	}function Xyi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;GR(e|0,i|0,r|0)}function Zyi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;iN(e|0,i|0,r|0)}function Jyi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;rN(e|0,i|0,r|0)}function Qyi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;nN(e|0,i|0,r|0)}function $yi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;fN(e|0,i|0,r|0)}function eFi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;lN(e|0,i|0)|0}function iFi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;Xr(e|0,i|0)}function rFi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;_n(e|0)}function nFi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;tt(e|0,i|0)}function fFi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;bt(e|0,i|0)}function tFi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;Yf(e|0,i|0)}function uFi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;Jf(e|0,i|0)}function aFi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;Qf(e|0,i|0)}function oFi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;Gf(e|0,i|0)}function cFi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;ot(e|0,i|0)}function lFi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;st(e|0,i|0)}function sFi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;Vf(e|0,i|0)}function bFi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;ct(e|0,i|0)}function kFi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;Wf(e|0,i|0)}function hFi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;ut(e|0,i|0)}function wFi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;Yt(e|0,i|0)}function dFi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;Kf(e|0,i|0)}function vFi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;nt(e|0,i|0)}function mFi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;gf(e|0,i|0)}function _Fi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;qf(e|0,i|0)}function pFi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;kt(e|0,i|0)}function EFi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;Xf(e|0,i|0)}function SFi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;Zf(e|0,i|0)}function gFi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;$f(e|0,i|0)}function yFi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;et(e|0,i|0)}function FFi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;it(e|0,i|0)}function OFi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;rt(e|0,i|0)}function AFi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;lt(e|0,i|0)}function MFi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;at(e|0,i|0)}function RFi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;ft(e|0,i|0)}function NFi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;Gt(e|0,i|0)}function TFi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;Qu(e|0,i|0,r|0)|0}function LFi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;Pf(e|0,i|0)|0}function DFi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;Bf(e|0,i|0)|0}function CFi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;zf(e|0,i|0)|0}function PFi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;$u(e|0,i|0,r|0)|0}function BFi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;ea(e|0,i|0)|0}function IFi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;Tf(e|0,i|0)|0}function HFi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;Lf(e|0,i|0)|0}function xFi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;Df(e|0,i|0)|0}function UFi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;xf(e|0,i|0)|0}function zFi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;If(e|0,i|0)|0}function jFi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;Uf(e|0,i|0)|0}function VFi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;Cf(e|0,i|0)|0}function qFi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;ia(e|0,i|0)|0}function YFi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;Hf(e|0,i|0)|0}function GFi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;Nf(e|0,i|0)|0}function WFi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;Cn(e|0,i|0)|0}function KFi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;za(e|0,i|0)}function XFi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;Wa(e|0,i|0)}function ZFi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;Ka(e|0,i|0)}function JFi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;Xa(e|0,i|0)}function QFi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;Za(e|0,i|0)}function $Fi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;Ja(e|0,i|0)}function eOi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;Qa(e|0,i|0)}function iOi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;$a(e|0,i|0)}function rOi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;Qo(e|0,i|0,r|0)}function nOi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;vc(e|0)}function fOi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;Rc(e|0)}function tOi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;wl(e|0,i|0,r|0)|0}function uOi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;Ll(e|0,i|0)|0}function aOi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;Bl(e|0,i|0)|0}function oOi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;Hl(e|0,i|0)|0}function cOi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;jl(e|0,i|0)|0}function lOi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;Xk(e|0)}function sOi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;dh(e|0,i|0,r|0,n|0,0,0,0,0,0)}function bOi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;mh(e|0,i|0,r|0)}function kOi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;_h(e|0,i|0,r|0)}function hOi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;ph(e|0,i|0)}function wOi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;Sh(e|0)|0}function dOi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;gh(e|0)|0}function vOi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;yh(e|0)|0}function mOi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;Fh(e|0,i|0,r|0)|0}function _Oi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;Oh(e|0,i|0)|0}function pOi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;Ah(e|0,i|0,r|0,n|0,0,0)}function EOi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;Rh(e|0,i|0,r|0,n|0,0,0,0)}function SOi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;Th(e|0,i|0,r|0,n|0,0)}function gOi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;Lh(e|0,i|0)}function yOi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;Dh(e|0)}function FOi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;Ch(e|0)}function OOi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;Ph(e|0,i|0,r|0)}function AOi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;Bh(e|0,i|0)}function MOi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;Ih(e|0,i|0,r|0)}function ROi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;Hh(e|0,i|0,r|0)}function NOi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;xh(e|0,i|0,r|0)}function TOi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;Uh(e|0,i|0)|0}function LOi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;jh(e|0,i|0,r|0)}function DOi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;Vh(e|0,i|0,r|0)}function COi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;qh(e|0,i|0,r|0)}function POi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;Yh(e|0,i|0)}function BOi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;Gh(e|0,i|0,r|0,n|0,0,0,0,0,0)}function IOi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;Zh(e|0,i|0,r|0)|0}function HOi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;$h(e|0)}function xOi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;td(e|0,i|0)}function UOi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;aT(e|0,i|0)}function zOi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;Ok(e|0)}function jOi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;cH(e|0,i|0,r|0)}function VOi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;lH(e|0,i|0)}function qOi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;sH(e|0,i|0,r|0,n|0,0,0,0,0,0)}function YOi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;kH(e|0,i|0,r|0)}function GOi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;hH(e|0,i|0,r|0)}function WOi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;dH(e|0,i|0,r|0)}function KOi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;vH(e|0,i|0,r|0)}function XOi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;_H(e|0,i|0,r|0)|0}function ZOi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;mH(e|0,i|0)}function JOi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;DH(e|0)}function QOi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;ex(e|0,i|0)|0}function $Oi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;ix(e|0,i|0,r|0,n|0,0)|0}function eAi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;rx(e|0,i|0,r|0,n|0,0,0,0)|0}function iAi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;nx(e|0,i|0,r|0,n|0,0,0)|0}function rAi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;fx(e|0,i|0)}function nAi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;ux(e|0,i|0)|0}function fAi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;ax(e|0,i|0,r|0,n|0,0)|0}function tAi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;ox(e|0,i|0,r|0,n|0,0,0,0)|0}function uAi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;cx(e|0,i|0)}function aAi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;wx(e|0,i|0,r|0)}function oAi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;oU(e|0,i|0,r|0)}function cAi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;cU(e|0,i|0,r|0)}function lAi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;tz(e|0,i|0,r|0)}function sAi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;Gz(e|0,i|0,r|0,n|0,0,0,0,0,0)}function bAi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;PV(e|0,i|0,r|0,n|0)|0}function kAi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;Rq(e|0,i|0)|0}function hAi(e,i,r,n){e=e|0;i=i|0;r=r|0;n=n|0;Kq(e|0,i|0,r|0)|0}var wAi=[_G,pG,EG,SG,gG,yG,FG,OG,AG,MG,RG,NG,TG,LG,DG,CG,PG,BG,IG,HG,xG,UG,zG,jG,VG,qG,YG,GG,WG,KG,XG,ZG,JG,QG,$G,eW,iW,rW,nW,fW,tW,uW,aW,oW,cW,lW,sW,bW,kW,hW,wW,dW,vW,mW,_W,pW,EW,SW,gW,yW,FW,OW,AW,MW,RW,NW,TW,LW,DW,CW,PW,BW,IW,HW,xW,UW,zW,jW,VW,qW,YW,GW,WW,KW,XW,ZW,JW,QW,$W,eK,iK,rK,nK,fK,tK,uK,aK,oK,cK,lK,sK,bK,kK,hK,wK,dK,vK,mK,_K,pK,EK,SK,gK,yK,FK,OK,AK,MK,RK,NK,TK,LK,DK,CK,PK,BK,IK,HK,xK,UK,zK,jK,VK,qK,YK,GK,WK,KK,XK,ZK,JK,QK,$K,eX,iX,rX,nX,fX,tX,uX,aX,oX,cX,lX,sX,bX,kX,hX,wX,dX,vX,mX,_X,pX,EX,SX,gX,yX,FX,OX,AX,MX,RX,NX,TX,LX,DX,CX,PX,BX,IX,HX,xX,UX,zX,jX,VX,qX,YX,GX,WX,KX,XX,ZX,JX,QX,$X,eZ,iZ,rZ,nZ,fZ,tZ,uZ,aZ,oZ,cZ,lZ,sZ,bZ,kZ,hZ,wZ,dZ,vZ,mZ,_Z,pZ,EZ,SZ,gZ,yZ,FZ,OZ,AZ,MZ,RZ,NZ,TZ,LZ,DZ,CZ,PZ,BZ,IZ,HZ,xZ,UZ,zZ,jZ,VZ,qZ,YZ,GZ,WZ,KZ,XZ,ZZ,JZ,QZ,$Z,eJ,iJ,rJ,nJ,fJ,tJ,uJ,aJ,oJ,cJ,lJ,sJ,bJ,kJ,hJ,wJ,dJ,vJ,mJ,_J,pJ,EJ,SJ,gJ,yJ,FJ,OJ,AJ,MJ,RJ,NJ,TJ,LJ,DJ,CJ,PJ,BJ,IJ,HJ,xJ,UJ,zJ,jJ,VJ,qJ,YJ,GJ,WJ,KJ,XJ,ZJ,JJ,QJ,$J,eQ,iQ,rQ,nQ,fQ,tQ,uQ,aQ,oQ,cQ,lQ,sQ,bQ,kQ,hQ,wQ,dQ,vQ,mQ,_Q,pQ,EQ,SQ,gQ,yQ,FQ,OQ,AQ,MQ,RQ,NQ,TQ,LQ,DQ,CQ,PQ,BQ,IQ,HQ,xQ,UQ,zQ,jQ,VQ,qQ,YQ,GQ,WQ,KQ,XQ,ZQ,JQ,QQ,$Q,e$,i$,r$,n$,f$,t$,u$,a$,o$,c$,l$,s$,b$,k$,h$,rx,w$,d$,v$,m$,ox,_$,p$,E$,S$,g$,y$,F$,O$,A$,M$,R$,N$,_G,_G,_G,_G,_G,_G,_G,_G,_G,_G,_G,_G,_G,_G,_G,_G,_G,_G,_G,_G,_G,_G,_G,_G,_G,_G,_G,_G,_G,_G,_G,_G,_G,_G,_G,_G,_G,_G,_G,_G,_G,_G,_G,_G,_G,_G,_G,_G,_G,_G,_G,_G,_G,_G,_G,_G,_G,_G,_G,_G,_G,_G,_G,_G,_G,_G,_G,_G,_G,_G,_G,_G,_G,_G,_G,_G,_G,_G,_G,_G,_G,_G,_G,_G,_G,_G,_G,_G,_G,_G,_G,_G,_G,_G,_G,_G,_G,_G,_G,_G,_G,_G,_G,_G,_G,_G,_G,_G,_G,_G,_G,_G,_G,_G,_G,_G,_G,_G,_G,_G];var dAi=[T$,L$,D$,C$,P$,Hm,B$,I$,H$,x$,U$,z$,j$,V$,q$,Y$,G$,W$,K$,X$,Z$,J$,Q$,$$,e0,i0,r0,n0,f0,t0,oA,u0,a0,o0,c0,l0,s0,b0,k0,h0,Dz,w0,d0,v0,m0,_0,p0,E0,S0,g0,y0,F0,O0,A0,M0,R0,N0,T0,L0,D0,C0,P0,B0,I0,H0,x0,U0,z0,j0,V0,q0,Y0,G0,W0,K0,X0,Z0,J0,Q0,$0,e1,i1,r1,n1,f1,t1,u1,a1,o1,c1,l1,s1,b1,k1,h1,w1,d1,v1,m1,_1,p1,E1,S1,g1,y1,F1,O1,A1,M1,R1,N1,T1,L1,D1,C1,P1,B1,I1,H1,x1,U1,z1,j1,V1,q1,Y1,G1,W1,K1,X1,Z1,J1,Q1,$1,e2,i2,r2,n2,f2,t2,u2,a2,o2,c2,l2,s2,b2,k2,h2,w2,d2,v2,m2,_2,p2,E2,S2,g2,y2,F2,O2,A2,M2,R2,N2,T2,L2,D2,C2,P2,B2,I2,H2,x2,U2,z2,j2,V2,q2,Y2,G2,W2,K2,X2,Z2,J2,Q2,$2,e3,i3,r3,n3,f3,t3,NY,u3,a3,o3,c3,aA,l3,s3,hm,b3,pm,k3,h3,w3,d3,v3,m3,_3,p3,E3,S3,g3,y3,F3,O3,A3,M3,R3,N3,T3,L3,D3,C3,P3,B3,I3,H3,x3,MO,U3,z3,bA,j3,wA,V3,vA,mA,q3,Y3,G3,W3,K3,X3,Z3,J3,Q3,$3,e4,i4,r4,n4,f4,t4,u4,a4,o4,c4,l4,s4,b4,k4,h4,w4,d4,v4,m4,_4,p4,E4,S4,g4,y4,F4,O4,A4,M4,R4,N4,T4,L4,D4,C4,P4,B4,I4,Qu,H4,x4,U4,$u,z4,j4,V4,q4,Y4,G4,W4,K4,X4,Z4,J4,Q4,$4,e8,i8,r8,n8,f8,t8,u8,a8,o8,c8,wl,l8,s8,b8,k8,h8,w8,d8,v8,m8,_8,p8,E8,S8,g8,Fh,y8,F8,O8,A8,M8,R8,N8,T8,L8,D8,C8,P8,B8,I8,H8,x8,U8,z8,j8,V8,q8,Y8,Zh,G8,W8,K8,X8,Z8,J8,Q8,$8,e6,i6,r6,n6,f6,_H,t6,u6,a6,o6,c6,l6,s6,b6,k6,h6,w6,d6,v6,m6,_6,p6,E6,S6,g6,y6,F6,Kq,T$,T$,T$,T$,T$,T$,T$,T$,T$,T$,T$,T$,T$,T$,T$,T$,T$,T$,T$,T$,T$,T$,T$,T$,T$,T$,T$,T$,T$,T$,T$,T$,T$,T$,T$,T$,T$,T$,T$,T$,T$,T$,T$,T$,T$,T$,T$,T$,T$,T$,T$,T$,T$,T$,T$,T$,T$,T$,T$,T$,T$,T$,T$,T$,T$,T$,T$,T$,T$,T$,T$,T$,T$,T$,T$,T$,T$,T$,T$,T$,T$,T$,T$,T$,T$,T$,T$,T$,T$,T$,T$,T$,T$,T$,T$,T$,T$,T$,T$,T$,T$,T$,T$,T$,T$,T$,T$,T$,T$,T$,T$,T$,T$,T$,T$,T$,T$,T$,T$,T$];var vAi=[O6,A6,M6,R6,N6,T6,L6,D6,C6,jm,P6,B6,I6,H6,x6,U6,z6,j6,V6,q6,Y6,G6,W6,K6,X6,Z6,J6,Q6,$6,e5,i5,r5,n5,f5,t5,u5,a5,o5,c5,l5,s5,b5,k5,h5,Iz,w5,d5,v5,m5,_5,p5,E5,S5,g5,y5,F5,O5,A5,M5,R5,N5,T5,L5,D5,C5,P5,B5,I5,H5,x5,U5,z5,j5,V5,q5,Y5,G5,W5,K5,X5,Z5,J5,Q5,$5,e9,i9,r9,n9,f9,t9,u9,a9,o9,c9,l9,s9,b9,k9,h9,w9,d9,v9,m9,_9,p9,E9,S9,g9,y9,F9,O9,A9,M9,R9,N9,T9,L9,D9,C9,P9,B9,I9,H9,x9,U9,z9,j9,V9,q9,Y9,G9,W9,K9,X9,Z9,J9,Q9,$9,e7,i7,r7,n7,f7,t7,u7,a7,o7,c7,l7,s7,b7,k7,h7,w7,d7,v7,m7,_7,p7,E7,S7,g7,y7,F7,O7,A7,M7,R7,N7,T7,L7,D7,C7,P7,B7,I7,H7,x7,U7,z7,j7,V7,q7,Y7,G7,W7,K7,X7,Z7,J7,Q7,$7,eee,iee,ree,nee,fee,tee,uee,aee,oee,cee,lee,see,bee,kee,hee,wee,dee,vee,mee,_ee,pee,Eee,See,gee,yee,Fee,Oee,Aee,Mee,Ree,Nee,Tee,Lee,Dee,Cee,Pee,Bee,Iee,Hee,xee,Uee,zee,jee,Vee,qee,Yee,Gee,Wee,Kee,Xee,Zee,Jee,Qee,$ee,eie,iie,rie,nie,fie,tie,uie,aie,oie,cie,lie,sie,bie,kie,hie,wie,die,vie,mie,_ie,pie,Eie,Sie,gie,yie,Fie,Oie,Aie,Mie,Rie,Nie,Tie,Lie,Die,Cie,Pie,Bie,Iie,Hie,xie,Uie,zie,jie,Vie,qie,Yie,Gie,Wie,Kie,Xie,Zie,Jie,Qie,$ie,ere,ire,rre,nre,fre,tre,ure,are,ore,cre,lre,sre,bre,kre,hre,wre,dre,vre,mre,_re,pre,Ere,Sre,gre,yre,Fre,Ore,Are,Mre,Rre,Nre,Tre,Lre,Dre,Cre,Pre,Rh,Bre,Ire,Hre,xre,Ure,zre,jre,Vre,qre,Yre,Gre,Wre,Kre,Xre,Zre,Jre,Qre,$re,ene,ine,rne,nne,fne,tne,une,ane,one,cne,lne,sne,bne,kne,hne,wne,dne,vne,mne,_ne,pne,Ene,Sne,gne,yne,Fne,One,Ane,Mne,Rne,Nne,Tne,Lne,Dne,Cne,Pne,Bne,O6,O6,O6,O6,O6,O6,O6,O6,O6,O6,O6,O6,O6,O6,O6,O6,O6,O6,O6,O6,O6,O6,O6,O6,O6,O6,O6,O6,O6,O6,O6,O6,O6,O6,O6,O6,O6,O6,O6,O6,O6,O6,O6,O6,O6,O6,O6,O6,O6,O6,O6,O6,O6,O6,O6,O6,O6,O6,O6,O6,O6,O6,O6,O6,O6,O6,O6,O6,O6,O6,O6,O6,O6,O6,O6,O6,O6,O6,O6,O6,O6,O6,O6,O6,O6,O6,O6,O6,O6,O6,O6,O6,O6,O6,O6,O6,O6,O6,O6,O6,O6,O6,O6,O6,O6,O6,O6,O6,O6,O6,O6,O6,O6,O6,O6,O6,O6,O6,O6,O6];var mAi=[Ine,Hne,xne,Une,zne,jne,Vne,qne,Yne,Gne,Wne,qm,Kne,Xne,Zne,Jne,Qne,$ne,efe,ife,rfe,nfe,ffe,tfe,ufe,afe,ofe,cfe,lfe,sfe,bfe,kfe,hfe,wfe,dfe,vfe,mfe,_fe,pfe,Efe,Sfe,gfe,yfe,Ffe,Ofe,Afe,Uz,Mfe,Rfe,Nfe,Tfe,Lfe,Dfe,Cfe,Pfe,Bfe,Ife,Hfe,xfe,Ufe,zfe,jfe,Vfe,qfe,Yfe,Gfe,Wfe,Kfe,Xfe,Zfe,Jfe,Qfe,$fe,ete,ite,rte,nte,fte,tte,ute,ate,ote,cte,lte,ste,bte,kte,hte,wte,dte,vte,mte,_te,pte,Ete,Ste,gte,yte,Fte,Ote,Ate,Mte,Rte,Nte,Tte,Lte,Dte,Cte,Pte,Bte,Ite,Hte,xte,Ute,zte,jte,Vte,qte,Yte,Gte,Wte,Kte,Xte,Zte,Jte,Qte,$te,eue,iue,rue,nue,fue,tue,uue,aue,oue,cue,lue,sue,bue,kue,hue,wue,due,vue,mue,_ue,pue,Eue,Sue,gue,yue,Fue,Oue,Aue,Mue,Rue,Nue,Tue,Lue,Due,Cue,Pue,Bue,Iue,Hue,xue,Uue,zue,jue,Vue,que,Yue,Gue,Wue,Kue,Xue,Zue,Jue,Que,$ue,eae,iae,rae,nae,fae,tae,uae,aae,oae,cae,lae,sae,bae,kae,hae,wae,dae,vae,mae,_ae,pae,Eae,Sae,gae,yae,Fae,Oae,Aae,Mae,Rae,Nae,Tae,Lae,Dae,Cae,Pae,Bae,Iae,Hae,xae,Uae,zae,jae,Vae,qae,Yae,Gae,Tg,_O,Wae,Kae,Xae,Zae,Jae,Qae,$ae,eoe,ioe,roe,noe,foe,toe,uoe,aoe,ooe,coe,loe,soe,boe,koe,hoe,woe,doe,voe,moe,_oe,poe,Eoe,Soe,goe,yoe,Foe,Ooe,Aoe,Moe,Roe,Noe,Toe,Loe,Doe,Coe,Poe,Boe,Ioe,Hoe,xoe,Uoe,zoe,joe,Voe,qoe,Yoe,Goe,Woe,Koe,Xoe,Zoe,Joe,Qoe,$oe,ece,ice,rce,nce,fce,tce,uce,ace,oce,cce,lce,sce,bce,kce,hce,wce,dce,vce,mce,_ce,pce,Ece,Sce,gce,yce,Fce,Oce,Ace,Mce,Rce,Nce,Tce,Lce,Dce,Cce,Pce,Bce,Ice,Hce,xce,Uce,zce,jce,Vce,qce,Yce,Gce,Th,Wce,Kce,Xce,Zce,Jce,Qce,$ce,ele,ile,rle,nle,fle,tle,ule,ale,ole,cle,lle,sle,ble,kle,hle,wle,dle,vle,mle,_le,ple,Ele,Sle,gle,yle,Fle,Ole,Ale,Mle,Rle,Nle,Tle,Lle,Dle,Cle,Ple,Ble,Ile,Hle,xle,Ule,zle,jle,Vle,qle,Yle,Ine,Ine,Ine,Ine,Ine,Ine,Ine,Ine,Ine,Ine,Ine,Ine,Ine,Ine,Ine,Ine,Ine,Ine,Ine,Ine,Ine,Ine,Ine,Ine,Ine,Ine,Ine,Ine,Ine,Ine,Ine,Ine,Ine,Ine,Ine,Ine,Ine,Ine,Ine,Ine,Ine,Ine,Ine,Ine,Ine,Ine,Ine,Ine,Ine,Ine,Ine,Ine,Ine,Ine,Ine,Ine,Ine,Ine,Ine,Ine,Ine,Ine,Ine,Ine,Ine,Ine,Ine,Ine,Ine,Ine,Ine,Ine,Ine,Ine,Ine,Ine,Ine,Ine,Ine,Ine,Ine,Ine,Ine,Ine,Ine,Ine,Ine,Ine,Ine,Ine,Ine,Ine,Ine,Ine,Ine,Ine,Ine,Ine,Ine,Ine,Ine,Ine,Ine,Ine,Ine,Ine,Ine,Ine,Ine,Ine,Ine,Ine,Ine,Ine,Ine,Ine,Ine,Ine,Ine,Ine];var _Ai=[Gle,Wle,Kle,Xle,Zle,Jle,Qle,$le,ese,ise,rse,nse,fse,tse,use,ase,ose,cse,lse,sse,bse,kse,hse,wse,dse,vse,mse,_se,pse,Ese,Sse,gse,yse,Fse,Ose,Ase,Mse,Rse,Nse,Tse,Lse,Dse,Cse,Pse,Bse,Ise,Hse,xse,Use,zse,jse,Vse,qse,Yse,Gse,Wse,Kse,Xse,Zse,Jse,Qse,$se,ebe,ibe,rbe,nbe,fbe,tbe,ube,abe,obe,cbe,lbe,sbe,bbe,kbe,hbe,wbe,dbe,vbe,mbe,_be,pbe,Ebe,Sbe,gbe,ybe,Fbe,Obe,Abe,Mbe,Rbe,Nbe,Tbe,Lbe,Dbe,Cbe,Pbe,Bbe,Ibe,Hbe,xbe,Ube,zbe,jbe,Vbe,qbe,Ybe,Gbe,Wbe,Kbe,Xbe,Zbe,Jbe,Qbe,$be,eke,ike,rke,nke,fke,tke,uke,ake,oke,cke,lke,ske,bke,kke,hke,wke,dke,vke,mke,_ke,pke,Eke,Ske,gke,yke,Fke,Oke,Ake,Mke,Rke,Nke,Tke,Lke,Dke,Cke,Pke,Bke,Ike,Hke,xke,Uke,zke,jke,Vke,qke,Yke,Gke,Wke,Kke,Xke,Zke,Jke,Qke,$ke,ehe,ihe,rhe,nhe,fhe,the,uhe,ahe,ohe,che,lhe,she,bhe,khe,hhe,whe,dhe,vhe,mhe,_he,phe,Ehe,She,ghe,yhe,Fhe,Ohe,Ahe,Mhe,Rhe,Nhe,The,Lhe,Dhe,Che,Phe,Bhe,Ihe,Hhe,xhe,Uhe,zhe,jhe,Vhe,qhe,Yhe,Ghe,Whe,Khe,Xhe,Zhe,Jhe,Qhe,$he,ewe,iwe,rwe,FO,nwe,fwe,twe,uwe,awe,owe,cwe,lwe,swe,bwe,kwe,hwe,wwe,dwe,vwe,mwe,_we,pwe,Ewe,Swe,gwe,ywe,Fwe,Owe,Awe,Mwe,Rwe,Nwe,Twe,Lwe,Dwe,Cwe,Pwe,Bwe,Iwe,Hwe,xwe,Uwe,zwe,jwe,Vwe,qwe,Ywe,Gwe,Wwe,Kwe,Xwe,Zwe,Jwe,Qwe,$we,ede,ide,rde,nde,fde,tde,ude,ade,ode,cde,lde,sde,bde,kde,hde,wde,dde,vde,mde,_de,pde,Ede,Sde,gde,yde,Fde,Ode,Ade,Mde,Rde,Nde,Tde,Lde,Dde,Cde,Pde,Bde,Ide,Hde,xde,Ude,zde,jde,Vde,qde,Yde,Gde,Wde,Kde,Xde,Zde,Jde,Qde,$de,eve,ive,rve,nve,fve,tve,uve,ave,ove,cve,lve,sve,bve,kve,hve,wve,dve,vve,mve,_ve,pve,Eve,Sve,gve,yve,Fve,Ove,Ave,Mve,Rve,Nve,Tve,Lve,Dve,Cve,Pve,Bve,Ive,Hve,xve,Uve,zve,jve,Vve,qve,Yve,Gve,Wve,Kve,Xve,Zve,Jve,Qve,$ve,eme,ime,rme,nme,fme,Gle,Gle,Gle,Gle,Gle,Gle,Gle,Gle,Gle,Gle,Gle,Gle,Gle,Gle,Gle,Gle,Gle,Gle,Gle,Gle,Gle,Gle,Gle,Gle,Gle,Gle,Gle,Gle,Gle,Gle,Gle,Gle,Gle,Gle,Gle,Gle,Gle,Gle,Gle,Gle,Gle,Gle,Gle,Gle,Gle,Gle,Gle,Gle,Gle,Gle,Gle,Gle,Gle,Gle,Gle,Gle,Gle,Gle,Gle,Gle,Gle,Gle,Gle,Gle,Gle,Gle,Gle,Gle,Gle,Gle,Gle,Gle,Gle,Gle,Gle,Gle,Gle,Gle,Gle,Gle,Gle,Gle,Gle,Gle,Gle,Gle,Gle,Gle,Gle,Gle,Gle,Gle,Gle,Gle,Gle,Gle,Gle,Gle,Gle,Gle,Gle,Gle,Gle,Gle,Gle,Gle,Gle,Gle,Gle,Gle,Gle,Gle,Gle,Gle,Gle,Gle,Gle,Gle,Gle,Gle];var pAi=[tme,ume,ame,ome,cme,lme,sme,bme,kme,hme,wme,dme,vme,Gm,Wm,mme,_me,pme,Eme,Sme,gme,yme,Fme,Ome,Ame,Mme,Rme,Nme,Tme,Lme,Dme,Zq,Cme,Pme,Bme,Ime,Hme,xme,Ume,zme,jme,Vme,qme,Yme,Gme,Wme,Kme,Xme,jz,Vz,Zme,Jme,Qme,$me,e_e,i_e,r_e,n_e,f_e,t_e,u_e,a_e,o_e,c_e,l_e,s_e,b_e,k_e,h_e,w_e,d_e,v_e,m_e,__e,p_e,E_e,S_e,g_e,y_e,F_e,O_e,A_e,M_e,R_e,N_e,T_e,L_e,D_e,C_e,P_e,B_e,I_e,H_e,x_e,U_e,z_e,j_e,V_e,q_e,Y_e,G_e,W_e,K_e,X_e,Z_e,J_e,Q_e,$_e,epe,ipe,rpe,npe,fpe,tpe,upe,ape,ope,cpe,lpe,spe,bpe,kpe,hpe,wpe,dpe,vpe,mpe,_pe,ppe,Epe,Spe,gpe,ype,Fpe,Ope,Ape,Mpe,Rpe,Npe,Tpe,Lpe,Dpe,Cpe,Ppe,Bpe,Ipe,Hpe,xpe,Upe,zpe,jpe,Vpe,qpe,Ype,Gpe,Wpe,Kpe,Xpe,Zpe,Jpe,Qpe,$pe,eEe,iEe,rEe,nEe,fEe,tEe,uEe,aEe,oEe,cEe,lEe,sEe,bEe,kEe,hEe,wEe,dEe,vEe,mEe,_Ee,pEe,EEe,SEe,gEe,yEe,FEe,OEe,AEe,MEe,REe,NEe,TEe,LEe,am,DEe,CEe,PEe,BEe,bm,km,IEe,HEe,xEe,Em,UEe,zEe,jEe,VEe,qEe,YEe,GEe,WEe,KEe,XEe,ZEe,JEe,QEe,$Ee,eSe,iSe,rSe,nSe,fSe,tSe,LS,uSe,aSe,oSe,cSe,lSe,sSe,bSe,kSe,hSe,wSe,dSe,vSe,mSe,_Se,pSe,FR,ESe,NR,SSe,PR,gSe,ySe,HR,xR,FSe,zR,OSe,ASe,MSe,RSe,NSe,TSe,LSe,_n,DSe,CSe,PSe,BSe,ISe,HSe,xSe,USe,zSe,jSe,VSe,qSe,YSe,GSe,WSe,KSe,XSe,ZSe,JSe,QSe,$Se,ege,ige,rge,nge,fge,tge,uge,age,oge,cge,lge,sge,bge,kge,hge,wge,dge,vge,mge,_ge,pge,Ege,Sge,gge,yge,Fge,Oge,Age,Mge,Rge,Nge,Tge,Lge,vc,Rc,Dge,Cge,Pge,Bge,Ige,Xk,Hge,xge,Uge,zge,jge,Vge,qge,Yge,Gge,Wge,Kge,Xge,Zge,Jge,Qge,$ge,eye,Dh,Ch,iye,rye,nye,fye,tye,uye,aye,oye,cye,lye,sye,bye,kye,hye,$h,wye,dye,vye,Ok,mye,_ye,pye,Eye,Sye,gye,yye,Fye,Oye,Aye,DH,Mye,Rye,Nye,Tye,Lye,Dye,Cye,Pye,Bye,Iye,Hye,xye,Uye,zye,jye,Vye,qye,Yye,Gye,Wye,tme,tme,tme,tme,tme,tme,tme,tme,tme,tme,tme,tme,tme,tme,tme,tme,tme,tme,tme,tme,tme,tme,tme,tme,tme,tme,tme,tme,tme,tme,tme,tme,tme,tme,tme,tme,tme,tme,tme,tme,tme,tme,tme,tme,tme,tme,tme,tme,tme,tme,tme,tme,tme,tme,tme,tme,tme,tme,tme,tme,tme,tme,tme,tme,tme,tme,tme,tme,tme,tme,tme,tme,tme,tme,tme,tme,tme,tme,tme,tme,tme,tme,tme,tme,tme,tme,tme,tme,tme,tme,tme,tme,tme,tme,tme,tme,tme,tme,tme,tme,tme,tme,tme,tme,tme,tme,tme,tme,tme,tme,tme,tme,tme,tme,tme,tme,tme,tme,tme,tme];var EAi=[Kye,Xye,Zye,Jye,Qye,$ye,eFe,iFe,rFe,nFe,fFe,tFe,Ym,uFe,aFe,oFe,c_,Km,cFe,lFe,sFe,Qm,bFe,kFe,hFe,wFe,dFe,vFe,mFe,_Fe,pFe,EFe,SFe,gFe,yFe,FFe,OFe,AFe,MFe,RFe,NFe,TFe,LFe,DFe,CFe,PFe,BFe,zz,IFe,HFe,xFe,Yz,Kz,UFe,zFe,Qz,jFe,VFe,qFe,YFe,GFe,WFe,KFe,XFe,ZFe,JFe,QFe,$Fe,eOe,iOe,rOe,nOe,fOe,tOe,uOe,aOe,oOe,cOe,lOe,sOe,bOe,kOe,hOe,wOe,dOe,vOe,mOe,_Oe,pOe,EOe,SOe,gOe,yOe,FOe,OOe,AOe,MOe,ROe,NOe,TOe,LOe,DOe,COe,POe,BOe,IOe,HOe,xOe,UOe,zOe,jOe,VOe,qOe,YOe,GOe,WOe,KOe,XOe,ZOe,JOe,QOe,$Oe,eAe,iAe,rAe,nAe,fAe,tAe,uAe,aAe,oAe,cAe,lAe,sAe,bAe,kAe,hAe,wAe,dAe,vAe,mAe,_Ae,pAe,EAe,SAe,gAe,yAe,FAe,OAe,AAe,MAe,RAe,NAe,TAe,LAe,DAe,CAe,PAe,BAe,IAe,HAe,xAe,UAe,zAe,jAe,VAe,qAe,YAe,GAe,WAe,KAe,XAe,ZAe,JAe,QAe,$Ae,eMe,iMe,rMe,nMe,fMe,tMe,uMe,aMe,oMe,cMe,lMe,sMe,bMe,kMe,hMe,wMe,dMe,vMe,mMe,_Me,pMe,EMe,SMe,gMe,yMe,FMe,OMe,AMe,MMe,RMe,NMe,TMe,LMe,DMe,CMe,O_,PMe,BMe,IMe,HMe,xMe,UMe,zMe,jMe,VMe,qMe,YMe,GMe,WMe,KMe,XMe,ZMe,JMe,QMe,$Me,eRe,iRe,rRe,nRe,fRe,tRe,uRe,aRe,oRe,cRe,lRe,sRe,bRe,kRe,hRe,wRe,dRe,IR,vRe,mRe,_Re,pRe,ERe,SRe,gRe,yRe,FRe,ORe,Xr,ARe,tt,bt,Yf,Jf,Qf,Gf,ot,st,Vf,ct,Wf,ut,Yt,Kf,nt,gf,qf,kt,Xf,Zf,$f,et,it,rt,lt,at,ft,Gt,MRe,RRe,NRe,TRe,LRe,DRe,CRe,PRe,BRe,IRe,HRe,xRe,URe,zRe,jRe,VRe,qRe,za,Wa,Ka,Xa,Za,Ja,Qa,$a,YRe,GRe,WRe,KRe,XRe,ZRe,JRe,QRe,$Re,eNe,iNe,rNe,nNe,ph,fNe,tNe,uNe,aNe,oNe,cNe,lNe,sNe,bNe,kNe,hNe,Lh,wNe,dNe,vNe,Bh,mNe,_Ne,pNe,ENe,SNe,gNe,yNe,FNe,Yh,ONe,ANe,MNe,RNe,td,NNe,aT,TNe,LNe,lH,DNe,CNe,PNe,BNe,INe,HNe,xNe,mH,UNe,zNe,jNe,VNe,qNe,fx,YNe,GNe,WNe,cx,KNe,XNe,ZNe,JNe,QNe,$Ne,eTe,iTe,rTe,nTe,fTe,Kye,Kye,Kye,Kye,Kye,Kye,Kye,Kye,Kye,Kye,Kye,Kye,Kye,Kye,Kye,Kye,Kye,Kye,Kye,Kye,Kye,Kye,Kye,Kye,Kye,Kye,Kye,Kye,Kye,Kye,Kye,Kye,Kye,Kye,Kye,Kye,Kye,Kye,Kye,Kye,Kye,Kye,Kye,Kye,Kye,Kye,Kye,Kye,Kye,Kye,Kye,Kye,Kye,Kye,Kye,Kye,Kye,Kye,Kye,Kye,Kye,Kye,Kye,Kye,Kye,Kye,Kye,Kye,Kye,Kye,Kye,Kye,Kye,Kye,Kye,Kye,Kye,Kye,Kye,Kye,Kye,Kye,Kye,Kye,Kye,Kye,Kye,Kye,Kye,Kye,Kye,Kye,Kye,Kye,Kye,Kye,Kye,Kye,Kye,Kye,Kye,Kye,Kye,Kye,Kye,Kye,Kye,Kye,Kye,Kye,Kye,Kye,Kye,Kye,Kye,Kye,Kye,Kye,Kye,Kye];var SAi=[tTe,uTe,aTe,oTe,cTe,lTe,sTe,bTe,kTe,hTe,wTe,dTe,vTe,mTe,_Te,pTe,ETe,STe,gTe,yTe,FTe,OTe,ATe,MTe,RTe,NTe,TTe,LTe,DTe,CTe,PTe,BTe,ITe,HTe,xTe,UTe,zTe,jTe,VTe,qTe,YTe,GTe,WTe,KTe,XTe,ZTe,JTe,QTe,$Te,eLe,iLe,rLe,nLe,fLe,tLe,uLe,aLe,oLe,cLe,lLe,sLe,bLe,kLe,hLe,wLe,dLe,vLe,mLe,_Le,pLe,ELe,SLe,gLe,yLe,FLe,OLe,ALe,MLe,RLe,NLe,TLe,LLe,DLe,CLe,PLe,BLe,ILe,HLe,xLe,ULe,zLe,jLe,VLe,qLe,YLe,GLe,WLe,KLe,XLe,ZLe,JLe,QLe,$Le,eDe,iDe,rDe,nDe,fDe,tDe,uDe,aDe,oDe,cDe,lDe,sDe,bDe,kDe,hDe,wDe,dDe,vDe,mDe,_De,pDe,EDe,SDe,gDe,yDe,FDe,ODe,ADe,MDe,RDe,NDe,TDe,LDe,DDe,CDe,PDe,BDe,IDe,HDe,xDe,UDe,zDe,jDe,VDe,qDe,YDe,GDe,WDe,KDe,XDe,ZDe,JDe,QDe,$De,eCe,iCe,rCe,nCe,fCe,tCe,uCe,aCe,oCe,cCe,lCe,sCe,bCe,kCe,hCe,wCe,dCe,vCe,mCe,_Ce,pCe,ECe,SCe,gCe,yCe,FCe,OCe,ACe,MCe,RCe,NCe,TCe,LCe,DCe,CCe,PCe,BCe,ICe,HCe,xCe,UCe,zCe,jCe,VCe,qCe,YCe,GCe,WCe,KCe,XCe,ZCe,JCe,QCe,$Ce,ePe,iPe,rPe,nPe,fPe,tPe,uPe,aPe,oPe,cPe,lPe,sPe,bPe,kPe,hPe,wPe,dPe,vPe,mPe,_Pe,pPe,EPe,SPe,gPe,yPe,FPe,OPe,APe,MPe,RPe,NPe,TPe,LPe,DPe,CPe,PPe,BPe,IPe,HPe,xPe,UPe,zPe,jPe,VPe,qPe,YPe,GPe,WPe,KPe,XPe,ZPe,JPe,QPe,$Pe,eBe,iBe,rBe,nBe,fBe,tBe,uBe,aBe,oBe,cBe,lBe,sBe,bBe,kBe,hBe,wBe,dBe,vBe,mBe,_Be,pBe,EBe,SBe,gBe,yBe,FBe,OBe,ABe,MBe,RBe,NBe,TBe,LBe,DBe,CBe,PBe,BBe,IBe,HBe,xBe,UBe,zBe,jBe,VBe,qBe,YBe,GBe,WBe,KBe,XBe,ZBe,JBe,QBe,$Be,eIe,iIe,rIe,nIe,fIe,tIe,uIe,aIe,oIe,cIe,lIe,sIe,bIe,kIe,hIe,wIe,dIe,vIe,mIe,_Ie,pIe,EIe,SIe,gIe,yIe,FIe,OIe,AIe,MIe,RIe,NIe,TIe,LIe,DIe,CIe,PIe,BIe,IIe,HIe,xIe,UIe,zIe,jIe,VIe,qIe,YIe,GIe,WIe,KIe,XIe,ZIe,JIe,QIe,$Ie,eHe,iHe,nx,rHe,nHe,fHe,tHe,uHe,aHe,oHe,cHe,lHe,sHe,bHe,kHe,hHe,wHe,dHe,vHe,tTe,tTe,tTe,tTe,tTe,tTe,tTe,tTe,tTe,tTe,tTe,tTe,tTe,tTe,tTe,tTe,tTe,tTe,tTe,tTe,tTe,tTe,tTe,tTe,tTe,tTe,tTe,tTe,tTe,tTe,tTe,tTe,tTe,tTe,tTe,tTe,tTe,tTe,tTe,tTe,tTe,tTe,tTe,tTe,tTe,tTe,tTe,tTe,tTe,tTe,tTe,tTe,tTe,tTe,tTe,tTe,tTe,tTe,tTe,tTe,tTe,tTe,tTe,tTe,tTe,tTe,tTe,tTe,tTe,tTe,tTe,tTe,tTe,tTe,tTe,tTe,tTe,tTe,tTe,tTe,tTe,tTe,tTe,tTe,tTe,tTe,tTe,tTe,tTe,tTe,tTe,tTe,tTe,tTe,tTe,tTe,tTe,tTe,tTe,tTe,tTe,tTe,tTe,tTe,tTe,tTe,tTe,tTe,tTe,tTe,tTe,tTe,tTe,tTe,tTe,tTe,tTe,tTe,tTe,tTe];var gAi=[mHe,_He,Pm,Bm,Im,pHe,EHe,SHe,gHe,yHe,FHe,OHe,AHe,MHe,RHe,NHe,THe,LHe,DHe,CHe,PHe,BHe,IHe,HHe,xHe,UHe,zHe,jHe,VHe,qHe,YHe,GHe,Xq,WHe,Yl,KHe,XHe,Mz,Rz,Nz,ZHe,JHe,QHe,$He,exe,ixe,rxe,nxe,fxe,txe,uxe,axe,oxe,cxe,lxe,sxe,bxe,kxe,hxe,wxe,dxe,yz,Fz,Oz,Az,vxe,OC,AC,MC,RC,NC,TC,LC,DC,CC,PC,BC,IC,HC,xC,UC,zC,jC,VC,qC,YC,GC,WC,KC,XC,ZC,JC,QC,$C,eP,iP,rP,nP,fP,tP,uP,aP,oP,cP,lP,sP,bP,kP,hP,wP,dP,vP,mP,_P,pP,EP,SP,gP,yP,FP,OP,AP,MP,RP,NP,TP,LP,DP,CP,PP,BP,IP,HP,xP,UP,zP,jP,VP,qP,YP,GP,WP,KP,XP,ZP,JP,QP,$P,eB,iB,rB,nB,fB,tB,uB,aB,oB,cB,lB,sB,bB,kB,hB,wB,dB,vB,mB,_B,pB,EB,SB,gB,yB,FB,OB,AB,MB,RB,NB,TB,LB,DB,CB,PB,BB,IB,HB,xB,UB,zB,jB,VB,qB,YB,mxe,_xe,om,pxe,lm,Exe,Sxe,gxe,yxe,Fxe,Oxe,Axe,Mxe,Rxe,Nxe,Txe,Am,Lxe,A_,Dxe,Cxe,Pxe,Bxe,Ixe,Hxe,xxe,Uxe,zxe,jxe,Vxe,qxe,Yxe,Gxe,Wxe,Kxe,Xxe,OO,AO,Zxe,RO,sA,Jxe,hA,Qxe,dA,$xe,eUe,iUe,rUe,OR,nUe,DR,fUe,BR,tUe,uUe,aUe,oUe,cUe,lUe,sUe,bUe,kUe,hUe,wUe,dUe,vUe,mUe,_Ue,pUe,EUe,SUe,gUe,yUe,FUe,OUe,AUe,MUe,RUe,NUe,TUe,LUe,DUe,CUe,PUe,BUe,IUe,HUe,xUe,UUe,zUe,jUe,VUe,qUe,YUe,GUe,WUe,KUe,XUe,ZUe,JUe,QUe,$Ue,eze,ize,rze,nze,fze,tze,uze,aze,oze,cze,lze,sze,bze,kze,hze,wze,dze,vze,mze,_ze,pze,Eze,Sze,gze,yze,Fze,Oze,Aze,Mze,Rze,Nze,Tze,Sh,gh,yh,Lze,Dze,Cze,Pze,Bze,Ize,Hze,xze,Uze,zze,jze,Vze,qze,Yze,Gze,Wze,Kze,Xze,Zze,Jze,Qze,$ze,eje,ije,rje,nje,fje,tje,uje,aje,oje,cje,lje,sje,bje,kje,hje,wje,dje,vje,mje,_je,pje,Eje,Sje,gje,yje,Fje,Oje,Aje,Mje,Rje,Nje,Tje,Lje,Dje,Cje,Pje,Bje,Ije,mHe,mHe,mHe,mHe,mHe,mHe,mHe,mHe,mHe,mHe,mHe,mHe,mHe,mHe,mHe,mHe,mHe,mHe,mHe,mHe,mHe,mHe,mHe,mHe,mHe,mHe,mHe,mHe,mHe,mHe,mHe,mHe,mHe,mHe,mHe,mHe,mHe,mHe,mHe,mHe,mHe,mHe,mHe,mHe,mHe,mHe,mHe,mHe,mHe,mHe,mHe,mHe,mHe,mHe,mHe,mHe,mHe,mHe,mHe,mHe,mHe,mHe,mHe,mHe,mHe,mHe,mHe,mHe,mHe,mHe,mHe,mHe,mHe,mHe,mHe,mHe,mHe,mHe,mHe,mHe,mHe,mHe,mHe,mHe,mHe,mHe,mHe,mHe,mHe,mHe,mHe,mHe,mHe,mHe,mHe,mHe,mHe,mHe,mHe,mHe,mHe,mHe,mHe,mHe,mHe,mHe,mHe,mHe,mHe,mHe,mHe,mHe,mHe,mHe,mHe,mHe,mHe,mHe,mHe,mHe];var yAi=[Hje,xje,Uje,zje,jje,Vje,qje,Yje,Gje,Wje,Kje,Xje,Zje,Jje,Qje,o_,$je,eVe,Xm,Zm,Jm,iVe,$m,e_,i_,rVe,n_,nVe,fVe,tVe,uVe,aVe,oVe,cVe,lVe,tp,sVe,bVe,kVe,hVe,wVe,dVe,vVe,mVe,_Ve,pVe,EVe,SVe,gVe,yVe,qz,FVe,OVe,Xz,Jz,AVe,kp,bp,MVe,$z,RVe,NVe,TVe,LVe,DVe,Zz,CVe,PVe,BVe,IVe,HVe,xVe,UVe,zVe,jVe,VVe,qVe,YVe,GVe,WVe,KVe,XVe,ZVe,JVe,QVe,$Ve,eqe,iqe,rqe,nqe,fqe,tqe,uqe,aqe,oqe,cqe,lqe,sqe,bqe,kqe,hqe,wqe,dqe,vqe,mqe,_qe,pqe,Eqe,Sqe,gqe,yqe,Fqe,Oqe,Aqe,Mqe,Rqe,Nqe,Tqe,Lqe,Dqe,Cqe,Pqe,Bqe,Iqe,Hqe,xqe,Uqe,zqe,jqe,Vqe,qqe,Yqe,Gqe,Wqe,Kqe,Xqe,Zqe,Jqe,Qqe,$qe,eYe,iYe,rYe,nYe,fYe,tYe,uYe,aYe,oYe,cYe,lYe,sYe,bYe,kYe,hYe,wYe,dYe,vYe,mYe,_Ye,pYe,EYe,SYe,gYe,yYe,FYe,OYe,AYe,MYe,RYe,NYe,TYe,LYe,DYe,CYe,PYe,BYe,IYe,HYe,xYe,UYe,zYe,jYe,VYe,qYe,YYe,GYe,WYe,KYe,XYe,ZYe,JYe,QYe,$Ye,eGe,iGe,rGe,nGe,fGe,tGe,uGe,aGe,oGe,cGe,lGe,sGe,Sm,gm,ym,Fm,bGe,kGe,hGe,wGe,dGe,vGe,mGe,_Ge,pGe,EGe,SGe,gGe,yGe,FGe,hp,wp,OGe,AGe,MGe,RGe,NGe,TGe,LGe,DGe,CGe,PGe,BGe,IGe,HGe,xGe,UGe,zGe,jGe,VGe,qGe,YGe,GGe,WGe,KGe,XGe,ZGe,JGe,QGe,GR,iN,rN,nN,fN,$Ge,eWe,iWe,rWe,nWe,fWe,tWe,uWe,aWe,oWe,cWe,lWe,sWe,bWe,kWe,hWe,wWe,dWe,vWe,mWe,_We,pWe,EWe,SWe,gWe,yWe,FWe,OWe,AWe,MWe,RWe,NWe,TWe,LWe,DWe,CWe,PWe,BWe,IWe,HWe,xWe,UWe,zWe,jWe,VWe,qWe,YWe,GWe,WWe,KWe,XWe,ZWe,JWe,QWe,$We,eKe,Qo,iKe,rKe,nKe,fKe,tKe,uKe,aKe,oKe,cKe,lKe,mh,_h,sKe,bKe,kKe,hKe,wKe,dKe,vKe,mKe,_Ke,pKe,EKe,SKe,gKe,yKe,FKe,Ph,OKe,Ih,Hh,xh,AKe,MKe,jh,Vh,qh,RKe,NKe,TKe,LKe,DKe,CKe,PKe,BKe,IKe,cH,HKe,xKe,UKe,kH,hH,dH,vH,zKe,jKe,VKe,qKe,YKe,GKe,WKe,KKe,XKe,ZKe,JKe,QKe,wx,$Ke,oU,cU,eXe,tz,iXe,rXe,nXe,fXe,tXe,Hje,Hje,Hje,Hje,Hje,Hje,Hje,Hje,Hje,Hje,Hje,Hje,Hje,Hje,Hje,Hje,Hje,Hje,Hje,Hje,Hje,Hje,Hje,Hje,Hje,Hje,Hje,Hje,Hje,Hje,Hje,Hje,Hje,Hje,Hje,Hje,Hje,Hje,Hje,Hje,Hje,Hje,Hje,Hje,Hje,Hje,Hje,Hje,Hje,Hje,Hje,Hje,Hje,Hje,Hje,Hje,Hje,Hje,Hje,Hje,Hje,Hje,Hje,Hje,Hje,Hje,Hje,Hje,Hje,Hje,Hje,Hje,Hje,Hje,Hje,Hje,Hje,Hje,Hje,Hje,Hje,Hje,Hje,Hje,Hje,Hje,Hje,Hje,Hje,Hje,Hje,Hje,Hje,Hje,Hje,Hje,Hje,Hje,Hje,Hje,Hje,Hje,Hje,Hje,Hje,Hje,Hje,Hje,Hje,Hje,Hje,Hje,Hje,Hje,Hje,Hje,Hje,Hje,Hje,Hje];var FAi=[uXe,aXe,oXe,cXe,lXe,sXe,bXe,kXe,hXe,wXe,dXe,vXe,mXe,_Xe,pXe,EXe,SXe,gXe,yXe,FXe,OXe,AXe,MXe,RXe,NXe,TXe,LXe,DXe,t_,CXe,PXe,BXe,IXe,HXe,xXe,UXe,zXe,jXe,VXe,qXe,YXe,GXe,WXe,KXe,XXe,ZXe,JXe,QXe,$Xe,eZe,iZe,rZe,nZe,fZe,tZe,uZe,aZe,oZe,cZe,lZe,sZe,bZe,kZe,hZe,wZe,dZe,vZe,mZe,_Ze,pZe,EZe,SZe,gZe,yZe,FZe,OZe,AZe,MZe,RZe,NZe,TZe,LZe,DZe,CZe,PZe,BZe,IZe,HZe,xZe,UZe,zZe,jZe,VZe,qZe,YZe,GZe,WZe,KZe,XZe,ZZe,JZe,QZe,$Ze,eJe,iJe,rJe,nJe,fJe,tJe,uJe,aJe,oJe,cJe,lJe,sJe,bJe,kJe,hJe,wJe,dJe,vJe,mJe,_Je,pJe,EJe,SJe,gJe,yJe,FJe,OJe,AJe,MJe,RJe,NJe,TJe,LJe,DJe,CJe,PJe,BJe,IJe,HJe,xJe,UJe,zJe,jJe,VJe,qJe,YJe,GJe,WJe,KJe,XJe,ZJe,JJe,QJe,$Je,eQe,iQe,rQe,nQe,fQe,tQe,uQe,aQe,oQe,cQe,lQe,sQe,bQe,kQe,hQe,wQe,dQe,vQe,mQe,_Qe,pQe,EQe,SQe,gQe,yQe,FQe,OQe,AQe,MQe,RQe,NQe,TQe,LQe,DQe,CQe,PQe,BQe,IQe,HQe,xQe,UQe,zQe,jQe,VQe,qQe,YQe,GQe,WQe,KQe,XQe,ZQe,JQe,QQe,$Qe,e$e,i$e,r$e,n$e,f$e,t$e,u$e,a$e,o$e,c$e,l$e,s$e,b$e,k$e,h$e,w$e,d$e,v$e,m$e,_$e,p$e,E$e,S$e,g$e,y$e,F$e,O$e,A$e,M$e,R$e,N$e,T$e,L$e,D$e,C$e,P$e,B$e,I$e,H$e,x$e,U$e,z$e,j$e,V$e,q$e,Y$e,G$e,W$e,K$e,X$e,Z$e,J$e,Q$e,$$e,e0e,i0e,r0e,n0e,f0e,t0e,u0e,a0e,o0e,c0e,l0e,s0e,b0e,k0e,h0e,w0e,d0e,v0e,m0e,_0e,p0e,E0e,S0e,g0e,y0e,F0e,O0e,A0e,M0e,R0e,N0e,T0e,L0e,D0e,C0e,P0e,B0e,I0e,H0e,x0e,U0e,z0e,j0e,V0e,q0e,Y0e,G0e,W0e,K0e,X0e,Z0e,J0e,Q0e,$0e,e1e,i1e,r1e,n1e,dh,f1e,t1e,u1e,a1e,o1e,c1e,l1e,s1e,b1e,k1e,h1e,w1e,d1e,v1e,m1e,_1e,p1e,E1e,S1e,g1e,y1e,F1e,O1e,A1e,M1e,R1e,N1e,T1e,L1e,Gh,D1e,C1e,P1e,B1e,I1e,H1e,x1e,U1e,z1e,sH,j1e,V1e,q1e,Y1e,G1e,W1e,K1e,X1e,Z1e,J1e,Q1e,$1e,e2e,i2e,r2e,n2e,f2e,t2e,u2e,a2e,o2e,c2e,l2e,Gz,s2e,b2e,k2e,h2e,uXe,uXe,uXe,uXe,uXe,uXe,uXe,uXe,uXe,uXe,uXe,uXe,uXe,uXe,uXe,uXe,uXe,uXe,uXe,uXe,uXe,uXe,uXe,uXe,uXe,uXe,uXe,uXe,uXe,uXe,uXe,uXe,uXe,uXe,uXe,uXe,uXe,uXe,uXe,uXe,uXe,uXe,uXe,uXe,uXe,uXe,uXe,uXe,uXe,uXe,uXe,uXe,uXe,uXe,uXe,uXe,uXe,uXe,uXe,uXe,uXe,uXe,uXe,uXe,uXe,uXe,uXe,uXe,uXe,uXe,uXe,uXe,uXe,uXe,uXe,uXe,uXe,uXe,uXe,uXe,uXe,uXe,uXe,uXe,uXe,uXe,uXe,uXe,uXe,uXe,uXe,uXe,uXe,uXe,uXe,uXe,uXe,uXe,uXe,uXe,uXe,uXe,uXe,uXe,uXe,uXe,uXe,uXe,uXe,uXe,uXe,uXe,uXe,uXe,uXe,uXe,uXe,uXe,uXe,uXe];var OAi=[w2e,d2e,v2e,m2e,_2e,p2e,E2e,S2e,g2e,y2e,F2e,O2e,A2e,M2e,R2e,N2e,T2e,L2e,D2e,C2e,P2e,B2e,I2e,H2e,x2e,U2e,z2e,j2e,V2e,q2e,Y2e,G2e,W2e,K2e,X2e,Z2e,J2e,Q2e,$2e,e3e,i3e,r3e,n3e,f3e,t3e,u3e,a3e,o3e,c3e,l3e,s3e,b3e,k3e,h3e,w3e,d3e,v3e,m3e,_3e,p3e,E3e,S3e,g3e,y3e,F3e,O3e,A3e,M3e,R3e,N3e,T3e,L3e,D3e,C3e,P3e,B3e,I3e,H3e,x3e,U3e,z3e,j3e,V3e,q3e,Y3e,G3e,W3e,K3e,X3e,Z3e,J3e,Q3e,$3e,e4e,i4e,r4e,n4e,f4e,t4e,u4e,a4e,o4e,c4e,l4e,s4e,b4e,k4e,h4e,w4e,d4e,v4e,m4e,_4e,p4e,E4e,S4e,g4e,y4e,F4e,O4e,A4e,M4e,R4e,N4e,T4e,L4e,D4e,C4e,P4e,B4e,I4e,H4e,x4e,U4e,z4e,j4e,V4e,q4e,Y4e,G4e,W4e,K4e,X4e,Z4e,J4e,Q4e,$4e,e8e,i8e,r8e,n8e,f8e,t8e,u8e,a8e,o8e,c8e,l8e,s8e,b8e,k8e,h8e,w8e,d8e,v8e,m8e,_8e,p8e,E8e,S8e,g8e,y8e,F8e,O8e,A8e,M8e,R8e,N8e,T8e,L8e,D8e,C8e,P8e,B8e,I8e,H8e,x8e,U8e,z8e,j8e,V8e,q8e,Y8e,G8e,W8e,K8e,X8e,Z8e,J8e,Q8e,$8e,e6e,i6e,r6e,n6e,f6e,t6e,u6e,a6e,o6e,c6e,l6e,s6e,Z_,J_,Q_,$_,ep,ip,N_,T_,rp,np,dN,b6e,k6e,h6e,w6e,d6e,v6e,m6e,_6e,p6e,E6e,S6e,g6e,y6e,F6e,O6e,A6e,M6e,_A,R6e,N6e,T6e,L6e,D6e,C6e,P6e,B6e,I6e,H6e,x6e,U6e,z6e,j6e,V6e,q6e,Y6e,G6e,W6e,K6e,X6e,Z6e,J6e,Q6e,$6e,e5e,i5e,r5e,n5e,f5e,t5e,u5e,a5e,o5e,c5e,l5e,s5e,b5e,k5e,h5e,w5e,d5e,v5e,m5e,_5e,p5e,E5e,S5e,g5e,y5e,F5e,O5e,A5e,M5e,R5e,N5e,T5e,L5e,D5e,C5e,P5e,B5e,I5e,H5e,x5e,U5e,z5e,j5e,V5e,q5e,Y5e,G5e,W5e,K5e,X5e,Z5e,J5e,Q5e,$5e,e9e,i9e,r9e,n9e,f9e,t9e,u9e,a9e,o9e,c9e,l9e,s9e,b9e,k9e,h9e,w9e,d9e,v9e,m9e,_9e,p9e,E9e,S9e,g9e,y9e,F9e,O9e,A9e,M9e,R9e,N9e,T9e,L9e,D9e,C9e,P9e,B9e,I9e,H9e,x9e,U9e,z9e,j9e,V9e,q9e,Y9e,G9e,W9e,K9e,X9e,Z9e,J9e,Q9e,$9e,e7e,i7e,r7e,n7e,f7e,t7e,u7e,a7e,o7e,c7e,l7e,s7e,b7e,k7e,PV,h7e,w7e,w2e,w2e,w2e,w2e,w2e,w2e,w2e,w2e,w2e,w2e,w2e,w2e,w2e,w2e,w2e,w2e,w2e,w2e,w2e,w2e,w2e,w2e,w2e,w2e,w2e,w2e,w2e,w2e,w2e,w2e,w2e,w2e,w2e,w2e,w2e,w2e,w2e,w2e,w2e,w2e,w2e,w2e,w2e,w2e,w2e,w2e,w2e,w2e,w2e,w2e,w2e,w2e,w2e,w2e,w2e,w2e,w2e,w2e,w2e,w2e,w2e,w2e,w2e,w2e,w2e,w2e,w2e,w2e,w2e,w2e,w2e,w2e,w2e,w2e,w2e,w2e,w2e,w2e,w2e,w2e,w2e,w2e,w2e,w2e,w2e,w2e,w2e,w2e,w2e,w2e,w2e,w2e,w2e,w2e,w2e,w2e,w2e,w2e,w2e,w2e,w2e,w2e,w2e,w2e,w2e,w2e,w2e,w2e,w2e,w2e,w2e,w2e,w2e,w2e,w2e,w2e,w2e,w2e,w2e,w2e];var AAi=[d7e,v7e,m7e,_7e,p7e,E7e,S7e,Um,g7e,y7e,F7e,O7e,A7e,M7e,R7e,N7e,T7e,L7e,D7e,C7e,P7e,B7e,I7e,H7e,x7e,U7e,z7e,j7e,V7e,q7e,Y7e,G7e,W7e,K7e,X7e,Z7e,J7e,Q7e,$7e,eei,iei,rei,Bz,nei,fei,tei,uei,aei,oei,cei,lei,sei,bei,kei,hei,wei,dei,vei,mei,_ei,pei,Eei,Sei,gei,yei,Fei,Oei,Aei,Mei,Rei,Nei,Tei,Lei,Dei,Cei,Pei,Bei,Iei,Hei,xei,Uei,zei,jei,Vei,qei,Yei,Gei,Wei,Kei,Xei,Zei,Jei,Qei,$ei,eii,iii,rii,nii,fii,tii,uii,aii,oii,cii,lii,sii,bii,kii,hii,wii,dii,vii,mii,_ii,pii,Eii,Sii,gii,yii,Fii,Oii,Aii,Mii,Rii,Nii,Tii,Lii,Dii,Cii,Pii,Bii,Iii,Hii,xii,Uii,zii,jii,Vii,qii,Yii,Gii,Wii,Kii,Xii,Zii,Jii,Qii,$ii,eri,iri,rri,nri,fri,tri,uri,ari,ori,cri,lri,sri,bri,kri,hri,wri,dri,vri,mri,_ri,pri,Eri,Sri,gri,yri,Fri,Ori,Ari,Mri,Rri,Nri,Tri,Lri,Dri,Cri,Pri,Bri,Iri,Hri,xri,Uri,zri,jri,Vri,qri,Yri,Gri,Wri,Kri,Xri,Zri,Jri,Qri,$ri,eni,ini,rni,nni,fni,tni,uni,ani,oni,cni,lni,sni,bni,kni,hni,wni,dni,vni,mni,_ni,pni,Eni,Sni,gni,yni,Fni,Oni,Ani,Mni,Rni,Nni,Tni,Lni,Dni,Cni,Pni,Bni,Ini,Hni,xni,Uni,zni,jni,Vni,qni,Yni,Gni,Wni,Kni,Xni,Zni,Jni,Qni,$ni,efi,ifi,rfi,nfi,ffi,tfi,ufi,afi,ofi,cfi,lfi,sfi,bfi,kfi,hfi,wfi,dfi,vfi,mfi,_fi,pfi,Efi,Sfi,gfi,yfi,Ffi,Ofi,Afi,Mfi,Rfi,Nfi,Tfi,Lfi,Dfi,Cfi,Pfi,Bfi,Ifi,Hfi,xfi,Ufi,zfi,jfi,Vfi,qfi,Yfi,Gfi,Wfi,Kfi,Xfi,Zfi,Jfi,Qfi,$fi,eti,iti,rti,nti,fti,tti,uti,ati,oti,cti,lti,sti,bti,kti,hti,wti,dti,vti,mti,_ti,pti,Eti,Sti,gti,Ah,yti,Fti,Oti,Ati,Mti,Rti,Nti,Tti,Lti,Dti,Cti,Pti,Bti,Iti,Hti,xti,Uti,zti,jti,Vti,qti,Yti,Gti,Wti,Kti,Xti,Zti,Jti,Qti,$ti,eui,iui,rui,nui,fui,tui,uui,aui,oui,cui,lui,sui,bui,kui,hui,wui,dui,vui,mui,_ui,pui,Eui,Sui,gui,yui,Fui,Oui,d7e,d7e,d7e,d7e,d7e,d7e,d7e,d7e,d7e,d7e,d7e,d7e,d7e,d7e,d7e,d7e,d7e,d7e,d7e,d7e,d7e,d7e,d7e,d7e,d7e,d7e,d7e,d7e,d7e,d7e,d7e,d7e,d7e,d7e,d7e,d7e,d7e,d7e,d7e,d7e,d7e,d7e,d7e,d7e,d7e,d7e,d7e,d7e,d7e,d7e,d7e,d7e,d7e,d7e,d7e,d7e,d7e,d7e,d7e,d7e,d7e,d7e,d7e,d7e,d7e,d7e,d7e,d7e,d7e,d7e,d7e,d7e,d7e,d7e,d7e,d7e,d7e,d7e,d7e,d7e,d7e,d7e,d7e,d7e,d7e,d7e,d7e,d7e,d7e,d7e,d7e,d7e,d7e,d7e,d7e,d7e,d7e,d7e,d7e,d7e,d7e,d7e,d7e,d7e,d7e,d7e,d7e,d7e,d7e,d7e,d7e,d7e,d7e,d7e,d7e,d7e,d7e,d7e,d7e,d7e];
	var MAi=[Aui,Mui,Rui,Nui,Tui,Lui,xm,Dui,Cui,Pui,Bui,Iui,Hui,xui,Uui,zui,jui,Vui,qui,Yui,Gui,Wui,Kui,Xui,Zui,r_,Jui,Qui,$ui,eai,iai,rai,nai,Jq,fai,tai,uai,aai,oai,cai,lai,Cz,sai,bai,kai,hai,wai,dai,vai,mai,_ai,pai,Eai,Sai,gai,yai,Fai,Oai,Pz,Aai,Mai,Rai,Nai,Tai,Lai,Dai,Cai,Pai,Bai,Iai,Hai,xai,Uai,zai,jai,Vai,qai,Yai,Gai,Wai,Kai,Xai,Zai,Jai,Qai,$ai,eoi,ioi,roi,noi,foi,toi,uoi,aoi,ooi,coi,loi,soi,boi,koi,hoi,woi,doi,voi,moi,_oi,poi,Eoi,Soi,goi,yoi,Foi,Ooi,Aoi,Moi,Roi,Noi,Toi,Loi,Doi,Coi,Poi,Boi,Ioi,Hoi,xoi,Uoi,zoi,joi,Voi,qoi,Yoi,Goi,Woi,Koi,Xoi,Zoi,Joi,Qoi,$oi,eci,ici,rci,nci,fci,tci,uci,aci,oci,cci,lci,sci,bci,kci,hci,wci,dci,vci,mci,_ci,pci,Eci,Sci,gci,yci,Fci,Oci,Aci,Mci,Rci,Nci,Tci,Lci,Dci,Cci,Pci,Bci,Ici,Hci,xci,Uci,zci,jci,Vci,qci,Yci,Gci,Wci,Kci,Xci,Zci,Jci,Qci,$ci,eli,ili,rli,cm,nli,fli,tli,uli,ali,oli,cli,lli,sli,bli,kli,hli,wli,dli,vli,mli,_li,pli,Eli,Sli,gli,yli,Fli,Oli,Ali,Mli,Rli,Nli,Tli,Lli,Dli,Cli,Pli,Bli,Ili,Hli,xli,Uli,zli,jli,Vli,qli,Yli,Gli,Wli,Kli,Xli,Zli,Jli,Qli,$li,esi,isi,UR,rsi,nsi,fsi,tsi,usi,asi,lN,osi,csi,lsi,ssi,bsi,ksi,hsi,wsi,dsi,vsi,msi,_si,psi,Esi,Ssi,gsi,ysi,Fsi,Osi,Asi,Msi,Rsi,Nsi,Tsi,Lsi,Dsi,Csi,Psi,Bsi,Isi,Hsi,Pf,Bf,zf,xsi,ea,Tf,Lf,Df,xf,If,Uf,Cf,ia,Hf,Nf,Cn,Usi,zsi,jsi,Vsi,qsi,Ysi,Gsi,Wsi,Ksi,Xsi,Zsi,Jsi,Ll,Bl,Hl,jl,Qsi,$si,ebi,ibi,rbi,nbi,fbi,tbi,ubi,abi,obi,Oh,cbi,lbi,sbi,bbi,kbi,hbi,wbi,dbi,vbi,mbi,_bi,pbi,Ebi,Uh,Sbi,gbi,ybi,Fbi,Obi,Abi,Mbi,Rbi,Nbi,Tbi,Lbi,Dbi,Cbi,Pbi,Bbi,Ibi,Hbi,xbi,Ubi,zbi,jbi,Vbi,qbi,Ybi,ex,Gbi,Wbi,Kbi,Xbi,ux,Zbi,Jbi,Qbi,$bi,eki,iki,rki,nki,fki,tki,uki,aki,Rq,oki,Aui,Aui,Aui,Aui,Aui,Aui,Aui,Aui,Aui,Aui,Aui,Aui,Aui,Aui,Aui,Aui,Aui,Aui,Aui,Aui,Aui,Aui,Aui,Aui,Aui,Aui,Aui,Aui,Aui,Aui,Aui,Aui,Aui,Aui,Aui,Aui,Aui,Aui,Aui,Aui,Aui,Aui,Aui,Aui,Aui,Aui,Aui,Aui,Aui,Aui,Aui,Aui,Aui,Aui,Aui,Aui,Aui,Aui,Aui,Aui,Aui,Aui,Aui,Aui,Aui,Aui,Aui,Aui,Aui,Aui,Aui,Aui,Aui,Aui,Aui,Aui,Aui,Aui,Aui,Aui,Aui,Aui,Aui,Aui,Aui,Aui,Aui,Aui,Aui,Aui,Aui,Aui,Aui,Aui,Aui,Aui,Aui,Aui,Aui,Aui,Aui,Aui,Aui,Aui,Aui,Aui,Aui,Aui,Aui,Aui,Aui,Aui,Aui,Aui,Aui,Aui,Aui,Aui,Aui,Aui];var RAi=[cki,lki,ski,bki,kki,hki,wki,dki,vki,mki,_ki,pki,Eki,Ski,gki,yki,Fki,Oki,Aki,Mki,Rki,Nki,Tki,Lki,Dki,Cki,Pki,Bki,Iki,Hki,xki,Uki,zki,jki,Vki,qki,Yki,Gki,Wki,Kki,Xki,Zki,Jki,Qki,$ki,ehi,ihi,rhi,nhi,fhi,thi,uhi,ahi,ohi,chi,lhi,shi,bhi,khi,hhi,whi,dhi,vhi,mhi,_hi,phi,Ehi,Shi,ghi,yhi,Fhi,Ohi,Ahi,Mhi,Rhi,Nhi,Thi,Lhi,Dhi,Chi,Phi,Bhi,Ihi,Hhi,xhi,Uhi,zhi,jhi,Vhi,qhi,Yhi,Ghi,Whi,Khi,Xhi,Zhi,Jhi,Qhi,$hi,ewi,iwi,rwi,nwi,fwi,twi,uwi,awi,owi,cwi,lwi,swi,bwi,kwi,hwi,wwi,dwi,vwi,mwi,_wi,pwi,Ewi,Swi,gwi,ywi,Fwi,Owi,Awi,Mwi,Rwi,Nwi,Twi,Lwi,Dwi,Cwi,Pwi,Bwi,Iwi,Hwi,xwi,Uwi,zwi,jwi,Vwi,qwi,Ywi,Gwi,Wwi,Kwi,Xwi,Zwi,Jwi,Qwi,$wi,edi,idi,rdi,ndi,fdi,tdi,udi,adi,odi,cdi,ldi,sdi,bdi,kdi,hdi,wdi,ddi,vdi,mdi,_di,pdi,Edi,Sdi,gdi,ydi,Fdi,Odi,Adi,Mdi,Rdi,Ndi,Tdi,Ldi,Ddi,Cdi,Pdi,Bdi,Idi,Hdi,xdi,Udi,zdi,jdi,Vdi,qdi,Ydi,Gdi,Wdi,Kdi,Xdi,Zdi,Jdi,Qdi,$di,evi,ivi,rvi,nvi,fvi,tvi,uvi,avi,ovi,cvi,lvi,svi,bvi,kvi,hvi,wvi,dvi,vvi,mvi,_vi,pvi,Evi,Svi,gvi,yvi,Fvi,Ovi,Avi,Mvi,Rvi,Nvi,Tvi,Lvi,Dvi,Cvi,Pvi,Bvi,Ivi,Hvi,xvi,Uvi,zvi,jvi,Vvi,qvi,Yvi,Gvi,Wvi,Kvi,Xvi,Zvi,Jvi,Qvi,$vi,emi,imi,rmi,nmi,fmi,tmi,umi,ami,omi,cmi,lmi,smi,bmi,kmi,hmi,wmi,dmi,vmi,mmi,_mi,pmi,Emi,Smi,gmi,ymi,Fmi,Omi,Ami,Mmi,Rmi,Nmi,Tmi,Lmi,Dmi,Cmi,Pmi,Bmi,Imi,Hmi,xmi,Umi,zmi,jmi,Vmi,qmi,Ymi,Gmi,Wmi,Kmi,Xmi,Zmi,Jmi,Qmi,$mi,e_i,i_i,r_i,n_i,f_i,t_i,u_i,a_i,o_i,c_i,l_i,s_i,b_i,k_i,h_i,w_i,d_i,v_i,m_i,__i,p_i,E_i,S_i,g_i,y_i,F_i,O_i,A_i,M_i,R_i,N_i,T_i,L_i,D_i,C_i,P_i,B_i,I_i,H_i,x_i,U_i,z_i,j_i,V_i,q_i,Y_i,G_i,W_i,K_i,X_i,Z_i,J_i,Q_i,$_i,epi,ipi,rpi,npi,ix,fpi,tpi,upi,api,ax,opi,cpi,lpi,spi,bpi,kpi,hpi,wpi,dpi,vpi,mpi,_pi,ppi,cki,cki,cki,cki,cki,cki,cki,cki,cki,cki,cki,cki,cki,cki,cki,cki,cki,cki,cki,cki,cki,cki,cki,cki,cki,cki,cki,cki,cki,cki,cki,cki,cki,cki,cki,cki,cki,cki,cki,cki,cki,cki,cki,cki,cki,cki,cki,cki,cki,cki,cki,cki,cki,cki,cki,cki,cki,cki,cki,cki,cki,cki,cki,cki,cki,cki,cki,cki,cki,cki,cki,cki,cki,cki,cki,cki,cki,cki,cki,cki,cki,cki,cki,cki,cki,cki,cki,cki,cki,cki,cki,cki,cki,cki,cki,cki,cki,cki,cki,cki,cki,cki,cki,cki,cki,cki,cki,cki,cki,cki,cki,cki,cki,cki,cki,cki,cki,cki,cki,cki];var NAi=[Epi,Cm,Spi,gpi,ypi,Fpi,Opi,Api,zm,Mpi,Vm,Rpi,Npi,Tpi,Lpi,Dpi,Cpi,Ppi,Bpi,Ipi,Hpi,xpi,Upi,zpi,jpi,Vpi,qpi,f_,Ypi,u_,Gpi,Wpi,Kpi,Xpi,Zpi,Jpi,Tz,Qpi,$pi,eEi,iEi,rEi,nEi,xz,fEi,Hz,tEi,uEi,aEi,oEi,cEi,lEi,sEi,bEi,kEi,hEi,wEi,dEi,vEi,mEi,Lz,_Ei,pEi,EEi,SEi,gEi,yEi,FEi,OEi,AEi,MEi,REi,NEi,TEi,LEi,DEi,CEi,PEi,BEi,IEi,HEi,xEi,UEi,zEi,jEi,VEi,qEi,YEi,GEi,WEi,KEi,XEi,ZEi,JEi,QEi,$Ei,eSi,iSi,rSi,nSi,fSi,tSi,uSi,aSi,oSi,cSi,lSi,sSi,bSi,kSi,hSi,wSi,dSi,vSi,mSi,_Si,pSi,ESi,SSi,gSi,ySi,FSi,OSi,ASi,MSi,RSi,NSi,TSi,LSi,DSi,CSi,PSi,BSi,ISi,HSi,xSi,USi,zSi,jSi,VSi,qSi,YSi,GSi,WSi,KSi,XSi,ZSi,JSi,QSi,$Si,egi,igi,rgi,ngi,fgi,tgi,ugi,agi,ogi,cgi,lgi,sgi,bgi,kgi,hgi,wgi,dgi,vgi,mgi,_gi,pgi,Egi,Sgi,ggi,ygi,Fgi,Ogi,Agi,Mgi,Rgi,Ngi,Tgi,Lgi,Dgi,Cgi,Pgi,Bgi,Igi,Hgi,xgi,Ugi,zgi,jgi,Vgi,qgi,Ygi,Ggi,Wgi,Kgi,Xgi,Zgi,Jgi,Qgi,$gi,eyi,iyi,ryi,nyi,fyi,tyi,uyi,ayi,oyi,cyi,lyi,syi,byi,kyi,hyi,wyi,dyi,vyi,myi,_yi,pyi,Eyi,Syi,gyi,yyi,Fyi,Oyi,Ayi,Myi,Ryi,Nyi,Tyi,Lyi,Dyi,Cyi,Pyi,Byi,Iyi,Hyi,xyi,Uyi,zyi,jyi,Vyi,qyi,Yyi,Gyi,Wyi,Kyi,Xyi,Zyi,Jyi,Qyi,$yi,eFi,iFi,rFi,nFi,fFi,tFi,uFi,aFi,oFi,cFi,lFi,sFi,bFi,kFi,hFi,wFi,dFi,vFi,mFi,_Fi,pFi,EFi,SFi,gFi,yFi,FFi,OFi,AFi,MFi,RFi,NFi,TFi,LFi,DFi,CFi,PFi,BFi,IFi,HFi,xFi,UFi,zFi,jFi,VFi,qFi,YFi,GFi,WFi,KFi,XFi,ZFi,JFi,QFi,$Fi,eOi,iOi,rOi,nOi,fOi,tOi,uOi,aOi,oOi,cOi,lOi,sOi,vh,bOi,kOi,hOi,Eh,wOi,dOi,vOi,mOi,_Oi,pOi,Mh,EOi,Nh,SOi,gOi,yOi,FOi,OOi,AOi,MOi,ROi,NOi,TOi,zh,LOi,DOi,COi,POi,BOi,Wh,IOi,HOi,xOi,qv,UOi,zOi,jOi,VOi,qOi,bH,YOi,GOi,WOi,KOi,XOi,ZOi,JOi,QOi,$Oi,eAi,iAi,rAi,nAi,fAi,tAi,uAi,aAi,_x,oAi,cAi,GU,lAi,sAi,Wz,bAi,kAi,hAi,Epi,Epi,Epi,Epi,Epi,Epi,Epi,Epi,Epi,Epi,Epi,Epi,Epi,Epi,Epi,Epi,Epi,Epi,Epi,Epi,Epi,Epi,Epi,Epi,Epi,Epi,Epi,Epi,Epi,Epi,Epi,Epi,Epi,Epi,Epi,Epi,Epi,Epi,Epi,Epi,Epi,Epi,Epi,Epi,Epi,Epi,Epi,Epi,Epi,Epi,Epi,Epi,Epi,Epi,Epi,Epi,Epi,Epi,Epi,Epi,Epi,Epi,Epi,Epi,Epi,Epi,Epi,Epi,Epi,Epi,Epi,Epi,Epi,Epi,Epi,Epi,Epi,Epi,Epi,Epi,Epi,Epi,Epi,Epi,Epi,Epi,Epi,Epi,Epi,Epi,Epi,Epi,Epi,Epi,Epi,Epi,Epi,Epi,Epi,Epi,Epi,Epi,Epi,Epi,Epi,Epi,Epi,Epi,Epi,Epi,Epi,Epi,Epi,Epi,Epi,Epi,Epi,Epi,Epi,Epi];return{_i64Subtract:BY,_strcat:xY,_free:Zq,_main:fm,_realloc:Jq,_strncpy:zY,_memmove:GY,_bitshift64Ashr:IY,_strlen:HY,_memset:VY,_malloc:Xq,_i64Add:jY,_memcpy:YY,_llvm_ctlz_i32:KY,_bitshift64Lshr:qY,_strcpy:WY,_bitshift64Shl:UY,runPostSets:PY,stackAlloc:Zv,stackSave:Jv,stackRestore:Qv,setThrew:$v,setTempRet0:rm,getTempRet0:nm,dynCall_iiiiiiii:nG,dynCall_iiii:fG,dynCall_viiiiiii:tG,dynCall_viiiii:uG,dynCall_i:aG,dynCall_vi:oG,dynCall_vii:cG,dynCall_iiiiiii:lG,dynCall_ii:sG,dynCall_viii:bG,dynCall_viiiiiiiii:kG,dynCall_iiiii:hG,dynCall_viiiiii:wG,dynCall_iii:dG,dynCall_iiiiii:vG,dynCall_viiii:mG}}(Module.asmGlobalArg,Module.asmLibraryArg,buffer),_i64Subtract=Module._i64Subtract=asm._i64Subtract,_strcat=Module._strcat=asm._strcat,_free=Module._free=asm._free,_main=Module._main=asm._main,_realloc=Module._realloc=asm._realloc,_strncpy=Module._strncpy=asm._strncpy,_memmove=Module._memmove=asm._memmove,_bitshift64Ashr=Module._bitshift64Ashr=asm._bitshift64Ashr,_strlen=Module._strlen=asm._strlen,_memset=Module._memset=asm._memset,_malloc=Module._malloc=asm._malloc,_i64Add=Module._i64Add=asm._i64Add,_memcpy=Module._memcpy=asm._memcpy,_llvm_ctlz_i32=Module._llvm_ctlz_i32=asm._llvm_ctlz_i32,_bitshift64Lshr=Module._bitshift64Lshr=asm._bitshift64Lshr,_strcpy=Module._strcpy=asm._strcpy,_bitshift64Shl=Module._bitshift64Shl=asm._bitshift64Shl,runPostSets=Module.runPostSets=asm.runPostSets,dynCall_iiiiiiii=Module.dynCall_iiiiiiii=asm.dynCall_iiiiiiii,dynCall_iiii=Module.dynCall_iiii=asm.dynCall_iiii,dynCall_viiiiiii=Module.dynCall_viiiiiii=asm.dynCall_viiiiiii,dynCall_viiiii=Module.dynCall_viiiii=asm.dynCall_viiiii,dynCall_i=Module.dynCall_i=asm.dynCall_i,dynCall_vi=Module.dynCall_vi=asm.dynCall_vi,dynCall_vii=Module.dynCall_vii=asm.dynCall_vii,dynCall_iiiiiii=Module.dynCall_iiiiiii=asm.dynCall_iiiiiii,dynCall_ii=Module.dynCall_ii=asm.dynCall_ii,dynCall_viii=Module.dynCall_viii=asm.dynCall_viii,dynCall_viiiiiiiii=Module.dynCall_viiiiiiiii=asm.dynCall_viiiiiiiii,dynCall_iiiii=Module.dynCall_iiiii=asm.dynCall_iiiii,dynCall_viiiiii=Module.dynCall_viiiiii=asm.dynCall_viiiiii,dynCall_iii=Module.dynCall_iii=asm.dynCall_iii,dynCall_iiiiii=Module.dynCall_iiiiii=asm.dynCall_iiiiii,dynCall_viiii=Module.dynCall_viiii=asm.dynCall_viiii;Runtime.stackAlloc=asm.stackAlloc,Runtime.stackSave=asm.stackSave,Runtime.stackRestore=asm.stackRestore,Runtime.setTempRet0=asm.setTempRet0,Runtime.getTempRet0=asm.getTempRet0;var i64Math=function(){function e(e,i,r){null!=e&&("number"==typeof e?this.fromNumber(e,i,r):null==i&&"string"!=typeof e?this.fromString(e,256):this.fromString(e,i))}function i(){return new e(null)}function r(e,i,r,n,f,t){for(;--t>=0;){var u=i*this[e++]+r[n]+f;f=Math.floor(u/67108864),r[n++]=67108863&u}return f}function n(e,i,r,n,f,t){for(var u=32767&i,a=i>>15;--t>=0;){var o=32767&this[e],c=this[e++]>>15,l=a*o+c*u;o=u*o+((32767&l)<<15)+r[n]+(1073741823&f),f=(o>>>30)+(l>>>15)+a*c+(f>>>30),r[n++]=1073741823&o}return f}function f(e,i,r,n,f,t){for(var u=16383&i,a=i>>14;--t>=0;){var o=16383&this[e],c=this[e++]>>14,l=a*o+c*u;o=u*o+((16383&l)<<14)+r[n]+f,f=(o>>28)+(l>>14)+a*c,r[n++]=268435455&o}return f}function t(e){return te.charAt(e)}function u(e,i){var r=ue[e.charCodeAt(i)];return null==r?-1:r}function a(e){for(var i=this.t-1;i>=0;--i)e[i]=this[i];e.t=this.t,e.s=this.s}function o(e){this.t=1,this.s=e<0?-1:0,e>0?this[0]=e:e<-1?this[0]=e+DV:this.t=0}function c(e){var r=i();return r.fromInt(e),r}function l(i,r){var n;if(16==r)n=4;else if(8==r)n=3;else if(256==r)n=8;else if(2==r)n=1;else if(32==r)n=5;else{if(4!=r)return void this.fromRadix(i,r);n=2}this.t=0,this.s=0;for(var f=i.length,t=!1,a=0;--f>=0;){var o=8==n?255&i[f]:u(i,f);o<0?"-"==i.charAt(f)&&(t=!0):(t=!1,0==a?this[this.t++]=o:a+n>this.DB?(this[this.t-1]|=(o&(1<<this.DB-a)-1)<<a,this[this.t++]=o>>this.DB-a):this[this.t-1]|=o<<a,a+=n,a>=this.DB&&(a-=this.DB))}8==n&&0!=(128&i[0])&&(this.s=-1,a>0&&(this[this.t-1]|=(1<<this.DB-a)-1<<a)),this.clamp(),t&&e.ZERO.subTo(this,this)}function s(){for(var e=this.s&this.DM;this.t>0&&this[this.t-1]==e;)--this.t}function b(e){if(this.s<0)return"-"+this.negate().toString(e);var i;if(16==e)i=4;else if(8==e)i=3;else if(2==e)i=1;else if(32==e)i=5;else{if(4!=e)return this.toRadix(e);i=2}var r,n=(1<<i)-1,f=!1,u="",a=this.t,o=this.DB-a*this.DB%i;if(a-- >0)for(o<this.DB&&(r=this[a]>>o)>0&&(f=!0,u=t(r));a>=0;)o<i?(r=(this[a]&(1<<o)-1)<<i-o,r|=this[--a]>>(o+=this.DB-i)):(r=this[a]>>(o-=i)&n,o<=0&&(o+=this.DB,--a)),r>0&&(f=!0),f&&(u+=t(r));return f?u:"0"}function k(){var r=i();return e.ZERO.subTo(this,r),r}function h(){return this.s<0?this.negate():this}function w(e){var i=this.s-e.s;if(0!=i)return i;var r=this.t;if(i=r-e.t,0!=i)return this.s<0?-i:i;for(;--r>=0;)if(0!=(i=this[r]-e[r]))return i;return 0}function d(e){var i,r=1;return 0!=(i=e>>>16)&&(e=i,r+=16),0!=(i=e>>8)&&(e=i,r+=8),0!=(i=e>>4)&&(e=i,r+=4),0!=(i=e>>2)&&(e=i,r+=2),0!=(i=e>>1)&&(e=i,r+=1),r}function v(){return this.t<=0?0:this.DB*(this.t-1)+d(this[this.t-1]^this.s&this.DM)}function m(e,i){var r;for(r=this.t-1;r>=0;--r)i[r+e]=this[r];for(r=e-1;r>=0;--r)i[r]=0;i.t=this.t+e,i.s=this.s}function _(e,i){for(var r=e;r<this.t;++r)i[r-e]=this[r];i.t=Math.max(this.t-e,0),i.s=this.s}function p(e,i){var r,n=e%this.DB,f=this.DB-n,t=(1<<f)-1,u=Math.floor(e/this.DB),a=this.s<<n&this.DM;for(r=this.t-1;r>=0;--r)i[r+u+1]=this[r]>>f|a,a=(this[r]&t)<<n;for(r=u-1;r>=0;--r)i[r]=0;i[u]=a,i.t=this.t+u+1,i.s=this.s,i.clamp()}function E(e,i){i.s=this.s;var r=Math.floor(e/this.DB);if(r>=this.t)return void(i.t=0);var n=e%this.DB,f=this.DB-n,t=(1<<n)-1;i[0]=this[r]>>n;for(var u=r+1;u<this.t;++u)i[u-r-1]|=(this[u]&t)<<f,i[u-r]=this[u]>>n;n>0&&(i[this.t-r-1]|=(this.s&t)<<f),i.t=this.t-r,i.clamp()}function S(e,i){for(var r=0,n=0,f=Math.min(e.t,this.t);r<f;)n+=this[r]-e[r],i[r++]=n&this.DM,n>>=this.DB;if(e.t<this.t){for(n-=e.s;r<this.t;)n+=this[r],i[r++]=n&this.DM,n>>=this.DB;n+=this.s}else{for(n+=this.s;r<e.t;)n-=e[r],i[r++]=n&this.DM,n>>=this.DB;n-=e.s}i.s=n<0?-1:0,n<-1?i[r++]=this.DV+n:n>0&&(i[r++]=n),i.t=r,i.clamp()}function g(i,r){var n=this.abs(),f=i.abs(),t=n.t;for(r.t=t+f.t;--t>=0;)r[t]=0;for(t=0;t<f.t;++t)r[t+n.t]=n.am(0,f[t],r,t,0,n.t);r.s=0,r.clamp(),this.s!=i.s&&e.ZERO.subTo(r,r)}function y(e){for(var i=this.abs(),r=e.t=2*i.t;--r>=0;)e[r]=0;for(r=0;r<i.t-1;++r){var n=i.am(r,i[r],e,2*r,0,1);(e[r+i.t]+=i.am(r+1,2*i[r],e,2*r+1,n,i.t-r-1))>=i.DV&&(e[r+i.t]-=i.DV,e[r+i.t+1]=1)}e.t>0&&(e[e.t-1]+=i.am(r,i[r],e,2*r,0,1)),e.s=0,e.clamp()}function F(r,n,f){var t=r.abs();if(!(t.t<=0)){var u=this.abs();if(u.t<t.t)return null!=n&&n.fromInt(0),void(null!=f&&this.copyTo(f));null==f&&(f=i());var a=i(),o=this.s,c=r.s,l=this.DB-d(t[t.t-1]);l>0?(t.lShiftTo(l,a),u.lShiftTo(l,f)):(t.copyTo(a),u.copyTo(f));var s=a.t,b=a[s-1];if(0!=b){var k=b*(1<<this.F1)+(s>1?a[s-2]>>this.F2:0),h=this.FV/k,w=(1<<this.F1)/k,v=1<<this.F2,m=f.t,_=m-s,p=null==n?i():n;for(a.dlShiftTo(_,p),f.compareTo(p)>=0&&(f[f.t++]=1,f.subTo(p,f)),e.ONE.dlShiftTo(s,p),p.subTo(a,a);a.t<s;)a[a.t++]=0;for(;--_>=0;){var E=f[--m]==b?this.DM:Math.floor(f[m]*h+(f[m-1]+v)*w);if((f[m]+=a.am(0,E,f,_,0,s))<E)for(a.dlShiftTo(_,p),f.subTo(p,f);f[m]<--E;)f.subTo(p,f)}null!=n&&(f.drShiftTo(s,n),o!=c&&e.ZERO.subTo(n,n)),f.t=s,f.clamp(),l>0&&f.rShiftTo(l,f),o<0&&e.ZERO.subTo(f,f)}}}function O(r){var n=i();return this.abs().divRemTo(r,null,n),this.s<0&&n.compareTo(e.ZERO)>0&&r.subTo(n,n),n}function A(e){this.m=e}function M(e){return e.s<0||e.compareTo(this.m)>=0?e.mod(this.m):e}function R(e){return e}function N(e){e.divRemTo(this.m,null,e)}function T(e,i,r){e.multiplyTo(i,r),this.reduce(r)}function L(e,i){e.squareTo(i),this.reduce(i)}function D(){if(this.t<1)return 0;var e=this[0];if(0==(1&e))return 0;var i=3&e;return i=i*(2-(15&e)*i)&15,i=i*(2-(255&e)*i)&255,i=i*(2-((65535&e)*i&65535))&65535,i=i*(2-e*i%this.DV)%this.DV,i>0?this.DV-i:-i}function C(e){this.m=e,this.mp=e.invDigit(),this.mpl=32767&this.mp,this.mph=this.mp>>15,this.um=(1<<e.DB-15)-1,this.mt2=2*e.t}function P(r){var n=i();return r.abs().dlShiftTo(this.m.t,n),n.divRemTo(this.m,null,n),r.s<0&&n.compareTo(e.ZERO)>0&&this.m.subTo(n,n),n}function B(e){var r=i();return e.copyTo(r),this.reduce(r),r}function I(e){for(;e.t<=this.mt2;)e[e.t++]=0;for(var i=0;i<this.m.t;++i){var r=32767&e[i],n=r*this.mpl+((r*this.mph+(e[i]>>15)*this.mpl&this.um)<<15)&e.DM;for(r=i+this.m.t,e[r]+=this.m.am(0,n,e,i,0,this.m.t);e[r]>=e.DV;)e[r]-=e.DV,e[++r]++}e.clamp(),e.drShiftTo(this.m.t,e),e.compareTo(this.m)>=0&&e.subTo(this.m,e)}function H(e,i){e.squareTo(i),this.reduce(i)}function x(e,i,r){e.multiplyTo(i,r),this.reduce(r)}function U(){return 0==(this.t>0?1&this[0]:this.s)}function z(r,n){if(r>4294967295||r<1)return e.ONE;var f=i(),t=i(),u=n.convert(this),a=d(r)-1;for(u.copyTo(f);--a>=0;)if(n.sqrTo(f,t),(r&1<<a)>0)n.mulTo(t,u,f);else{var o=f;f=t,t=o}return n.revert(f)}function j(e,i){var r;return r=e<256||i.isEven()?new A(i):new C(i),this.exp(e,r)}function V(i,r){this.fromInt(0),null==r&&(r=10);for(var n=this.chunkSize(r),f=Math.pow(r,n),t=!1,a=0,o=0,c=0;c<i.length;++c){var l=u(i,c);l<0?"-"==i.charAt(c)&&0==this.signum()&&(t=!0):(o=r*o+l,++a>=n&&(this.dMultiply(f),this.dAddOffset(o,0),a=0,o=0))}a>0&&(this.dMultiply(Math.pow(r,a)),this.dAddOffset(o,0)),t&&e.ZERO.subTo(this,this)}function q(e){return Math.floor(Math.LN2*this.DB/Math.log(e))}function Y(){return this.s<0?-1:this.t<=0||1==this.t&&this[0]<=0?0:1}function G(e){this[this.t]=this.am(0,e-1,this,0,0,this.t),++this.t,this.clamp()}function W(e,i){if(0!=e){for(;this.t<=i;)this[this.t++]=0;for(this[i]+=e;this[i]>=this.DV;)this[i]-=this.DV,++i>=this.t&&(this[this.t++]=0),++this[i]}}function K(e){if(null==e&&(e=10),0==this.signum()||e<2||e>36)return"0";var r=this.chunkSize(e),n=Math.pow(e,r),f=c(n),t=i(),u=i(),a="";for(this.divRemTo(f,t,u);t.signum()>0;)a=(n+u.intValue()).toString(e).substr(1)+a,t.divRemTo(f,t,u);return u.intValue().toString(e)+a}function X(){if(this.s<0){if(1==this.t)return this[0]-this.DV;if(0==this.t)return-1}else{if(1==this.t)return this[0];if(0==this.t)return 0}return(this[1]&(1<<32-this.DB)-1)<<this.DB|this[0]}function Z(e,i){for(var r=0,n=0,f=Math.min(e.t,this.t);r<f;)n+=this[r]+e[r],i[r++]=n&this.DM,n>>=this.DB;if(e.t<this.t){for(n+=e.s;r<this.t;)n+=this[r],i[r++]=n&this.DM,n>>=this.DB;n+=this.s}else{for(n+=this.s;r<e.t;)n+=e[r],i[r++]=n&this.DM,n>>=this.DB;n+=e.s}i.s=n<0?-1:0,n>0?i[r++]=n:n<-1&&(i[r++]=this.DV+n),i.t=r,i.clamp()}var J={math:{}};J.math.Long=function(e,i){this.low_=0|e,this.high_=0|i},J.math.Long.IntCache_={},J.math.Long.fromInt=function(e){if(-128<=e&&e<128){var i=J.math.Long.IntCache_[e];if(i)return i}var r=new J.math.Long(0|e,e<0?-1:0);return-128<=e&&e<128&&(J.math.Long.IntCache_[e]=r),r},J.math.Long.fromNumber=function(e){return isNaN(e)||!isFinite(e)?J.math.Long.ZERO:e<=-J.math.Long.TWO_PWR_63_DBL_?J.math.Long.MIN_VALUE:e+1>=J.math.Long.TWO_PWR_63_DBL_?J.math.Long.MAX_VALUE:e<0?J.math.Long.fromNumber(-e).negate():new J.math.Long(e%J.math.Long.TWO_PWR_32_DBL_|0,e/J.math.Long.TWO_PWR_32_DBL_|0)},J.math.Long.fromBits=function(e,i){return new J.math.Long(e,i)},J.math.Long.fromString=function(e,i){if(0==e.length)throw Error("number format error: empty string");var r=i||10;if(r<2||36<r)throw Error("radix out of range: "+r);if("-"==e.charAt(0))return J.math.Long.fromString(e.substring(1),r).negate();if(e.indexOf("-")>=0)throw Error('number format error: interior "-" character: '+e);for(var n=J.math.Long.fromNumber(Math.pow(r,8)),f=J.math.Long.ZERO,t=0;t<e.length;t+=8){var u=Math.min(8,e.length-t),a=parseInt(e.substring(t,t+u),r);if(u<8){var o=J.math.Long.fromNumber(Math.pow(r,u));f=f.multiply(o).add(J.math.Long.fromNumber(a))}else f=f.multiply(n),f=f.add(J.math.Long.fromNumber(a))}return f},J.math.Long.TWO_PWR_16_DBL_=65536,J.math.Long.TWO_PWR_24_DBL_=1<<24,J.math.Long.TWO_PWR_32_DBL_=J.math.Long.TWO_PWR_16_DBL_*J.math.Long.TWO_PWR_16_DBL_,J.math.Long.TWO_PWR_31_DBL_=J.math.Long.TWO_PWR_32_DBL_/2,J.math.Long.TWO_PWR_48_DBL_=J.math.Long.TWO_PWR_32_DBL_*J.math.Long.TWO_PWR_16_DBL_,J.math.Long.TWO_PWR_64_DBL_=J.math.Long.TWO_PWR_32_DBL_*J.math.Long.TWO_PWR_32_DBL_,J.math.Long.TWO_PWR_63_DBL_=J.math.Long.TWO_PWR_64_DBL_/2,J.math.Long.ZERO=J.math.Long.fromInt(0),J.math.Long.ONE=J.math.Long.fromInt(1),J.math.Long.NEG_ONE=J.math.Long.fromInt(-1),J.math.Long.MAX_VALUE=J.math.Long.fromBits(-1,2147483647),J.math.Long.MIN_VALUE=J.math.Long.fromBits(0,-2147483648),J.math.Long.TWO_PWR_24_=J.math.Long.fromInt(1<<24),J.math.Long.prototype.toInt=function(){return this.low_},J.math.Long.prototype.toNumber=function(){return this.high_*J.math.Long.TWO_PWR_32_DBL_+this.getLowBitsUnsigned()},J.math.Long.prototype.toString=function(e){var i=e||10;if(i<2||36<i)throw Error("radix out of range: "+i);if(this.isZero())return"0";if(this.isNegative()){if(this.equals(J.math.Long.MIN_VALUE)){var r=J.math.Long.fromNumber(i),n=this.div(r),f=n.multiply(r).subtract(this);return n.toString(i)+f.toInt().toString(i)}return"-"+this.negate().toString(i)}for(var t=J.math.Long.fromNumber(Math.pow(i,6)),f=this,u="";;){var a=f.div(t),o=f.subtract(a.multiply(t)).toInt(),c=o.toString(i);if(f=a,f.isZero())return c+u;for(;c.length<6;)c="0"+c;u=""+c+u}},J.math.Long.prototype.getHighBits=function(){return this.high_},J.math.Long.prototype.getLowBits=function(){return this.low_},J.math.Long.prototype.getLowBitsUnsigned=function(){return this.low_>=0?this.low_:J.math.Long.TWO_PWR_32_DBL_+this.low_},J.math.Long.prototype.getNumBitsAbs=function(){if(this.isNegative())return this.equals(J.math.Long.MIN_VALUE)?64:this.negate().getNumBitsAbs();for(var e=0!=this.high_?this.high_:this.low_,i=31;i>0&&0==(e&1<<i);i--);return 0!=this.high_?i+33:i+1},J.math.Long.prototype.isZero=function(){return 0==this.high_&&0==this.low_},J.math.Long.prototype.isNegative=function(){return this.high_<0},J.math.Long.prototype.isOdd=function(){return 1==(1&this.low_)},J.math.Long.prototype.equals=function(e){return this.high_==e.high_&&this.low_==e.low_},J.math.Long.prototype.notEquals=function(e){return this.high_!=e.high_||this.low_!=e.low_},J.math.Long.prototype.lessThan=function(e){return this.compare(e)<0},J.math.Long.prototype.lessThanOrEqual=function(e){return this.compare(e)<=0},J.math.Long.prototype.greaterThan=function(e){return this.compare(e)>0},J.math.Long.prototype.greaterThanOrEqual=function(e){return this.compare(e)>=0},J.math.Long.prototype.compare=function(e){if(this.equals(e))return 0;var i=this.isNegative(),r=e.isNegative();return i&&!r?-1:!i&&r?1:this.subtract(e).isNegative()?-1:1},J.math.Long.prototype.negate=function(){return this.equals(J.math.Long.MIN_VALUE)?J.math.Long.MIN_VALUE:this.not().add(J.math.Long.ONE)},J.math.Long.prototype.add=function(e){var i=this.high_>>>16,r=65535&this.high_,n=this.low_>>>16,f=65535&this.low_,t=e.high_>>>16,u=65535&e.high_,a=e.low_>>>16,o=65535&e.low_,c=0,l=0,s=0,b=0;return b+=f+o,s+=b>>>16,b&=65535,s+=n+a,l+=s>>>16,s&=65535,l+=r+u,c+=l>>>16,l&=65535,c+=i+t,c&=65535,J.math.Long.fromBits(s<<16|b,c<<16|l)},J.math.Long.prototype.subtract=function(e){return this.add(e.negate())},J.math.Long.prototype.multiply=function(e){if(this.isZero())return J.math.Long.ZERO;if(e.isZero())return J.math.Long.ZERO;if(this.equals(J.math.Long.MIN_VALUE))return e.isOdd()?J.math.Long.MIN_VALUE:J.math.Long.ZERO;if(e.equals(J.math.Long.MIN_VALUE))return this.isOdd()?J.math.Long.MIN_VALUE:J.math.Long.ZERO;if(this.isNegative())return e.isNegative()?this.negate().multiply(e.negate()):this.negate().multiply(e).negate();if(e.isNegative())return this.multiply(e.negate()).negate();if(this.lessThan(J.math.Long.TWO_PWR_24_)&&e.lessThan(J.math.Long.TWO_PWR_24_))return J.math.Long.fromNumber(this.toNumber()*e.toNumber());var i=this.high_>>>16,r=65535&this.high_,n=this.low_>>>16,f=65535&this.low_,t=e.high_>>>16,u=65535&e.high_,a=e.low_>>>16,o=65535&e.low_,c=0,l=0,s=0,b=0;return b+=f*o,s+=b>>>16,b&=65535,s+=n*o,l+=s>>>16,s&=65535,s+=f*a,l+=s>>>16,s&=65535,l+=r*o,c+=l>>>16,l&=65535,l+=n*a,c+=l>>>16,l&=65535,l+=f*u,c+=l>>>16,l&=65535,c+=i*o+r*a+n*u+f*t,c&=65535,J.math.Long.fromBits(s<<16|b,c<<16|l)},J.math.Long.prototype.div=function(e){if(e.isZero())throw Error("division by zero");if(this.isZero())return J.math.Long.ZERO;if(this.equals(J.math.Long.MIN_VALUE)){if(e.equals(J.math.Long.ONE)||e.equals(J.math.Long.NEG_ONE))return J.math.Long.MIN_VALUE;if(e.equals(J.math.Long.MIN_VALUE))return J.math.Long.ONE;var i=this.shiftRight(1),r=i.div(e).shiftLeft(1);if(r.equals(J.math.Long.ZERO))return e.isNegative()?J.math.Long.ONE:J.math.Long.NEG_ONE;var n=this.subtract(e.multiply(r)),f=r.add(n.div(e));return f}if(e.equals(J.math.Long.MIN_VALUE))return J.math.Long.ZERO;if(this.isNegative())return e.isNegative()?this.negate().div(e.negate()):this.negate().div(e).negate();if(e.isNegative())return this.div(e.negate()).negate();for(var t=J.math.Long.ZERO,n=this;n.greaterThanOrEqual(e);){for(var r=Math.max(1,Math.floor(n.toNumber()/e.toNumber())),u=Math.ceil(Math.log(r)/Math.LN2),a=u<=48?1:Math.pow(2,u-48),o=J.math.Long.fromNumber(r),c=o.multiply(e);c.isNegative()||c.greaterThan(n);)r-=a,o=J.math.Long.fromNumber(r),c=o.multiply(e);o.isZero()&&(o=J.math.Long.ONE),t=t.add(o),n=n.subtract(c)}return t},J.math.Long.prototype.modulo=function(e){return this.subtract(this.div(e).multiply(e))},J.math.Long.prototype.not=function(){return J.math.Long.fromBits(~this.low_,~this.high_)},J.math.Long.prototype.and=function(e){return J.math.Long.fromBits(this.low_&e.low_,this.high_&e.high_)},J.math.Long.prototype.or=function(e){return J.math.Long.fromBits(this.low_|e.low_,this.high_|e.high_)},J.math.Long.prototype.xor=function(e){return J.math.Long.fromBits(this.low_^e.low_,this.high_^e.high_)},J.math.Long.prototype.shiftLeft=function(e){if(e&=63,0==e)return this;var i=this.low_;if(e<32){var r=this.high_;return J.math.Long.fromBits(i<<e,r<<e|i>>>32-e)}return J.math.Long.fromBits(0,i<<e-32)},J.math.Long.prototype.shiftRight=function(e){if(e&=63,0==e)return this;var i=this.high_;if(e<32){var r=this.low_;return J.math.Long.fromBits(r>>>e|i<<32-e,i>>e)}return J.math.Long.fromBits(i>>e-32,i>=0?0:-1)},J.math.Long.prototype.shiftRightUnsigned=function(e){if(e&=63,0==e)return this;var i=this.high_;if(e<32){var r=this.low_;return J.math.Long.fromBits(r>>>e|i<<32-e,i>>>e)}return 32==e?J.math.Long.fromBits(i,0):J.math.Long.fromBits(i>>>e-32,0)};var Q,$={appName:"Modern Browser"},ee=0xdeadbeefcafe,ie=15715070==(16777215&ee);ie&&"Microsoft Internet Explorer"==$.appName?(e.prototype.am=n,Q=30):ie&&"Netscape"!=$.appName?(e.prototype.am=r,Q=26):(e.prototype.am=f,Q=28),e.prototype.DB=Q,e.prototype.DM=(1<<Q)-1,e.prototype.DV=1<<Q;var re=52;e.prototype.FV=Math.pow(2,re),e.prototype.F1=re-Q,e.prototype.F2=2*Q-re;var ne,fe,te="0123456789abcdefghijklmnopqrstuvwxyz",ue=new Array;for(ne="0".charCodeAt(0),fe=0;fe<=9;++fe)ue[ne++]=fe;for(ne="a".charCodeAt(0),fe=10;fe<36;++fe)ue[ne++]=fe;for(ne="A".charCodeAt(0),fe=10;fe<36;++fe)ue[ne++]=fe;A.prototype.convert=M,A.prototype.revert=R,A.prototype.reduce=N,A.prototype.mulTo=T,A.prototype.sqrTo=L,C.prototype.convert=P,C.prototype.revert=B,C.prototype.reduce=I,C.prototype.mulTo=x,C.prototype.sqrTo=H,e.prototype.copyTo=a,e.prototype.fromInt=o,e.prototype.fromString=l,e.prototype.clamp=s,e.prototype.dlShiftTo=m,e.prototype.drShiftTo=_,e.prototype.lShiftTo=p,e.prototype.rShiftTo=E,e.prototype.subTo=S,e.prototype.multiplyTo=g,e.prototype.squareTo=y,e.prototype.divRemTo=F,e.prototype.invDigit=D,e.prototype.isEven=U,e.prototype.exp=z,e.prototype.toString=b,e.prototype.negate=k,e.prototype.abs=h,e.prototype.compareTo=w,e.prototype.bitLength=v,e.prototype.mod=O,e.prototype.modPowInt=j,e.ZERO=c(0),e.ONE=c(1),e.prototype.fromRadix=V,e.prototype.chunkSize=q,e.prototype.signum=Y,e.prototype.dMultiply=G,e.prototype.dAddOffset=W,e.prototype.toRadix=K,e.prototype.intValue=X,e.prototype.addTo=Z;var ae={abs:function(e,i){var r,n=new J.math.Long(e,i);r=n.isNegative()?n.negate():n,HEAP32[tempDoublePtr>>2]=r.low_,HEAP32[tempDoublePtr+4>>2]=r.high_},ensureTemps:function(){ae.ensuredTemps||(ae.ensuredTemps=!0,ae.two32=new e,ae.two32.fromString("4294967296",10),ae.two64=new e,ae.two64.fromString("18446744073709551616",10),ae.temp1=new e,ae.temp2=new e)},lh2bignum:function(i,r){var n=new e;n.fromString(r.toString(),10);var f=new e;n.multiplyTo(ae.two32,f);var t=new e;t.fromString(i.toString(),10);var u=new e;return t.addTo(f,u),u},stringify:function(i,r,n){var f=new J.math.Long(i,r).toString();if(n&&"-"==f[0]){ae.ensureTemps();var t=new e;t.fromString(f,10),f=new e,ae.two64.addTo(t,f),f=f.toString(10)}return f},fromString:function(i,r,n,f,t){ae.ensureTemps();var u=new e;u.fromString(i,r);var a=new e;a.fromString(n,10);var o=new e;if(o.fromString(f,10),t&&u.compareTo(e.ZERO)<0){var c=new e;u.addTo(ae.two64,c),u=c}var l=!1;u.compareTo(a)<0?(u=a,l=!0):u.compareTo(o)>0&&(u=o,l=!0);var s=J.math.Long.fromString(u.toString());if(HEAP32[tempDoublePtr>>2]=s.low_,HEAP32[tempDoublePtr+4>>2]=s.high_,l)throw"range error"}};return ae}();memoryInitializer&&("function"==typeof Module.locateFile?memoryInitializer=Module.locateFile(memoryInitializer):Module.memoryInitializerPrefixURL&&(memoryInitializer=Module.memoryInitializerPrefixURL+memoryInitializer),addRunDependency("memory initializer"),Browser.asyncLoad(memoryInitializer,function(e){HEAPU8.set(e,STATIC_BASE),removeRunDependency("memory initializer")},function(e){throw"could not load memory initializer "+memoryInitializer})),ExitStatus.prototype=new Error,ExitStatus.prototype.constructor=ExitStatus;var initialStackTop,preloadStartTime=null,calledMain=!1;if(dependenciesFulfilled=function e(){!Module.calledRun&&shouldRunNow&&run(),Module.calledRun||(dependenciesFulfilled=e)},Module.callMain=Module.callMain=function(e){function i(){for(var e=0;e<3;e++)n.push(0)}assert(0==runDependencies,"cannot call main when async dependencies remain! (listen on __ATMAIN__)"),assert(0==__ATPRERUN__.length,"cannot call main when preRun functions remain to be called"),e=e||[],ensureInitRuntime();var r=e.length+1,n=[allocate(intArrayFromString(Module.thisProgram),"i8",ALLOC_NORMAL)];i();for(var f=0;f<r-1;f+=1)n.push(allocate(intArrayFromString(e[f]),"i8",ALLOC_NORMAL)),i();n.push(0),n=allocate(n,"i32",ALLOC_NORMAL),initialStackTop=STACKTOP;try{var t=Module._main(r,n,0);exit(t)}catch(e){if(e instanceof ExitStatus)return;if("SimulateInfiniteLoop"==e)return void(Module.noExitRuntime=!0);throw e&&"object"==typeof e&&e.stack&&Module.printErr("exception thrown: "+[e,e.stack]),e}finally{calledMain=!0}},Module.run=Module.run=run,Module.exit=Module.exit=exit,Module.abort=Module.abort=abort,Module.preInit)for("function"==typeof Module.preInit&&(Module.preInit=[Module.preInit]);Module.preInit.length>0;)Module.preInit.pop()();var shouldRunNow=!0;return Module.noInitialRun&&(shouldRunNow=!1),run(),Module.return=Module.return.split("\n").slice(0,-2),{errors:Module.return.length?Module.return:null}}}(),module.exports=xmllint;
	/* WEBPACK VAR INJECTION */}.call(exports, __webpack_require__(2).Buffer))

/***/ },
/* 2 */
/***/ function(module, exports, __webpack_require__) {

	/* WEBPACK VAR INJECTION */(function(Buffer, global) {/*!
	 * The buffer module from node.js, for the browser.
	 *
	 * @author   Feross Aboukhadijeh <feross@feross.org> <http://feross.org>
	 * @license  MIT
	 */
	/* eslint-disable no-proto */

	'use strict'

	var base64 = __webpack_require__(5)
	var ieee754 = __webpack_require__(3)
	var isArray = __webpack_require__(4)

	exports.Buffer = Buffer
	exports.SlowBuffer = SlowBuffer
	exports.INSPECT_MAX_BYTES = 50
	Buffer.poolSize = 8192 // not used by this implementation

	var rootParent = {}

	/**
	 * If `Buffer.TYPED_ARRAY_SUPPORT`:
	 *   === true    Use Uint8Array implementation (fastest)
	 *   === false   Use Object implementation (most compatible, even IE6)
	 *
	 * Browsers that support typed arrays are IE 10+, Firefox 4+, Chrome 7+, Safari 5.1+,
	 * Opera 11.6+, iOS 4.2+.
	 *
	 * Due to various browser bugs, sometimes the Object implementation will be used even
	 * when the browser supports typed arrays.
	 *
	 * Note:
	 *
	 *   - Firefox 4-29 lacks support for adding new properties to `Uint8Array` instances,
	 *     See: https://bugzilla.mozilla.org/show_bug.cgi?id=695438.
	 *
	 *   - Safari 5-7 lacks support for changing the `Object.prototype.constructor` property
	 *     on objects.
	 *
	 *   - Chrome 9-10 is missing the `TypedArray.prototype.subarray` function.
	 *
	 *   - IE10 has a broken `TypedArray.prototype.subarray` function which returns arrays of
	 *     incorrect length in some situations.

	 * We detect these buggy browsers and set `Buffer.TYPED_ARRAY_SUPPORT` to `false` so they
	 * get the Object implementation, which is slower but behaves correctly.
	 */
	Buffer.TYPED_ARRAY_SUPPORT = global.TYPED_ARRAY_SUPPORT !== undefined
	  ? global.TYPED_ARRAY_SUPPORT
	  : typedArraySupport()

	function typedArraySupport () {
	  function Bar () {}
	  try {
	    var arr = new Uint8Array(1)
	    arr.foo = function () { return 42 }
	    arr.constructor = Bar
	    return arr.foo() === 42 && // typed array instances can be augmented
	        arr.constructor === Bar && // constructor can be set
	        typeof arr.subarray === 'function' && // chrome 9-10 lack `subarray`
	        arr.subarray(1, 1).byteLength === 0 // ie10 has broken `subarray`
	  } catch (e) {
	    return false
	  }
	}

	function kMaxLength () {
	  return Buffer.TYPED_ARRAY_SUPPORT
	    ? 0x7fffffff
	    : 0x3fffffff
	}

	/**
	 * Class: Buffer
	 * =============
	 *
	 * The Buffer constructor returns instances of `Uint8Array` that are augmented
	 * with function properties for all the node `Buffer` API functions. We use
	 * `Uint8Array` so that square bracket notation works as expected -- it returns
	 * a single octet.
	 *
	 * By augmenting the instances, we can avoid modifying the `Uint8Array`
	 * prototype.
	 */
	function Buffer (arg) {
	  if (!(this instanceof Buffer)) {
	    // Avoid going through an ArgumentsAdaptorTrampoline in the common case.
	    if (arguments.length > 1) return new Buffer(arg, arguments[1])
	    return new Buffer(arg)
	  }

	  if (!Buffer.TYPED_ARRAY_SUPPORT) {
	    this.length = 0
	    this.parent = undefined
	  }

	  // Common case.
	  if (typeof arg === 'number') {
	    return fromNumber(this, arg)
	  }

	  // Slightly less common case.
	  if (typeof arg === 'string') {
	    return fromString(this, arg, arguments.length > 1 ? arguments[1] : 'utf8')
	  }

	  // Unusual.
	  return fromObject(this, arg)
	}

	function fromNumber (that, length) {
	  that = allocate(that, length < 0 ? 0 : checked(length) | 0)
	  if (!Buffer.TYPED_ARRAY_SUPPORT) {
	    for (var i = 0; i < length; i++) {
	      that[i] = 0
	    }
	  }
	  return that
	}

	function fromString (that, string, encoding) {
	  if (typeof encoding !== 'string' || encoding === '') encoding = 'utf8'

	  // Assumption: byteLength() return value is always < kMaxLength.
	  var length = byteLength(string, encoding) | 0
	  that = allocate(that, length)

	  that.write(string, encoding)
	  return that
	}

	function fromObject (that, object) {
	  if (Buffer.isBuffer(object)) return fromBuffer(that, object)

	  if (isArray(object)) return fromArray(that, object)

	  if (object == null) {
	    throw new TypeError('must start with number, buffer, array or string')
	  }

	  if (typeof ArrayBuffer !== 'undefined') {
	    if (object.buffer instanceof ArrayBuffer) {
	      return fromTypedArray(that, object)
	    }
	    if (object instanceof ArrayBuffer) {
	      return fromArrayBuffer(that, object)
	    }
	  }

	  if (object.length) return fromArrayLike(that, object)

	  return fromJsonObject(that, object)
	}

	function fromBuffer (that, buffer) {
	  var length = checked(buffer.length) | 0
	  that = allocate(that, length)
	  buffer.copy(that, 0, 0, length)
	  return that
	}

	function fromArray (that, array) {
	  var length = checked(array.length) | 0
	  that = allocate(that, length)
	  for (var i = 0; i < length; i += 1) {
	    that[i] = array[i] & 255
	  }
	  return that
	}

	// Duplicate of fromArray() to keep fromArray() monomorphic.
	function fromTypedArray (that, array) {
	  var length = checked(array.length) | 0
	  that = allocate(that, length)
	  // Truncating the elements is probably not what people expect from typed
	  // arrays with BYTES_PER_ELEMENT > 1 but it's compatible with the behavior
	  // of the old Buffer constructor.
	  for (var i = 0; i < length; i += 1) {
	    that[i] = array[i] & 255
	  }
	  return that
	}

	function fromArrayBuffer (that, array) {
	  if (Buffer.TYPED_ARRAY_SUPPORT) {
	    // Return an augmented `Uint8Array` instance, for best performance
	    array.byteLength
	    that = Buffer._augment(new Uint8Array(array))
	  } else {
	    // Fallback: Return an object instance of the Buffer class
	    that = fromTypedArray(that, new Uint8Array(array))
	  }
	  return that
	}

	function fromArrayLike (that, array) {
	  var length = checked(array.length) | 0
	  that = allocate(that, length)
	  for (var i = 0; i < length; i += 1) {
	    that[i] = array[i] & 255
	  }
	  return that
	}

	// Deserialize { type: 'Buffer', data: [1,2,3,...] } into a Buffer object.
	// Returns a zero-length buffer for inputs that don't conform to the spec.
	function fromJsonObject (that, object) {
	  var array
	  var length = 0

	  if (object.type === 'Buffer' && isArray(object.data)) {
	    array = object.data
	    length = checked(array.length) | 0
	  }
	  that = allocate(that, length)

	  for (var i = 0; i < length; i += 1) {
	    that[i] = array[i] & 255
	  }
	  return that
	}

	if (Buffer.TYPED_ARRAY_SUPPORT) {
	  Buffer.prototype.__proto__ = Uint8Array.prototype
	  Buffer.__proto__ = Uint8Array
	} else {
	  // pre-set for values that may exist in the future
	  Buffer.prototype.length = undefined
	  Buffer.prototype.parent = undefined
	}

	function allocate (that, length) {
	  if (Buffer.TYPED_ARRAY_SUPPORT) {
	    // Return an augmented `Uint8Array` instance, for best performance
	    that = Buffer._augment(new Uint8Array(length))
	    that.__proto__ = Buffer.prototype
	  } else {
	    // Fallback: Return an object instance of the Buffer class
	    that.length = length
	    that._isBuffer = true
	  }

	  var fromPool = length !== 0 && length <= Buffer.poolSize >>> 1
	  if (fromPool) that.parent = rootParent

	  return that
	}

	function checked (length) {
	  // Note: cannot use `length < kMaxLength` here because that fails when
	  // length is NaN (which is otherwise coerced to zero.)
	  if (length >= kMaxLength()) {
	    throw new RangeError('Attempt to allocate Buffer larger than maximum ' +
	                         'size: 0x' + kMaxLength().toString(16) + ' bytes')
	  }
	  return length | 0
	}

	function SlowBuffer (subject, encoding) {
	  if (!(this instanceof SlowBuffer)) return new SlowBuffer(subject, encoding)

	  var buf = new Buffer(subject, encoding)
	  delete buf.parent
	  return buf
	}

	Buffer.isBuffer = function isBuffer (b) {
	  return !!(b != null && b._isBuffer)
	}

	Buffer.compare = function compare (a, b) {
	  if (!Buffer.isBuffer(a) || !Buffer.isBuffer(b)) {
	    throw new TypeError('Arguments must be Buffers')
	  }

	  if (a === b) return 0

	  var x = a.length
	  var y = b.length

	  var i = 0
	  var len = Math.min(x, y)
	  while (i < len) {
	    if (a[i] !== b[i]) break

	    ++i
	  }

	  if (i !== len) {
	    x = a[i]
	    y = b[i]
	  }

	  if (x < y) return -1
	  if (y < x) return 1
	  return 0
	}

	Buffer.isEncoding = function isEncoding (encoding) {
	  switch (String(encoding).toLowerCase()) {
	    case 'hex':
	    case 'utf8':
	    case 'utf-8':
	    case 'ascii':
	    case 'binary':
	    case 'base64':
	    case 'raw':
	    case 'ucs2':
	    case 'ucs-2':
	    case 'utf16le':
	    case 'utf-16le':
	      return true
	    default:
	      return false
	  }
	}

	Buffer.concat = function concat (list, length) {
	  if (!isArray(list)) throw new TypeError('list argument must be an Array of Buffers.')

	  if (list.length === 0) {
	    return new Buffer(0)
	  }

	  var i
	  if (length === undefined) {
	    length = 0
	    for (i = 0; i < list.length; i++) {
	      length += list[i].length
	    }
	  }

	  var buf = new Buffer(length)
	  var pos = 0
	  for (i = 0; i < list.length; i++) {
	    var item = list[i]
	    item.copy(buf, pos)
	    pos += item.length
	  }
	  return buf
	}

	function byteLength (string, encoding) {
	  if (typeof string !== 'string') string = '' + string

	  var len = string.length
	  if (len === 0) return 0

	  // Use a for loop to avoid recursion
	  var loweredCase = false
	  for (;;) {
	    switch (encoding) {
	      case 'ascii':
	      case 'binary':
	      // Deprecated
	      case 'raw':
	      case 'raws':
	        return len
	      case 'utf8':
	      case 'utf-8':
	        return utf8ToBytes(string).length
	      case 'ucs2':
	      case 'ucs-2':
	      case 'utf16le':
	      case 'utf-16le':
	        return len * 2
	      case 'hex':
	        return len >>> 1
	      case 'base64':
	        return base64ToBytes(string).length
	      default:
	        if (loweredCase) return utf8ToBytes(string).length // assume utf8
	        encoding = ('' + encoding).toLowerCase()
	        loweredCase = true
	    }
	  }
	}
	Buffer.byteLength = byteLength

	function slowToString (encoding, start, end) {
	  var loweredCase = false

	  start = start | 0
	  end = end === undefined || end === Infinity ? this.length : end | 0

	  if (!encoding) encoding = 'utf8'
	  if (start < 0) start = 0
	  if (end > this.length) end = this.length
	  if (end <= start) return ''

	  while (true) {
	    switch (encoding) {
	      case 'hex':
	        return hexSlice(this, start, end)

	      case 'utf8':
	      case 'utf-8':
	        return utf8Slice(this, start, end)

	      case 'ascii':
	        return asciiSlice(this, start, end)

	      case 'binary':
	        return binarySlice(this, start, end)

	      case 'base64':
	        return base64Slice(this, start, end)

	      case 'ucs2':
	      case 'ucs-2':
	      case 'utf16le':
	      case 'utf-16le':
	        return utf16leSlice(this, start, end)

	      default:
	        if (loweredCase) throw new TypeError('Unknown encoding: ' + encoding)
	        encoding = (encoding + '').toLowerCase()
	        loweredCase = true
	    }
	  }
	}

	Buffer.prototype.toString = function toString () {
	  var length = this.length | 0
	  if (length === 0) return ''
	  if (arguments.length === 0) return utf8Slice(this, 0, length)
	  return slowToString.apply(this, arguments)
	}

	Buffer.prototype.equals = function equals (b) {
	  if (!Buffer.isBuffer(b)) throw new TypeError('Argument must be a Buffer')
	  if (this === b) return true
	  return Buffer.compare(this, b) === 0
	}

	Buffer.prototype.inspect = function inspect () {
	  var str = ''
	  var max = exports.INSPECT_MAX_BYTES
	  if (this.length > 0) {
	    str = this.toString('hex', 0, max).match(/.{2}/g).join(' ')
	    if (this.length > max) str += ' ... '
	  }
	  return '<Buffer ' + str + '>'
	}

	Buffer.prototype.compare = function compare (b) {
	  if (!Buffer.isBuffer(b)) throw new TypeError('Argument must be a Buffer')
	  if (this === b) return 0
	  return Buffer.compare(this, b)
	}

	Buffer.prototype.indexOf = function indexOf (val, byteOffset) {
	  if (byteOffset > 0x7fffffff) byteOffset = 0x7fffffff
	  else if (byteOffset < -0x80000000) byteOffset = -0x80000000
	  byteOffset >>= 0

	  if (this.length === 0) return -1
	  if (byteOffset >= this.length) return -1

	  // Negative offsets start from the end of the buffer
	  if (byteOffset < 0) byteOffset = Math.max(this.length + byteOffset, 0)

	  if (typeof val === 'string') {
	    if (val.length === 0) return -1 // special case: looking for empty string always fails
	    return String.prototype.indexOf.call(this, val, byteOffset)
	  }
	  if (Buffer.isBuffer(val)) {
	    return arrayIndexOf(this, val, byteOffset)
	  }
	  if (typeof val === 'number') {
	    if (Buffer.TYPED_ARRAY_SUPPORT && Uint8Array.prototype.indexOf === 'function') {
	      return Uint8Array.prototype.indexOf.call(this, val, byteOffset)
	    }
	    return arrayIndexOf(this, [ val ], byteOffset)
	  }

	  function arrayIndexOf (arr, val, byteOffset) {
	    var foundIndex = -1
	    for (var i = 0; byteOffset + i < arr.length; i++) {
	      if (arr[byteOffset + i] === val[foundIndex === -1 ? 0 : i - foundIndex]) {
	        if (foundIndex === -1) foundIndex = i
	        if (i - foundIndex + 1 === val.length) return byteOffset + foundIndex
	      } else {
	        foundIndex = -1
	      }
	    }
	    return -1
	  }

	  throw new TypeError('val must be string, number or Buffer')
	}

	// `get` is deprecated
	Buffer.prototype.get = function get (offset) {
	  console.log('.get() is deprecated. Access using array indexes instead.')
	  return this.readUInt8(offset)
	}

	// `set` is deprecated
	Buffer.prototype.set = function set (v, offset) {
	  console.log('.set() is deprecated. Access using array indexes instead.')
	  return this.writeUInt8(v, offset)
	}

	function hexWrite (buf, string, offset, length) {
	  offset = Number(offset) || 0
	  var remaining = buf.length - offset
	  if (!length) {
	    length = remaining
	  } else {
	    length = Number(length)
	    if (length > remaining) {
	      length = remaining
	    }
	  }

	  // must be an even number of digits
	  var strLen = string.length
	  if (strLen % 2 !== 0) throw new Error('Invalid hex string')

	  if (length > strLen / 2) {
	    length = strLen / 2
	  }
	  for (var i = 0; i < length; i++) {
	    var parsed = parseInt(string.substr(i * 2, 2), 16)
	    if (isNaN(parsed)) throw new Error('Invalid hex string')
	    buf[offset + i] = parsed
	  }
	  return i
	}

	function utf8Write (buf, string, offset, length) {
	  return blitBuffer(utf8ToBytes(string, buf.length - offset), buf, offset, length)
	}

	function asciiWrite (buf, string, offset, length) {
	  return blitBuffer(asciiToBytes(string), buf, offset, length)
	}

	function binaryWrite (buf, string, offset, length) {
	  return asciiWrite(buf, string, offset, length)
	}

	function base64Write (buf, string, offset, length) {
	  return blitBuffer(base64ToBytes(string), buf, offset, length)
	}

	function ucs2Write (buf, string, offset, length) {
	  return blitBuffer(utf16leToBytes(string, buf.length - offset), buf, offset, length)
	}

	Buffer.prototype.write = function write (string, offset, length, encoding) {
	  // Buffer#write(string)
	  if (offset === undefined) {
	    encoding = 'utf8'
	    length = this.length
	    offset = 0
	  // Buffer#write(string, encoding)
	  } else if (length === undefined && typeof offset === 'string') {
	    encoding = offset
	    length = this.length
	    offset = 0
	  // Buffer#write(string, offset[, length][, encoding])
	  } else if (isFinite(offset)) {
	    offset = offset | 0
	    if (isFinite(length)) {
	      length = length | 0
	      if (encoding === undefined) encoding = 'utf8'
	    } else {
	      encoding = length
	      length = undefined
	    }
	  // legacy write(string, encoding, offset, length) - remove in v0.13
	  } else {
	    var swap = encoding
	    encoding = offset
	    offset = length | 0
	    length = swap
	  }

	  var remaining = this.length - offset
	  if (length === undefined || length > remaining) length = remaining

	  if ((string.length > 0 && (length < 0 || offset < 0)) || offset > this.length) {
	    throw new RangeError('attempt to write outside buffer bounds')
	  }

	  if (!encoding) encoding = 'utf8'

	  var loweredCase = false
	  for (;;) {
	    switch (encoding) {
	      case 'hex':
	        return hexWrite(this, string, offset, length)

	      case 'utf8':
	      case 'utf-8':
	        return utf8Write(this, string, offset, length)

	      case 'ascii':
	        return asciiWrite(this, string, offset, length)

	      case 'binary':
	        return binaryWrite(this, string, offset, length)

	      case 'base64':
	        // Warning: maxLength not taken into account in base64Write
	        return base64Write(this, string, offset, length)

	      case 'ucs2':
	      case 'ucs-2':
	      case 'utf16le':
	      case 'utf-16le':
	        return ucs2Write(this, string, offset, length)

	      default:
	        if (loweredCase) throw new TypeError('Unknown encoding: ' + encoding)
	        encoding = ('' + encoding).toLowerCase()
	        loweredCase = true
	    }
	  }
	}

	Buffer.prototype.toJSON = function toJSON () {
	  return {
	    type: 'Buffer',
	    data: Array.prototype.slice.call(this._arr || this, 0)
	  }
	}

	function base64Slice (buf, start, end) {
	  if (start === 0 && end === buf.length) {
	    return base64.fromByteArray(buf)
	  } else {
	    return base64.fromByteArray(buf.slice(start, end))
	  }
	}

	function utf8Slice (buf, start, end) {
	  end = Math.min(buf.length, end)
	  var res = []

	  var i = start
	  while (i < end) {
	    var firstByte = buf[i]
	    var codePoint = null
	    var bytesPerSequence = (firstByte > 0xEF) ? 4
	      : (firstByte > 0xDF) ? 3
	      : (firstByte > 0xBF) ? 2
	      : 1

	    if (i + bytesPerSequence <= end) {
	      var secondByte, thirdByte, fourthByte, tempCodePoint

	      switch (bytesPerSequence) {
	        case 1:
	          if (firstByte < 0x80) {
	            codePoint = firstByte
	          }
	          break
	        case 2:
	          secondByte = buf[i + 1]
	          if ((secondByte & 0xC0) === 0x80) {
	            tempCodePoint = (firstByte & 0x1F) << 0x6 | (secondByte & 0x3F)
	            if (tempCodePoint > 0x7F) {
	              codePoint = tempCodePoint
	            }
	          }
	          break
	        case 3:
	          secondByte = buf[i + 1]
	          thirdByte = buf[i + 2]
	          if ((secondByte & 0xC0) === 0x80 && (thirdByte & 0xC0) === 0x80) {
	            tempCodePoint = (firstByte & 0xF) << 0xC | (secondByte & 0x3F) << 0x6 | (thirdByte & 0x3F)
	            if (tempCodePoint > 0x7FF && (tempCodePoint < 0xD800 || tempCodePoint > 0xDFFF)) {
	              codePoint = tempCodePoint
	            }
	          }
	          break
	        case 4:
	          secondByte = buf[i + 1]
	          thirdByte = buf[i + 2]
	          fourthByte = buf[i + 3]
	          if ((secondByte & 0xC0) === 0x80 && (thirdByte & 0xC0) === 0x80 && (fourthByte & 0xC0) === 0x80) {
	            tempCodePoint = (firstByte & 0xF) << 0x12 | (secondByte & 0x3F) << 0xC | (thirdByte & 0x3F) << 0x6 | (fourthByte & 0x3F)
	            if (tempCodePoint > 0xFFFF && tempCodePoint < 0x110000) {
	              codePoint = tempCodePoint
	            }
	          }
	      }
	    }

	    if (codePoint === null) {
	      // we did not generate a valid codePoint so insert a
	      // replacement char (U+FFFD) and advance only 1 byte
	      codePoint = 0xFFFD
	      bytesPerSequence = 1
	    } else if (codePoint > 0xFFFF) {
	      // encode to utf16 (surrogate pair dance)
	      codePoint -= 0x10000
	      res.push(codePoint >>> 10 & 0x3FF | 0xD800)
	      codePoint = 0xDC00 | codePoint & 0x3FF
	    }

	    res.push(codePoint)
	    i += bytesPerSequence
	  }

	  return decodeCodePointsArray(res)
	}

	// Based on http://stackoverflow.com/a/22747272/680742, the browser with
	// the lowest limit is Chrome, with 0x10000 args.
	// We go 1 magnitude less, for safety
	var MAX_ARGUMENTS_LENGTH = 0x1000

	function decodeCodePointsArray (codePoints) {
	  var len = codePoints.length
	  if (len <= MAX_ARGUMENTS_LENGTH) {
	    return String.fromCharCode.apply(String, codePoints) // avoid extra slice()
	  }

	  // Decode in chunks to avoid "call stack size exceeded".
	  var res = ''
	  var i = 0
	  while (i < len) {
	    res += String.fromCharCode.apply(
	      String,
	      codePoints.slice(i, i += MAX_ARGUMENTS_LENGTH)
	    )
	  }
	  return res
	}

	function asciiSlice (buf, start, end) {
	  var ret = ''
	  end = Math.min(buf.length, end)

	  for (var i = start; i < end; i++) {
	    ret += String.fromCharCode(buf[i] & 0x7F)
	  }
	  return ret
	}

	function binarySlice (buf, start, end) {
	  var ret = ''
	  end = Math.min(buf.length, end)

	  for (var i = start; i < end; i++) {
	    ret += String.fromCharCode(buf[i])
	  }
	  return ret
	}

	function hexSlice (buf, start, end) {
	  var len = buf.length

	  if (!start || start < 0) start = 0
	  if (!end || end < 0 || end > len) end = len

	  var out = ''
	  for (var i = start; i < end; i++) {
	    out += toHex(buf[i])
	  }
	  return out
	}

	function utf16leSlice (buf, start, end) {
	  var bytes = buf.slice(start, end)
	  var res = ''
	  for (var i = 0; i < bytes.length; i += 2) {
	    res += String.fromCharCode(bytes[i] + bytes[i + 1] * 256)
	  }
	  return res
	}

	Buffer.prototype.slice = function slice (start, end) {
	  var len = this.length
	  start = ~~start
	  end = end === undefined ? len : ~~end

	  if (start < 0) {
	    start += len
	    if (start < 0) start = 0
	  } else if (start > len) {
	    start = len
	  }

	  if (end < 0) {
	    end += len
	    if (end < 0) end = 0
	  } else if (end > len) {
	    end = len
	  }

	  if (end < start) end = start

	  var newBuf
	  if (Buffer.TYPED_ARRAY_SUPPORT) {
	    newBuf = Buffer._augment(this.subarray(start, end))
	  } else {
	    var sliceLen = end - start
	    newBuf = new Buffer(sliceLen, undefined)
	    for (var i = 0; i < sliceLen; i++) {
	      newBuf[i] = this[i + start]
	    }
	  }

	  if (newBuf.length) newBuf.parent = this.parent || this

	  return newBuf
	}

	/*
	 * Need to make sure that buffer isn't trying to write out of bounds.
	 */
	function checkOffset (offset, ext, length) {
	  if ((offset % 1) !== 0 || offset < 0) throw new RangeError('offset is not uint')
	  if (offset + ext > length) throw new RangeError('Trying to access beyond buffer length')
	}

	Buffer.prototype.readUIntLE = function readUIntLE (offset, byteLength, noAssert) {
	  offset = offset | 0
	  byteLength = byteLength | 0
	  if (!noAssert) checkOffset(offset, byteLength, this.length)

	  var val = this[offset]
	  var mul = 1
	  var i = 0
	  while (++i < byteLength && (mul *= 0x100)) {
	    val += this[offset + i] * mul
	  }

	  return val
	}

	Buffer.prototype.readUIntBE = function readUIntBE (offset, byteLength, noAssert) {
	  offset = offset | 0
	  byteLength = byteLength | 0
	  if (!noAssert) {
	    checkOffset(offset, byteLength, this.length)
	  }

	  var val = this[offset + --byteLength]
	  var mul = 1
	  while (byteLength > 0 && (mul *= 0x100)) {
	    val += this[offset + --byteLength] * mul
	  }

	  return val
	}

	Buffer.prototype.readUInt8 = function readUInt8 (offset, noAssert) {
	  if (!noAssert) checkOffset(offset, 1, this.length)
	  return this[offset]
	}

	Buffer.prototype.readUInt16LE = function readUInt16LE (offset, noAssert) {
	  if (!noAssert) checkOffset(offset, 2, this.length)
	  return this[offset] | (this[offset + 1] << 8)
	}

	Buffer.prototype.readUInt16BE = function readUInt16BE (offset, noAssert) {
	  if (!noAssert) checkOffset(offset, 2, this.length)
	  return (this[offset] << 8) | this[offset + 1]
	}

	Buffer.prototype.readUInt32LE = function readUInt32LE (offset, noAssert) {
	  if (!noAssert) checkOffset(offset, 4, this.length)

	  return ((this[offset]) |
	      (this[offset + 1] << 8) |
	      (this[offset + 2] << 16)) +
	      (this[offset + 3] * 0x1000000)
	}

	Buffer.prototype.readUInt32BE = function readUInt32BE (offset, noAssert) {
	  if (!noAssert) checkOffset(offset, 4, this.length)

	  return (this[offset] * 0x1000000) +
	    ((this[offset + 1] << 16) |
	    (this[offset + 2] << 8) |
	    this[offset + 3])
	}

	Buffer.prototype.readIntLE = function readIntLE (offset, byteLength, noAssert) {
	  offset = offset | 0
	  byteLength = byteLength | 0
	  if (!noAssert) checkOffset(offset, byteLength, this.length)

	  var val = this[offset]
	  var mul = 1
	  var i = 0
	  while (++i < byteLength && (mul *= 0x100)) {
	    val += this[offset + i] * mul
	  }
	  mul *= 0x80

	  if (val >= mul) val -= Math.pow(2, 8 * byteLength)

	  return val
	}

	Buffer.prototype.readIntBE = function readIntBE (offset, byteLength, noAssert) {
	  offset = offset | 0
	  byteLength = byteLength | 0
	  if (!noAssert) checkOffset(offset, byteLength, this.length)

	  var i = byteLength
	  var mul = 1
	  var val = this[offset + --i]
	  while (i > 0 && (mul *= 0x100)) {
	    val += this[offset + --i] * mul
	  }
	  mul *= 0x80

	  if (val >= mul) val -= Math.pow(2, 8 * byteLength)

	  return val
	}

	Buffer.prototype.readInt8 = function readInt8 (offset, noAssert) {
	  if (!noAssert) checkOffset(offset, 1, this.length)
	  if (!(this[offset] & 0x80)) return (this[offset])
	  return ((0xff - this[offset] + 1) * -1)
	}

	Buffer.prototype.readInt16LE = function readInt16LE (offset, noAssert) {
	  if (!noAssert) checkOffset(offset, 2, this.length)
	  var val = this[offset] | (this[offset + 1] << 8)
	  return (val & 0x8000) ? val | 0xFFFF0000 : val
	}

	Buffer.prototype.readInt16BE = function readInt16BE (offset, noAssert) {
	  if (!noAssert) checkOffset(offset, 2, this.length)
	  var val = this[offset + 1] | (this[offset] << 8)
	  return (val & 0x8000) ? val | 0xFFFF0000 : val
	}

	Buffer.prototype.readInt32LE = function readInt32LE (offset, noAssert) {
	  if (!noAssert) checkOffset(offset, 4, this.length)

	  return (this[offset]) |
	    (this[offset + 1] << 8) |
	    (this[offset + 2] << 16) |
	    (this[offset + 3] << 24)
	}

	Buffer.prototype.readInt32BE = function readInt32BE (offset, noAssert) {
	  if (!noAssert) checkOffset(offset, 4, this.length)

	  return (this[offset] << 24) |
	    (this[offset + 1] << 16) |
	    (this[offset + 2] << 8) |
	    (this[offset + 3])
	}

	Buffer.prototype.readFloatLE = function readFloatLE (offset, noAssert) {
	  if (!noAssert) checkOffset(offset, 4, this.length)
	  return ieee754.read(this, offset, true, 23, 4)
	}

	Buffer.prototype.readFloatBE = function readFloatBE (offset, noAssert) {
	  if (!noAssert) checkOffset(offset, 4, this.length)
	  return ieee754.read(this, offset, false, 23, 4)
	}

	Buffer.prototype.readDoubleLE = function readDoubleLE (offset, noAssert) {
	  if (!noAssert) checkOffset(offset, 8, this.length)
	  return ieee754.read(this, offset, true, 52, 8)
	}

	Buffer.prototype.readDoubleBE = function readDoubleBE (offset, noAssert) {
	  if (!noAssert) checkOffset(offset, 8, this.length)
	  return ieee754.read(this, offset, false, 52, 8)
	}

	function checkInt (buf, value, offset, ext, max, min) {
	  if (!Buffer.isBuffer(buf)) throw new TypeError('buffer must be a Buffer instance')
	  if (value > max || value < min) throw new RangeError('value is out of bounds')
	  if (offset + ext > buf.length) throw new RangeError('index out of range')
	}

	Buffer.prototype.writeUIntLE = function writeUIntLE (value, offset, byteLength, noAssert) {
	  value = +value
	  offset = offset | 0
	  byteLength = byteLength | 0
	  if (!noAssert) checkInt(this, value, offset, byteLength, Math.pow(2, 8 * byteLength), 0)

	  var mul = 1
	  var i = 0
	  this[offset] = value & 0xFF
	  while (++i < byteLength && (mul *= 0x100)) {
	    this[offset + i] = (value / mul) & 0xFF
	  }

	  return offset + byteLength
	}

	Buffer.prototype.writeUIntBE = function writeUIntBE (value, offset, byteLength, noAssert) {
	  value = +value
	  offset = offset | 0
	  byteLength = byteLength | 0
	  if (!noAssert) checkInt(this, value, offset, byteLength, Math.pow(2, 8 * byteLength), 0)

	  var i = byteLength - 1
	  var mul = 1
	  this[offset + i] = value & 0xFF
	  while (--i >= 0 && (mul *= 0x100)) {
	    this[offset + i] = (value / mul) & 0xFF
	  }

	  return offset + byteLength
	}

	Buffer.prototype.writeUInt8 = function writeUInt8 (value, offset, noAssert) {
	  value = +value
	  offset = offset | 0
	  if (!noAssert) checkInt(this, value, offset, 1, 0xff, 0)
	  if (!Buffer.TYPED_ARRAY_SUPPORT) value = Math.floor(value)
	  this[offset] = (value & 0xff)
	  return offset + 1
	}

	function objectWriteUInt16 (buf, value, offset, littleEndian) {
	  if (value < 0) value = 0xffff + value + 1
	  for (var i = 0, j = Math.min(buf.length - offset, 2); i < j; i++) {
	    buf[offset + i] = (value & (0xff << (8 * (littleEndian ? i : 1 - i)))) >>>
	      (littleEndian ? i : 1 - i) * 8
	  }
	}

	Buffer.prototype.writeUInt16LE = function writeUInt16LE (value, offset, noAssert) {
	  value = +value
	  offset = offset | 0
	  if (!noAssert) checkInt(this, value, offset, 2, 0xffff, 0)
	  if (Buffer.TYPED_ARRAY_SUPPORT) {
	    this[offset] = (value & 0xff)
	    this[offset + 1] = (value >>> 8)
	  } else {
	    objectWriteUInt16(this, value, offset, true)
	  }
	  return offset + 2
	}

	Buffer.prototype.writeUInt16BE = function writeUInt16BE (value, offset, noAssert) {
	  value = +value
	  offset = offset | 0
	  if (!noAssert) checkInt(this, value, offset, 2, 0xffff, 0)
	  if (Buffer.TYPED_ARRAY_SUPPORT) {
	    this[offset] = (value >>> 8)
	    this[offset + 1] = (value & 0xff)
	  } else {
	    objectWriteUInt16(this, value, offset, false)
	  }
	  return offset + 2
	}

	function objectWriteUInt32 (buf, value, offset, littleEndian) {
	  if (value < 0) value = 0xffffffff + value + 1
	  for (var i = 0, j = Math.min(buf.length - offset, 4); i < j; i++) {
	    buf[offset + i] = (value >>> (littleEndian ? i : 3 - i) * 8) & 0xff
	  }
	}

	Buffer.prototype.writeUInt32LE = function writeUInt32LE (value, offset, noAssert) {
	  value = +value
	  offset = offset | 0
	  if (!noAssert) checkInt(this, value, offset, 4, 0xffffffff, 0)
	  if (Buffer.TYPED_ARRAY_SUPPORT) {
	    this[offset + 3] = (value >>> 24)
	    this[offset + 2] = (value >>> 16)
	    this[offset + 1] = (value >>> 8)
	    this[offset] = (value & 0xff)
	  } else {
	    objectWriteUInt32(this, value, offset, true)
	  }
	  return offset + 4
	}

	Buffer.prototype.writeUInt32BE = function writeUInt32BE (value, offset, noAssert) {
	  value = +value
	  offset = offset | 0
	  if (!noAssert) checkInt(this, value, offset, 4, 0xffffffff, 0)
	  if (Buffer.TYPED_ARRAY_SUPPORT) {
	    this[offset] = (value >>> 24)
	    this[offset + 1] = (value >>> 16)
	    this[offset + 2] = (value >>> 8)
	    this[offset + 3] = (value & 0xff)
	  } else {
	    objectWriteUInt32(this, value, offset, false)
	  }
	  return offset + 4
	}

	Buffer.prototype.writeIntLE = function writeIntLE (value, offset, byteLength, noAssert) {
	  value = +value
	  offset = offset | 0
	  if (!noAssert) {
	    var limit = Math.pow(2, 8 * byteLength - 1)

	    checkInt(this, value, offset, byteLength, limit - 1, -limit)
	  }

	  var i = 0
	  var mul = 1
	  var sub = value < 0 ? 1 : 0
	  this[offset] = value & 0xFF
	  while (++i < byteLength && (mul *= 0x100)) {
	    this[offset + i] = ((value / mul) >> 0) - sub & 0xFF
	  }

	  return offset + byteLength
	}

	Buffer.prototype.writeIntBE = function writeIntBE (value, offset, byteLength, noAssert) {
	  value = +value
	  offset = offset | 0
	  if (!noAssert) {
	    var limit = Math.pow(2, 8 * byteLength - 1)

	    checkInt(this, value, offset, byteLength, limit - 1, -limit)
	  }

	  var i = byteLength - 1
	  var mul = 1
	  var sub = value < 0 ? 1 : 0
	  this[offset + i] = value & 0xFF
	  while (--i >= 0 && (mul *= 0x100)) {
	    this[offset + i] = ((value / mul) >> 0) - sub & 0xFF
	  }

	  return offset + byteLength
	}

	Buffer.prototype.writeInt8 = function writeInt8 (value, offset, noAssert) {
	  value = +value
	  offset = offset | 0
	  if (!noAssert) checkInt(this, value, offset, 1, 0x7f, -0x80)
	  if (!Buffer.TYPED_ARRAY_SUPPORT) value = Math.floor(value)
	  if (value < 0) value = 0xff + value + 1
	  this[offset] = (value & 0xff)
	  return offset + 1
	}

	Buffer.prototype.writeInt16LE = function writeInt16LE (value, offset, noAssert) {
	  value = +value
	  offset = offset | 0
	  if (!noAssert) checkInt(this, value, offset, 2, 0x7fff, -0x8000)
	  if (Buffer.TYPED_ARRAY_SUPPORT) {
	    this[offset] = (value & 0xff)
	    this[offset + 1] = (value >>> 8)
	  } else {
	    objectWriteUInt16(this, value, offset, true)
	  }
	  return offset + 2
	}

	Buffer.prototype.writeInt16BE = function writeInt16BE (value, offset, noAssert) {
	  value = +value
	  offset = offset | 0
	  if (!noAssert) checkInt(this, value, offset, 2, 0x7fff, -0x8000)
	  if (Buffer.TYPED_ARRAY_SUPPORT) {
	    this[offset] = (value >>> 8)
	    this[offset + 1] = (value & 0xff)
	  } else {
	    objectWriteUInt16(this, value, offset, false)
	  }
	  return offset + 2
	}

	Buffer.prototype.writeInt32LE = function writeInt32LE (value, offset, noAssert) {
	  value = +value
	  offset = offset | 0
	  if (!noAssert) checkInt(this, value, offset, 4, 0x7fffffff, -0x80000000)
	  if (Buffer.TYPED_ARRAY_SUPPORT) {
	    this[offset] = (value & 0xff)
	    this[offset + 1] = (value >>> 8)
	    this[offset + 2] = (value >>> 16)
	    this[offset + 3] = (value >>> 24)
	  } else {
	    objectWriteUInt32(this, value, offset, true)
	  }
	  return offset + 4
	}

	Buffer.prototype.writeInt32BE = function writeInt32BE (value, offset, noAssert) {
	  value = +value
	  offset = offset | 0
	  if (!noAssert) checkInt(this, value, offset, 4, 0x7fffffff, -0x80000000)
	  if (value < 0) value = 0xffffffff + value + 1
	  if (Buffer.TYPED_ARRAY_SUPPORT) {
	    this[offset] = (value >>> 24)
	    this[offset + 1] = (value >>> 16)
	    this[offset + 2] = (value >>> 8)
	    this[offset + 3] = (value & 0xff)
	  } else {
	    objectWriteUInt32(this, value, offset, false)
	  }
	  return offset + 4
	}

	function checkIEEE754 (buf, value, offset, ext, max, min) {
	  if (value > max || value < min) throw new RangeError('value is out of bounds')
	  if (offset + ext > buf.length) throw new RangeError('index out of range')
	  if (offset < 0) throw new RangeError('index out of range')
	}

	function writeFloat (buf, value, offset, littleEndian, noAssert) {
	  if (!noAssert) {
	    checkIEEE754(buf, value, offset, 4, 3.4028234663852886e+38, -3.4028234663852886e+38)
	  }
	  ieee754.write(buf, value, offset, littleEndian, 23, 4)
	  return offset + 4
	}

	Buffer.prototype.writeFloatLE = function writeFloatLE (value, offset, noAssert) {
	  return writeFloat(this, value, offset, true, noAssert)
	}

	Buffer.prototype.writeFloatBE = function writeFloatBE (value, offset, noAssert) {
	  return writeFloat(this, value, offset, false, noAssert)
	}

	function writeDouble (buf, value, offset, littleEndian, noAssert) {
	  if (!noAssert) {
	    checkIEEE754(buf, value, offset, 8, 1.7976931348623157E+308, -1.7976931348623157E+308)
	  }
	  ieee754.write(buf, value, offset, littleEndian, 52, 8)
	  return offset + 8
	}

	Buffer.prototype.writeDoubleLE = function writeDoubleLE (value, offset, noAssert) {
	  return writeDouble(this, value, offset, true, noAssert)
	}

	Buffer.prototype.writeDoubleBE = function writeDoubleBE (value, offset, noAssert) {
	  return writeDouble(this, value, offset, false, noAssert)
	}

	// copy(targetBuffer, targetStart=0, sourceStart=0, sourceEnd=buffer.length)
	Buffer.prototype.copy = function copy (target, targetStart, start, end) {
	  if (!start) start = 0
	  if (!end && end !== 0) end = this.length
	  if (targetStart >= target.length) targetStart = target.length
	  if (!targetStart) targetStart = 0
	  if (end > 0 && end < start) end = start

	  // Copy 0 bytes; we're done
	  if (end === start) return 0
	  if (target.length === 0 || this.length === 0) return 0

	  // Fatal error conditions
	  if (targetStart < 0) {
	    throw new RangeError('targetStart out of bounds')
	  }
	  if (start < 0 || start >= this.length) throw new RangeError('sourceStart out of bounds')
	  if (end < 0) throw new RangeError('sourceEnd out of bounds')

	  // Are we oob?
	  if (end > this.length) end = this.length
	  if (target.length - targetStart < end - start) {
	    end = target.length - targetStart + start
	  }

	  var len = end - start
	  var i

	  if (this === target && start < targetStart && targetStart < end) {
	    // descending copy from end
	    for (i = len - 1; i >= 0; i--) {
	      target[i + targetStart] = this[i + start]
	    }
	  } else if (len < 1000 || !Buffer.TYPED_ARRAY_SUPPORT) {
	    // ascending copy from start
	    for (i = 0; i < len; i++) {
	      target[i + targetStart] = this[i + start]
	    }
	  } else {
	    target._set(this.subarray(start, start + len), targetStart)
	  }

	  return len
	}

	// fill(value, start=0, end=buffer.length)
	Buffer.prototype.fill = function fill (value, start, end) {
	  if (!value) value = 0
	  if (!start) start = 0
	  if (!end) end = this.length

	  if (end < start) throw new RangeError('end < start')

	  // Fill 0 bytes; we're done
	  if (end === start) return
	  if (this.length === 0) return

	  if (start < 0 || start >= this.length) throw new RangeError('start out of bounds')
	  if (end < 0 || end > this.length) throw new RangeError('end out of bounds')

	  var i
	  if (typeof value === 'number') {
	    for (i = start; i < end; i++) {
	      this[i] = value
	    }
	  } else {
	    var bytes = utf8ToBytes(value.toString())
	    var len = bytes.length
	    for (i = start; i < end; i++) {
	      this[i] = bytes[i % len]
	    }
	  }

	  return this
	}

	/**
	 * Creates a new `ArrayBuffer` with the *copied* memory of the buffer instance.
	 * Added in Node 0.12. Only available in browsers that support ArrayBuffer.
	 */
	Buffer.prototype.toArrayBuffer = function toArrayBuffer () {
	  if (typeof Uint8Array !== 'undefined') {
	    if (Buffer.TYPED_ARRAY_SUPPORT) {
	      return (new Buffer(this)).buffer
	    } else {
	      var buf = new Uint8Array(this.length)
	      for (var i = 0, len = buf.length; i < len; i += 1) {
	        buf[i] = this[i]
	      }
	      return buf.buffer
	    }
	  } else {
	    throw new TypeError('Buffer.toArrayBuffer not supported in this browser')
	  }
	}

	// HELPER FUNCTIONS
	// ================

	var BP = Buffer.prototype

	/**
	 * Augment a Uint8Array *instance* (not the Uint8Array class!) with Buffer methods
	 */
	Buffer._augment = function _augment (arr) {
	  arr.constructor = Buffer
	  arr._isBuffer = true

	  // save reference to original Uint8Array set method before overwriting
	  arr._set = arr.set

	  // deprecated
	  arr.get = BP.get
	  arr.set = BP.set

	  arr.write = BP.write
	  arr.toString = BP.toString
	  arr.toLocaleString = BP.toString
	  arr.toJSON = BP.toJSON
	  arr.equals = BP.equals
	  arr.compare = BP.compare
	  arr.indexOf = BP.indexOf
	  arr.copy = BP.copy
	  arr.slice = BP.slice
	  arr.readUIntLE = BP.readUIntLE
	  arr.readUIntBE = BP.readUIntBE
	  arr.readUInt8 = BP.readUInt8
	  arr.readUInt16LE = BP.readUInt16LE
	  arr.readUInt16BE = BP.readUInt16BE
	  arr.readUInt32LE = BP.readUInt32LE
	  arr.readUInt32BE = BP.readUInt32BE
	  arr.readIntLE = BP.readIntLE
	  arr.readIntBE = BP.readIntBE
	  arr.readInt8 = BP.readInt8
	  arr.readInt16LE = BP.readInt16LE
	  arr.readInt16BE = BP.readInt16BE
	  arr.readInt32LE = BP.readInt32LE
	  arr.readInt32BE = BP.readInt32BE
	  arr.readFloatLE = BP.readFloatLE
	  arr.readFloatBE = BP.readFloatBE
	  arr.readDoubleLE = BP.readDoubleLE
	  arr.readDoubleBE = BP.readDoubleBE
	  arr.writeUInt8 = BP.writeUInt8
	  arr.writeUIntLE = BP.writeUIntLE
	  arr.writeUIntBE = BP.writeUIntBE
	  arr.writeUInt16LE = BP.writeUInt16LE
	  arr.writeUInt16BE = BP.writeUInt16BE
	  arr.writeUInt32LE = BP.writeUInt32LE
	  arr.writeUInt32BE = BP.writeUInt32BE
	  arr.writeIntLE = BP.writeIntLE
	  arr.writeIntBE = BP.writeIntBE
	  arr.writeInt8 = BP.writeInt8
	  arr.writeInt16LE = BP.writeInt16LE
	  arr.writeInt16BE = BP.writeInt16BE
	  arr.writeInt32LE = BP.writeInt32LE
	  arr.writeInt32BE = BP.writeInt32BE
	  arr.writeFloatLE = BP.writeFloatLE
	  arr.writeFloatBE = BP.writeFloatBE
	  arr.writeDoubleLE = BP.writeDoubleLE
	  arr.writeDoubleBE = BP.writeDoubleBE
	  arr.fill = BP.fill
	  arr.inspect = BP.inspect
	  arr.toArrayBuffer = BP.toArrayBuffer

	  return arr
	}

	var INVALID_BASE64_RE = /[^+\/0-9A-Za-z-_]/g

	function base64clean (str) {
	  // Node strips out invalid characters like \n and \t from the string, base64-js does not
	  str = stringtrim(str).replace(INVALID_BASE64_RE, '')
	  // Node converts strings with length < 2 to ''
	  if (str.length < 2) return ''
	  // Node allows for non-padded base64 strings (missing trailing ===), base64-js does not
	  while (str.length % 4 !== 0) {
	    str = str + '='
	  }
	  return str
	}

	function stringtrim (str) {
	  if (str.trim) return str.trim()
	  return str.replace(/^\s+|\s+$/g, '')
	}

	function toHex (n) {
	  if (n < 16) return '0' + n.toString(16)
	  return n.toString(16)
	}

	function utf8ToBytes (string, units) {
	  units = units || Infinity
	  var codePoint
	  var length = string.length
	  var leadSurrogate = null
	  var bytes = []

	  for (var i = 0; i < length; i++) {
	    codePoint = string.charCodeAt(i)

	    // is surrogate component
	    if (codePoint > 0xD7FF && codePoint < 0xE000) {
	      // last char was a lead
	      if (!leadSurrogate) {
	        // no lead yet
	        if (codePoint > 0xDBFF) {
	          // unexpected trail
	          if ((units -= 3) > -1) bytes.push(0xEF, 0xBF, 0xBD)
	          continue
	        } else if (i + 1 === length) {
	          // unpaired lead
	          if ((units -= 3) > -1) bytes.push(0xEF, 0xBF, 0xBD)
	          continue
	        }

	        // valid lead
	        leadSurrogate = codePoint

	        continue
	      }

	      // 2 leads in a row
	      if (codePoint < 0xDC00) {
	        if ((units -= 3) > -1) bytes.push(0xEF, 0xBF, 0xBD)
	        leadSurrogate = codePoint
	        continue
	      }

	      // valid surrogate pair
	      codePoint = (leadSurrogate - 0xD800 << 10 | codePoint - 0xDC00) + 0x10000
	    } else if (leadSurrogate) {
	      // valid bmp char, but last char was a lead
	      if ((units -= 3) > -1) bytes.push(0xEF, 0xBF, 0xBD)
	    }

	    leadSurrogate = null

	    // encode utf8
	    if (codePoint < 0x80) {
	      if ((units -= 1) < 0) break
	      bytes.push(codePoint)
	    } else if (codePoint < 0x800) {
	      if ((units -= 2) < 0) break
	      bytes.push(
	        codePoint >> 0x6 | 0xC0,
	        codePoint & 0x3F | 0x80
	      )
	    } else if (codePoint < 0x10000) {
	      if ((units -= 3) < 0) break
	      bytes.push(
	        codePoint >> 0xC | 0xE0,
	        codePoint >> 0x6 & 0x3F | 0x80,
	        codePoint & 0x3F | 0x80
	      )
	    } else if (codePoint < 0x110000) {
	      if ((units -= 4) < 0) break
	      bytes.push(
	        codePoint >> 0x12 | 0xF0,
	        codePoint >> 0xC & 0x3F | 0x80,
	        codePoint >> 0x6 & 0x3F | 0x80,
	        codePoint & 0x3F | 0x80
	      )
	    } else {
	      throw new Error('Invalid code point')
	    }
	  }

	  return bytes
	}

	function asciiToBytes (str) {
	  var byteArray = []
	  for (var i = 0; i < str.length; i++) {
	    // Node's code seems to be doing this and not & 0x7F..
	    byteArray.push(str.charCodeAt(i) & 0xFF)
	  }
	  return byteArray
	}

	function utf16leToBytes (str, units) {
	  var c, hi, lo
	  var byteArray = []
	  for (var i = 0; i < str.length; i++) {
	    if ((units -= 2) < 0) break

	    c = str.charCodeAt(i)
	    hi = c >> 8
	    lo = c % 256
	    byteArray.push(lo)
	    byteArray.push(hi)
	  }

	  return byteArray
	}

	function base64ToBytes (str) {
	  return base64.toByteArray(base64clean(str))
	}

	function blitBuffer (src, dst, offset, length) {
	  for (var i = 0; i < length; i++) {
	    if ((i + offset >= dst.length) || (i >= src.length)) break
	    dst[i + offset] = src[i]
	  }
	  return i
	}
	
	/* WEBPACK VAR INJECTION */}.call(exports, __webpack_require__(2).Buffer, (function() { return this; }())))

/***/ },
/* 3 */
/***/ function(module, exports, __webpack_require__) {

	exports.read = function (buffer, offset, isLE, mLen, nBytes) {
	  var e, m
	  var eLen = nBytes * 8 - mLen - 1
	  var eMax = (1 << eLen) - 1
	  var eBias = eMax >> 1
	  var nBits = -7
	  var i = isLE ? (nBytes - 1) : 0
	  var d = isLE ? -1 : 1
	  var s = buffer[offset + i]

	  i += d

	  e = s & ((1 << (-nBits)) - 1)
	  s >>= (-nBits)
	  nBits += eLen
	  for (; nBits > 0; e = e * 256 + buffer[offset + i], i += d, nBits -= 8) {}

	  m = e & ((1 << (-nBits)) - 1)
	  e >>= (-nBits)
	  nBits += mLen
	  for (; nBits > 0; m = m * 256 + buffer[offset + i], i += d, nBits -= 8) {}

	  if (e === 0) {
	    e = 1 - eBias
	  } else if (e === eMax) {
	    return m ? NaN : ((s ? -1 : 1) * Infinity)
	  } else {
	    m = m + Math.pow(2, mLen)
	    e = e - eBias
	  }
	  return (s ? -1 : 1) * m * Math.pow(2, e - mLen)
	}

	exports.write = function (buffer, value, offset, isLE, mLen, nBytes) {
	  var e, m, c
	  var eLen = nBytes * 8 - mLen - 1
	  var eMax = (1 << eLen) - 1
	  var eBias = eMax >> 1
	  var rt = (mLen === 23 ? Math.pow(2, -24) - Math.pow(2, -77) : 0)
	  var i = isLE ? 0 : (nBytes - 1)
	  var d = isLE ? 1 : -1
	  var s = value < 0 || (value === 0 && 1 / value < 0) ? 1 : 0

	  value = Math.abs(value)

	  if (isNaN(value) || value === Infinity) {
	    m = isNaN(value) ? 1 : 0
	    e = eMax
	  } else {
	    e = Math.floor(Math.log(value) / Math.LN2)
	    if (value * (c = Math.pow(2, -e)) < 1) {
	      e--
	      c *= 2
	    }
	    if (e + eBias >= 1) {
	      value += rt / c
	    } else {
	      value += rt * Math.pow(2, 1 - eBias)
	    }
	    if (value * c >= 2) {
	      e++
	      c /= 2
	    }

	    if (e + eBias >= eMax) {
	      m = 0
	      e = eMax
	    } else if (e + eBias >= 1) {
	      m = (value * c - 1) * Math.pow(2, mLen)
	      e = e + eBias
	    } else {
	      m = value * Math.pow(2, eBias - 1) * Math.pow(2, mLen)
	      e = 0
	    }
	  }

	  for (; mLen >= 8; buffer[offset + i] = m & 0xff, i += d, m /= 256, mLen -= 8) {}

	  e = (e << mLen) | m
	  eLen += mLen
	  for (; eLen > 0; buffer[offset + i] = e & 0xff, i += d, e /= 256, eLen -= 8) {}

	  buffer[offset + i - d] |= s * 128
	}


/***/ },
/* 4 */
/***/ function(module, exports, __webpack_require__) {

	var toString = {}.toString;

	module.exports = Array.isArray || function (arr) {
	  return toString.call(arr) == '[object Array]';
	};


/***/ },
/* 5 */
/***/ function(module, exports, __webpack_require__) {

	var lookup = 'ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/';

	;(function (exports) {
		'use strict';

	  var Arr = (typeof Uint8Array !== 'undefined')
	    ? Uint8Array
	    : Array

		var PLUS   = '+'.charCodeAt(0)
		var SLASH  = '/'.charCodeAt(0)
		var NUMBER = '0'.charCodeAt(0)
		var LOWER  = 'a'.charCodeAt(0)
		var UPPER  = 'A'.charCodeAt(0)
		var PLUS_URL_SAFE = '-'.charCodeAt(0)
		var SLASH_URL_SAFE = '_'.charCodeAt(0)

		function decode (elt) {
			var code = elt.charCodeAt(0)
			if (code === PLUS ||
			    code === PLUS_URL_SAFE)
				return 62 // '+'
			if (code === SLASH ||
			    code === SLASH_URL_SAFE)
				return 63 // '/'
			if (code < NUMBER)
				return -1 //no match
			if (code < NUMBER + 10)
				return code - NUMBER + 26 + 26
			if (code < UPPER + 26)
				return code - UPPER
			if (code < LOWER + 26)
				return code - LOWER + 26
		}

		function b64ToByteArray (b64) {
			var i, j, l, tmp, placeHolders, arr

			if (b64.length % 4 > 0) {
				throw new Error('Invalid string. Length must be a multiple of 4')
			}

			// the number of equal signs (place holders)
			// if there are two placeholders, than the two characters before it
			// represent one byte
			// if there is only one, then the three characters before it represent 2 bytes
			// this is just a cheap hack to not do indexOf twice
			var len = b64.length
			placeHolders = '=' === b64.charAt(len - 2) ? 2 : '=' === b64.charAt(len - 1) ? 1 : 0

			// base64 is 4/3 + up to two characters of the original data
			arr = new Arr(b64.length * 3 / 4 - placeHolders)

			// if there are placeholders, only get up to the last complete 4 chars
			l = placeHolders > 0 ? b64.length - 4 : b64.length

			var L = 0

			function push (v) {
				arr[L++] = v
			}

			for (i = 0, j = 0; i < l; i += 4, j += 3) {
				tmp = (decode(b64.charAt(i)) << 18) | (decode(b64.charAt(i + 1)) << 12) | (decode(b64.charAt(i + 2)) << 6) | decode(b64.charAt(i + 3))
				push((tmp & 0xFF0000) >> 16)
				push((tmp & 0xFF00) >> 8)
				push(tmp & 0xFF)
			}

			if (placeHolders === 2) {
				tmp = (decode(b64.charAt(i)) << 2) | (decode(b64.charAt(i + 1)) >> 4)
				push(tmp & 0xFF)
			} else if (placeHolders === 1) {
				tmp = (decode(b64.charAt(i)) << 10) | (decode(b64.charAt(i + 1)) << 4) | (decode(b64.charAt(i + 2)) >> 2)
				push((tmp >> 8) & 0xFF)
				push(tmp & 0xFF)
			}

			return arr
		}

		function uint8ToBase64 (uint8) {
			var i,
				extraBytes = uint8.length % 3, // if we have 1 byte left, pad 2 bytes
				output = "",
				temp, length

			function encode (num) {
				return lookup.charAt(num)
			}

			function tripletToBase64 (num) {
				return encode(num >> 18 & 0x3F) + encode(num >> 12 & 0x3F) + encode(num >> 6 & 0x3F) + encode(num & 0x3F)
			}

			// go through the array every three bytes, we'll deal with trailing stuff later
			for (i = 0, length = uint8.length - extraBytes; i < length; i += 3) {
				temp = (uint8[i] << 16) + (uint8[i + 1] << 8) + (uint8[i + 2])
				output += tripletToBase64(temp)
			}

			// pad the end with zeros, but make sure to not forget the extra bytes
			switch (extraBytes) {
				case 1:
					temp = uint8[uint8.length - 1]
					output += encode(temp >> 2)
					output += encode((temp << 4) & 0x3F)
					output += '=='
					break
				case 2:
					temp = (uint8[uint8.length - 2] << 8) + (uint8[uint8.length - 1])
					output += encode(temp >> 10)
					output += encode((temp >> 4) & 0x3F)
					output += encode((temp << 2) & 0x3F)
					output += '='
					break
			}

			return output
		}

		exports.toByteArray = b64ToByteArray
		exports.fromByteArray = uint8ToBase64
	}(typeof exports === 'undefined' ? (this.base64js = {}) : exports))


/***/ }
/******/ ])
});

!function(e,t){"object"==typeof exports&&"object"==typeof module?module.exports=t(require("RAML.XmlValidation"),require("typescript"),function(){try{return require("RAML.JsonValidation")}catch(e){}}()):"function"==typeof define&&define.amd?define(["RAML.XmlValidation","typescript","RAML.JsonValidation"],t):"object"==typeof exports?exports.Parser=t(require("RAML.XmlValidation"),require("typescript"),function(){try{return require("RAML.JsonValidation")}catch(e){}}()):(e.RAML=e.RAML||{},e.RAML.Parser=t(e["RAML.XmlValidation"],e.typescript,e["RAML.JsonValidation"]))}(this,function(__WEBPACK_EXTERNAL_MODULE_139__,__WEBPACK_EXTERNAL_MODULE_156__,__WEBPACK_EXTERNAL_MODULE_176__){return function(e){function t(r){if(n[r])return n[r].exports;var i=n[r]={exports:{},id:r,loaded:!1};return e[r].call(i.exports,i,i.exports,t),i.loaded=!0,i.exports}var n={};return t.m=e,t.c=n,t.p="",t(0)}([function(e,t,n){"use strict";function r(e,t,n){return m.loadApi(e,t,n).getOrElse(null)}function i(e,t,n){return m.loadApi(e,t,n).getOrElse(null)}function a(e,t,n){return{fsResolver:{content:function(r){return r===(n||d.resolve("/","#local.raml")).replace(/\\/,"/")?e:t&&t.fsResolver?t.fsResolver.content(r):void 0},contentAsync:function(r){return r===(n||d.resolve("/","#local.raml")).replace(/\\/,"/")?Promise.resolve(e):t&&t.fsResolver?t.fsResolver.contentAsync(r):void 0}},httpResolver:t?t.httpResolver:null,rejectOnErrors:t?t.rejectOnErrors:!1,attributeDefaults:t?t.attributeDefaults:!0}}function o(e,t){var n=null;return t&&t.filePath&&(n=t.filePath),m.loadApi(n||"/#local.raml",[],a(e,t,n)).getOrElse(null)}function s(e,t){var n=null;return t&&t.filePath&&(n=t.filePath),m.loadApiAsync(n||"/#local.raml",[],a(e,t,n))}function u(e,t,n){return m.loadApiAsync(e,t,n)}function l(e,t,n){return m.loadRAMLAsync(e,t,n)}function p(e){return m.getLanguageElementByRuntimeType(e)}function c(e){return t.api10.isFragment(e)}function f(e){return t.api10.asFragment(e)}var m=n(8),d=n(15),h=n(21);t.api10=n(11),t.api08=n(12),t.loadApiSync=r,t.loadRAMLSync=i,t.parseRAMLSync=o,t.parseRAML=s,t.loadApi=u,t.loadRAML=l,t.getLanguageElementByRuntimeType=p,t.isFragment=c,t.asFragment=f,t.hl=n(9),t.ll=n(10),t.search=n(13),t.stubs=n(1),t.utils=n(2),t.project=n(3),t.universeHelpers=n(14),t.ds=n(37),t.schema=n(4),t.universes=t.ds.universesInfo,t.parser=n(5),t.expander=n(6),t.wrapperHelper=n(7),"undefined"==typeof Promise&&"undefined"!=typeof window&&(window.Promise=h)},function(e,t,n){"use strict";function r(e,t,n,r){return void 0===n&&(n=null),E.createStubNode(e,t,n,r)}function i(e,t,n){return E.createStub(e,t,n)}function a(e,t,n){return E.createStub0(e,t,n)}function o(e,t){return E.createResourceStub(e,t)}function s(e,t){return E.createMethodStub(e,t)}function u(e,t){return E.createResponseStub(e,t)}function l(e,t){return E.createBodyStub(e,t)}function p(e,t){return E.createUriParameterStub(e,t)}function c(e,t){return E.createQueryParameterStub(e,t)}function f(e,t,n,r,i){return void 0===i&&(i=!1),new S.ASTPropImpl(e,t,n,r,i)}function m(e,t,n,r){return new S.ASTNodeImpl(e,t,n,r)}function d(e,t,n,r){return new b(e,t,n,r)}function h(e,t,n,r){return new N(e,t,n,r)}function y(e,t){return T.createMapping(e,t)}function v(){return T.createMap([])}function g(e,t){return E.createAttr(e,t)}var A=this&&this.__extends||function(e,t){function n(){this.constructor=e}for(var r in t)t.hasOwnProperty(r)&&(e[r]=t[r]);e.prototype=null===t?Object.create(t):(n.prototype=t.prototype,new n)},S=n(16),T=n(26),E=n(19);t.createStubNode=r,t.createStub=i,t.createStubNoParentPatch=a,t.createResourceStub=o,t.createMethodStub=s,t.createResponseStub=u,t.createBodyStub=l,t.createUriParameterStub=p,t.createQueryParameterStub=c,t.createASTPropImpl=f,t.createASTNodeImpl=m,t.createVirtualASTPropImpl=d,t.createVirtualNodeImpl=h;var b=function(e){function t(){e.apply(this,arguments)}return A(t,e),t.prototype.value=function(){return""},t}(S.ASTPropImpl),N=function(e){function t(){e.apply(this,arguments)}return A(t,e),t.prototype.value=function(){return""},t}(S.ASTNodeImpl);t.createMapping=y,t.createMap=v,t.createAttr=g},function(e,t,n){"use strict";function r(){return l.hasAsyncRequests()}function i(e){l.addLoadCallback(e)}function a(){return m.getTransformNames()}function o(e){return p.getFragmentDefenitionName(e)}function s(e,t,n){if(c.ReferenceType.isInstance(n.range())){var r=(n.range(),f.createNode(e));return new p.StructuredValue(r,t,n)}return e}function u(e){return(new d.UrlParameterNameValidator).parseUrl(e)}var l=n(27),p=n(16),c=n(37),f=n(26),m=n(29),d=n(30),h=n(31),y=n(17);t.hasAsyncRequests=r,t.addLoadCallback=i,t.getTransformerNames=a,t.updateType=function(e){var t=h.doDescrimination(e);null==t&&e.property()&&(t=e.property().range()),t&&e.patchType(t)},t.getFragmentDefenitionName=o,t.genStructuredValue=s,t.parseUrl=u;var v=function(){function e(e,t){this.node=e,this.targetUnitRoot=t}return e}();t.UnitLink=v;var g=function(){function e(e,t){this.errors=e,this.primaryUnitRoot=t}return e.prototype.accept=function(e){this.transformIssue(e),this.errors.push(e)},e.prototype.transformIssue=function(e){var t=this,n=null,r=this.findIssueTail(e);r.node&&(n=r.node.lowLevel().unit());var i=this.primaryUnitRoot.lowLevel().unit();if(n&&i&&n!=i){var a=this.findPathToNodeUnit(this.primaryUnitRoot,r.node);if(a&&a.length>0){var o=a.map(function(n){return t.convertConnectingNodeToError(n,e)});if(o&&o.length>0)for(var s=r,u=o.length-1;u>=0;u--){var l=o[u];s.extras=[],s.extras.push(l),s=l}}}},e.prototype.begin=function(){},e.prototype.end=function(){},e.prototype.acceptUnique=function(e){for(var t=0,n=this.errors;t<n.length;t++){var r=n[t];if(r.start==e.start&&r.message==e.message)return}this.accept(e)},e.prototype.findPathToNodeUnit=function(e,t){return t.lowLevel()&&t.lowLevel().unit()?this.findPathToNodeUnitRecursively(e,t.lowLevel().unit()):[]},e.prototype.findPathToNodeUnitRecursively=function(e,t){for(var n=this.findUnitLinks(e),r=0;r<n.length;r++){var i=n[r];if(i.targetUnitRoot&&i.targetUnitRoot.lowLevel()&&i.targetUnitRoot.lowLevel().unit()==t)return[i.node];var a=this.findPathToNodeUnitRecursively(i.targetUnitRoot,t);if(a)return a.unshift(i.node),a}return null},e.prototype.findUnitLinks=function(e){var t=[];return t=t.concat(this.findMasterLinks(e))},e.prototype.findMasterLinks=function(e){if(!e.getMaster)return[];var t=e.getMaster();if(!t)return[];var n=e.asElement().attr(y.Universe10.Extension.properties["extends"].name);return n&&n.value()?[new v(n,t)]:[]},e.prototype.convertConnectingNodeToError=function(e,t){if(!e)return null;var n=e.lowLevel(),r=n.start(),i=n.end(),a=this.generateLinkMessageByNode(e,t);return{code:t.code,isWarning:t.isWarning,message:a,node:e,start:r,end:i,path:n.unit()?n.unit().path():"",extras:[],unit:n.unit()}},e.prototype.generateLinkMessageByNode=function(e,t){return e.property().nameId()==y.Universe10.Extension.properties["extends"].name?"Error in the master file: "+t.message:t.message},e.prototype.findIssueTail=function(e){return e.extras&&0!=e.extras.length?this.findIssueTail(e.extras[0]):e},e}();t.PointOfViewValidationAcceptorImpl=g},function(e,t,n){"use strict";function r(e,t,n){return new i.Project(e,t,n)}var i=n(26);t.createProject=r},function(e,t,n){"use strict";function r(e,t){var n=n.createProject(h.dirname(e)),r={$ref:t},i=JSON.stringify(r),a=n.setCachedUnitContent(h.basename(e),i),s=o(i,a);return s.jsonSchema.$ref}function i(e,t){return v.createSchema(e,new y.ContentProvider(t))}function a(e){return v.getXMLSchema(e)}function o(e,t){return v.getJSONSchema(e,new y.ContentProvider(t))}function s(e,t,n){return m.completeReference(e,t,n)}function u(e){return m.getIncludePath(e)}function l(e){return m.getIncludeReference(e)}function p(){return new d.SchemaToModelGenerator}function c(){return new d.ModelToSchemaGenerator}var f=n(37),m=n(28),d=n(18),h=n(15),y=n(32),v=f.getSchemaUtils();t.dereference=r,t.createSchema=i,t.getXMLSchema=a,t.getJSONSchema=o,t.completeReference=s,t.getIncludePath=u,t.getIncludeReference=l,t.createSchemaModelGenerator=p,t.createModelToSchemaGenerator=c},function(e,t,n){"use strict";t.modify=n(20)},function(e,t,n){"use strict";function r(e){return i.expandTraitsAndResourceTypes(e)}var i=n(29);t.expandTraitsAndResourceTypes=r},function(e,t,n){"use strict";function r(e){return i.completeRelativeUri(e)}var i=n(34);t.completeRelativeUri=r},function(e,t,n){"use strict";function r(e,t,n){var r=a(e,t,n);return new y(r)}function i(e,t,n){var r=a(e,t,n);return new y(r)}function a(e,t,n){var r=Array.isArray(t),i=r?t:null,a=r?n:t;a=a||{};var o=p(e,a),s=e.indexOf("://"),u=-1!=s&&6>s?e:h.basename(e),l=o.unit(u);n&&!i&&(i=null);var m;if(l)if(i&&i.length>0){var d=[];i.forEach(function(e){if(!e||0==e.trim().length)throw new Error("Extensions and overlays list should contain legal file paths")}),i.forEach(function(e){d.push(o.unit(e,h.isAbsolute(e)))}),d.forEach(function(e){return c(e,a)}),m=c(S.mergeAPIs(l,d,g.OverlayMergeMode.MERGE),a)}else m=c(l,a),m.highLevel().setMergeMode(g.OverlayMergeMode.MERGE);if(!l)throw new Error("Can not resolve :"+e);if(a.rejectOnErrors&&m&&m.errors().filter(function(e){return!e.isWarning}).length)throw f(m);return null!=a.attributeDefaults&&m?m.setAttributeDefaults(a.attributeDefaults):m&&m.setAttributeDefaults(!0),m}function o(e,t,n){var r=s(e,t,n);return r.then(function(e){return e})}function s(e,t,n){var r=Array.isArray(t),i=r?t:null,a=r?n:t;a=a||{};var o=p(e,a),s=e.indexOf("://"),u=-1!=s&&6>s?e:h.basename(e);return n&&!i&&(i=null),i&&0!=i.length?(i.forEach(function(e){if(!e||0==e.trim().length)throw new Error("Extensions and overlays list should contain legal file paths")}),l(o,u,a).then(function(e){var t=[];return i.forEach(function(e){t.push(l(o,e,a))}),Promise.all(t).then(function(t){var n=[];t.forEach(function(e){return n.push(e.highLevel().lowLevel().unit())});var r=S.mergeAPIs(e.highLevel().lowLevel().unit(),n,g.OverlayMergeMode.MERGE),i=r.wrapperNode();return null!=a.attributeDefaults&&r?i.setAttributeDefaults(a.attributeDefaults):r&&i.setAttributeDefaults(!0),i.highLevel()}).then(function(e){return c(e,a)})})):l(o,u,a).then(function(e){return e.highLevel().setMergeMode(g.OverlayMergeMode.MERGE),null!=a.attributeDefaults&&e?e.setAttributeDefaults(a.attributeDefaults):e&&e.setAttributeDefaults(!0),e})}function u(e){if(null==e)return null;var t=e.getAdapter(E.RAMLService).getDeclaringNode();return null==t?null:t.wrapperNode()}function l(e,t,n){return A.fetchIncludesAndMasterAsync(e,t).then(function(e){try{var t=c(e,n);return n.rejectOnErrors&&t&&t.errors().filter(function(e){return!e.isWarning}).length?Promise.reject(f(t)):t}catch(r){return Promise.reject(r)}})}function p(e,t){t=t||{};var n=t.fsResolver,r=t.httpResolver,i=h.dirname(e),a=new v.Project(i,n,r);return a}function c(e,t,n){if(void 0===n&&(n=!1),!e)return null;var r=null,i=null;e.isRAMLUnit?r=e:(i=e,r=i.lowLevel().unit());var a,o=r.contents(),s=g.ramlFirstLine(o);if(!s)throw new Error("Invalid first line. A RAML document is expected to start with '#%RAML <version> <?fragment type>'.");var u,l,p=s[1];s[2];if("0.8"==p?l="RAML08":"1.0"==p&&(l="RAML10"),!l)throw new Error("Unknown version of RAML expected to see one of '#%RAML 0.8' or '#%RAML 1.0'");if("RAML08"==l&&n)throw new Error("Extensions and overlays are not supported in RAML 0.8.");var c=b(l);c.type(u);return i||(i=g.fromUnit(r)),a=i.wrapperNode()}function f(e){var t=new Error("Api contains errors.");return t.parserErrors=e.errors(),t}function m(e,t,n){void 0===t&&(t=!1),void 0===n&&(n=!0);var r=b("RAML10"),i=r.type(T.Universe10.Api.name),a=new v.Project(e),o=[];return a.units().forEach(function(e){var r=e.ast();t&&(r=A.toChildCachingNode(r));var a=new d.ApiImpl(new g.ASTNodeImpl(r,null,i,null));n&&(a=S.expandTraitsAndResourceTypes(a)),o.push(a)}),o}var d=n(22),h=n(15),y=n(23),v=n(26),g=n(16),A=n(26),S=n(29),T=n(17),E=n(35),b=n(36);t.loadApi=r,t.loadRAML=i,t.loadApiAsync=o,t.loadRAMLAsync=s,t.getLanguageElementByRuntimeType=u,t.toError=f,t.loadApis1=m},function(e,t,n){(function(e){"use strict";function n(e){return e.asElement&&e.getKind&&e.asAttr&&e.lowLevel}function r(){var t=e.ramlValidation;if(t){var n=t.nodeValidators;if(Array.isArray(n))return n}return[]}function i(){var t=e.ramlValidation;if(t){var n=t.astAnnotationValidators;if(Array.isArray(n))return n}return[]}!function(e){e[e.BASIC=0]="BASIC",e[e.NODE=1]="NODE",e[e.ATTRIBUTE=2]="ATTRIBUTE"}(t.NodeKind||(t.NodeKind={}));t.NodeKind;!function(e){e[e.RAML10=0]="RAML10",e[e.RAML08=1]="RAML08"}(t.RAMLVersion||(t.RAMLVersion={}));t.RAMLVersion;t.isParseResult=n,function(e){e[e.UNRESOLVED_REFERENCE=0]="UNRESOLVED_REFERENCE",e[e.YAML_ERROR=1]="YAML_ERROR",e[e.UNKNOWN_NODE=2]="UNKNOWN_NODE",e[e.MISSING_REQUIRED_PROPERTY=3]="MISSING_REQUIRED_PROPERTY",e[e.PROPERTY_EXPECT_TO_HAVE_SINGLE_VALUE=4]="PROPERTY_EXPECT_TO_HAVE_SINGLE_VALUE",e[e.KEY_SHOULD_BE_UNIQUE_INTHISCONTEXT=5]="KEY_SHOULD_BE_UNIQUE_INTHISCONTEXT",e[e.UNABLE_TO_RESOLVE_INCLUDE_FILE=6]="UNABLE_TO_RESOLVE_INCLUDE_FILE",e[e.INVALID_VALUE_SCHEMA=7]="INVALID_VALUE_SCHEMA",e[e.MISSED_CONTEXT_REQUIREMENT=8]="MISSED_CONTEXT_REQUIREMENT",e[e.NODE_HAS_VALUE=9]="NODE_HAS_VALUE",e[e.ONLY_OVERRIDE_ALLOWED=10]="ONLY_OVERRIDE_ALLOWED",e[e.ILLEGAL_PROPERTY_VALUE=11]="ILLEGAL_PROPERTY_VALUE",e[e.ILLEGAL_PROPERTY=12]="ILLEGAL_PROPERTY",e[e.INVALID_PROPERTY=13]="INVALID_PROPERTY"}(t.IssueCode||(t.IssueCode={}));t.IssueCode;t.getNodeValidationPlugins=r,t.getNodeAnnotationValidationPlugins=i}).call(t,function(){return this}())},function(e,t,n){"use strict";function r(e,t){return new S(v.CHANGE_VALUE,e,t,-1)}function i(e,t){return new S(v.CHANGE_VALUE,e,t.lowLevel(),-1)}function a(e,t){return new S(v.CHANGE_KEY,e,t,-1)}function o(e,t){return new S(v.REMOVE_CHILD,e,t,-1)}function s(e,t,n,r){void 0===n&&(n=null),void 0===r&&(r=!1);var i=new S(v.ADD_CHILD,e,t,-1);return i.insertionPoint=n,i.toSeq=r,i}function u(e,t){return new S(v.INIT_RAML_FILE,e,t,-1)}function l(e,t,n){if(m.isAbsolute(e)){var r=m.extname(t);".xsd"!=r&&(e=e.substr(1),t=p(n,m.basename(t)))}return c(e)||m.isAbsolute(e)?e:c(t)||m.isAbsolute(t)?p(m.dirname(t),e):p(m.dirname(p(n,t)),e)}function p(e,t){if(c(t))return t;var n;if(c(e)){var r=h.stringEndsWith(e,"/")?e:e+"/";n=d.resolve(r,t).replace(/\\/g,"/")}else n=m.resolve(e,t).replace(/\\/g,"/");return n}function c(e){return null==e?!1:h.stringStartsWith(e,"http://")||h.stringStartsWith(e,"https://")}function f(e){return e.start&&e.end&&e.unit&&e.key&&e.value&&e.children&&e.includePath}var m=n(15),d=n(38),h=n(33),y=function(){function e(){}return e}();t.ASTDelta=y,function(e){e[e.ADD_CHILD=0]="ADD_CHILD",e[e.REMOVE_CHILD=1]="REMOVE_CHILD",e[e.MOVE_CHILD=2]="MOVE_CHILD",e[e.CHANGE_KEY=3]="CHANGE_KEY",e[e.CHANGE_VALUE=4]="CHANGE_VALUE",e[e.INIT_RAML_FILE=5]="INIT_RAML_FILE"}(t.CommandKind||(t.CommandKind={}));var v=t.CommandKind,g=function(){function e(e,t,n,r,i){void 0===i&&(i=null),this.offset=e,this.replacementLength=t,this.text=n,this.unit=r,this.target=i}return e}();t.TextChangeCommand=g;var A=function(){function e(){this.commands=[]}return e}();t.CompositeCommand=A,function(e){e[e.NONE=0]="NONE",e[e.START=1]="START",e[e.END=2]="END",e[e.POINT=3]="POINT"}(t.InsertionPointType||(t.InsertionPointType={}));var S=(t.InsertionPointType,function(){function e(e,t,n,r){this.toSeq=!1,this.kind=e,this.target=t,this.value=n,this.position=r}return e}());t.ASTChangeCommand=S,t.setAttr=r,t.setAttrStructured=i,t.setKey=a,t.removeNode=o,t.insertNode=s,t.initRamlFile=u;var T=function(){function e(e,t){this.content=e,this.absPath=t}return e.prototype.position=function(e){var t=e;this.initMapping();for(var n=0;n<this.mapping.length;n++){var r=this.mapping[n];if(r>t)return{line:n,column:t,position:e};t-=r}if(0==t)return{line:this.mapping.length-1,column:this.mapping[this.mapping.length-1],position:this.content.length};if(1==t)return{line:this.mapping.length-1,column:this.mapping[this.mapping.length-1]-1,position:e-1};throw new Error("Character position exceeds text length: "+e+" > + "+this.content.length+".\nUnit path: "+this.absPath)},e.prototype.initMapping=function(){if(null==this.mapping){if(null==this.content)throw new Error("Line Mapper has been given null content"+(null!=this.absPath?". Path: "+this.absPath:" and null path."));this.mapping=[];for(var e=0,t=this.content.length,n=0;t>n;n++)"\r"==this.content.charAt(n)?t-1>n&&"\n"==this.content.charAt(n+1)?(this.mapping.push(n-e+2),e=n+2,n++):(this.mapping.push(n-e+1),e=n+1):"\n"==this.content.charAt(n)&&(this.mapping.push(n-e+1),e=n+1);this.mapping.push(t-e)}},e}();t.LineMapperImpl=T,t.buildPath=l,t.toAbsolutePath=p,t.isWebPath=c,t.isLowLevelNode=f},function(e,t,n){"use strict";function r(e){return"Api"==e.kind()&&"RAML10"==e.RAMLVersion()}function i(e){return"LibraryBase"==e.kind()&&"RAML10"==e.RAMLVersion()}function a(e){return"Annotable"==e.kind()&&"RAML10"==e.RAMLVersion()}function o(e){return"AnnotationRef"==e.kind()&&"RAML10"==e.RAMLVersion()}function s(e){return"Reference"==e.kind()&&"RAML10"==e.RAMLVersion()}function u(e){return"ValueType"==e.kind()&&"RAML10"==e.RAMLVersion()}function l(e){return"StringType"==e.kind()&&"RAML10"==e.RAMLVersion()}function p(e){return"UriTemplate"==e.kind()&&"RAML10"==e.RAMLVersion()}function c(e){return"RelativeUriString"==e.kind()&&"RAML10"==e.RAMLVersion()}function f(e){return"FullUriTemplateString"==e.kind()&&"RAML10"==e.RAMLVersion()}function m(e){return"StatusCodeString"==e.kind()&&"RAML10"==e.RAMLVersion()}function d(e){return"FixedUriString"==e.kind()&&"RAML10"==e.RAMLVersion()}function h(e){return"ContentType"==e.kind()&&"RAML10"==e.RAMLVersion()}function y(e){return"MarkdownString"==e.kind()&&"RAML10"==e.RAMLVersion()}function v(e){return"SchemaString"==e.kind()&&"RAML10"==e.RAMLVersion()}function g(e){return"MimeType"==e.kind()&&"RAML10"==e.RAMLVersion()}function A(e){return"AnyType"==e.kind()&&"RAML10"==e.RAMLVersion()}function S(e){return"NumberType"==e.kind()&&"RAML10"==e.RAMLVersion()}function T(e){return"IntegerType"==e.kind()&&"RAML10"==e.RAMLVersion()}function E(e){return"NullType"==e.kind()&&"RAML10"==e.RAMLVersion()}function b(e){return"TimeOnlyType"==e.kind()&&"RAML10"==e.RAMLVersion()}function N(e){return"DateOnlyType"==e.kind()&&"RAML10"==e.RAMLVersion()}function _(e){return"DateTimeOnlyType"==e.kind()&&"RAML10"==e.RAMLVersion()}function M(e){return"DateTimeType"==e.kind()&&"RAML10"==e.RAMLVersion()}function w(e){return"FileType"==e.kind()&&"RAML10"==e.RAMLVersion()}function R(e){return"BooleanType"==e.kind()&&"RAML10"==e.RAMLVersion()}function I(e){return"AnnotationTarget"==e.kind()&&"RAML10"==e.RAMLVersion()}function C(e){return"TraitRef"==e.kind()&&"RAML10"==e.RAMLVersion()}function L(e){return"Trait"==e.kind()&&"RAML10"==e.RAMLVersion()}function P(e){return"MethodBase"==e.kind()&&"RAML10"==e.RAMLVersion()}function O(e){return"Operation"==e.kind()&&"RAML10"==e.RAMLVersion()}function D(e){return"TypeDeclaration"==e.kind()&&"RAML10"==e.RAMLVersion()}function x(e){return"ModelLocation"==e.kind()&&"RAML10"==e.RAMLVersion()}function U(e){return"LocationKind"==e.kind()&&"RAML10"==e.RAMLVersion()}function k(e){return"ExampleSpec"==e.kind()&&"RAML10"==e.RAMLVersion()}function F(e){return"UsesDeclaration"==e.kind()&&"RAML10"==e.RAMLVersion()}function B(e){return"XMLFacetInfo"==e.kind()&&"RAML10"==e.RAMLVersion()}function K(e){return"ArrayTypeDeclaration"==e.kind()&&"RAML10"==e.RAMLVersion()}function V(e){return"UnionTypeDeclaration"==e.kind()&&"RAML10"==e.RAMLVersion()}function j(e){return"ObjectTypeDeclaration"==e.kind()&&"RAML10"==e.RAMLVersion()}function W(e){return"StringTypeDeclaration"==e.kind()&&"RAML10"==e.RAMLVersion()}function q(e){return"BooleanTypeDeclaration"==e.kind()&&"RAML10"==e.RAMLVersion()}function Y(e){return"NumberTypeDeclaration"==e.kind()&&"RAML10"==e.RAMLVersion()}function H(e){return"IntegerTypeDeclaration"==e.kind()&&"RAML10"==e.RAMLVersion()}function $(e){return"DateOnlyTypeDeclaration"==e.kind()&&"RAML10"==e.RAMLVersion()}function G(e){return"TimeOnlyTypeDeclaration"==e.kind()&&"RAML10"==e.RAMLVersion()}function X(e){return"DateTimeOnlyTypeDeclaration"==e.kind()&&"RAML10"==e.RAMLVersion()}function z(e){return"DateTimeTypeDeclaration"==e.kind()&&"RAML10"==e.RAMLVersion()}function J(e){return"FileTypeDeclaration"==e.kind()&&"RAML10"==e.RAMLVersion()}function Q(e){return"Response"==e.kind()&&"RAML10"==e.RAMLVersion()}function Z(e){return"SecuritySchemePart"==e.kind()&&"RAML10"==e.RAMLVersion()}function ee(e){return"SecuritySchemeRef"==e.kind()&&"RAML10"==e.RAMLVersion()}function te(e){return"AbstractSecurityScheme"==e.kind()&&"RAML10"==e.RAMLVersion()}function ne(e){return"SecuritySchemeSettings"==e.kind()&&"RAML10"==e.RAMLVersion()}function re(e){return"OAuth1SecuritySchemeSettings"==e.kind()&&"RAML10"==e.RAMLVersion()}function ie(e){return"OAuth2SecuritySchemeSettings"==e.kind()&&"RAML10"==e.RAMLVersion()}function ae(e){return"OAuth2SecurityScheme"==e.kind()&&"RAML10"==e.RAMLVersion()}function oe(e){return"OAuth1SecurityScheme"==e.kind()&&"RAML10"==e.RAMLVersion()}function se(e){return"PassThroughSecurityScheme"==e.kind()&&"RAML10"==e.RAMLVersion()}function ue(e){return"BasicSecurityScheme"==e.kind()&&"RAML10"==e.RAMLVersion()}function le(e){return"DigestSecurityScheme"==e.kind()&&"RAML10"==e.RAMLVersion()}function pe(e){return"CustomSecurityScheme"==e.kind()&&"RAML10"==e.RAMLVersion()}function ce(e){return"Method"==e.kind()&&"RAML10"==e.RAMLVersion()}function fe(e){return"ResourceTypeRef"==e.kind()&&"RAML10"==e.RAMLVersion()}function me(e){return"ResourceType"==e.kind()&&"RAML10"==e.RAMLVersion()}function de(e){return"ResourceBase"==e.kind()&&"RAML10"==e.RAMLVersion()}function he(e){return"Resource"==e.kind()&&"RAML10"==e.RAMLVersion()}function ye(e){return"DocumentationItem"==e.kind()&&"RAML10"==e.RAMLVersion()}function ve(e){return"Library"==e.kind()&&"RAML10"==e.RAMLVersion()}function ge(e){return"Overlay"==e.kind()&&"RAML10"==e.RAMLVersion()}function Ae(e){return"Extension"==e.kind()&&"RAML10"==e.RAMLVersion()}function Se(e){return null==e.highLevel().parent()}function Te(e){return Se(e)?e:null}t.isApi=r,t.isLibraryBase=i,t.isAnnotable=a,t.isAnnotationRef=o,t.isReference=s,t.isValueType=u,t.isStringType=l,t.isUriTemplate=p,t.isRelativeUriString=c,t.isFullUriTemplateString=f,t.isStatusCodeString=m,t.isFixedUriString=d,t.isContentType=h,t.isMarkdownString=y,t.isSchemaString=v,t.isMimeType=g,t.isAnyType=A,t.isNumberType=S,t.isIntegerType=T,t.isNullType=E,t.isTimeOnlyType=b,t.isDateOnlyType=N,t.isDateTimeOnlyType=_,t.isDateTimeType=M,t.isFileType=w,t.isBooleanType=R,t.isAnnotationTarget=I,t.isTraitRef=C,t.isTrait=L,t.isMethodBase=P,t.isOperation=O,t.isTypeDeclaration=D,t.isModelLocation=x,t.isLocationKind=U,t.isExampleSpec=k,t.isUsesDeclaration=F,t.isXMLFacetInfo=B,t.isArrayTypeDeclaration=K,t.isUnionTypeDeclaration=V,t.isObjectTypeDeclaration=j,t.isStringTypeDeclaration=W,t.isBooleanTypeDeclaration=q,t.isNumberTypeDeclaration=Y,t.isIntegerTypeDeclaration=H,t.isDateOnlyTypeDeclaration=$,t.isTimeOnlyTypeDeclaration=G,t.isDateTimeOnlyTypeDeclaration=X,t.isDateTimeTypeDeclaration=z,t.isFileTypeDeclaration=J,t.isResponse=Q,t.isSecuritySchemePart=Z,t.isSecuritySchemeRef=ee,t.isAbstractSecurityScheme=te,t.isSecuritySchemeSettings=ne,t.isOAuth1SecuritySchemeSettings=re,t.isOAuth2SecuritySchemeSettings=ie,t.isOAuth2SecurityScheme=ae,t.isOAuth1SecurityScheme=oe,t.isPassThroughSecurityScheme=se,t.isBasicSecurityScheme=ue,t.isDigestSecurityScheme=le,t.isCustomSecurityScheme=pe,t.isMethod=ce,t.isResourceTypeRef=fe,t.isResourceType=me,t.isResourceBase=de,t.isResource=he,t.isDocumentationItem=ye,t.isLibrary=ve,t.isOverlay=ge,t.isExtension=Ae,t.isFragment=Se,t.asFragment=Te},function(e,t,n){"use strict";function r(e){return"Api"==e.kind()&&"RAML08"==e.RAMLVersion()}function i(e){return"FullUriTemplateString"==e.kind()&&"RAML08"==e.RAMLVersion()}function a(e){return"UriTemplate"==e.kind()&&"RAML08"==e.RAMLVersion()}function o(e){return"StringType"==e.kind()&&"RAML08"==e.RAMLVersion()}function s(e){return"ValueType"==e.kind()&&"RAML08"==e.RAMLVersion()}function u(e){return"AnyType"==e.kind()&&"RAML08"==e.RAMLVersion()}function l(e){return"NumberType"==e.kind()&&"RAML08"==e.RAMLVersion()}function p(e){return"BooleanType"==e.kind()&&"RAML08"==e.RAMLVersion()}function c(e){return"Reference"==e.kind()&&"RAML08"==e.RAMLVersion()}function f(e){return"ResourceTypeRef"==e.kind()&&"RAML08"==e.RAMLVersion()}function m(e){return"ResourceType"==e.kind()&&"RAML08"==e.RAMLVersion()}function d(e){return"Method"==e.kind()&&"RAML08"==e.RAMLVersion()}function h(e){return"MethodBase"==e.kind()&&"RAML08"==e.RAMLVersion()}function y(e){return"Response"==e.kind()&&"RAML08"==e.RAMLVersion()}function v(e){return"StatusCodeString"==e.kind()&&"RAML08"==e.RAMLVersion()}function g(e){return"Parameter"==e.kind()&&"RAML08"==e.RAMLVersion()}function A(e){return"ParameterLocation"==e.kind()&&"RAML08"==e.RAMLVersion()}function S(e){return"MarkdownString"==e.kind()&&"RAML08"==e.RAMLVersion()}function T(e){return"StringTypeDeclaration"==e.kind()&&"RAML08"==e.RAMLVersion()}function E(e){return"BooleanTypeDeclaration"==e.kind()&&"RAML08"==e.RAMLVersion()}function b(e){return"NumberTypeDeclaration"==e.kind()&&"RAML08"==e.RAMLVersion()}function N(e){return"IntegerTypeDeclaration"==e.kind()&&"RAML08"==e.RAMLVersion()}function _(e){return"DateTypeDeclaration"==e.kind()&&"RAML08"==e.RAMLVersion()}function M(e){return"FileTypeDeclaration"==e.kind()&&"RAML08"==e.RAMLVersion()}function w(e){return"BodyLike"==e.kind()&&"RAML08"==e.RAMLVersion()}function R(e){return"SchemaString"==e.kind()&&"RAML08"==e.RAMLVersion()}function I(e){return"JSonSchemaString"==e.kind()&&"RAML08"==e.RAMLVersion()}function C(e){return"XMLSchemaString"==e.kind()&&"RAML08"==e.RAMLVersion()}function L(e){return"ExampleString"==e.kind()&&"RAML08"==e.RAMLVersion()}function P(e){return"JSONExample"==e.kind()&&"RAML08"==e.RAMLVersion()}function O(e){return"XMLExample"==e.kind()&&"RAML08"==e.RAMLVersion()}function D(e){return"XMLBody"==e.kind()&&"RAML08"==e.RAMLVersion()}function x(e){return"JSONBody"==e.kind()&&"RAML08"==e.RAMLVersion()}function U(e){return"SecuritySchemeRef"==e.kind()&&"RAML08"==e.RAMLVersion()}function k(e){return"AbstractSecurityScheme"==e.kind()&&"RAML08"==e.RAMLVersion()}function F(e){return"SecuritySchemePart"==e.kind()&&"RAML08"==e.RAMLVersion()}function B(e){return"TraitRef"==e.kind()&&"RAML08"==e.RAMLVersion()}function K(e){return"Trait"==e.kind()&&"RAML08"==e.RAMLVersion()}function V(e){return"SecuritySchemeSettings"==e.kind()&&"RAML08"==e.RAMLVersion()}function j(e){return"OAuth1SecuritySchemeSettings"==e.kind()&&"RAML08"==e.RAMLVersion()}function W(e){return"FixedUri"==e.kind()&&"RAML08"==e.RAMLVersion()}function q(e){return"OAuth2SecuritySchemeSettings"==e.kind()&&"RAML08"==e.RAMLVersion()}function Y(e){return"OAuth2SecurityScheme"==e.kind()&&"RAML08"==e.RAMLVersion()}function H(e){return"OAuth1SecurityScheme"==e.kind()&&"RAML08"==e.RAMLVersion()}function $(e){return"BasicSecurityScheme"==e.kind()&&"RAML08"==e.RAMLVersion()}function G(e){return"DigestSecurityScheme"==e.kind()&&"RAML08"==e.RAMLVersion()}function X(e){return"CustomSecurityScheme"==e.kind()&&"RAML08"==e.RAMLVersion()}function z(e){return"MimeType"==e.kind()&&"RAML08"==e.RAMLVersion()}function J(e){return"RelativeUriString"==e.kind()&&"RAML08"==e.RAMLVersion()}function Q(e){return"GlobalSchema"==e.kind()&&"RAML08"==e.RAMLVersion()}function Z(e){return"RAMLSimpleElement"==e.kind()&&"RAML08"==e.RAMLVersion()}function ee(e){return"DocumentationItem"==e.kind()&&"RAML08"==e.RAMLVersion()}function te(e){return"Resource"==e.kind()&&"RAML08"==e.RAMLVersion()}t.isApi=r,t.isFullUriTemplateString=i,t.isUriTemplate=a,t.isStringType=o,t.isValueType=s,t.isAnyType=u,t.isNumberType=l,t.isBooleanType=p,t.isReference=c,t.isResourceTypeRef=f,t.isResourceType=m,t.isMethod=d,t.isMethodBase=h,t.isResponse=y,t.isStatusCodeString=v,t.isParameter=g,t.isParameterLocation=A,t.isMarkdownString=S,t.isStringTypeDeclaration=T,t.isBooleanTypeDeclaration=E,t.isNumberTypeDeclaration=b,t.isIntegerTypeDeclaration=N,t.isDateTypeDeclaration=_,t.isFileTypeDeclaration=M,t.isBodyLike=w,t.isSchemaString=R,t.isJSonSchemaString=I,t.isXMLSchemaString=C,t.isExampleString=L,t.isJSONExample=P,t.isXMLExample=O,t.isXMLBody=D,t.isJSONBody=x,t.isSecuritySchemeRef=U,t.isAbstractSecurityScheme=k,t.isSecuritySchemePart=F,t.isTraitRef=B,t.isTrait=K,t.isSecuritySchemeSettings=V,t.isOAuth1SecuritySchemeSettings=j,t.isFixedUri=W,t.isOAuth2SecuritySchemeSettings=q,t.isOAuth2SecurityScheme=Y,t.isOAuth1SecurityScheme=H,t.isBasicSecurityScheme=$,t.isDigestSecurityScheme=G,t.isCustomSecurityScheme=X,t.isMimeType=z,t.isRelativeUriString=J,t.isGlobalSchema=Q,t.isRAMLSimpleElement=Z,t.isDocumentationItem=ee,t.isResource=te},function(e,t,n){"use strict";function r(e,t,n){return N.findDeclaration(e,t,n)}function i(e,t){return N.findUsages(e,t)}function a(e){return N.globalDeclarations(e)}function o(e,t,n){N.refFinder(e,t,n)}function s(e,t){return N.findDeclarationByNode(e,t)}function u(e,t){return N.determineCompletionKind(e,t)}function l(e,t){return N.enumValues(e,t)}function p(e,t){return _.qName(e,t)}function c(e,t){return N.subTypesWithLocals(e,t)}function f(e,t){return N.nodesDeclaringType(e,t)}function m(e){return N.isExampleNodeContent(e)}function d(e){return N.findExampleContentType(e)}function h(e,t){return N.parseDocumentationContent(e,t)}function y(e,t){return N.parseStructuredExample(e,t)}function v(e){return N.isExampleNode(e)}function g(e,t){return N.referenceTargets(e,t)}function A(e){return M.getNominalTypeSource(e)}function S(e,t){return N.findAllSubTypes(e,t)}function T(e){return N.declRoot(e)}function E(e,t,n,r,i){return void 0===r&&(r=!0),void 0===i&&(i=!0),N.deepFindNode(e,t,n,r,i)}function b(e){return N.allChildren(e)}var N=n(24),_=n(16),M=n(25);t.findDeclaration=r,t.findUsages=i,t.globalDeclarations=a,t.refFinder=o,t.findDeclarationByNode=s,function(e){e[e.VALUE_COMPLETION=0]="VALUE_COMPLETION",e[e.KEY_COMPLETION=1]="KEY_COMPLETION",e[e.PATH_COMPLETION=2]="PATH_COMPLETION",e[e.DIRECTIVE_COMPLETION=3]="DIRECTIVE_COMPLETION",e[e.VERSION_COMPLETION=4]="VERSION_COMPLETION",e[e.ANNOTATION_COMPLETION=5]="ANNOTATION_COMPLETION",e[e.SEQUENCE_KEY_COPLETION=6]="SEQUENCE_KEY_COPLETION",e[e.INCOMMENT=7]="INCOMMENT"}(t.LocationKind||(t.LocationKind={}));t.LocationKind;t.determineCompletionKind=u,t.enumValues=l,t.qName=p,t.subTypesWithLocals=c,t.nodesDeclaringType=f,t.isExampleNodeContent=m,t.findExampleContentType=d,t.parseDocumentationContent=h,t.parseStructuredExample=y,t.isExampleNode=v,t.referenceTargets=g,t.getNominalTypeSource=A,t.findAllSubTypes=S,t.declRoot=T,t.deepFindNode=E,t.allChildren=b},function(e,t,n){"use strict";function r(e){return e.nameId()===je.Universe10.Api.properties.documentation.name||e.nameId()===je.Universe08.Api.properties.documentation.name}function i(e){return e===je.Universe10.Trait.properties.usage.name||e===je.Universe08.Trait.properties.usage.name||e===je.Universe10.ResourceType.properties.usage.name||e===je.Universe08.ResourceType.properties.usage.name||e===je.Universe10.Library.properties.usage.name||e===je.Universe10.Overlay.properties.usage.name||e===je.Universe10.Extension.properties.usage.name}function a(e){return i(e.nameId())}function o(e){return e.nameId()==je.Universe10.Overlay.properties["extends"].name||e.nameId()==je.Universe10.Extension.properties["extends"].name}function s(e){return e===je.Universe10.TypeDeclaration.properties.description.name||"description"===e}function u(e){return s(e.nameId())}function l(e){return e===je.Universe10.TypeDeclaration.properties.required.name||e===je.Universe08.Parameter.properties.required.name||"required"===e}function p(e){return e===je.Universe10.TypeDeclaration.properties.displayName.name||"displayName"===e}function c(e){return p(e.nameId())}function f(e){return l(e.nameId())}function m(e){return e===je.Universe10.Api.properties.title.name||e===je.Universe08.Api.properties.title.name||e===je.Universe10.DocumentationItem.properties.title.name||e===je.Universe08.DocumentationItem.properties.title.name||e===je.Universe10.Overlay.properties.title.name||e===je.Universe10.Extension.properties.title.name;
}function d(e){return m(e.nameId())}function h(e){return y(e.nameId())}function y(e){return e===je.Universe08.MethodBase.properties.headers.name||e===je.Universe08.Response.properties.headers.name||e===je.Universe08.SecuritySchemePart.properties.headers.name||e===je.Universe10.MethodBase.properties.headers.name||e===je.Universe10.Response.properties.headers.name}function v(e){return g(e.nameId())}function g(e){return e===je.Universe08.BodyLike.properties.formParameters.name}function A(e){return S(e.nameId())}function S(e){return e===je.Universe08.MethodBase.properties.queryParameters.name||e===je.Universe08.SecuritySchemePart.properties.queryParameters.name||e===je.Universe10.MethodBase.properties.queryParameters.name}function T(e){return e.nameId()===je.Universe10.Api.properties.annotations.name||e.nameId()===je.Universe10.TypeDeclaration.properties.annotations.name||e.nameId()===je.Universe10.Response.properties.annotations.name}function E(e){return e.nameId()===je.Universe10.AnnotationRef.properties.annotation.name}function b(e){return e.nameId()===je.Universe10.MethodBase.properties.is.name||e.nameId()===je.Universe08.Method.properties.is.name||e.nameId()===je.Universe10.ResourceBase.properties.is.name||e.nameId()===je.Universe08.ResourceType.properties.is.name||e.nameId()===je.Universe08.Resource.properties.is.name}function N(e){return e.nameId()===je.Universe10.Api.properties.securedBy.name||e.nameId()===je.Universe08.Api.properties.securedBy.name||e.nameId()===je.Universe10.MethodBase.properties.securedBy.name||e.nameId()===je.Universe08.MethodBase.properties.securedBy.name||e.nameId()===je.Universe08.ResourceType.properties.securedBy.name||e.nameId()===je.Universe08.Resource.properties.securedBy.name||e.nameId()===je.Universe10.ResourceBase.properties.securedBy.name}function _(e){return e.nameId()===je.Universe10.LibraryBase.properties.securitySchemes.name||e.nameId()===je.Universe08.Api.properties.securitySchemes.name}function M(e){return e.nameId()===je.Universe10.SecuritySchemeRef.properties.securityScheme.name||e.nameId()===je.Universe08.SecuritySchemeRef.properties.securityScheme.name}function w(e){return e.nameId()===je.Universe10.AbstractSecurityScheme.properties.type.name||e.nameId()===je.Universe08.AbstractSecurityScheme.properties.type.name||e.nameId()===je.Universe08.ResourceType.properties.type.name||e.nameId()===je.Universe08.Resource.properties.type.name||e.nameId()===je.Universe08.Parameter.properties.type.name||e.nameId()===je.Universe10.ResourceBase.properties.type.name||e.nameId()===je.Universe10.TypeDeclaration.properties.type.name}function R(e){return e.nameId()===je.Universe10.ArrayTypeDeclaration.properties.items.name}function I(e){return e.nameId()===je.Universe10.ObjectTypeDeclaration.properties.properties.name}function C(e){return e.nameId()===je.Universe10.MethodBase.properties.responses.name||e.nameId()===je.Universe08.MethodBase.properties.responses.name}function L(e){return e.nameId()===je.Universe10.Api.properties.protocols.name||e.nameId()===je.Universe08.Api.properties.protocols.name||e.nameId()===je.Universe10.MethodBase.properties.protocols.name}function P(e){return e.nameId()===je.Universe10.TypeDeclaration.properties.name.name||e.nameId()===je.Universe10.TypeDeclaration.properties.name.name||e.nameId()===je.Universe08.AbstractSecurityScheme.properties.name.name||e.nameId()===je.Universe10.AbstractSecurityScheme.properties.name.name||e.nameId()===je.Universe08.Trait.properties.name.name||e.nameId()===je.Universe10.Trait.properties.name.name||"name"===e.nameId()}function O(e){return e.nameId()===je.Universe10.MethodBase.properties.body.name||e.nameId()===je.Universe08.MethodBase.properties.body.name||e.nameId()===je.Universe10.Response.properties.body.name||e.nameId()===je.Universe08.Response.properties.body.name}function D(e){return e.nameId()===je.Universe10.TypeDeclaration.properties["default"].name||e.nameId()===je.Universe08.Parameter.properties["default"].name}function x(e){return e.nameId()===je.Universe08.BodyLike.properties.schema.name||e.nameId()===je.Universe08.XMLBody.properties.schema.name||e.nameId()===je.Universe08.JSONBody.properties.schema.name||e.nameId()===je.Universe10.TypeDeclaration.properties.schema.name}function U(e){return e.nameId()===je.Universe08.Api.properties.traits.name||e.nameId()===je.Universe10.LibraryBase.properties.traits.name}function k(e){return e.nameId()===je.Universe08.TraitRef.properties.trait.name||e.nameId()===je.Universe10.TraitRef.properties.trait.name}function F(e){return e.nameId()===je.Universe08.Api.properties.resourceTypes.name||e.nameId()===je.Universe10.LibraryBase.properties.resourceTypes.name}function B(e){return e.nameId()===je.Universe08.ResourceTypeRef.properties.resourceType.name||e.nameId()===je.Universe10.ResourceTypeRef.properties.resourceType.name}function K(e){return e.nameId()===je.Universe10.TypeDeclaration.properties.facets.name}function V(e){return e.nameId()===je.Universe08.Api.properties.schemas.name||e.nameId()===je.Universe10.LibraryBase.properties.schemas.name}function j(e){return e.nameId()===je.Universe10.Api.properties.resources.name||e.nameId()===je.Universe08.Api.properties.resources.name||e.nameId()===je.Universe10.Resource.properties.resources.name||e.nameId()===je.Universe08.Resource.properties.resources.name}function W(e){return e.nameId()===je.Universe10.ResourceBase.properties.methods.name||e.nameId()===je.Universe08.Resource.properties.methods.name||e.nameId()===je.Universe08.ResourceType.properties.methods.name}function q(e){return e&&e.nameId()===je.Universe10.LibraryBase.properties.types.name}function Y(e){return e.nameId()===je.Universe10.TypeDeclaration.properties.example.name||"example"===e.nameId()}function H(e){return e.nameId()===je.Universe10.StringTypeDeclaration.properties["enum"].name||e.nameId()===je.Universe10.NumberTypeDeclaration.properties["enum"].name||e.nameId()===je.Universe08.StringTypeDeclaration.properties["enum"].name}function $(e){return e.nameId()===je.Universe10.TypeDeclaration.properties.example.name||e.nameId()===je.Universe10.TypeDeclaration.properties.examples.name}function G(e){return e.nameId()===je.Universe08.GlobalSchema.properties.value.name}function X(e){return e.nameId()===je.Universe08.Api.properties.uriParameters.name||e.nameId()===je.Universe08.ResourceType.properties.uriParameters.name||e.nameId()===je.Universe08.Resource.properties.uriParameters.name||e.nameId()===je.Universe10.ResourceBase.properties.uriParameters.name}function z(e){return e.nameId()===je.Universe08.Resource.properties.baseUriParameters.name||e.nameId()===je.Universe08.Api.properties.baseUriParameters.name||e.nameId()===je.Universe10.Api.properties.baseUriParameters.name}function J(e){return e.nameId()===je.Universe08.Api.properties.RAMLVersion.name||e.nameId()===je.Universe10.Api.properties.RAMLVersion.name}function Q(e){return e.nameId()===je.Universe10.FragmentDeclaration.properties.uses.name}function Z(e){return e.nameId()===je.Universe10.LibraryBase.properties.annotationTypes.name}function ee(e){return e.key()==je.Universe10.Method||e.key()==je.Universe08.Method}function te(e){return e.key()==je.Universe10.Api||e.key()==je.Universe08.Api}function ne(e){return e.key()==je.Universe10.BooleanType||e.key()==je.Universe08.BooleanType}function re(e){return e.key()==je.Universe10.MarkdownString||e.key()==je.Universe08.MarkdownString}function ie(e){return e.key()==je.Universe10.Resource||e.key()==je.Universe08.Resource}function ae(e){return e.key()==je.Universe10.Trait||e.key()==je.Universe08.Trait}function oe(e){return e.key()==je.Universe10.TraitRef||e.key()==je.Universe08.TraitRef}function se(e){return e.key()==je.Universe10.ResourceTypeRef||e.key()==je.Universe08.ResourceTypeRef}function ue(e){return e.key()==je.Universe08.GlobalSchema}function le(e){return e.key()==je.Universe10.AbstractSecurityScheme||e.key()==je.Universe08.AbstractSecurityScheme}function pe(e){return e.isAssignableFrom(je.Universe10.AbstractSecurityScheme.name)}function ce(e){return e.key()==je.Universe10.SecuritySchemeRef||e.key()==je.Universe08.SecuritySchemeRef}function fe(e){return e.key()==je.Universe10.TypeDeclaration}function me(e){return e.key()==je.Universe10.Response||e.key()==je.Universe08.Response}function de(e){return e.key()==je.Universe08.BodyLike}function he(e){return e.key()==je.Universe10.Overlay}function ye(e){return!1}function ve(e){return e.key()==je.Universe10.ResourceType||e.key()==je.Universe08.ResourceType}function ge(e){return e.key()==je.Universe10.SchemaString||e.key()==je.Universe08.SchemaString}function Ae(e){return e.key()==je.Universe10.MethodBase||e.key()==je.Universe08.MethodBase}function Se(e){return e.key()==je.Universe10.Library}function Te(e){return e.key()==je.Universe10.StringType||e.key()==je.Universe08.StringType}function Ee(e){return e.key()==je.Universe10.ExampleSpec}function be(e){return e.key()==je.Universe10.Extension}function Ne(e){return e.isAssignableFrom(je.Universe10.TypeDeclaration.name)}function _e(e){return e.key()==je.Universe10.DocumentationItem||e.key()==je.Universe08.DocumentationItem}function Me(e){return e.isAssignableFrom(je.Universe10.AnnotationRef.name)}function we(e){return e.isAssignableFrom(je.Universe10.Api.name)||e.isAssignableFrom(je.Universe08.Api.name)}function Re(e){return e.isAssignableFrom(je.Universe10.LibraryBase.name)}function Ie(e){return e.isAssignableFrom(je.Universe10.ResourceBase.name)||e.isAssignableFrom(je.Universe08.Resource.name)}function Ce(e){return e.isAssignableFrom(je.Universe10.ObjectTypeDeclaration.name)}function Le(e){return e.isAssignableFrom(je.Universe10.TypeDeclaration.name)}function Pe(e){return e.isAssignableFrom(je.Universe10.TypeDeclaration.name)}function Oe(e){return e.isAssignableFrom(je.Universe10.MethodBase.name)||e.isAssignableFrom(je.Universe08.MethodBase.name)}function De(e){return e.key()==je.Universe10.SecuritySchemePart||e.key()==je.Universe08.SecuritySchemePart}function xe(e){return e.nameId()===je.Universe08.Api.properties.mediaType.name||e.nameId()===je.Universe10.Api.properties.mediaType.name}function Ue(e){return"RAML08"==e.universe().version()}function ke(e){return"RAML10"==e.universe().version()}function Fe(e){return Ue(e.definition())}function Be(e){return Ue(e.definition())}function Ke(e){return ke(e.definition())}function Ve(e){return ke(e.definition())}var je=n(17);t.isDocumentationProperty=r,t.isUsagePropertyName=i,t.isUsageProperty=a,t.isMasterRefProperty=o,t.isDescriptionPropertyName=s,t.isDescriptionProperty=u,t.isRequiredPropertyName=l,t.isDisplayNamePropertyName=p,t.isDisplayNameProperty=c,t.isRequiredProperty=f,t.isTitlePropertyName=m,t.isTitleProperty=d,t.isHeadersProperty=h,t.isHeadersPropertyName=y,t.isFormParametersProperty=v,t.isFormParametersPropertyName=g,t.isQueryParametersProperty=A,t.isQueryParametersPropertyName=S,t.isAnnotationsProperty=T,t.isAnnotationProperty=E,t.isIsProperty=b,t.isSecuredByProperty=N,t.isSecuritySchemesProperty=_,t.isSecuritySchemeProperty=M,t.isTypeProperty=w,t.isItemsProperty=R,t.isPropertiesProperty=I,t.isResponsesProperty=C,t.isProtocolsProperty=L,t.isNameProperty=P,t.isBodyProperty=O,t.isDefaultValue=D,t.isSchemaProperty=x,t.isTraitsProperty=U,t.isTraitProperty=k,t.isResourceTypesProperty=F,t.isResourceTypeProperty=B,t.isFacetsProperty=K,t.isSchemasProperty=V,t.isResourcesProperty=j,t.isMethodsProperty=W,t.isTypesProperty=q,t.isExampleProperty=Y,t.isEnumProperty=H,t.isExamplesProperty=$,t.isValueProperty=G,t.isUriParametersProperty=X,t.isBaseUriParametersProperty=z,t.isRAMLVersionProperty=J,t.isUsesProperty=Q,t.isAnnotationTypesProperty=Z,t.isMethodType=ee,t.isApiType=te,t.isBooleanTypeType=ne,t.isMarkdownStringType=re,t.isResourceType=ie,t.isTraitType=ae,t.isTraitRefType=oe,t.isResourceTypeRefType=se,t.isGlobalSchemaType=ue,t.isSecuritySchemaType=le,t.isSecuritySchemaTypeDescendant=pe,t.isSecuritySchemeRefType=ce,t.isTypeDeclarationType=fe,t.isResponseType=me,t.isBodyLikeType=de,t.isOverlayType=he,t.isAnnotationTypeType=ye,t.isResourceTypeType=ve,t.isSchemaStringType=ge,t.isMethodBaseType=Ae,t.isLibraryType=Se,t.isStringTypeType=Te,t.isExampleSpecType=Ee,t.isExtensionType=be,t.isTypeDeclarationTypeOrDescendant=Ne,t.isDocumentationType=_e,t.isAnnotationRefTypeOrDescendant=Me,t.isApiSibling=we,t.isLibraryBaseSibling=Re,t.isResourceBaseSibling=Ie,t.isObjectTypeDeclarationSibling=Ce,t.isTypeDeclarationDescendant=Le,t.isTypeDeclarationSibling=Pe,t.isMethodBaseSibling=Oe,t.isSecuritySchemePartType=De,t.isMediaTypeProperty=xe,t.isRAML08Type=Ue,t.isRAML10Type=ke,t.isRAML08Node=Fe,t.isRAML08Attribute=Be,t.isRAML10Node=Ke,t.isRAML10Attribute=Ve},function(e,t,n){(function(e){function n(e,t){for(var n=0,r=e.length-1;r>=0;r--){var i=e[r];"."===i?e.splice(r,1):".."===i?(e.splice(r,1),n++):n&&(e.splice(r,1),n--)}if(t)for(;n--;n)e.unshift("..");return e}function r(e,t){if(e.filter)return e.filter(t);for(var n=[],r=0;r<e.length;r++)t(e[r],r,e)&&n.push(e[r]);return n}var i=/^(\/?|)([\s\S]*?)((?:\.{1,2}|[^\/]+?|)(\.[^.\/]*|))(?:[\/]*)$/,a=function(e){return i.exec(e).slice(1)};t.resolve=function(){for(var t="",i=!1,a=arguments.length-1;a>=-1&&!i;a--){var o=a>=0?arguments[a]:e.cwd();if("string"!=typeof o)throw new TypeError("Arguments to path.resolve must be strings");o&&(t=o+"/"+t,i="/"===o.charAt(0))}return t=n(r(t.split("/"),function(e){return!!e}),!i).join("/"),(i?"/":"")+t||"."},t.normalize=function(e){var i=t.isAbsolute(e),a="/"===o(e,-1);return e=n(r(e.split("/"),function(e){return!!e}),!i).join("/"),e||i||(e="."),e&&a&&(e+="/"),(i?"/":"")+e},t.isAbsolute=function(e){return"/"===e.charAt(0)},t.join=function(){var e=Array.prototype.slice.call(arguments,0);return t.normalize(r(e,function(e,t){if("string"!=typeof e)throw new TypeError("Arguments to path.join must be strings");return e}).join("/"))},t.relative=function(e,n){function r(e){for(var t=0;t<e.length&&""===e[t];t++);for(var n=e.length-1;n>=0&&""===e[n];n--);return t>n?[]:e.slice(t,n-t+1)}e=t.resolve(e).substr(1),n=t.resolve(n).substr(1);for(var i=r(e.split("/")),a=r(n.split("/")),o=Math.min(i.length,a.length),s=o,u=0;o>u;u++)if(i[u]!==a[u]){s=u;break}for(var l=[],u=s;u<i.length;u++)l.push("..");return l=l.concat(a.slice(s)),l.join("/")},t.sep="/",t.delimiter=":",t.dirname=function(e){var t=a(e),n=t[0],r=t[1];return n||r?(r&&(r=r.substr(0,r.length-1)),n+r):"."},t.basename=function(e,t){var n=a(e)[2];return t&&n.substr(-1*t.length)===t&&(n=n.substr(0,n.length-t.length)),n},t.extname=function(e){return a(e)[3]};var o="b"==="ab".substr(-1)?function(e,t,n){return e.substr(t,n)}:function(e,t,n){return 0>t&&(t=e.length+t),e.substr(t,n)}}).call(t,n(61))},function(e,t,n){"use strict";function r(e,t){var n=e.name();if(y.LowLevelProxyNode.isInstance(t.lowLevel())){if(y.LowLevelProxyNode.isInstance(e.lowLevel()))return n;var r=t.root().lowLevel().unit(),i=r.project().namespaceResolver(),a=e.lowLevel().unit(),o=i.resolveNamespace(r,a);if(null!=o){var s=o.namespace();if(null!=s)return s+"."+n}}if(e.lowLevel().unit()!=t.lowLevel().unit())for(var u=t;;){if(u.lowLevel().includePath()||null==u.parent()){u.unitMap||(u.unitMap={},u.asElement().elements().forEach(function(e){if(e.definition().key()==N.Universe10.UsesDeclaration){var t=e.attr("value");if(t){var n=e.root().lowLevel().unit().resolve(t.value());if(null!=n){var r=e.attr("key");r&&(u.unitMap[n.absolutePath()]=r.value())}}}}));var l=u.unitMap[e.lowLevel().unit().absolutePath()];if(l)return l+"."+n}if(!u.parent())break;u=u.parent()}return n}function i(e){return e.match(/^\s*#%RAML\s+(\d\.\d)\s*(\w*)\s*$/m)}function a(e){var t=e.lowLevel()&&e.lowLevel().unit()&&e.lowLevel().unit().contents();return null==t?null:Y(t,e.lowLevel()).ptype}function o(e){if(null==e)return null;var t=e.contents(),n=e.ast(),r=Y(t,n),i=r.ptype,a=r.localUniverse,o=a.type(i);o||(o=a.type("Api"));var s=new q(n,null,o,null);return s.setUniverse(a),s.children(),s}function s(e,t){if(t){var n=t.root().lowLevel().unit();return n?new U.PointOfViewValidationAcceptorImpl(e,t.root()):{accept:function(t){e.push(t)},begin:function(){},end:function(){},acceptUnique:function(t){for(var n=0,r=e;n<r.length;n++){var i=r[n];if(i.start==t.start&&i.message==t.message)return}this.accept(t)}}}}function u(e){if(null!=e.parent())return!1;var t=e.lowLevel().unit();if(null==t)return!1;var n=t.contents(),r=i(n);return r.length<3?!1:"AnnotationTypeDeclaration"==r[2]}function l(e,t,n){var r=e.validationIssue;if(!r){var i=e.issueCode||t,a=e.node||n,o=e.message||"The "+t+" plugin reports an error",s=e.isWarning;r=T.createIssue(i,o,a,s)}return r}function p(e){for(var t=[],n=d.getNodeValidationPlugins(),r=0,i=n;r<i.length;r++){var a=i[r],o=a.process(e);o&&o.forEach(function(n){var r=l(n,a.id(),e);t.push(r)})}return t}function c(e){for(var t=new H(e),n=[],r=d.getNodeAnnotationValidationPlugins(),i=0,a=r;i<a.length;i++){var o=a[i],s=o.process(t);s&&s.forEach(function(t){var r=l(t,o.id(),e);n.push(r)})}return n}var f=this&&this.__extends||function(e,t){function n(){this.constructor=e}for(var r in t)t.hasOwnProperty(r)&&(e[r]=t[r]);e.prototype=null===t?Object.create(t):(n.prototype=t.prototype,new n)},m=n(37),d=n(9),h=n(64),y=n(41),v=m,g=n(31),A=n(13),S=n(42),T=n(30),E=n(29),b=n(43),N=n(17),_=n(26),M=n(40),w=v,R=n(75),I=n(34),C=n(44),L=n(45),P=n(14),O=n(27),D=m.rt,x=n(32),U=n(2);t.qName=r;var k=function(){function e(e,t){this._node=e,this._parent=t,this._implicit=!1,this.values={},e&&e.setHighLevelParseResult(this)}return e.isInstance=function(t){return null!=t&&t.getClassIdentifier&&"function"==typeof t.getClassIdentifier&&h.contains(t.getClassIdentifier(),e.CLASS_IDENTIFIER)},e.prototype.getClassIdentifier=function(){var t=[];return t.concat(e.CLASS_IDENTIFIER)},e.prototype.getKind=function(){return d.NodeKind.BASIC},e.prototype.asAttr=function(){return null},e.prototype.asElement=function(){return null},e.prototype.hashkey=function(){return this._hashkey||(this._hashkey=this.parent()?this.parent().hashkey()+"/"+this.name():this.name()),this._hashkey},e.prototype.root=function(){return this.parent()?this.parent().root():this},e.prototype.version=function(){return""},e.prototype.getLowLevelStart=function(){return this.lowLevel().kind()===_.Kind.SCALAR?this.lowLevel().start():this.lowLevel().keyStart()},e.prototype.getLowLevelEnd=function(){return this.lowLevel().kind()===_.Kind.SCALAR?this.lowLevel().end():this.lowLevel().keyEnd()},e.prototype.isSameNode=function(e){return e&&e.lowLevel().actual()==this.lowLevel().actual()?!0:!1},e.prototype.checkContextValue=function(e,t,n){var r=this.computedValue(e);return r&&-1!=r.indexOf(t)?!0:t==r||"false"==t},e.prototype.printDetails=function(e){return(e?e:"")+"Unkown\n"},e.prototype.testSerialize=function(e){return(e?e:"")+"Unkown\n"},e.prototype.errors=function(){var e=[],t=s(e,this);return this.validate(t),e},e.prototype.markCh=function(){for(var e=this.lowLevel();y.LowLevelProxyNode.isInstance(e);)e=e.originalNode();return e=e._node?e._node:e,e.markCh?!0:void(e.markCh=1)},e.prototype.unmarkCh=function(){for(var e=this.lowLevel();y.LowLevelProxyNode.isInstance(e);)e=e.originalNode();e=e._node?e._node:e,delete e.markCh},e.prototype.validate=function(e){T.validate(this,e);for(var t=0,n=p(this);t<n.length;t++){var r=n[t];e.accept(r)}for(var i=0,a=c(this);i<a.length;i++){var r=a[i];e.accept(r)}},e.prototype.allowRecursive=function(){return!1},e.prototype.setComputed=function(e,t){this.values[e]=t},e.prototype.computedValue=function(e){var t=this.values[e];return!t&&this.parent()?this.parent().computedValue(e):t},e.prototype.lowLevel=function(){return this._node},e.prototype.name=function(){var e=this.lowLevel().key();return e?e:""},e.prototype.optional=function(){var e=this.lowLevel(),t=e.optional();if(null!=e.key())return t;var n=this.property();if(!n||!n.isMultiValue())return t;for(var r=e.parent();r&&null==r.highLevelNode();){if(r.kind()==R.Kind.MAPPING)return r.optional();r=r.parent()}return t},e.prototype.parent=function(){return this._parent},e.prototype.setParent=function(e){this._parent=e},e.prototype.isElement=function(){return!1},e.prototype.directChildren=function(){return this.children()},e.prototype.children=function(){return[]},e.prototype.isAttached=function(){return null!=this.parent()},e.prototype.isImplicit=function(){return this._implicit},e.prototype.isAttr=function(){return!1},e.prototype.isUnknown=function(){return!0},e.prototype.id=function(){var e=this;if(this.cachedId)return this.cachedId;if(this._parent){var t=this.parent().id();t+="."+this.name();var n=this.parent().directChildren().filter(function(t){return t.name()==e.name()});if(n.length>1){var r=n.indexOf(this);t+="["+r+"]"}return this.cachedId=t,t}return this.cachedId="",this.cachedId},e.prototype.localId=function(){return this.name()},e.prototype.fullLocalId=function(){var e=this;if(this.cachedFullId)return this.cachedFullId;if(this._parent){var t=".";t+=null!=this.property()&&P.isAnnotationsProperty(this.property())?this.lowLevel().key():this.name();var n=this.parent().directChildren().filter(function(t){return t.name()==e.name()});if(n.length>1){var r=n.indexOf(this);t+="["+r+"]"}return this.cachedFullId=t,t}return this.cachedFullId=this.localId(),this.cachedFullId},e.prototype.property=function(){return null},e.CLASS_IDENTIFIER="highLevelImpl.BasicASTNode",e}();t.BasicASTNode=k;var F=function(){function e(e,t,n,r){void 0===r&&(r=null),this.node=e,this._parent=t,this.kv=r,this._pr=n}return e.isInstance=function(t){return null!=t&&t.getClassIdentifier&&"function"==typeof t.getClassIdentifier&&h.contains(t.getClassIdentifier(),e.CLASS_IDENTIFIER)},e.prototype.getClassIdentifier=function(){var t=[];return t.concat(e.CLASS_IDENTIFIER)},e.prototype.valueName=function(){var e=null;return this.kv&&(e=this.kv),e=this.node.key(),this._pr&&this._pr.isAnnotation()&&e&&"("==e.charAt(0)&&(e=e.substring(1,e.length-1)),e},e.prototype.children=function(){return this.node.children().map(function(t){return new e(t,null,null)})},e.prototype.lowLevel=function(){return this.node},e.prototype.toHighLevel=function(e){if(!e&&this._parent&&(e=this._parent),this._hl)return this._hl;var t=this.valueName(),n=A.referenceTargets(this._pr,e).filter(function(n){return r(n,e)==t});if(n&&n[0]){var i=n[0].localType(),a=new q(this.node,e,i,this._pr);return this._pr&&this._pr.childRestrictions().forEach(function(e){a.setComputed(e.name,e.value)}),this._hl=a,a}return null},e.prototype.toHighLevel2=function(e){!e&&this._parent&&(e=this._parent);var t=this.valueName(),n=A.referenceTargets(this._pr,e).filter(function(n){return r(n,e)==t});if(n&&n[0]){var i=n[0].localType(),a=new q(this.node,e,i,this._pr);return this._pr&&this._pr.childRestrictions().forEach(function(e){a.setComputed(e.name,e.value)}),a}if(this._pr.range()){var a=new q(this.node.parent(),e,this._pr.range(),this._pr);return this._pr&&this._pr.childRestrictions().forEach(function(e){a.setComputed(e.name,e.value)}),a}return null},e.CLASS_IDENTIFIER="highLevelImpl.StructuredValue",e}();t.StructuredValue=F;var B=function(e){function t(t,n,r,i,a){void 0===a&&(a=!1),e.call(this,t,n),this._def=r,this._prop=i,this.fromKey=a}return f(t,e),t.isInstance=function(e){return null!=e&&e.getClassIdentifier&&"function"==typeof e.getClassIdentifier&&h.contains(e.getClassIdentifier(),t.CLASS_IDENTIFIER_ASTPropImpl)},t.prototype.getClassIdentifier=function(){var n=e.prototype.getClassIdentifier.call(this);return n.concat(t.CLASS_IDENTIFIER_ASTPropImpl)},t.prototype.definition=function(){return this._def},t.prototype.asAttr=function(){return this},t.prototype.errors=function(){var e=[],t=s(e,this);return this.parent().validate(t),e},t.prototype.isString=function(){return!this._def||this._def.key()!==N.Universe08.StringType&&this._def.key()!=N.Universe10.StringType?!1:!0},t.prototype.isAnnotatedScalar=function(){return this.property().isAnnotation()||this.property().isKey()?!1:this.lowLevel().isAnnotatedScalar()},t.prototype.annotations=function(){var e=this.lowLevel().children(),n=[],r=this.definition().universe().type(N.Universe10.Annotable.name);if(!r)return n;for(var i=r.property("annotations"),a=0;a<e.length;a++){var o=e[a],s=o.key();if(null!=s&&"("==s[0]&&")"==s[s.length-1]){var u=new t(o,this.parent(),i.range(),i);n.push(u)}}return n},t.prototype.getKind=function(){return d.NodeKind.ATTRIBUTE},t.prototype.owningWrapper=function(){return{node:this.parent().wrapperNode(),property:this.name()}},t.prototype.patchType=function(e){this._def=e},t.prototype.findReferenceDeclaration=function(){var e=this,t=A.referenceTargets(this.property(),this.parent()),n=this.value();if(F.isInstance(n))var i=n,a=i.valueName();else var a=""+n;var o=h.find(t,function(t){return r(t,e.parent())==a});return o},t.prototype.findReferencedValue=function(){var e=this.findReferenceDeclaration();if(e){var t=e.attr("value"),n=e.definition().key();if(n===N.Universe08.GlobalSchema){if(t){var r=t.value();if(r){var i=T.isValid(this._def,this.parent(),r,t.property());return i}}return null}}return e},t.prototype.isElement=function(){return!1},t.prototype.property=function(){return this._prop},t.prototype.convertMultivalueToString=function(e){for(var t=0,n=2;" "==e[n];)t++,n++;var r=M.splitOnLines(e);return r=r.map(function(e){return e.substring(t,e.length)}),r.join("")},t.prototype.overrideValue=function(e){this._value=e},t.prototype.value=function(){return this._value?this._value:(this._value=this.calcValue(),this._value)},t.prototype.calcValue=function(){if(this._computed)return this.computedValue(this.property().nameId());if(this.fromKey){var e=this.parent(),t=e.definition();if("RAML08"==t.universe().version())return this._node.key();if(P.isNameProperty(this.property())&&t.isAssignableFrom(N.Universe10.TypeDeclaration.name)){var n=e.attr("required");if(n&&null!=n.value())return this._node.optional()?this._node.key()+"?":this._node.key()}return this._node.key()}if(this.property().isAnnotation()&&this._node.key()&&"annotations"!=this._node.key())return new F(this._node,this.parent(),this._prop);var r=null!=this.property()&&!(null==this.parent()||null==this.parent().definition()||P.isTypeProperty(this.property())&&P.isTypeDeclarationSibling(this.parent().definition()))&&P.isStringTypeType(this.property().range()),i=this._node.value(r);if(this.property().isSelfNode()&&(!i||_.ASTNode.isInstance(i))&&(i=this._node,0==i.children().length&&(i=null)),_.ASTNode.isInstance(i)||y.LowLevelProxyNode.isInstance(i)){var a=!1;if(this.property().range().hasStructure()||this._node.isAnnotatedScalar()&&this._node.children().forEach(function(e){"value"===e.key()&&(i=e.value(r),a=!0)}),!a)return this._sval?this._sval:(this._sval=new F(i,this.parent(),this._prop),this._sval)}if("string"==typeof i&&M.isMultiLineValue(i)){var o=this.convertMultivalueToString(i);return o}return null==i&&this._node.children().length>0&&this.property()&&(P.isTypeProperty(this.property())||P.isItemsProperty(this.property()))&&this.parent()&&P.isTypeDeclarationSibling(this.parent().definition())?new F(this._node,this.parent(),this._prop):i},t.prototype.name=function(){return this._prop.nameId()},t.prototype.printDetails=function(e){var t=this.definition().nameId(),n=this.property().range().nameId(),r=(e?e:"")+(this.name()+" : "+t+"["+n+"]  =  "+this.value())+(this.property().isKey()&&this.optional()?"?":"")+"\n";if(F.isInstance(this.value())){var i=this.value().toHighLevel();i&&i.printDetails&&(r+=i.printDetails(e+"	"))}return r},t.prototype.testSerialize=function(e){var t=this.definition().nameId(),n=(e?e:"")+(this.name()+" : "+t+"  =  "+this.value())+"\n";if(F.isInstance(this.value())){var r=this.value().toHighLevel();if(r&&r.testSerialize)n+=r.testSerialize((e?e:"")+"  ");else{var i=this.value().lowLevel(),a=i.dumpToObject(),o=JSON.stringify(a),s="",u=o.split("\n");u.forEach(function(t){return s+=(e?e:"")+"  "+t+"\n"}),n+=s+"\n"}}return n},t.prototype.isAttr=function(){return!0},t.prototype.isUnknown=function(){return!1},t.prototype.setValue=function(e){S.setValue(this,e),this._value=null},t.prototype.setKey=function(e){S.setKey(this,e),this._value=null},t.prototype.children=function(){return[]},t.prototype.addStringValue=function(e){S.addStringValue(this,e),this._value=null},t.prototype.addStructuredValue=function(e){S.addStructuredValue(this,e),this._value=null},t.prototype.addValue=function(e){if(!this.property().isMultiValue())throw new Error("setValue(string) only apply to multi-values properties");"string"==typeof e?this.addStringValue(e):this.addStructuredValue(e),this._value=null},t.prototype.isEmbedded=function(){var e=this.lowLevel().asMapping().key.value;return this.property().canBeValue()&&e!=this.property().nameId()},t.prototype.remove=function(){S.removeAttr(this)},t.prototype.setValues=function(e){S.setValues(this,e),this._value=null},t.prototype.isEmpty=function(){if(!this.property().isMultiValue())throw new Error("isEmpty() only apply to multi-values attributes");var e=this.parent(),t=(e.lowLevel(),e.attributes(this.name()));if(0==t.length)return!0;if(1==t.length){var n=t[0].lowLevel();return n.isMapping()&&null==n.value()?!0:!1}return!1},t.prototype.isFromKey=function(){return this.fromKey},t.CLASS_IDENTIFIER_ASTPropImpl="highLevelImpl.ASTPropImpl",t}(k);t.ASTPropImpl=B;var K=new g.BasicNodeBuilder;!function(e){e[e.MERGE=0]="MERGE",e[e.AGGREGATE=1]="AGGREGATE"}(t.OverlayMergeMode||(t.OverlayMergeMode={}));var V=t.OverlayMergeMode,j=function(e){function t(n,r){e.call(this),this._node=n,this._highLevelRoot=r;var i=r.root(),a=i.getMaster();if(a&&this._node===r.lowLevel()){var o=r.getMasterCounterPart();o&&(this._toMerge=new t(o.lowLevel(),o))}}return f(t,e),t.isInstance=function(e){return null!=e&&e.getClassIdentifier&&"function"==typeof e.getClassIdentifier&&h.contains(e.getClassIdentifier(),t.CLASS_IDENTIFIER_LowLevelWrapperForTypeSystem)},t.prototype.getClassIdentifier=function(){var n=e.prototype.getClassIdentifier.call(this);return n.concat(t.CLASS_IDENTIFIER_LowLevelWrapperForTypeSystem)},t.prototype.contentProvider=function(){var e=this._node&&this._node.includeBaseUnit()&&(this._node.includePath&&this._node.includePath()?this._node.includeBaseUnit().resolve(this._node.includePath()):this._node.includeBaseUnit());return new x.ContentProvider(e)},t.prototype.key=function(){var e=this._node.key();return this._node.optional()&&(e+="?"),e},t.prototype.value=function(){var e=this._node.valueKind();if(e===R.Kind.SEQ)return this.children().map(function(e){return e.value()});if(e===R.Kind.MAP||e===R.Kind.ANCHOR_REF){var n=this._node.dumpToObject(!1);return n[this.key()]}if(this._node.kind()==R.Kind.MAP){var n=this._node.dumpToObject(!1);return n}if(e===R.Kind.INCLUDE_REF){var r=null,i=this._node.includePath();try{r=this._node.unit().resolve(i)}catch(a){}if(null!=r&&r.isRAMLUnit()){var o=r.ast(),s=new t(o,r.highLevel().asElement());return o.kind()==R.Kind.SEQ?s.children().map(function(e){return e.value()}):s.value()}}var u=this._node.value();return u},t.prototype.children=function(){var e=this;if(this._children)return this._children;"uses"!=this.key()||this._node.parent().parent()?this._children=this._node.children().map(function(n){return new t(n,e._highLevelRoot)}):this._children=this._node.children().map(function(t){return new W(t,e._highLevelRoot)}),this.childByKey={};for(var n=0;n<this._children.length;n++){var r=this._children[n];this.childByKey[r.key()]=r}if(this._toMerge)for(var i=this._toMerge.children(),n=0;n<i.length;n++){var r=i[n],a=this.childByKey[r.key()];a?a._toMerge=r:(this._children.push(r),this.childByKey[r.key()]=r)}return this._children},t.prototype.childWithKey=function(e){return this._children||this.children(),this.childByKey[e]},t.prototype.kind=function(){var e=this._node.valueKind();if(e==R.Kind.MAPPING||null===e)return D.NodeKind.MAP;if(e==R.Kind.MAP)return D.NodeKind.MAP;var t=this._node.kind();return t==R.Kind.MAP?D.NodeKind.MAP:e==R.Kind.SEQ?D.NodeKind.ARRAY:e==R.Kind.INCLUDE_REF&&this._node.children().length>0?D.NodeKind.MAP:D.NodeKind.SCALAR},t.prototype.getSource=function(){if(!this._node)return null;
var e=this._node.highLevelNode();if(!e){var t=this._node.start(),n=A.deepFindNode(this._highLevelRoot,t,t,!0,!1);return n&&(this._node.setHighLevelParseResult(n),q.isInstance(n)&&this._node.setHighLevelNode(n)),n}return e},t.prototype.node=function(){return this._node},t.CLASS_IDENTIFIER_LowLevelWrapperForTypeSystem="highLevelImpl.LowLevelWrapperForTypeSystem",t}(m.SourceProvider);t.LowLevelWrapperForTypeSystem=j;var W=function(e){function t(){e.apply(this,arguments)}return f(t,e),t.prototype.children=function(){var e=this._node.unit().resolve(this.value());return e&&e.isRAMLUnit()&&e.contents().trim().length>0?new j(e.ast(),this._highLevelRoot).children():[]},t.prototype.anchor=function(){return this._node.actual()},t.prototype.childWithKey=function(e){for(var t=this.children(),n=0;n<t.length;n++)if(t[n].key()==e)return t[n];return null},t}(j);t.UsesNodeWrapperFoTypeSystem=W;var q=function(e){function t(t,n,r,i){e.call(this,t,n),this._def=r,this._prop=i,this._expanded=!1,this._allowQuestion=!1,this._subTypesCache=null,this._auxChecked=!1,this.overlayMergeMode=V.MERGE,t&&t.setHighLevelNode(this),y.LowLevelProxyNode.isInstance(t)&&(this._expanded=!0)}return f(t,e),t.isInstance=function(e){return null!=e&&e.getClassIdentifier&&"function"==typeof e.getClassIdentifier&&h.contains(e.getClassIdentifier(),t.CLASS_IDENTIFIER_ASTNodeImpl)},t.prototype.getClassIdentifier=function(){var n=e.prototype.getClassIdentifier.call(this);return n.concat(t.CLASS_IDENTIFIER_ASTNodeImpl)},t.prototype.createIssue=function(e){return T.toIssue(e,this)},t.prototype.validate=function(t){var n=this.definition().key();if((n==N.Universe10.Api||n==N.Universe08.Api||n==N.Universe10.Extension)&&!this.isExpanded()){var r=E.expandTraitsAndResourceTypes(this.wrapperNode()),i=r.highLevel();return i.resetChildren(),i.children(),i._expanded=!0,i.clearTypesCache(),void i.validate(t)}(n==N.Universe10.Overlay||n==N.Universe10.Extension)&&this.clearTypesCache(),e.prototype.validate.call(this,t)},t.prototype.clearTypesCache=function(){if(this._types=null,this.lowLevel()){var e=this.lowLevel().actual();e.types=null}},t.prototype.types=function(){var e=this;if(!this._types){if(this.parent()&&this.definition().key()!==N.Universe10.Library)return this.parent().types();var t=this.lowLevel().actual();if(t.types)return t.types;this._types=D.parseFromAST(new j(this.lowLevel(),this)),this._types.types().forEach(function(t){var n=b.convertType(e,t);n.putExtra(m.USER_DEFINED_EXTRA,!0)}),t.types=this._types}return this._types},t.prototype.setTypes=function(e){this._types=e},t.prototype.parsedType=function(){if(!this._ptype){if(this.property()&&this.property().nameId()==N.Universe10.MethodBase.properties.body.name){var e=this.isParametrizedType();this._ptype=D.parseTypeFromAST(this.name(),new j(this.lowLevel(),this),this.types(),!0,!1,!1,e)}else{var t=this.property()&&this.property().nameId()==N.Universe10.LibraryBase.properties.annotationTypes.name,n=!this.property()||this.property().nameId()==N.Universe10.LibraryBase.properties.types.name||this.property().nameId()==N.Universe10.LibraryBase.properties.schemas.name;if(!t&&null==this.parent()){var r=this.universe();r&&r.getOriginalTopLevelText()&&"AnnotationTypeDeclaration"==r.getOriginalTopLevelText()&&(t=!0)}this._ptype=D.parseTypeFromAST(this.name(),new j(this.lowLevel(),this),this.types(),!1,t,n)}this.property()&&P.isTypesProperty(this.property())&&this.parent()&&P.isApiType(this.parent().definition())&&this._ptype.putExtra&&this._ptype.putExtra(m.DEFINED_IN_TYPES_EXTRA,!0);var i=this._ptype;i.putExtra(m.USER_DEFINED_EXTRA,!0),this._ptype.putExtra(m.SOURCE_EXTRA,this)}return this._ptype},t.prototype.isParametrizedType=function(){var e=!1,t=this.attr(N.Universe10.TypeDeclaration.properties.type.name);if(t){var n=t.value();if("string"==typeof n&&n.indexOf("<<")>=0)for(var r=this.parent();null!=r;){if(P.isResourceTypeType(r.definition())||P.isTraitType(r.definition())){e=!0;break}r=r.parent()}}return e},t.prototype.localType=function(){return b.typeFromNode(this)},t.prototype.patchProp=function(e){this._prop=e},t.prototype.getKind=function(){return d.NodeKind.NODE},t.prototype.wrapperNode=function(){if(!this._wrapperNode){if(P.isExampleSpecType(this.definition())){var e=R.newMap([R.newMapping(R.newScalar("example"),this.lowLevel().actual())]),t=R.newMapping(R.newScalar("types"),R.newMap([R.newMapping(R.newScalar("__AUX_TYPE__"),e)])),n=R.newMap([t]),r=new _.ASTNode(n,this.lowLevel().unit(),null,null,null),i=D.parseFromAST(new j(r,this)),a=D.toNominal(i.types()[0],function(e){return null}),o=I.examplesFromNominal(a,this,!0,!1);return o[0]}this.children(),this._wrapperNode=this.buildWrapperNode()}return this._wrapperNode},t.prototype.asElement=function(){return this},t.prototype.buildWrapperNode=function(){var e=this.definition().universe().version();return"RAML10"==e?C.buildWrapperNode(this):"RAML08"==e?L.buildWrapperNode(this):null},t.prototype.propertiesAllowedToUse=function(){var e=this;return this.definition().allProperties().filter(function(t){return e.isAllowedToUse(t)})},t.prototype.isAllowedToUse=function(e){var t=this,n=!0;return e.getAdapter(w.RAMLPropertyService).isSystem()?!1:(e.getContextRequirements().forEach(function(e){if(-1!=e.name.indexOf("("))return!0;var r=t.computedValue(e.name);r?n=n&&r==e.value:e.value&&(n=!1)}),n)},t.prototype.allowRecursive=function(){return this.definition().getAdapter(w.RAMLService).isUserDefined()?!0:!1},t.prototype.setWrapperNode=function(e){this._wrapperNode=e},t.prototype.setAssociatedType=function(e){this._associatedDef=e},t.prototype.associatedType=function(){return this._associatedDef},t.prototype.knownIds=function(){return this.isAuxilary(),this._knownIds?this._knownIds:{}},t.prototype.findById=function(e){var t=this,n=this.root();if(n!=this)return n.findById(e);if(!this._knownIds){this._knownIds={};var r=A.allChildren(this);r.forEach(function(e){return t._knownIds[e.id()]=e})}if(this.isAuxilary()){if(!this._slaveIds){this._slaveIds={};var r=A.allChildren(this);r.forEach(function(e){return t._slaveIds[e.id()]=e})}var i=this._slaveIds[e];if(i)return i}return this._knownIds[e]},t.prototype.isAuxilary=function(){if(this._isAux)return!0;if(this._auxChecked)return!1;this._auxChecked=!0;var e=this.getMaster();return e?(this._isAux=!0,this.initilizeKnownIDs(e),!0):!1},t.prototype.initilizeKnownIDs=function(e){var t=this;this._knownIds={};var n=A.allChildren(e);n.forEach(function(e){return t._knownIds[e.id()]=e}),this._knownIds[""]=e},t.prototype.getMaster=function(){if(this.masterApi)return this.masterApi;var e=this.calculateMasterByRef();return e&&e.setSlave(this),e},t.prototype.overrideMaster=function(e){this.masterApi=e,this.resetAuxilaryState(),e&&e.setSlave(this)},t.prototype.setSlave=function(e){this.slave=e},t.prototype.setMergeMode=function(e){this.overlayMergeMode=e,this.resetAuxilaryState()},t.prototype.getMergeMode=function(){return this.overlayMergeMode},t.prototype.calculateMasterByRef=function(){var e=this.lowLevel().unit();if(!e)return null;var t=e.getMasterReferenceNode();if(!t||!t.value())return null;var n=this.lowLevel();if(n.master)return n.master;var r=t.value(),i=this.lowLevel().unit().project().resolve(this.lowLevel().unit().path(),r);if(!i)return null;var a=i.expandedHighLevel();return a.setMergeMode(this.overlayMergeMode),n.master=a,a},t.prototype.resetAuxilaryState=function(){this._isAux=!1,this._auxChecked=!1,this._knownIds=null,this.clearChildrenCache()},t.prototype.printDetails=function(e){var t="";e||(e="");var n=this.definition().nameId(),r=this.property()?this.property().range().nameId():"",i=this.property()?this.property().nameId():"";return t+=e+n+"["+r+"] <--- "+i+"\n",this.children().forEach(function(n){t+=n.printDetails(e+"	")}),t},t.prototype.testSerialize=function(e){var t="";e||(e="");var n=this.definition().nameId(),r=this.property()?this.property().nameId():"";return t+=e+n+" <-- "+r+"\n",this.children().forEach(function(n){n.testSerialize&&(t+=n.testSerialize(e+"  "))}),t},t.prototype.getExtractedChildren=function(){var e=this.root();if(e.isAuxilary()){if(e._knownIds){var t=e._knownIds[this.id()];if(t){var n=t.children();return n}}return[]}return[]},t.prototype.getMasterCounterPart=function(){var e=this.root();if(e.isAuxilary()){if(e._knownIds){var t=e._knownIds[this.id()];return t}return null}return null},t.prototype.getExtractedLowLevelChildren=function(e){var t=this.root();if(t.isAuxilary()){if(t._knownLowLevelIds){var n=t._knownLowLevelIds[this.id()];if(n)return n.children()}return[]}return[]},t.prototype.allowsQuestion=function(){return this._allowQuestion||this.definition().getAdapter(w.RAMLService).getAllowQuestion()},t.prototype.findReferences=function(){var e=this,t=[];A.refFinder(this.root(),this,t),t.length>1&&(t=t.filter(function(t){return t!=e&&t.parent()!=e}));var n=[];return t.forEach(function(e){h.find(n,function(t){return t==e})||n.push(e)}),n},t.prototype.setNamePatch=function(e){this._patchedName=e},t.prototype.isNamePatch=function(){return this._patchedName},t.prototype.name=function(){if(this._patchedName)return this._patchedName;var t=h.find(this.directChildren(),function(e){return e.property()&&e.property().getAdapter(w.RAMLPropertyService).isKey()});if(t&&B.isInstance(t)){var n=null,r=this.definition(),i=r.universe().version();if(r&&"RAML10"==i&&t.isFromKey()){var a=this._node.key();n=this._node.optional()?a+"?":a}else n=t.value();return n}return e.prototype.name.call(this)},t.prototype.findElementAtOffset=function(e){return this._findNode(this,e,e)},t.prototype.isElement=function(){return!0},t.prototype.universe=function(){return this._universe?this._universe:this.definition().universe()},t.prototype.setUniverse=function(e){this._universe=e},t.prototype._findNode=function(e,t,n){var r=this;if(null==e)return null;if(e.lowLevel()&&e.lowLevel().start()<=t&&e.lowLevel().end()>=n){var i=e;return e.elements().forEach(function(a){if(a.lowLevel().unit()==e.lowLevel().unit()){var o=r._findNode(a,t,n);o&&(i=o)}}),i}return null},t.prototype.isStub=function(){return!this.lowLevel().unit()||this.lowLevel().unit().isStubUnit()},t.prototype.add=function(e){S.addToNode(this,e)},t.prototype.remove=function(e){S.removeNodeFrom(this,e)},t.prototype.dump=function(e){return this._node.dump()},t.prototype.patchType=function(e){this._def=e;this._associatedDef;this._associatedDef=null,this._children=null,this._mergedChildren=null},t.prototype.children=function(){var e=this.lowLevel();return e&&e.isValueInclude&&e.isValueInclude()&&O.isWaitingFor(e.includePath())?(this._children=null,[]):this._children?this._mergedChildren?this._mergedChildren:(this._mergedChildren=this.mergeChildren(this._children,this.getExtractedChildren()),this._mergedChildren):this._node?(this._children=K.process(this,this._node.children()),this._children=this._children.filter(function(e){return null!=e}),this.mergeChildren(this._children,this.getExtractedChildren())):[]},t.prototype.mergeChildren=function(e,t){var n=this,r=this.root();if(r.overlayMergeMode==V.AGGREGATE)return e.concat(t);if(r.overlayMergeMode==V.MERGE){var i=[];return e.forEach(function(e){var r=h.find(t,function(t){return t.fullLocalId()==e.fullLocalId()});r?n.mergeChild(i,e,r):i.push(e)}),t.forEach(function(t){var n=h.find(e,function(e){return t.fullLocalId()==e.fullLocalId()});n||i.push(t)}),i}return null},t.prototype.mergeLowLevelChildren=function(e,t){var n=this,r=this.root();if(r.overlayMergeMode==V.AGGREGATE)return e.concat(t);if(r.overlayMergeMode==V.MERGE){var i=[];return e.forEach(function(e){var r=h.find(t,function(t){return t.key()==e.key()});r?n.mergeLowLevelChild(i,e,r):i.push(e)}),t.forEach(function(t){var n=h.find(e,function(e){return t.key()==e.key()});n||i.push(t)}),i}return null},t.prototype.mergeLowLevelChild=function(e,t,n){return t.kind()!=n.kind()?(e.push(t),void e.push(n)):void e.push(t)},t.prototype.mergeChild=function(e,t,n){return t.getKind()!=n.getKind()?(e.push(t),void e.push(n)):t.getKind()==d.NodeKind.NODE?void e.push(t):t.getKind()==d.NodeKind.ATTRIBUTE?void e.push(t):t.getKind()==d.NodeKind.BASIC?(e.push(t),void e.push(n)):void 0},t.prototype.directChildren=function(){return this._children?this._children:this._node?(this._children=K.process(this,this._node.children()),this._children):[]},t.prototype.resetChildren=function(){this._children=null,this._mergedChildren=null},t.prototype.isEmptyRamlFile=function(){var e=this.lowLevel().root();return e.isScalar()},t.prototype.initRamlFile=function(){S.initEmptyRAMLFile(this)},t.prototype.createAttr=function(e,t){S.createAttr(this,e,t)},t.prototype.isAttr=function(){return!1},t.prototype.isUnknown=function(){return!1},t.prototype.value=function(){return this._node.value()},t.prototype.valuesOf=function(e){var t=this._def.property(e);return null!=t?this.elements().filter(function(e){return e.property()==t}):[]},t.prototype.attr=function(e){return h.find(this.attrs(),function(t){return t.name()==e})},t.prototype.attrOrCreate=function(e){var t=this.attr(e);return t||this.createAttr(e,""),this.attr(e)},t.prototype.attrValue=function(e){var t=this.attr(e);return t?t.value():null},t.prototype.attributes=function(e){return h.filter(this.attrs(),function(t){return t.name()==e})},t.prototype.attrs=function(){var e=this.children().filter(function(e){return e.isAttr()});if(this._patchedName){var t=h.find(this.definition().allProperties(),function(e){return e.getAdapter(w.RAMLPropertyService).isKey()});if(t){var n=new B(this.lowLevel(),this,t.range(),t,!0);return n._value=this._patchedName,[n].concat(e)}}return e},t.prototype.elements=function(){return this.children().filter(function(e){return!e.isAttr()&&!e.isUnknown()})},t.prototype.element=function(e){var t=this.elementsOfKind(e);return t.length>0?t[0]:null},t.prototype.elementsOfKind=function(e){var t=this.elements().filter(function(t){return t.property().nameId()==e});return t},t.prototype.definition=function(){return this._def},t.prototype.property=function(){return this._prop},t.prototype.isExpanded=function(){return this._expanded},t.prototype.copy=function(){return new t(this.lowLevel().copy(),this.parent(),this.definition(),this.property())},t.prototype.clearChildrenCache=function(){this._children=null,this._mergedChildren=null},t.prototype.optionalProperties=function(){var e=this.definition();if(null==e)return[];var t=[],n={},r=this.lowLevel().children();r.forEach(function(e){e.optional()&&(n[e.key()]=!0)});var i=e.allProperties();return i.forEach(function(e){var r=e;n[r.nameId()]&&t.push(r.nameId())}),t},t.CLASS_IDENTIFIER_ASTNodeImpl="highLevelImpl.ASTNodeImpl",t}(k);t.ASTNodeImpl=q,t.universeProvider=n(36);var Y=function(e,n){var r=i(e),a=r&&r[1]||"",o=r&&r.length>2&&r[2]||"Api",s=r&&r.length>2&&r[2],u="1.0"==a?new v.Universe(null,"RAML10",t.universeProvider("RAML10"),"RAML10"):new v.Universe(null,"RAML08",t.universeProvider("RAML08"));return"API"==o?o="Api":"NamedExample"==o?o="ExampleSpec":"DataType"==o?o="TypeDeclaration":"SecurityScheme"==o?o="AbstractSecurityScheme":"AnnotationTypeDeclaration"==o&&(o="TypeDeclaration"),u.setOriginalTopLevelText(s),u.setTopLevel(o),u.setTypedVersion(a),{ptype:o,localUniverse:u}};t.ramlFirstLine=i,t.getFragmentDefenitionName=a,t.fromUnit=o,t.createBasicValidationAcceptor=s,t.isAnnotationTypeFragment=u;var H=function(){function e(e){this._node=e}return e.prototype.kind=function(){return"AnnotatedNode"},e.prototype.annotationsMap=function(){var e=this;return this._annotationsMap||(this._annotationsMap={},this.annotations().forEach(function(t){var n=t.name(),r=n.lastIndexOf(".");r>=0&&(n=n.substring(r+1)),e._annotationsMap[n]=t})),this._annotationsMap},e.prototype.annotations=function(){if(!this._annotations){var e=[];this._node.isElement()?e=this._node.asElement().attributes(v.universesInfo.Universe10.Annotable.properties.annotations.name):this._node.isAttr()&&(e=this._node.asAttr().annotations()),this._annotations=e.map(function(e){return new $(e)})}return this._annotations},e.prototype.value=function(){if(this._node.isElement())return this._node.asElement().wrapperNode().toJSON();if(this._node.isAttr()){var e=this._node.asAttr().value();return F.isInstance(e)?e.lowLevel().dump():e}return this._node.lowLevel().dump()},e.prototype.name=function(){return this._node.name()},e.prototype.entry=function(){return this._node},e}();t.AnnotatedNode=H;var $=function(){function e(e){this.attr=e}return e.prototype.name=function(){return this.attr.value().valueName()},e.prototype.value=function(){var e=this.attr.value();if(F.isInstance(e)){var t=e.lowLevel().dumpToObject(),n=Object.keys(t)[0];return t[n]}return e},e.prototype.definition=function(){var e=this.attr.parent(),t=this.name(),n=A.referenceTargets(this.attr.property(),e).filter(function(n){return r(n,e)==t});return 0==n.length?null:n[0].parsedType()},e}();t.AnnotationInstance=$,t.applyNodeValidationPlugins=p,t.applyNodeAnnotationValidationPlugins=c},function(e,t,n){"use strict";var r=n(37);e.exports=r.universesInfo},function(e,t,n){"use strict";var r=n(64),i=n(40),a=n(22),o=function(){function e(){}return e.prototype.generateText=function(e){var t=this,n=JSON.parse(e),r=n.items;if(!r)return"";var i="",a=r instanceof Array?r:[r];return i+="types:\n",a.forEach(function(e){i+="  - "+e.title+":\n",i+=t.generateObj(e,3)}),i},e.prototype.generateObj=function(e,t){var n="";if(n+=i.indent(t,"type: "+e.type)+"\n",e.properties){n+=i.indent(t,"properties:\n");for(var r in e.properties){var a=e.properties[r];n+=i.indent(t+1,r+":\n"),n+="object"==a.type?this.generateObj(a,t+2):i.indent(t+2,"type: "+a.type)+"\n"}return n}},e.prototype.generateTo=function(e,t,n){var r=this,i=JSON.parse(t),o=i.items;if(o){var s=o instanceof Array?o:[o],u=[];return s.forEach(function(t){var n=new a.ObjectTypeDeclarationImpl(t.title);r.generateObjTo(n,t),new a.BasicSecuritySchemeImpl(e).addToProp(n,"types"),u.push(t.title)}),u}i.title&&(n=i.title);var l=new a.ObjectTypeDeclarationImpl(n);return this.generateObjTo(l,i),new a.BasicSecuritySchemeImpl(e).addToProp(l,"types"),[n]},e.prototype.generateObjTo=function(e,t){if(e.setType(t.type),t.properties)for(var n in t.properties){var r=t.properties[n],i=this.makeTypeField(n,r);"array"==r.type,e.addToProp(i,"properties")}},e.prototype.makeTypeField=function(e,t){var n=this.makeType(e,t.type);if(t.type&&n.setType(t.type),"number"==t.type){var r=n;void 0!=t.minimum&&r.setMinimum(t.minimum),void 0!=t.maximum&&r.setMaximum(t.maximum)}if("array"==t.type){var i=t.items.type;n.setType(i+"[]");var a=n;void 0!=t.minItems&&a.setMinItems(t.minItems),void 0!=t.maxItems&&a.setMaxItems(t.maxItems),void 0!=t.uniqueItems&&a.setUniqueItems(t.uniqueItems)}return"object"==t.type&&this.generateObjTo(n,t),n},e.prototype.makeType=function(e,t){return"number"==t?new a.NumberTypeDeclarationImpl(e):"string"==t?new a.StringTypeDeclarationImpl(e):"array"==t?new a.ArrayTypeDeclarationImpl(e):new a.ObjectTypeDeclarationImpl(e)},e.prototype.generateItemsTo=function(e,t){var n=t.items;if(n){var r=n instanceof Array?n:[n];r.forEach(function(e){})}},e}();t.SchemaToModelGenerator=o;var s=function(){function e(){}return e.prototype.generateSchema=function(e){var t=this.generateType(e);return t.$schema="http://json-schema.org/draft-04/schema#",t},e.prototype.isSimpleType=function(e){return"string"==e||"number"==e||"boolean"==e||"object"==e},e.prototype.generateType=function(e){var t=this.allTypes(e),n={};n.title=e.attrValue("name");if(e.attrValue("type")){var i=e.attributes("type"),a=!1,o=!1;for(var s in i){var u=i[s].value(),l=i[s].lowLevel();if(n.type="",l.isValueInclude()){var p=JSON.parse(u);n.type="object",n.properties=p.properties}else if(this.isSimpleType(u)){if(n.type=u,o=!0,a)throw new Error("couldn't mix user defined and basic types in inheritance")}else{var c=this.resolveType(e,u);if(c){var f=this.generateTypeExp(u,t);if(n.properties?r.extend(n.properties,f.properties):n.properties=f.properties,n.type="object",a=!0,o)throw new Error("couldn't mix user defined and basic types in inheritance")}else{var f=this.generateTypeExp(u,t);n.type="object",a=!0,f.anyOf&&(n.anyOf=f.anyOf)}}}}else n.type="object";var m=this.generateProperties(e);return n.properties?r.extend(n.properties,m):n.properties=m,n},e.prototype.makeUnion=function(e,t){var n=this,r=[];return e.forEach(function(e){e=e.trim(),t[e]?r.push({type:"object",properties:n.generateType(t[e]).properties}):r.push({type:e})}),r},e.prototype.generateTypeExp=function(e,t){var n={};if(i.endsWith(e,"[]"))n.type="array",n.items={type:e.substring(0,e.length-2)};else if(e.indexOf("|")>0){var r=e.split("|");n.anyOf=this.makeUnion(r,t)}else if(t[e]){var a=this.generateType(t[e]);n.type="object",n.properties=a.properties}else n.type=e;return n},e.prototype.allTypes=function(e){var t=e.root(),n=t.elementsOfKind("types"),r={};return n.forEach(function(e){r[e.name()]=e}),r},e.prototype.resolveType=function(e,t){var n=this.allTypes(e);return n[t]},e.prototype.generateProperty=function(e,t){var n=this,i=this.allTypes(e),a={},o=e.definition().allProperties();o.forEach(function(t){if("name"!=t.nameId()){var o=e.attrValue(t.nameId());if(null!=o&&void 0!=o&&"undefined"!=o)if("type"==t.nameId()){var s=n.generateTypeExp(o,i);r.extend(a,s)}else if("enum"==t.nameId()){var u=e.attributes("enum"),l=u.map(function(e){return e.value()});a["enum"]=l}else a[t.nameId()]=o}}),t&&(a.required=!1);var s=(e.elements(),this.generateProperties(e));return Object.getOwnPropertyNames(s).length>0&&(a.properties=s),a},e.prototype.generateProperties=function(e){var t=this,n={},r=e.elements(),i=!0;return r.forEach(function(e){var r=e.attrValue("name");if("string"==typeof r){r=r.trim();var a=e.optional();n[r]=t.generateProperty(e,a),i=!1}}),n},e}();t.ModelToSchemaGenerator=s},function(e,t,n){"use strict";function r(e,t,n){var r=e.definition().property(t);if(!r)return null;var i=r.range(),a=m(i,r,n);return a}function i(e,t,n,r){var i=y.newMap(n.map(function(e){return y.newMapping(y.newScalar(e.key),y.newScalar(e.value))})),a=new d.ASTNode(i,r?r.lowLevel().unit():null,r?r.lowLevel():null,null,null);return new h.StructuredValue(a,r,r?r.definition().property(e):null,t)}function a(e,t,n){var r=e.definition().property(t);if(!r)return null;var i=r.range(),a=e.lowLevel().unit().stub(),o=m(i,r,n,a);return o.isInEdit=!0,o.lowLevel()._unit=a,o._parent=e.copy(),o._parent.lowLevel()._unit=a,o}function o(e,t){return a(e,"resources",t)}function s(e,t){return a(e,"methods",t)}function u(e,t){return a(e,"responses",t)}function l(e,t){return a(e,"body",t)}function p(e,t){return a(e,"uriParameters",t)}function c(e,t){return a(e,"queryParameters",t)}function f(e,t){var n=d.createMapping(e.nameId(),t),r=new h.ASTPropImpl(n,null,e.range(),e);return r}function m(e,t,n,r){void 0===n&&(n=null);var i=d.createNode(n?n:"key",null,r),a=new h.ASTNodeImpl(i,null,e,t);return i.unit()||(i._unit=r),a.children(),a}var d=n(26),h=n(16),y=n(75);t.createStub0=r,t.genStructuredValue=i,t.createStub=a,t.createResourceStub=o,t.createMethodStub=s,t.createResponseStub=u,t.createBodyStub=l,t.createUriParameterStub=p,t.createQueryParameterStub=c,t.createAttr=f,t.createStubNode=m},function(e,t,n){"use strict";function r(e){return new u.TypeDeclarationImpl(e)}function i(e){return new u.ObjectTypeDeclarationImpl(e)}function a(e,t){e.setSchema(t)}function o(e,t){var n=(l.getUniverse("RAML10").type(l.universesInfo.Universe10.ExampleSpec.name),l.universesInfo.Universe10.TypeDeclaration.properties.example.name),r=e.highLevel(),i=r.lowLevel(),a=r.children().filter(function(e){return e.lowLevel().key()==n}),o=p.createNode(n);c.setAttr(o,t),a.length>0&&(c.removeNode(i,a[0].lowLevel()),a[0]._node=o,c.insertNode(i,o)),r.createAttr&&r.createAttr(n,t)}function s(e,t){e.add(t)}var u=n(22),l=n(37),p=n(26),c=n(10);t.createTypeDeclaration=r,t.createObjectTypeDeclaration=i,t.setTypeDeclarationSchema=a,t.setTypeDeclarationExample=o,t.addChild=s},function(e,t,n){!function(t){function n(){}function r(e,t){return function(){e.apply(t,arguments)}}function i(e){if("object"!=typeof this)throw new TypeError("Promises must be constructed via new");if("function"!=typeof e)throw new TypeError("not a function");this._state=0,this._handled=!1,this._value=void 0,this._deferreds=[],p(e,this)}function a(e,t){for(;3===e._state;)e=e._value;return 0===e._state?void e._deferreds.push(t):(e._handled=!0,void f(function(){var n=1===e._state?t.onFulfilled:t.onRejected;if(null===n)return void(1===e._state?o:s)(t.promise,e._value);var r;try{r=n(e._value)}catch(i){return void s(t.promise,i)}o(t.promise,r)}))}function o(e,t){try{if(t===e)throw new TypeError("A promise cannot be resolved with itself.");if(t&&("object"==typeof t||"function"==typeof t)){var n=t.then;if(t instanceof i)return e._state=3,e._value=t,void u(e);if("function"==typeof n)return void p(r(n,t),e)}e._state=1,e._value=t,u(e)}catch(a){s(e,a)}}function s(e,t){e._state=2,e._value=t,u(e)}function u(e){2===e._state&&0===e._deferreds.length&&f(function(){e._handled||m(e._value)});for(var t=0,n=e._deferreds.length;n>t;t++)a(e,e._deferreds[t]);e._deferreds=null}function l(e,t,n){this.onFulfilled="function"==typeof e?e:null,this.onRejected="function"==typeof t?t:null,this.promise=n}function p(e,t){var n=!1;try{e(function(e){n||(n=!0,o(t,e))},function(e){n||(n=!0,s(t,e))})}catch(r){if(n)return;n=!0,s(t,r)}}var c=setTimeout,f="function"==typeof setImmediate&&setImmediate||function(e){c(e,0)},m=function(e){"undefined"!=typeof console&&console&&console.warn("Possible Unhandled Promise Rejection:",e)};i.prototype["catch"]=function(e){return this.then(null,e)},i.prototype.then=function(e,t){var r=new this.constructor(n);return a(this,new l(e,t,r)),r},i.all=function(e){var t=Array.prototype.slice.call(e);return new i(function(e,n){function r(a,o){try{if(o&&("object"==typeof o||"function"==typeof o)){var s=o.then;if("function"==typeof s)return void s.call(o,function(e){r(a,e)},n)}t[a]=o,0===--i&&e(t)}catch(u){n(u)}}if(0===t.length)return e([]);for(var i=t.length,a=0;a<t.length;a++)r(a,t[a])})},i.resolve=function(e){return e&&"object"==typeof e&&e.constructor===i?e:new i(function(t){t(e)})},i.reject=function(e){return new i(function(t,n){n(e)})},i.race=function(e){return new i(function(t,n){for(var r=0,i=e.length;i>r;r++)e[r].then(t,n)})},i._setImmediateFn=function(e){f=e},i._setUnhandledRejectionFn=function(e){m=e},"undefined"!=typeof e&&e.exports?e.exports=i:t.Promise||(t.Promise=i)}(this)},function(e,t,n){"use strict";function r(e){var t=J.getUniverse("RAML10"),n=t.type("Api"),r=z.createStubNode(n,null,e);return r}function i(e){var t=J.getUniverse("RAML10"),n=t.type("LibraryBase"),r=z.createStubNode(n,null,e);return r}function a(e){var t=J.getUniverse("RAML10"),n=t.type("FragmentDeclaration"),r=z.createStubNode(n,null,e);return r}function o(e){var t=J.getUniverse("RAML10"),n=t.type("Trait"),r=z.createStubNode(n,null,e);return r}function s(e){var t=J.getUniverse("RAML10"),n=t.type("MethodBase"),r=z.createStubNode(n,null,e);return r}function u(e){var t=J.getUniverse("RAML10"),n=t.type("Operation"),r=z.createStubNode(n,null,e);return r}function l(e){var t=J.getUniverse("RAML10"),n=t.type("TypeDeclaration"),r=z.createStubNode(n,null,e);return r}function p(e){var t=J.getUniverse("RAML10"),n=t.type("UsesDeclaration"),r=z.createStubNode(n,null,e);return r}function c(e){var t=J.getUniverse("RAML10"),n=t.type("XMLFacetInfo"),r=z.createStubNode(n,null,e);return r}function f(e){var t=J.getUniverse("RAML10"),n=t.type("ArrayTypeDeclaration"),r=z.createStubNode(n,null,e);return r}function m(e){var t=J.getUniverse("RAML10"),n=t.type("UnionTypeDeclaration"),r=z.createStubNode(n,null,e);return r}function d(e){var t=J.getUniverse("RAML10"),n=t.type("ObjectTypeDeclaration"),r=z.createStubNode(n,null,e);return r}function h(e){var t=J.getUniverse("RAML10"),n=t.type("StringTypeDeclaration"),r=z.createStubNode(n,null,e);return r}function y(e){var t=J.getUniverse("RAML10"),n=t.type("BooleanTypeDeclaration"),r=z.createStubNode(n,null,e);return r}function v(e){var t=J.getUniverse("RAML10"),n=t.type("NumberTypeDeclaration"),r=z.createStubNode(n,null,e);return r}function g(e){var t=J.getUniverse("RAML10"),n=t.type("IntegerTypeDeclaration"),r=z.createStubNode(n,null,e);return r}function A(e){var t=J.getUniverse("RAML10"),n=t.type("DateOnlyTypeDeclaration"),r=z.createStubNode(n,null,e);return r}function S(e){var t=J.getUniverse("RAML10"),n=t.type("TimeOnlyTypeDeclaration"),r=z.createStubNode(n,null,e);return r}function T(e){var t=J.getUniverse("RAML10"),n=t.type("DateTimeOnlyTypeDeclaration"),r=z.createStubNode(n,null,e);return r}function E(e){var t=J.getUniverse("RAML10"),n=t.type("DateTimeTypeDeclaration"),r=z.createStubNode(n,null,e);return r}function b(e){var t=J.getUniverse("RAML10"),n=t.type("FileTypeDeclaration"),r=z.createStubNode(n,null,e);return r}function N(e){var t=J.getUniverse("RAML10"),n=t.type("Response"),r=z.createStubNode(n,null,e);return r}function _(e){var t=J.getUniverse("RAML10"),n=t.type("SecuritySchemePart"),r=z.createStubNode(n,null,e);return r}function M(e){var t=J.getUniverse("RAML10"),n=t.type("AbstractSecurityScheme"),r=z.createStubNode(n,null,e);return r}function w(e){var t=J.getUniverse("RAML10"),n=t.type("SecuritySchemeSettings"),r=z.createStubNode(n,null,e);return r}function R(e){var t=J.getUniverse("RAML10"),n=t.type("OAuth1SecuritySchemeSettings"),r=z.createStubNode(n,null,e);return r}function I(e){var t=J.getUniverse("RAML10"),n=t.type("OAuth2SecuritySchemeSettings"),r=z.createStubNode(n,null,e);return r}function C(e){var t=J.getUniverse("RAML10"),n=t.type("OAuth2SecurityScheme"),r=z.createStubNode(n,null,e);return r}function L(e){var t=J.getUniverse("RAML10"),n=t.type("OAuth1SecurityScheme"),r=z.createStubNode(n,null,e);return r}function P(e){var t=J.getUniverse("RAML10"),n=t.type("PassThroughSecurityScheme"),r=z.createStubNode(n,null,e);return r}function O(e){var t=J.getUniverse("RAML10"),n=t.type("BasicSecurityScheme"),r=z.createStubNode(n,null,e);return r}function D(e){var t=J.getUniverse("RAML10"),n=t.type("DigestSecurityScheme"),r=z.createStubNode(n,null,e);return r}function x(e){var t=J.getUniverse("RAML10"),n=t.type("CustomSecurityScheme"),r=z.createStubNode(n,null,e);return r}function U(e){var t=J.getUniverse("RAML10"),n=t.type("Method"),r=z.createStubNode(n,null,e);return r}function k(e){var t=J.getUniverse("RAML10"),n=t.type("ResourceType"),r=z.createStubNode(n,null,e);return r}function F(e){var t=J.getUniverse("RAML10"),n=t.type("ResourceBase"),r=z.createStubNode(n,null,e);return r}function B(e){var t=J.getUniverse("RAML10"),n=t.type("Resource"),r=z.createStubNode(n,null,e);return r}function K(e){var t=J.getUniverse("RAML10"),n=t.type("DocumentationItem"),r=z.createStubNode(n,null,e);return r}function V(e){var t=J.getUniverse("RAML10"),n=t.type("Library"),r=z.createStubNode(n,null,e);return r}function j(e){var t=J.getUniverse("RAML10"),n=t.type("Overlay"),r=z.createStubNode(n,null,e);return r}function W(e){var t=J.getUniverse("RAML10"),n=t.type("Extension"),r=z.createStubNode(n,null,e);return r}function q(e,t,n){return Z.loadApi(e,t,n).getOrElse(null)}function Y(e,t,n){return Z.loadApi(e,t,n).getOrElse(null)}function H(e,t,n){return Z.loadApiAsync(e,t,n)}function $(e,t,n){return Z.loadRAMLAsync(e,t,n)}function G(e){return Z.getLanguageElementByRuntimeType(e)}var X=this&&this.__extends||function(e,t){function n(){this.constructor=e}for(var r in t)t.hasOwnProperty(r)&&(e[r]=t[r]);e.prototype=null===t?Object.create(t):(n.prototype=t.prototype,new n)},z=n(19),J=n(37),Q=n(47),Z=n(8),ee=n(34),te=function(e){function t(){e.apply(this,arguments)}return X(t,e),t.prototype.annotations=function(){return e.prototype.attributes.call(this,"annotations",function(e){return new Ct(e)})},t.prototype.wrapperClassName=function(){return"AnnotableImpl"},t.prototype.kind=function(){return"Annotable"},t.prototype.allKinds=function(){return e.prototype.allKinds.call(this).concat("Annotable")},t.prototype.allWrapperClassNames=function(){return e.prototype.allWrapperClassNames.call(this).concat("RAML10.AnnotableImpl");
},t.isInstance=function(e){if(null!=e&&e.allWrapperClassNames&&"function"==typeof e.allWrapperClassNames)for(var t=0,n=e.allWrapperClassNames();t<n.length;t++){var r=n[t];if("RAML10.AnnotableImpl"==r)return!0}return!1},t.prototype.RAMLVersion=function(){return"RAML10"},t}(Q.BasicNodeImpl);t.AnnotableImpl=te;var ne=function(e){function t(){e.apply(this,arguments)}return X(t,e),t.prototype.wrapperClassName=function(){return"ValueTypeImpl"},t.prototype.kind=function(){return"ValueType"},t.prototype.allKinds=function(){return e.prototype.allKinds.call(this).concat("ValueType")},t.prototype.allWrapperClassNames=function(){return e.prototype.allWrapperClassNames.call(this).concat("undefined.ValueTypeImpl")},t.isInstance=function(e){if(null!=e&&e.allWrapperClassNames&&"function"==typeof e.allWrapperClassNames)for(var t=0,n=e.allWrapperClassNames();t<n.length;t++){var r=n[t];if("undefined.ValueTypeImpl"==r)return!0}return!1},t.prototype.RAMLVersion=function(){return"undefined"},t.prototype.value=function(){return this.attr.value()},t}(Q.AttributeNodeImpl);t.ValueTypeImpl=ne;var re=function(e){function t(){e.apply(this,arguments)}return X(t,e),t.prototype.wrapperClassName=function(){return"StringTypeImpl"},t.prototype.kind=function(){return"StringType"},t.prototype.allKinds=function(){return e.prototype.allKinds.call(this).concat("StringType")},t.prototype.allWrapperClassNames=function(){return e.prototype.allWrapperClassNames.call(this).concat("RAML10.StringTypeImpl")},t.isInstance=function(e){if(null!=e&&e.allWrapperClassNames&&"function"==typeof e.allWrapperClassNames)for(var t=0,n=e.allWrapperClassNames();t<n.length;t++){var r=n[t];if("RAML10.StringTypeImpl"==r)return!0}return!1},t.prototype.RAMLVersion=function(){return"RAML10"},t.prototype.value=function(){return this.attr.value()},t}(ne);t.StringTypeImpl=re;var ie=function(e){function t(){e.apply(this,arguments)}return X(t,e),t.prototype.wrapperClassName=function(){return"UriTemplateImpl"},t.prototype.kind=function(){return"UriTemplate"},t.prototype.allKinds=function(){return e.prototype.allKinds.call(this).concat("UriTemplate")},t.prototype.allWrapperClassNames=function(){return e.prototype.allWrapperClassNames.call(this).concat("RAML10.UriTemplateImpl")},t.isInstance=function(e){if(null!=e&&e.allWrapperClassNames&&"function"==typeof e.allWrapperClassNames)for(var t=0,n=e.allWrapperClassNames();t<n.length;t++){var r=n[t];if("RAML10.UriTemplateImpl"==r)return!0}return!1},t.prototype.RAMLVersion=function(){return"RAML10"},t}(re);t.UriTemplateImpl=ie;var ae=function(e){function t(){e.apply(this,arguments)}return X(t,e),t.prototype.wrapperClassName=function(){return"RelativeUriStringImpl"},t.prototype.kind=function(){return"RelativeUriString"},t.prototype.allKinds=function(){return e.prototype.allKinds.call(this).concat("RelativeUriString")},t.prototype.allWrapperClassNames=function(){return e.prototype.allWrapperClassNames.call(this).concat("RAML10.RelativeUriStringImpl")},t.isInstance=function(e){if(null!=e&&e.allWrapperClassNames&&"function"==typeof e.allWrapperClassNames)for(var t=0,n=e.allWrapperClassNames();t<n.length;t++){var r=n[t];if("RAML10.RelativeUriStringImpl"==r)return!0}return!1},t.prototype.RAMLVersion=function(){return"RAML10"},t}(ie);t.RelativeUriStringImpl=ae;var oe=function(e){function t(){e.apply(this,arguments)}return X(t,e),t.prototype.wrapperClassName=function(){return"FullUriTemplateStringImpl"},t.prototype.kind=function(){return"FullUriTemplateString"},t.prototype.allKinds=function(){return e.prototype.allKinds.call(this).concat("FullUriTemplateString")},t.prototype.allWrapperClassNames=function(){return e.prototype.allWrapperClassNames.call(this).concat("RAML10.FullUriTemplateStringImpl")},t.isInstance=function(e){if(null!=e&&e.allWrapperClassNames&&"function"==typeof e.allWrapperClassNames)for(var t=0,n=e.allWrapperClassNames();t<n.length;t++){var r=n[t];if("RAML10.FullUriTemplateStringImpl"==r)return!0}return!1},t.prototype.RAMLVersion=function(){return"RAML10"},t}(ie);t.FullUriTemplateStringImpl=oe;var se=function(e){function t(){e.apply(this,arguments)}return X(t,e),t.prototype.wrapperClassName=function(){return"StatusCodeStringImpl"},t.prototype.kind=function(){return"StatusCodeString"},t.prototype.allKinds=function(){return e.prototype.allKinds.call(this).concat("StatusCodeString")},t.prototype.allWrapperClassNames=function(){return e.prototype.allWrapperClassNames.call(this).concat("RAML10.StatusCodeStringImpl")},t.isInstance=function(e){if(null!=e&&e.allWrapperClassNames&&"function"==typeof e.allWrapperClassNames)for(var t=0,n=e.allWrapperClassNames();t<n.length;t++){var r=n[t];if("RAML10.StatusCodeStringImpl"==r)return!0}return!1},t.prototype.RAMLVersion=function(){return"RAML10"},t}(re);t.StatusCodeStringImpl=se;var ue=function(e){function t(){e.apply(this,arguments)}return X(t,e),t.prototype.wrapperClassName=function(){return"FixedUriStringImpl"},t.prototype.kind=function(){return"FixedUriString"},t.prototype.allKinds=function(){return e.prototype.allKinds.call(this).concat("FixedUriString")},t.prototype.allWrapperClassNames=function(){return e.prototype.allWrapperClassNames.call(this).concat("RAML10.FixedUriStringImpl")},t.isInstance=function(e){if(null!=e&&e.allWrapperClassNames&&"function"==typeof e.allWrapperClassNames)for(var t=0,n=e.allWrapperClassNames();t<n.length;t++){var r=n[t];if("RAML10.FixedUriStringImpl"==r)return!0}return!1},t.prototype.RAMLVersion=function(){return"RAML10"},t}(re);t.FixedUriStringImpl=ue;var le=function(e){function t(){e.apply(this,arguments)}return X(t,e),t.prototype.wrapperClassName=function(){return"ContentTypeImpl"},t.prototype.kind=function(){return"ContentType"},t.prototype.allKinds=function(){return e.prototype.allKinds.call(this).concat("ContentType")},t.prototype.allWrapperClassNames=function(){return e.prototype.allWrapperClassNames.call(this).concat("RAML10.ContentTypeImpl")},t.isInstance=function(e){if(null!=e&&e.allWrapperClassNames&&"function"==typeof e.allWrapperClassNames)for(var t=0,n=e.allWrapperClassNames();t<n.length;t++){var r=n[t];if("RAML10.ContentTypeImpl"==r)return!0}return!1},t.prototype.RAMLVersion=function(){return"RAML10"},t}(re);t.ContentTypeImpl=le;var pe=function(e){function t(){e.apply(this,arguments)}return X(t,e),t.prototype.wrapperClassName=function(){return"MarkdownStringImpl"},t.prototype.kind=function(){return"MarkdownString"},t.prototype.allKinds=function(){return e.prototype.allKinds.call(this).concat("MarkdownString")},t.prototype.allWrapperClassNames=function(){return e.prototype.allWrapperClassNames.call(this).concat("RAML10.MarkdownStringImpl")},t.isInstance=function(e){if(null!=e&&e.allWrapperClassNames&&"function"==typeof e.allWrapperClassNames)for(var t=0,n=e.allWrapperClassNames();t<n.length;t++){var r=n[t];if("RAML10.MarkdownStringImpl"==r)return!0}return!1},t.prototype.RAMLVersion=function(){return"RAML10"},t}(re);t.MarkdownStringImpl=pe;var ce=function(e){function t(){e.apply(this,arguments)}return X(t,e),t.prototype.wrapperClassName=function(){return"SchemaStringImpl"},t.prototype.kind=function(){return"SchemaString"},t.prototype.allKinds=function(){return e.prototype.allKinds.call(this).concat("SchemaString")},t.prototype.allWrapperClassNames=function(){return e.prototype.allWrapperClassNames.call(this).concat("RAML10.SchemaStringImpl")},t.isInstance=function(e){if(null!=e&&e.allWrapperClassNames&&"function"==typeof e.allWrapperClassNames)for(var t=0,n=e.allWrapperClassNames();t<n.length;t++){var r=n[t];if("RAML10.SchemaStringImpl"==r)return!0}return!1},t.prototype.RAMLVersion=function(){return"RAML10"},t}(re);t.SchemaStringImpl=ce;var fe=function(e){function t(){e.apply(this,arguments)}return X(t,e),t.prototype.wrapperClassName=function(){return"MimeTypeImpl"},t.prototype.kind=function(){return"MimeType"},t.prototype.allKinds=function(){return e.prototype.allKinds.call(this).concat("MimeType")},t.prototype.allWrapperClassNames=function(){return e.prototype.allWrapperClassNames.call(this).concat("RAML10.MimeTypeImpl")},t.isInstance=function(e){if(null!=e&&e.allWrapperClassNames&&"function"==typeof e.allWrapperClassNames)for(var t=0,n=e.allWrapperClassNames();t<n.length;t++){var r=n[t];if("RAML10.MimeTypeImpl"==r)return!0}return!1},t.prototype.RAMLVersion=function(){return"RAML10"},t}(re);t.MimeTypeImpl=fe;var me=function(e){function t(){e.apply(this,arguments)}return X(t,e),t.prototype.wrapperClassName=function(){return"AnyTypeImpl"},t.prototype.kind=function(){return"AnyType"},t.prototype.allKinds=function(){return e.prototype.allKinds.call(this).concat("AnyType")},t.prototype.allWrapperClassNames=function(){return e.prototype.allWrapperClassNames.call(this).concat("RAML10.AnyTypeImpl")},t.isInstance=function(e){if(null!=e&&e.allWrapperClassNames&&"function"==typeof e.allWrapperClassNames)for(var t=0,n=e.allWrapperClassNames();t<n.length;t++){var r=n[t];if("RAML10.AnyTypeImpl"==r)return!0}return!1},t.prototype.RAMLVersion=function(){return"RAML10"},t}(ne);t.AnyTypeImpl=me;var de=function(e){function t(){e.apply(this,arguments)}return X(t,e),t.prototype.wrapperClassName=function(){return"NumberTypeImpl"},t.prototype.kind=function(){return"NumberType"},t.prototype.allKinds=function(){return e.prototype.allKinds.call(this).concat("NumberType")},t.prototype.allWrapperClassNames=function(){return e.prototype.allWrapperClassNames.call(this).concat("RAML10.NumberTypeImpl")},t.isInstance=function(e){if(null!=e&&e.allWrapperClassNames&&"function"==typeof e.allWrapperClassNames)for(var t=0,n=e.allWrapperClassNames();t<n.length;t++){var r=n[t];if("RAML10.NumberTypeImpl"==r)return!0}return!1},t.prototype.RAMLVersion=function(){return"RAML10"},t.prototype.value=function(){return this.attr.value()},t}(ne);t.NumberTypeImpl=de;var he=function(e){function t(){e.apply(this,arguments)}return X(t,e),t.prototype.wrapperClassName=function(){return"IntegerTypeImpl"},t.prototype.kind=function(){return"IntegerType"},t.prototype.allKinds=function(){return e.prototype.allKinds.call(this).concat("IntegerType")},t.prototype.allWrapperClassNames=function(){return e.prototype.allWrapperClassNames.call(this).concat("RAML10.IntegerTypeImpl")},t.isInstance=function(e){if(null!=e&&e.allWrapperClassNames&&"function"==typeof e.allWrapperClassNames)for(var t=0,n=e.allWrapperClassNames();t<n.length;t++){var r=n[t];if("RAML10.IntegerTypeImpl"==r)return!0}return!1},t.prototype.RAMLVersion=function(){return"RAML10"},t}(ne);t.IntegerTypeImpl=he;var ye=function(e){function t(){e.apply(this,arguments)}return X(t,e),t.prototype.wrapperClassName=function(){return"NullTypeImpl"},t.prototype.kind=function(){return"NullType"},t.prototype.allKinds=function(){return e.prototype.allKinds.call(this).concat("NullType")},t.prototype.allWrapperClassNames=function(){return e.prototype.allWrapperClassNames.call(this).concat("RAML10.NullTypeImpl")},t.isInstance=function(e){if(null!=e&&e.allWrapperClassNames&&"function"==typeof e.allWrapperClassNames)for(var t=0,n=e.allWrapperClassNames();t<n.length;t++){var r=n[t];if("RAML10.NullTypeImpl"==r)return!0}return!1},t.prototype.RAMLVersion=function(){return"RAML10"},t}(ne);t.NullTypeImpl=ye;var ve=function(e){function t(){e.apply(this,arguments)}return X(t,e),t.prototype.wrapperClassName=function(){return"TimeOnlyTypeImpl"},t.prototype.kind=function(){return"TimeOnlyType"},t.prototype.allKinds=function(){return e.prototype.allKinds.call(this).concat("TimeOnlyType")},t.prototype.allWrapperClassNames=function(){return e.prototype.allWrapperClassNames.call(this).concat("RAML10.TimeOnlyTypeImpl")},t.isInstance=function(e){if(null!=e&&e.allWrapperClassNames&&"function"==typeof e.allWrapperClassNames)for(var t=0,n=e.allWrapperClassNames();t<n.length;t++){var r=n[t];if("RAML10.TimeOnlyTypeImpl"==r)return!0}return!1},t.prototype.RAMLVersion=function(){return"RAML10"},t}(ne);t.TimeOnlyTypeImpl=ve;var ge=function(e){function t(){e.apply(this,arguments)}return X(t,e),t.prototype.wrapperClassName=function(){return"DateOnlyTypeImpl"},t.prototype.kind=function(){return"DateOnlyType"},t.prototype.allKinds=function(){return e.prototype.allKinds.call(this).concat("DateOnlyType")},t.prototype.allWrapperClassNames=function(){return e.prototype.allWrapperClassNames.call(this).concat("RAML10.DateOnlyTypeImpl")},t.isInstance=function(e){if(null!=e&&e.allWrapperClassNames&&"function"==typeof e.allWrapperClassNames)for(var t=0,n=e.allWrapperClassNames();t<n.length;t++){var r=n[t];if("RAML10.DateOnlyTypeImpl"==r)return!0}return!1},t.prototype.RAMLVersion=function(){return"RAML10"},t}(ne);t.DateOnlyTypeImpl=ge;var Ae=function(e){function t(){e.apply(this,arguments)}return X(t,e),t.prototype.wrapperClassName=function(){return"DateTimeOnlyTypeImpl"},t.prototype.kind=function(){return"DateTimeOnlyType"},t.prototype.allKinds=function(){return e.prototype.allKinds.call(this).concat("DateTimeOnlyType")},t.prototype.allWrapperClassNames=function(){return e.prototype.allWrapperClassNames.call(this).concat("RAML10.DateTimeOnlyTypeImpl")},t.isInstance=function(e){if(null!=e&&e.allWrapperClassNames&&"function"==typeof e.allWrapperClassNames)for(var t=0,n=e.allWrapperClassNames();t<n.length;t++){var r=n[t];if("RAML10.DateTimeOnlyTypeImpl"==r)return!0}return!1},t.prototype.RAMLVersion=function(){return"RAML10"},t}(ne);t.DateTimeOnlyTypeImpl=Ae;var Se=function(e){function t(){e.apply(this,arguments)}return X(t,e),t.prototype.wrapperClassName=function(){return"DateTimeTypeImpl"},t.prototype.kind=function(){return"DateTimeType"},t.prototype.allKinds=function(){return e.prototype.allKinds.call(this).concat("DateTimeType")},t.prototype.allWrapperClassNames=function(){return e.prototype.allWrapperClassNames.call(this).concat("RAML10.DateTimeTypeImpl")},t.isInstance=function(e){if(null!=e&&e.allWrapperClassNames&&"function"==typeof e.allWrapperClassNames)for(var t=0,n=e.allWrapperClassNames();t<n.length;t++){var r=n[t];if("RAML10.DateTimeTypeImpl"==r)return!0}return!1},t.prototype.RAMLVersion=function(){return"RAML10"},t}(ne);t.DateTimeTypeImpl=Se;var Te=function(e){function t(){e.apply(this,arguments)}return X(t,e),t.prototype.wrapperClassName=function(){return"FileTypeImpl"},t.prototype.kind=function(){return"FileType"},t.prototype.allKinds=function(){return e.prototype.allKinds.call(this).concat("FileType")},t.prototype.allWrapperClassNames=function(){return e.prototype.allWrapperClassNames.call(this).concat("RAML10.FileTypeImpl")},t.isInstance=function(e){if(null!=e&&e.allWrapperClassNames&&"function"==typeof e.allWrapperClassNames)for(var t=0,n=e.allWrapperClassNames();t<n.length;t++){var r=n[t];if("RAML10.FileTypeImpl"==r)return!0}return!1},t.prototype.RAMLVersion=function(){return"RAML10"},t}(ne);t.FileTypeImpl=Te;var Ee=function(e){function t(){e.apply(this,arguments)}return X(t,e),t.prototype.wrapperClassName=function(){return"BooleanTypeImpl"},t.prototype.kind=function(){return"BooleanType"},t.prototype.allKinds=function(){return e.prototype.allKinds.call(this).concat("BooleanType")},t.prototype.allWrapperClassNames=function(){return e.prototype.allWrapperClassNames.call(this).concat("RAML10.BooleanTypeImpl")},t.isInstance=function(e){if(null!=e&&e.allWrapperClassNames&&"function"==typeof e.allWrapperClassNames)for(var t=0,n=e.allWrapperClassNames();t<n.length;t++){var r=n[t];if("RAML10.BooleanTypeImpl"==r)return!0}return!1},t.prototype.RAMLVersion=function(){return"RAML10"},t.prototype.value=function(){return this.attr.value()},t}(ne);t.BooleanTypeImpl=Ee;var be=function(e){function t(){e.apply(this,arguments)}return X(t,e),t.prototype.wrapperClassName=function(){return"AnnotationTargetImpl"},t.prototype.kind=function(){return"AnnotationTarget"},t.prototype.allKinds=function(){return e.prototype.allKinds.call(this).concat("AnnotationTarget")},t.prototype.allWrapperClassNames=function(){return e.prototype.allWrapperClassNames.call(this).concat("RAML10.AnnotationTargetImpl")},t.isInstance=function(e){if(null!=e&&e.allWrapperClassNames&&"function"==typeof e.allWrapperClassNames)for(var t=0,n=e.allWrapperClassNames();t<n.length;t++){var r=n[t];if("RAML10.AnnotationTargetImpl"==r)return!0}return!1},t.prototype.RAMLVersion=function(){return"RAML10"},t}(ne);t.AnnotationTargetImpl=be;var Ne=function(e){function t(){e.apply(this,arguments)}return X(t,e),t.prototype.wrapperClassName=function(){return"ReferenceImpl"},t.prototype.kind=function(){return"Reference"},t.prototype.allKinds=function(){return e.prototype.allKinds.call(this).concat("Reference")},t.prototype.allWrapperClassNames=function(){return e.prototype.allWrapperClassNames.call(this).concat("RAML10.ReferenceImpl")},t.isInstance=function(e){if(null!=e&&e.allWrapperClassNames&&"function"==typeof e.allWrapperClassNames)for(var t=0,n=e.allWrapperClassNames();t<n.length;t++){var r=n[t];if("RAML10.ReferenceImpl"==r)return!0}return!1},t.prototype.RAMLVersion=function(){return"RAML10"},t.prototype.value=function(){return Q.toStructuredValue(this.attr)},t.prototype.structuredValue=function(){return ee.structuredValue(this)},t.prototype.name=function(){return ee.referenceName(this)},t}(Q.AttributeNodeImpl);t.ReferenceImpl=Ne;var _e=function(e){function t(){e.apply(this,arguments)}return X(t,e),t.prototype.wrapperClassName=function(){return"TraitRefImpl"},t.prototype.kind=function(){return"TraitRef"},t.prototype.allKinds=function(){return e.prototype.allKinds.call(this).concat("TraitRef")},t.prototype.allWrapperClassNames=function(){return e.prototype.allWrapperClassNames.call(this).concat("RAML10.TraitRefImpl")},t.isInstance=function(e){if(null!=e&&e.allWrapperClassNames&&"function"==typeof e.allWrapperClassNames)for(var t=0,n=e.allWrapperClassNames();t<n.length;t++){var r=n[t];if("RAML10.TraitRefImpl"==r)return!0}return!1},t.prototype.RAMLVersion=function(){return"RAML10"},t.prototype.trait=function(){return ee.referencedTrait(this)},t}(Ne);t.TraitRefImpl=_e;var Me=function(e){function t(t,n){void 0===n&&(n=!0),e.call(this,"string"==typeof t?u(t):t,n),this.nodeOrKey=t,this.setAsTopLevel=n}return X(t,e),t.prototype.queryParameters=function(){return e.prototype.elements.call(this,"queryParameters")},t.prototype.headers=function(){return e.prototype.elements.call(this,"headers")},t.prototype.queryString=function(){return e.prototype.element.call(this,"queryString")},t.prototype.responses=function(){return e.prototype.elements.call(this,"responses")},t.prototype.wrapperClassName=function(){return"OperationImpl"},t.prototype.kind=function(){return"Operation"},t.prototype.allKinds=function(){return e.prototype.allKinds.call(this).concat("Operation")},t.prototype.allWrapperClassNames=function(){return e.prototype.allWrapperClassNames.call(this).concat("RAML10.OperationImpl")},t.isInstance=function(e){if(null!=e&&e.allWrapperClassNames&&"function"==typeof e.allWrapperClassNames)for(var t=0,n=e.allWrapperClassNames();t<n.length;t++){var r=n[t];if("RAML10.OperationImpl"==r)return!0}return!1},t.prototype.RAMLVersion=function(){return"RAML10"},t}(te);t.OperationImpl=Me;var we=function(e){function t(t,n){void 0===n&&(n=!0),e.call(this,"string"==typeof t?l(t):t,n),this.nodeOrKey=t,this.setAsTopLevel=n}return X(t,e),t.prototype.name=function(){return e.prototype.attribute.call(this,"name",this.toString)},t.prototype.setName=function(e){return this.highLevel().attrOrCreate("name").setValue(""+e),this},t.prototype.displayName=function(){return e.prototype.attribute.call(this,"displayName",this.toString)},t.prototype.setDisplayName=function(e){return this.highLevel().attrOrCreate("displayName").setValue(""+e),this},t.prototype.facets=function(){return e.prototype.elements.call(this,"facets")},t.prototype.schema_original=function(){return e.prototype.attributes.call(this,"schema",this.toString)},t.prototype.setSchema=function(e){return this.highLevel().attrOrCreate("schema").setValue(""+e),this},t.prototype.type_original=function(){return e.prototype.attributes.call(this,"type",this.toString)},t.prototype.setType=function(e){return this.highLevel().attrOrCreate("type").setValue(""+e),this},t.prototype.location=function(){return e.prototype.attribute.call(this,"location",function(e){return new Re(e)})},t.prototype.locationKind=function(){return e.prototype.attribute.call(this,"locationKind",function(e){return new Ie(e)})},t.prototype["default"]=function(){return e.prototype.attribute.call(this,"default",this.toAny)},t.prototype.setDefault=function(e){return this.highLevel().attrOrCreate("default").setValue(""+e),this},t.prototype.example_original=function(){return e.prototype.element.call(this,"example")},t.prototype.examples_original=function(){return e.prototype.elements.call(this,"examples")},t.prototype.required=function(){return e.prototype.attribute.call(this,"required",this.toBoolean)},t.prototype.setRequired=function(e){return this.highLevel().attrOrCreate("required").setValue(""+e),this},t.prototype.description=function(){return e.prototype.attribute.call(this,"description",function(e){return new pe(e)})},t.prototype.xml=function(){return e.prototype.element.call(this,"xml")},t.prototype.allowedTargets=function(){return e.prototype.attributes.call(this,"allowedTargets",function(e){return new be(e)})},t.prototype.isAnnotation=function(){return e.prototype.attribute.call(this,"isAnnotation",this.toBoolean)},t.prototype.setIsAnnotation=function(e){return this.highLevel().attrOrCreate("isAnnotation").setValue(""+e),this},t.prototype.annotations=function(){return e.prototype.attributes.call(this,"annotations",function(e){return new Ct(e)})},t.prototype.uses=function(){return e.prototype.elements.call(this,"uses")},t.prototype.wrapperClassName=function(){return"TypeDeclarationImpl"},t.prototype.kind=function(){return"TypeDeclaration"},t.prototype.allKinds=function(){return e.prototype.allKinds.call(this).concat("TypeDeclaration")},t.prototype.allWrapperClassNames=function(){return e.prototype.allWrapperClassNames.call(this).concat("RAML10.TypeDeclarationImpl")},t.isInstance=function(e){if(null!=e&&e.allWrapperClassNames&&"function"==typeof e.allWrapperClassNames)for(var t=0,n=e.allWrapperClassNames();t<n.length;t++){var r=n[t];if("RAML10.TypeDeclarationImpl"==r)return!0}return!1},t.prototype.RAMLVersion=function(){return"RAML10"},t.prototype.runtimeType=function(){return ee.runtimeType(this)},t.prototype.validateInstance=function(e){return ee.validateInstance(this,e)},t.prototype.validateInstanceWithDetailedStatuses=function(e){return ee.validateInstanceWithDetailedStatuses(this,e)},t.prototype.example=function(){return ee.getTypeExample(this)},t.prototype.examples=function(){return ee.getTypeExamples(this)},t.prototype.fixedFacets=function(){return ee.typeFixedFacets(this)},t.prototype.type=function(){return ee.typeValue(this)},t.prototype.schema=function(){return ee.schemaValue(this)},t.prototype.structuredType=function(){return ee.typeStructuredValue(this)},t.prototype.parametrizedProperties=function(){return ee.getTemplateParametrizedProperties(this)},t.prototype.scalarsAnnotations=function(){return new xe(this.highLevel())},t}(te);t.TypeDeclarationImpl=we;var Re=function(){function e(e){this.attr=e}return e.prototype.wrapperClassName=function(){return"ModelLocationImpl"},e.prototype.kind=function(){return"ModelLocation"},e.prototype.allKinds=function(){return["ModelLocation"]},e.prototype.allWrapperClassNames=function(){return["RAML10.ModelLocationImpl"]},e.isInstance=function(e){if(null!=e&&e.allWrapperClassNames&&"function"==typeof e.allWrapperClassNames)for(var t=0,n=e.allWrapperClassNames();t<n.length;t++){var r=n[t];if("RAML10.ModelLocationImpl"==r)return!0}return!1},e.prototype.RAMLVersion=function(){return"RAML10"},e}();t.ModelLocationImpl=Re;var Ie=function(){function e(e){this.attr=e}return e.prototype.wrapperClassName=function(){return"LocationKindImpl"},e.prototype.kind=function(){return"LocationKind"},e.prototype.allKinds=function(){return["LocationKind"]},e.prototype.allWrapperClassNames=function(){return["RAML10.LocationKindImpl"]},e.isInstance=function(e){if(null!=e&&e.allWrapperClassNames&&"function"==typeof e.allWrapperClassNames)for(var t=0,n=e.allWrapperClassNames();t<n.length;t++){var r=n[t];if("RAML10.LocationKindImpl"==r)return!0}return!1},e.prototype.RAMLVersion=function(){return"RAML10"},e}();t.LocationKindImpl=Ie;var Ce=function(e){function t(t,n){void 0===n&&(n=!0),e.call(this,"string"==typeof t?p(t):t,n),this.nodeOrKey=t,this.setAsTopLevel=n}return X(t,e),t.prototype.key=function(){return e.prototype.attribute.call(this,"key",this.toString)},t.prototype.setKey=function(e){return this.highLevel().attrOrCreate("key").setValue(""+e),this},t.prototype.value=function(){return e.prototype.attribute.call(this,"value",this.toString)},t.prototype.setValue=function(e){return this.highLevel().attrOrCreate("value").setValue(""+e),this},t.prototype.wrapperClassName=function(){return"UsesDeclarationImpl"},t.prototype.kind=function(){return"UsesDeclaration"},t.prototype.allKinds=function(){return e.prototype.allKinds.call(this).concat("UsesDeclaration")},t.prototype.allWrapperClassNames=function(){return e.prototype.allWrapperClassNames.call(this).concat("RAML10.UsesDeclarationImpl")},t.isInstance=function(e){if(null!=e&&e.allWrapperClassNames&&"function"==typeof e.allWrapperClassNames)for(var t=0,n=e.allWrapperClassNames();t<n.length;t++){var r=n[t];if("RAML10.UsesDeclarationImpl"==r)return!0}return!1},t.prototype.RAMLVersion=function(){return"RAML10"},t.prototype.ast=function(){return ee.referencedNode(this)},t.prototype.scalarsAnnotations=function(){return new Le(this.highLevel())},t}(te);t.UsesDeclarationImpl=Ce;var Le=function(){function e(e){this.node=e}return e.prototype.value=function(){var e=this.node.attr("value");if(null==e)return[];var t=e.annotations(),n=Q.attributesToValues(t,function(e){return new Ct(e)});return n},e}();t.UsesDeclarationScalarsAnnotationsImpl=Le;var Pe=function(e){function t(t,n){void 0===n&&(n=!0),e.call(this,"string"==typeof t?c(t):t,n),this.nodeOrKey=t,this.setAsTopLevel=n}return X(t,e),t.prototype.attribute=function(){return e.prototype.attribute.call(this,"attribute",this.toBoolean)},t.prototype.setAttribute=function(e){return this.highLevel().attrOrCreate("attribute").setValue(""+e),this},t.prototype.wrapped=function(){return e.prototype.attribute.call(this,"wrapped",this.toBoolean)},t.prototype.setWrapped=function(e){return this.highLevel().attrOrCreate("wrapped").setValue(""+e),this},t.prototype.name=function(){return e.prototype.attribute.call(this,"name",this.toString)},t.prototype.setName=function(e){return this.highLevel().attrOrCreate("name").setValue(""+e),this},t.prototype.namespace=function(){return e.prototype.attribute.call(this,"namespace",this.toString)},t.prototype.setNamespace=function(e){return this.highLevel().attrOrCreate("namespace").setValue(""+e),this},t.prototype.prefix=function(){return e.prototype.attribute.call(this,"prefix",this.toString)},t.prototype.setPrefix=function(e){return this.highLevel().attrOrCreate("prefix").setValue(""+e),this},t.prototype.wrapperClassName=function(){return"XMLFacetInfoImpl"},t.prototype.kind=function(){return"XMLFacetInfo"},t.prototype.allKinds=function(){return e.prototype.allKinds.call(this).concat("XMLFacetInfo")},t.prototype.allWrapperClassNames=function(){return e.prototype.allWrapperClassNames.call(this).concat("RAML10.XMLFacetInfoImpl")},t.isInstance=function(e){if(null!=e&&e.allWrapperClassNames&&"function"==typeof e.allWrapperClassNames)for(var t=0,n=e.allWrapperClassNames();t<n.length;t++){var r=n[t];if("RAML10.XMLFacetInfoImpl"==r)return!0}return!1},t.prototype.RAMLVersion=function(){return"RAML10"},t.prototype.scalarsAnnotations=function(){return new Oe(this.highLevel())},t}(te);t.XMLFacetInfoImpl=Pe;var Oe=function(){function e(e){this.node=e}return e.prototype.attribute=function(){var e=this.node.attr("attribute");if(null==e)return[];var t=e.annotations(),n=Q.attributesToValues(t,function(e){return new Ct(e)});return n},e.prototype.wrapped=function(){var e=this.node.attr("wrapped");if(null==e)return[];var t=e.annotations(),n=Q.attributesToValues(t,function(e){return new Ct(e)});return n},e.prototype.name=function(){var e=this.node.attr("name");if(null==e)return[];var t=e.annotations(),n=Q.attributesToValues(t,function(e){return new Ct(e)});return n},e.prototype.namespace=function(){var e=this.node.attr("namespace");if(null==e)return[];var t=e.annotations(),n=Q.attributesToValues(t,function(e){return new Ct(e)});return n},e.prototype.prefix=function(){var e=this.node.attr("prefix");if(null==e)return[];var t=e.annotations(),n=Q.attributesToValues(t,function(e){return new Ct(e)});return n},e}();t.XMLFacetInfoScalarsAnnotationsImpl=Oe;var De=function(e){function t(t,n){void 0===n&&(n=!0),e.call(this,"string"==typeof t?f(t):t,n),this.nodeOrKey=t,this.setAsTopLevel=n}return X(t,e),t.prototype.uniqueItems=function(){return e.prototype.attribute.call(this,"uniqueItems",this.toBoolean)},t.prototype.setUniqueItems=function(e){return this.highLevel().attrOrCreate("uniqueItems").setValue(""+e),this},t.prototype.items_original=function(){return e.prototype.attributes.call(this,"items",this.toString)},t.prototype.setItems=function(e){return this.highLevel().attrOrCreate("items").setValue(""+e),this},t.prototype.minItems=function(){return e.prototype.attribute.call(this,"minItems",this.toNumber)},t.prototype.setMinItems=function(e){return this.highLevel().attrOrCreate("minItems").setValue(""+e),this},t.prototype.maxItems=function(){return e.prototype.attribute.call(this,"maxItems",this.toNumber)},t.prototype.setMaxItems=function(e){return this.highLevel().attrOrCreate("maxItems").setValue(""+e),this},t.prototype.wrapperClassName=function(){return"ArrayTypeDeclarationImpl"},t.prototype.kind=function(){return"ArrayTypeDeclaration"},t.prototype.allKinds=function(){return e.prototype.allKinds.call(this).concat("ArrayTypeDeclaration")},t.prototype.allWrapperClassNames=function(){return e.prototype.allWrapperClassNames.call(this).concat("RAML10.ArrayTypeDeclarationImpl")},t.isInstance=function(e){if(null!=e&&e.allWrapperClassNames&&"function"==typeof e.allWrapperClassNames)for(var t=0,n=e.allWrapperClassNames();t<n.length;t++){var r=n[t];if("RAML10.ArrayTypeDeclarationImpl"==r)return!0}return!1},t.prototype.RAMLVersion=function(){return"RAML10"},t.prototype.items=function(){return ee.getItems(this)},t.prototype.findComponentTypeDeclaration=function(){return ee.findComponentTypeDeclaration(this)},t.prototype.scalarsAnnotations=function(){return new Ue(this.highLevel())},t}(we);t.ArrayTypeDeclarationImpl=De;var xe=function(){function e(e){this.node=e}return e.prototype.displayName=function(){var e=this.node.attr("displayName");if(null==e)return[];var t=e.annotations(),n=Q.attributesToValues(t,function(e){return new Ct(e)});return n},e.prototype.schema=function(){var e=this.node.attributes("schema");return e.map(function(e){var t=e.annotations(),n=Q.attributesToValues(t,function(e){return new Ct(e)});return n})},e.prototype.type=function(){var e=this.node.attributes("type");return e.map(function(e){var t=e.annotations(),n=Q.attributesToValues(t,function(e){return new Ct(e)});return n})},e.prototype.location=function(){var e=this.node.attr("location");if(null==e)return[];var t=e.annotations(),n=Q.attributesToValues(t,function(e){return new Ct(e)});return n},e.prototype.locationKind=function(){var e=this.node.attr("locationKind");if(null==e)return[];var t=e.annotations(),n=Q.attributesToValues(t,function(e){return new Ct(e)});return n},e.prototype["default"]=function(){var e=this.node.attr("default");if(null==e)return[];var t=e.annotations(),n=Q.attributesToValues(t,function(e){return new Ct(e)});return n},e.prototype.required=function(){var e=this.node.attr("required");if(null==e)return[];var t=e.annotations(),n=Q.attributesToValues(t,function(e){return new Ct(e)});return n},e.prototype.description=function(){var e=this.node.attr("description");if(null==e)return[];var t=e.annotations(),n=Q.attributesToValues(t,function(e){return new Ct(e);
});return n},e.prototype.allowedTargets=function(){var e=this.node.attributes("allowedTargets");return e.map(function(e){var t=e.annotations(),n=Q.attributesToValues(t,function(e){return new Ct(e)});return n})},e.prototype.isAnnotation=function(){var e=this.node.attr("isAnnotation");if(null==e)return[];var t=e.annotations(),n=Q.attributesToValues(t,function(e){return new Ct(e)});return n},e}();t.TypeDeclarationScalarsAnnotationsImpl=xe;var Ue=function(e){function t(){e.apply(this,arguments)}return X(t,e),t.prototype.uniqueItems=function(){var e=this.node.attr("uniqueItems");if(null==e)return[];var t=e.annotations(),n=Q.attributesToValues(t,function(e){return new Ct(e)});return n},t.prototype.items=function(){var e=this.node.attributes("items");return e.map(function(e){var t=e.annotations(),n=Q.attributesToValues(t,function(e){return new Ct(e)});return n})},t.prototype.minItems=function(){var e=this.node.attr("minItems");if(null==e)return[];var t=e.annotations(),n=Q.attributesToValues(t,function(e){return new Ct(e)});return n},t.prototype.maxItems=function(){var e=this.node.attr("maxItems");if(null==e)return[];var t=e.annotations(),n=Q.attributesToValues(t,function(e){return new Ct(e)});return n},t}(xe);t.ArrayTypeDeclarationScalarsAnnotationsImpl=Ue;var ke=function(e){function t(t,n){void 0===n&&(n=!0),e.call(this,"string"==typeof t?m(t):t,n),this.nodeOrKey=t,this.setAsTopLevel=n}return X(t,e),t.prototype.wrapperClassName=function(){return"UnionTypeDeclarationImpl"},t.prototype.kind=function(){return"UnionTypeDeclaration"},t.prototype.allKinds=function(){return e.prototype.allKinds.call(this).concat("UnionTypeDeclaration")},t.prototype.allWrapperClassNames=function(){return e.prototype.allWrapperClassNames.call(this).concat("RAML10.UnionTypeDeclarationImpl")},t.isInstance=function(e){if(null!=e&&e.allWrapperClassNames&&"function"==typeof e.allWrapperClassNames)for(var t=0,n=e.allWrapperClassNames();t<n.length;t++){var r=n[t];if("RAML10.UnionTypeDeclarationImpl"==r)return!0}return!1},t.prototype.RAMLVersion=function(){return"RAML10"},t}(we);t.UnionTypeDeclarationImpl=ke;var Fe=function(e){function t(t,n){void 0===n&&(n=!0),e.call(this,"string"==typeof t?d(t):t,n),this.nodeOrKey=t,this.setAsTopLevel=n}return X(t,e),t.prototype.properties=function(){return e.prototype.elements.call(this,"properties")},t.prototype.minProperties=function(){return e.prototype.attribute.call(this,"minProperties",this.toNumber)},t.prototype.setMinProperties=function(e){return this.highLevel().attrOrCreate("minProperties").setValue(""+e),this},t.prototype.maxProperties=function(){return e.prototype.attribute.call(this,"maxProperties",this.toNumber)},t.prototype.setMaxProperties=function(e){return this.highLevel().attrOrCreate("maxProperties").setValue(""+e),this},t.prototype.additionalProperties=function(){return e.prototype.attribute.call(this,"additionalProperties",this.toBoolean)},t.prototype.setAdditionalProperties=function(e){return this.highLevel().attrOrCreate("additionalProperties").setValue(""+e),this},t.prototype.discriminator=function(){return e.prototype.attribute.call(this,"discriminator",this.toString)},t.prototype.setDiscriminator=function(e){return this.highLevel().attrOrCreate("discriminator").setValue(""+e),this},t.prototype.discriminatorValue=function(){return e.prototype.attribute.call(this,"discriminatorValue",this.toString)},t.prototype.setDiscriminatorValue=function(e){return this.highLevel().attrOrCreate("discriminatorValue").setValue(""+e),this},t.prototype.wrapperClassName=function(){return"ObjectTypeDeclarationImpl"},t.prototype.kind=function(){return"ObjectTypeDeclaration"},t.prototype.allKinds=function(){return e.prototype.allKinds.call(this).concat("ObjectTypeDeclaration")},t.prototype.allWrapperClassNames=function(){return e.prototype.allWrapperClassNames.call(this).concat("RAML10.ObjectTypeDeclarationImpl")},t.isInstance=function(e){if(null!=e&&e.allWrapperClassNames&&"function"==typeof e.allWrapperClassNames)for(var t=0,n=e.allWrapperClassNames();t<n.length;t++){var r=n[t];if("RAML10.ObjectTypeDeclarationImpl"==r)return!0}return!1},t.prototype.RAMLVersion=function(){return"RAML10"},t.prototype.scalarsAnnotations=function(){return new Be(this.highLevel())},t}(we);t.ObjectTypeDeclarationImpl=Fe;var Be=function(e){function t(){e.apply(this,arguments)}return X(t,e),t.prototype.minProperties=function(){var e=this.node.attr("minProperties");if(null==e)return[];var t=e.annotations(),n=Q.attributesToValues(t,function(e){return new Ct(e)});return n},t.prototype.maxProperties=function(){var e=this.node.attr("maxProperties");if(null==e)return[];var t=e.annotations(),n=Q.attributesToValues(t,function(e){return new Ct(e)});return n},t.prototype.additionalProperties=function(){var e=this.node.attr("additionalProperties");if(null==e)return[];var t=e.annotations(),n=Q.attributesToValues(t,function(e){return new Ct(e)});return n},t.prototype.discriminator=function(){var e=this.node.attr("discriminator");if(null==e)return[];var t=e.annotations(),n=Q.attributesToValues(t,function(e){return new Ct(e)});return n},t.prototype.discriminatorValue=function(){var e=this.node.attr("discriminatorValue");if(null==e)return[];var t=e.annotations(),n=Q.attributesToValues(t,function(e){return new Ct(e)});return n},t}(xe);t.ObjectTypeDeclarationScalarsAnnotationsImpl=Be;var Ke=function(e){function t(t,n){void 0===n&&(n=!0),e.call(this,"string"==typeof t?h(t):t,n),this.nodeOrKey=t,this.setAsTopLevel=n}return X(t,e),t.prototype.pattern=function(){return e.prototype.attribute.call(this,"pattern",this.toString)},t.prototype.setPattern=function(e){return this.highLevel().attrOrCreate("pattern").setValue(""+e),this},t.prototype.minLength=function(){return e.prototype.attribute.call(this,"minLength",this.toNumber)},t.prototype.setMinLength=function(e){return this.highLevel().attrOrCreate("minLength").setValue(""+e),this},t.prototype.maxLength=function(){return e.prototype.attribute.call(this,"maxLength",this.toNumber)},t.prototype.setMaxLength=function(e){return this.highLevel().attrOrCreate("maxLength").setValue(""+e),this},t.prototype["enum"]=function(){return e.prototype.attributes.call(this,"enum",this.toString)},t.prototype.setEnum=function(e){return this.highLevel().attrOrCreate("enum").setValue(""+e),this},t.prototype.wrapperClassName=function(){return"StringTypeDeclarationImpl"},t.prototype.kind=function(){return"StringTypeDeclaration"},t.prototype.allKinds=function(){return e.prototype.allKinds.call(this).concat("StringTypeDeclaration")},t.prototype.allWrapperClassNames=function(){return e.prototype.allWrapperClassNames.call(this).concat("RAML10.StringTypeDeclarationImpl")},t.isInstance=function(e){if(null!=e&&e.allWrapperClassNames&&"function"==typeof e.allWrapperClassNames)for(var t=0,n=e.allWrapperClassNames();t<n.length;t++){var r=n[t];if("RAML10.StringTypeDeclarationImpl"==r)return!0}return!1},t.prototype.RAMLVersion=function(){return"RAML10"},t.prototype.scalarsAnnotations=function(){return new Ve(this.highLevel())},t}(we);t.StringTypeDeclarationImpl=Ke;var Ve=function(e){function t(){e.apply(this,arguments)}return X(t,e),t.prototype.pattern=function(){var e=this.node.attr("pattern");if(null==e)return[];var t=e.annotations(),n=Q.attributesToValues(t,function(e){return new Ct(e)});return n},t.prototype.minLength=function(){var e=this.node.attr("minLength");if(null==e)return[];var t=e.annotations(),n=Q.attributesToValues(t,function(e){return new Ct(e)});return n},t.prototype.maxLength=function(){var e=this.node.attr("maxLength");if(null==e)return[];var t=e.annotations(),n=Q.attributesToValues(t,function(e){return new Ct(e)});return n},t.prototype["enum"]=function(){var e=this.node.attributes("enum");return e.map(function(e){var t=e.annotations(),n=Q.attributesToValues(t,function(e){return new Ct(e)});return n})},t}(xe);t.StringTypeDeclarationScalarsAnnotationsImpl=Ve;var je=function(e){function t(t,n){void 0===n&&(n=!0),e.call(this,"string"==typeof t?y(t):t,n),this.nodeOrKey=t,this.setAsTopLevel=n}return X(t,e),t.prototype.wrapperClassName=function(){return"BooleanTypeDeclarationImpl"},t.prototype.kind=function(){return"BooleanTypeDeclaration"},t.prototype.allKinds=function(){return e.prototype.allKinds.call(this).concat("BooleanTypeDeclaration")},t.prototype.allWrapperClassNames=function(){return e.prototype.allWrapperClassNames.call(this).concat("RAML10.BooleanTypeDeclarationImpl")},t.isInstance=function(e){if(null!=e&&e.allWrapperClassNames&&"function"==typeof e.allWrapperClassNames)for(var t=0,n=e.allWrapperClassNames();t<n.length;t++){var r=n[t];if("RAML10.BooleanTypeDeclarationImpl"==r)return!0}return!1},t.prototype.RAMLVersion=function(){return"RAML10"},t}(we);t.BooleanTypeDeclarationImpl=je;var We=function(e){function t(t,n){void 0===n&&(n=!0),e.call(this,"string"==typeof t?v(t):t,n),this.nodeOrKey=t,this.setAsTopLevel=n}return X(t,e),t.prototype.minimum=function(){return e.prototype.attribute.call(this,"minimum",this.toNumber)},t.prototype.setMinimum=function(e){return this.highLevel().attrOrCreate("minimum").setValue(""+e),this},t.prototype.maximum=function(){return e.prototype.attribute.call(this,"maximum",this.toNumber)},t.prototype.setMaximum=function(e){return this.highLevel().attrOrCreate("maximum").setValue(""+e),this},t.prototype["enum"]=function(){return e.prototype.attributes.call(this,"enum",this.toString)},t.prototype.setEnum=function(e){return this.highLevel().attrOrCreate("enum").setValue(""+e),this},t.prototype.format=function(){return e.prototype.attribute.call(this,"format",this.toString)},t.prototype.setFormat=function(e){return this.highLevel().attrOrCreate("format").setValue(""+e),this},t.prototype.multipleOf=function(){return e.prototype.attribute.call(this,"multipleOf",this.toNumber)},t.prototype.setMultipleOf=function(e){return this.highLevel().attrOrCreate("multipleOf").setValue(""+e),this},t.prototype.wrapperClassName=function(){return"NumberTypeDeclarationImpl"},t.prototype.kind=function(){return"NumberTypeDeclaration"},t.prototype.allKinds=function(){return e.prototype.allKinds.call(this).concat("NumberTypeDeclaration")},t.prototype.allWrapperClassNames=function(){return e.prototype.allWrapperClassNames.call(this).concat("RAML10.NumberTypeDeclarationImpl")},t.isInstance=function(e){if(null!=e&&e.allWrapperClassNames&&"function"==typeof e.allWrapperClassNames)for(var t=0,n=e.allWrapperClassNames();t<n.length;t++){var r=n[t];if("RAML10.NumberTypeDeclarationImpl"==r)return!0}return!1},t.prototype.RAMLVersion=function(){return"RAML10"},t.prototype.scalarsAnnotations=function(){return new Ye(this.highLevel())},t}(we);t.NumberTypeDeclarationImpl=We;var qe=function(e){function t(t,n){void 0===n&&(n=!0),e.call(this,"string"==typeof t?g(t):t,n),this.nodeOrKey=t,this.setAsTopLevel=n}return X(t,e),t.prototype.format=function(){return e.prototype.attribute.call(this,"format",this.toString)},t.prototype.setFormat=function(e){return this.highLevel().attrOrCreate("format").setValue(""+e),this},t.prototype.wrapperClassName=function(){return"IntegerTypeDeclarationImpl"},t.prototype.kind=function(){return"IntegerTypeDeclaration"},t.prototype.allKinds=function(){return e.prototype.allKinds.call(this).concat("IntegerTypeDeclaration")},t.prototype.allWrapperClassNames=function(){return e.prototype.allWrapperClassNames.call(this).concat("RAML10.IntegerTypeDeclarationImpl")},t.isInstance=function(e){if(null!=e&&e.allWrapperClassNames&&"function"==typeof e.allWrapperClassNames)for(var t=0,n=e.allWrapperClassNames();t<n.length;t++){var r=n[t];if("RAML10.IntegerTypeDeclarationImpl"==r)return!0}return!1},t.prototype.RAMLVersion=function(){return"RAML10"},t.prototype.scalarsAnnotations=function(){return new He(this.highLevel())},t}(We);t.IntegerTypeDeclarationImpl=qe;var Ye=function(e){function t(){e.apply(this,arguments)}return X(t,e),t.prototype.minimum=function(){var e=this.node.attr("minimum");if(null==e)return[];var t=e.annotations(),n=Q.attributesToValues(t,function(e){return new Ct(e)});return n},t.prototype.maximum=function(){var e=this.node.attr("maximum");if(null==e)return[];var t=e.annotations(),n=Q.attributesToValues(t,function(e){return new Ct(e)});return n},t.prototype["enum"]=function(){var e=this.node.attributes("enum");return e.map(function(e){var t=e.annotations(),n=Q.attributesToValues(t,function(e){return new Ct(e)});return n})},t.prototype.format=function(){var e=this.node.attr("format");if(null==e)return[];var t=e.annotations(),n=Q.attributesToValues(t,function(e){return new Ct(e)});return n},t.prototype.multipleOf=function(){var e=this.node.attr("multipleOf");if(null==e)return[];var t=e.annotations(),n=Q.attributesToValues(t,function(e){return new Ct(e)});return n},t}(xe);t.NumberTypeDeclarationScalarsAnnotationsImpl=Ye;var He=function(e){function t(){e.apply(this,arguments)}return X(t,e),t.prototype.format=function(){var e=this.node.attr("format");if(null==e)return[];var t=e.annotations(),n=Q.attributesToValues(t,function(e){return new Ct(e)});return n},t}(Ye);t.IntegerTypeDeclarationScalarsAnnotationsImpl=He;var $e=function(e){function t(t,n){void 0===n&&(n=!0),e.call(this,"string"==typeof t?A(t):t,n),this.nodeOrKey=t,this.setAsTopLevel=n}return X(t,e),t.prototype.wrapperClassName=function(){return"DateOnlyTypeDeclarationImpl"},t.prototype.kind=function(){return"DateOnlyTypeDeclaration"},t.prototype.allKinds=function(){return e.prototype.allKinds.call(this).concat("DateOnlyTypeDeclaration")},t.prototype.allWrapperClassNames=function(){return e.prototype.allWrapperClassNames.call(this).concat("RAML10.DateOnlyTypeDeclarationImpl")},t.isInstance=function(e){if(null!=e&&e.allWrapperClassNames&&"function"==typeof e.allWrapperClassNames)for(var t=0,n=e.allWrapperClassNames();t<n.length;t++){var r=n[t];if("RAML10.DateOnlyTypeDeclarationImpl"==r)return!0}return!1},t.prototype.RAMLVersion=function(){return"RAML10"},t}(we);t.DateOnlyTypeDeclarationImpl=$e;var Ge=function(e){function t(t,n){void 0===n&&(n=!0),e.call(this,"string"==typeof t?S(t):t,n),this.nodeOrKey=t,this.setAsTopLevel=n}return X(t,e),t.prototype.wrapperClassName=function(){return"TimeOnlyTypeDeclarationImpl"},t.prototype.kind=function(){return"TimeOnlyTypeDeclaration"},t.prototype.allKinds=function(){return e.prototype.allKinds.call(this).concat("TimeOnlyTypeDeclaration")},t.prototype.allWrapperClassNames=function(){return e.prototype.allWrapperClassNames.call(this).concat("RAML10.TimeOnlyTypeDeclarationImpl")},t.isInstance=function(e){if(null!=e&&e.allWrapperClassNames&&"function"==typeof e.allWrapperClassNames)for(var t=0,n=e.allWrapperClassNames();t<n.length;t++){var r=n[t];if("RAML10.TimeOnlyTypeDeclarationImpl"==r)return!0}return!1},t.prototype.RAMLVersion=function(){return"RAML10"},t}(we);t.TimeOnlyTypeDeclarationImpl=Ge;var Xe=function(e){function t(t,n){void 0===n&&(n=!0),e.call(this,"string"==typeof t?T(t):t,n),this.nodeOrKey=t,this.setAsTopLevel=n}return X(t,e),t.prototype.wrapperClassName=function(){return"DateTimeOnlyTypeDeclarationImpl"},t.prototype.kind=function(){return"DateTimeOnlyTypeDeclaration"},t.prototype.allKinds=function(){return e.prototype.allKinds.call(this).concat("DateTimeOnlyTypeDeclaration")},t.prototype.allWrapperClassNames=function(){return e.prototype.allWrapperClassNames.call(this).concat("RAML10.DateTimeOnlyTypeDeclarationImpl")},t.isInstance=function(e){if(null!=e&&e.allWrapperClassNames&&"function"==typeof e.allWrapperClassNames)for(var t=0,n=e.allWrapperClassNames();t<n.length;t++){var r=n[t];if("RAML10.DateTimeOnlyTypeDeclarationImpl"==r)return!0}return!1},t.prototype.RAMLVersion=function(){return"RAML10"},t}(we);t.DateTimeOnlyTypeDeclarationImpl=Xe;var ze=function(e){function t(t,n){void 0===n&&(n=!0),e.call(this,"string"==typeof t?E(t):t,n),this.nodeOrKey=t,this.setAsTopLevel=n}return X(t,e),t.prototype.format=function(){return e.prototype.attribute.call(this,"format",this.toString)},t.prototype.setFormat=function(e){return this.highLevel().attrOrCreate("format").setValue(""+e),this},t.prototype.wrapperClassName=function(){return"DateTimeTypeDeclarationImpl"},t.prototype.kind=function(){return"DateTimeTypeDeclaration"},t.prototype.allKinds=function(){return e.prototype.allKinds.call(this).concat("DateTimeTypeDeclaration")},t.prototype.allWrapperClassNames=function(){return e.prototype.allWrapperClassNames.call(this).concat("RAML10.DateTimeTypeDeclarationImpl")},t.isInstance=function(e){if(null!=e&&e.allWrapperClassNames&&"function"==typeof e.allWrapperClassNames)for(var t=0,n=e.allWrapperClassNames();t<n.length;t++){var r=n[t];if("RAML10.DateTimeTypeDeclarationImpl"==r)return!0}return!1},t.prototype.RAMLVersion=function(){return"RAML10"},t.prototype.scalarsAnnotations=function(){return new Je(this.highLevel())},t}(we);t.DateTimeTypeDeclarationImpl=ze;var Je=function(e){function t(){e.apply(this,arguments)}return X(t,e),t.prototype.format=function(){var e=this.node.attr("format");if(null==e)return[];var t=e.annotations(),n=Q.attributesToValues(t,function(e){return new Ct(e)});return n},t}(xe);t.DateTimeTypeDeclarationScalarsAnnotationsImpl=Je;var Qe=function(e){function t(t,n){void 0===n&&(n=!0),e.call(this,"string"==typeof t?b(t):t,n),this.nodeOrKey=t,this.setAsTopLevel=n}return X(t,e),t.prototype.fileTypes=function(){return e.prototype.attributes.call(this,"fileTypes",function(e){return new le(e)})},t.prototype.minLength=function(){return e.prototype.attribute.call(this,"minLength",this.toNumber)},t.prototype.setMinLength=function(e){return this.highLevel().attrOrCreate("minLength").setValue(""+e),this},t.prototype.maxLength=function(){return e.prototype.attribute.call(this,"maxLength",this.toNumber)},t.prototype.setMaxLength=function(e){return this.highLevel().attrOrCreate("maxLength").setValue(""+e),this},t.prototype.wrapperClassName=function(){return"FileTypeDeclarationImpl"},t.prototype.kind=function(){return"FileTypeDeclaration"},t.prototype.allKinds=function(){return e.prototype.allKinds.call(this).concat("FileTypeDeclaration")},t.prototype.allWrapperClassNames=function(){return e.prototype.allWrapperClassNames.call(this).concat("RAML10.FileTypeDeclarationImpl")},t.isInstance=function(e){if(null!=e&&e.allWrapperClassNames&&"function"==typeof e.allWrapperClassNames)for(var t=0,n=e.allWrapperClassNames();t<n.length;t++){var r=n[t];if("RAML10.FileTypeDeclarationImpl"==r)return!0}return!1},t.prototype.RAMLVersion=function(){return"RAML10"},t.prototype.scalarsAnnotations=function(){return new Ze(this.highLevel())},t}(we);t.FileTypeDeclarationImpl=Qe;var Ze=function(e){function t(){e.apply(this,arguments)}return X(t,e),t.prototype.fileTypes=function(){var e=this.node.attributes("fileTypes");return e.map(function(e){var t=e.annotations(),n=Q.attributesToValues(t,function(e){return new Ct(e)});return n})},t.prototype.minLength=function(){var e=this.node.attr("minLength");if(null==e)return[];var t=e.annotations(),n=Q.attributesToValues(t,function(e){return new Ct(e)});return n},t.prototype.maxLength=function(){var e=this.node.attr("maxLength");if(null==e)return[];var t=e.annotations(),n=Q.attributesToValues(t,function(e){return new Ct(e)});return n},t}(xe);t.FileTypeDeclarationScalarsAnnotationsImpl=Ze;var et=function(e){function t(t,n){void 0===n&&(n=!0),e.call(this,"string"==typeof t?N(t):t,n),this.nodeOrKey=t,this.setAsTopLevel=n}return X(t,e),t.prototype.code=function(){return e.prototype.attribute.call(this,"code",function(e){return new se(e)})},t.prototype.headers=function(){return e.prototype.elements.call(this,"headers")},t.prototype.body=function(){return e.prototype.elements.call(this,"body")},t.prototype.description=function(){return e.prototype.attribute.call(this,"description",function(e){return new pe(e)})},t.prototype.annotations=function(){return e.prototype.attributes.call(this,"annotations",function(e){return new Ct(e)})},t.prototype.wrapperClassName=function(){return"ResponseImpl"},t.prototype.kind=function(){return"Response"},t.prototype.allKinds=function(){return e.prototype.allKinds.call(this).concat("Response")},t.prototype.allWrapperClassNames=function(){return e.prototype.allWrapperClassNames.call(this).concat("RAML10.ResponseImpl")},t.isInstance=function(e){if(null!=e&&e.allWrapperClassNames&&"function"==typeof e.allWrapperClassNames)for(var t=0,n=e.allWrapperClassNames();t<n.length;t++){var r=n[t];if("RAML10.ResponseImpl"==r)return!0}return!1},t.prototype.RAMLVersion=function(){return"RAML10"},t.prototype.isOkRange=function(){return ee.isOkRange(this)},t.prototype.scalarsAnnotations=function(){return new tt(this.highLevel())},t}(te);t.ResponseImpl=et;var tt=function(){function e(e){this.node=e}return e.prototype.description=function(){var e=this.node.attr("description");if(null==e)return[];var t=e.annotations(),n=Q.attributesToValues(t,function(e){return new Ct(e)});return n},e}();t.ResponseScalarsAnnotationsImpl=tt;var nt=function(e){function t(t,n){void 0===n&&(n=!0),e.call(this,"string"==typeof t?_(t):t,n),this.nodeOrKey=t,this.setAsTopLevel=n}return X(t,e),t.prototype.annotations=function(){return e.prototype.attributes.call(this,"annotations",function(e){return new Ct(e)})},t.prototype.wrapperClassName=function(){return"SecuritySchemePartImpl"},t.prototype.kind=function(){return"SecuritySchemePart"},t.prototype.allKinds=function(){return e.prototype.allKinds.call(this).concat("SecuritySchemePart")},t.prototype.allWrapperClassNames=function(){return e.prototype.allWrapperClassNames.call(this).concat("RAML10.SecuritySchemePartImpl")},t.isInstance=function(e){if(null!=e&&e.allWrapperClassNames&&"function"==typeof e.allWrapperClassNames)for(var t=0,n=e.allWrapperClassNames();t<n.length;t++){var r=n[t];if("RAML10.SecuritySchemePartImpl"==r)return!0}return!1},t.prototype.RAMLVersion=function(){return"RAML10"},t}(Me);t.SecuritySchemePartImpl=nt;var rt=function(e){function t(t,n){void 0===n&&(n=!0),e.call(this,"string"==typeof t?s(t):t,n),this.nodeOrKey=t,this.setAsTopLevel=n}return X(t,e),t.prototype.body=function(){return e.prototype.elements.call(this,"body")},t.prototype.protocols=function(){return e.prototype.attributes.call(this,"protocols",this.toString)},t.prototype.setProtocols=function(e){return this.highLevel().attrOrCreate("protocols").setValue(""+e),this},t.prototype.is=function(){return e.prototype.attributes.call(this,"is",function(e){return new _e(e)})},t.prototype.securedBy=function(){return e.prototype.attributes.call(this,"securedBy",function(e){return new it(e)})},t.prototype.description=function(){return e.prototype.attribute.call(this,"description",function(e){return new pe(e)})},t.prototype.displayName=function(){return e.prototype.attribute.call(this,"displayName",this.toString)},t.prototype.setDisplayName=function(e){return this.highLevel().attrOrCreate("displayName").setValue(""+e),this},t.prototype.wrapperClassName=function(){return"MethodBaseImpl"},t.prototype.kind=function(){return"MethodBase"},t.prototype.allKinds=function(){return e.prototype.allKinds.call(this).concat("MethodBase")},t.prototype.allWrapperClassNames=function(){return e.prototype.allWrapperClassNames.call(this).concat("RAML10.MethodBaseImpl")},t.isInstance=function(e){if(null!=e&&e.allWrapperClassNames&&"function"==typeof e.allWrapperClassNames)for(var t=0,n=e.allWrapperClassNames();t<n.length;t++){var r=n[t];if("RAML10.MethodBaseImpl"==r)return!0}return!1},t.prototype.RAMLVersion=function(){return"RAML10"},t.prototype.scalarsAnnotations=function(){return new At(this.highLevel())},t}(Me);t.MethodBaseImpl=rt;var it=function(e){function t(){e.apply(this,arguments)}return X(t,e),t.prototype.wrapperClassName=function(){return"SecuritySchemeRefImpl"},t.prototype.kind=function(){return"SecuritySchemeRef"},t.prototype.allKinds=function(){return e.prototype.allKinds.call(this).concat("SecuritySchemeRef")},t.prototype.allWrapperClassNames=function(){return e.prototype.allWrapperClassNames.call(this).concat("RAML10.SecuritySchemeRefImpl")},t.isInstance=function(e){if(null!=e&&e.allWrapperClassNames&&"function"==typeof e.allWrapperClassNames)for(var t=0,n=e.allWrapperClassNames();t<n.length;t++){var r=n[t];if("RAML10.SecuritySchemeRefImpl"==r)return!0}return!1},t.prototype.RAMLVersion=function(){return"RAML10"},t.prototype.securitySchemeName=function(){return ee.securitySchemeName(this)},t.prototype.securityScheme=function(){return ee.securityScheme(this)},t}(Ne);t.SecuritySchemeRefImpl=it;var at=function(e){function t(t,n){void 0===n&&(n=!0),e.call(this,"string"==typeof t?M(t):t,n),this.nodeOrKey=t,this.setAsTopLevel=n}return X(t,e),t.prototype.name=function(){return e.prototype.attribute.call(this,"name",this.toString)},t.prototype.setName=function(e){return this.highLevel().attrOrCreate("name").setValue(""+e),this},t.prototype.type=function(){return e.prototype.attribute.call(this,"type",this.toString)},t.prototype.setType=function(e){return this.highLevel().attrOrCreate("type").setValue(""+e),this},t.prototype.description=function(){return e.prototype.attribute.call(this,"description",function(e){return new pe(e)})},t.prototype.describedBy=function(){return e.prototype.element.call(this,"describedBy")},t.prototype.displayName=function(){return e.prototype.attribute.call(this,"displayName",this.toString)},t.prototype.setDisplayName=function(e){return this.highLevel().attrOrCreate("displayName").setValue(""+e),this},t.prototype.settings=function(){return e.prototype.element.call(this,"settings")},t.prototype.wrapperClassName=function(){return"AbstractSecuritySchemeImpl"},t.prototype.kind=function(){return"AbstractSecurityScheme"},t.prototype.allKinds=function(){return e.prototype.allKinds.call(this).concat("AbstractSecurityScheme")},t.prototype.allWrapperClassNames=function(){return e.prototype.allWrapperClassNames.call(this).concat("RAML10.AbstractSecuritySchemeImpl")},t.isInstance=function(e){if(null!=e&&e.allWrapperClassNames&&"function"==typeof e.allWrapperClassNames)for(var t=0,n=e.allWrapperClassNames();t<n.length;t++){var r=n[t];if("RAML10.AbstractSecuritySchemeImpl"==r)return!0}return!1},t.prototype.RAMLVersion=function(){return"RAML10"},t.prototype.scalarsAnnotations=function(){return new vt(this.highLevel())},t}(te);t.AbstractSecuritySchemeImpl=at;var ot=function(e){function t(t,n){void 0===n&&(n=!0),e.call(this,"string"==typeof t?w(t):t,n),this.nodeOrKey=t,this.setAsTopLevel=n}return X(t,e),t.prototype.wrapperClassName=function(){return"SecuritySchemeSettingsImpl"},t.prototype.kind=function(){return"SecuritySchemeSettings"},t.prototype.allKinds=function(){return e.prototype.allKinds.call(this).concat("SecuritySchemeSettings")},t.prototype.allWrapperClassNames=function(){return e.prototype.allWrapperClassNames.call(this).concat("RAML10.SecuritySchemeSettingsImpl")},t.isInstance=function(e){if(null!=e&&e.allWrapperClassNames&&"function"==typeof e.allWrapperClassNames)for(var t=0,n=e.allWrapperClassNames();t<n.length;t++){var r=n[t];if("RAML10.SecuritySchemeSettingsImpl"==r)return!0}return!1},t.prototype.RAMLVersion=function(){return"RAML10"},t}(te);t.SecuritySchemeSettingsImpl=ot;var st=function(e){function t(t,n){void 0===n&&(n=!0),e.call(this,"string"==typeof t?R(t):t,n),this.nodeOrKey=t,this.setAsTopLevel=n}return X(t,e),t.prototype.requestTokenUri=function(){return e.prototype.attribute.call(this,"requestTokenUri",function(e){return new ue(e)})},t.prototype.authorizationUri=function(){return e.prototype.attribute.call(this,"authorizationUri",function(e){return new ue(e)})},t.prototype.tokenCredentialsUri=function(){return e.prototype.attribute.call(this,"tokenCredentialsUri",function(e){return new ue(e)})},t.prototype.signatures=function(){return e.prototype.attributes.call(this,"signatures",this.toString)},t.prototype.setSignatures=function(e){return this.highLevel().attrOrCreate("signatures").setValue(""+e),this},t.prototype.wrapperClassName=function(){return"OAuth1SecuritySchemeSettingsImpl"},t.prototype.kind=function(){return"OAuth1SecuritySchemeSettings"},t.prototype.allKinds=function(){return e.prototype.allKinds.call(this).concat("OAuth1SecuritySchemeSettings")},t.prototype.allWrapperClassNames=function(){return e.prototype.allWrapperClassNames.call(this).concat("RAML10.OAuth1SecuritySchemeSettingsImpl")},t.isInstance=function(e){if(null!=e&&e.allWrapperClassNames&&"function"==typeof e.allWrapperClassNames)for(var t=0,n=e.allWrapperClassNames();t<n.length;t++){var r=n[t];if("RAML10.OAuth1SecuritySchemeSettingsImpl"==r)return!0}return!1},t.prototype.RAMLVersion=function(){return"RAML10"},t.prototype.scalarsAnnotations=function(){return new ut(this.highLevel())},t}(ot);t.OAuth1SecuritySchemeSettingsImpl=st;var ut=function(){function e(e){this.node=e}return e.prototype.requestTokenUri=function(){var e=this.node.attr("requestTokenUri");if(null==e)return[];var t=e.annotations(),n=Q.attributesToValues(t,function(e){return new Ct(e)});return n},e.prototype.authorizationUri=function(){var e=this.node.attr("authorizationUri");if(null==e)return[];var t=e.annotations(),n=Q.attributesToValues(t,function(e){return new Ct(e)});return n},e.prototype.tokenCredentialsUri=function(){var e=this.node.attr("tokenCredentialsUri");if(null==e)return[];var t=e.annotations(),n=Q.attributesToValues(t,function(e){return new Ct(e)});return n},e.prototype.signatures=function(){var e=this.node.attributes("signatures");return e.map(function(e){var t=e.annotations(),n=Q.attributesToValues(t,function(e){return new Ct(e)});return n})},e}();t.OAuth1SecuritySchemeSettingsScalarsAnnotationsImpl=ut;var lt=function(e){function t(t,n){void 0===n&&(n=!0),e.call(this,"string"==typeof t?I(t):t,n),this.nodeOrKey=t,this.setAsTopLevel=n}return X(t,e),t.prototype.accessTokenUri=function(){return e.prototype.attribute.call(this,"accessTokenUri",function(e){return new ue(e)})},t.prototype.authorizationUri=function(){return e.prototype.attribute.call(this,"authorizationUri",function(e){return new ue(e)})},t.prototype.authorizationGrants=function(){return e.prototype.attributes.call(this,"authorizationGrants",this.toString)},t.prototype.setAuthorizationGrants=function(e){return this.highLevel().attrOrCreate("authorizationGrants").setValue(""+e),this},t.prototype.scopes=function(){return e.prototype.attributes.call(this,"scopes",this.toString)},t.prototype.setScopes=function(e){return this.highLevel().attrOrCreate("scopes").setValue(""+e),this},t.prototype.wrapperClassName=function(){return"OAuth2SecuritySchemeSettingsImpl"},t.prototype.kind=function(){return"OAuth2SecuritySchemeSettings"},t.prototype.allKinds=function(){return e.prototype.allKinds.call(this).concat("OAuth2SecuritySchemeSettings")},t.prototype.allWrapperClassNames=function(){return e.prototype.allWrapperClassNames.call(this).concat("RAML10.OAuth2SecuritySchemeSettingsImpl")},t.isInstance=function(e){if(null!=e&&e.allWrapperClassNames&&"function"==typeof e.allWrapperClassNames)for(var t=0,n=e.allWrapperClassNames();t<n.length;t++){var r=n[t];if("RAML10.OAuth2SecuritySchemeSettingsImpl"==r)return!0}return!1},t.prototype.RAMLVersion=function(){return"RAML10"},t.prototype.scalarsAnnotations=function(){return new pt(this.highLevel())},t}(ot);t.OAuth2SecuritySchemeSettingsImpl=lt;var pt=function(){function e(e){this.node=e}return e.prototype.accessTokenUri=function(){var e=this.node.attr("accessTokenUri");if(null==e)return[];var t=e.annotations(),n=Q.attributesToValues(t,function(e){return new Ct(e)});return n},e.prototype.authorizationUri=function(){var e=this.node.attr("authorizationUri");if(null==e)return[];var t=e.annotations(),n=Q.attributesToValues(t,function(e){return new Ct(e)});return n},e.prototype.authorizationGrants=function(){var e=this.node.attributes("authorizationGrants");return e.map(function(e){var t=e.annotations(),n=Q.attributesToValues(t,function(e){return new Ct(e)});return n})},e.prototype.scopes=function(){var e=this.node.attributes("scopes");return e.map(function(e){var t=e.annotations(),n=Q.attributesToValues(t,function(e){return new Ct(e)});return n})},e}();t.OAuth2SecuritySchemeSettingsScalarsAnnotationsImpl=pt;
var ct=function(e){function t(t,n){void 0===n&&(n=!0),e.call(this,"string"==typeof t?C(t):t,n),this.nodeOrKey=t,this.setAsTopLevel=n}return X(t,e),t.prototype.settings=function(){return e.prototype.element.call(this,"settings")},t.prototype.wrapperClassName=function(){return"OAuth2SecuritySchemeImpl"},t.prototype.kind=function(){return"OAuth2SecurityScheme"},t.prototype.allKinds=function(){return e.prototype.allKinds.call(this).concat("OAuth2SecurityScheme")},t.prototype.allWrapperClassNames=function(){return e.prototype.allWrapperClassNames.call(this).concat("RAML10.OAuth2SecuritySchemeImpl")},t.isInstance=function(e){if(null!=e&&e.allWrapperClassNames&&"function"==typeof e.allWrapperClassNames)for(var t=0,n=e.allWrapperClassNames();t<n.length;t++){var r=n[t];if("RAML10.OAuth2SecuritySchemeImpl"==r)return!0}return!1},t.prototype.RAMLVersion=function(){return"RAML10"},t}(at);t.OAuth2SecuritySchemeImpl=ct;var ft=function(e){function t(t,n){void 0===n&&(n=!0),e.call(this,"string"==typeof t?L(t):t,n),this.nodeOrKey=t,this.setAsTopLevel=n}return X(t,e),t.prototype.settings=function(){return e.prototype.element.call(this,"settings")},t.prototype.wrapperClassName=function(){return"OAuth1SecuritySchemeImpl"},t.prototype.kind=function(){return"OAuth1SecurityScheme"},t.prototype.allKinds=function(){return e.prototype.allKinds.call(this).concat("OAuth1SecurityScheme")},t.prototype.allWrapperClassNames=function(){return e.prototype.allWrapperClassNames.call(this).concat("RAML10.OAuth1SecuritySchemeImpl")},t.isInstance=function(e){if(null!=e&&e.allWrapperClassNames&&"function"==typeof e.allWrapperClassNames)for(var t=0,n=e.allWrapperClassNames();t<n.length;t++){var r=n[t];if("RAML10.OAuth1SecuritySchemeImpl"==r)return!0}return!1},t.prototype.RAMLVersion=function(){return"RAML10"},t}(at);t.OAuth1SecuritySchemeImpl=ft;var mt=function(e){function t(t,n){void 0===n&&(n=!0),e.call(this,"string"==typeof t?P(t):t,n),this.nodeOrKey=t,this.setAsTopLevel=n}return X(t,e),t.prototype.settings=function(){return e.prototype.element.call(this,"settings")},t.prototype.wrapperClassName=function(){return"PassThroughSecuritySchemeImpl"},t.prototype.kind=function(){return"PassThroughSecurityScheme"},t.prototype.allKinds=function(){return e.prototype.allKinds.call(this).concat("PassThroughSecurityScheme")},t.prototype.allWrapperClassNames=function(){return e.prototype.allWrapperClassNames.call(this).concat("RAML10.PassThroughSecuritySchemeImpl")},t.isInstance=function(e){if(null!=e&&e.allWrapperClassNames&&"function"==typeof e.allWrapperClassNames)for(var t=0,n=e.allWrapperClassNames();t<n.length;t++){var r=n[t];if("RAML10.PassThroughSecuritySchemeImpl"==r)return!0}return!1},t.prototype.RAMLVersion=function(){return"RAML10"},t}(at);t.PassThroughSecuritySchemeImpl=mt;var dt=function(e){function t(t,n){void 0===n&&(n=!0),e.call(this,"string"==typeof t?O(t):t,n),this.nodeOrKey=t,this.setAsTopLevel=n}return X(t,e),t.prototype.wrapperClassName=function(){return"BasicSecuritySchemeImpl"},t.prototype.kind=function(){return"BasicSecurityScheme"},t.prototype.allKinds=function(){return e.prototype.allKinds.call(this).concat("BasicSecurityScheme")},t.prototype.allWrapperClassNames=function(){return e.prototype.allWrapperClassNames.call(this).concat("RAML10.BasicSecuritySchemeImpl")},t.isInstance=function(e){if(null!=e&&e.allWrapperClassNames&&"function"==typeof e.allWrapperClassNames)for(var t=0,n=e.allWrapperClassNames();t<n.length;t++){var r=n[t];if("RAML10.BasicSecuritySchemeImpl"==r)return!0}return!1},t.prototype.RAMLVersion=function(){return"RAML10"},t}(at);t.BasicSecuritySchemeImpl=dt;var ht=function(e){function t(t,n){void 0===n&&(n=!0),e.call(this,"string"==typeof t?D(t):t,n),this.nodeOrKey=t,this.setAsTopLevel=n}return X(t,e),t.prototype.wrapperClassName=function(){return"DigestSecuritySchemeImpl"},t.prototype.kind=function(){return"DigestSecurityScheme"},t.prototype.allKinds=function(){return e.prototype.allKinds.call(this).concat("DigestSecurityScheme")},t.prototype.allWrapperClassNames=function(){return e.prototype.allWrapperClassNames.call(this).concat("RAML10.DigestSecuritySchemeImpl")},t.isInstance=function(e){if(null!=e&&e.allWrapperClassNames&&"function"==typeof e.allWrapperClassNames)for(var t=0,n=e.allWrapperClassNames();t<n.length;t++){var r=n[t];if("RAML10.DigestSecuritySchemeImpl"==r)return!0}return!1},t.prototype.RAMLVersion=function(){return"RAML10"},t}(at);t.DigestSecuritySchemeImpl=ht;var yt=function(e){function t(t,n){void 0===n&&(n=!0),e.call(this,"string"==typeof t?x(t):t,n),this.nodeOrKey=t,this.setAsTopLevel=n}return X(t,e),t.prototype.wrapperClassName=function(){return"CustomSecuritySchemeImpl"},t.prototype.kind=function(){return"CustomSecurityScheme"},t.prototype.allKinds=function(){return e.prototype.allKinds.call(this).concat("CustomSecurityScheme")},t.prototype.allWrapperClassNames=function(){return e.prototype.allWrapperClassNames.call(this).concat("RAML10.CustomSecuritySchemeImpl")},t.isInstance=function(e){if(null!=e&&e.allWrapperClassNames&&"function"==typeof e.allWrapperClassNames)for(var t=0,n=e.allWrapperClassNames();t<n.length;t++){var r=n[t];if("RAML10.CustomSecuritySchemeImpl"==r)return!0}return!1},t.prototype.RAMLVersion=function(){return"RAML10"},t}(at);t.CustomSecuritySchemeImpl=yt;var vt=function(){function e(e){this.node=e}return e.prototype.type=function(){var e=this.node.attr("type");if(null==e)return[];var t=e.annotations(),n=Q.attributesToValues(t,function(e){return new Ct(e)});return n},e.prototype.description=function(){var e=this.node.attr("description");if(null==e)return[];var t=e.annotations(),n=Q.attributesToValues(t,function(e){return new Ct(e)});return n},e.prototype.displayName=function(){var e=this.node.attr("displayName");if(null==e)return[];var t=e.annotations(),n=Q.attributesToValues(t,function(e){return new Ct(e)});return n},e}();t.AbstractSecuritySchemeScalarsAnnotationsImpl=vt;var gt=function(e){function t(t,n){void 0===n&&(n=!0),e.call(this,"string"==typeof t?U(t):t,n),this.nodeOrKey=t,this.setAsTopLevel=n}return X(t,e),t.prototype.method=function(){return e.prototype.attribute.call(this,"method",this.toString)},t.prototype.setMethod=function(e){return this.highLevel().attrOrCreate("method").setValue(""+e),this},t.prototype.displayName=function(){return e.prototype.attribute.call(this,"displayName",this.toString)},t.prototype.setDisplayName=function(e){return this.highLevel().attrOrCreate("displayName").setValue(""+e),this},t.prototype.wrapperClassName=function(){return"MethodImpl"},t.prototype.kind=function(){return"Method"},t.prototype.allKinds=function(){return e.prototype.allKinds.call(this).concat("Method")},t.prototype.allWrapperClassNames=function(){return e.prototype.allWrapperClassNames.call(this).concat("RAML10.MethodImpl")},t.isInstance=function(e){if(null!=e&&e.allWrapperClassNames&&"function"==typeof e.allWrapperClassNames)for(var t=0,n=e.allWrapperClassNames();t<n.length;t++){var r=n[t];if("RAML10.MethodImpl"==r)return!0}return!1},t.prototype.RAMLVersion=function(){return"RAML10"},t.prototype.parentResource=function(){return ee.parentResource(this)},t.prototype.ownerApi=function(){return ee.ownerApi(this)},t.prototype.methodId=function(){return ee.methodId(this)},t.prototype.allSecuredBy=function(){return ee.allSecuredBy(this)},t.prototype.parametrizedProperties=function(){return ee.getTemplateParametrizedProperties(this)},t.prototype.scalarsAnnotations=function(){return new St(this.highLevel())},t}(rt);t.MethodImpl=gt;var At=function(){function e(e){this.node=e}return e.prototype.protocols=function(){var e=this.node.attributes("protocols");return e.map(function(e){var t=e.annotations(),n=Q.attributesToValues(t,function(e){return new Ct(e)});return n})},e.prototype.is=function(){var e=this.node.attributes("is");return e.map(function(e){var t=e.annotations(),n=Q.attributesToValues(t,function(e){return new Ct(e)});return n})},e.prototype.securedBy=function(){var e=this.node.attributes("securedBy");return e.map(function(e){var t=e.annotations(),n=Q.attributesToValues(t,function(e){return new Ct(e)});return n})},e.prototype.description=function(){var e=this.node.attr("description");if(null==e)return[];var t=e.annotations(),n=Q.attributesToValues(t,function(e){return new Ct(e)});return n},e.prototype.displayName=function(){var e=this.node.attr("displayName");if(null==e)return[];var t=e.annotations(),n=Q.attributesToValues(t,function(e){return new Ct(e)});return n},e}();t.MethodBaseScalarsAnnotationsImpl=At;var St=function(e){function t(){e.apply(this,arguments)}return X(t,e),t.prototype.displayName=function(){var e=this.node.attr("displayName");if(null==e)return[];var t=e.annotations(),n=Q.attributesToValues(t,function(e){return new Ct(e)});return n},t}(At);t.MethodScalarsAnnotationsImpl=St;var Tt=function(e){function t(t,n){void 0===n&&(n=!0),e.call(this,"string"==typeof t?o(t):t,n),this.nodeOrKey=t,this.setAsTopLevel=n}return X(t,e),t.prototype.name=function(){return e.prototype.attribute.call(this,"name",this.toString)},t.prototype.setName=function(e){return this.highLevel().attrOrCreate("name").setValue(""+e),this},t.prototype.usage=function(){return e.prototype.attribute.call(this,"usage",this.toString)},t.prototype.setUsage=function(e){return this.highLevel().attrOrCreate("usage").setValue(""+e),this},t.prototype.displayName=function(){return e.prototype.attribute.call(this,"displayName",this.toString)},t.prototype.setDisplayName=function(e){return this.highLevel().attrOrCreate("displayName").setValue(""+e),this},t.prototype.uses=function(){return e.prototype.elements.call(this,"uses")},t.prototype.wrapperClassName=function(){return"TraitImpl"},t.prototype.kind=function(){return"Trait"},t.prototype.allKinds=function(){return e.prototype.allKinds.call(this).concat("Trait")},t.prototype.allWrapperClassNames=function(){return e.prototype.allWrapperClassNames.call(this).concat("RAML10.TraitImpl")},t.isInstance=function(e){if(null!=e&&e.allWrapperClassNames&&"function"==typeof e.allWrapperClassNames)for(var t=0,n=e.allWrapperClassNames();t<n.length;t++){var r=n[t];if("RAML10.TraitImpl"==r)return!0}return!1},t.prototype.RAMLVersion=function(){return"RAML10"},t.prototype.parametrizedProperties=function(){return ee.getTemplateParametrizedProperties(this)},t.prototype.scalarsAnnotations=function(){return new Et(this.highLevel())},t}(rt);t.TraitImpl=Tt;var Et=function(e){function t(){e.apply(this,arguments)}return X(t,e),t.prototype.usage=function(){var e=this.node.attr("usage");if(null==e)return[];var t=e.annotations(),n=Q.attributesToValues(t,function(e){return new Ct(e)});return n},t.prototype.displayName=function(){var e=this.node.attr("displayName");if(null==e)return[];var t=e.annotations(),n=Q.attributesToValues(t,function(e){return new Ct(e)});return n},t}(At);t.TraitScalarsAnnotationsImpl=Et;var bt=function(e){function t(){e.apply(this,arguments)}return X(t,e),t.prototype.wrapperClassName=function(){return"ResourceTypeRefImpl"},t.prototype.kind=function(){return"ResourceTypeRef"},t.prototype.allKinds=function(){return e.prototype.allKinds.call(this).concat("ResourceTypeRef")},t.prototype.allWrapperClassNames=function(){return e.prototype.allWrapperClassNames.call(this).concat("RAML10.ResourceTypeRefImpl")},t.isInstance=function(e){if(null!=e&&e.allWrapperClassNames&&"function"==typeof e.allWrapperClassNames)for(var t=0,n=e.allWrapperClassNames();t<n.length;t++){var r=n[t];if("RAML10.ResourceTypeRefImpl"==r)return!0}return!1},t.prototype.RAMLVersion=function(){return"RAML10"},t.prototype.resourceType=function(){return ee.referencedResourceType(this)},t}(Ne);t.ResourceTypeRefImpl=bt;var Nt=function(e){function t(t,n){void 0===n&&(n=!0),e.call(this,"string"==typeof t?F(t):t,n),this.nodeOrKey=t,this.setAsTopLevel=n}return X(t,e),t.prototype.methods=function(){return e.prototype.elements.call(this,"methods")},t.prototype.is=function(){return e.prototype.attributes.call(this,"is",function(e){return new _e(e)})},t.prototype.type=function(){return e.prototype.attribute.call(this,"type",function(e){return new bt(e)})},t.prototype.description=function(){return e.prototype.attribute.call(this,"description",function(e){return new pe(e)})},t.prototype.securedBy=function(){return e.prototype.attributes.call(this,"securedBy",function(e){return new it(e)})},t.prototype.uriParameters_original=function(){return e.prototype.elements.call(this,"uriParameters")},t.prototype.wrapperClassName=function(){return"ResourceBaseImpl"},t.prototype.kind=function(){return"ResourceBase"},t.prototype.allKinds=function(){return e.prototype.allKinds.call(this).concat("ResourceBase")},t.prototype.allWrapperClassNames=function(){return e.prototype.allWrapperClassNames.call(this).concat("RAML10.ResourceBaseImpl")},t.isInstance=function(e){if(null!=e&&e.allWrapperClassNames&&"function"==typeof e.allWrapperClassNames)for(var t=0,n=e.allWrapperClassNames();t<n.length;t++){var r=n[t];if("RAML10.ResourceBaseImpl"==r)return!0}return!1},t.prototype.RAMLVersion=function(){return"RAML10"},t.prototype.uriParameters=function(){return ee.uriParametersPrimary(this)},t.prototype.allUriParameters=function(){return ee.uriParameters(this)},t.prototype.allSecuredBy=function(){return ee.allSecuredBy(this)},t.prototype.scalarsAnnotations=function(){return new Mt(this.highLevel())},t}(te);t.ResourceBaseImpl=Nt;var _t=function(e){function t(t,n){void 0===n&&(n=!0),e.call(this,"string"==typeof t?B(t):t,n),this.nodeOrKey=t,this.setAsTopLevel=n}return X(t,e),t.prototype.relativeUri=function(){return e.prototype.attribute.call(this,"relativeUri",function(e){return new ae(e)})},t.prototype.displayName=function(){return e.prototype.attribute.call(this,"displayName",this.toString)},t.prototype.setDisplayName=function(e){return this.highLevel().attrOrCreate("displayName").setValue(""+e),this},t.prototype.resources=function(){return e.prototype.elements.call(this,"resources")},t.prototype.description=function(){return e.prototype.attribute.call(this,"description",function(e){return new pe(e)})},t.prototype.annotations=function(){return e.prototype.attributes.call(this,"annotations",function(e){return new Ct(e)})},t.prototype.wrapperClassName=function(){return"ResourceImpl"},t.prototype.kind=function(){return"Resource"},t.prototype.allKinds=function(){return e.prototype.allKinds.call(this).concat("Resource")},t.prototype.allWrapperClassNames=function(){return e.prototype.allWrapperClassNames.call(this).concat("RAML10.ResourceImpl")},t.isInstance=function(e){if(null!=e&&e.allWrapperClassNames&&"function"==typeof e.allWrapperClassNames)for(var t=0,n=e.allWrapperClassNames();t<n.length;t++){var r=n[t];if("RAML10.ResourceImpl"==r)return!0}return!1},t.prototype.RAMLVersion=function(){return"RAML10"},t.prototype.completeRelativeUri=function(){return ee.completeRelativeUri(this)},t.prototype.absoluteUri=function(){return ee.absoluteUri(this)},t.prototype.parentResource=function(){return ee.parent(this)},t.prototype.childResource=function(e){return ee.childResource(this,e)},t.prototype.childMethod=function(e){return ee.childMethod(this,e)},t.prototype.ownerApi=function(){return ee.ownerApi(this)},t.prototype.absoluteUriParameters=function(){return ee.absoluteUriParameters(this)},t.prototype.scalarsAnnotations=function(){return new wt(this.highLevel())},t}(Nt);t.ResourceImpl=_t;var Mt=function(){function e(e){this.node=e}return e.prototype.is=function(){var e=this.node.attributes("is");return e.map(function(e){var t=e.annotations(),n=Q.attributesToValues(t,function(e){return new Ct(e)});return n})},e.prototype.type=function(){var e=this.node.attr("type");if(null==e)return[];var t=e.annotations(),n=Q.attributesToValues(t,function(e){return new Ct(e)});return n},e.prototype.description=function(){var e=this.node.attr("description");if(null==e)return[];var t=e.annotations(),n=Q.attributesToValues(t,function(e){return new Ct(e)});return n},e.prototype.securedBy=function(){var e=this.node.attributes("securedBy");return e.map(function(e){var t=e.annotations(),n=Q.attributesToValues(t,function(e){return new Ct(e)});return n})},e}();t.ResourceBaseScalarsAnnotationsImpl=Mt;var wt=function(e){function t(){e.apply(this,arguments)}return X(t,e),t.prototype.displayName=function(){var e=this.node.attr("displayName");if(null==e)return[];var t=e.annotations(),n=Q.attributesToValues(t,function(e){return new Ct(e)});return n},t.prototype.description=function(){var e=this.node.attr("description");if(null==e)return[];var t=e.annotations(),n=Q.attributesToValues(t,function(e){return new Ct(e)});return n},t}(Mt);t.ResourceScalarsAnnotationsImpl=wt;var Rt=function(e){function t(t,n){void 0===n&&(n=!0),e.call(this,"string"==typeof t?k(t):t,n),this.nodeOrKey=t,this.setAsTopLevel=n}return X(t,e),t.prototype.displayName=function(){return e.prototype.attribute.call(this,"displayName",this.toString)},t.prototype.setDisplayName=function(e){return this.highLevel().attrOrCreate("displayName").setValue(""+e),this},t.prototype.name=function(){return e.prototype.attribute.call(this,"name",this.toString)},t.prototype.setName=function(e){return this.highLevel().attrOrCreate("name").setValue(""+e),this},t.prototype.usage=function(){return e.prototype.attribute.call(this,"usage",this.toString)},t.prototype.setUsage=function(e){return this.highLevel().attrOrCreate("usage").setValue(""+e),this},t.prototype.uses=function(){return e.prototype.elements.call(this,"uses")},t.prototype.wrapperClassName=function(){return"ResourceTypeImpl"},t.prototype.kind=function(){return"ResourceType"},t.prototype.allKinds=function(){return e.prototype.allKinds.call(this).concat("ResourceType")},t.prototype.allWrapperClassNames=function(){return e.prototype.allWrapperClassNames.call(this).concat("RAML10.ResourceTypeImpl")},t.isInstance=function(e){if(null!=e&&e.allWrapperClassNames&&"function"==typeof e.allWrapperClassNames)for(var t=0,n=e.allWrapperClassNames();t<n.length;t++){var r=n[t];if("RAML10.ResourceTypeImpl"==r)return!0}return!1},t.prototype.RAMLVersion=function(){return"RAML10"},t.prototype.parametrizedProperties=function(){return ee.getTemplateParametrizedProperties(this)},t.prototype.scalarsAnnotations=function(){return new It(this.highLevel())},t}(Nt);t.ResourceTypeImpl=Rt;var It=function(e){function t(){e.apply(this,arguments)}return X(t,e),t.prototype.displayName=function(){var e=this.node.attr("displayName");if(null==e)return[];var t=e.annotations(),n=Q.attributesToValues(t,function(e){return new Ct(e)});return n},t.prototype.usage=function(){var e=this.node.attr("usage");if(null==e)return[];var t=e.annotations(),n=Q.attributesToValues(t,function(e){return new Ct(e)});return n},t}(Mt);t.ResourceTypeScalarsAnnotationsImpl=It;var Ct=function(e){function t(){e.apply(this,arguments)}return X(t,e),t.prototype.wrapperClassName=function(){return"AnnotationRefImpl"},t.prototype.kind=function(){return"AnnotationRef"},t.prototype.allKinds=function(){return e.prototype.allKinds.call(this).concat("AnnotationRef")},t.prototype.allWrapperClassNames=function(){return e.prototype.allWrapperClassNames.call(this).concat("RAML10.AnnotationRefImpl")},t.isInstance=function(e){if(null!=e&&e.allWrapperClassNames&&"function"==typeof e.allWrapperClassNames)for(var t=0,n=e.allWrapperClassNames();t<n.length;t++){var r=n[t];if("RAML10.AnnotationRefImpl"==r)return!0}return!1},t.prototype.RAMLVersion=function(){return"RAML10"},t.prototype.annotation=function(){return ee.referencedAnnotation(this)},t}(Ne);t.AnnotationRefImpl=Ct;var Lt=function(e){function t(t,n){void 0===n&&(n=!0),e.call(this,"string"==typeof t?K(t):t,n),this.nodeOrKey=t,this.setAsTopLevel=n}return X(t,e),t.prototype.title=function(){return e.prototype.attribute.call(this,"title",this.toString)},t.prototype.setTitle=function(e){return this.highLevel().attrOrCreate("title").setValue(""+e),this},t.prototype.content=function(){return e.prototype.attribute.call(this,"content",function(e){return new pe(e)})},t.prototype.uses=function(){return e.prototype.elements.call(this,"uses")},t.prototype.wrapperClassName=function(){return"DocumentationItemImpl"},t.prototype.kind=function(){return"DocumentationItem"},t.prototype.allKinds=function(){return e.prototype.allKinds.call(this).concat("DocumentationItem")},t.prototype.allWrapperClassNames=function(){return e.prototype.allWrapperClassNames.call(this).concat("RAML10.DocumentationItemImpl")},t.isInstance=function(e){if(null!=e&&e.allWrapperClassNames&&"function"==typeof e.allWrapperClassNames)for(var t=0,n=e.allWrapperClassNames();t<n.length;t++){var r=n[t];if("RAML10.DocumentationItemImpl"==r)return!0}return!1},t.prototype.RAMLVersion=function(){return"RAML10"},t.prototype.scalarsAnnotations=function(){return new Pt(this.highLevel())},t}(te);t.DocumentationItemImpl=Lt;var Pt=function(){function e(e){this.node=e}return e.prototype.title=function(){var e=this.node.attr("title");if(null==e)return[];var t=e.annotations(),n=Q.attributesToValues(t,function(e){return new Ct(e)});return n},e.prototype.content=function(){var e=this.node.attr("content");if(null==e)return[];var t=e.annotations(),n=Q.attributesToValues(t,function(e){return new Ct(e)});return n},e}();t.DocumentationItemScalarsAnnotationsImpl=Pt;var Ot=function(e){function t(t,n){void 0===n&&(n=!0),e.call(this,"string"==typeof t?a(t):t,n),this.nodeOrKey=t,this.setAsTopLevel=n}return X(t,e),t.prototype.uses=function(){return e.prototype.elements.call(this,"uses")},t.prototype.wrapperClassName=function(){return"FragmentDeclarationImpl"},t.prototype.kind=function(){return"FragmentDeclaration"},t.prototype.allKinds=function(){return e.prototype.allKinds.call(this).concat("FragmentDeclaration")},t.prototype.allWrapperClassNames=function(){return e.prototype.allWrapperClassNames.call(this).concat("RAML10.FragmentDeclarationImpl")},t.isInstance=function(e){if(null!=e&&e.allWrapperClassNames&&"function"==typeof e.allWrapperClassNames)for(var t=0,n=e.allWrapperClassNames();t<n.length;t++){var r=n[t];if("RAML10.FragmentDeclarationImpl"==r)return!0}return!1},t.prototype.RAMLVersion=function(){return"RAML10"},t}(te);t.FragmentDeclarationImpl=Ot;var Dt=function(e){function t(t,n){void 0===n&&(n=!0),e.call(this,"string"==typeof t?i(t):t,n),this.nodeOrKey=t,this.setAsTopLevel=n}return X(t,e),t.prototype.schemas=function(){return e.prototype.elements.call(this,"schemas")},t.prototype.types=function(){return e.prototype.elements.call(this,"types")},t.prototype.traits_original=function(){return e.prototype.elements.call(this,"traits")},t.prototype.resourceTypes_original=function(){return e.prototype.elements.call(this,"resourceTypes")},t.prototype.annotationTypes=function(){return e.prototype.elements.call(this,"annotationTypes")},t.prototype.securitySchemes=function(){return e.prototype.elements.call(this,"securitySchemes")},t.prototype.wrapperClassName=function(){return"LibraryBaseImpl"},t.prototype.kind=function(){return"LibraryBase"},t.prototype.allKinds=function(){return e.prototype.allKinds.call(this).concat("LibraryBase")},t.prototype.allWrapperClassNames=function(){return e.prototype.allWrapperClassNames.call(this).concat("RAML10.LibraryBaseImpl")},t.isInstance=function(e){if(null!=e&&e.allWrapperClassNames&&"function"==typeof e.allWrapperClassNames)for(var t=0,n=e.allWrapperClassNames();t<n.length;t++){var r=n[t];if("RAML10.LibraryBaseImpl"==r)return!0}return!1},t.prototype.RAMLVersion=function(){return"RAML10"},t.prototype.traits=function(){return ee.traitsPrimary(this)},t.prototype.allTraits=function(){return ee.allTraits(this)},t.prototype.resourceTypes=function(){return ee.resourceTypesPrimary(this)},t.prototype.allResourceTypes=function(){return ee.allResourceTypes(this)},t}(Ot);t.LibraryBaseImpl=Dt;var xt=function(e){function t(t,n){void 0===n&&(n=!0),e.call(this,"string"==typeof t?V(t):t,n),this.nodeOrKey=t,this.setAsTopLevel=n}return X(t,e),t.prototype.usage=function(){return e.prototype.attribute.call(this,"usage",this.toString)},t.prototype.setUsage=function(e){return this.highLevel().attrOrCreate("usage").setValue(""+e),this},t.prototype.name=function(){return e.prototype.attribute.call(this,"name",this.toString)},t.prototype.setName=function(e){return this.highLevel().attrOrCreate("name").setValue(""+e),this},t.prototype.wrapperClassName=function(){return"LibraryImpl"},t.prototype.kind=function(){return"Library"},t.prototype.allKinds=function(){return e.prototype.allKinds.call(this).concat("Library")},t.prototype.allWrapperClassNames=function(){return e.prototype.allWrapperClassNames.call(this).concat("RAML10.LibraryImpl")},t.isInstance=function(e){if(null!=e&&e.allWrapperClassNames&&"function"==typeof e.allWrapperClassNames)for(var t=0,n=e.allWrapperClassNames();t<n.length;t++){var r=n[t];if("RAML10.LibraryImpl"==r)return!0}return!1},t.prototype.RAMLVersion=function(){return"RAML10"},t.prototype.scalarsAnnotations=function(){return new Ut(this.highLevel())},t}(Dt);t.LibraryImpl=xt;var Ut=function(){function e(e){this.node=e}return e.prototype.usage=function(){var e=this.node.attr("usage");if(null==e)return[];var t=e.annotations(),n=Q.attributesToValues(t,function(e){return new Ct(e)});return n},e}();t.LibraryScalarsAnnotationsImpl=Ut;var kt=function(e){function t(t,n){void 0===n&&(n=!0),e.call(this,"string"==typeof t?r(t):t,n),this.nodeOrKey=t,this.setAsTopLevel=n}return X(t,e),t.prototype.title=function(){return e.prototype.attribute.call(this,"title",this.toString)},t.prototype.setTitle=function(e){return this.highLevel().attrOrCreate("title").setValue(""+e),this},t.prototype.description=function(){return e.prototype.attribute.call(this,"description",function(e){return new pe(e)})},t.prototype.version=function(){return e.prototype.attribute.call(this,"version",this.toString)},t.prototype.setVersion=function(e){return this.highLevel().attrOrCreate("version").setValue(""+e),this},t.prototype.baseUri=function(){return e.prototype.attribute.call(this,"baseUri",function(e){return new oe(e)})},t.prototype.baseUriParameters_original=function(){return e.prototype.elements.call(this,"baseUriParameters")},t.prototype.protocols=function(){return e.prototype.attributes.call(this,"protocols",this.toString)},t.prototype.setProtocols=function(e){return this.highLevel().attrOrCreate("protocols").setValue(""+e),this},t.prototype.mediaType=function(){return e.prototype.attributes.call(this,"mediaType",function(e){return new fe(e)})},t.prototype.securedBy=function(){return e.prototype.attributes.call(this,"securedBy",function(e){return new it(e)})},t.prototype.resources=function(){return e.prototype.elements.call(this,"resources")},t.prototype.documentation=function(){return e.prototype.elements.call(this,"documentation")},t.prototype.annotations=function(){return e.prototype.attributes.call(this,"annotations",function(e){return new Ct(e)})},t.prototype.wrapperClassName=function(){return"ApiImpl"},t.prototype.kind=function(){return"Api"},t.prototype.allKinds=function(){return e.prototype.allKinds.call(this).concat("Api")},t.prototype.allWrapperClassNames=function(){return e.prototype.allWrapperClassNames.call(this).concat("RAML10.ApiImpl")},t.isInstance=function(e){if(null!=e&&e.allWrapperClassNames&&"function"==typeof e.allWrapperClassNames)for(var t=0,n=e.allWrapperClassNames();t<n.length;t++){var r=n[t];if("RAML10.ApiImpl"==r)return!0}return!1},t.prototype.RAMLVersion_original=function(){return"RAML10"},t.prototype.expand=function(e){return void 0===e&&(e=!1),ee.expandSpec(this,e)},t.prototype.childResource=function(e){return ee.childResource(this,e)},t.prototype.allResources=function(){return ee.allResources(this)},t.prototype.baseUriParameters=function(){return ee.baseUriParametersPrimary(this)},t.prototype.allBaseUriParameters=function(){return ee.baseUriParameters(this)},t.prototype.allProtocols=function(){return ee.allProtocols(this)},t.prototype.RAMLVersion=function(){return ee.RAMLVersion(this)},t.prototype.scalarsAnnotations=function(){return new Bt(this.highLevel())},t}(Dt);t.ApiImpl=kt;var Ft=function(e){function t(t,n){void 0===n&&(n=!0),e.call(this,"string"==typeof t?j(t):t,n),this.nodeOrKey=t,this.setAsTopLevel=n}return X(t,e),t.prototype.usage=function(){return e.prototype.attribute.call(this,"usage",this.toString)},t.prototype.setUsage=function(e){return this.highLevel().attrOrCreate("usage").setValue(""+e),this},t.prototype["extends"]=function(){return e.prototype.attribute.call(this,"extends",this.toString)},t.prototype.setExtends=function(e){return this.highLevel().attrOrCreate("extends").setValue(""+e),this},t.prototype.title=function(){return e.prototype.attribute.call(this,"title",this.toString)},t.prototype.setTitle=function(e){return this.highLevel().attrOrCreate("title").setValue(""+e),this},t.prototype.wrapperClassName=function(){return"OverlayImpl"},t.prototype.kind=function(){return"Overlay"},t.prototype.allKinds=function(){return e.prototype.allKinds.call(this).concat("Overlay")},t.prototype.allWrapperClassNames=function(){return e.prototype.allWrapperClassNames.call(this).concat("RAML10.OverlayImpl")},t.isInstance=function(e){if(null!=e&&e.allWrapperClassNames&&"function"==typeof e.allWrapperClassNames)for(var t=0,n=e.allWrapperClassNames();t<n.length;t++){var r=n[t];if("RAML10.OverlayImpl"==r)return!0}return!1},t.prototype.RAMLVersion=function(){return"RAML10"},t.prototype.scalarsAnnotations=function(){return new Kt(this.highLevel())},t}(kt);t.OverlayImpl=Ft;var Bt=function(){function e(e){this.node=e}return e.prototype.title=function(){var e=this.node.attr("title");if(null==e)return[];var t=e.annotations(),n=Q.attributesToValues(t,function(e){return new Ct(e)});return n},e.prototype.description=function(){var e=this.node.attr("description");if(null==e)return[];var t=e.annotations(),n=Q.attributesToValues(t,function(e){return new Ct(e)});return n},e.prototype.version=function(){var e=this.node.attr("version");if(null==e)return[];var t=e.annotations(),n=Q.attributesToValues(t,function(e){return new Ct(e)});return n},e.prototype.baseUri=function(){var e=this.node.attr("baseUri");if(null==e)return[];var t=e.annotations(),n=Q.attributesToValues(t,function(e){return new Ct(e)});return n},e.prototype.protocols=function(){var e=this.node.attributes("protocols");return e.map(function(e){var t=e.annotations(),n=Q.attributesToValues(t,function(e){return new Ct(e)});return n})},e.prototype.mediaType=function(){var e=this.node.attributes("mediaType");return e.map(function(e){var t=e.annotations(),n=Q.attributesToValues(t,function(e){return new Ct(e)});return n})},e.prototype.securedBy=function(){var e=this.node.attributes("securedBy");return e.map(function(e){var t=e.annotations(),n=Q.attributesToValues(t,function(e){return new Ct(e)});return n})},e}();t.ApiScalarsAnnotationsImpl=Bt;var Kt=function(e){function t(){e.apply(this,arguments)}return X(t,e),t.prototype.usage=function(){var e=this.node.attr("usage");if(null==e)return[];var t=e.annotations(),n=Q.attributesToValues(t,function(e){return new Ct(e)});return n},t.prototype["extends"]=function(){var e=this.node.attr("extends");if(null==e)return[];var t=e.annotations(),n=Q.attributesToValues(t,function(e){return new Ct(e)});return n},t.prototype.title=function(){var e=this.node.attr("title");if(null==e)return[];var t=e.annotations(),n=Q.attributesToValues(t,function(e){return new Ct(e)});return n},t}(Bt);t.OverlayScalarsAnnotationsImpl=Kt;var Vt=function(e){function t(t,n){void 0===n&&(n=!0),e.call(this,"string"==typeof t?W(t):t,n),this.nodeOrKey=t,this.setAsTopLevel=n}return X(t,e),t.prototype.usage=function(){return e.prototype.attribute.call(this,"usage",this.toString)},t.prototype.setUsage=function(e){return this.highLevel().attrOrCreate("usage").setValue(""+e),this},t.prototype["extends"]=function(){return e.prototype.attribute.call(this,"extends",this.toString)},t.prototype.setExtends=function(e){return this.highLevel().attrOrCreate("extends").setValue(""+e),this},t.prototype.title=function(){return e.prototype.attribute.call(this,"title",this.toString)},t.prototype.setTitle=function(e){
return this.highLevel().attrOrCreate("title").setValue(""+e),this},t.prototype.wrapperClassName=function(){return"ExtensionImpl"},t.prototype.kind=function(){return"Extension"},t.prototype.allKinds=function(){return e.prototype.allKinds.call(this).concat("Extension")},t.prototype.allWrapperClassNames=function(){return e.prototype.allWrapperClassNames.call(this).concat("RAML10.ExtensionImpl")},t.isInstance=function(e){if(null!=e&&e.allWrapperClassNames&&"function"==typeof e.allWrapperClassNames)for(var t=0,n=e.allWrapperClassNames();t<n.length;t++){var r=n[t];if("RAML10.ExtensionImpl"==r)return!0}return!1},t.prototype.RAMLVersion=function(){return"RAML10"},t.prototype.scalarsAnnotations=function(){return new jt(this.highLevel())},t}(kt);t.ExtensionImpl=Vt;var jt=function(e){function t(){e.apply(this,arguments)}return X(t,e),t.prototype.usage=function(){var e=this.node.attr("usage");if(null==e)return[];var t=e.annotations(),n=Q.attributesToValues(t,function(e){return new Ct(e)});return n},t.prototype["extends"]=function(){var e=this.node.attr("extends");if(null==e)return[];var t=e.annotations(),n=Q.attributesToValues(t,function(e){return new Ct(e)});return n},t.prototype.title=function(){var e=this.node.attr("title");if(null==e)return[];var t=e.annotations(),n=Q.attributesToValues(t,function(e){return new Ct(e)});return n},t}(Bt);t.ExtensionScalarsAnnotationsImpl=jt,t.loadApiSync=q,t.loadRAMLSync=Y,t.loadApi=H,t.loadRAML=$,t.getLanguageElementByRuntimeType=G},function(e,t,n){"use strict";var r,i=n(68),a=function(e){return null!=e},o=function(){function e(t){var n=this;this._value=t,this._isDefined=!1,this._isEmpty=!0,this._arr=void 0,this.getOrThrow=function(){return i(n._isDefined,"Opt is empty. Use `Opt#getOrElse` or check `Opt#isDefined`."),n._value},this.value=function(){return n._value},this.isDefined=function(){return n._isDefined},this.isEmpty=function(){return n._isEmpty},this.toArray=function(){return n._arr||(n._arr=n._isDefined?[n._value]:[])},this.getOrElse=function(e){return n._isDefined?n._value:e},this.getOrElseF=function(e){return n._isDefined?n._value:e()},this.map=function(t){return n._isEmpty?e.empty():new e(t(n._value))},this.flatMap=function(t){return n.map(t).getOrElse(e.empty())},this.equals=function(t){return i(t instanceof e,"Expected other to be an `Opt`, but got `%s`",typeof t),n._isDefined===t.isDefined()&&n._value===t.value()},a(this._value)&&(this._isDefined=!0,this._isEmpty=!1)}return e.prototype.forEach=function(e){this.isDefined()&&e(this._value)},e.empty=function(){return r||(r=new e)},e}();e.exports=o},function(e,t,n){"use strict";function r(e){for(var t=[],n={};null!=e.parent();)e.lowLevel().includePath()&&(t=t.concat(a(e,n))),e=e.parent();return t=t.concat(a(e,n))}function i(e){var t=e.node();if(t&&x.isParseResult(t))return t;var n=V.getNominalPropertySource2(e);return n?n.getSource():null}function a(e,t,n){if(void 0===t&&(t={}),void 0===n&&(n=[]),!e.lowLevel())return[];var r=e.lowLevel().unit().absolutePath();if(t[r]=!0,!F.ASTNodeImpl.isInstance(e))return n;var i=!1;return e.elements().forEach(function(e){if(e.definition().key()==B.Universe10.UsesDeclaration){if(i)return;var r=e.attr("value");if(r){var o=e.root().lowLevel().unit().resolve(r.value());if(o&&j.isWaitingFor(o.absolutePath()))return void(i=!0);null!=o&&o.isRAMLUnit()&&!t[o.absolutePath()]&&o.highLevel().isElement()&&a(o.highLevel().asElement(),t,n)}}else n.push(e)}),n}function o(e,t){for(var n="",r=e-1;r>=0;r--){var i=t.charAt(r);if(" "==i||"	"==i)n?n+=i:n=i;else if("\r"==i||"\n"==i)return n}}function s(e,t,n,r,i){if(void 0===r&&(r=!0),void 0===i&&(i=!0),null==e)return null;if(e.lowLevel()&&e.lowLevel().start()<=t&&e.lowLevel().end()>=n){if(F.ASTNodeImpl.isInstance(e)){for(var a=e,o=r?a.children():a.directChildren(),u=0;u<o.length;u++)if(r||o[u].lowLevel().unit()==e.lowLevel().unit()){var l=s(o[u],t,n,r);if(l)return!i&&F.ASTPropImpl.isInstance(l)&&(l=l.parent()),l}return e}if(F.ASTPropImpl.isInstance(e)){var p=e;if(!p.property().isKey()){var c=p.value();if(F.StructuredValue.isInstance(c)){var f=c,m=f.toHighLevel2();if(m&&!r&&m.lowLevel().unit()!=e.lowLevel().unit())return null;var l=s(m,t,n,r);if(l)return!i&&F.ASTPropImpl.isInstance(l)&&(l=l.parent()),l}return i?p:p.parent()}return null}return null}return null}function u(e,t){for(var n=-1,r=t-1;r>=0;r--){var i=e.charAt(r);if("\r"==i||"\n"==i||" "==i||"	"==i||'"'==i||"'"==i||":"==i){n=r+1;break}}for(var a=-1,r=t;r<e.length;r++){var i=e.charAt(r);if("\r"==i||"\n"==i||" "==i||"	"==i||'"'==i||"'"==i||":"==i){a=r;break}}return-1!=n&&-1!=a?e.substring(n,a):""}function l(e,t){for(var n="",r=t;r>=0;r--){var i=e[r];if(" "==i||"\r"==i||"\n"==i||"|"==i||"["==i||"]"==i||":"==i||"("==i||")"==i)break;n=i+n}for(var r=t+1;r<e.length;r++){var i=e[r];if(" "==i||"\r"==i||"\n"==i||"|"==i||"["==i||"]"==i||":"==i||"("==i||")"==i||","==i)break;n+=i}return n}function p(e,t){var n=h(e,t);if(n){if(F.ASTNodeImpl.isInstance(n)){var r=n;return{node:r,results:r.findReferences()}}F.ASTPropImpl.isInstance(n)}var i=s(F.fromUnit(e),t,t,!1);if(F.ASTNodeImpl.isInstance(i))return{node:i,results:i.findReferences()};if(F.ASTPropImpl.isInstance(i)){var a=i;if(a.property().canBeValue())return{node:a.parent(),results:a.parent().findReferences()}}return{node:null,results:[]}}function c(e,t){var n=e;if(n.getAdapter(K.RAMLPropertyService).isTypeExpr()){var i=r(t).filter(function(e){var t=e.definition().key();return t===B.Universe08.GlobalSchema?!0:e.definition().isAssignableFrom(B.Universe10.TypeDeclaration.name)});return i}if(n.getAdapter(K.RAMLPropertyService).isDescriminating()){var a=M(n.range(),t);return a}if(n.isReference()){var o=n.referencesTo(),a=M(o,t);return a}if(n.range().hasValueTypeInHierarchy()){var s=n.range().getAdapter(K.RAMLService);if(s.globallyDeclaredBy().length>0){var i=r(t).filter(function(e){return null!=U.find(s.globallyDeclaredBy(),function(t){return t==e.definition()})});return i}}return[]}function f(e,t){if(t){var n=[];if(e.getAdapter(K.RAMLPropertyService).isTypeExpr()){var i=r(t).filter(function(e){var t=e.definition().key();return t===B.Universe08.GlobalSchema?!0:e.definition().isAssignableFrom(B.Universe10.TypeDeclaration.name)});n=i.map(function(e){return F.qName(e,t)});var a=t.definition().universe().type(B.Universe10.TypeDeclaration.name);if(a){var o=a.allSubTypes();n=n.concat(o.map(function(e){return e.getAdapter(K.RAMLService).descriminatorValue()}))}return n}var s=e.range().key();if((s==B.Universe08.SchemaString||s==B.Universe10.SchemaString)&&"RAML10"==e.range().universe().version()&&e.range().hasValueTypeInHierarchy()){var i=r(t).filter(function(e){return e.definition().isAssignableFrom(B.Universe10.TypeDeclaration.name)});n=i.map(function(e){return F.qName(e,t)})}if(e.getAdapter(K.RAMLPropertyService).isDescriminating()){var o=b(e.domain(),t);n=n.concat(o.map(function(e){return e.getAdapter(K.RAMLService).descriminatorValue()}))}else if(e.isReference()){var u=M(e.referencesTo(),t);n=u.map(function(e){return F.qName(e,t)})}else if(e.range().hasValueTypeInHierarchy()){var l=e.range().getAdapter(K.RAMLService);if(l.globallyDeclaredBy().length>0){var i=r(t).filter(function(e){return null!=U.find(l.globallyDeclaredBy(),function(t){return t==e.definition()})});n=n.concat(i.map(function(e){return F.qName(e,t)}))}}return e.isAllowNull()&&n.push("null"),e.enumOptions()&&(n=n.concat(e.enumOptions())),n}return e.enumOptions()&&"string"==typeof e.enumOptions()?[e.enumOptions()+""]:e.enumOptions()}function m(e){return e.isElement()&&e.asElement().definition().key()!=B.Universe10.Library?null:e.asElement().attrValue("name")}function d(e,t){var n=e.lowLevel().unit();if(!n)return null;var r=e.lowLevel().start(),i=e.lowLevel().end();if(t&&t==q.KEY_COMPLETION?(r=e.lowLevel().keyStart(),i=e.lowLevel().keyEnd()):t&&t==q.VALUE_COMPLETION&&(r=e.lowLevel().valueStart(),i=e.lowLevel().valueEnd()),-1==r||-1==i)return null;var a=Math.floor((r+i)/2);return h(n,a,t)}function h(e,t,n){var r=s(F.fromUnit(e),t,t,!1),a=null;if(r.isElement()&&r.asElement().definition().isAssignableFrom(B.Universe10.TypeDeclaration.name)&&r.asElement().directChildren().forEach(function(e){if(e.isUnknown()&&e.getLowLevelStart()<t&&e.getLowLevelEnd()>t){var n=r.asElement().localType();n.allFacets().forEach(function(t){if(t.nameId()==e.lowLevel().key()&&k.UserDefinedProp.isInstance(t)){var n=i(t);a=n}})}}),!r.property())return r;if("example"==r.property().nameId()){r.parent().localType();r.lowLevel().children().forEach(function(e){"example"==e.key()&&e.children().forEach(function(e){if(e.start()<t&&e.end()>t){var n=r.parent().asElement().localType();n.allProperties().forEach(function(t){if(t.nameId()==e.key()&&k.UserDefinedProp.isInstance(t)){var n=i(t);a=n}})}})})}if(a)return a;var o=null!=n?n:T(e.contents(),t);if(o==q.VALUE_COMPLETION){var l=r;if(F.ASTPropImpl.isInstance(r)){var p=r;if(p&&p.value()){if(!F.StructuredValue.isInstance(p.value()))return W(t,e.contents(),p,l);var c=p.value(),f=c.toHighLevel();if(f){var m=U.find(f.attrs(),function(e){return e.lowLevel().start()<t&&e.lowLevel().end()>=t});if(m)return W(t,e.contents(),m,f,p.property())}}}else{var d=l.property();if(d)return W(t,e.contents(),null,l,d)}}if(o==q.KEY_COMPLETION||o==q.SEQUENCE_KEY_COPLETION){var l=r,h=r.property();if(D.UserDefinedProp.isInstance(h)){var g=h;return i(g)}if(F.ASTNodeImpl.isInstance(r)&&D.isUserDefinedClass(l.definition())){var A=l.definition();return A.isAssignableFrom("TypeDeclaration")?r:A.getAdapter(K.RAMLService).getDeclaringNode()}if(F.ASTPropImpl.isInstance(r)){var E=r;if(S(E)){var b=y(E);if(b){var N=v(E,b);if(N){var r=s(N,t,t);if(h=r.property(),D.UserDefinedProp.isInstance(h)){var g=h;return i(g)}if(F.ASTNodeImpl.isInstance(r)&&D.isUserDefinedClass(l.definition())){var A=l.definition();return A.getAdapter(K.RAMLService).getDeclaringNode()}}}}}}if(o==q.PATH_COMPLETION){var _=u(e.contents(),t);if(_){var M=e.resolve(_);return M}}}function y(e){var t=null;if(e.isElement()?t=e:e.isAttr()&&(t=e.parent()),!t.definition().isAssignableFrom(B.Universe10.TypeDeclaration.name)){var n=t.parent();if(!n)return null;if(n.definition().isAssignableFrom(B.Universe10.TypeDeclaration.name))t=n;else{if(n=n.parent(),null==n)return null;if(!n.definition().isAssignableFrom(B.Universe10.TypeDeclaration.name))return null;t=n}}return t.localType()}function v(e,t){return F.StructuredValue.isInstance(e.value())?new F.ASTNodeImpl(e.value().lowLevel(),e.parent(),t,e.property()):null}function g(e,t){return new F.ASTNodeImpl(e.lowLevel(),e,t,e.property())}function A(e){return e.definition().key()==B.Universe10.ExampleSpec}function S(e){var t=B.Universe10.TypeDeclaration.properties.example.name,n=B.Universe10.ObjectTypeDeclaration.name;if(!F.ASTPropImpl.isInstance(e))return!1;var r=e,i=r.parent(),a=i&&i.property();a&&a.nameId();return t===r.name()&&r.isString()&&F.ASTNodeImpl.isInstance(i)&&i.definition().isAssignableFrom(n)?!0:!1}function T(e,t){for(var n=!1,r=!1,i=!1,a=t-1;a>=0;a--){var s=e.charAt(a);if("("==s)i=!0;else{if(i){if("\r"==s||"\n"==s){for(var u=!1,l=t-1;l<e.length;l++){var p=e[l];if(")"==p&&(u=!0),"\r"==p||"\n"==p)break;if(":"==p){i=!1;break}}if(i&&u)return q.ANNOTATION_COMPLETION;break}if(" "==s||"	"==s)continue;break}if("\r"==s||"\n"==s)break;if(":"==s)break}}for(var a=t-1;a>=0;a--){var s=e.charAt(a);if("#"==s){if(0==a)return q.VERSION_COMPLETION;for(var l=a-1;l>=0;l--){var c=e.charAt(l);if("\r"==c||"\n"==c)break;if("!"==c&&e.indexOf("!include",l)==l)return q.PATH_COMPLETION}return q.INCOMMENT}if(":"==s)return n?q.DIRECTIVE_COMPLETION:q.VALUE_COMPLETION;if("\r"==s||"\n"==s){for(var f=!1,m=o(t,e),d=a;d>0;d--){if(s=e.charAt(d),":"==s){if(f){var h=o(d,e);if(h.length<m.length)return q.VALUE_COMPLETION}break}"|"!=s?(("\r"==s||"\n"==s)&&(f=!1)," "!=s&&"	"!=s&&(f=!1)):f=!0}return r?q.SEQUENCE_KEY_COPLETION:q.KEY_COMPLETION}if("-"==s&&(r=!0),"!"==s){if(e.indexOf("!include",a)==a)return q.PATH_COMPLETION;e.indexOf("!i",a)==a&&(n=!0)}}}function E(e,t){if(!t)return null;for(var n=t.split("/"),r=e,i=0;i<n.length;i++)if("#"!=n[i]){if(r=U.find(r.children(),function(e){return e.key()==n[i]}),!r)return null}else r=e.unit().ast();return r}function b(e,n){if(null==e)return[];var i=e.nameId();n=t.declRoot(n);var a=n;if(a._subTypesCache){var o=a._subTypesCache[i];if(o)return o}else a._subTypesCache={};var s=e.allSubTypes();if(e.getAdapter(K.RAMLService).getRuntimeExtenders().length>0&&n){var u=r(n),l=e.getAdapter(K.RAMLService).getRuntimeExtenders();n.root();l.forEach(function(t){var n=u.filter(function(n){var r=n.definition().allSuperTypes();r.push(n.definition());var i=n.definition()==t||null!=U.find(r,function(e){return e==t})||null!=U.find(r,function(t){return t==e});return i});s=s.concat(n.map(function(e){return e.localType()}))})}return s=U.unique(s),a._subTypesCache[i]=s,s}function N(e,n,i){n=t.declRoot(n);var a=r(n),o=U.find(a,function(t){return F.qName(t,n)==e&&t.property()&&t.property().nameId()==B.Universe10.LibraryBase.properties.types.name});return o.localType()}function _(e,n,i){n=t.declRoot(n);var a=r(n),o=U.find(a,function(t){return F.qName(t,n)==e&&t.property()&&t.property().nameId()==B.Universe10.LibraryBase.properties.schemas.name});return o.localType()}function M(e,t){var n=[],i=[e].concat(e.getAdapter(K.RAMLService).getRuntimeExtenders());if(t){var a=t;i.forEach(function(e){var t=r(a),i=t.filter(function(t){return t.definition().isAssignableFrom(e.nameId())});n=n.concat(i)})}var o=!e.hasValueTypeInHierarchy();if(o&&e.getAdapter(K.RAMLService).isInlinedTemplates()&&t){var a=t,s=r(a).filter(function(t){return t.definition()==e});n=n.concat(s)}else{var a=t,u={};e.allSubTypes().forEach(function(e){return u[e.nameId()]=!0}),u[e.nameId()]=!0;var s=r(a).filter(function(e){return u[e.definition().nameId()]});n=n.concat(s)}return n}function w(e,t){var n=e.range();return b(n,t)}function R(e,t){if(t){if(e.isDescriminator()){var n=e.range(),i=n.getAdapter(K.RAMLService).getRuntimeExtenders();if(i.length>0&&t){var a=[];return i.forEach(function(e){var n=r(t).filter(function(t){return t.definition()==e});a=a.concat(n)}),a}return[]}if(e.isReference())return M(e.referencesTo(),t);if(e.range().hasValueTypeInHierarchy()){var o=e.range().getAdapter(K.RAMLService);if(o.globallyDeclaredBy&&o.globallyDeclaredBy().length>0){var s=r(t).filter(function(e){return null!=U.find(o.globallyDeclaredBy(),function(t){return t==e.definition()})});return s}}}return[]}function I(e){var t=[];return C(e,t),t}function C(e,t){e.children().forEach(function(e){t.push(e),C(e,t)})}function L(e,t,n){e.elements().forEach(function(e){L(e,t,n);e.definition()}),e.attrs().forEach(function(r){var i=r.property(),a=r.value();if(D.UserDefinedProp.isInstance(i)){var o=i.node();o==t?n.push(r):o.lowLevel().start()==t.lowLevel().start()&&o.lowLevel().unit()==t.lowLevel().unit()&&n.push(r)}if(S(r)){var s=y(r);if(s){var u=v(r,s);u&&L(u,t,n)}}else if(i.getAdapter(K.RAMLPropertyService).isTypeExpr()&&"string"==typeof a){var l=e.localType();Y(l,r,t,n);var p=m(t);if(p&&-1!=a.indexOf(p)){var c=P(r);c&&c.lowLevel().start()==t.lowLevel().start()&&n.push(r)}}if(i.isReference()||i.isDescriminator())if("string"==typeof a){var f=R(i,e);U.find(f,function(e){return e.name()==a&&e==t})&&n.push(r);var p=m(t);if(p&&-1!=a.indexOf(p)){var c=P(r);c&&c.lowLevel().start()==t.lowLevel().start()&&n.push(r)}}else{var d=a;if(d){var h=d.valueName(),f=R(i,e);U.find(f,function(e){return e.name()==h&&e==t})&&n.push(r);var g=d.toHighLevel();g&&L(g,t,n);var p=m(t);if(p&&-1!=h.indexOf(p)){var c=P(g);c&&c.lowLevel().start()==t.lowLevel().start()&&n.push(r)}}}else{var f=R(i,e);U.find(f,function(e){return e.name()==a&&e==t})&&n.push(r)}})}function P(e){if(!e.lowLevel)return null;var t=e.lowLevel();if(!t)return null;if(t.key()){var n=Math.floor((t.keyEnd()+t.keyStart())/2),r=O(t.unit(),n);if(r)return r}if(t.value()){var n=Math.floor((t.valueEnd()+t.valueStart())/2),r=O(t.unit(),n);if(r)return r}return null}function O(e,t){var n=h(e,t);if(n&&n.isElement&&n.isElement())for(var r=n.asElement(),i=r;i;){if(i.definition().key()==B.Universe10.Library)return i;i=i.parent()}return null}var D=n(37),x=n(9),U=n(64),k=n(37),F=n(16),B=n(17),K=k,V=n(25),j=n(27);t.declRoot=function(e){for(var t=e;;){if(t.definition().key()==B.Universe10.Library)break;var n=t.parent();if(!n)break;t=n}return t},t.globalDeclarations=r,t.findDeclarations=a,t.deepFindNode=s,t.extractName=l;var W=function(e,t,n,r,a){void 0===a&&(a=n.property());var o=c(a,r),s=l(t,e),u=U.find(o,function(e){return F.qName(e,r)==s});if(u)return u;if(D.UserDefinedProp.isInstance(a)){var p=a;return i(p)}return null};t.findUsages=p,t.referenceTargets=c,t.enumValues=f,t.findDeclarationByNode=d,t.findDeclaration=h,t.findExampleContentType=y,t.parseDocumentationContent=v,t.parseStructuredExample=g,t.isExampleNode=A,t.isExampleNodeContent=S,t.determineCompletionKind=T,function(e){e[e.VALUE_COMPLETION=0]="VALUE_COMPLETION",e[e.KEY_COMPLETION=1]="KEY_COMPLETION",e[e.PATH_COMPLETION=2]="PATH_COMPLETION",e[e.DIRECTIVE_COMPLETION=3]="DIRECTIVE_COMPLETION",e[e.VERSION_COMPLETION=4]="VERSION_COMPLETION",e[e.ANNOTATION_COMPLETION=5]="ANNOTATION_COMPLETION",e[e.SEQUENCE_KEY_COPLETION=6]="SEQUENCE_KEY_COPLETION",e[e.INCOMMENT=7]="INCOMMENT"}(t.LocationKind||(t.LocationKind={}));var q=t.LocationKind;t.resolveReference=E,t.subTypesWithLocals=b,t.subTypesWithName=N,t.schemasWithName=_,t.nodesDeclaringType=M,t.findAllSubTypes=w,t.allChildren=I;var Y=function(e,t,n,r){var i=e.getAdapter(K.RAMLService).getDeclaringNode();if(i&&n.isSameNode(i))return void r.push(t);if(e.isArray()&&Y(e.array().componentType(),t,n,r),e.isUnion()){var a=e.union();Y(a.leftType(),t,n,r),Y(a.rightType(),t,n,r)}e.superTypes().some(function(e){return e.nameId()==n.name()})&&r.push(t)};t.refFinder=L},function(e,t,n){"use strict";function r(e){var t=e.getExtra(p.SOURCE_EXTRA);return null==t?null:l.isSourceProvider(t)?t:f.isLowLevelNode(t)?{getSource:function(){return t.highLevelNode()}}:c.isParseResult(t)?{getSource:function(){return t}}:null}function i(e){return r(e)}function a(e){var t=e.getAdapters();return t?d.find(t,function(e){return l.rt.isParsedType(e)}):null}function o(e){if(!e)return null;var t=e.getExtra(p.SOURCE_EXTRA);if(t)return r(e);var n=a(e);return n?i(n):null}function s(e,t){var n=o(e);return n?{getSource:function(){var e=n.getSource(),r=e.asElement();if(null==r)return null;var i=r.elementsOfKind(m.Universe10.ObjectTypeDeclaration.properties.properties.name);return null==i||0==i.length?null:d.find(i,function(e){return t==e.attrValue(m.Universe10.TypeDeclaration.properties.name.name)})}}:null}function u(e){return s(e.domain(),e.nameId())}var l=n(37),p=l.rt,c=n(9),f=n(10),m=n(17),d=n(64);t.getExtraProviderSource=r,t.getRTypeSource=i,t.findRTypeByNominal=a,t.getNominalTypeSource=o,t.getNominalPropertySource=s,t.getNominalPropertySource2=u},function(e,t,n){"use strict";function r(){return new W}function i(e){if(null==e)return null;switch(e.kind){case M.Kind.SCALAR:return{errors:[],startPosition:e.startPosition,endPosition:e.endPosition,value:e.value,kind:M.Kind.SCALAR,parent:e.parent};case M.Kind.MAPPING:var t=e;return{errors:[],key:i(t.key),value:i(t.value),startPosition:t.startPosition,endPosition:t.endPosition,kind:M.Kind.MAPPING,parent:t.parent};case M.Kind.MAP:var n=e;return{errors:[],startPosition:e.startPosition,endPosition:e.endPosition,mappings:n.mappings.map(function(e){return i(e)}),kind:M.Kind.MAP,parent:n.parent}}return e}function a(e){var t=e.match(/^.*((\r\n|\n|\r)|$)/gm);return t}function o(e,t){for(var n=a(e),r=[],i=0;i<n.length;i++)0==i?r.push(n[0]):r.push(n[i].substring(t.length));return r.join("")}function s(e){for(var t="",n=0;n<e.length;n++){var r=e[n];if("\r"!=r&&"\n"!=r){if(" "!=r&&"	"!=r)break;t+=r}}return t}function u(e,t){var n=e.substr(t.offset,t.replacementLength);return-1!=n.indexOf("\n")?!0:-1!=t.text.indexOf("\n")?!0:void 0}function l(e){if("null"==e)e=null;else if("~"==e)e=null;else if("true"==e)e=!0;else if("false"==e)e=!1;else{var t=parseFloat(e);isNaN(t)||(""+e).match("^[-+]?[0-9]*\\.?[0-9]+$")&&(e=t)}return e}function p(e,t,n){var r=M.newMapping(M.newScalar(e),M.newMap());return new z(r,n,t,null,null)}function c(e){var t=M.newMap(e);return new z(t,null,null,null,null)}function f(e){var t=M.newScalar(e);return new z(t,null,null,null,null)}function m(e,t,n){return new z(e,n,t,null,null)}function d(e){var t=M.newMapping(M.newScalar(e),M.newItems());return new z(t,null,null,null,null)}function h(e){var t=M.newMapping(M.newScalar(e),M.newMap());return new z(t,null,null,null,null)}function y(e,t){var n=M.newMapping(M.newScalar(e),M.newScalar(t));return new z(n,null,null,null,null)}function v(e){if(!z.isInstance(e))return null;var t=e,n=new z(t.yamlNode(),t.unit(),null,null,null,!0);return n._errors=t._errors,n}function g(e){if(!z.isInstance(e))return null;var t=e,n=new z(t.yamlNode(),t.unit(),null,null,null,!1);return n._errors=t._errors,n}function A(e){var t=e.highLevelNode();if(t)return t.definition();var n=e.parent();if(!n)return null;var r=e.key();if(!r)return null;var i=n.nodeDefinition();if(!i)return null;if(!i.property)return null;var a=i.property(r);return a?a.range():null}function S(e,t,n,r){if(e.isOverlayOrExtension()){var i=e.getMasterReferenceNode();if(i){var a=i.value();if(a){var o=b.dirname(e.absolutePath()),s=E.toAbsolutePath(o,a);if(!t[s]){if(n[s])return void i.errors().push(new F(n[a]));var u=r[s];u||(u=[],r[s]=u),u.push(i)}}}}}function T(e,t){var n={},r={},i=[],a=function(t){for(var o=[],s={};t<i.length;){var u=i[t],l=u.absolutePath();S(u,n,r,s);var p=u.getIncludeNodes();p.forEach(function(t){var i=t.includePath();if(i){var a=O.getIncludeReference(i);if(a)return void o.push(e.resolveAsync(u.absolutePath(),i));if(i){var p=E.buildPath(i,l,e.getRootPath());if(!n[p]){if(r[p]&&t.errors)return void t.errors().push(new F(r[i]));var c=s[p];c||(c=[],s[p]=c),c.push(t)}}}}),t++}var c=Object.keys(s);if(0==o.length&&0==c.length)return Promise.resolve();var f=o;return c.forEach(function(t){f.push(e.unitAsync(t,!0).then(function(e){n[e.absolutePath()]||(n[e.absolutePath()]=!0,i.push(e))},function(n){var i=e.pathToUnit[t];s[t].forEach(function(e){i||e.errors&&e.errors().push(new F(n))}),r[t]=n,e.failedUnits[t]=n,i&&(n.inner=!0)}))}),Promise.all(f).then(function(e){return a(t)})};return e.unitAsync(t,b.isAbsolute(t)).then(function(e){return i.push(e),n[e.absolutePath()]=!0,a(0)}).then(function(e){return i.length>0?i[0]:null})}var E=n(10),b=n(15),N=n(38),_=n(39),M=n(75),w=n(64),R=n(40),I=n(16),C=n(35),L=n(27),P=n(33),O=n(28),D=n(48),x=n(17),U=n(29),k=n(49),F=M.YAMLException;t.Kind={SCALAR:M.Kind.SCALAR};var B=function(){function e(e){this.text="",this.indent=e}return e.prototype.isLastNL=function(){return this.text.length>0&&"\n"==this.text[this.text.length-1]},e.prototype.addWithIndent=function(e,t){this.isLastNL()&&(this.text+=R.indent(e),this.text+=this.indent),this.text+=t},e.prototype.addChar=function(e){this.isLastNL()&&(this.text+=this.indent),this.text+=e},e.prototype.append=function(e){for(var t=0;t<e.length;t++)this.addChar(e[t])},e}();t.MarkupIndentingBuffer=B;var K=function(){function e(e,t,n,r,i){this._path=e,this._content=t,this._tl=n,this._project=r,this._apath=i,this._includedByPaths=[],this._path=null!=this._path?this._path.replace(/\\/g,"/"):null}return e.isInstance=function(t){return null!=t&&t.getClassIdentifier&&"function"==typeof t.getClassIdentifier&&w.contains(t.getClassIdentifier(),e.CLASS_IDENTIFIER)},e.prototype.getClassIdentifier=function(){var t=[];return t.concat(e.CLASS_IDENTIFIER)},e.prototype.highLevel=function(){return this._hl?this._hl:(this._hl=I.fromUnit(this),this._hl)},e.prototype.isStubUnit=function(){return this.stu},e.prototype.resolveAsync=function(e){var t=this._project.resolveAsync(this._path,e);return t},e.prototype.getIncludeNodes=function(){var e=this.ast(),t=[];return null==e?[]:(e.gatherIncludes(t),e.children().forEach(function(e){"uses"==e.key()&&e.children().forEach(function(e){t.push({includePath:function(){var t=e.value();return"string"!=typeof t?null:t}})})}),t)},e.prototype.cloneToProject=function(t){var n=new e(this._path,this._content,this._tl,t,this._apath);return n},e.prototype.clone=function(){var t=new e(this._path,this._content,this._tl,this.project(),this._apath);return t},e.prototype.stub=function(){var t=new e(this._path,this._content,this._tl,this.project(),this._apath);return t.stu=!0,t},e.prototype.isDirty=function(){return!1},e.prototype.expandedHighLevel=function(){if(this.expanded)return this.expanded;var e=this.highLevel().asElement(),t=U.expandTraitsAndResourceTypes(e.wrapperNode()),n=t.highLevel();return n._expanded=!0,this.expanded=n,n},e.prototype.absolutePath=function(){return this._apath},e.prototype.isRAMLUnit=function(){var e=this.absolutePath();if(E.isWebPath(e))try{e=N.parse(e).pathname}catch(t){e=this._path}var n=b.extname(e);return".raml"==n||".yaml"==n||".yml"==n},e.prototype.contents=function(){return this._content},e.prototype.resolve=function(e){"string"!=typeof e&&(e=""+e);var t=this._project.resolve(this._path,e);return t},e.prototype.path=function(){return this._path},e.prototype.lexerErrors=function(){return null==this.errors&&this.ast(),this.errors},e.prototype.ast=function(){var e=this;if(this._node)return this._node;try{var t=M.load(this._content,{ignoreDuplicateKeys:!0});return this.errors=t.errors,this.errors.forEach(function(t){t.mark&&(t.mark.filePath=e.absolutePath())}),this._node=new z(t,this,null,null,null),this._node._errors=this.errors,this._node}catch(n){return this.errors=[],this.errors.push(new F(n.message)),this._node=null,this._node}},e.prototype.isTopLevel=function(){return this._tl},e.prototype.updateContent=function(e){this._content=e,this.errors=null,this._node=null,this._lineMapper=null},e.prototype.updateContentSafe=function(e){this._content=e,this._lineMapper=null,this._hl=null},e.prototype.project=function(){return this._project},e.prototype.lineMapper=function(){return null==this._lineMapper&&(this._lineMapper=new E.LineMapperImpl(this.contents(),this.absolutePath())),this._lineMapper},e.prototype.isOverlayOrExtension=function(){for(var e=this.contents(),t="",n=null,r=0,i=0,a=0;a<e.length;a++){var o=e.charAt(a);if("\r"==o||"\n"==o){t?n=e.substring(i,a).trim():t=e.substring(0,a).trim();break}" "==o&&(r++,t||2!=r||(t=e.substring(0,a),i=a))}return"Extension"==n||"Overlay"==n},e.prototype.getMasterReferenceNode=function(){return w.find(this.ast().children(),function(e){return e.key()==x.Universe10.Overlay.properties["extends"].name})},e.prototype.addIncludedBy=function(e){this.includedByContains(e)||this._includedByPaths.push(e)},e.prototype.includedByContains=function(e){return null!=w.find(this._includedByPaths,function(t){return t==e})},e.prototype.getIncludedByPaths=function(){return this._includedByPaths},e.CLASS_IDENTIFIER="jsyaml2lowLevel.CompilationUnit",e}();t.CompilationUnit=K;var V=n(60).XMLHttpRequest,j=n(60).XMLHttpRequest,W=function(){function e(){}return e.prototype.open=function(e,t,n){this.xhr=n?new j:new V,this.async=n,this.xhr.open(e,t,n)},e.prototype.setRequestHeader=function(e,t){this.xhr.setRequestHeader(e,t)},e.prototype.getResponseHeader=function(e){return this.xhr.getResponseHeader(e)},e.prototype.getAllResponseHeaders=function(){return this.xhr.getAllResponseHeaders()},e.prototype.send=function(e){var t=this;this.xhr.onload=function(){return t.onResponse(!1)},this.xhr.onerror=function(){return t.onResponse(!0)},this.xhr.send(e)},e.prototype.onResponse=function(e){return this.statusText=this.xhr.statusText,this.responseText=this.xhr.responseText,this.responseType=this.xhr.responseType,this.status=this.xhr.status,e&&this.onerror?void this.onerror():void(this.onload&&this.onload())},e}();t.XMLHttpRequestWrapper=W,t.buildXHR=r;var q=function(){function e(){}return e.prototype.execute=function(e,t){void 0===t&&(t=!0);var n=r(),i=e.url;t&&(i=this.appendParams(e,e.url)),n.open(e.method,i,!1),this.doRequest(e,n);var a=n.status;if(a>300&&400>a){var o=n.getResponseHeader("location");if(o)return e.url=o,this.execute(e,!1)}var s={status:a,statusText:n.statusText,headers:n.getAllResponseHeaders().split("\n").map(function(e){var t=e.indexOf(":");return{name:e.substring(0,t).trim(),value:e.substring(t+1).trim()}}),content:{text:n.responseText,mimeType:n.responseType}};return s},e.prototype.appendParams=function(e,t){var n=e.queryString&&e.queryString.length>0;if(n){t+="?";var r=[];n&&(r=r.concat(e.queryString.map(function(e){return encodeURIComponent(e.name)+"="+encodeURIComponent(e.value)}))),t+=r.join("&")}return t},e.prototype.log=function(e,t){},e.prototype.executeAsync=function(e,t){void 0===t&&(t=!0);var n=r(),i=e.url;t&&(i=this.appendParams(e,e.url));var a=this;return new Promise(function(t,r){n.open(e.method,i,!0),n.onload=function(){var e=n.status,r={status:e,statusText:n.statusText,headers:n.getAllResponseHeaders().split("\n").map(function(e){var t=e.indexOf(":");return{name:e.substring(0,t).trim(),value:e.substring(t+1).trim()}}),content:{text:n.responseText,mimeType:n.responseType}};t(r)},n.onerror=function(){r(new F("Network Error"))},a.doRequest(e,n)})},e.prototype.doRequest=function(e,t){if(e.headers&&e.headers.forEach(function(e){return t.setRequestHeader(e.name,e.value)}),e.postData)if(e.postData.params){var n=e.postData.params.map(function(e){return encodeURIComponent(e.name)+"="+encodeURIComponent(e.value)}).join("&");t.send(n)}else t.send(e.postData.text);else t.send()},e}();t.SimpleExecutor=q;var Y=function(){function e(){this.executor=new q}return e.prototype.getResource=function(e){if("undefined"!=typeof atom&&null!=atom){var t=L.get(e);if(t)return t;L.addNotify(e);try{var n={content:""};return this.getResourceAsync(e).then(function(t){try{t.errorMessage?L.set(e,{content:null,errorMessage:null}):(t.errorMessage=null,L.set(e,t))}finally{n.callback&&n.callback(L.get(e)),L.removeNotity(e)}},function(t){L.set(e,{content:null,errorMessage:null}),n.callback&&n.callback(L.get(e)),L.removeNotity(e)}),n}catch(r){console.log("Error"),console.log(r)}}var i=this.executor.execute({method:"get",url:e});if(!i)throw new F("Unable to execute GET "+e);var a=this.toResponse(i,e);return a},e.prototype.getResourceAsync=function(e){var t=this;return this.executor.executeAsync({method:"get",url:e}).then(function(n){if(!n)return Promise.reject(new F("Unable to execute GET "+e));var r=t.toResponse(n,e);return r},function(t){return Promise.reject(new F("Unable to execute GET "+e))})},e.prototype.toResponse=function(e,t){var n=null;e.status>=400&&(n="GET "+t+"\nreturned error: "+e.status,e.statusText&&(n+=" "+e.statusText));var r=null;e.content&&e.content.text&&(r=e.content.text);var i={content:r,errorMessage:n};return i},e}();t.HTTPResolverImpl=Y;var H=function(){function e(){}return e.prototype.content=function(e){if("string"!=typeof e&&(e=""+e),!_.existsSync(e))return null;try{return _.readFileSync(e).toString()}catch(t){return null}},e.prototype.list=function(e){return _.readdirSync(e)},e.prototype.contentAsync=function(e){return new Promise(function(t,n){_.readFile(e,function(e,r){if(null!=e)return n(e);var i=r.toString();t(i)})})},e.prototype.listAsync=function(e){return new Promise(function(t,n){_.readdir(e,function(e,r){return null!=e?t(e):void n(r)})})},e}();t.FSResolverImpl=H;var $=function(e,t,n){if(t&&(t.startPosition>=e&&(t.startPosition+=n),t.endPosition>e&&(t.endPosition+=n),t.kind==M.Kind.MAPPING)){var r=t;$(e,r.key,n),$(e,r.value,n)}},G=function(e,t){for(var n="",r=e.start()-1;r>0;){var i=t[r];if(" "!=i&&"-"!=i)break;n=" "+n,r--}return n},X=function(){function e(e,t,n){this.rootPath=e,this.resolver=t,this._httpResolver=n,this.listeners=[],this.tlisteners=[],this.pathToUnit={},this.failedUnits={},this._fsEnabled=!0,this._namespaceResolver=new k.NamespaceResolver,null==this.resolver?this.resolver=new H:this._fsEnabled=!1,null==this._httpResolver&&(this._httpResolver=new Y)}return e.prototype.getRootPath=function(){return this.rootPath},e.prototype.fsEnabled=function(){return this._fsEnabled},e.prototype.cloneWithResolver=function(t,n){
void 0===n&&(n=null);var r=new e(this.rootPath,t,n?n:this._httpResolver);for(var i in this.pathToUnit)r.pathToUnit[i]=this.pathToUnit[i].cloneToProject(r);return r},e.prototype.setCachedUnitContent=function(e,t,n){void 0===n&&(n=!0);var r=e,i=E.toAbsolutePath(this.rootPath,e),a=new K(r,t,n,this,i);return this.pathToUnit[i]=a,a},e.prototype.resolveAsync=function(e,t){var n=this;if(!t)return Promise.reject(new F("Unit path is null"));var r=O.getIncludeReference(t),i=t;r&&(t=r.getIncludePath());var a=E.buildPath(t,e,this.rootPath);if(r){var o,s=E.toAbsolutePath(b.dirname(E.toAbsolutePath(this.rootPath,e)),r.encodedName());this.pathToUnit[a]?Promise.resolve(o).then(function(e){return n.pathToUnit[s]=new K(r.encodedName(),O.resolveContents(i,n.pathToUnit[a].contents()),!1,n,s),n.pathToUnit[s]}):this.unitAsync(a,!0).then(function(e){return n.pathToUnit[a]=e,n.pathToUnit[s]=new K(r.encodedName(),O.resolveContents(i,n.pathToUnit[a].contents()),!1,n,s),n.pathToUnit[s]})}return this.unitAsync(a,!0)},e.prototype.resolve=function(e,t){if(!t)return null;t=t.replace(/\\/g,"/");var n=O.getIncludeReference(t),r=t;n&&(t=n.getIncludePath());var i=E.buildPath(t,e,this.rootPath);if(n){this.pathToUnit[i]||(this.pathToUnit[i]=this.unit(i,!0));var a=this.pathToUnit[i],o=E.toAbsolutePath(b.dirname(E.toAbsolutePath(this.rootPath,e)),n.encodedName());return this.pathToUnit[o]?this.pathToUnit[o]:(this.pathToUnit[o]=new K(n.encodedName(),O.resolveContents(r,a&&a.contents()),!1,this,o),this.pathToUnit[o])}return this.unit(i,!0)},e.prototype.units=function(){var e=this;if(!this.resolver.list)throw new F("Provided FSResolver is unable to list files. Please, use ExtendedFSResolver.");var t=this.resolver.list(this.rootPath).filter(function(e){return".raml"==b.extname(e)});return t.map(function(t){return e.unit(t)}).filter(function(e){return e.isTopLevel()})},e.prototype.unitsAsync=function(){var e=this;return this.resolver.listAsync?this.resolver.listAsync(this.rootPath).then(function(t){var n=t.filter(function(e){return".raml"==b.extname(e)}).map(function(t){return e.unitAsync(t).then(function(e){return e.isTopLevel()?e:null},function(e){return null})});return Promise.all(n).then(function(e){return e.filter(function(e){return null!=e})})}):Promise.reject(new F("Provided FSResolver is unable to list files. Please, use ExtendedFSResolver."))},e.prototype.lexerErrors=function(){var e=[];return this.units().forEach(function(t){e=e.concat(t.lexerErrors())}),e},e.prototype.deleteUnit=function(e,t){void 0===t&&(t=!1);var n=null;n=E.isWebPath(e)?e:t?e:E.toAbsolutePath(this.rootPath,e),delete this.pathToUnit[n]},e.prototype.unit=function(e,t){if(void 0===t&&(t=!1),t||E.isWebPath(e)){if(null!=this.failedUnits[e]&&!this.failedUnits[e].inner)return null}else{var n=E.toAbsolutePath(this.rootPath,e);if(this.failedUnits[n]&&!this.failedUnits[e].inner)return null}var r,i=null,a=e;if(E.isWebPath(e)){if(this.pathToUnit[a])return this.pathToUnit[a];if(this._httpResolver){if(r=this._httpResolver.getResource(e),r&&r.errorMessage)throw new F(r.errorMessage);i=r?r.content:null}else r=(new Y).getResource(a),i=r?r.content:null}else{"/"!=e.charAt(0)||t||(e=e.substr(1));var a=E.toAbsolutePath(this.rootPath,e);if(this.pathToUnit[a])return this.pathToUnit[a];if(E.isWebPath(a))if(this._httpResolver){var o=this._httpResolver.getResource(a);if(o&&o.errorMessage)throw new F(o.errorMessage);i=o?o.content:null}else{var s=(new Y).getResource(a);i=s?s.content:null}else i=this.resolver.content(a)}if(null==i)return null;var u=P.stringStartsWith(i,"#%RAML"),l=E.isWebPath(this.rootPath)==E.isWebPath(a)?b.relative(this.rootPath,a):a,p=new K(l,i,u,this,a);return this.pathToUnit[a]=p,r&&(r.callback=function(e){p.updateContent(e&&e.content)}),p},e.prototype.unitAsync=function(e,t){var n=this;void 0===t&&(t=!1);var r=null,i=e;if(E.isWebPath(e)){if(this.pathToUnit[i])return Promise.resolve(this.pathToUnit[i]);if(this._httpResolver){var a=this._httpResolver.getResourceAsync(i);r=a.then(function(e){return e.errorMessage?Promise.reject(new F(e.errorMessage)):e.content})}else r=(new Y).getResourceAsync(i)}else{if("/"!=e.charAt(0)||t||(e=e.substr(1)),i=t?e:E.toAbsolutePath(this.rootPath,e),this.pathToUnit[i])return Promise.resolve(this.pathToUnit[i]);if(E.isWebPath(i))if(this._httpResolver){var a=this._httpResolver.getResourceAsync(i);r=a.then(function(e){return e.errorMessage?Promise.reject(new F(e.errorMessage)):e.content})}else r=(new Y).getResourceAsync(i);else r=this.resolver.contentAsync(i)}if(null==r)return Promise.resolve(null);var o=E.isWebPath(this.rootPath)==E.isWebPath(i)?b.relative(this.rootPath,i):i;return r.then(function(e){if(null==e)return Promise.reject(new F("Can note resolve "+i));var t=P.stringStartsWith(e,"#%RAML"),r=new K(o,e,t,n,i);return n.pathToUnit[i]=r,r},function(e){return"object"==typeof e&&e instanceof F?Promise.reject(e):Promise.reject(new F(e.toString()))}).then(function(e){return e.isRAMLUnit()?e:D.isScheme(e.contents())?D.startDownloadingReferencesAsync(e.contents(),e):e})},e.prototype.visualizeNewlines=function(e){for(var t="",n=0;n<e.length;n++){var r=e[n];"\r"==r&&(r="\\r"),"\n"==r&&(r="\\n"),t+=r}return t},e.prototype.indent=function(e){var t=e.unit().contents();if(e==e.root())return"";var n=G(e,t),r=a(e.dump());if(r.length>1&&r[1].trim().length>0){var i=s(r[1]);return n+i}return n+"  "},e.prototype.startIndent=function(e){e.unit().contents();if(e==e.root())return"";var t=a(e.dump());if(t.length>0){console.log("FIRST: "+t[0]);var n=s(t[0]);return n+"  "}return""},e.prototype.canWriteInOneLine=function(e){return!1},e.prototype.isOneLine=function(e){return e.text().indexOf("\n")<0},e.prototype.recalcPositionsUp=function(e){for(var t=e;t;)t.recalcEndPositionFromChilds(),t=t.parent()},e.prototype.add2=function(e,t,n,r,i){void 0===i&&(i=!1);var a=e.unit(),o=(e.root(),null);if(r&&(z.isInstance(r)&&(o=r),Q.isInstance(r)&&(o=r.point)),e.isValueInclude()){var s=e.children();if(0==s.length)throw new F("not implemented: insert into empty include ref");var u=s[0].parent();return void this.add2(u,t,n,o,i)}var l=(new R.TextRange(a.contents(),t.start(),t.end()),new R.TextRange(a.contents(),e.start(),e.end()),e.unit().contents());e.valueKind()==M.Kind.SEQ&&(e=m(e.valueAsSeq(),e,e.unit()));var i=this.isJson(e),p=i?"":this.indent(e.isSeq()?e.parent():e),c=p,f=p.length,d=e.isSeq()||e.isMapping()&&(e.isValueSeq()||e.isValueScalar()||!e.asMapping().value);n=n,n&&(i||d&&(c+="  ",f+=2));var h=new B(c);t.markupNode(h,t._actualNode(),0,i);var y=h.text;if(n){var v=R.trimEnd(y),g=y.length-v.length;if(g>0){var A=y.length;y=y.substring(0,A-g),t.shiftNodes(A-g,-g)}}n&&!i?(t.highLevelNode(),e.isMapping(),y=e.isSeq()||e.isMapping()&&(e.isValueSeq()||e.isValueScalar()||!e.asMapping().value)?p+"- "+y:p+y):y=p+y;var S=e.end();if(o)o!=e?S=o.end():i&&n||(S=e.keyEnd()+1,S=new R.TextRange(l,S,S).extendAnyUntilNewLines().endpos());else if(i&&n){var T=e.asSeq();T&&(S=T.items.length>0?T.items[T.items.length-1].endPosition:T.endPosition-1)}else if(r&&Q.isInstance(r)){var E=r;E.type==J.START&&(S=e.keyEnd()+1,S=new R.TextRange(l,S,S).extendAnyUntilNewLines().endpos())}var b=new R.TextRange(l,0,S);if(S=b.extendToNewlines().reduceSpaces().endpos(),i&&e.isSeq()){var T=e.asSeq();T.items.length>0&&(y=", "+y,f+=2)}else S>0&&"\n"!=l[S-1]&&(y="\n"+y,f++);var N=0;n&&!i&&(y+="\n",N++);var _=l.substring(0,S)+y+l.substring(S,l.length),w=a;if(w.updateContentSafe(_),this.executeReplace(new R.TextRange(l,S,S),y,w),e.root().shiftNodes(S,f+(t.end()-t.start())+N),o){for(var s=e.children(),I=-1,C=0;C<s.length;C++){var L=s[C];if(L.start()==o.start()&&L.end()==o.end()){I=C;break}}I>=0?e.addChild(t,I+1):e.addChild(t)}else e.addChild(t);t.shiftNodes(0,S+f),this.recalcPositionsUp(e),t.setUnit(e.unit()),t.visit(function(t){var n=t;return n.setUnit(e.unit()),!0})},e.prototype.isJsonMap=function(e){if(!e.isMap())return!1;var t=e.text().trim();return t.length>=2&&"{"==t[0]&&"}"==t[t.length-1]},e.prototype.isJsonSeq=function(e){if(!e.isSeq())return!1;var t=e.text().trim();return t.length>=2&&"["==t[0]&&"]"==t[t.length-1]},e.prototype.isJson=function(e){return this.isJsonMap(e)||this.isJsonSeq(e)},e.prototype.remove=function(e,t,n){var r=n.parent();if(n._oldText=n.dump(),this.isOneLine(n)&&n.isMapping()&&n.parent().isMap()){var i=n.parent();if(1==i.asMap().mappings.length&&null!=i.parent())return void this.remove(e,i.parent(),i)}if(this.isOneLine(n)&&n.isScalar()&&n.parent().isSeq()){var a=n.parent(),o=a.asSeq();if(1==o.items.length)return void this.remove(e,a.parent(),a)}if(t.isMapping()&&n.isSeq()){var s=t.parent();return void this.remove(e,s,t)}var u=new R.TextRange(e.contents(),n.start(),n.end()),l=(new R.TextRange(e.contents(),t.start(),t.end()),new R.TextRange(e.contents(),r.start(),r.end()),u.startpos());if(t.isSeq()){var p=n.isSeq()?n:n.parentOfKind(M.Kind.SEQ);u=p&&this.isJson(p)?u.extendSpaces().extendCharIfAny(",").extendSpaces():u.extendToStartOfLine().extendAnyUntilNewLines().extendToNewlines()}t.isMap()&&(u=u.trimEnd().extendAnyUntilNewLines().extendToNewlines(),u=u.extendToStartOfLine().extendUntilNewlinesBack()),t.kind()==M.Kind.MAPPING&&(this.isJson(n)&&this.isOneLine(n)||(u=u.extendSpacesUntilNewLines(),u=u.extendToNewlines(),u=u.extendToStartOfLine().extendUntilNewlinesBack())),n.isSeq()&&(u=u.reduceSpaces());var c=e;c.updateContentSafe(u.remove()),this.executeReplace(u,"",c),n.parent().removeChild(n);var f=-u.len();t.root().shiftNodes(l,f),this.recalcPositionsUp(t)},e.prototype.changeKey=function(e,t,n){var r=new R.TextRange(t.unit().contents(),t.keyStart(),t.keyEnd());if(t.kind()==M.Kind.MAPPING){var i=t._actualNode().key;i.value=n,i.endPosition=i.startPosition+n.length}var a=e;this.executeReplace(r,n,a);var o=n.length-r.len();t.root().shiftNodes(r.startpos(),o,t),this.recalcPositionsUp(t)},e.prototype.executeReplace=function(e,t,n){var r=new E.TextChangeCommand(e.startpos(),e.endpos()-e.startpos(),t,n);n.project();try{this.tlisteners.forEach(function(e){return e(r)})}catch(i){return!1}var a=e.replace(t);return n.updateContentSafe(a),!0},e.prototype.changeValue=function(e,t,n){var r,i=new R.TextRange(t.unit().contents(),t.start(),t.end()),a=0,o=0,s=null,u=null;if(t.kind()==M.Kind.SCALAR){if("string"!=typeof n)throw new F("not implemented");t.asScalar().value=n,r=n}else if(t.kind()==M.Kind.MAPPING){if(u=t.asMapping(),t.isValueInclude()){var l=t.valueAsInclude(),p=l.value,f=p,m=t.unit().resolve(f);if(null==m)return void console.log("attr.setValue: couldn't resolve: "+f);if(m.isRAMLUnit())return;return void(O.getIncludeReference(p)||m.updateContent(n))}if(i=u.value?i.withStart(t.valueStart()).withEnd(t.valueEnd()):i.withStart(t.keyEnd()+1).withEnd(t.keyEnd()+1),i=i.reduceNewlinesEnd(),null==n)r="",u.value=null;else if("string"==typeof n||null==n){var d=n,h=this.indent(t);if(d&&R.isMultiLine(d)&&(d=""+R.makeMutiLine(d,h.length/2)),r=d,u.value){if(u.value.kind==M.Kind.SEQ){console.log("seq value");u.value.items[0];throw"assign value!!!"}if(u.value.kind==M.Kind.SCALAR){var y=u.value,v=y.value||"";y.value=d,u.value.endPosition=u.value.startPosition+d.length,u.endPosition=u.value.endPosition,o+=d.length-v.length}}else if(console.log("no value"),u.value=M.newScalar(d),u.value.startPosition=t.keyEnd()+1,u.value.endPosition=u.value.startPosition+d.length,u.endPosition=u.value.endPosition,e.contents().length>t.keyEnd()+1){var g=t.keyEnd()+1;":"==e.contents()[g-1]&&(r=" "+r,u.value.startPosition++,u.value.endPosition++,u.endPosition++,o++)}}else{var A=n;if(A.isMapping())n=c([A.asMapping()]),A=n;else if(!A.isMap())throw new F("only MAP/MAPPING nodes allowed as values");var S=new B("");A.markupNode(S,A._actualNode(),0,!0),r=""+S.text,A.shiftNodes(0,i.startpos()+o),s=A}}else console.log("Unsupported change value case: "+t.kindName());var T=e;this.executeReplace(i,r,T);var E=r.length-i.len();t.root().shiftNodes(i.endpos()+a,E,t),s&&(u.value=s._actualNode()),this.recalcPositionsUp(t)},e.prototype.initWithRoot=function(e,t){var n=e.end();t.markup(!1),t._actualNode().startPosition=n,t._actualNode().endPosition=n,t.setUnit(e.unit())},e.prototype.execute=function(e){var t=this;e.commands.forEach(function(e){switch(e.kind){case E.CommandKind.CHANGE_VALUE:var n=e.target,r=n.value();r||(r="");var i=e.value;if(console.log("set value: "+typeof r+" ==> "+typeof i),"string"!=typeof r&&"number"!=typeof r&&"boolean"!=typeof r||"string"!=typeof i)if("string"!=typeof r&&"number"!=typeof r&&"boolean"!=typeof r||"string"==typeof i)if("string"!=typeof r&&"string"==typeof i){var a=e.value;if(r.kind()!=M.Kind.MAPPING)throw new F("unsupported case: attribute value conversion: "+typeof r+" ==> "+typeof i+" not supported");R.isMultiLine(a)?(n.children().forEach(function(e){t.remove(n.unit(),n,e)}),t.changeValue(n.unit(),n,a)):t.changeKey(n.unit(),r,a)}else{if("string"==typeof r||"string"==typeof i)throw new F("shouldn't be this case: attribute value conversion "+typeof r+" ==> "+typeof i+" not supported");var o=i;if(o.isMapping()&&(i=c([o.asMapping()])),r==i)break;var s=i;s.asMap();n.children().forEach(function(e){t.remove(n.unit(),n,e)}),s.children().forEach(function(e){}),t.changeValue(n.unit(),n,i)}else t.changeValue(n.unit(),n,i);else r!=i&&t.changeValue(n.unit(),n,i);return;case E.CommandKind.CHANGE_KEY:var n=e.target;return void t.changeKey(n.unit(),n,e.value);case E.CommandKind.ADD_CHILD:var n=e.target,u=e.value;return void t.add2(n,u,e.toSeq,e.insertionPoint);case E.CommandKind.REMOVE_CHILD:var l=e.target,s=e.value;return void t.remove(l.unit(),l,s);case E.CommandKind.INIT_RAML_FILE:var p=e.target,f=e.value;return void t.initWithRoot(p,f);default:return void console.log("UNSUPPORTED COMMAND: "+E.CommandKind[e.kind])}})},e.prototype.replaceYamlNode=function(e,t,n,r,i){var a=M.load(t,{ignoreDuplicateKeys:!0});this.updatePositions(e.start(),a),e.root().shiftNodes(n,r);var o=e.parent(),s=e._actualNode(),u=s.parent;if(a.parent=u,o&&o.kind()==M.Kind.MAP){var l=o._actualNode();l.mappings=l.mappings.map(function(e){return e!=s?e:a})}e.updateFrom(a),this.recalcPositionsUp(e)},e.prototype.executeTextChange2=function(e){var t=e.unit,n=t.contents(),r=e.target;if(r){var i=n.substring(r.start(),r.end());n=n.substr(0,e.offset)+e.text+n.substr(e.offset+e.replacementLength);var a=i.substr(0,e.offset-r.start())+e.text+i.substr(e.offset-r.start()+e.replacementLength);if(t.updateContentSafe(n),e.offset>r.start())try{var o=e.text.length-e.replacementLength,s=e.offset;r.unit().project().replaceYamlNode(r,a,s,o,e.unit)}catch(u){console.log("New node contents (causes error below): \n"+a),console.log("Reparse error: "+u.stack)}}else n=n.substr(0,e.offset)+e.text+n.substr(e.offset+e.replacementLength);t.updateContent(n),this.listeners.forEach(function(e){e(null)}),this.tlisteners.forEach(function(t){t(e)})},e.prototype.executeTextChange=function(e){(new Date).getTime();try{var t=e.unit.contents(),n=e.target;null==n&&(n=this.findNode(e.unit.ast(),e.offset,e.offset+e.replacementLength));var r=e.unit;if(n){var a=t.substring(n.start(),n.end()),o=t;t=t.substr(0,e.offset)+e.text+t.substr(e.offset+e.replacementLength);var s=a.substr(0,e.offset-n.start())+e.text+a.substr(e.offset-n.start()+e.replacementLength);r.updateContentSafe(t);u(o,e);if(e.offset>n.start())try{var l=M.load(s,{ignoreDuplicateKeys:!0});this.updatePositions(n.start(),l);var p=e.text.length-e.replacementLength;if(e.unit.ast().shiftNodes(e.offset,p),null!=l&&l.kind==M.Kind.MAP){var c=l.mappings[0],f=n._actualNode(),m=f.parent,d=new E.ASTDelta,h=e.unit;if(d.commands=[new E.ASTChangeCommand(E.CommandKind.CHANGE_VALUE,new z(i(f),h,null,null,null),new z(c,h,null,null,null),0)],m&&m.kind==M.Kind.MAP){var y=m;y.mappings=y.mappings.map(function(e){return e!=f?e:c})}return c.parent=m,this.recalcPositionsUp(n),n.updateFrom(c),this.listeners.forEach(function(e){e(d)}),void this.tlisteners.forEach(function(t){t(e)})}}catch(v){console.log("New node contents (causes error below): \n"+s),console.log("Reparse error: "+v.stack)}}else t=t.substr(0,e.offset)+e.text+t.substr(e.offset+e.replacementLength);(new Date).getTime();
//!find node in scope
r.updateContent(t),this.listeners.forEach(function(e){e(null)}),this.tlisteners.forEach(function(t){t(e)})}finally{(new Date).getTime()}},e.prototype.updatePositions=function(e,t){var n=this;if(null!=t)switch(-1==t.startPosition?t.startPosition=e:t.startPosition=e+t.startPosition,t.endPosition=e+t.endPosition,t.kind){case M.Kind.MAP:var r=t;r.mappings.forEach(function(t){return n.updatePositions(e,t)});break;case M.Kind.MAPPING:var i=t;this.updatePositions(e,i.key),this.updatePositions(e,i.value);break;case M.Kind.SCALAR:break;case M.Kind.SEQ:var a=t;a.items.forEach(function(t){return n.updatePositions(e,t)})}},e.prototype.findNode=function(e,t,n){var r=this;if(null==e)return null;var i=e;if(e.start()<=t&&e.end()>=n){var a=e;return i.directChildren().forEach(function(e){var i=r.findNode(e,t,n);i&&(a=i)}),a}return null},e.prototype.addTextChangeListener=function(e){this.tlisteners.push(e)},e.prototype.removeTextChangeListener=function(e){this.tlisteners=this.tlisteners.filter(function(t){return t!=e})},e.prototype.addListener=function(e){this.listeners.push(e)},e.prototype.removeListener=function(e){this.listeners=this.listeners.filter(function(t){return t!=e})},e.prototype.namespaceResolver=function(){return this._namespaceResolver},e}();t.Project=X;var z=function(){function e(e,t,n,r,i,a,o){void 0===a&&(a=!1),void 0===o&&(o=!1),this._node=e,this._unit=t,this._parent=n,this._anchor=r,this._include=i,this.cacheChildren=a,this._includesContents=o,this._errors=[]}return e.isInstance=function(t){return null!=t&&t.getClassIdentifier&&"function"==typeof t.getClassIdentifier&&w.contains(t.getClassIdentifier(),e.CLASS_IDENTIFIER)},e.prototype.getClassIdentifier=function(){var t=[];return t.concat(e.CLASS_IDENTIFIER)},e.prototype.actual=function(){return this._node},e.prototype.yamlNode=function(){return this._node},e.prototype.includesContents=function(){return this._includesContents},e.prototype.setIncludesContents=function(e){this._includesContents=e},e.prototype.gatherIncludes=function(t,n,r,i){var a=this;if(void 0===t&&(t=[]),void 0===n&&(n=null),void 0===r&&(r=null),void 0===i&&(i=!0),null!=this._node){var o=this._node.kind;if(o!=M.Kind.SCALAR)if(o==M.Kind.MAP){var s=this._node;1!=s.mappings.length||i?s.mappings.map(function(t){return new e(t,a._unit,a,r?r:a._anchor,n?n:a._include,a.cacheChildren)}).forEach(function(e){return e.gatherIncludes(t)}):new e(s.mappings[0].value,this._unit,this,n,r,this.cacheChildren).gatherIncludes(t)}else if(o==M.Kind.MAPPING){var u=this._node;null==u.value||new e(u.value,this._unit,this,r?r:this._anchor,n?n:this._include,this.cacheChildren).gatherIncludes(t)}else if(o==M.Kind.SEQ){var l=this._node;l.items.filter(function(e){return null!=e}).map(function(t){return new e(t,a._unit,a,r?r:a._anchor,n?n:a._include,a.cacheChildren)}).forEach(function(e){return e.gatherIncludes(t)})}else o==M.Kind.INCLUDE_REF&&this._unit&&t.push(this);else if(D.isScheme(this._node.value)){var p=D.getReferences(this._node.value,this.unit());p.forEach(function(n){var r=M.newScalar(n);r.kind=M.Kind.INCLUDE_REF;var i=new e(r,a.unit(),null,null,null);t.push(i)})}}},e.prototype.setHighLevelParseResult=function(e){this._highLevelParseResult=e},e.prototype.highLevelParseResult=function(){return this._highLevelParseResult},e.prototype.setHighLevelNode=function(e){this._highLevelNode=e},e.prototype.highLevelNode=function(){return this._highLevelNode},e.prototype.start=function(){return this._node.startPosition},e.prototype.errors=function(){return this._errors},e.prototype.addIncludeError=function(e){if(!w.find(this._errors,function(t){return t.message==e.message})){var t=this._node;t.includeErrors||(t.includeErrors=[]),w.find(t.includeErrors,function(t){return t.message==e.message})||(this._errors.push(e),t.includeErrors.push(e))}},e.prototype.parent=function(){return this._parent},e.prototype.recalcEndPositionFromChilds=function(){var e=(this.children(),this.children()[0]),t=this.children()[this.children().length-1];if(this.isMapping()){var n=this.asMapping();if(n.value)if(n.value.kind==M.Kind.MAP){var r=n.value;r.startPosition<0&&e&&(r.startPosition=e.start()),t&&(this._node.endPosition=t._node.endPosition),this._node.endPosition=Math.max(this._node.endPosition,n.value.endPosition)}else if(n.value.kind==M.Kind.SEQ){var i=n.value;if(i.startPosition<0&&i.items.length>0){var a=i.items[0].startPosition,o=new R.TextRange(this.unit().contents(),a,a);o=o.extendSpacesBack().extendCharIfAnyBack("-"),i.startPosition=o.startpos()}if(i.items.length>0){var s=i.items[i.items.length-1];this._node.endPosition=Math.max(this._node.endPosition,i.endPosition,s.endPosition),i.endPosition=Math.max(this._node.endPosition,i.endPosition,s.endPosition)}}else n.value.kind==M.Kind.SCALAR||t&&(this._node.endPosition=t._node.endPosition)}else t&&(this._node.endPosition=t._node.endPosition)},e.prototype.isValueLocal=function(){if(this._node.kind==M.Kind.MAPPING){var e=this._node.value.kind;return e!=M.Kind.INCLUDE_REF&&e!=M.Kind.ANCHOR_REF}return!0},e.prototype.keyStart=function(){return this._node.kind==M.Kind.MAPPING?this._node.key.startPosition:-1},e.prototype.keyEnd=function(){return this._node.kind==M.Kind.MAPPING?this._node.key.endPosition:-1},e.prototype.valueStart=function(){if(this._node.kind==M.Kind.MAPPING){var e=this.asMapping();return e.value?e.value.startPosition:e.endPosition}return this._node.kind==M.Kind.SCALAR?this.start():-1},e.prototype.valueEnd=function(){if(this._node.kind==M.Kind.MAPPING){var e=this.asMapping();return e.value?e.value.endPosition:e.endPosition}return this._node.kind==M.Kind.SCALAR?this.end():-1},e.prototype.end=function(){return this._node.endPosition},e.prototype.dump=function(){if(this._oldText)return this._oldText;if(this._unit&&this._node.startPosition>0&&this._node.endPosition>0){var e=this._unit.contents().substring(this._node.startPosition,this._node.endPosition);return e=o(e,G(this,this._unit.contents()))}return M.dump(this.dumpToObject(),{})},e.prototype.dumpToObject=function(e){return void 0===e&&(e=!1),this.dumpNode(this._node,e)},e.prototype.dumpNode=function(e,t){var n=this;if(void 0===t&&(t=!1),!e)return null;if(e.kind==M.Kind.INCLUDE_REF){if(this._unit){var r=e,i=r.value,a=null;try{a=this._unit.resolve(i)}catch(o){}if(null==a)return null;if(a.isRAMLUnit()&&this.canInclude(a)){var s=this.unit(),u=a;u.addIncludedBy(s.absolutePath()),s.getIncludedByPaths().forEach(function(e){u.addIncludedBy(e)});var p=a.ast();if(p)return p.dumpToObject(t)}else if(this.canInclude(a))return a.contents()}return null}if(e.kind==M.Kind.SEQ){var c=e,f=[];return c.items.forEach(function(e){return f.push(n.dumpNode(e,t))}),f}if(e.kind==M.Kind.ANCHOR_REF){var m=e;return this.dumpNode(m.value,t)}if(e.kind==M.Kind.MAPPING){var d=e,h={},y=d.value,v=this.dumpNode(y,t);return h[""+this.dumpNode(d.key,t)]=v,h}if(e.kind==M.Kind.SCALAR){var r=e,g=r.value;return r.plainScalar&&(g=l(g)),g}if(e.kind==M.Kind.MAP){var A=e,S={};return A.mappings&&A.mappings.forEach(function(e){var r=n.dumpNode(e.value,t);null==r&&(r=t?"!$$$novalue":r),S[n.dumpNode(e.key,t)+""]=r}),S}},e.prototype.keyKind=function(){return this._node.key?this._node.key.kind:null},e.prototype._actualNode=function(){return this._node},e.prototype.execute=function(e){this.unit()?this.unit().project().execute(e):e.commands.forEach(function(e){switch(e.kind){case E.CommandKind.CHANGE_VALUE:var t=e.target,n=e.value,r=t._actualNode();t.start();return void(r.kind==M.Kind.MAPPING&&(r.value=M.newScalar(""+n)));case E.CommandKind.CHANGE_KEY:var t=e.target,n=e.value,r=t._actualNode();if(r.kind==M.Kind.MAPPING){var i=r.key;i.value=n}return}})},e.prototype.updateFrom=function(e){this._node=e},e.prototype.isAnnotatedScalar=function(){if(!this.unit())return!1;var e;if(this.kind()==M.Kind.MAPPING&&this.valueKind()==M.Kind.MAP?e=this._node.value.mappings:null==this.key()&&this.kind()==M.Kind.MAP&&(e=this._node.mappings),e){var t=e.length>0;return e.forEach(function(e){"value"!==e.key.value&&(e.key.value&&"("==e.key.value.charAt(0)&&")"==e.key.value.charAt(e.key.value.length-1)||(t=!1))}),t}return!1},e.prototype.value=function(t){if(!this._node)return"";if(this._node.kind==M.Kind.SCALAR){if("~"===this._node.value&&null===this._node.valueObject)return t?"null":null;if(!t&&""+this._node.valueObject===this._node.value)return this._node.valueObject;var n=this._node.value;return t||this._node.plainScalar&&(n=l(n)),n}if(this._node.kind==M.Kind.ANCHOR_REF){var r=this._node;return new e(r.value,this._unit,this,null,null).value(t)}if(this._node.kind==M.Kind.MAPPING){var i=this._node;if(null==i.value)return null;if(this.isAnnotatedScalar())for(var a=new e(i.value,this._unit,this,null,null),o=a.children(),s=0;s<o.length;s++)if("value"===o[s].key())return o[s].valueKind()==M.Kind.SEQ?o[s].children().map(function(e){return e.value()}):o[s].value();return new e(i.value,this._unit,this,null,null).value(t)}if(this._node.kind==M.Kind.INCLUDE_REF){var u=this._node.value,p=u,c=null;try{c=this._unit.resolve(p)}catch(f){return"can not resolve "+p+" due to: "+f.message}if(null==c)return"can not resolve "+p;if(c.isRAMLUnit()){var m=c.ast();return m?m.value():"can not resolve "+p+" due to: file is empty"}var d=c.contents();return R.isMultiLineValue(d)&&(d=R.fromMutiLine(d)),d}if(this._node.kind==M.Kind.MAP){var h=this._node;if(1==h.mappings.length)return new e(h.mappings[0],this._unit,this,null,null);if(this.isAnnotatedScalar())for(var o=this.children(),s=0;s<o.length;s++)if("value"===o[s].key())return o[s].valueKind()==M.Kind.SEQ?o[s].children().map(function(e){return e.value()}):o[s].value()}if(this._node.kind==M.Kind.SEQ){var y=this._node;if(1==y.items.length)return new e(y.items[0],this._unit,this,null,null).value(t)}return null},e.prototype.printDetails=function(e){var t="";e||(e="");var n=this.kindName();return this.kind()==M.Kind.SCALAR?t+=e+"["+n+"] "+this.value()+"\n":this.kind()==M.Kind.MAPPING&&this._node.value&&this._node.value.kind==M.Kind.SCALAR?t+=e+"["+n+"] "+this.key()+" = "+this.value()+"\n":this.kind()==M.Kind.MAPPING?(t+=e+"["+n+"] "+this.key()+" = :\n",this.children().forEach(function(n){t+=n.printDetails(e+"	")})):(t+=e+"["+n+"] :\n",this.children().forEach(function(n){t+=n.printDetails(e+"	")})),t},e.prototype.visit=function(e){this.children().forEach(function(t){e(t)&&t.visit(e)})},e.prototype.rawKey=function(){if(!this._node)return"";if(this._node.kind==M.Kind.MAPPING){var e=this._node;if(e.key.kind==M.Kind.SEQ){var t=e.key,n="[";return t.items.forEach(function(e){return n+=e.value}),n+"]"}return e.key.value}if(this._node.kind==M.Kind.INCLUDE_REF){var r=this.children();if(1==r.length)return r[0].key()}return null},e.prototype.key=function(e){void 0===e&&(e=!1);var t=this.rawKey();return e?t:(null!=t&&P.stringEndsWith(t,"?")&&(t=t.substring(0,t.length-1)),t)},e.prototype.optional=function(){var e=this.rawKey();return null!=e&&P.stringEndsWith(e,"?")},e.prototype.addChild=function(e,t){void 0===t&&(t=-1);var n=e;if(n._parent=this,this._oldText=null,this.isMap()){var r=this.asMap();(null==r.mappings||void 0==r.mappings)&&(r.mappings=[]),t>=0?r.mappings.splice(t,0,n.asMapping()):r.mappings.push(n.asMapping())}else if(this.isMapping()){var i=this.asMapping(),a=i.value;if(!i.value&&n.isMap())return void(i.value=n._actualNode());if(i.value&&i.value.kind==M.Kind.SCALAR&&(i.value=null,a=null),a||(a=n.isScalar()||n.highLevelNode()&&n.highLevelNode().property().getAdapter(C.RAMLPropertyParserService).isEmbedMap()?M.newSeq():M.newMap(),i.value=a),a.kind==M.Kind.MAP){var r=a;(null==r.mappings||void 0==r.mappings)&&(r.mappings=[]),n.isScalar(),t>=0?r.mappings.splice(t,0,n.asMapping()):r.mappings.push(n.asMapping())}else{if(a.kind!=M.Kind.SEQ)throw new F("Insert into mapping with "+M.Kind[i.value.kind]+" value not supported");var o=a;t>=0?o.items.splice(t,0,n._actualNode()):o.items.push(n._actualNode())}}else{if(!this.isSeq())throw new F("Insert into "+this.kindName()+" not supported");var o=this.asSeq();t>=0?o.items.splice(t,0,n._actualNode()):o.items.push(n._actualNode())}},e.prototype.removeChild=function(e){this._oldText=null;var t,n,r=e;if(this.kind()==M.Kind.SEQ){var i=this.asSeq();t=r._node,n=i.items.indexOf(t),n>-1&&i.items.splice(n,1)}else if(this.kind()==M.Kind.MAP){var a=this.asMap();t=r.asMapping(),n=a.mappings.indexOf(t),n>-1&&a.mappings.splice(n,1)}else{if(this.kind()!=M.Kind.MAPPING)throw new F("Delete from "+M.Kind[this.kind()]+" unsupported");var o=this.asMapping();if(r._actualNode()==o.value)o.value=null;else{var a=o.value;t=r.asMapping(),a&&a.mappings&&(n=a.mappings.indexOf(t),n>-1&&a.mappings.splice(n,1))}}},e.prototype.hasInnerIncludeError=function(){return this.innerIncludeErrors},e.prototype.includeErrors=function(){if(this._node.kind==M.Kind.MAPPING){var t=this._node;if(null==t.value)return[];var n=new e(t.value,this._unit,this,this._anchor,this._include),r=n.includeErrors();return this.innerIncludeErrors=n.hasInnerIncludeError(),r}var i=[];if(this._node.kind==M.Kind.INCLUDE_REF){var t=this._node;if(null==t.value)return[];var a=this.includePath(),o=null;try{o=this._unit.resolve(a)}catch(s){this.innerIncludeErrors=s.inner;var u="Can not resolve "+a+" due to: "+s.message;return i.push(u),i}var l=this._node.includeErrors;if(l&&l.length>0)return this.innerIncludeErrors=!0,i=l.map(function(e){return"object"==typeof e&&e instanceof s?e.message:e.toString()});if(null==o)return i.push("Can not resolve "+a),i;if(o.isRAMLUnit()){var p=o.ast();if(p)return[];i.push(""+a+" can not be parsed")}}return i},e.prototype.joinMappingsWithFullIncludeAnchor=function(t,n,r){var i=this,a=w.find(t,function(e){return e.key&&e.value&&e.key.kind==M.Kind.SCALAR&&"<<"==e.key.value&&e.value.kind==M.Kind.ANCHOR_REF});if(!a)return t.map(function(t){return new e(t,i._unit,i,r?r:i._anchor,n?n:i._include,i.cacheChildren)});var o=w.filter(t,function(e){return!(e.key.kind==M.Kind.SCALAR&&"<<"==e.key.value&&e.value.kind==M.Kind.ANCHOR_REF)}),s=new e(a.value,this._unit,this,n,r,this.cacheChildren).children(null,null,!0),u=o.map(function(t){return new e(t,i._unit,i,r?r:i._anchor,n?n:i._include,i.cacheChildren)});return u.concat(s)},e.prototype.children=function(t,n,r){var i=this;if(void 0===t&&(t=null),void 0===n&&(n=null),void 0===r&&(r=!0),null==this._node)return[];if(this.cacheChildren&&this._children)return this._children;var a,o=this._node.kind;if(o==M.Kind.SCALAR)a=[];else if(o==M.Kind.MAP){var s=this._node;a=1!=s.mappings.length||r?this.joinMappingsWithFullIncludeAnchor(s.mappings,t,n):new e(s.mappings[0].value,this._unit,this,t,n,this.cacheChildren).children(null,null,!0)}else if(o==M.Kind.MAPPING){var u=this._node;if(null==u.value)a=[];else{var l=new e(u.value,this._unit,this,n?n:this._anchor,t?t:this._include,this.cacheChildren);a=l.children(),l.includesContents()&&this.setIncludesContents(!0)}}else if(o==M.Kind.SEQ){var p=this._node;a=p.items.filter(function(e){return null!=e}).map(function(r){return new e(r,i._unit,i,n?n:i._anchor,t?t:i._include,i.cacheChildren)})}else if(o==M.Kind.INCLUDE_REF){if(this._unit){var c=this.includePath(),f=null;try{f=this._unit.resolve(c)}catch(m){}if(null==f)a=[];else if(f.isRAMLUnit())if(this.canInclude(f)){var d=this.unit(),h=f;h.addIncludedBy(d.absolutePath()),d.getIncludedByPaths().forEach(function(e){h.addIncludedBy(e)});var y=f.ast();y&&(this.cacheChildren&&(y=v(y)),a=f.ast().children(this,null),this.setIncludesContents(!0))}else this.addIncludeError&&this.addIncludeError(new m("Recursive definition"))}a||(a=[])}else{if(o!=M.Kind.ANCHOR_REF)throw new m("Should never happen; kind : "+M.Kind[this._node.kind]);var g=this._node;a=new e(g.value,this._unit,this,null,null,this.cacheChildren).children()}return this.cacheChildren&&(this._children=a),a},e.prototype.canInclude=function(e){for(var t=this.includedFrom();null!=t;){if(t.unit().absolutePath()==e.absolutePath())return!1;t=t.includedFrom()}return!this.unit().includedByContains(e.absolutePath())},e.prototype.directChildren=function(t,n,r){var i=this;if(void 0===t&&(t=null),void 0===n&&(n=null),void 0===r&&(r=!0),this._node){switch(this._node.kind){case M.Kind.SCALAR:return[];case M.Kind.MAP:var a=this._node;return 1!=a.mappings.length||r?a.mappings.map(function(r){return new e(r,i._unit,i,n?n:i._anchor,t?t:i._include)}):new e(a.mappings[0].value,this._unit,this,t,n).directChildren(null,null,!0);case M.Kind.MAPPING:var o=this._node;return null==o.value?[]:new e(o.value,this._unit,this,n?n:this._anchor,t?t:this._include).directChildren();case M.Kind.SEQ:var s=this._node;return s.items.filter(function(e){return null!=e}).map(function(r){return new e(r,i._unit,i,n?n:i._anchor,t?t:i._include)});case M.Kind.INCLUDE_REF:return[];case M.Kind.ANCHOR_REF:return[]}throw new F("Should never happen; kind : "+M.Kind[this._node.kind])}return[]},e.prototype.anchorId=function(){return this._node.anchorId},e.prototype.unit=function(){return this._unit},e.prototype.includeBaseUnit=function(){return this._unit},e.prototype.setUnit=function(e){this._unit=e},e.prototype.includePath=function(){var e=this.getIncludeString();return e?e:null},e.prototype.includeReference=function(){var e=this.getIncludeString();return e?O.getIncludeReference(e):null},e.prototype.getIncludeString=function(){if(this._node.kind==M.Kind.INCLUDE_REF){var t=this._node.value;return t}if(this._node.kind==M.Kind.MAPPING){var n=this._node;return null==n.value?null:new e(n.value,this._unit,this,null,null).getIncludeString()}return null},e.prototype.anchoredFrom=function(){return this._anchor},e.prototype.includedFrom=function(){return this._include},e.prototype.kind=function(){return this._actualNode().kind},e.prototype.valueKind=function(){if(this._node.kind!=M.Kind.MAPPING)return null;var e=this._node;return e.value?e.value.kind:null},e.prototype.anchorValueKind=function(){if(this.valueKind()==M.Kind.ANCHOR_REF){var e=this._node.value;return e.value.kind}return null},e.prototype.valueKindName=function(){var e=this.valueKind();return void 0!=e?M.Kind[e]:null},e.prototype.kindName=function(){return M.Kind[this.kind()]},e.prototype.indent=function(e,t){void 0===t&&(t="");for(var n="",r=0;e>r;r++)n+="  ";return n+t},e.prototype.replaceNewlines=function(e,t){void 0===t&&(t=null);for(var n="",r=0;r<e.length;r++){var i=e[r];"\r"==i&&(i=null==t?"\\r":t),"\n"==i&&(i=null==t?"\\n":t),n+=i}return n},e.prototype.shortText=function(e,t){void 0===t&&(t=50);var n=this.end()-this.start(),r=n,i=this.unit();!e&&i&&(e=i.contents());var a;if(e){var o=e;a=o?o.substring(this.start(),this.end()):"[no-text]"}else a="[no-unit]";return a="["+this.start()+".."+this.end()+"] "+n+" // "+a+" //",n>r&&(a+="..."),a=this.replaceNewlines(a)},e.prototype.nodeShortText=function(e,t,n){void 0===n&&(n=50);var r=e.endPosition-e.startPosition,i=r,a=this.unit();!t&&a&&(t=a.contents());var o;if(t){var s=t;o=s?s.substring(e.startPosition,e.endPosition):"[no-text]"}else o="[no-unit]";return o="["+e.startPosition+".."+e.endPosition+"] "+r+" // "+o+" //",r>i&&(o+="..."),o=this.replaceNewlines(o)},e.prototype.show=function(e,t,n){void 0===e&&(e=null),void 0===t&&(t=0),void 0===n&&(n=null),e&&0==t&&console.log(e);var r=this.children(),i=this.kindName(),a=this._actualNode().value;this.kind()==M.Kind.MAPPING&&(i+="["+this._actualNode().key.value+"]"),i+=a?"/"+M.Kind[a.kind]:"",0==r.length?(console.log(this.indent(t)+i+" // "+this.shortText(n)),this.isMapping()&&this.asMapping().value&&console.log(this.indent(t+1)+"// "+this.valueKindName()+": "+this.nodeShortText(this.asMapping().value,n))):(console.log(this.indent(t)+i+" { // "+this.shortText(n)),this.isMapping()&&this.asMapping().value&&console.log(this.indent(t+1)+"// "+this.valueKindName()+": "+this.nodeShortText(this.asMapping().value,n)),r.forEach(function(e){var r=e;r.show(null,t+1,n)}),console.log(this.indent(t)+"}"))},e.prototype.showParents=function(e,t){void 0===t&&(t=0),e&&0==t&&console.log(e);var n=0;if(this.parent()){var r=this.parent();n=r.showParents(null,t+1)}var i=this.kindName(),a=this._actualNode().value;return i+=a?"/"+M.Kind[a.kind]:"/null",console.log(this.indent(n)+i+" // "+this.shortText(null)),n+1},e.prototype.inlined=function(e){return e==M.Kind.SCALAR||e==M.Kind.INCLUDE_REF},e.prototype.markupNode=function(e,t,n,r){void 0===r&&(r=!1);var i=e.text.length;switch(t.kind){case M.Kind.MAP:r&&e.append("{");for(var o=t.mappings,s=0;s<o.length;s++)r&&s>0&&e.append(", "),this.markupNode(e,o[s],n,r);r&&e.append("}");break;case M.Kind.SEQ:for(var u=t.items,s=0;s<u.length;s++)e.append(this.indent(n,"- ")),this.markupNode(e,u[s],n+1,r);break;case M.Kind.MAPPING:var l=t,p=l.value;if(r){if(!p){e.append("\n");break}if(e.append(l.key.value),e.append(": "),p.kind==M.Kind.SCALAR){var c=p;e.append(c.value)}else{if(p.kind!=M.Kind.MAP)throw new F("markup not implemented: "+M.Kind[p.kind]);this.markupNode(e,l.value,n+1,r)}break}if(e.addWithIndent(n,l.key.value+":"),!p){e.append("\n");break}if(p.kind==M.Kind.SCALAR)var c=p;l.value?(e.append(this.inlined(l.value.kind)?" ":"\n"),this.markupNode(e,l.value,n+1,r)):e.append("\n");break;case M.Kind.SCALAR:var c=t;if(R.isMultiLine(c.value)){e.append("|\n");for(var f=a(c.value),s=0;s<f.length;s++)e.append(this.indent(n,f[s]));e.append("\n")}else e.append(c.value+"\n");break;case M.Kind.INCLUDE_REF:var m=t;e.append("!include "+m.value+"\n");break;default:throw new F("Unknown node kind: "+M.Kind[t.kind])}for(;i<e.text.length&&" "==e.text[i];)i++;t.startPosition=i,t.endPosition=e.text.length},e.prototype.markup=function(e){void 0===e&&(e=!1);var t=new B("");return this.markupNode(t,this._actualNode(),0,e),t.text},e.prototype.root=function(){for(var e=this;e.parent();){var t=e.parent();e=t}return e},e.prototype.parentOfKind=function(e){for(var t=this.parent();t;){if(t.kind()==e)return t;t=t.parent()}return null},e.prototype.find=function(e){var t=null;return this.directChildren().forEach(function(n){n.key()&&n.key()==e&&(t||(t=n))}),t},e.prototype.shiftNodes=function(e,t,n){if(this.directChildren().forEach(function(r){if(n&&n.start()==r.start()&&n.end()==r.end());else{r.shiftNodes(e,t,n)}}),n&&n.start()==this.start()&&n.end()==this.end());else{var r=this._actualNode();r&&$(e,r,t)}return null},e.prototype.isMap=function(){return this.kind()==M.Kind.MAP},e.prototype.isMapping=function(){return this.kind()==M.Kind.MAPPING},e.prototype.isSeq=function(){return this.kind()==M.Kind.SEQ},e.prototype.isScalar=function(){return this.kind()==M.Kind.SCALAR},e.prototype.asMap=function(){if(!this.isMap())throw new F("map expected instead of "+this.kindName());return this._actualNode()},e.prototype.asMapping=function(){if(!this.isMapping())throw new F("maping expected instead of "+this.kindName());return this._actualNode()},e.prototype.asSeq=function(){if(!this.isSeq())throw new F("seq expected instead of "+this.kindName());return this._actualNode()},e.prototype.asScalar=function(){if(!this.isScalar())throw new F("scalar expected instead of "+this.kindName());return this._actualNode()},e.prototype.isValueSeq=function(){return this.valueKind()==M.Kind.SEQ},e.prototype.isValueMap=function(){return this.valueKind()==M.Kind.MAP},e.prototype.isValueInclude=function(){return this.valueKind()==M.Kind.INCLUDE_REF},e.prototype.isValueScalar=function(){return this.valueKind()==M.Kind.SCALAR},e.prototype.valueAsSeq=function(){if(!this.isMapping())throw new F("mapping expected instead of "+this.kindName());if(this.valueKind()!=M.Kind.SEQ)throw new F("mappng/seq expected instead of mapping/"+this.kindName());return this.asMapping().value},e.prototype.valueAsMap=function(){if(!this.isMapping())throw new F("mapping expected instead of "+this.kindName());if(this.valueKind()!=M.Kind.MAP)throw new F("mappng/map expected instead of mapping/"+this.kindName());return this.asMapping().value},e.prototype.valueAsScalar=function(){if(!this.isMapping())throw new F("mapping expected instead of "+this.kindName());if(this.valueKind()!=M.Kind.SCALAR)throw new F("mappng/scalar expected instead of mapping/"+this.kindName());return this.asMapping().value},e.prototype.valueAsInclude=function(){if(!this.isMapping())throw new F("mapping expected instead of "+this.kindName());if(this.valueKind()!=M.Kind.INCLUDE_REF)throw new F("mappng/include expected instead of mapping/"+this.kindName());return this.asMapping().value},e.prototype.text=function(e){if(void 0===e&&(e=null),!e){if(!this.unit())return"[no-text]";e=this.unit().contents()}return e.substring(this.start(),this.end())},e.prototype.copy=function(){var t=i(this._actualNode());return new e(t,this._unit,this._parent,this._anchor,this._include,this._includesContents)},e.prototype.nodeDefinition=function(){return A(this)},e.CLASS_IDENTIFIER="jsyaml2lowLevel.ASTNode",e}();t.ASTNode=z,function(e){e[e.NONE=0]="NONE",e[e.START=1]="START",e[e.END=2]="END",e[e.POINT=3]="POINT"}(t.InsertionPointType||(t.InsertionPointType={}));var J=t.InsertionPointType,Q=function(){function e(e,t){void 0===t&&(t=null),this.type=e,this.point=t}return e.isInstance=function(t){return null!=t&&t.getClassIdentifier&&"function"==typeof t.getClassIdentifier&&w.contains(t.getClassIdentifier(),e.CLASS_IDENTIFIER)},e.prototype.getClassIdentifier=function(){var t=[];return t.concat(e.CLASS_IDENTIFIER)},e.after=function(t){return new e(J.POINT,t)},e.atStart=function(){return new e(J.START)},e.atEnd=function(){return new e(J.END)},e.node=function(){return new e(J.NONE)},e.prototype.show=function(e){e?(console.log(e),console.log("  insertion point type: "+J[this.type])):console.log("insertion point type: "+J[this.type]),this.type==J.POINT&&this.point&&this.point.show()},e.CLASS_IDENTIFIER="jsyaml2lowLevel.InsertionPoint",e}();t.InsertionPoint=Q,t.createNode=p,t.createMap=c,t.createScalar=f,t.createSeq=m,t.createSeqNode=d,t.createMapNode=h,t.createMapping=y,t.toChildCachingNode=v,t.toIncludingNode=g,t.getDefinitionForLowLevelNode=A,t.fetchIncludesAndMasterAsync=T},function(e,t,n){"use strict";function r(){return Object.keys(m).length>0}function i(e){f.push(e)}function a(e){m[e]=!0}function o(e){delete m[e],f.forEach(function(t){return t(e)})}function s(e){return m[e]?!0:!1}function u(e,t){c.set(e,t)}function l(e){return c.get(e)}n(65);n(63),n(74);var p=n(76),c=p(50);t.hasAsyncRequests=r,t.addLoadCallback=i;var f=[],m={};t.addNotify=a,t.removeNotity=o,t.isWaitingFor=s,t.set=u,t.get=l},function(e,t,n){"use strict";function r(e){if(!e)return e;var t=e.indexOf("#");return-1==t?e:e.substring(0,t)}function i(e){if(!e)return null;"string"!=typeof e&&(e=""+e);var t=e.indexOf("#");if(-1==t)return null;var n=t==e.length-1?"":e.substring(t+1,e.length),i=n.split("/");return 0==i.length?null:(""==i[0].trim()&&i.splice(0,1),new d(n,r(e),i))}function a(){return[new h,new y]}function o(e,t){if(!e)return t;var n=i(e);if(!n)return t;var a=r(e);return s(a,n,t).content}function s(e,t,n){var r=c.find(a(),function(t){return t.isApplicable(e,n)});return r?r.resolveReference(n,t):{content:n,validation:[]}}function u(e,t,n){if(!n)return[];var r=c.find(a(),function(t){return t.isApplicable(e,n)});return r?r.completeReference(n,t):[]}function l(e,t){return e&&t?e.lastIndexOf(t)===e.length-t.length:!1}function p(e,t){for(var n=e.getElementsByTagName(t),r=[],i=0;i<n.length;i++){var a=n[i];a.parentNode===e&&r.push(a)}return r}var c=n(64),f=n(72).DOMParser,m=n(62);t.getIncludePath=r,t.getIncludeReference=i,t.getIncludeReferenceResolvers=a,t.resolveContents=o,t.resolve=s,t.completeReference=u;var d=function(){function e(e,t,n){this.includePath=t,this.segments=n,this.originalString=e}return e.prototype.getIncludePath=function(){return this.includePath},e.prototype.getFragments=function(){return this.segments},e.prototype.asString=function(){return this.originalString},e.prototype.encodedName=function(e){return void 0===e&&(e=!0),m(this.includePath+"/"+this.asString())+(e?this.includePath.substring(this.includePath.lastIndexOf(".")):"")},e}(),h=function(){function e(){}return e.prototype.isApplicable=function(e,t){return e&&(l(e.trim(),".js")||l(e.trim(),".json"))},e.prototype.resolveReference=function(e,t){try{var n={};return n.$ref=t.getIncludePath()+"#"+t.asString(),{content:JSON.stringify(n,null,2),validation:[]}}catch(r){console.log(r)}return{content:e,validation:[]}},e.prototype.completeReference=function(e,t){try{var n=JSON.parse(e),r=t.getFragments();if(!r||0==r.length)return this.getChildren(n);for(var i=n,a=t.asString().lastIndexOf("/")==t.asString().length-1,o=(a?r.length:r.length-1,0);o<r.length-1;o++){var s=r[o];if(i=this.findChild(i,s),!i)return[]}if(a)return this.getChildren(i);var u=r[r.length-1],l=[];return this.getChildren(i).forEach(function(e){0==e.indexOf(u)&&l.push(e)}),l}catch(p){console.log(p)}return[]},e.prototype.findChild=function(e,t){var n=t.replace("~1","/");return n=t.replace("~0","~"),e[n]},e.prototype.getChildren=function(e){return Object.keys(e)},e}(),y=function(){function e(){}return e.prototype.isApplicable=function(e,t){return e&&(l(e.trim(),".xml")||l(e.trim(),".xsd"))},e.prototype.resolveReference=function(e,t){try{var n=(new f).parseFromString(e),r=t.asString(),i=t.encodedName(!1),a=p(n,"xs:schema")[0],o=p(a,"xs:element"),s=p(a,"xs:complexType"),u=c.find(o,function(e){return e.getAttribute("name")===r}),l=u?c.find(s,function(e){return e.getAttribute("name")===u.getAttribute("type")}):c.find(s,function(e){return e.getAttribute("name")===r}),m=n.createElement("xs:element");m.setAttribute("name",i),l&&m.setAttribute("type",l.getAttribute("name")),u&&m.setAttribute("originalname",u.getAttribute("name")),m.setAttribute("requestedname",r),m.setAttribute("extraelement","true"),a.appendChild(m);var d=n.toString(),h=d,y=d.indexOf("?>");if(y>0&&d.length>y+2){var v=d.charAt(y+2);"\n"!=v&&(h=d.slice(0,y+2)+"\n"+d.slice(y+2))}return{content:h,validation:[]}}catch(g){console.log(g)}return{content:e,validation:[]}},e.prototype.completeReference=function(e,t){try{var n=(new f).parseFromString(e),r=[],i=p(n,"xs:schema")[0],a=p(i,"xs:element"),o=p(i,"xs:complexType");a.forEach(function(e){return r.push(e.getAttribute("name"))}),o.forEach(function(e){return r.push(e.getAttribute("name"))});var s=0===t.asString().trim().length;return s?r:r.filter(function(e){return 0===e.indexOf(t.asString())})}catch(u){return[]}},e}()},function(e,t,n){"use strict";function r(e){return e instanceof v.ApiImpl||e instanceof g.ApiImpl?(new R).expandTraitsAndResourceTypes(e):null}function i(e){return(new I).expandLibraries(e)}function a(e,t,n){var r=m.fromUnit(e);if(!r)throw new Error("couldn't load api from "+e.absolutePath());if(!t||0==t.length)return r;for(var i=[],a=0;a<t.length;a++){var s=t[a],u=m.fromUnit(s);if(!u)throw new Error("couldn't load api from "+s.absolutePath());i.push(u)}var l=o(r,i,n);return l}function o(e,t,n,r,i){void 0===r&&(r=null),void 0===i&&(i=!1);for(var a=e,o=0,s=t;o<s.length;o++){var u=s[o];i&&y.LowLevelProxyNode.isInstance(a.lowLevel())&&(a=(new R).expandHighLevelNode(a,r,e.wrapperNode()).highLevel()),u.overrideMaster(a),u.setMergeMode(n),a=u}return a}function s(e){for(var t=[],n=0,r=e;n<r.length;n++){var i=r[n];u(t,i,!0)}return t}function u(e,t,n){void 0===n&&(n=!1);var r=n?e:e.concat([]),i=t.lowLevel().unit();if(null==i)return r;if(0==r.length)r.push(i);else{var a=r[r.length-1].absolutePath();i.absolutePath()!=a&&r.push(i)}return r}function l(e){for(var t=[];e;)t.push(e),e=e.parent();return s(t)}function p(){return L.map(function(e){return e.name})}function c(e){for(var t=[],n=e.split("|").slice(1),r=0,i=n;r<i.length;r++)for(var a=i[r],o=0;o<L.length;o++)if(a.match(L[o].regexp)){t.push(L[o].transformer);break}return t}var f=this&&this.__extends||function(e,t){function n(){this.constructor=e}for(var r in t)t.hasOwnProperty(r)&&(e[r]=t[r]);e.prototype=null===t?Object.create(t):(n.prototype=t.prototype,new n)},m=n(16),d=n(75),h=n(33),y=n(41),v=n(22),g=n(50),A=n(34),S=n(51),T=n(71),E=n(17),b=n(64),N=n(52),_=n(49),M=n(14),w=n(73);t.expandTraitsAndResourceTypes=r,t.expandLibraries=i,t.mergeAPIs=a;var R=function(){function e(){this.namespaceResolver=new _.NamespaceResolver}return e.prototype.expandTraitsAndResourceTypes=function(e,t,n){if(void 0===t&&(t=null),
void 0===n&&(n=!1),this.init(e),!e.highLevel().lowLevel())return e;var r=e.highLevel().lowLevel().unit(),i=r.project().namespaceResolver().hasFragments(r),a=0!=this.globalTraits.length||0!=this.globalResourceTypes.length;if(!a&&!i&&!n)return e;var o=this.createHighLevelNode(e.highLevel(),!1,t);if(e.definition().key()==E.Universe10.Overlay)return o.wrapperNode();var s=this.expandHighLevelNode(o,t,e);return s},e.prototype.init=function(e){this.ramlVersion=e.highLevel().definition().universe().version(),this.globalTraits="RAML10"==this.ramlVersion?A.allTraits(e):S.allTraits(e),this.globalResourceTypes="RAML10"==this.ramlVersion?A.allResourceTypes(e):S.allResourceTypes(e)},e.prototype.expandHighLevelNode=function(e,t,n){var r=this;this.init(n);var i=e.wrapperNode();i.setAttributeDefaults(n.getDefaultsCalculator().isEnabled()),i.highLevel().setMergeMode(n.highLevel().getMergeMode());var a=i.resources();return a.forEach(function(e){return r.processResource(e)}),"RAML10"==this.ramlVersion&&(t=t||new N.ReferencePatcher,t.process(e),e.lowLevel().actual().referencePatcher=t),i},e.prototype.getTemplate=function(e,t,n,r){var i=t.lowLevel().unit().path(),a=n[i];a||(a={},n[i]=a);var o=a[e];return void 0!==o?o:(o=null,o=b.find(r,function(n){return m.qName(n.highLevel(),t)==e}),o||(o=null),a[e]=o,o)},e.prototype.createHighLevelNode=function(e,t,n,r){void 0===t&&(t=!0),void 0===n&&(n=null),void 0===r&&(r=!1);for(var i=e,a=[],s=i;s;){var u,l=s.lowLevel();u=i.definition().key()!=E.Universe10.Overlay||r?new y.LowLevelCompositeNode(l,null,null,this.ramlVersion):l;var p=s.definition(),c=new m.ASTNodeImpl(u,null,p,null);if(a.push(c),!t)break;s=s.getMaster()}var f=a.pop();a=a.reverse();var d=i.getMergeMode();return o(f,a,d,n,r)},e.prototype.processResource=function(e,t){var n=this;void 0===t&&(t=[]);var r=t.concat(e.highLevel()),i=this.collectResourceData(e,e,void 0,void 0,r),a=e.highLevel().lowLevel();i.filter(function(e){return null!=e.resourceType}).forEach(function(t){var n=t.resourceType.node.highLevel().lowLevel(),r=t.resourceType.transformer;r.owner=e,a.adopt(n,r)});var o=e.methods();o.forEach(function(e){var t=e.highLevel().lowLevel(),n=e.method(),r=[];i.forEach(function(i){var a=i.methodTraits[n];a&&(r=r.concat(a),a.forEach(function(n){var r=n.node.highLevel().lowLevel(),i=n.transformer;i.owner=e,t.adopt(r,i)}));var o=i.traits;o&&(r=r.concat(o),o.forEach(function(n){var r=n.node.highLevel().lowLevel(),i=n.transformer;i.owner=e,t.adopt(r,i)}))})});var s=e.resources();s.forEach(function(e){return n.processResource(e,r)})},e.prototype.collectResourceData=function(e,t,n,r,i,a){var o=this;void 0===n&&(n=[]),void 0===i&&(i=[]),void 0===a&&(a={}),i=i.concat([t.highLevel()]);var u=this.extractTraits(t,r,i),l={},p=t.methods();p.forEach(function(e){var t=o.extractTraits(e,r,i);t&&t.length>0&&(l[e.method()]=t)});var c,f=t.type();if(null!=f){var d=s(i);c=this.readGenerictData(e,f,t.highLevel(),"resource type",r,d)}var h={resourceType:c,traits:u,methodTraits:l};if(n.push(h),c){var y=c.node,v=m.qName(y.highLevel(),e.highLevel());a[v]?h.resourceType=null:(a[v]=!0,this.collectResourceData(e,y,n,c.transformer,i,a))}return n},e.prototype.extractTraits=function(e,t,n,r){var i=this;void 0===r&&(r={}),n=n.concat([e.highLevel()]);for(var a=[],o=-1;o<a.length;o++){var l=0>o?null:a[o],p=l?l.node:e,c=l?l.unitsChain:s(n),f=l?l.transformer:t;p.is&&p.is().forEach(function(t){var n=u(c,t.highLevel()),o=i.readGenerictData(e,t,p.highLevel(),"trait",f,n);if(o){var s=o.name;r[s]=!0,a.push(o)}})}return a},e.prototype.readGenerictData=function(e,t,n,r,i,a){void 0===a&&(a=[]);var o=t.value(),s=T.plural(w.camelCase(r));if("string"==typeof o){i&&(o=i.transform(o).value);var u=N.getDeclaration(o,s,this.namespaceResolver,a);if(u){var l=u.wrapperNode();return{name:o,transformer:null,parentTransformer:i,node:l,ref:t,unitsChain:a}}}else if(m.StructuredValue.isInstance(o)){var p=o,c=p.valueName();i&&(c=i.transform(c).value);var f={},h={},u=N.getDeclaration(c,s,this.namespaceResolver,a);if(u){var l=u.wrapperNode();"RAML08"==this.ramlVersion?p.children().forEach(function(e){return f[e.valueName()]=e.lowLevel().value()}):p.children().forEach(function(e){var t=e.lowLevel();t.valueKind()==d.Kind.SCALAR?f[e.valueName()]=t.value():t.valueKind()==d.Kind.INCLUDE_REF&&0==t.children().length?f[e.valueName()]=t.value():h[e.valueName()]=t});var y=new D(e,null,a);Object.keys(f).forEach(function(e){var t=y.transform(f[e]);t&&"object"!=typeof t&&(f[e]=t)});var v=new O(r,c,a,f,h,i),g=new D(null,v,a);return{name:c,transformer:g,parentTransformer:i,node:l,ref:t,unitsChain:a}}}return null},e.prototype.appendTraitReferences=function(e,t){if(0!=t.length){var n=t.map(function(e){return{node:e.ref.highLevel().lowLevel(),transformer:e.parentTransformer}});N.patchMethodIs(e.highLevel(),n)}},e}();t.TraitsAndResourceTypesExpander=R;var I=function(){function e(){}return e.prototype.expandLibraries=function(e){var t=e;if(null==t)return null;y.LowLevelCompositeNode.isInstance(t.highLevel().lowLevel())&&(t=t.highLevel().lowLevel().unit().highLevel().asElement().wrapperNode());var n=new R,r=new N.ReferencePatcher,i=n.createHighLevelNode(t.highLevel(),!0,r,!0),a=n.expandHighLevelNode(i,r,t);return this.processNode(r,a.highLevel()),a},e.prototype.processNode=function(e,t){if(null!=t){var n=t.getMaster();this.processNode(e,n),M.isOverlayType(t.definition())&&e.process(t),e.expandLibraries(t)}},e}();t.LibraryExpander=I,t.toUnits=l;var C=function(){function e(t,n){this.name=t,this.regexp=new RegExp(e.leftTransformRegexp.source+t+e.rightTransformRegexp.source),this.transformer=n}return e.leftTransformRegexp=/\s*!\s*/,e.rightTransformRegexp=/\s*$/,e}(),L=[new C("singularize",function(e){return T.singular(e)}),new C("pluralize",function(e){return T.plural(e)}),new C("uppercase",function(e){return e?e.toUpperCase():e}),new C("lowercase",function(e){return e?e.toLowerCase():e}),new C("lowercamelcase",function(e){return e?w.camelCase(e):e}),new C("uppercamelcase",function(e){if(!e)return e;var t=w.camelCase(e);return t[0].toUpperCase()+t.substring(1,t.length)}),new C("lowerunderscorecase",function(e){if(!e)return e;var t=w.snake(e);return t.toLowerCase()}),new C("upperunderscorecase",function(e){if(!e)return e;var t=w.snake(e);return t.toUpperCase()}),new C("lowerhyphencase",function(e){if(!e)return e;var t=w.param(e);return t.toLowerCase()}),new C("upperhyphencase",function(e){if(!e)return e;var t=w.param(e);return t.toUpperCase()})];t.getTransformNames=p,t.getTransformersForOccurence=c;var P=function(){function e(){this.buf=null}return e.prototype.append=function(e){""!==e&&(null!=this.buf?null!=e&&("string"!=typeof this.buf&&(this.buf=""+this.buf),this.buf+=e):""!==e&&(this.buf=e))},e.prototype.value=function(){return null!=this.buf?this.buf:""},e}(),O=function(){function e(e,t,n,r,i,a){this.templateKind=e,this.templateName=t,this.unitsChain=n,this.params=r,this.structuredParams=i,this.vDelegate=a}return e.prototype.transform=function(e,t,n,r){var i={},a=[];if("string"==typeof e){if(this.structuredParams&&h.stringStartsWith(e,"<<")&&h.stringEndsWith(e,">>")){var o=e.substring(2,e.length-2),s=this.structuredParams[o];if(null!=s)return{value:s.value(t),errors:a}}for(var u=e,l=new P,p=0,f=u.indexOf("<<");f>=0;f=u.indexOf("<<",p)){l.append(u.substring(p,f));var m=f;if(f+="<<".length,p=this.paramUpperBound(u,f),-1==p)break;var d=u.substring(f,p);p+=">>".length;var y,o,v=u.substring(m,p),g=c(d);if(g.length>0){var A=d.indexOf("|");if(o=d.substring(0,A).trim(),y=this.params[o],y&&"string"==typeof y&&y.indexOf("<<")>=0&&this.vDelegate&&(y=this.vDelegate.transform(y,t,n,r).value),y)for(var S=0,T=g;S<T.length;S++){var E=T[S];y=E(y)}}else o=d.trim(),y=this.params[o],y&&"string"==typeof y&&y.indexOf("<<")>=0&&this.vDelegate&&(y=this.vDelegate.transform(y,t,n,r).value);(null===y||void 0===y)&&(i[o]=!0,y=v),l.append(y)}return l.append(u.substring(p,u.length)),{value:l.value(),errors:a}}return{value:e,errors:a}},e.prototype.paramUpperBound=function(e,t){for(var n=0,r=t;r<e.length;r++)if(h.stringStartsWith(e,"<<",r))n++,r++;else if(h.stringStartsWith(e,">>",r)){if(0==n)return r;n--,r++}return e.length},e.prototype.children=function(e){var t=this.substitutionNode(e);return t?t.children():null},e.prototype.valueKind=function(e){var t=this.substitutionNode(e);return t?t.valueKind():null},e.prototype.substitutionNode=function(e){var t=this.paramName(e);return t&&this.structuredParams[t]},e.prototype.paramName=function(e){var t=null;if(e.valueKind()==d.Kind.SCALAR){var n=(""+e.value()).trim();h.stringStartsWith(n,"<<")&&h.stringEndsWith(n,">>")&&(t=n.substring(2,n.length-2))}return t},e}();t.ValueTransformer=O;var D=function(e){function t(t,n,r){e.call(this,null!=n?n.templateKind:"",null!=n?n.templateName:"",r),this.owner=t,this.delegate=n}return f(t,e),t.prototype.transform=function(t,n,r,i){if(null==t||null!=r&&!r())return{value:t,errors:[]};var a={value:t,errors:[]},o=!1;x.forEach(function(e){return o=o||t.toString().indexOf("<<"+e)>=0}),o&&(this.initParams(),a=e.prototype.transform.call(this,t,n,r,i));var s=null!=this.delegate?this.delegate.transform(a.value,n,r,i):a.value;return null!=r&&r()&&null!=i&&(s.value=i(s.value,this)),s},t.prototype.initParams=function(){for(var e,t,n="",r=this.owner.highLevel().lowLevel(),i=r,a=null;i;){var o=i.key();if(null!=o)if(h.stringStartsWith(o,"/")){if(!t)for(var s=o.split("/"),u=s.length-1;u>=0;u--){var l=s[u];if(-1==l.indexOf("{")){t=s[u];break}l.length>0&&(a=l)}n=o+n}else e=o;i=i.parent()}t||a&&(t=""),this.params={resourcePath:n,resourcePathName:t},e&&(this.params.methodName=e)},t.prototype.children=function(e){return null!=this.delegate?this.delegate.children(e):null},t.prototype.valueKind=function(e){return null!=this.delegate?this.delegate.valueKind(e):null},t}(O);t.DefaultTransformer=D;var x=["resourcePath","resourcePathName","methodName"]},function(e,t,n){(function(e){"use strict";function r(e,t,n){return new xe.Function(e).call(t,n)}function i(e,t){var n=e.property();return n&&n.getContextRequirements().forEach(function(r){e.checkContextValue(r.name,r.value,r.value)||t.accept(J(Pe.CONTEXT_REQUIREMENT,{name:r.name,value:r.value,propName:n.nameId()},e))}),n}function a(e,t){var n;try{n=e.lowLevel().unit().project().fsEnabled()}catch(r){n=!0}if(n&&"undefined"!=typeof he&&he){for(var i=["exists","readFile","writeFile","readdir","existsSync","readFileSync","writeFileSync","readdirSync"],a=(Object.keys(he),0);a<i.length;a++)if(!he[i[a]])return;var o=e.lowLevel().unit().absolutePath(),s=de.dirname(o),u=de.resolve(s,"raml-lint.js");Ue(u,t,e);var l=de.resolve(s,".raml");if(he.existsSync(l)){var p=he.statSync(l);if(p.isDirectory()){var c=he.readdirSync(l);c.forEach(function(n){-1!=n.indexOf("-lint.js")&&Ue(de.resolve(l,n),t,e)})}}}}function o(e){return e.nameId()==ye.Universe10.TypeDeclaration.properties.type.name||e.nameId()==ye.Universe10.TypeDeclaration.properties.schema.name}function s(e){return l(e)?e.nameId()==ye.Universe10.TypeDeclaration.properties["default"].name:!1}function u(e){return l(e)?e.nameId()==ye.Universe10.TypeDeclaration.properties.example.name:!1}function l(e){return e.domain()?e.domain().getAdapter(Ae.RAMLService).isUserDefined()?!1:!0:!1}function p(e){return l(e)?e.nameId()==ye.Universe08.MethodBase.properties.securedBy.name:!1}function c(e){for(var t=e;;){if(t.definition().getAdapter(Ae.RAMLService).isInlinedTemplates())return t.definition().nameId();var n=t.parent();if(!n)break;t=n}return null}function f(e){var n=e.parent(),r=null,i=n.definition();if(n&&fe.UserDefinedClass.isInstance(i)){var a=n.property();if(ve.isIsProperty(a)||ve.isTypeProperty(a)){var o=e.name();r=null!=t.RESERVED_TEMPLATE_PARAMETERS[o]?J(Pe.INVALID_PARAMETER_NAME,{paramName:o},e):J(Pe.UNUSED_PARAMETER,{paramName:o},e)}}if(!r){var s=e.name(),u=ge("RAML08"),l=i.universe().version()==u.version();if(l){var p=ye.Universe08.Parameter.name;ye.Universe10.TypeDeclaration.name;if(l&&i.isAssignableFrom(p)){for(var c=u.type(p).allSubTypes().filter(function(e){return null!=ye.Universe08[e.nameId()].properties[s]}),f={},m=0;m<c.length;m++){var d=c[m];if(!f[d.nameId()]){var h=d.valueRequirements();if(h&&0!=h.length){var y=h.filter(function(e){return"type"==e.name}).map(function(e){return e.value});if(0!=y.length){var v=y[0];f[d.nameId()]=v,d.allSubTypes().forEach(function(e){return c.push(e)})}}}}var g=Object.keys(f).map(function(e){return f[e]}).sort();if(g.length>0){var A=g.map(function(e,t){var n="'"+e+"'";return t==g.length-1?n:t==g.length-2?n+" or ":n+", "}).join("");r=J(Pe.INVALID_PROPERTY_OWNER_TYPE,{propName:s,namesStr:A},e)}}}}return r}function m(e,t){if(e.isElement()){if(e.invalidSequence){var n=e.property().nameId();n=Ce.sentenceCase(Le.singular(n)),t.acceptUnique(Z(Pe.SEQUENCE_NOT_ALLOWED_10,{propName:n},e.lowLevel().parent().parent(),e))}var r=e.asElement();if(r.definition().isAssignableFrom(ye.Universe10.LibraryBase.name)){var i,a=!1,o=!1;r.lowLevel().children().forEach(function(e){"schemas"==e.key()&&(a=!0,i=e),"types"==e.key()&&(o=!0)}),a&&o&&t.accept(ht(i,r,ue.IssueCode.ILLEGAL_PROPERTY_VALUE,!1,"types and schemas are mutually exclusive",!1))}r.definition().requiredProperties()&&r.definition().requiredProperties().length>0;d(e,t),(new tt).validate(r,t),(new mt).validate(r,t)}else d(e,t);(new ct).validate(e,t)}function d(e,t,n){void 0===n&&(n=!1);var r=e.parent(),i=e.lowLevel().value();if(e.lowLevel()){if(e.lowLevel().keyKind()==ce.Kind.MAP&&t.accept(J(Pe.NODE_KEY_IS_A_MAP,{},e)),e.lowLevel().keyKind()==ce.Kind.SEQ&&null==i){var a=!1;e.isElement()&&e.asElement().definition().isAssignableFrom(ye.Universe10.TypeDeclaration.name)&&(a=!0),a||t.accept(J(Pe.NODE_KEY_IS_A_SEQUENCE,{},e))}null==r&&e.lowLevel().errors().forEach(function(n){var r=n.mark?n.mark.position:0,i={code:"YAML_ERROR",message:n.message,node:null,start:r,end:r+1,isWarning:!1,path:e.lowLevel().unit()==e.root().lowLevel().unit()?null:e.lowLevel().unit().path(),unit:e.lowLevel().unit()};t.accept(i)})}if(e.isUnknown()){if(-1!=e.name().indexOf("<<")&&null!=c(r))return(new Ve).validateName(e,t),!1;if(e.needSequence&&t.accept(J(Pe.SEQUENCE_REQUIRED,{name:e.name()},e)),e.needMap)return e.knownProperty?t.accept(J(Pe.PROPERTY_MUST_BE_A_MAP_10,{propName:e.knownProperty.nameId()},e)):t.accept(J(Pe.MAP_REQUIRED,{},e)),!1;if(e.unresolvedRef&&t.accept(J(Pe.UNRESOLVED_REFERENCE,{ref:i},e)),e.knownProperty){if(0==e.lowLevel().includeErrors().length){if(c(r)&&Ne.startsWith(i,"<<")&&Ne.endsWith(i,">>"))return!1;if("body"==e.name()&&e.computedValue("mediaType"))return!1;"~"!=e.lowLevel().value()&&t.accept(J(Pe.SCALAR_PROHIBITED,{propName:e.name()},e))}}else{var o=f(e);o||(o=J(Pe.UNKNOWN_NODE,{name:e.name()},e)),t.accept(o)}}if(e.markCh()&&!e.allowRecursive())return e.property()?(t.accept(J(Pe.RECURSIVE_DEFINITION,{name:e.name()},e)),!1):!1;if(e.definition&&e.definition().isAssignableFrom(ye.Universe10.Operation.name)){var s=y(e.wrapperNode()),u=s.queryStringComesFrom,l=s.queryParamsComesFrom;u&&l&&(t.accept(h(u,e,!1)),t.accept(h(l,e,!0)))}var p=e.definition&&e.definition()&&(e.definition().key()===ye.Universe10.Overlay||e.definition().key()===ye.Universe10.Extension);return p&&E(e,t,n),!0}function h(e,t,n){var r=e,i=e,a=n?ye.Universe10.Operation.properties.queryString.name:ye.Universe10.Operation.properties.queryParameters.name;return r.unit?Z(Pe.PROPERTY_ALREADY_SPECIFIED,{propName:a},r,t):J(Pe.PROPERTY_ALREADY_SPECIFIED,{propName:a},i)}function y(e){return{queryParamsComesFrom:v(e,!0),queryStringComesFrom:v(e,!1)}}function v(e,t){if(!e)return null;var n=A(e,t);if(n)return n;var r=e.is&&e.is()||[],i=pe.find(r,function(e){return v(e.trait(),t)});if(i)return i.highLevel();var a=e.parentResource&&e.parentResource(),o=a&&g(a,t);return o?o:(a=e.parent&&e.parent(),a&&a.highLevel().definition().isAssignableFrom(ye.Universe10.ResourceBase.name)?g(a,t):null)}function g(e,t){var n=e.is(),r=pe.find(n,function(e){return v(e.trait(),t)});if(r)return r.highLevel();var i=e.type(),a=i&&i.resourceType(),o=a&&g(a,t);return o?i.highLevel():void 0}function A(e,t){return t?S(e):T(e)}function S(e){var t=e.highLevel();return t.lowLevel&&pe.find(t.lowLevel().children(),function(e){return e.key&&e.key()===ye.Universe10.Operation.properties.queryParameters.name})}function T(e){var t=e.highLevel(),n=t.element(ye.Universe10.Operation.properties.queryString.name);return n}function E(e,t,n){if(void 0===n&&(n=!1),!e.parent()){var r=e.asElement();if(r&&r.isAuxilary()){var i=r.getMaster();i&&m(i,t)}}}function b(e,t,n){if(void 0===n&&(n=!1),d(e,t,n))try{var r=e.definition&&e.definition()&&(e.definition().key()===ye.Universe10.Overlay||e.definition().key()===ye.Universe10.Extension),i=r?e.children():e.directChildren();i.filter(function(e){return!n||e.property&&e.property()&&e.property().isRequired()}).forEach(function(n){if(n&&n.errorMessage){var r=n.errorMessage;return void t.accept(J(r.entry,r.parameters,n.name()?n:e))}n.validate(t)})}finally{e.unmarkCh()}}function N(e){var t=e.value();if("string"==typeof t&&-1!=t.indexOf("<<"))return!0;for(var n=e.children(),r=0;r<n.length;r++)if(N(n[r]))return!0;return!1}function _(e,t){if(!e.parent())try{w(e,t)}finally{M(e,t)}if(e.isAttr())(new We).validate(e,t);else if(e.isElement()){if(e.invalidSequence){var n=e.property().nameId(),r=Ce.sentenceCase(Le.singular(n));t.acceptUnique(Z(Pe.SEQUENCE_NOT_ALLOWED_10,{propName:r},e.lowLevel().parent().parent(),e,!1))}var i=e.asElement();if(ve.isExampleSpecType(i.definition())){var a=i.children();if(0==a.length)return void b(e,t,!0);var o=a.filter(function(e){var t=e.lowLevel().key();return t?"("==t.charAt(0)&&")"==t.charAt(t.length-1)?!1:null==i.definition().property(t):!0});if(o.length>0)return void b(e,t,!0)}if(i.definition().isAnnotationType()||i.property()&&"annotations"==i.property().nameId())return void(new Ze).validate(i,t);if(i.definition().isAssignableFrom(ye.Universe10.UsesDeclaration.name)){var s=i.attr(ye.Universe10.UsesDeclaration.properties.value.name);if(s&&s.value()){var u=i.lowLevel().unit().resolve(s.value());if(u){if(!Me.isWaitingFor(s.value())){var l=[];if(0===u.contents().trim().length)return void t.accept(J(Pe.EMPTY_FILE,{path:s.value()},i,!1));if(u.highLevel().validate(me.createBasicValidationAcceptor(l,u.highLevel())),l.length>0){var p=Fe(s,i);l.forEach(function(e){e.unit=null==e.unit?u:e.unit,e.path||(e.path=u.absolutePath())});for(var f=0,m=l;f<m.length;f++){for(var d=m[f],h=d;h.extras.length>0;)h=h.extras[0];h!=p&&h.extras.push(p),t.accept(d)}}}}else t.accept(J(Pe.INVALID_LIBRARY_PATH,{path:s.value()},i,!1))}}if(i.definition().isAssignableFrom(ye.Universe10.TypeDeclaration.name)){if(c(i)&&N(i.lowLevel()))return;return i.attrs().forEach(function(n){var r=n.property().range().key();if(r==ye.Universe08.RelativeUriString||r==ye.Universe10.RelativeUriString)return void(new He).validate(n,t);if(r==ye.Universe08.FullUriTemplateString||r==ye.Universe10.FullUriTemplateString)return void(new He).validate(n,t);if(n.property().getAdapter(Ae.RAMLPropertyService).isKey()){var a=e.property()&&e.property().nameId();if(a==ye.Universe08.Resource.properties.uriParameters.name||a==ye.Universe08.Resource.properties.baseUriParameters.name)return;if(i.property()&&i.property().nameId()==ye.Universe10.MethodBase.properties.body.name)return void(new $e).validate(n,t)}}),(new ot).validate(i,t),(new st).validate(i,t),(new it).validate(i,t),void(new et).validate(i,t)}if(i.definition().isAssignableFrom(ye.Universe10.LibraryBase.name)){var y,v=!1,g=!1;i.lowLevel().children().forEach(function(e){"schemas"==e.key()&&(v=!0,y=e),"types"==e.key()&&(g=!0)}),v&&g&&t.accept(Z(Pe.TYPES_AND_SCHEMAS_ARE_EXCLUSIVE,{},y,i))}var A=i.definition().requiredProperties()&&i.definition().requiredProperties().length>0,S=i.definition().getAdapter(Ae.RAMLService).getAllowAny();S?A&&b(e,t,!0):b(e,t),(new ft).validate(i,t),(new tt).validate(i,t),(new mt).validate(i,t)}else b(e,t);(new ct).validate(e,t)}function M(e,t){if(e.lowLevel()){var n=e.lowLevel().actual();delete n._inc,e.children().forEach(function(e){return M(e,t)})}}function w(e,t){var n=e.lowLevel();if(n){var r=n.actual();if(!r._inc){if(e.isElement()){var i=e.name();"string"==typeof i&&null!=i&&-1!=i.indexOf(" ")&&t.accept(J(Pe.SPACES_IN_KEY,{value:i},e,!0))}if(r._inc=!0,n){n.includeErrors().forEach(function(n){var r=!1;e.lowLevel().hasInnerIncludeError()&&(r=!0);var i=J(Pe.INCLUDE_ERROR,{msg:n},e,r);t.accept(i)});var a=n.includePath();if(null!=a&&!de.isAbsolute(a)&&!le.isWebPath(a)){var o=n.unit().absolutePath(),s=I(de.dirname(o),a);if(s>0){var u=J(Pe.PATH_EXCEEDS_ROOT,{},e,!0);t.accept(u)}}}e.children().forEach(function(e){return w(e,t)}),0==e.children().length&&null!=n&&n.children().forEach(function(n){return R(n,t,e)})}}}function R(e,t,n){e.includeErrors().forEach(function(r){var i=!1;e.hasInnerIncludeError()&&(i=!0);var a=Z(Pe.INCLUDE_ERROR,{msg:r},e,n,i);t.accept(a)});var r=e.includePath();if(null!=r&&!de.isAbsolute(r)&&!le.isWebPath(r)){var i=e.unit().absolutePath(),a=I(de.dirname(i),r);if(a>0){var o=Z(Pe.PATH_EXCEEDS_ROOT,{},e,n,!0);t.accept(o)}}e.children().forEach(function(e){return R(e,t,n)})}function I(e,t){for(var n=Be(e),r=Be(t),i=n.length,a=0,o=0,s=r;o<s.length;o++){var u=s[o];".."==u?(i--,0>i&&(a=Math.min(i,a))):i++}return-1*a}function C(e,t,n,r,i){return e.hasArrayInHierarchy()?L(e,t,n,r,i):e.hasValueTypeInHierarchy()?P(e,t,n,r,i):!0}function L(e,t,n,r,i){return e.arrayInHierarchy().componentType()?C(e.arrayInHierarchy().componentType(),t,n,r):!0}function P(e,t,n,r,i){try{if(e.key()==ye.Universe10.AnnotationRef){var a=Ee.referenceTargets(r,t),o=pe.find(a,function(e){return me.qName(e,t)==n});if(null!=o){var s=o.attributes("allowedTargets");if(s){var u=s.map(function(e){return e.value()});if(u.length>0){var l=!1,p=t.definition().allSuperTypes();p=p.concat([t.definition()]);var c=p.map(function(e){return e.nameId()});if(u.forEach(function(e){"API"==e&&(e="Api"),"NamedExample"==e&&(e="ExampleSpec"),"SecurityScheme"==e&&(e="AbstractSecurityScheme"),"SecuritySchemeSettings"==e&&(e="SecuritySchemeSettings"),pe.find(c,function(t){return t==e})?l=!0:("Parameter"==e&&t.computedValue("location")&&(l=!0),"Field"==e&&t.computedValue("field")&&(l=!0))}),!l){var f=u.map(function(e){return"'"+e+"'"}).join(", ");return new qe(Pe.INVALID_ANNOTATION_LOCATION,{aName:n,aValues:f})}}}}return v}if(e.key()==ye.Universe08.SchemaString||e.key()==ye.Universe10.SchemaString){var m=!1;if(fe.UserDefinedProp.isInstance(r)){var d=r,h=d.node();if(h){var y=h.property();y&&(m=ve.isTypeProperty(y)||ve.isSchemaProperty(y))}}if(m)return!1;var v=we.createSchema(n,Y(t.lowLevel()));return v instanceof Error&&(v.canBeRef=!0),v}if(e.key()==ye.Universe08.StatusCodeString||e.key()==ye.Universe10.StatusCodeString){var g=te(n);if(null!=g)return g}if(e.key()==ye.Universe08.BooleanType||e.isAssignableFrom(ye.Universe10.BooleanType.name)){if("true"!==n&&"false"!==n&&n!==!0&&n!==!1)return new qe(Pe.BOOLEAN_EXPECTED);if(i){var A=i.lowLevel().value(!0);if("true"!==A&&"false"!==A)return new qe(Pe.BOOLEAN_EXPECTED)}}if(e.key()==ye.Universe08.NumberType||e.isAssignableFrom(ye.Universe10.NumberType.name)){var S=parseFloat(n);if(isNaN(S))return new qe(Pe.NUMBER_EXPECTED,{propName:r.nameId()})}if((e.key()==ye.Universe08.StringType||e.isAssignableFrom(ye.Universe10.StringType.name))&&null===n&&t&&r){var T=t.attr(r.nameId());if(T){var E=T.lowLevel().children();if(E&&E.length>0)return new qe(Pe.STRING_EXPECTED_3,{propName:r.nameId()})}}return!0}catch(b){return b.canBeRef=!0,b}}function O(e){if(!e)return!1;var t=e.toLowerCase(),n=e.toUpperCase();return e!==t&&e!==n?!0:!1}function D(e){if(!e)return null;if(e.isElement()){var n=e,r=n.definition();if(r&&t.typeToName.hasOwnProperty(r.nameId()))return t.typeToName[r.nameId()];if(r.isAssignableFrom(ye.Universe10.TypeDeclaration.name)||r.isAssignableFrom(ye.Universe08.Parameter.name)){if(n.property()&&t.parameterPropertyToName.hasOwnProperty(n.property().nameId()))return t.parameterPropertyToName[n.property().nameId()];if(n.property()&&n.parent()&&n.property().nameId()==ye.Universe10.LibraryBase.properties.types.name&&n.parent().definition()&&n.parent().definition().isAssignableFrom(ye.Universe10.LibraryBase.name))return"type";if(n.property()&&n.parent()&&n.property().nameId()==ye.Universe10.LibraryBase.properties.securitySchemes.name&&n.parent().definition()&&n.parent().definition().isAssignableFrom(ye.Universe10.LibraryBase.name))return"security scheme"}}return null}function x(e,t,n){var r=Ee.declRoot(n);r._cach||(r._cach={});var i=e.id();if(e.domain()&&(i+=e.domain().nameId()),i){var a=r._cach[i];if(a)return null!=a[t]}var o=Ee.enumValues(e,n),s={};return o.forEach(function(e){return s[e]=1}),e.id()&&(r._cach[i]=s),null!=s[t]}function U(e,n,r,i){if(F(e,n,i),B(e,n,i),r&&("null"!=r||!e.isAllowNull())){var a=e.getAdapter(Ae.RAMLPropertyService),o=x(e,r,n.parent());if(o||n.lowLevel().unit().absolutePath()===n.parent().lowLevel().unit().absolutePath()||(o=x(e,r,me.fromUnit(n.lowLevel().unit()))),!o){if("string"==typeof r&&0==r.indexOf("x-")&&e.nameId()==ye.Universe10.TypeDeclaration.properties.type.name)return!0;var s=a.isReference&&a.isReference()&&a.referencesTo&&a.referencesTo()&&a.referencesTo().nameId&&a.referencesTo().nameId(),u=t.typeToName[s]||V(n),l={referencedToName:u,ref:r},p=u?Pe.UNRECOGNIZED_ELEMENT:Pe.UNRESOLVED_REFERENCE,c=K(p,e,n);return i.accept(J(c,l,n,e.range().key()===ye.Universe08.SchemaString)),!0}return k(n)&&ve.isTraitRefType(n.definition())?(i.accept(J(Pe.DUPLICATE_TRAIT_REFERENCE,{refValue:r},n)),!0):!1}}function k(e){var t,n=e.property().domain().universe().version();if(t="RAML10"==n?oe(ae.serialize(e.lowLevel())):e.value()&&e.value().valueName&&e.value().valueName(),!t)return!1;var r=e.parent&&e.parent();if(!r)return!1;var i=e.name&&e.name();if(!i)return!1;var a=r.attributes&&r.attributes(i);if(!a)return!1;if(0===a.length)return!1;var o=0;return a.forEach(function(e){var r;"RAML10"==n?t=oe(ae.serialize(e.lowLevel())):r=e.value&&e.value()&&e.value().valueName&&e.value().valueName(),r===t&&o++}),o>1}function F(e,t,n){if(ve.isIsProperty(e)){var r=t.lowLevel();if(null!=r){var i=null,a=r.parent(),o=null!=a?a.parent():null;if(r.kind()==ce.Kind.MAPPING&&r.key()&&"is"==r.key()?i=r:null!=a&&a.kind()==ce.Kind.MAPPING&&a.key()&&"is"==a.key()?i=a:null!=o&&o.kind()==ce.Kind.MAPPING&&o.key()&&"is"==o.key()&&(i=o),null!=i){null==i.value()||i.children()&&0!=i.children().length||n.accept(J(Pe.IS_IS_ARRAY,{},t));var s=!1;i.children().forEach(function(e){e.kind()!=ce.Kind.SCALAR&&e.kind()!=ce.Kind.MAP&&(s=!0)}),s&&n.accept(J(Pe.IS_IS_ARRAY,{},t))}}}}function B(e,t,n){if(ve.isTypeProperty(e)&&ve.isResourceTypeRefType(t.definition())){var r=t.lowLevel();null==t.value()&&r&&r.children()&&0==r.children().length?r.kind()==ce.Kind.MAPPING&&null!=r.valueKind()&&n.accept(J(Pe.RESOURCE_TYPE_NAME,{},t)):null==t.value()&&r&&r.children()&&r.children().length>1&&n.accept(J(Pe.MULTIPLE_RESOURCE_TYPES,{},t))}}function K(e,t,n){return"type"==t.nameId()&&"RAML08"==t.domain().universe().version()&&t.domain().isAssignableFrom(ye.Universe08.Parameter.name)?Pe.TYPES_VARIETY_RESTRICTION:null!=n.parent()&&ve.isSecuritySchemaType(n.parent().definition())?Pe.UNRECOGNIZED_SECURITY_SCHEME:e}function V(e){var t=e&&e.lowLevel()&&e.lowLevel().key();if(t===ye.Universe10.AbstractSecurityScheme.properties.type.name){var n=e.parent()&&e.parent().definition()&&e.parent().definition().nameId();if(n===ye.Universe10.AbstractSecurityScheme.name)return"security scheme type"}else if(t===ye.Universe08.BodyLike.properties.schema.name){var n=e.parent()&&e.parent().definition()&&e.parent().definition().nameId();if(n===ye.Universe08.BodyLike.name)return"schema"}}function j(e,t){var n=t.getValidationPath();return q(e,n)}function W(e){var t=e.getExtra(be.SOURCE_EXTRA);return me.LowLevelWrapperForTypeSystem.isInstance(t)?t.node():null}function q(e,t){if(!t)return e;var n=e.children().filter(function(e){return e.isAttr()&&e.asAttr().isFromKey()?!1:e.name()===t.name}),r=t.child&&"number"==typeof t.child.name?t.child.name:-1;if(r>=0&&n.length>r)return q(n[r],t.child.child);if(n.length>0)return q(n[0],t.child);if(!e.lowLevel())return e;for(var i=e.lowLevel().children(),a=0;a<i.length;a++)if(i[a].key()===t.name){var o=new me.BasicASTNode(i[a],e);return q(o,t.child)}if(!isNaN(t.name)&&i[t.name]){var s=i[t.name],o=new me.BasicASTNode(s,e);return q(o,t.child)}return e}function Y(e){var t=e&&e.includeBaseUnit()&&(e.includePath&&e.includePath()?e.includeBaseUnit().resolve(e.includePath()):e.includeBaseUnit());return new _e.ContentProvider(t)}function H(e){return-1!=e.indexOf("json")}function $(e){return-1!=e.indexOf("xml")}function G(e){var t=X(e);if("body"==t){var n=e.root().attr("mediaType");return n?n.value():null}return t}function X(e){if(e.parent()){var t=e.parent().definition();if(t.key()==ye.Universe08.BodyLike)return e.parent().name();if(e.parent().parent()){var n=e.parent().parent().definition().key();if(n==ye.Universe08.Response||n==ye.Universe10.Response)return e.parent().property().nameId()==ye.Universe08.Response.properties.headers.name?null:e.parent().name();if(n==ye.Universe08.Method||n==ye.Universe10.Method)return e.parent().property().nameId()==ye.Universe10.MethodBase.properties.queryParameters.name||e.parent().property().nameId()==ye.Universe10.MethodBase.properties.headers.name?null:e.parent().name()}}return null}function z(e,t){return Q(e.getCode(),e.getMessage(),j(t,e),e.isWarning())}function J(e,t,n,r){void 0===r&&(r=!1);var i=ne(e,t);return Q(e.code,i,n,r)}function Q(e,t,n,r){void 0===r&&(r=!1);var i=null,a=null;if(se.LowLevelProxyNode.isInstance(n.lowLevel()))for(var o=n.lowLevel();!o.primaryNode();)i||(i=dt(n,e,r,t,!0,a)),n=n.parent(),o=n.lowLevel();var s=n;if(n&&(a=n.property(),n.lowLevel().unit()!=n.root().lowLevel().unit())){i=dt(n,e,r,t,!0,a);for(n.lowLevel().unit();n.lowLevel().unit()!=n.root().lowLevel().unit();)a=n.property(),n=n.parent()}if(i){var u=n.lowLevel().unit().project().namespaceResolver();if(u){var l=u.resolveNamespace(n.root().lowLevel().unit(),s.lowLevel().unit());if(l){var p=l.usesNodes.map(function(e){return Z(Pe.ISSUES_IN_THE_LIBRARY,{value:e.value()},e,e.unit().highLevel(),!0)});p.push(i),p=p.reverse();for(var c=0;c<p.length-1;c++)p[c].extras.push(p[c+1]);return i}}n.property()&&n.property().nameId()==ye.Universe10.FragmentDeclaration.properties.uses.name&&null!=n.parent()&&(a=n.property(),n=n.parent())}var f=dt(n,e,r,t,!1,a);if(i){if(i.extras.push(f),n.lowLevel().valueKind()==ce.Kind.INCLUDE_REF){var m=Pe.ERROR_IN_INCLUDED_FILE;f.code=m.code,f.message=ne(m,{msg:f.message})}f=i}return f}function Z(e,t,n,r,i,a){void 0===i&&(i=!1),void 0===a&&(a=!1);var o=ne(e,t);return ee(e.code,o,n,r,i,a)}function ee(e,t,n,r,i,a){void 0===i&&(i=!1),void 0===a&&(a=!1);var o=null;if(n){var s=r.root().lowLevel().unit();if(r.lowLevel().unit()!=s){o=ht(n,r,e,i,t,!0);var u=r.lowLevel().unit();for(u&&(t=t+" "+u.path());r.lowLevel().unit()!=s;)r=r.parent()}}o&&(r.property()&&r.property().nameId()==ye.Universe10.FragmentDeclaration.properties.uses.name&&null!=r.parent()&&(r=r.parent()),n=r.lowLevel());var l=ht(n,r,e,i,t,a);return o&&(o.extras.push(l),n.valueKind()==ce.Kind.INCLUDE_REF&&(l.message="Error in the included file: "+l.message),l=o),l}function te(e){if(3!=e.length)return new qe(Pe.STATUS_MUST_BE_3NUMBER);for(var t=0;t<e.length;t++){var n=e[t];if(!pe.find(["0","1","2","3","4","5","6","7","8","9"],function(e){return e==n}))return new qe(Pe.STATUS_MUST_BE_3NUMBER)}return null}function ne(e,t){for(var n="",r=e.message,i=0,a=r.indexOf("{{");a>=0;a=r.indexOf("{{",i)){if(n+=r.substring(i,a),i=r.indexOf("}}",a),0>i){i=a;break}a+="{{".length;var o=r.substring(a,i);i+="}}".length;var s=t[o];if(void 0===s)throw new Error("Message parameter '"+o+"' has no value specified.");n+=s}return n+=r.substring(i,r.length)}var re=this&&this.__extends||function(e,t){function n(){this.constructor=e}for(var r in t)t.hasOwnProperty(r)&&(e[r]=t[r]);e.prototype=null===t?Object.create(t):(n.prototype=t.prototype,new n)},ie=n(26),ae=n(53),oe=n(66),se=n(41),ue=n(9),le=n(10),pe=n(64),ce=n(75),fe=n(37),me=n(16),de=n(15),he=n(46),ye=n(17),ve=n(14),ge=n(36),Ae=fe,Se=n(54),Te=n(29),Ee=n(13),be=fe.rt,Ne=n(40),_e=n(32),Me=n(27),we=fe.getSchemaUtils(),Re=n(67),Ie=n(55),Ce=n(73),Le=n(71),Pe=n(81),Oe=function(){
function e(){this.validateNotStrictExamples=!0}return e}(),De=new Oe,xe=n(80);t.RESERVED_TEMPLATE_PARAMETERS={resourcePathName:'Part of the resource path following the rightmost "/"',methodName:"Method name",resourcePath:"Path of the resource"};var Ue=function(e,t,n){if(he.existsSync(e))try{var i=he.readFileSync(e).toString(),a=new ke(t);r(i,a,null),a.visit(n)}catch(o){console.log("Error in custom linter"),console.log(o)}},ke=function(){function e(e){this.acceptor=e,this.nodes={}}return e.prototype.error=function(e,t){this.acceptor.accept(J(Pe.INVALID_VALUE_SCHEMA,{iValue:t},e.highLevel()))},e.prototype.errorOnProperty=function(e,t,n){var r=e.highLevel().attr(t);this.acceptor.accept(J(Pe.INVALID_VALUE_SCHEMA,{iValue:n},r))},e.prototype.warningOnProperty=function(e,t,n){var r=e.highLevel().attr(t);this.acceptor.accept(J(Pe.INVALID_VALUE_SCHEMA,{iValue:n},r,!0))},e.prototype.warning=function(e,t){this.acceptor.accept(J(Pe.INVALID_VALUE_SCHEMA,{iValue:t},e.highLevel(),!0))},e.prototype.registerRule=function(e,t){var n=this.nodes[e];n||(n=[],this.nodes[e]=n),n.push(t)},e.prototype.visit=function(e){var t=this,n=e.definition();this.process(n,e),n.allSuperTypes().forEach(function(n){return t.process(n,e)}),e.elements().forEach(function(e){return t.visit(e)})},e.prototype.process=function(e,t){var n=this;if(fe.NodeClass.isInstance(e)&&!e.getAdapter(Ae.RAMLService).getDeclaringNode()){var r=this.nodes[e.nameId()];r&&r.forEach(function(e){return e(t.wrapperNode(),n)})}},e}();(function(){function e(){}return e.prototype.toString=function(){return this.prev?this.value+"."+this.prev.toString():this.value},e.prototype.last=function(){return this.prev?this.prev.last():this},e})();t.validateBasicFlat=d;(function(){function e(){}return e})();t.validateBasic=b;var Fe=function(e,t){var n=t.lowLevel().start(),r=[];if(0>n){for(var i=t.attr("key").value().split("."),a=[],o=t.parent(),s=0,u=i;s<u.length;s++){var l=u[s],p=pe.find(o.elementsOfKind("uses"),function(e){return e.attr("key")&&e.attr("key").value()==l});a.push(p),o=p.lowLevel().unit().resolve(p.attr("value").value()).highLevel().asElement()}var c=a.map(function(e){return J(Pe.ISSUES_IN_THE_LIBRARY,{value:e.attr("value").value()},e,!0)});c=c.reverse();for(var f=0;f<c.length-1;f++)c[f].extras.push(c[f+1]);return c[0]}return r.push(t),J(Pe.ISSUES_IN_THE_LIBRARY,{value:e.value()},t,!0)};t.validate=_;var Be=function(t){t=t.replace(/\\/g,"/").trim(),t.length>1&&":"==t.charAt(1)&&/^win/.test(e.platform)&&(t=t.substring(2));var n=t.split("/");return 0==n[0].length&&(n=n.slice(1)),n.length>0&&0==n[n.length-1].length&&(n=n.slice(0,n.length-1)),n},Ke=function(e,t,n){try{new RegExp(e)}catch(r){t.accept(J(Pe.ILLEGAL_PATTERN,{value:e},n))}},Ve=function(){function e(){}return e.prototype.validateName=function(e,t){var n=e.name();if(n){var r=e.lowLevel().keyStart();this.check(n,r,e,t)}},e.prototype.validateValue=function(e,t){var n=e.value();if("string"==typeof n){var r=e.lowLevel().valueStart();this.check(n,r,e,t)}},e.prototype.hasTraitOrResourceTypeParent=function(e){for(var t=e.parent();null!=t;){if(!t.definition())return!1;if(ve.isTraitType(t.definition())||ve.isResourceTypeType(t.definition()))return!0;t=t.parent()}return!1},e.prototype.check=function(e,t,n,r){if(!this.hasTraitOrResourceTypeParent(n))return[];for(var i=[],a=0,o=e.indexOf("<<");o>=0;o=e.indexOf("<<",a)){o+="<<".length,a=e.indexOf(">>",o);var s=e.substring(o,a),u=s.indexOf("|"),l=u>=0?s.substring(0,u):s;if(0==l.trim().length){var p=J(Pe.TEMPLATE_PARAMETER_NAME_MUST_CONTAIN_NONWHITESPACE_CHARACTERS,{},n);p.start=t+o,p.end=t+a,r.accept(p)}if(-1!=u){u++;for(var c=s.split("|").slice(1).map(function(e){return e.trim()}),f=Te.getTransformNames(),m=0,d=c;m<d.length;m++){var h=d[m];if(!pe.find(f,function(e){return h===e||h==="!"+e})){var p=J(Pe.UNKNOWN_FUNCTION,{transformerName:h},n,!1);p.start=t+u,p.end=t+a,r.accept(p)}}}a+=">>".length}return i},e}(),je=function(){function e(){}return e.prototype.validate=function(t,n){var r=t.parent();if(r&&(r.definition().isAssignableFrom(ye.Universe08.Method.name)||r.definition().isAssignableFrom(ye.Universe10.Method.name))){var i=pe.find(r.lowLevel()&&r.lowLevel().children()||[],function(e){var t=e.key();return t&&(ye.Universe08.MethodBase.properties.body.name===t||ye.Universe10.MethodBase.properties.body.name===t)});i&&pe.find(e.methodsWithoutRequestBody,function(e){return r.name()===e})&&n.accept(J(Pe.REQUEST_BODY_DISABLED,{methodName:r.name()},r))}},e.methodsWithoutRequestBody=["trace"],e}(),We=function(){function e(){}return e.prototype.validate=function(e,t){var n=i(e,t),r=e.value(),a=e.parent().definition().universe().version(),l=null!=c(e.parent());if(!e.property().range().hasStructure()){if(me.StructuredValue.isInstance(r)&&!e.property().isSelfNode()){if(o(e.property())&&e.property().domain().key()==ye.Universe08.BodyLike){var f=new me.ASTNodeImpl(e.lowLevel(),e.parent(),e.parent().definition().universe().type(ye.Universe08.BodyLike.name),e.property());return void f.validate(t)}if("RAML10"==a&&l)return;t.accept(J(Pe.SCALAR_EXPECTED,{},e))}else{var m=e.lowLevel().valueKind();if(e.lowLevel().valueKind()!=ce.Kind.INCLUDE_REF&&!e.property().getAdapter(Ae.RAMLPropertyService).isKey()&&!e.property().isMultiValue()){var d=e.property().range().key();(d==ye.Universe08.StringType||d==ye.Universe08.MarkdownString||d==ye.Universe08.MimeType)&&(m!=ce.Kind.SEQ&&m!=ce.Kind.MAPPING&&m!=ce.Kind.MAP&&(!e.property().isRequired()&&"mediaType"!=e.property().nameId()||null!=m&&void 0!==m)||e.property().domain().getAdapter(Ae.RAMLService).isInlinedTemplates()||t.accept(J(Pe.STRING_EXPECTED,{propName:e.name()},e)))}}if(e.isAnnotatedScalar()){var h=new Ze;e.annotations().forEach(function(e){var n=e.value(),r=n.toHighLevel();r?h.validate(r,t):t.accept(J(Pe.UNKNOWN_ANNOTATION,{aName:n.valueName()},e))})}}var y;if("string"==typeof r?y=r:me.StructuredValue.isInstance(r)&&(y=r.valueName()),!(y&&-1!=y.indexOf("<<")&&y.indexOf(">>")>y.indexOf("<<")&&((new Ve).validateValue(e,t),l))){if((new je).validate(e,t),e.property().range().key()==ye.Universe08.MimeType||e.property().range().key()==ye.Universe10.MimeType||e.property().nameId()==ye.Universe10.TypeDeclaration.properties.name.name&&e.parent().property().nameId()==ye.Universe10.MethodBase.properties.body.name)return void(new $e).validate(e,t);if(u(e.property())||s(e.property())){if("RAML08"==a){e.lowLevel().value();if(e.lowLevel().children().length>0){var v=u(e.property())?"'example'":"'defaultValue'";t.accept(J(Pe.STRING_EXPECTED_2,{propName:v},e,!1))}}(new lt).validate(e,t)}if(p(e.property())){if("RAML08"==a){var g=e.lowLevel().parent(),A=ce.Kind.SEQ;se.LowLevelProxyNode.isInstance(e.lowLevel())?g.valueKind()!=A&&t.accept(J(Pe.SECUREDBY_LIST_08,{},e,!1)):g.kind()!=A&&t.accept(J(Pe.SECUREDBY_LIST_08,{},e,!1))}if((new lt).validate(e,t),"RAML10"==a&&me.StructuredValue.isInstance(r)){var S=r,T=S.children().filter(function(e){return"scopes"==e.valueName()});if(T.length>0){var E=e.findReferencedValue();if(E){var b=[];T.forEach(function(e){var t=e.children();if(t.length>0)t.forEach(function(e){var t=e.lowLevel().value();null==t||l&&t.indexOf("<<")>=0||b.push(e)});else{var n=e.lowLevel().value();null==n||l&&n.indexOf("<<")>=0||b.push(e)}});var N={},_=E.element(fe.universesInfo.Universe10.AbstractSecurityScheme.properties.settings.name);if(_){var M=_.attributes(fe.universesInfo.Universe10.OAuth2SecuritySchemeSettings.properties.scopes.name);M.forEach(function(e){return N[e.value()]=!0})}for(var w=0,R=b;w<R.length;w++){var I=R[w],C=I.lowLevel().value();N.hasOwnProperty(C)||t.accept(Z(Pe.INVALID_SECURITY_SCHEME_SCOPE,{invalidScope:C,securityScheme:E.name(),allowedScopes:Object.keys(N).map(function(e){return"'"+e+"'"}).join(", ")},I.lowLevel(),e,!1))}}}}}if(e.property().nameId()==ye.Universe10.TypeDeclaration.properties.name.name){var L=e.parent().property()&&e.parent().property().nameId();if(L==ye.Universe08.Resource.properties.uriParameters.name||L==ye.Universe08.Resource.properties.baseUriParameters.name)return}var P=e.property().range().key();if(P==ye.Universe08.RelativeUriString||P==ye.Universe10.RelativeUriString)return void(new He).validate(e,t);if(P==ye.Universe08.FullUriTemplateString||P==ye.Universe10.FullUriTemplateString)return void(new He).validate(e,t);if("pattern"==e.name()&&ye.Universe10.StringType==e.definition().key()&&e.parent().definition().isAssignableFrom("StringTypeDeclaration")&&Ke(e.value(),t,e),"name"==e.name()&&ye.Universe10.StringType==e.definition().key()&&"string"==typeof e.value()&&0==e.value().indexOf("[")&&e.value().lastIndexOf("]")==e.value().length-1&&me.ASTNodeImpl.isInstance(e.parent())&&ye.Universe10.ObjectTypeDeclaration.properties.properties.name==e.parent().property().nameId()&&me.ASTNodeImpl.isInstance(e.parent().parent())&&ye.Universe10.ObjectTypeDeclaration==e.parent().parent().definition().key()){var O=e.value().substr(1,e.value().length-2);Ke(O,t,e)}n.isReference()||n.isDescriminator()?(new Xe).validate(e,t):(new Ye).validate(e,t)}},e}();t.isValid=C;var qe=function(e){function t(t,n){void 0===n&&(n={}),e.call(this),this.messageEntry=t,this.parameters=n}return re(t,e),t.isInstance=function(e){return null!=e&&e.getClassIdentifier&&"function"==typeof e.getClassIdentifier&&pe.contains(e.getClassIdentifier(),t.CLASS_IDENTIFIER_ValidationError)},t.prototype.getClassIdentifier=function(){var e=[];return e.concat(t.CLASS_IDENTIFIER_ValidationError)},t.CLASS_IDENTIFIER_ValidationError="linter.ValidationError",t}(Error),Ye=function(){function e(){}return e.prototype.validate=function(e,t){var n=e.value(),r=e.property(),i=r.range(),a=i.getAdapter(Ae.RAMLService).getDeclaringNode();if(a&&i.isUserDefined()){var o=a.parsedType(),s=e.parent().lowLevel().dumpToObject(),u=s[e.parent().name()],l=r.canBeValue(),p=l||null===u||void 0===u?u:u[r.nameId()],c=o.validate(p,!0);c.isOk()||c.getErrors().forEach(function(n){return t.accept(Q(n.getCode(),n.getMessage(),e,!1))})}var f=t;if(e.lowLevel().keyKind()!=ce.Kind.SEQ)var m=C(r.range(),e.parent(),n,r,e);else m=!0;if(m instanceof Error&&!m.canBeRef){if(qe.isInstance(m)){var d=m;f.accept(J(d.messageEntry,d.parameters,e))}else f.accept(J(Pe.SCHEMA_EXCEPTION,{msg:m.message},e));return void(m=null)}if(!m||m instanceof Error)if("value"!=r.nameId()){if(!U(r,e,n,f)){if((r.nameId()==ye.Universe10.TypeDeclaration.properties.schema.name||ye.Universe10.TypeDeclaration.properties.type.name)&&n&&n.trim()&&(r.domain().key()==ye.Universe08.BodyLike||r.domain().key()==ye.Universe10.TypeDeclaration)){var h=n.trim().charAt(0);if("{"!=h&&"<"!=h)return}var y=e.findReferencedValue();if(y instanceof Error)if(qe.isInstance(y)){var d=y;f.accept(J(d.messageEntry,d.parameters,e))}else f.accept(J(Pe.SCHEMA_EXCEPTION,{msg:y.message},e));if(!y){if(n&&r.nameId()==ye.Universe10.TypeDeclaration.properties.schema.name){var v=n.trim();if("{"!=v.charAt(0)&&"<"!=v.charAt(0)&&(-1!=n.indexOf("|")||-1!=n.indexOf("[]")||-1!=n.indexOf("(")))return}if(m instanceof Error&&n){if(qe.isInstance(m)){var d=m;f.accept(J(d.messageEntry,d.parameters,e))}else f.accept(J(Pe.SCHEMA_EXCEPTION,{msg:m.message},e));return void(m=null)}if(e.property().isRequired()&&null==e.value())f.accept(J(Pe.EMPTY_VALUE_NOT_ALLOWED,{},e));else{var g=e.lowLevel().valueKind();(g==ce.Kind.MAP||g==ce.Kind.SEQ||g==ce.Kind.MAPPING)&&f.accept(J(Pe.EMPTY_VALUE_NOT_ALLOWED,{},e))}}}}else if(m instanceof Error){var A=m.message;f.accept(J(Pe.SCHEMA_ERROR,{msg:A},e,r.range().key()==ye.Universe08.SchemaString))}else{var n=e.value();f.accept(J(Pe.INVALID_VALUE_SCHEMA,{iValue:n},e,r.range().key()==ye.Universe08.SchemaString))}var S=r.enumOptions();if(S){var T=e.parent()&&e.parent().definition(),E=T&&T.isAssignableFrom(ye.Universe10.Api.name),b=T&&T.isAssignableFrom(ye.Universe08.Api.name),N=r.nameId()===ye.Universe08.Api.properties.protocols.name,_=r.nameId()===ye.Universe10.Api.properties.protocols.name;if("string"!=typeof n)return;!b&&!E||!N&&!_||O(n)||(n=n.toUpperCase()),"string"==typeof S?S!=n&&(n&&0==n.indexOf("x-")&&r.nameId()==ye.Universe08.AbstractSecurityScheme.properties.type.name||f.accept(J(Pe.INVALID_VALUE,{iValue:n,aValues:"'"+S+"'"},e))):S.length>0&&(pe.find(S,function(e){return e==n})||n&&0==n.indexOf("x-")&&r.nameId()==ye.Universe08.AbstractSecurityScheme.properties.type.name||f.accept(J(Pe.INVALID_VALUE,{iValue:n,aValues:S.map(function(e){return"'"+e+"'"}).join(", ")},e)))}},e}(),He=function(){function e(){}return e.prototype.validate=function(e,t){try{var n=(new Ge).parseUrl(e.value());if(n.some(function(e){return"version"==e})&&"baseUri"==e.property().nameId()){var r=e.root().attr("version");r||t.accept(J(Pe.MISSING_VERSION,{},e,!1))}n.some(function(e){return 0==e.length})&&t.accept(J(Pe.URI_PARAMETER_NAME_MISSING,{},e,!1))}catch(i){t.accept(J(Pe.URI_EXCEPTION,{msg:i.message},e,!1))}},e}(),$e=function(){function e(){}return e.prototype.validate=function(e,t){try{var n=e.value();if(!n)return;if("*/*"==n)return;if(n.indexOf("/*")==n.length-2&&(n=n.substring(0,n.length-2)+"/xxx"),e.parent()&&e.parent().parent()&&e.parent().parent().definition().isAssignableFrom(ye.Universe10.Trait.name)&&n.indexOf("<<")>=0)return;if("body"==n&&e.parent().parent()){var r=e.parent().parent().definition().key();(r===ye.Universe08.Response||r===ye.Universe10.Response||e.parent().parent().definition().isAssignableFrom(ye.Universe10.MethodBase.name))&&(n=e.parent().computedValue("mediaType"))}var i=Re.parse(n);i.type.match(/[\w\d][\w\d!#\$&\-\^_+\.]*/)||t.accept(J(Pe.INVALID_MEDIATYPE,{mediaType:i.type},e))}catch(a){t.accept(J(Pe.MEDIATYPE_EXCEPTION,{msg:a.message},e))}(e.value()&&"multipart/form-data"==e.value()||"application/x-www-form-urlencoded"==e.value())&&e.parent()&&e.parent().parent()&&e.parent().parent().property()&&e.parent().parent().property().nameId()==ye.Universe10.MethodBase.properties.responses.name&&t.accept(J(Pe.FORM_IN_RESPONSE,{},e,!0))},e}(),Ge=function(){function e(){}return e.prototype.checkBaseUri=function(e,t,n,r){var i=t.root().attr("baseUri");if(i){var a=i.value();try{var o=this.parseUrl(a);pe.find(o,function(e){return e==n})||r.accept(J(Pe.UNUSED_URL_PARAMETER,{paramName:""},e))}catch(s){}}else r.accept(J(Pe.UNUSED_URL_PARAMETER,{paramName:""},e))},e.prototype.parseUrl=function(e){for(var t=[],n="",r=!1,i=0,a=0;a<e.length;a++){var o=e[a];"{"!=o?"}"!=o?r&&(n+=o):(i--,r=!1,t.push(n),n=""):(i++,r=!0)}if(i>0)throw new Error("Invalid resource name: unmatched '{'");if(0>i)throw new Error("Invalid resource name: unmatched '}'");return t},e.prototype.validate=function(e,t){var n=e.value();if(e.parent().property().nameId()==ye.Universe10.Api.properties.baseUri.name){var r=e.parent().parent();return void this.checkBaseUri(e,r,n,t)}var r=e.parent().parent(),i=r.name();if(r.definition().key()===ye.Universe10.Api||r.definition().key()===ye.Universe08.Api)return void this.checkBaseUri(e,r,n,t);if(r.definition().key()!=ye.Universe10.ResourceType&&r.definition().key()!=ye.Universe08.ResourceType)try{var a=this.parseUrl(i),o=pe.find(a,function(e){return e==n});if(!o){var s=e.root().attr(ye.Universe10.Api.properties.baseUri.name);if(s&&e.name()===ye.Universe08.Api.properties.baseUriParameters.name){var u=s.value();if(u&&(a=this.parseUrl(u),a&&a.length>0&&pe.find(a,function(e){return e==n})))return}t.accept(J(Pe.UNUSED_URL_PARAMETER,{paramName:"'"+n+"'"},e))}}catch(l){}},e}();t.UrlParameterNameValidator=Ge,t.typeToName={},t.typeToName[ye.Universe08.Trait.name]="trait",t.typeToName[ye.Universe08.ResourceType.name]="resource type",t.typeToName[ye.Universe10.Trait.name]="trait",t.typeToName[ye.Universe10.ResourceType.name]="resource type",t.typeToName[ye.Universe10.AbstractSecurityScheme.name]="security scheme",t.typeToName[ye.Universe10.Method.name]="method",t.typeToName[ye.Universe08.Method.name]="method",t.typeToName[ye.Universe10.Resource.name]="resource",t.typeToName[ye.Universe08.Resource.name]="resource",t.typeToName[ye.Universe10.Api.name]="api",t.typeToName[ye.Universe08.Api.name]="api",t.typeToName[ye.Universe10.Response.name]="response",t.typeToName[ye.Universe08.Response.name]="response",t.typeToName[ye.Universe08.BodyLike.name]="body",t.parameterPropertyToName={},t.parameterPropertyToName[ye.Universe08.MethodBase.properties.headers.name]="header",t.parameterPropertyToName[ye.Universe08.MethodBase.properties.queryParameters.name]="query parameter",t.parameterPropertyToName[ye.Universe08.Api.properties.uriParameters.name]="uri parameter",t.parameterPropertyToName[ye.Universe08.Api.properties.baseUriParameters.name]="base uri parameter",t.parameterPropertyToName[ye.Universe08.BodyLike.properties.formParameters.name]="form parameter",t.parameterPropertyToName[ye.Universe10.MethodBase.properties.headers.name]="header",t.parameterPropertyToName[ye.Universe10.MethodBase.properties.queryParameters.name]="query parameter",t.parameterPropertyToName[ye.Universe10.ResourceBase.properties.uriParameters.name]="uri parameter",t.parameterPropertyToName[ye.Universe10.Api.properties.baseUriParameters.name]="base uri parameter",t.parameterPropertyToName[ye.Universe10.MethodBase.properties.body.name]="body",t.getHumanReadableNodeName=D;var Xe=function(){function e(){}return e.prototype.validate=function(e,t){var n=e.value(),r=n,i=e.property();if("string"==typeof n){if(U(i,e,n,t),fe.ReferenceType.isInstance(i.range())){var a=(i.range(),ie.createNode(""+n,e.lowLevel().parent(),e.lowLevel().unit()));a._actualNode().startPosition=e.lowLevel().valueStart(),a._actualNode().endPosition=e.lowLevel().valueEnd();var o=new me.StructuredValue(a,e.parent(),e.property()),s=o.toHighLevel();s&&s.validate(t)}}else if(null!=n){var u=n;if(u){r=u.valueName();var l=u.valueName();if(!U(i,e,l,t)){var p=u.toHighLevel();p&&p.validate(t)}}else r=null}else e.definition().isAssignableFrom(ye.Universe10.Reference.name)&&U(i,e,null,t);if(r){var c=C(i.range(),e.parent(),r,i);if(c instanceof Error){if(qe.isInstance(c)){var f=c;t.accept(J(f.messageEntry,f.parameters,e))}else t.accept(J(Pe.SCHEMA_EXCEPTION,{msg:c.message},e));c=null}}},e}(),ze=function(){function e(){}return e.prototype.validate=function(e,t){var n=e.universe(),r=n.getTypedVersion();if(r){if("0.8"!==r&&"1.0"!==r){var i=J(Pe.UNKNOWN_RAML_VERSION,{},e);t.accept(i)}var a=n.getOriginalTopLevelText();if(a){var o={typeName:a};if(a!=e.definition().nameId()){if("Api"==e.definition().nameId()){var i=J(Pe.UNKNOWN_TOPL_LEVEL_TYPE,o,e);t.accept(i)}}else if("Api"==n.getOriginalTopLevelText()){var i=J(Pe.REDUNDANT_FRAGMENT_NAME,o,e);t.accept(i)}}}},e}(),Je=function(){function e(){}return e.prototype.validate=function(e,t){var n=this;e.definition().getAdapter(Ae.RAMLService).getContextRequirements().forEach(function(n){if(!e.checkContextValue(n.name,n.value,n.value)){var r={v1:n.name,v2:n.value,v3:e.definition().nameId()},i=Pe.CONTEXT_REQUIREMENT_VIOLATION;"location"==n.name&&"ParameterLocation.FORM"==n.value&&(i=Pe.WEB_FORMS),t.accept(J(i,r,e))}});var r,i=e.definition().getAdapter(Ae.RAMLService).isInlinedTemplates();if(i){for(var a={},o=0,s=e.lowLevel().children();o<s.length;o++){var u=s[o];a[u.key()]=u.value(!0)}for(var l=e.definition().isAssignableFrom(ye.Universe10.Trait.name)?"trait":"resource type",p=Te.toUnits(e),c=new Te.ValueTransformer(l,e.definition().nameId(),p,a),f=e.parent(),m=f?f.definition():e.definition();null!=f&&!ve.isResourceType(m)&&!ve.isMethodType(m);)f=f.parent();r=new Te.DefaultTransformer(f,c,p)}e.definition().requiredProperties().forEach(function(a){if(i){var o=a.getAdapter(Ae.RAMLPropertyService).meta("templatePaths");if(o){for(var s=e.parent(),u=!1,l=0,p=o;l<p.length;l++){var c=p[l];if(c=c.map(function(e){return r.transform(e).value}),n.checkPathSufficiency(s.lowLevel(),c,s)){u=!0;break}}if(!u)return}}var f=a.range();if(f.hasArrayInHierarchy()&&(f=f.arrayInHierarchy().componentType()),f.hasValueTypeInHierarchy()){var m=e.attr(a.nameId()),d=!1;if(null!=m&&(m.lowLevel().kind()==ce.Kind.SCALAR||m.lowLevel().valueKind()==ce.Kind.SCALAR||m.lowLevel().kind()==ce.Kind.INCLUDE_REF||m.lowLevel().valueKind()==ce.Kind.INCLUDE_REF||null===m.lowLevel().valueKind()&&!i?d=!0:0!=m.lowLevel().children().length&&(d=!0)),!d){var h={propName:a.nameId()},y=Pe.MISSING_REQUIRED_PROPERTY;i&&(y=Pe.VALUE_NOT_PROVIDED);var v=J(y,h,e);t.accept(v)}}else{var g=e.elementsOfKind(a.nameId());if(!g||0==g.length){var v=J(Pe.MISSING_REQUIRED_PROPERTY,{propName:a.nameId()},e);t.accept(v)}}})},e.prototype.checkPathSufficiency=function(e,t,n){if(null==n||null==n.definition())return!1;var r=n.definition();if(ve.isResourceTypeType(r)||ve.isTraitType(r))return!0;if(0==t.length)return!1;if(null==e)return!1;var i=t[0];if(null==i)return!1;if("/"==i)return this.checkPathSufficiency(e,t.slice(1),n);if(0==i.length)return!0;var a=e.children().filter(function(e){return e.key()==i});0==a.length&&t.indexOf("/")<0;var o=a[0];if(se.LowLevelCompositeNode.isInstance(o)&&(o=o.primaryNode()),null==o)return t.indexOf("/")<0;if("type"==o.key())return!0;if(1==t.length)return null==o||null==o.value();var s=t.slice(1);return this.checkPathSufficiency(o,s,n)},e}(),Qe=function(){function e(){}return e.prototype.validate=function(e,t){var n=e.lowLevel().unit();e.lowLevel().visit(function(r){if(r.unit()!=n)return!1;if(r.value()&&r._node&&r._node.value&&r._node.value.doubleQuoted){var i=(r.value()+"").indexOf(":"),a=(r.value()+"").indexOf("\n");if(-1!=i&&-1!=a&&(!r.includePath()||0==r.includePath().length)){var o=J(Pe.SUSPICIOUS_DOUBLEQUOTE,{value:r.value()},e,!0);o.start=r._node.value.startPosition,o.end=r._node.value.endPosition,o.start==o.end&&o.end++,t.accept(o)}}return!0})},e}(),Ze=function(){function e(){}return e.prototype.validate=function(e,t){var n=e.definition(),r=n.getAdapter(Ae.RAMLService).getDeclaringNode();if(r){var i=r.parsedType(),a=e.lowLevel().dumpToObject(!0);a&&(a=a[Object.keys(a)[0]]);var o=i.validate(a,!1,!1);o.isOk()||o.getErrors().forEach(function(n){return t.accept(Q(n.getCode(),n.getMessage(),j(e,n),!1))})}},e}(),et=function(){function e(){this.annotables={API:!0,DocumentationItem:!0,Resource:!0,Method:!0,Response:!0,RequestBody:!0,ResponseBody:!0,TypeDeclaration:!0,Example:!0,ResourceType:!0,Trait:!0,SecurityScheme:!0,SecuritySchemeSettings:!0,AnnotationType:!0,Library:!0,Overlay:!0,Extension:!0}}return e.prototype.validate=function(e,t){var n=(e.definition(),e.parsedType()),r=n.validateType(e.types().getAnnotationTypeRegistry());if(!r.isOk())for(var i=0,a=r.getErrors();i<a.length;i++){var o,s=a[i],u=W(s);o=u?ee(s.getCode(),s.getMessage(),u,j(e,s),s.isWarning(),!0):Q(s.getCode(),s.getMessage(),j(e,s),s.isWarning()),t.accept(o)}var l=e.lowLevel()&&pe.find(e.lowLevel().children(),function(e){return"examples"==e.key()});if(l&&l.valueKind&&l.valueKind()===ce.Kind.SEQ&&(o=Z(Pe.MAP_EXPECTED,{},l,e,!1),t.accept(o)),e.property()&&ve.isAnnotationTypesProperty(e.property())||me.isAnnotationTypeFragment(e))for(var p=e.attributes(ye.Universe10.TypeDeclaration.properties.allowedTargets.name),c=0,f=p;c<f.length;c++){var m=f[c];this.checkAnnotationTarget(m,t)}},e.prototype.checkAnnotationTarget=function(e,t){var n=e.value();if(null!=n){"string"!=typeof n&&t.accept(J(Pe.ANNOTATION_TARGET_MUST_BE_A_STRING,{},e,!1));var r=n;n.replace(/\w|\s/g,"").length>0?t.accept(J(Pe.ALLOWED_TARGETS_MUST_BE_ARRAY,{},e,!1)):this.annotables[r]||t.accept(J(Pe.UNSUPPORTED_ANNOTATION_TARGET,{aTarget:r},e,!1))}},e}(),tt=function(){function e(){}return e.prototype.validate=function(e,t){if(!e.definition().isAnnotationType()){if(e.lowLevel().keyKind()==ce.Kind.SEQ){var n=e.definition().isAssignableFrom(ye.Universe10.TypeDeclaration.name);n||t.accept(J(Pe.NODE_KEY_IS_A_SEQUENCE,{},e))}var r=e.name();if(null==r&&(r=e.lowLevel().key(),null==r&&(r="")),e.definition().key()==ye.Universe08.GlobalSchema&&e.lowLevel().valueKind()!=ce.Kind.SCALAR){var o=!1;if(e.lowLevel().valueKind()==ce.Kind.ANCHOR_REF||e.lowLevel().valueKind()==ce.Kind.INCLUDE_REF){var s=e.lowLevel().value();"string"==typeof s&&(o=!0)}o||t.accept(J(Pe.SCHEMA_NAME_MUST_BE_STRING,{name:r},e))}e.parent()||((new ze).validate(e,t),(e.definition().key()==ye.Universe08.Api||e.definition().key()==ye.Universe10.Api)&&(new Se).validateApi(e.wrapperNode(),t),(new Qe).validate(e,t),a(e,t)),(new at).validate(e,t);var u=e.definition();if(u.key()==ye.Universe08.BodyLike&&e.lowLevel().children().map(function(e){return e.key()}).some(function(e){return"formParameters"===e}))if(e.parent()&&e.parent().definition().key()==ye.Universe08.Response){var l=J(Pe.FORM_PARAMS_IN_RESPONSE,{},e);t.accept(l)}else if(e.lowLevel().children().map(function(e){return e.key()}).some(function(e){return"schema"===e||"example"===e})){var l=J(Pe.FORM_PARAMS_WITH_EXAMPLE,{},e);t.accept(l)}if(u.key()==ye.Universe10.OAuth2SecuritySchemeSettings){var p=!1;if(e.attributes("authorizationGrants").forEach(function(e){var n=e.value();if("authorization_code"===n||"implicit"===n)p=!0;else if("password"!==n&&"client_credentials"!==n&&n&&"string"==typeof n&&-1==n.indexOf("://")&&-1==n.indexOf(":")){var r=J(Pe.AUTHORIZATION_GRANTS_ENUM,{},e);t.accept(r)}}),p&&!e.attr("authorizationUri")){var l=J(Pe.AUTHORIZATION_URI_REQUIRED,{},e);t.accept(l)}}if(e.definition().isAssignableFrom(ye.Universe08.Parameter.name)||e.definition().isAssignableFrom(ye.Universe10.TypeDeclaration.name)){var c=e.attributes("enum").map(function(e){return e.value()});if(c.length!=pe.uniq(c).length){var l=J(Pe.REPEATING_COMPONENTS_IN_ENUM,{},e);t.accept(l)}if(e.definition().isAssignableFrom(ye.Universe08.NumberTypeDeclaration.name)||e.definition().isAssignableFrom(ye.Universe10.NumberTypeDeclaration.name)){var f=e.definition().isAssignableFrom(ye.Universe08.IntegerTypeDeclaration.name)||e.definition().isAssignableFrom(ye.Universe10.IntegerTypeDeclaration.name);e.attributes("enum").forEach(function(e){var n=f?parseInt(e.value()):parseFloat(e.value()),r=f?!isNaN(n)&&-1===e.value().indexOf("."):!isNaN(n);if(!r){var i=J(f?Pe.INTEGER_EXPECTED:Pe.NUMBER_EXPECTED_2,{},e);t.accept(i)}})}}ve.isResourceTypeType(e.definition())&&null==e.value()&&"null"===e.lowLevel().value(!0)&&t.accept(J(Pe.RESOURCE_TYPE_NULL,{},e)),i(e,t);var m=e.value();if(("string"==typeof m||"number"==typeof m||"boolean"==typeof m)&&!e.definition().getAdapter(Ae.RAMLService).allowValue()&&e.parent()&&"~"!=m){var l=J(Pe.SCALAR_PROHIBITED_2,{name:r},e);t.accept(l)}(new Je).validate(e,t),(new ut).validate(e,t),(new it).validate(e,t)}},e}(),nt=function(){function e(){}return e.prototype.validate=function(e,t){var n=e.attrValue(ye.Universe10.TypeDeclaration.properties.name.name);"version"==n&&t.accept(J(Pe.VERSION_NOT_ALLOWED,{},e))},e}(),rt=function(){function e(e,t,n,r){void 0===r&&(r=!1),this.definitions=e,this.propertyName=t,this.assignableFrom=r,this.validator=n}return e.prototype.validate=function(e,t){var n=e.definition();if(null!=n){var r=!1;if(r=this.assignableFrom?this.definitions.some(function(e){return n.isAssignableFrom(e.name)}):this.definitions.some(function(e){return e===n})){if(null!=this.propertyName){if(null==e.property())return;if(e.property().nameId()!=this.propertyName)return}this.validator.validate(e,t)}}},e}(),it=function(){function e(){}return e.createRegistry=function(){var t=[];return e.registerValidator(t,[ye.Universe10.TypeDeclaration,ye.Universe08.Parameter],ye.Universe10.Api.properties.baseUriParameters.name,new nt,!0),t},e.registerValidator=function(e,t,n,r,i){void 0===i&&(i=!1);var a=new rt(t,n,r,i);e.push(a)},e.prototype.validate=function(t,n){e.entries.forEach(function(e){return e.validate(t,n)})},e.entries=e.createRegistry(),e}(),at=function(){function e(){}return e.prototype.allowsAnyChildren=function(e,t){var n=e.property(),r=e.definition();return(ve.isAnnotationTypeType(r)||ve.isTypeDeclarationTypeOrDescendant(r))&&ve.isAnnotationTypesProperty(n)?!0:e.parent()==t&&ve.isTypesProperty(n)&&ve.isTypeDeclarationTypeOrDescendant(r)?!0:ve.isSchemasProperty(n)&&ve.isTypeDeclarationTypeOrDescendant(r)?!0:e.parent()==t&&ve.isDocumentationProperty(n)&&ve.isDocumentationType(r)?!0:ve.isAnnotationsProperty(n)?!0:ve.isUsesProperty(n)?!0:ve.isExamplesProperty(n)?!0:!1},e.prototype.nodeAllowedDueToParent=function(e,t){for(var n=e;n!=t&&null!=n;){if(this.allowsAnyChildren(n,t))return!0;n=n.parent()}return!1},e.prototype.validate=function(e,t){var n=e.root();e.property(),e.definition();if(ve.isOverlayType(n.definition())){if(e==n)return void this.validateProperties(e,t);if(!this.nodeAllowedDueToParent(e,n)){var r=n.knownIds();if(r){var i=r.hasOwnProperty(e.id());return i?void this.validateProperties(e,t):void t.accept(J(Pe.INVALID_OVERLAY_NODE,{nodeId:e.id()},e))}}}},e.prototype.validateProperties=function(e,t){e.attrs().forEach(function(n){n.property().getAdapter(Ae.RAMLPropertyService).isKey()||n.parent()==e&&(n.isElement()||ve.isTitlePropertyName(n.name())||ve.isDescriptionPropertyName(n.name())||ve.isDisplayNamePropertyName(n.name())||ve.isUsagePropertyName(n.name())||ve.isExampleProperty(n.property())||ve.isMasterRefProperty(n.property())||ve.isAnnotationsProperty(n.property())||ve.isUsesProperty(n.property())||t.accept(J(Pe.INVALID_OVERRIDE_IN_OVERLAY,{propName:n.name()},n)))})},e}(),ot=function(){function e(){}return e.prototype.validate=function(e,t){var n=this,r=new at;r.validate(e,t),e.directChildren().forEach(function(e){e.isElement()&&n.validate(e.asElement(),t)})},e}(),st=function(){function e(){}return e.prototype.val=function(e,t,n){var r=this;if(e.kind()==ce.Kind.MAP||e.kind()==ce.Kind.MAPPING){var i={};e.children().forEach(function(e){var r=e.key();if(r){if(i.hasOwnProperty(r)){var a=J(Pe.KEYS_SHOULD_BE_UNIQUE,{},n,!1);e.unit()==n.lowLevel().unit()&&(a.start=e.keyStart(),a.end=e.keyEnd()),t.accept(a)}i[r]=1}})}e.children().forEach(function(e){r.val(e,t,n)})},e.prototype.validate=function(e,t){this.val(e.lowLevel(),t,e)},e}(),ut=function(){function e(){}return e.prototype.validate=function(e,t){this.validateChildElements(e,t);var n=e.lowLevel().children(),r=pe.groupBy(n.filter(function(e){return null!=e.key()}),function(e){return e.key()});this.validateChildAttributes(e,r,t),this.validateUnrecognizedLowLevelChildren(e,r,t)},e.prototype.validateChildElements=function(e,t){var n={},r=e.directChildren().filter(function(e){return e.isElement()});r.forEach(function(e){var t=e;if(!t._computed&&t.name()){var r=t.name()+t.property().nameId();n.hasOwnProperty(r)?t.isNamePatch()||n[r].push(t):n[r]=[t]}}),Object.keys(n).forEach(function(e){var r=n[e];!r||r.length<2||r.forEach(function(e){var n=D(e),r={name:e.name()},i=Pe.ALREADY_EXISTS_IN_CONTEXT;n&&(r.capitalized=Ce.upperCaseFirst(n),i=Pe.ALREADY_EXISTS);var a=J(i,r,e);t.accept(a)})})},e.prototype.validateChildAttributes=function(e,t,n){var r=this.getHighLevelAttributes(e),i=pe.groupBy(r,function(e){return e.name()}),a=this.allowsAnyAndHasRequireds(e);Object.keys(i).forEach(function(r){if(!(i[r].length<2)){var o=i[r][0].isUnknown(),s=!o&&i[r][0].property().isMultiValue();s&&(e.definition().isAssignableFrom(ye.Universe08.SecuritySchemeSettings.name)||e.definition().isAssignableFrom(ye.Universe10.SecuritySchemeSettings.name))&&(s=t[r]&&1===t[r].length),(o&&a||!s||s&&null!=t[r]&&t[r].length>1)&&i[r].forEach(function(e){var t={propName:e.property()?e.property().nameId():e.name()},r=Pe.PROPERTY_USED,i=D(e.parent());i&&(t.parent=Ce.upperCaseFirst(i),r=Pe.PARENT_PROPERTY_USED);var a=J(r,t,e);n.accept(a)})}})},e.prototype.validateUnrecognizedLowLevelChildren=function(e,t,n){var r=e.directChildren(),i=pe.groupBy(r,function(e){return e.name()});Object.keys(t).forEach(function(r){if(r&&t[r].length>1&&!i[r]){if(e.definition().isAssignableFrom(ye.Universe10.ObjectTypeDeclaration.name))return;var a={propName:r},o=Pe.PROPERTY_USED,s=D(e);s&&(a.parent=Ce.upperCaseFirst(s),o=Pe.PARENT_PROPERTY_USED),t[r].forEach(function(t){var r=Z(o,a,t,e);r.start=t.keyStart(),r.end=t.keyEnd(),n.accept(r)})}})},e.prototype.filterMultiValueAnnotations=function(e,t,n){this.getHighLevelAttributes(e);Object.keys(t).forEach(function(e){"("!==e.charAt(0)||t[e].length<2})},e.prototype.getHighLevelAttributes=function(e){var t=this.allowsAnyAndHasRequireds(e);return e.directChildren().filter(function(e){return e.isAttr()||t});
},e.prototype.allowsAnyAndHasRequireds=function(e){var t=e.definition().requiredProperties(),n=t&&t.length>0,r=e.definition().getAdapter(Ae.RAMLService),i=r&&r.getAllowAny(),a=i&&n;return a},e}(),lt=function(){function e(){}return e.prototype.validate=function(e,t){var n=this.isStrict(e);if(n||De.validateNotStrictExamples){var r=this.parseObject(e,t,n);if(r){var i=this.aquireSchema(e);i&&i.validate(r,t,n)}}},e.prototype.isExampleNode=function(e){return this.isSingleExampleNode(e)||this.isExampleNodeInMultipleDecl(e)},e.prototype.isSingleExampleNode=function(e){return e.name()==ye.Universe10.TypeDeclaration.properties.example.name},e.prototype.isExampleNodeInMultipleDecl=function(e){var t=e.parent();return t?ve.isExampleSpecType(t.definition()):!1},e.prototype.findParentSchemaOrTypeAttribute=function(e){var t=e.parent().attr(ye.Universe10.TypeDeclaration.properties.schema.name);return t?t:(t=e.parent().attr(ye.Universe10.TypeDeclaration.properties.type.name))?t:e.parent()?(t=e.parent().parent().attr(ye.Universe10.TypeDeclaration.properties.schema.name))?t:(t=e.parent().parent().attr(ye.Universe10.TypeDeclaration.properties.type.name),t?t:null):null},e.prototype.aquireSchema=function(e){var t=e.parent().definition().isAssignableFrom(ye.Universe10.TypeDeclaration.name);if(this.isExampleNode(e)){var n=e;if(this.isExampleNodeInMultipleDecl(e)&&(n=e.parent()),n.parent()&&(n.parent().definition().isAssignableFrom(ye.Universe10.TypeDeclaration.name)&&null===n.parent().parent()?t=!1:n.parent().property().nameId()==ye.Universe10.LibraryBase.properties.types.name&&(t=!1),n.parent().parent())){var r=n.parent().parent().definition().key();(r==ye.Universe08.Method||r==ye.Universe10.Method)&&(n.parent().property().nameId()==ye.Universe10.MethodBase.properties.queryParameters.name||(t=!0)),(r==ye.Universe08.Response||r==ye.Universe10.Response)&&(t=!0)}}if(e.parent().definition().key()==ye.Universe08.BodyLike||t){var i=this.findParentSchemaOrTypeAttribute(e);if(i){var a=i.value();if(me.StructuredValue.isInstance(a))return null;var o=(""+a).trim(),s=null;if("{"==o.charAt(0))try{s=we.getJSONSchema(o,Y(i.lowLevel()))}catch(u){return null}if("<"==o.charAt(0))try{s=we.getXMLSchema(o)}catch(u){return null}if(s)return{validate:function(t,n,r){try{if(t.__$validated)return;if(s instanceof Error)return void n.accept(J(Pe.INVALID_VALUE_SCHEMA,{iValue:s.message},e,!r));s.validateObject(t)}catch(a){var o="Cannot assign to read only property '__$validated' of ";if(a.message&&0==a.message.indexOf(o)){var u=a.message.substr(o.length,a.message.length-o.length);return void n.accept(J(Pe.INVALID_JSON_SCHEMA,{propName:u},i,!r))}if("Object.keys called on non-object"==a.message)return;return void n.accept(J(Pe.EXAMPLE_SCHEMA_FAILURE,{msg:a.message},e,!r))}}};if(o.length>0){var l=e.parent(),p=l&&l.parent(),c=l&&l.definition()&&l.definition().isAssignableFrom(ye.Universe10.ObjectTypeDeclaration.name)&&l;if(c=c||p&&p.definition()&&p.definition().isAssignableFrom(ye.Universe10.ObjectTypeDeclaration.name)&&p)return this.typeValidator(c,e)}}}return this.getSchemaFromModel(e)},e.prototype.getSchemaFromModel=function(e){var t=e.parent();return this.typeValidator(t,e)},e.prototype.typeValidator=function(e,t){var n={validate:function(n,r,i){var a=e.parsedType();if(a&&!a.isUnknown()){"number"==typeof n&&a.isString()&&(n=""+n),"boolean"==typeof n&&a.isString()&&(n=""+n),a.getExtra("repeat")&&(n=[n]);var o=a.validate(n,!1);o.isOk()||o.getErrors().forEach(function(e){return r.accept(Q(e.getCode(),e.getMessage(),t,!i))})}}};return n},e.prototype.toObject=function(e,t,n){var r=t.lowLevel().dumpToObject(!0);return this.testDublication(e,t.lowLevel(),n),r.example?r.example:r.content?r.content:void 0},e.prototype.testDublication=function(e,t,n){var r=this,i={};t.children().forEach(function(t){t.key()&&(i[t.key()]&&n.accept(J(Pe.KEYS_SHOULD_BE_UNIQUE,{},new me.BasicASTNode(t,e.parent()))),i[t.key()]=t),r.testDublication(e,t,n)})},e.prototype.parseObject=function(e,t,n){var r=null,i=e.value(),a=G(e);if(me.StructuredValue.isInstance(i))r=this.toObject(e,i,t);else if(a){if(H(a))try{r=JSON.parse(i)}catch(o){return void t.accept(J(Pe.CAN_NOT_PARSE_JSON,{msg:o.message},e,!n))}if($(a))try{r=Ie.parseXML(i)}catch(o){return void t.accept(J(Pe.CAN_NOT_PARSE_XML,{msg:o.message},e,!n))}}else try{if(!(i&&i.length>0)||"["!=i.trim().charAt(0)&&"{"!=i.trim().charAt(0)&&"<"!=i.trim().charAt(0)){if("true"==i)return!0;if("false"==i)return!1;var s=parseFloat(i);return isNaN(s)?i:s}r=JSON.parse(i)}catch(o){if(0!=i.trim().indexOf("<"))return i;try{r=Ie.parseXML(i)}catch(o){return void t.accept(J(Pe.CAN_NOT_PARSE_XML,{msg:o.message},e,!n))}}return r},e.prototype.isStrict=function(e){if(ve.isDefaultValue(e.property()))return!0;if(ve.isExampleProperty(e.property())&&"RAML08"==e.parent().definition().universe().version())return!1;var t=!1,n=e.parent().attr("strict");return n&&"true"==n.value()&&(t=!0),t},e}();t.ExampleAndDefaultValueValidator=lt;var pt=function(e,t,n){var r=Ce.sentence(e);return t||(r=Ce.ucFirst(r)),n&&(r=Le.plural(r)),r},ct=function(){function e(){}return e.prototype.validate=function(e,t){if(e.isAttr()){if(!e.optional())return;var n=e,r=n.property();if(r.isMultiValue()||r.range().isArray())return;if(!r.isFromParentKey()){var i=c(n.parent());if(i&&r.isValueProperty()){var a=pt(i,!0,!0),o=J(Pe.OPTIONAL_SCLARAR_PROPERTIES_10,{templateNamePlural:a,propName:n.name()},n,!1);t.accept(o)}}}else if(e.isElement()){var s=e,r=s.property(),u=s.allowsQuestion();if(!u){var l=r?pt(r.nameId(),!0,!0):"API root";s.optionalProperties().forEach(function(n){s.children().forEach(function(n){var r={propName:l,oPropName:n.lowLevel().key()},i=J(Pe.OPTIONAL_PROPERTIES_10,r,e,!1);t.accept(i)})})}var p=e.asElement().definition();if(e.optional()&&"RAML10"==p.universe().version()){var r=e.property(),f=ve.isQueryParametersProperty(r)||ve.isUriParametersProperty(r)||ve.isHeadersProperty(r);if(!(ve.isMethodType(p)||ve.isTypeDeclarationType(p)&&f)){var o=J(Pe.ONLY_METHODS_CAN_BE_OPTIONAL,{},e,!1);t.accept(o)}}}},e}(),ft=function(){function e(){}return e.prototype.validate=function(e,t){var n=e.definition(),r=ye.Universe10.Api.properties.baseUri.name,i=ye.Universe10.Api.properties.baseUriParameters.name,a=ye.Universe10.Resource.properties.relativeUri.name,o=ye.Universe10.ResourceBase.properties.uriParameters.name;if(ve.isApiSibling(n))this.inspectParameters(e,t,r,i);else if(ve.isResourceType(n)){var s=e.root();this.inspectParameters(e,t,r,i,s),this.inspectParameters(e,t,a,o)}else if(ve.isResourceTypeType(n)){var s=e.root();this.inspectParameters(e,t,r,i,s)}},e.prototype.inspectParameters=function(e,t,n,r,i){i=i||e;var a="",o=i.attr(n);o&&(a=o.value(),a&&"string"==typeof a||(a=""));var s=e.elementsOfKind(r);s.forEach(function(n){var i=n.attr(ye.Universe10.TypeDeclaration.properties.name.name);if(i){var o=i.value();if(null!=o&&a.indexOf("{"+o+"}")<0){if(ve.isResourceTypeType(e.definition())&&o.indexOf("<<")>=0)return;var s=Ce.upperCaseFirst(Le.singular(Ce.sentence(r))),u=J(Pe.PROPERTY_UNUSED,{propName:s},n,!0);t.accept(u)}}})},e}(),mt=function(){function e(){this.nameProperty=ye.Universe10.ResourceType.properties.name.name}return e.prototype.validate=function(e,t){var n=e.definition();if(ve.isLibraryBaseSibling(n)||ve.isApiType(n)){var r=(ye.Universe10.LibraryBase.properties.resourceTypes.name,ye.Universe10.ResourceBase.properties.type.name),i=(ye.Universe10.LibraryBase.properties.traits.name,ye.Universe10.MethodBase.properties.is.name),a=Ee.globalDeclarations(e).filter(function(e){return ve.isResourceTypeType(e.definition())}),o=Ee.globalDeclarations(e).filter(function(e){return ve.isTraitType(e.definition())});this.checkCycles(a,r,t),this.checkCycles(o,i,t)}},e.prototype.checkCycles=function(e,t,n){var r=this,i={};e.forEach(function(e){var t=r.templateName(e);i[t]=e});var a={};e.forEach(function(e){var o=r.templateName(e);a[o]||r.findCyclesInDefinition(e,t,i).forEach(function(t){t.forEach(function(e){return a[e]=!0}),t=t.reverse();var r=pt(e.definition().nameId()),i=t.join(" -> "),o={typeName:r,cycle:i},s=J(Pe.CYCLE_IN_DEFINITION,o,e,!1);n.accept(s)})})},e.prototype.templateName=function(e){var t=e.attr(this.nameProperty);return t?t.value():null},e.prototype.findCyclesInDefinition=function(e,t,n,r){void 0===r&&(r={});var i=this.templateName(e);if(r[i])return[[i]];var a={};Object.keys(r).forEach(function(e){return a[e]=r[e]}),a[i]=!0;for(var o=[],s=e.attributes(t),u=0;u<s.length;u++){var l=s[u],p=l.value();if(p){var c="string"==typeof p?p:p.valueName(),f=n[c];if(null!=f){var m=this.findCyclesInDefinition(f,t,n,a);m.forEach(function(e){return o.push(e)})}}}return o.forEach(function(e){return e.push(i)}),o},e}();t.isJson=H,t.isXML=$,t.getMediaType=G;var dt=function(e,t,n,r,i,a,o){var s=o?o:e.lowLevel(),u=s.unit()&&s.unit().contents(),l=u&&u.length,p=s.start(),c=s.end();if(l&&c>l&&(c=l-1),s.key()&&s.keyStart()){var f=s.keyStart();f>0&&(p=f);var m=s.keyEnd();m>0&&(c=m)}if(p>c&&(c=p+1,e.isElement())){var d=e.definition();ve.isApiType(d)&&(p=0==l?0:l-1,c=p)}if(a&&!a.getAdapter(Ae.RAMLPropertyService).isMerged()&&null==e.parent()){var h=pe.find(s.children(),function(e){return e.key()==a.nameId()});if(h){var f=h.keyStart(),m=h.keyEnd();f>0&&m>f&&(p=f,c=m)}}return{code:t,isWarning:n,message:r,node:e,start:p,end:c,path:i?s.unit()?s.unit().path():"":null,extras:[],unit:e?s.unit():null}},ht=function(e,t,n,r,i,a){var o=e.unit()&&e.unit().contents(),s=o&&o.length,u=e.start(),l=e.end();if(s&&l>=s&&(l=s-1),e.key()&&e.keyStart()){var p=e.keyStart();p>0&&(u=p);var c=e.keyEnd();c>0&&(l=c)}return{code:n,isWarning:r,message:i,node:t,start:u,end:l,path:a?e.unit()?e.unit().path():"":null,extras:[],unit:e?e.unit():null}};t.toIssue=z,t.createIssue1=J,t.createIssue=Q,t.createLLIssue=ee,t.validateResponseString=te}).call(t,n(61))},function(e,t,n){"use strict";function r(e,t){if(void 0===t&&(t=0),t>20)return[];try{var n=[],i=e.leftType();i&&n.push(i);var a=e.rightType();if(a)if(a.hasUnionInHierarchy()){var o=r(a.unionInHierarchy(),t+1);n=n.concat(o)}else n.push(a);return n}finally{}}function i(e){var t=e.definition();if(!t||!N.isTypeDeclarationDescendant(t))return!1;var n=e.lowLevel();if(n.valueKind()!==v.Kind.SEQ)return!1;var r=n.children();if(null==r)return!1;for(var i=0,a=r;i<a.length;i++){var o=a[i];if(o.kind()!==v.Kind.SCALAR)return!1}return!0}function a(e,t){if(!t)return e.definition().universe().type(b.Universe10.StringTypeDeclaration.name);var n=e.parsedType();return n.isString()?e.definition().universe().type(b.Universe10.StringTypeDeclaration.name):n.isNumber()?n.isInteger()?e.definition().universe().type(b.Universe10.IntegerTypeDeclaration.name):e.definition().universe().type(b.Universe10.NumberTypeDeclaration.name):n.isBoolean()?e.definition().universe().type(b.Universe10.BooleanTypeDeclaration.name):n.isObject()?e.definition().universe().type(b.Universe10.ObjectTypeDeclaration.name):n.isArray()?e.definition().universe().type(b.Universe10.ArrayTypeDeclaration.name):n.isFile()?e.definition().universe().type(b.Universe10.FileTypeDeclaration.name):n.isDateTime()?e.definition().universe().type(b.Universe10.DateTimeTypeDeclaration.name):n.isDateTimeOnly()?e.definition().universe().type(b.Universe10.DateTimeOnlyTypeDeclaration.name):n.isDateOnly()?e.definition().universe().type(b.Universe10.DateOnlyTypeDeclaration.name):n.isTimeOnly()?e.definition().universe().type(b.Universe10.TimeOnlyTypeDeclaration.name):n.isUnion()?e.definition().universe().type(b.Universe10.UnionTypeDeclaration.name):e.definition().universe().type(b.Universe10.TypeDeclaration.name)}function o(e){return function(t){var n=e.type(t);if(!n){new h.UserDefinedClass("",e,null,"","")}return n}}function s(e,t){var n=e.asElement();if(null==n)return null;var r=n.elementsOfKind(b.Universe10.TypeDeclaration.properties.facets.name);return null==r||0==r.length?null:g.find(r,function(e){return t==e.attrValue(b.Universe10.TypeDeclaration.properties.name.name)})}function u(e){var t=e.owner();if(null==t)return null;var n=e.facetName();if(!n)return null;var r=t.getExtra(M.SOURCE_EXTRA);return null==r?null:A.isSourceProvider(r)||y.isParseResult(r)?{getSource:function(){if(A.isSourceProvider(r)){var e=r.getSource();if(e&&y.isParseResult(e))return s(e,n)}else if(y.isParseResult(r))return s(r,n);return null},getClassIdentifier:function(){return[h.SourceProvider.CLASS_IDENTIFIER]}}:null}function l(e,t,n){if(null==e)return null;var r=new h.NodeClass(t.name(),t.definition().universe(),"",""),i=t.parsedType();return i.allFacets().forEach(function(e){if(e.kind()==h.tsInterfaces.MetaInformationKind.FacetDeclaration){var i=u(e),a=null;null!=i?(a=new h.UserDefinedProp(e.facetName(),null),a.setSourceProvider(i)):a=new h.Property(e.facetName(),"");var s=null;s=n?n.definition().universe():t.definition().universe(),a.withRange(s.type("StringType")),a.withDomain(r),a.withGroupName(e.facetName()),a.withRequired(!1),e.value(),M.setPropertyConstructor(function(e){var t=new h.Property(e,"");return t.unmerge(),t}),a.withRange(M.toNominal(e.value(),o(t.definition().universe())))}}),r._superTypes.push(e),r}function p(e,t,n){var r=n.attr("type");if(r){var i=a(n,r.value()),o=l(i,n,t);return o&&0==o.superTypes().length&&o._superTypes.push(n.definition().universe().type(b.Universe10.TypeDeclaration.name)),o}var s=b.Universe10.ObjectTypeDeclaration.properties.properties.name;if(e){if("body"==e.nameId()||g.find(n.lowLevel().children(),function(e){return e.key()===s}))return n.definition().universe().type(b.Universe10.ObjectTypeDeclaration.name)}else if(!t&&n.lowLevel()&&g.find(n.lowLevel().children(),function(e){return e.key()===s}))return n.definition().universe().type(b.Universe10.ObjectTypeDeclaration.name);return n.definition().universe().type(b.Universe10.StringTypeDeclaration.name)}function c(e){try{var t=e.definition().nameId(),n=t===b.Universe10.Api.name||t===b.Universe08.Api.name;if(!n&&!e.property()&&!e.parent()&&e.definition().nameId()===S.getFragmentDefenitionName(e)){if(e.property()&&e.property().nameId()===b.Universe10.LibraryBase.properties.annotationTypes.name)return f(null,null,e);var r=null,i=e.definition().allSubTypes();return i.forEach(function(t){!r&&d(t,e,null)&&(r=t)}),r}}catch(a){}return f(e.property(),e.parent(),e)}function f(e,t,n){var r=n.lowLevel();e&&e.nameId()==b.Universe10.FragmentDeclaration.properties.uses.name&&e.range().nameId()==b.Universe10.Library.name;var i=e?e.range().nameId():n.definition().nameId();if(r._node&&r._node.descriminate)return null;r._node&&(r._node.descriminate=1);try{if(i==b.Universe10.TypeDeclaration.name){var a=p(e,t,n);if(e||!e&&!t&&n.lowLevel()){if(e&&null!=a&&(e.nameId()==b.Universe10.MethodBase.properties.body.name||e.nameId()==b.Universe10.ArrayTypeDeclaration.properties.items.name||e.nameId()==b.Universe10.Response.properties.headers.name||e.nameId()==b.Universe10.MethodBase.properties.queryParameters.name)){var o=new h.UserDefinedClass(n.lowLevel().key(),a.universe(),n,n.lowLevel().unit()?n.lowLevel().unit().path():"","");return o._superTypes.push(a),o}if(null!=a&&N.isAnnotationTypeType(n.definition())){var s=m(a),o=new h.UserDefinedClass(n.lowLevel().key(),a.universe(),n,n.lowLevel().unit()?n.lowLevel().unit().path():"","");return o._superTypes.push(s),o._superTypes.push(a),o}}if(a)return a}var u=null;if(e&&t){var l=E.findAllSubTypes(e,t);return l.length>0&&l.forEach(function(e){u||d(e,n,u)&&(u=e)}),u}}finally{r._node&&delete r._node.descriminate}}function m(e){for(var t,n=[e].concat(e.allSuperTypes()),r=0;r<n.length;r++){var i=n[r];if(!i.isUserDefined()){if(i.isUnion()){var a=i,o=a.leftType(),s=(a.leftType(),m(o)),u=m(o);if(s.isAssignableFrom(u.nameId())&&(null==t||s.isAssignableFrom(t.nameId()))){t=s;continue}if(u.isAssignableFrom(s.nameId())&&(null==t||u.isAssignableFrom(t.nameId()))){t=u;continue}t=e.universe().type(b.Universe10.UnionTypeDeclaration.name);break}if(i.isArray()){t=e.universe().type(b.Universe10.ArrayTypeDeclaration.name);break}for(var l=i.subTypes(),p=0;p<l.length;p++){var c=l[p];c.isAssignableFrom(b.Universe10.TypeDeclaration.name)&&(null==t?t=c:c.isAssignableFrom(t.nameId())&&(t=c))}}}return null!=t?t:e.universe().type(b.Universe10.TypeDeclaration.name)}function d(e,t,n){if(t.isAttr()||t.isUnknown())return!1;var r=t,i=g.find(e.superTypes(),function(t){var n=g.find(t.allProperties(),function(e){return e.isDescriminator()});if(n){var i=r.attr(n.nameId());if(i&&i.value()==e.nameId())return!0}return!1});if(i)return!0;if(0==e.valueRequirements().length)return!1;var a=!0;return e.valueRequirements().forEach(function(t){var i=r.attr(t.name);if(i)if(i.value()==t.value);else if(e.getAdapter(_.RAMLService).getConsumesRefs()){var o=i.value(),s=[];e.superTypes().forEach(function(e){return e.allSubTypes().forEach(function(e){s.push(e)})});var u=[];g.unique(s).forEach(function(e){u.push(e.nameId()),e.valueRequirements().forEach(function(e){u.push(e.value)}),e.getAdapter(_.RAMLService).getAliases().forEach(function(e){return u.push(e)})}),g.find(u,function(e){return e==o})&&(a=!1)}else a=!1;else{var l=e.getAdapter(_.RAMLService).getDefining(),p=!1;if(l.forEach(function(e){r.lowLevel().children().forEach(function(t){t.key()==e&&(p=!0)})}),p)return void(a=!0);if(n)a=!1;else{var c=e.property(t.name);c&&c.defaultValue()==t.value||(a=!1)}}}),a}var h=n(37),y=n(9),v=n(75),g=n(64),A=h,S=n(16),T=n(41),E=n(13),b=n(17),N=n(14),_=h,M=h.rt,w=n(81),R=n(67),I=function(){function e(e){this._props=e,this.parentValue=g.find(e,function(e){return e.isFromParentValue()}),this.parentKey=g.find(e,function(e){return e.isFromParentKey()}),this.canBeValue=g.find(e,function(e){return e.canBeValue()})}return e.prototype.add=function(e){this._props.push(e)},e.prototype.match=function(e){var t=this,n=null,r="";return this._props.forEach(function(i){i.getAdapter(_.RAMLPropertyService).isSystem()||i!=t.parentValue&&i!=t.parentKey&&i.matchKey(e)&&(null!=i.keyPrefix()?i.keyPrefix().length>=r.length&&(r=i.keyPrefix(),n=i):(n=i,r=i.nameId()))}),n},e}(),C=0,L=function(){function e(){this.shouldDescriminate=!1}return e.prototype.process=function(e,t){var n=this,a=e.lowLevel(),o=e;o._mergedChildren=null;var s=a._node?a._node:a;try{if(s.currentChildren)return s.currentChildren;if(!e.definition())return;if(null==e.parent()&&!this.shouldDescriminate){this.shouldDescriminate=!0;try{var u=this.process(e,t),l=e;l._children=u;var p=c(e);p&&l.patchType(p);var u=this.process(e,t);l._children=u}finally{this.shouldDescriminate=!1}}if(e.definition().hasUnionInHierarchy()&&e.parent()&&e.property().nameId()==b.Universe10.LibraryBase.properties.annotations.name){var f=r(e.definition().unionInHierarchy()),m=null,d=null,h=null,y=1e3,g=e;if(f.forEach(function(r){if(!m&&!r.hasUnionInHierarchy()){g.patchType(r);if(0==C){C++;try{for(var i=n.process(e,t),a=0,o=0;o<i.length;o++)i[o].isUnknown()&&a++;0==a&&(m=i),y>a&&(y=a,d=i,h=r)}finally{C--}}}}),m)return g.patchType(h),m;d&&g.patchType(h)}var A=new I(e.definition().allProperties());if(null==e.parent()||e.lowLevel().includePath()){var T=e.definition().universe();"RAML10"==T.version()&&(e.definition().property("uses")||T.type("FragmentDeclaration").allProperties().forEach(function(e){return A.add(e)}))}var E=e,M=E._allowQuestion||e.definition().getAdapter(_.RAMLService).getAllowQuestion(),R=[];if(A.parentKey){if(e.lowLevel().key()){var L=new S.ASTPropImpl(e.lowLevel(),e,A.parentKey.range(),A.parentKey,!0);R.push(L);var O=e.property()&&N.isBodyProperty(e.property())&&e.lowLevel().key()==e.property().nameId();if(O){var D=P(E);!D&&E._computedKey&&L.overrideValue(E._computedKey)}}if(e.lowLevel().valueKind()===v.Kind.SEQ&&!i(e)){var x=new S.BasicASTNode(e.lowLevel(),E);return x.errorMessage={entry:w.DEFINITION_SHOULD_BE_A_MAP,parameters:{typeName:e.definition().nameId()}},R.push(x),R}}if(null!=e.lowLevel().value(!0))if(A.parentValue)R.push(new S.ASTPropImpl(e.lowLevel(),e,A.parentValue.range(),A.parentValue));else if(A.canBeValue){var U=e.lowLevel().value();null==U&&(U=e.lowLevel().value(!0)),"string"==typeof U&&U.trim().length>0&&R.push(new S.ASTPropImpl(e.lowLevel(),e,A.canBeValue.range(),A.canBeValue))}if(E._children=R,E.definition().getAdapter(_.RAMLService).isUserDefined())R=this.processChildren(t,E,R,M,A);else if(E.definition().key()==b.Universe08.Api||E.definition().key()==b.Universe10.Api){var k=t.filter(function(e){return"uses"==e.key()});R=this.processChildren(k,E,R,M,A);var F=t.filter(function(e){return"types"==e.key()});R=this.processChildren(F,E,R,M,A);var B=t.filter(function(e){return"types"!=e.key()&&"uses"!=e.key()});R=this.processChildren(B,E,R,M,A)}else R=this.processChildren(t,E,R,M,A);return E._children=R,R}finally{}},e.prototype.isTypeDeclarationShortcut=function(e,t){var n=N.isTypeProperty(t),r=e.definition()&&N.isTypeDeclarationTypeOrDescendant(e.definition());return r&&n&&e.lowLevel()&&e.lowLevel().valueKind()===v.Kind.SEQ?!0:!1},e.prototype.processChildren=function(e,t,n,r,i){var a=this,o=b.Universe10.TypeDeclaration.name,s=b.Universe10.TypeDeclaration.properties.type.name,u=b.Universe10.ArrayTypeDeclaration.properties.items.name;return t.definition()&&t.definition().isAssignableFrom(o)&&t.lowLevel()&&i.canBeValue&&(i.canBeValue.nameId()===s||i.canBeValue.nameId()===u)&&t.lowLevel()._node&&t.lowLevel()._node.value&&t.lowLevel()._node.value.kind===v.Kind.SEQ?(e.forEach(function(e){var r=new S.ASTPropImpl(e,t,i.canBeValue.range(),i.canBeValue);n.push(r)}),n):(e.forEach(function(e){if(i.canBeValue&&a.isTypeDeclarationShortcut(t,i.canBeValue))return void n.push(new S.ASTPropImpl(e,t,i.canBeValue.range(),i.canBeValue));var o=e.key(),s=null!=o?i.match(o):null;if(null!=s){var u=s.range();if(s.isAnnotation()&&"annotations"!=o){var l=new S.ASTPropImpl(e,t,u,s);return void n.push(l)}var p=!1,c=s.isMultiValue();if(u.isArray()?(c=!0,u=u.array().componentType(),p=!0):u.hasArrayInHierarchy()&&(c=!0,p=!0),u.hasValueTypeInHierarchy()){var m=e.children(),d=e.valueKind()==v.Kind.SEQ;if((d&&m.length>0||m.length>1)&&c)if(m.length>1&&N.isTypeDeclarationSibling(t.definition())&&(N.isTypeProperty(s)||N.isItemsProperty(s))&&e.valueKind()!=v.Kind.SEQ){var l=new S.ASTPropImpl(e,t,u,s);n.push(l),t.setComputed(s.nameId(),l)}else{var y=[];m.forEach(function(e){var r=new S.ASTPropImpl(e,t,u,s);n.push(r),y.push(e.value())}),s.isInherited()&&t.setComputed(s.nameId(),y)}else{s.isInherited()&&t.setComputed(s.nameId(),e.value());var A=new S.ASTPropImpl(e,t,u,s);if(d||e.valueKind()==v.Kind.MAP){var E=s.range().nameId();s.getAdapter(_.RAMLPropertyService).isExampleProperty()||("StringType"==E&&(E="string"),"NumberType"==E&&(E="number"),"BooleanType"==E&&(E="boolean"),("string"==E||"number"==E||"boolean"==E)&&(e.isAnnotatedScalar()||(A.errorMessage={entry:w.INVALID_PROPERTY_RANGE,parameters:{propName:s.groupName(),range:E}},0==e.children().length&&"enum"==s.groupName()&&(A.errorMessage={entry:w.ENUM_IS_EMPTY,parameters:{}},e.valueKind()==v.Kind.MAP&&(A.errorMessage={entry:w.ENUM_MUST_BE_AN_ARRAY,parameters:{}})))))}n.push(A)}return}var M=[];if(t._children=n,null!=e.value()&&("string"==typeof e.value()||"boolean"==typeof e.value()||"number"==typeof e.value())&&(""+e.value()).trim().length>0){var I=s.range();if(!I.allProperties().some(function(e){var t=e;return t?t.canBeValue()&&t.isFromParentValue():!1})){var C=new S.BasicASTNode(e,t);C.getLowLevelEnd=function(){return-1},C.getLowLevelStart=function(){return-1},C.knownProperty=s,n.push(C)}}if(s.isMerged()){var L=new S.ASTNodeImpl(e,t,u,s);L._allowQuestion=r,M.push(L)}else if(c)if(s.getAdapter(_.RAMLPropertyService).isEmbedMap()){var O=e.children(),D=[],x=!1;if(O.forEach(function(e){e.kind()==v.Kind.INCLUDE_REF&&"RAML08"==t.universe().version()?e.children().forEach(function(e){var n=new S.ASTNodeImpl(e,t,u,s);n._allowQuestion=r,M.push(n),x=!0}):D.push(e)}),O=D,0==O.length){if(s.range().key()==b.Universe08.ResourceType&&!x){var U=new S.BasicASTNode(e,t);U.errorMessage={entry:w.PROPERTY_MUST_BE_A_MAP,parameters:{propName:s.nameId()}},n.push(U)}if(e.valueKind()==v.Kind.SCALAR&&s.range().key()==b.Universe08.AbstractSecurityScheme){var U=new S.BasicASTNode(e.parent(),t);U.errorMessage={entry:w.PROPERTY_MUST_BE_A_MAP,parameters:{propName:s.nameId()}},n.push(U)}}if(O.forEach(function(e){var i=e.children();if(e.key()||1!=i.length)if("RAML10"==t.universe().version()){var a=new S.ASTNodeImpl(e,t,u,s);a._allowQuestion=r,M.push(a)}else{var o=new S.BasicASTNode(e,t);n.push(o),e.key()&&(o.needSequence=!0)}else if("RAML10"!=t.universe().version()||t.parent()){var a=new S.ASTNodeImpl(i[0],t,u,s);a._allowQuestion=r,M.push(a)}}),"RAML10"==t.universe().version()&&e.valueKind()==v.Kind.SEQ){var C=new S.BasicASTNode(e,t);n.push(C),C.needMap=!0,C.knownProperty=s}}else{var k={},F=[];if(h.NodeClass.isInstance(u)){var B=u;B.getAdapter(_.RAMLService).getCanInherit().length>0&&B.getAdapter(_.RAMLService).getCanInherit().forEach(function(n){for(var i=t.computedValue(n),a=Array.isArray(i)?i:[i],o=0;o<a.length;o++){var l=a[o];if(l&&s.nameId()==b.Universe10.Response.properties.body.name){for(var p=g.find(e.children(),function(e){return e.key()==l}),c=e;c.originalNode;)c=c.originalNode();var m=g.find(c.children(),function(e){try{return R.parse(e.key()),!0}catch(t){return!1}});if(!m){var d=t.parent().definition().key(),h=new S.ASTNodeImpl(e,t,u,s);h._computedKey=l,(d==b.Universe10.MethodBase||d==b.Universe08.MethodBase)&&h.setComputed("form","true");var y=P(t),v=f(s,t,h);v&&(y||v.setName(l),h.patchType(v));var A=h.children();h._children=A.filter(function(e){return!e.isUnknown()}),h._allowQuestion=r,p||F.push(h),h.children().forEach(function(e){if(e.property().getAdapter(_.RAMLPropertyService).isKey()){var t=e;return void(t._computed=!0)}if(e.isElement()&&(e.property().getAdapter(_.RAMLPropertyService).isMerged()||(k[e.property().nameId()]=!0)),e.property().isAnnotation()){var t=e,n=t.value(),r="";r=S.StructuredValue.isInstance(n)?n.valueName():""+n,k["("+r+")"]=!0}else k[e.name()]=!0});var T=h.definition().allProperties();T.forEach(function(e){e.getAdapter(_.RAMLPropertyService).isKey()||e.getAdapter(_.RAMLPropertyService).isSystem()||h.lowLevel().children().some(function(t){return t.key()==e.nameId()})&&(k[e.nameId()]=!0)}),h._computed=!0}}}})}var K=[];if(0==e.children().length&&e.valueKind()==v.Kind.SEQ&&s.range().key()==b.Universe08.Parameter){var U=new S.BasicASTNode(e,t);U.errorMessage={entry:w.PROPERTY_MUST_BE_A_MAP,parameters:{propName:s.nameId()}},n.push(U)}if("documentation"===s.nameId()&&e.valueKind()!==v.Kind.SEQ){if(!t.definition().getAdapter(_.RAMLService).isUserDefined()){var U=new S.BasicASTNode(e,t);U.errorMessage={entry:w.PROPERTY_MUST_BE_A_SEQUENCE,parameters:{propName:s.nameId()}},n.push(U)}}else e.children().forEach(function(e){if(!k[e.key()])if(e.valueKind()==v.Kind.SEQ){var i="RAML10"==t.definition().universe().version();if(e.children().forEach(function(n){var a=new S.ASTNodeImpl(n,t,u,s);a._allowQuestion=r,a.setNamePatch(e.key()),i&&(a.invalidSequence=!0),K.push(a)}),0==e.children().length){var a=new S.BasicASTNode(e,t);s.range().key()==b.Universe08.Parameter?a.errorMessage={entry:w.NAMED_PARAMETER_NEEDS_TYPE,parameters:{}}:a.errorMessage={entry:w.NODE_SHOULD_HAVE_VALUE,parameters:{}},n.push(a)}}else{var o=new S.ASTNodeImpl(e,t,u,s),l=s.domain().key();"body"!=s.nameId()||l!=b.Universe08.MethodBase&&l!=b.Universe10.MethodBase||o.setComputed("form","true"),o._allowQuestion=r,K.push(o)}});K.length>0?K.forEach(function(e){return M.push(e)}):F.forEach(function(e){return M.push(e)})}else M.push(new S.ASTNodeImpl(e,t,u,s));t._children=t._children.concat(M),n=n.concat(M),M.forEach(function(e){var n=f(s,t,e);n&&n!=e.definition()&&e.patchType(n),e._associatedDef=null,s.childRestrictions().forEach(function(t){e.setComputed(t.name,t.value)});e.definition()})}else T.LowLevelCompositeNode.isInstance(e)&&null==e.primaryNode()||n.push(new S.BasicASTNode(e,t))}),n)},e}();t.BasicNodeBuilder=L,t.doDescrimination=c;var P=function(e){for(var t=!1,n=e;n;){var r=n.definition();if(N.isTraitType(r)||N.isResourceTypeType(r)){t=!0;break}n=n.parent()}return t}},function(e,t,n){"use strict";function r(e){return a.isWebPath(e)}var i=n(15),a=n(10),o=n(27),s=function(){function e(e){this.unit=e}return e.prototype.contextPath=function(){if(!this.unit)return"";var e=this.unit.absolutePath();return e||""},e.prototype.normalizePath=function(e){if(!e)return e;var t;if(r(e)){var n=0===e.toLowerCase().indexOf("https")?"https://":"http://";t=n+i.normalize(e.substring(n.length)).replace(/\\/g,"/")}else t=i.normalize(e).replace(/\\/g,"/");return t},e.prototype.content=function(e){var t=this.normalizePath(e),n=this.toRelativeIfNeeded(t),r=this.unit.resolve(n);return r?r.contents()||"":""},e.prototype.contentAsync=function(e){var t=this.normalizePath(e),n=this.toRelativeIfNeeded(t),r=this.unit.resolveAsync(n);if(!r)return Promise.resolve("");var i=r.then(function(e){return e&&e.contents()||""});return i},e.prototype.toRelativeIfNeeded=function(e){var t=e;return i.isAbsolute(e)&&!r(e)&&(t=i.relative(i.dirname(this.unit.absolutePath()),e)),t},e.prototype.hasAsyncRequests=function(){return o.hasAsyncRequests()},e.prototype.resolvePath=function(e,t){return a.buildPath(t,e,this.unit.project().getRootPath())},e.prototype.isAbsolutePath=function(e){return e?r(e)?!0:i.isAbsolute(e):!1},e.prototype.promiseResolve=function(e){return Promise.resolve(e)},e}();t.ContentProvider=s},function(e,t,n){"use strict";function r(e){var t={};return e.forEach(function(e){return Object.keys(e).forEach(function(n){return t[n]=e[n]})}),t}function i(e,t){return new N(b.find(e||[],t))}function a(e){return Object.keys(e).map(function(t){return[t,e[t]]})}function o(e){var t={};return e.forEach(function(e){return t[e[0]]=e[1]}),t}function s(e,t){return t(e),e}function u(e,t){"object"==typeof e&&Object.keys(e).forEach(function(n){return t(n,e[n])})}function l(e,n,r){void 0===r&&(r=!1);var i={};return e.forEach(function(e){var a=t.shallowCopy(e);r&&delete a[n],i[e[n]]=a}),i}function p(e,t){var n=e.length-t.length;return n>=0&&e.lastIndexOf(t)===n}function c(e,t,n){return void 0===n&&(n=0),e.length-t.length>=n&&e.substring(n,n+t.length)===t}function f(e){return"_"==e[e.length-1]}function m(e,t,n){var r,i=!1;e[t]=function(){return i||(i=!0,r=n.apply(e)),r}}function d(e,n){void 0===n&&(n=f);for(var r in e)n(r)&&t.ifInstanceOf(e[r],Function,function(t){return 0===t.length?m(e,r,t):null})}function h(e,t){void 0!==e&&t(e)}function y(e){return"string"!=typeof e||""==e?!1:p(e,".raml")}function v(e){for(var t,n=[],r=new RegExp("require\\('([^']+)'\\)","gi");t=r.exec(e);)n.push(t[1]);for(var i=new RegExp('require\\("([^"]+)"\\)',"gi");t=i.exec(e);)n.push(t[1]);return n=b.unique(n).filter(function(e){return""!=e}),n.sort(),n}function g(e){return"undefined"!=typeof e&&null!=e}function A(e){return 0==e.length?e:e.charAt(0).toUpperCase()+e.substr(1)}function S(e,t,n){void 0===n&&(n=!1);var r=Object.keys(t);if(n){var i={};r.forEach(function(e){return i[e]=!0}),Object.keys(e).forEach(function(e){return i[e]=!0}),r=Object.keys(i)}r.forEach(function(n){var r=e[n];r instanceof Object?(t[n]||(t[n]={}),S(r,t[n],!0)):void 0!=r&&(t[n]=e[n])})}function T(e,t){return Object.keys(t).forEach(function(n){return e=E(e,n,t[n])}),e}function E(e,t,n){for(var r="",i=0,a=e.indexOf(t);a<e.length&&a>=0;a=e.indexOf(t,i))r+=e.substring(i,a),r+=n,i=a+t.length;return r+=e.substring(i,e.length)}var b=n(64),N=n(23);t.defined=function(e){return null!==e&&void 0!==e},t.flattenArrayOfObjects=r,t.find=i,t.isInstance=function(e,t){return e instanceof t?[e]:[]},t.ifInstanceOf=function(e,t,n){return e instanceof t?n(e):null},t.toTuples=a,t.fromTuples=o,t.collectInstancesOf=function(e,n){return s([],function(r){return e.forEach(function(e){return t.ifInstanceOf(e,n,function(e){return r.push(e)})})})},t.collectInstancesOfInMap=function(e,t){return Object.keys(e).map(function(t){return[t,e[t]]}).filter(function(e){return e[1]instanceof t}).map(function(e){return e})},t.asArray=function(e){return t.defined(e)?e instanceof Array?e:[e]:[]},t.shallowCopy=function(e){return s({},function(t){return Object.keys(e).forEach(function(n){return t[n]=e[n];
})})},t.flatMap=function(e,n){return t.flatten(e.map(n))},t.flatten=function(e){return Array.prototype.concat.apply([],e)},t.takeWhile=function(e,t){return s([],function(n){for(var r=0;r<e.length&&t(e[r]);r++)n.push(e[r])})},t.tap=s,t.kv=u,t.indexed=l,t.stringEndsWith=p,t.stringStartsWith=c,t.lazypropkeyfilter=f,t.lazyprops=d,t.iff=h,t.isRAMLUrl=y,t.getAllRequiredExternalModulesFromCode=v,t.serial=function(){var e=0;return function(){return e++}}(),t.isEssential=g,t.firstToUpper=A,t.updateObject=S,t.replaceMap=T,t.replace=E},function(e,t,n){"use strict";function r(e){return e.highLevel().localType()}function i(e){return e.highLevel().localType()}function a(e){var t=new Ie.Project(Le.dirname(e)),n=t.unit(Le.basename(e));return n&&n.isRAMLUnit()?ve.fromUnit(n).wrapperNode():null}function o(e){var t="",n=e;do e=n,t=e.relativeUri().value()+t,n=e.parent();while(n.definition().key().name==Ee.Universe10.Resource.name);return t}function s(e,t){return void 0===t&&(t=!1),t?l(e):u(e)}function u(e){var t=e.highLevel().lowLevel();return Me.LowLevelProxyNode.isInstance(t)?e:_e.expandTraitsAndResourceTypes(e)}function l(e){return _e.expandLibraries(e)}function p(e){var t="",n=e;do e=n,t=e.relativeUri().value()+t,n=e.parent();while(n.definition().key().name==Ee.Universe10.Resource.name);t=t.replace(/\/\//g,"/");var r=n.baseUri(),i=r?r.value():"";return i=i?i:"",Ne.stringEndsWith(i,"/")&&(t=t.substring(1)),t=i+t}function c(e,t){return e.runtimeType().validate(t).map(function(e){return e.getMessage()})}function f(e,t){return e.runtimeType().validate(t)}function m(e){return d(e)}function d(e){return e.highLevel().lowLevel().actual().libExpanded?e.traits_original():v(e,function(e){return Pe.isTraitType(e)})}function h(e){return y(e)}function y(e){return e.highLevel().lowLevel().actual().libExpanded?e.resourceTypes_original():v(e,function(e){return Pe.isResourceTypeType(e)})}function v(e,t){var n=Re.globalDeclarations(e.highLevel()).filter(function(e){return t(e.definition())}),r=e.highLevel().lowLevel(),i=r.includePath();i||(i=r.unit().path());var a=Me.LowLevelProxyNode.isInstance(e.highLevel().lowLevel()),o=a?new _e.TraitsAndResourceTypesExpander:null,s=n.map(function(t){var n,r=t.lowLevel().unit().path();return a&&(Me.LowLevelProxyNode.isInstance(t.lowLevel())||(t=o.createHighLevelNode(t,!1)),(new we.ReferencePatcher).process(t,e.highLevel(),!0,!0)),r!=i?(n=me.buildWrapperNode(t,!1),n.meta().setCalculated()):n=t.wrapperNode(),n});return s}function g(e){var t=[],n=e;do e=n,t.push(e.relativeUri().value()),n=e.parent();while(n.definition().key().name==Ee.Universe10.Resource.name);return t.reverse()}function A(e){return fe.ResourceImpl.isInstance(e.parent())?e.parent():null}function S(e){var t=e.parent();return t.definition().key().name==Ee.Universe10.Resource.name?t:null}function T(e,t){if(null==e)return null;var n=e.resources();return n?(n=n.filter(function(e){return e.relativeUri().value()==t}),0==n.length?null:n[0]):null}function E(e,t){if(!e)return null;for(var n=null,r=0;r<t.length;r++){if(n=T(e,t[r]),!n)return null;e=n}return n}function b(e,t){return e?e.methods().filter(function(e){return e.method()==t}):null}function N(e,t,n){var r=E(e,t);return r?b(r,n):null}function _(e){return Pe.isApiSibling(e.definition())}function M(e){for(var t=e;!_(t);)t=t.parent();return t}function w(e){var t=e.parent();if(fe.ResourceImpl.isInstance(t))return o(t)+" "+e.method().toLowerCase();if(fe.ResourceTypeImpl.isInstance(t))return t.name()+" "+e.method().toLowerCase();throw new Error("Method is supposed to be owned by Resource or ResourceType.\nHere the method is owned by "+e.definition().key().name)}function R(e){var t=e.code().value(),n=ge.validateResponseString(t);if(null!=n)return!1;try{if(parseInt(t.charAt(0))<4)return!0}catch(r){}return!1}function I(e){var t=[],n=function(e){t.push(e),e.resources().forEach(function(e){return n(e)})};return e.resources().forEach(function(e){return n(e)}),t}function C(e,t){for(var n={};null!=t;)P(t).forEach(function(e){return n[e.name()]=new ke(e)}),t=S(t);var r=he.ramlPathMatch(o(t),n,{})(e);return r?new be(Object.keys(r.params).map(function(e){return new Ue(e,r.params[e])})):be.empty()}function L(e){return P(e)}function P(e){var t=e.uriParameters_original();if(!fe.ResourceImpl.isInstance(e))return t;var n=e.relativeUri().value(),r=Ee.Universe10.ResourceBase.properties.uriParameters.name;return ue(t,n,e,r)}function O(e){return D(e)}function D(e){var t=e.baseUri()?e.baseUri().value():"",n=e.baseUriParameters_original(),r=Ee.Universe10.Api.properties.baseUriParameters.name;return ue(n,t,e,r)}function x(e){var t=[],n=e;do e=n,t=P(e).concat(t),n=e.parent();while(n.definition().key().name==Ee.Universe10.Resource.name);var r=n;r.baseUriParameters();return t=D(r).concat(t)}function U(e){return k(e)}function k(e){return e.protocols().map(function(e){return e.toUpperCase()})}function F(e){return B(e)}function B(e){return e.securedBy()}function K(e){var t=e.highLevel();if(!t)return"";var n=t.value();return n?n.toString():""}function V(e){var t=e.highLevel();if(!t)return null;var n=Re.findDeclarationByNode(t,Re.LocationKind.VALUE_COMPLETION);if(!n)return null;if(!n.getKind||n.getKind()!=ye.NodeKind.NODE)return null;var r=n.wrapperNode();return fe.AbstractSecuritySchemeImpl.isInstance(r)?r:null}function j(e){return e.highLevel().definition().universe().version()}function W(e){var t=e.value().lowLevel(),n=null,r=t.highLevelParseResult();if(r){var i=null,a=!1;if(r.isAttr()?(a=Pe.isAnnotationsProperty(r.property()),i=r.parent().types()):r.isElement()&&(i=r.asElement().types()),i){var o=e.name(),s=o.indexOf(".")>=0;if(s){var u=a?i.getAnnotationTypeRegistry():i.getTypeRegistry();n=u.get(o)}else n=a?i.getAnnotationType(o):i.getType(o)}}return new de.TypeInstanceImpl(t,n)}function q(e){var t=e.highLevel().value();return"string"==typeof t||null==t?t:t.valueName()}function Y(e){return G(e)}function H(e){return G(e)}function $(e){return G(e)}function G(e){var t=e.highLevel(),n=t.parent(),r=e.name(),i=Re.referenceTargets(t.property(),n).filter(function(e){return ve.qName(e,n)==r});return 0==i.length?null:i[0].wrapperNode()}function X(e,t,n,r){void 0===r&&(r=!0);var i=t.lowLevel(),a=t.definition().property(n?"example":"examples"),o=Se.getUniverse("RAML10"),s=o.type(Te.Universe10.ExampleSpec.name),u=e.examples().filter(function(e){return null!=e&&!e.isEmpty()&&e.isSingle()==n});return u.map(function(e){var n=e.asJSON(),o=e.isSingle()?"example":null,u=i.unit(),l=new Ce.AstNode(u,n,i,null,o),p=r?new ve.ASTNodeImpl(l,t,s,a):t,c=e.annotations(),f=De(c,l,p,u),m=e.scalarsAnnotations(),d={};Object.keys(m).forEach(function(e){return d[e]=De(m[e],l,p,u)});var h=new Fe(p,e,f,{description:function(){return d.description||[]},displayName:function(){return d.displayName||[]},strict:function(){return d.strict||[]}});return h})}function z(e,t){void 0===t&&(t=!1);var n=e.runtimeDefinition();if(!n)return[];var r=e.highLevel();return X(n,r,t)}function J(e){var t=z(e,!0);return t.length>0?t[0]:null}function Q(e){return z(e)}function Z(e){var t=e.runtimeDefinition(),n=t.getFixedFacets(),r=Object.keys(n);if(e.kind()!=Te.Universe10.UnionTypeDeclaration.name)for(var i=0,a=r;i<a.length;i++){var o=a[i];null==t.facet(o)&&delete n[o]}if(0==Object.keys(n).length)return null;var s=new Ce.AstNode(null,n);return new de.TypeInstanceImpl(s)}function ee(e){var t=e.highLevel().attributes(Se.universesInfo.Universe10.TypeDeclaration.properties.type.name),n=t.filter(function(e){return ve.StructuredValue.isInstance(e.value())});if(0==n.length)return e.type_original().map(function(e){return null===e||"NULL"===e||"Null"===e?"string":e});var r=!1,i=t.map(function(e){var t=e.value();return null==t?null:"string"==typeof t?t:(ve.StructuredValue.isInstance(t)&&(r=!0),t.toString())});return r?null:i}function te(e){var t=!1,n=e.highLevel().attributes(Se.universesInfo.Universe10.TypeDeclaration.properties.schema.name);if(t)return null;var r=n.filter(function(e){return ve.StructuredValue.isInstance(e.value())});if(0==r.length)return e.schema_original();var i=n.map(function(e){var n=e.value();return"string"==typeof n?n:(ve.StructuredValue.isInstance(n)&&(t=!0),n.toString())});return t?null:i}function ne(e){var t=e.highLevel().attributes(Se.universesInfo.Universe10.TypeDeclaration.properties.type.name);t=t.concat(e.highLevel().attributes(Se.universesInfo.Universe10.TypeDeclaration.properties.schema.name));for(var n=t.map(function(e){return e.value()}),r=0,i=n;r<i.length;r++){var a=i[r];if(ve.StructuredValue.isInstance(a)){var o=new de.TypeInstanceImpl(a.lowLevel());return o}}return null}function re(e){var t=e.value(),n=e.highLevel().lowLevel().unit().resolve(t),r=n.highLevel(),i=r.asElement();if(i){var a=i.wrapperNode();return ce.isLibrary(a)?(a.setAttributeDefaults(e.attributeDefaults()),a):null}return null}function ie(e){var t=e.highLevel().attributes(Se.universesInfo.Universe10.ArrayTypeDeclaration.properties.items.name),n=t.filter(function(e){return ve.StructuredValue.isInstance(e.value())});if(0==n.length)return e.items_original().map(function(e){return null===e||"NULL"===e||"Null"===e?"string":e});var r=!1,i=t.map(function(e){var t=e.value();return null==t?null:"string"==typeof t?t:(ve.StructuredValue.isInstance(t)&&(r=!0),t.toString())});return r?null:i}function ae(e){var t=e.highLevel();if(!t)return null;var n=t.attr(Ee.Universe10.TypeDeclaration.properties.type.name);if(null==n)return null;var r=n.lowLevel();if(null==r)return null;var i=n.value();if(!i||"string"!=typeof i)return null;var a=r.end()-i.length+1,o=n.lowLevel().unit();if(!o)return null;var s=Re.findDeclaration(o,a);return s&&s.getKind&&s.getKind()==ye.NodeKind.NODE&&Pe.isTypeDeclarationSibling(s.definition())?s.wrapperNode():null}function oe(e){var t=e.runtimeType();if(!t)return null;if(!t.isArray()||!t.componentType)return null;var n=t,r=n.componentType();if(!r)return null;var i=Re.getNominalTypeSource(r);if(!i)return null;var a=i.getSource();if(!a)return null;if(!a.isElement())return null;if(!Pe.isTypeDeclarationSibling(a.definition()))return null;var o=a.wrapperNode();return o}function se(e){var t=e.items_original();if(t&&"string"!=typeof t&&(!Array.isArray(t)||0!=t.length)){var n=e.highLevel(),r=Te.Universe10.ArrayTypeDeclaration.properties.items.name,i=n.attr(r),a=n.definition().universe().type(Te.Universe10.TypeDeclaration.name),o=n.definition().universe().type(Te.Universe10.ArrayTypeDeclaration.name),s=new ve.ASTNodeImpl(i.lowLevel(),n,a,o.property(r));s.patchType(Oe.doDescrimination(s))}var u=oe(e);return u?u:ae(e)}function ue(e,t,n,r){if("string"!=typeof t)return[];var i=n.highLevel(),a=i.definition(),o=a.property(r);if(!t)return[];var s={};e.forEach(function(e){var t=s[e.name()];t||(t=[],s[e.name()]=t),t.push(e)});for(var u=[],l=0,p={},c=t.indexOf("{");c>=0&&(l=t.indexOf("}",++c),!(0>l));c=t.indexOf("{",l)){var f=t.substring(c,l);if(p[f]=!0,s[f])s[f].forEach(function(e){return u.push(e)});else{var m=a.universe(),d=m.type(Te.Universe10.StringTypeDeclaration.name),h=Ae.createStubNode(d,null,f,i.lowLevel().unit()),y=me.buildWrapperNode(h),v=y.highLevel();v.setParent(i),y.meta().setCalculated(),y.setName(f),v.patchProp(o),u.push(y)}}return Object.keys(s).filter(function(e){return!p[e]}).forEach(function(e){return s[e].forEach(function(e){return u.push(e)})}),u}function le(e){if(e.kind()==Te.Universe10.Method.name||Pe.isTypeDeclarationSibling(e.definition())){for(var t=!1,n=e.highLevel().parent();null!=n;){var r=n.definition();if(Pe.isResourceTypeType(r)||Pe.isTraitType(r)){t=!0;break}n=n.parent()}if(!t)return null}var i=e.highLevel();if(null==i)return null;var a=i.lowLevel();if(null==a)return null;var o=a.children().filter(function(e){var t=e.key();return t?"("==t.charAt(0)&&")"==t.charAt(t.length-1)?!1:t.indexOf("<<")>=0:!1});if(0==o.length)return null;var s=new de.TypeInstanceImpl(o);return s}var pe=this&&this.__extends||function(e,t){function n(){this.constructor=e}for(var r in t)t.hasOwnProperty(r)&&(e[r]=t[r]);e.prototype=null===t?Object.create(t):(n.prototype=t.prototype,new n)},ce=n(11),fe=n(22),me=n(44),de=n(47),he=n(56),ye=n(9),ve=n(16),ge=n(30),Ae=n(19),Se=n(37),Te=n(17),Ee=n(17),be=n(23),Ne=n(33),_e=n(29),Me=n(41),we=n(52),Re=n(13),Ie=n(26),Ce=n(53),Le=n(15),Pe=n(14),Oe=n(31);t.resolveType=r,t.runtimeType=i,t.load=a,t.completeRelativeUri=o,t.expandSpec=s,t.expandTraitsAndResourceTypes=u,t.expandLibraries=l,t.absoluteUri=p,t.validateInstance=c,t.validateInstanceWithDetailedStatuses=f,t.traitsPrimary=m,t.allTraits=d,t.resourceTypesPrimary=h,t.allResourceTypes=y,t.relativeUriSegments=g,t.parentResource=A,t.parent=S,t.childResource=T,t.getResource=E,t.childMethod=b,t.getMethod=N,t.ownerApi=M,t.methodId=w,t.isOkRange=R,t.allResources=I,t.matchUri=C;t.uriParametersPrimary=L,t.uriParameters=P,t.baseUriParametersPrimary=O,t.baseUriParameters=D,t.absoluteUriParameters=x,t.protocolsPrimary=U,t.allProtocols=k,t.securedByPrimary=F,t.allSecuredBy=B,t.securitySchemeName=K,t.securityScheme=V,t.RAMLVersion=j,t.structuredValue=W,t.referenceName=q,t.referencedTrait=Y,t.referencedAnnotation=H,t.referencedResourceType=$;var De=function(e,t,n,r){var i=[];if(e)for(var a=Se.getUniverse("RAML10"),o=a.type("Annotable").property("annotations"),s=0,u=Object.keys(e);s<u.length;s++){var l=u[s],p=e[l],c=new Ce.AstNode(r,p.value(),t,null,"("+l+")"),f=new ve.ASTPropImpl(c,n,o.range(),o),m=new fe.AnnotationRefImpl(f);i.push(m)}return i};t.examplesFromNominal=X,t.getTypeExample=J,t.getTypeExamples=Q,t.typeFixedFacets=Z,t.typeValue=ee,t.schemaValue=te,t.typeStructuredValue=ne,t.referencedNode=re,t.getItems=ie,t.findComponentTypeDeclaration=se,t.getTemplateParametrizedProperties=le;var xe=function(){function e(e,t){this._content=e,this._name=t}return e.prototype.name=function(){return this._name},e.prototype.content=function(){return this._content},e}();t.SchemaDef=xe;var Ue=function(){function e(e,t){this.key=e,this.value=t}return e}();t.ParamValue=Ue;var ke=function(){function e(e){this._param=e,this.description=e.description()?e.description().value():this.description,this.displayName=e.displayName(),this.type=e.type().length>0?e.type()[0]:"string",this.example=e.example(),this.required=e.required(),this["default"]=e["default"]()}return e}(),Fe=function(e){function t(t,n,r,i){e.call(this,t),this.expandable=n,this._annotations=r,this._scalarAnnotations=i}return pe(t,e),t.prototype.value=function(){return this.expandable.asString()},t.prototype.structuredValue=function(){var e;e=this.expandable.isJSONString()||this.expandable.isYAML()?this.expandable.asJSON():this.expandable.original();var t=this._node.lowLevel(),n=this.expandable.isSingle()?"example":null,r=new Ce.AstNode(t.unit(),e,t,null,n);return new de.TypeInstanceImpl(r)},t.prototype.strict=function(){return this.expandable.strict()},t.prototype.description=function(){var e=this.expandable.description();if(null==e&&null!==e)return null;var t=Ae.createAttr(this._node.definition().property(Te.Universe10.ExampleSpec.properties.description.name),e),n=new fe.MarkdownStringImpl(t);return n},t.prototype.name=function(){return this.expandable.name()},t.prototype.displayName=function(){return this.expandable.displayName()},t.prototype.annotations=function(){return this._annotations},t.prototype.scalarsAnnotations=function(){return this._scalarAnnotations},t.prototype.uses=function(){return e.prototype.elements.call(this,"uses")},t}(de.BasicNodeImpl);t.ExampleSpecImpl=Fe},function(e,t,n){"use strict";var r=n(37);e.exports=r},function(e,t,n){"use strict";var r=n(37);e.exports=r.getUniverse},function(e,t,n){"use strict";function r(){return t.rt.getSchemaUtils()}function i(e){e.isUnion?e.addAdapter(new _(e)):e.range&&e.addAdapter(new N(e))}function a(e){return e.getSource&&"function"==typeof e.getSource}function o(e){var t=e;return t.genuineUserDefinedType&&t.isUserDefined&&t.isUserDefined()}function s(e,t,n,r,i){var a=new S(e,t);return a.withDomain(n,i).withRange(r)}var u=this&&this.__extends||function(e,t){function n(){this.constructor=e}for(var r in t)t.hasOwnProperty(r)&&(e[r]=t[r]);e.prototype=null===t?Object.create(t):(n.prototype=t.prototype,new n)};t.rt=n(83);var l=t.rt.nominalTypes;t.getSchemaUtils=r,t.TOP_LEVEL_EXTRA=t.rt.TOP_LEVEL_EXTRA,t.DEFINED_IN_TYPES_EXTRA=t.rt.DEFINED_IN_TYPES_EXTRA,t.USER_DEFINED_EXTRA=t.rt.USER_DEFINED_EXTRA,t.SOURCE_EXTRA=t.rt.SOURCE_EXTRA,t.tsInterfaces=t.rt.tsInterfaces,t.injector={inject:function(e){i(e)}},l.registerInjector(t.injector);var p=function(e){function t(){e.apply(this,arguments)}return u(t,e),t}(l.AbstractType);t.AbstractType=p;var c=function(e){function t(){e.apply(this,arguments)}return u(t,e),t}(l.ValueType);t.ValueType=c;var f=function(){function e(){}return e.isInstance=function(t){if(null!=t&&t.getClassIdentifier&&"function"==typeof t.getClassIdentifier)for(var n=0,r=t.getClassIdentifier();n<r.length;n++){var i=r[n];if(i==e.CLASS_IDENTIFIER)return!0}return!1},e.prototype.getClassIdentifier=function(){var t=[];return t.concat(e.CLASS_IDENTIFIER)},e.prototype.getSource=function(){return null},e.CLASS_IDENTIFIER="definitionSystem.SourceProvider",e}();t.SourceProvider=f,t.isSourceProvider=a;var m=function(e){function t(){e.apply(this,arguments),this.values=[]}return u(t,e),t.isInstance=function(e){if(null!=e&&e.getClassIdentifier&&"function"==typeof e.getClassIdentifier)for(var n=0,r=e.getClassIdentifier();n<r.length;n++){var i=r[n];if(i==t.CLASS_IDENTIFIER)return!0}return!1},t.prototype.getClassIdentifier=function(){var e=[];return e.concat(t.CLASS_IDENTIFIER)},t.CLASS_IDENTIFIER="definitionSystem.EnumType",t}(c);t.EnumType=m;var d=function(e){function t(t,n,r,i){e.call(this,t,i,n),this.referenceTo=r}return u(t,e),t.isInstance=function(e){if(null!=e&&e.getClassIdentifier&&"function"==typeof e.getClassIdentifier)for(var n=0,r=e.getClassIdentifier();n<r.length;n++){var i=r[n];if(i==t.CLASS_IDENTIFIER)return!0}return!1},t.prototype.getClassIdentifier=function(){var e=[];return e.concat(t.CLASS_IDENTIFIER)},t.prototype.getReferencedType=function(){return this.universe().type(this.referenceTo)},t.prototype.hasStructure=function(){return!0},t.CLASS_IDENTIFIER="definitionSystem.ReferenceType",t}(c);t.ReferenceType=d;var h=function(e){function t(t,n,r,i){void 0===i&&(i=""),e.call(this,t,n,r)}return u(t,e),t.isInstance=function(e){if(null!=e&&e.getClassIdentifier&&"function"==typeof e.getClassIdentifier)for(var n=0,r=e.getClassIdentifier();n<r.length;n++){var i=r[n];if(i==t.CLASS_IDENTIFIER)return!0}return!1},t.prototype.getClassIdentifier=function(){var e=[];return e.concat(t.CLASS_IDENTIFIER)},t.prototype.allProperties=function(t){return void 0===t&&(t={}),e.prototype.allProperties.call(this,t)},t.CLASS_IDENTIFIER="definitionSystem.NodeClass",t}(l.StructuredType);t.NodeClass=h;var y=function(e){function t(t,n,r,i,a){e.call(this,t,n,i,a),this.getAdapter(_).setDeclaringNode(r)}return u(t,e),t.isInstance=function(e){if(null!=e&&e.getClassIdentifier&&"function"==typeof e.getClassIdentifier)for(var n=0,r=e.getClassIdentifier();n<r.length;n++){var i=r[n];if(i==t.CLASS_IDENTIFIER_UserDefinedClass)return!0}return!1},t.prototype.getClassIdentifier=function(){var n=e.prototype.getClassIdentifier.call(this);return n.concat(t.CLASS_IDENTIFIER_UserDefinedClass)},t.prototype.key=function(){return null},t.prototype.isUserDefined=function(){return!0},t.prototype.typeId=function(){var e=this.nameId(),t=this.getAdapter(_).getDeclaringNode();if(t){e+=t.lowLevel().start();var n=t.lowLevel().unit();n&&(e+=n.absolutePath())}return e},t.prototype.hasValueTypeInHierarchy=function(){return this._value?!0:this.isAssignableFrom("ObjectTypeDeclaration")?!1:!1},t.prototype.isGenuineUserDefinedType=function(){return null!=this.genuineUserDefinedType()},t.prototype.genuineUserDefinedType=function(){var e=this.getAdapter(_).getDeclaringNode();return e?this:null},t.CLASS_IDENTIFIER_UserDefinedClass="definitionSystem.UserDefinedClass",t}(h);t.UserDefinedClass=y,t.isUserDefinedClass=o;var v=function(e){function t(){e.apply(this,arguments)}return u(t,e),t.prototype.allProperties=function(e){void 0===e&&(e={});var t=this.superTypes()[0].allProperties();if(0==t.length){var n=this.getAdapter(_).getDeclaringNode(),r=new T("value",n);r.withDomain(this),r.withCanBeValue(),r.withRequired(!1);this.superTypes()[0];t=[],r.withRange(r.node().asElement().definition().universe().type("string")),t.push(r)}return t},t.prototype.isAnnotationType=function(){return!0},t}(y);t.AnnotationType=v;var g=function(e){function t(t,n,r,i){void 0===n&&(n=""),void 0===r&&(r=null),void 0===i&&(i="RAML08"),e.call(this,n),this._parent=r,this._classes=[],this._uversion="RAML08",this.aMap={},this.matchedObjects=t,this._uversion=i}return u(t,e),t.prototype.matched=function(){return this.matchedObjects?this.matchedObjects:this._parent?this._parent.matched():void 0},t.prototype.setTopLevel=function(e){this._topLevel=e},t.prototype.getTopLevel=function(){return this._topLevel},t.prototype.setOriginalTopLevelText=function(e){this._originalTopLevelText=e},t.prototype.getOriginalTopLevelText=function(){return this._originalTopLevelText},t.prototype.setTypedVersion=function(e){this._typedVersion=e},t.prototype.getTypedVersion=function(){return this._typedVersion},t.prototype.version=function(){return this._uversion},t.prototype.setUniverseVersion=function(e){this._uversion=e},t.prototype.types=function(){var e=[].concat(this._classes);return null!=this._parent&&(e=e.concat(this._parent.types())),e},t.prototype.type=function(e){if(this.aMap[e])return this.aMap[e];for(var t,n=0;n<this._classes.length;n++)if(this._classes[n].nameId()==e){t=this._classes[n];break}if(null==t&&this._parent){var t=this._parent.type(e);if(t instanceof p){var r=t;r._universe=this}}return t},t.prototype.register=function(e){return this._classes.push(e),e instanceof h&&this._classes.forEach(function(t){if(t instanceof h){var n=t;n.getAdapter(_).getExtendedType()==e&&e.getAdapter(_).getRuntimeExtenders().push(t)}}),this},t.prototype.registerAlias=function(e,t){this.aMap[e]=t},t.prototype.unregister=function(e){this._classes=this._classes.filter(function(t){return t!=e});var t=e.superTypes();return t.forEach(function(t){var n=t;n._superTypes=n._superTypes.filter(function(t){return t!=e})}),t=e.subTypes(),t.forEach(function(t){var n=t;n._subTypes=n._subTypes.filter(function(t){return t!=e})}),this},t.prototype.registerSuperClass=function(e,t){var n=e,r=t;n._superTypes.push(t),r._subTypes.push(e)},t}(l.Described);t.Universe=g,t.prop=s;var A=function(){function e(e,t){this.name=e,this.value=t}return e}();t.ChildValueConstraint=A;var S=function(e){function t(){e.apply(this,arguments),this._isFromParentValue=!1,this._isFromParentKey=!1,this._key=!1,this._declaresFields=!1,this._describes=null,this._canBeDuplicator=!1,this._allowsNull=!1,this._canBeValue=!1,this._isInherited=!1,this._selfNode=!1,this._noDirectParse=!1,this._contextReq=[],this.determinesChildValues=[]}return u(t,e),t.prototype.isPrimitive=function(){return this.range().isValueType()&&!(this.range()instanceof d)},t.prototype.withNoDirectParse=function(){this._noDirectParse=!0},t.prototype.isNoDirectParse=function(){return this._noDirectParse},t.prototype.withSelfNode=function(){this._selfNode=!0},t.prototype.isSelfNode=function(){return this._selfNode},t.prototype.matchKey=function(t){return null!=this._groupName?this.isAnnotation()?"("==t.charAt(0)&&")"==t.charAt(t.length-1)?!0:!1:this._groupName==t:e.prototype.matchKey.call(this,t)},t.prototype.valueDocProvider=function(){return this._vprovider},t.prototype.setValueDocProvider=function(e){return this._vprovider=e,this},t.prototype.suggester=function(){return this._suggester},t.prototype.setValueSuggester=function(e){this._suggester=e},t.prototype.enumOptions=function(){return this._enumOptions&&"string"==typeof this._enumOptions?[this._enumOptions+""]:this._enumOptions},t.prototype.getOftenKeys=function(){return this._oftenKeys},t.prototype.withOftenKeys=function(e){return this._oftenKeys=e,this},t.prototype.withCanBeValue=function(){return this._canBeValue=!0,this},t.prototype.withInherited=function(e){this._isInherited=e},t.prototype.isInherited=function(){return this._isInherited},t.prototype.isAllowNull=function(){return this._allowsNull},t.prototype.withAllowNull=function(){this._allowsNull=!0},t.prototype.getCanBeDuplicator=function(){return this._canBeDuplicator},t.prototype.canBeValue=function(){return this._canBeValue},t.prototype.setCanBeDuplicator=function(){return this._canBeDuplicator=!0,!0},t.prototype.inheritedContextValue=function(){return this._inheritsValueFromContext},t.prototype.withInheritedContextValue=function(e){return this._inheritsValueFromContext=e,this},t.prototype.withContextRequirement=function(e,t){this._contextReq.push({name:e,value:t})},t.prototype.getContextRequirements=function(){return this._contextReq},t.prototype.withDescribes=function(e){return this._describes=e,this},t.prototype.describesAnnotation=function(){return null!=this._describes},t.prototype.describedAnnotation=function(){return this._describes},t.prototype.isReference=function(){return this.range()instanceof d},t.prototype.referencesTo=function(){return this.range().getReferencedType()},t.prototype.newInstanceName=function(){return this._newInstanceName?this._newInstanceName:this.range().nameId()},t.prototype.withThisPropertyDeclaresFields=function(e){return void 0===e&&(e=!0),this._declaresFields=e,this},t.prototype.isThisPropertyDeclaresTypeFields=function(){return this._declaresFields},t.prototype.withNewInstanceName=function(e){return this._newInstanceName=e,this},t.prototype.addChildValueConstraint=function(e){this.determinesChildValues.push(e)},t.prototype.getChildValueConstraints=function(){return this.determinesChildValues},t.prototype.childRestrictions=function(){return this.determinesChildValues},t.prototype.id=function(){return this._id?this._id:this._groupName?this.domain().getAdapter(_).getDeclaringNode()?null:(this._id=this._groupName+this.domain().nameId(),this._id):null},t.prototype.isAnnotation=function(){return"annotations"==this._groupName&&this.domain()&&!this.domain().isUserDefined()},t.prototype.withFromParentValue=function(e){return void 0===e&&(e=!0),this._isFromParentValue=e,this},t.prototype.withFromParentKey=function(e){return void 0===e&&(e=!0),this._isFromParentKey=e,this},t.prototype.isFromParentKey=function(){return this._isFromParentKey},t.prototype.isFromParentValue=function(){return this._isFromParentValue},t.prototype.withGroupName=function(e){return this._groupName=e,this},t.prototype.unmerge=function(){return this._groupName=this.nameId(),this},t.prototype.merge=function(){return this._groupName=null,this},t.prototype.withKey=function(e){return this._key=e,this},t.prototype.isKey=function(){return this._key},t.prototype.isMerged=function(){return null==this._groupName},t.prototype.groupName=function(){return this._groupName},t.prototype.key=function(){return null},t}(l.Property);t.Property=S;var T=function(e){function t(t,n){e.call(this,t),this._node=n}return u(t,e),t.isInstance=function(e){if(null!=e&&e.getClassIdentifier&&"function"==typeof e.getClassIdentifier)for(var n=e.getClassIdentifier(),r=0;r<n.length;r++)if(n[r]==t.CLASS_IDENTIFIER)return!0;return!1},t.prototype.getClassIdentifier=function(){var e=[];return e.concat(t.CLASS_IDENTIFIER)},t.prototype.withDisplayName=function(e){this._displayName=e},t.prototype.getDisplayName=function(){return this._displayName},t.prototype.node=function(){return this._node||null==this.sourceProvider||(this._node=this.sourceProvider.getSource()),this._node},t.prototype.setSourceProvider=function(e){this.sourceProvider=e},t.CLASS_IDENTIFIER="definitionSystem.UserDefinedProp",t}(S);t.UserDefinedProp=T;var E=function(){function e(){}return e.prototype.setDocTableName=function(e){this._documentationTableName=e},e.prototype.docTableName=function(){return this._documentationTableName},e.prototype.setHidden=function(e){this._isHidden=e},e.prototype.isHidden=function(){return this._isHidden},e.prototype.setMarkdownDescription=function(e){this._markdownDescription=e},e.prototype.markdownDescription=function(){return this._markdownDescription},e.prototype.setValueDescription=function(e){this._valueDescription=e},e.prototype.valueDescription=function(){return this._valueDescription},e}();t.RAMLPropertyDocumentationService=E;var b=function(e){function t(){e.apply(this,arguments)}return u(t,e),t.prototype.isSystem=function(){return this._isSystemProperty},t.prototype.withSystem=function(e){return this._isSystemProperty=e,this},t.prototype.isEmbedMap=function(){return this._isEmbededMap},t.prototype.withEmbedMap=function(){return this._isEmbededMap=!0,this},t}(E);t.RAMLPropertyParserService=b;var N=function(e){function t(t){if(e.call(this),this._property=t,this._meta={},!t)throw new Error;e.call(this)}return u(t,e),t.prototype.valueDocProvider=function(){return this._property.valueDocProvider()},t.prototype.withPropertyGrammarType=function(e){this._propertyGrammarType=e},t.prototype.getPropertyGrammarType=function(){return this._propertyGrammarType},t.prototype.id=function(){return this._property.nameId()},t.prototype.range=function(){return this._property.range()},t.prototype.domain=function(){return this._property.domain()},t.prototype.isAllowNull=function(){return this._property.isAllowNull()},t.prototype.referencesTo=function(){return this._property.referencesTo()},t.prototype.isReference=function(){return this._property.isReference()},t.prototype.nameId=function(){return this._property.nameId()},t.prototype.priority=function(){return this.isKey()?128:this.isReference()?64:this.isTypeExpr()?32:"example"==this.nameId()?0:-1024},t.prototype.isKey=function(){return this._property instanceof S?this._property.isKey():!1},t.prototype.isMerged=function(){return this._property instanceof S?this._property.isMerged():!1},t.prototype.isTypeExpr=function(){return this.texpr},t.prototype.isExampleProperty=function(){return this.example},t.prototype.setExample=function(e){this.example=e},t.prototype.setTypeExpression=function(e){this.texpr=e},t.prototype.isDescriminating=function(){return this._property.isDescriminator()},t.prototype.putMeta=function(e,t){this._meta[e]=t},t.prototype.meta=function(e){return this._meta[e]},t}(b);t.RAMLPropertyService=N;var _=function(){function e(e){
//!!!
this._allowsOptionalProperties=!1,this._possibleInterfaces=[],
//!!!
this._canInherit=[],this._declaredBy=[],
//!!!
this._aliases=[],
//!!!???
this._defining=[],this._runtimeExtenders=[],
//!!!???
this._declaresType=null,
//!!!
this._isTemplate=!1,
//!!!
this._contextRequirements=[],this._type=e}return e.prototype.withAllowQuestion=function(){this._allowsOptionalProperties=!0},e.prototype.getAllowQuestion=function(){return this._allowsOptionalProperties},e.prototype.withCanInherit=function(e){this._canInherit.push(e)},e.prototype.getReferenceIs=function(){return this._referenceIs},e.prototype.withReferenceIs=function(e){this._referenceIs=e},e.prototype.descriminatorValue=function(){return 0==this.valueRequirements().length?this.nameId():this.valueRequirements()[0].value},e.prototype.getCanInherit=function(){return this._canInherit},e.prototype.withAllowAny=function(){this._allowsAnyChildren=!0},e.prototype.getAllowAny=function(){return this._allowsAnyChildren||this._type.isExternal()},e.prototype.globallyDeclaredBy=function(){return this._declaredBy},e.prototype.setGloballyDeclaredBy=function(e){this._declaredBy.push(e)},e.prototype.setDeclaringNode=function(e){this._node=e},e.prototype.nameId=function(){return this._type.nameId()},e.prototype.universe=function(){return this._type.universe()},e.prototype.isAssignableFrom=function(e){return this._type.isAssignableFrom(e)},e.prototype.setConsumesRefs=function(e){this._consumesRef=e},e.prototype.definingPropertyIsEnough=function(e){this._defining.push(e)},e.prototype.getDefining=function(){return this._defining},e.prototype.getConsumesRefs=function(){return this._consumesRef},e.prototype.addAlias=function(e){this._aliases.push(e)},e.prototype.getAliases=function(){return this._aliases},e.prototype.valueRequirements=function(){return this._type.valueRequirements()},e.prototype.isAnnotation=function(){return this._annotationChecked?this._isAnnotation:(this._annotationChecked=!0,this._isAnnotation=this._type.allSuperTypes().some(function(e){return e.key()&&"AnnotationRef"==e.key().name}),this._isAnnotation)},e.prototype.allowValue=function(){return this._allowsValueSet?this._allowsValue:this._type.allProperties().some(function(e){return e.isFromParentValue()||e.canBeValue()})?(this._allowsValue=!0,this._allowsValueSet=!0,!0):(this._allowsValueSet=!0,!1)},e.prototype.key=function(){return this._type.key()},e.prototype.getRepresentationOf=function(){return this._representationOf},e.prototype.getPath=function(){return""},e.prototype.isDeclaration=function(){return this._isTemplate?!0:this._convertsToGlobal?!0:this._declaresType?!0:this.key()&&"Library"===this.key().name?!0:!1},e.prototype.isGlobalDeclaration=function(){return this._actuallyExports?!0:this._isTemplate?!0:this._declaresType?!0:!1},e.prototype.isTypeSystemMember=function(){return null!=this._declaresType},e.prototype.getExtendedType=function(){return this.universe().type(this._declaresType)},e.prototype.setInlinedTemplates=function(e){return this._isTemplate=e,this},e.prototype.getRuntimeExtenders=function(){return this._runtimeExtenders},e.prototype.isInlinedTemplates=function(){return this._isTemplate},e.prototype.setExtendedTypeName=function(t){this._declaresType=t;var n=this.universe().type(t);if(n instanceof h){var r=n;r.getAdapter(e)._runtimeExtenders.push(this._type)}},e.prototype.getKeyProp=function(){for(var e=this._type.allProperties(),t=0;t<e.length;t++)if(e[t].getAdapter(N).isKey())return e[t];return null},e.prototype.withActuallyExports=function(e){this._actuallyExports=e},e.prototype.withConvertsToGlobal=function(e){this._convertsToGlobal=e},e.prototype.getConvertsToGlobal=function(){return this._convertsToGlobal},e.prototype.getActuallyExports=function(){return this._actuallyExports},e.prototype.isUserDefined=function(){return this._type instanceof h?this._type.isUserDefined():this._type instanceof p?this._type.isUserDefined():!1},e.prototype.withContextRequirement=function(e,t){this._contextRequirements.push({name:e,value:t})},e.prototype.getContextRequirements=function(){return this._contextRequirements},e.prototype.findMembersDeterminer=function(){for(var e=this._type.allProperties(),t=0;t<e.length;t++)if(e[t].isThisPropertyDeclaresTypeFields())return e[t];return null},e.prototype.getDeclaringNode=function(){if(this._node)return this._node;if(this._type){var e=this._type.getExtra(t.SOURCE_EXTRA);return e?e instanceof f||e.getSource&&"function"==typeof e.getSource?e.getSource():e:null}return null},e.prototype.registerSupertypes=function(e){var t=this,n=this._type.universe();e.forEach(function(e){var r=n.type(e);r&&t._type.addSuperType(r)})},e.prototype.registerPossibleInterfaces=function(e){for(var t=this._type.universe(),n=0,r=e;n<r.length;n++){var i=r[n],a=t.type(i);if(!a)return;this._possibleInterfaces.push(a)}},e.prototype.possibleInterfaces=function(){return this._possibleInterfaces},e}();t.RAMLService=_;var M={},w=n(57),R=w.universeDumps,I=n(58),C=n(59);t.universesInfo=C,t.getUniverse=function(){var e=function(e){if(M[e])return M[e];var t=R[e],n=I.toDefSystem(t,"RAML08"==e?C.Universe08:C.Universe10);return n&&(n.setUniverseVersion(e),M[e]=n),n};return e.availableUniverses=function(){return Object.keys(R)},e}()},function(e,t,n){function r(){this.protocol=null,this.slashes=null,this.auth=null,this.host=null,this.port=null,this.hostname=null,this.hash=null,this.search=null,this.query=null,this.pathname=null,this.path=null,this.href=null}function i(e,t,n){if(e&&l(e)&&e instanceof r)return e;var i=new r;return i.parse(e,t,n),i}function a(e){return u(e)&&(e=i(e)),e instanceof r?e.format():r.prototype.format.call(e)}function o(e,t){return i(e,!1,!0).resolve(t)}function s(e,t){return e?i(e,!1,!0).resolveObject(t):t}function u(e){return"string"==typeof e}function l(e){return"object"==typeof e&&null!==e}function p(e){return null===e}function c(e){return null==e}var f=n(84);t.parse=i,t.resolve=o,t.resolveObject=s,t.format=a,t.Url=r;var m=/^([a-z0-9.+-]+:)/i,d=/:[0-9]*$/,h=["<",">",'"',"`"," ","\r","\n","	"],y=["{","}","|","\\","^","`"].concat(h),v=["'"].concat(y),g=["%","/","?",";","#"].concat(v),A=["/","?","#"],S=255,T=/^[a-z0-9A-Z_-]{0,63}$/,E=/^([a-z0-9A-Z_-]{0,63})(.*)$/,b={javascript:!0,"javascript:":!0},N={javascript:!0,"javascript:":!0},_={http:!0,https:!0,ftp:!0,gopher:!0,file:!0,"http:":!0,"https:":!0,"ftp:":!0,"gopher:":!0,"file:":!0},M=n(82);r.prototype.parse=function(e,t,n){if(!u(e))throw new TypeError("Parameter 'url' must be a string, not "+typeof e);var r=e;r=r.trim();var i=m.exec(r);if(i){i=i[0];var a=i.toLowerCase();this.protocol=a,r=r.substr(i.length)}if(n||i||r.match(/^\/\/[^@\/]+@[^@\/]+/)){var o="//"===r.substr(0,2);!o||i&&N[i]||(r=r.substr(2),this.slashes=!0)}if(!N[i]&&(o||i&&!_[i])){for(var s=-1,l=0;l<A.length;l++){var p=r.indexOf(A[l]);-1!==p&&(-1===s||s>p)&&(s=p)}var c,d;d=-1===s?r.lastIndexOf("@"):r.lastIndexOf("@",s),-1!==d&&(c=r.slice(0,d),r=r.slice(d+1),this.auth=decodeURIComponent(c)),s=-1;for(var l=0;l<g.length;l++){var p=r.indexOf(g[l]);-1!==p&&(-1===s||s>p)&&(s=p)}-1===s&&(s=r.length),this.host=r.slice(0,s),r=r.slice(s),this.parseHost(),this.hostname=this.hostname||"";var h="["===this.hostname[0]&&"]"===this.hostname[this.hostname.length-1];if(!h)for(var y=this.hostname.split(/\./),l=0,w=y.length;w>l;l++){var R=y[l];if(R&&!R.match(T)){for(var I="",C=0,L=R.length;L>C;C++)I+=R.charCodeAt(C)>127?"x":R[C];if(!I.match(T)){var P=y.slice(0,l),O=y.slice(l+1),D=R.match(E);D&&(P.push(D[1]),O.unshift(D[2])),O.length&&(r="/"+O.join(".")+r),this.hostname=P.join(".");break}}}if(this.hostname.length>S?this.hostname="":this.hostname=this.hostname.toLowerCase(),!h){for(var x=this.hostname.split("."),U=[],l=0;l<x.length;++l){var k=x[l];U.push(k.match(/[^A-Za-z0-9_-]/)?"xn--"+f.encode(k):k)}this.hostname=U.join(".")}var F=this.port?":"+this.port:"",B=this.hostname||"";this.host=B+F,this.href+=this.host,h&&(this.hostname=this.hostname.substr(1,this.hostname.length-2),"/"!==r[0]&&(r="/"+r))}if(!b[a])for(var l=0,w=v.length;w>l;l++){var K=v[l],V=encodeURIComponent(K);V===K&&(V=escape(K)),r=r.split(K).join(V)}var j=r.indexOf("#");-1!==j&&(this.hash=r.substr(j),r=r.slice(0,j));var W=r.indexOf("?");if(-1!==W?(this.search=r.substr(W),this.query=r.substr(W+1),t&&(this.query=M.parse(this.query)),r=r.slice(0,W)):t&&(this.search="",this.query={}),r&&(this.pathname=r),_[a]&&this.hostname&&!this.pathname&&(this.pathname="/"),this.pathname||this.search){var F=this.pathname||"",k=this.search||"";this.path=F+k}return this.href=this.format(),this},r.prototype.format=function(){var e=this.auth||"";e&&(e=encodeURIComponent(e),e=e.replace(/%3A/i,":"),e+="@");var t=this.protocol||"",n=this.pathname||"",r=this.hash||"",i=!1,a="";this.host?i=e+this.host:this.hostname&&(i=e+(-1===this.hostname.indexOf(":")?this.hostname:"["+this.hostname+"]"),this.port&&(i+=":"+this.port)),this.query&&l(this.query)&&Object.keys(this.query).length&&(a=M.stringify(this.query));var o=this.search||a&&"?"+a||"";return t&&":"!==t.substr(-1)&&(t+=":"),this.slashes||(!t||_[t])&&i!==!1?(i="//"+(i||""),n&&"/"!==n.charAt(0)&&(n="/"+n)):i||(i=""),r&&"#"!==r.charAt(0)&&(r="#"+r),o&&"?"!==o.charAt(0)&&(o="?"+o),n=n.replace(/[?#]/g,function(e){return encodeURIComponent(e)}),o=o.replace("#","%23"),t+i+n+o+r},r.prototype.resolve=function(e){return this.resolveObject(i(e,!1,!0)).format()},r.prototype.resolveObject=function(e){if(u(e)){var t=new r;t.parse(e,!1,!0),e=t}var n=new r;if(Object.keys(this).forEach(function(e){n[e]=this[e]},this),n.hash=e.hash,""===e.href)return n.href=n.format(),n;if(e.slashes&&!e.protocol)return Object.keys(e).forEach(function(t){"protocol"!==t&&(n[t]=e[t])}),_[n.protocol]&&n.hostname&&!n.pathname&&(n.path=n.pathname="/"),n.href=n.format(),n;if(e.protocol&&e.protocol!==n.protocol){if(!_[e.protocol])return Object.keys(e).forEach(function(t){n[t]=e[t]}),n.href=n.format(),n;if(n.protocol=e.protocol,e.host||N[e.protocol])n.pathname=e.pathname;else{for(var i=(e.pathname||"").split("/");i.length&&!(e.host=i.shift()););e.host||(e.host=""),e.hostname||(e.hostname=""),""!==i[0]&&i.unshift(""),i.length<2&&i.unshift(""),n.pathname=i.join("/")}if(n.search=e.search,n.query=e.query,n.host=e.host||"",n.auth=e.auth,n.hostname=e.hostname||e.host,n.port=e.port,n.pathname||n.search){var a=n.pathname||"",o=n.search||"";n.path=a+o}return n.slashes=n.slashes||e.slashes,n.href=n.format(),n}var s=n.pathname&&"/"===n.pathname.charAt(0),l=e.host||e.pathname&&"/"===e.pathname.charAt(0),f=l||s||n.host&&e.pathname,m=f,d=n.pathname&&n.pathname.split("/")||[],i=e.pathname&&e.pathname.split("/")||[],h=n.protocol&&!_[n.protocol];if(h&&(n.hostname="",n.port=null,n.host&&(""===d[0]?d[0]=n.host:d.unshift(n.host)),n.host="",e.protocol&&(e.hostname=null,e.port=null,e.host&&(""===i[0]?i[0]=e.host:i.unshift(e.host)),e.host=null),f=f&&(""===i[0]||""===d[0])),l)n.host=e.host||""===e.host?e.host:n.host,n.hostname=e.hostname||""===e.hostname?e.hostname:n.hostname,n.search=e.search,n.query=e.query,d=i;else if(i.length)d||(d=[]),d.pop(),d=d.concat(i),n.search=e.search,n.query=e.query;else if(!c(e.search)){if(h){n.hostname=n.host=d.shift();var y=n.host&&n.host.indexOf("@")>0?n.host.split("@"):!1;y&&(n.auth=y.shift(),n.host=n.hostname=y.shift())}return n.search=e.search,n.query=e.query,p(n.pathname)&&p(n.search)||(n.path=(n.pathname?n.pathname:"")+(n.search?n.search:"")),n.href=n.format(),n}if(!d.length)return n.pathname=null,n.search?n.path="/"+n.search:n.path=null,n.href=n.format(),n;for(var v=d.slice(-1)[0],g=(n.host||e.host)&&("."===v||".."===v)||""===v,A=0,S=d.length;S>=0;S--)v=d[S],"."==v?d.splice(S,1):".."===v?(d.splice(S,1),A++):A&&(d.splice(S,1),A--);if(!f&&!m)for(;A--;A)d.unshift("..");!f||""===d[0]||d[0]&&"/"===d[0].charAt(0)||d.unshift(""),g&&"/"!==d.join("/").substr(-1)&&d.push("");var T=""===d[0]||d[0]&&"/"===d[0].charAt(0);if(h){n.hostname=n.host=T?"":d.length?d.shift():"";var y=n.host&&n.host.indexOf("@")>0?n.host.split("@"):!1;y&&(n.auth=y.shift(),n.host=n.hostname=y.shift())}return f=f||n.host&&d.length,f&&!T&&d.unshift(""),d.length?n.pathname=d.join("/"):(n.pathname=null,n.path=null),p(n.pathname)&&p(n.search)||(n.path=(n.pathname?n.pathname:"")+(n.search?n.search:"")),n.auth=e.auth||n.auth,n.slashes=n.slashes||e.slashes,n.href=n.format(),n},r.prototype.parseHost=function(){var e=this.host,t=d.exec(e);t&&(t=t[0],":"!==t&&(this.port=t.substr(1)),e=e.substr(0,e.length-t.length)),e&&(this.hostname=e)}},function(e,t,n){},function(e,t,n){"use strict";function r(e){return e&&e.indexOf("\n")>=0}function i(e){return r(e)&&e.length>2&&"|"==e[0]&&("\n"==e[1]||"\r"==e[1]||"\n"==e[2])}function a(e,t){var n="";if(r(e)){n+="|\n";for(var i=m(e),a=0;a<i.length;a++)n+=u(t,i[a])}else n+=e;return n}function o(e){if(!i(e))return e;for(var t=null,n=m(e),r=1;r<n.length;r++){var a=n[r],o=a.substring(2);t?t+=o:t=o}return t}function s(e){if(!e)return e;for(var t=0;t<e.length;){var n=e[t];if("\r"!=n&&"\n"!=n&&" "!=n&&"	"!=n)break;t++}return e.substring(t,e.length)}function u(e,t){void 0===t&&(t="");for(var n="",r=0;e>r;r++)n+="  ";return n+t}function l(e,t){void 0===t&&(t=""),console.log(u(e,t))}function p(e,t){void 0===t&&(t=null);for(var n="",r=0;r<e.length;r++){var i=e[r];"\r"==i&&(i=null==t?"\\r":t),"\n"==i&&(i=null==t?"\\n":t),n+=i}return n}function c(e){for(var t=e.length;t>0;){var n=e[t-1];if(" "!=n&&"	"!=n&&"\r"!=n&&"\n"!=n)break;t--}return e.substring(0,t)}function f(e){return s(c(e))}function m(e){var t=e.match(/^.*((\r\n|\n|\r)|$)/gm);return t}function d(e,t){if(!e||!t||e.length<t.length)return!1;for(var n=0;n<t.length;n++)if(e[n]!=t[n])return!1;return!0}function h(e,t){if(!e||!t||e.length<t.length)return!1;for(var n=0;n<t.length;n++)if(e[e.length-1-n]!=t[t.length-1-n])return!1;return!0}function y(e){return e.charAt(0).toUpperCase()+e.slice(1)}t.isMultiLine=r,t.isMultiLineValue=i,t.makeMutiLine=a,t.fromMutiLine=o,t.trimStart=s,t.indent=u,t.print=l,t.replaceNewlines=p,t.trimEnd=c,t.trim=f,t.splitOnLines=m,t.startsWith=d,t.endsWith=h,t.capitalize=y;var v=function(){function e(e,t,n){this.contents=e,this.start=t,this.end=n}return e.prototype.text=function(){return this.contents.substring(this.start,this.end)},e.prototype.startpos=function(){return this.start},e.prototype.endpos=function(){return this.end},e.prototype.len=function(){return this.end-this.start},e.prototype.unitText=function(){return this.contents},e.prototype.withStart=function(t){return new e(this.contents,t,this.end)},e.prototype.withEnd=function(t){return new e(this.contents,this.start,t)},e.prototype.sub=function(e,t){return this.contents.substring(e,t)},e.prototype.trimStart=function(){for(var t=this.start;t<this.contents.length-1;){var n=this.contents[t];if(" "!=n&&"	"!=n)break;t++}return new e(this.contents,t,this.end)},e.prototype.trimEnd=function(){for(var t=this.end;t>0;){var n=this.contents[t-1];if(" "!=n&&"	"!=n)break;t--}return new e(this.contents,this.start,t)},e.prototype.extendToStartOfLine=function(){for(var t=this.start;t>0;){var n=this.contents[t-1];if("\r"==n||"\n"==n)break;t--}return new e(this.contents,t,this.end)},e.prototype.extendAnyUntilNewLines=function(){var t=this.end;if(t>0){var n=this.contents[t-1];if("\n"==n)return this}for(;t<this.contents.length-1;){var r=this.contents[t];if("\r"==r||"\n"==r)break;t++}return new e(this.contents,this.start,t)},e.prototype.extendSpacesUntilNewLines=function(){var t=this.end;if(t>0){var n=this.contents[t-1];if("\n"==n)return this}for(;t<this.contents.length-1;){var r=this.contents[t];if(" "!=r||"\r"==r||"\n"==r)break;t++}return new e(this.contents,this.start,t)},e.prototype.extendSpaces=function(){for(var t=this.end;t<this.contents.length-1;){var n=this.contents[t];if(" "!=n)break;t++}return new e(this.contents,this.start,t)},e.prototype.extendSpacesBack=function(){for(var t=this.start;t>0;){var n=this.contents[t-1];if(" "!=n)break;t--}return new e(this.contents,t,this.end)},e.prototype.extendCharIfAny=function(t){var n=this.end;return n<this.contents.length-1&&this.contents[n]==t&&n++,new e(this.contents,this.start,n)},e.prototype.extendCharIfAnyBack=function(t){var n=this.start;return n>0&&this.contents[n-1]==t&&n--,new e(this.contents,n,this.end)},e.prototype.extendToNewlines=function(){var t=this.end;if(t>0){var n=this.contents[t-1];if("\n"==n)return this}for(;t<this.contents.length-1;){var r=this.contents[t];if("\r"!=r&&"\n"!=r)break;t++}return new e(this.contents,this.start,t)},e.prototype.extendUntilNewlinesBack=function(){for(var t=this.start;t>0;){var n=this.contents[t-1];if("\r"==n||"\n"==n)break;t--}return new e(this.contents,t,this.end)},e.prototype.reduceNewlinesEnd=function(){for(var t=this.end;t>this.start;){var n=this.contents[t-1];if("\r"!=n&&"\n"!=n)break;t--}return new e(this.contents,this.start,t)},e.prototype.reduceSpaces=function(){for(var t=this.end;t>this.start;){var n=this.contents[t-1];if(" "!=n)break;t--}return new e(this.contents,this.start,t)},e.prototype.replace=function(e){return this.sub(0,this.start)+e+this.sub(this.end,this.unitText().length)},e.prototype.remove=function(){return this.sub(0,this.start)+this.sub(this.end,this.unitText().length)},e}();t.TextRange=v},function(e,t,n){"use strict";var r=this&&this.__extends||function(e,t){function n(){this.constructor=e}for(var r in t)t.hasOwnProperty(r)&&(e[r]=t[r]);e.prototype=null===t?Object.create(t):(n.prototype=t.prototype,new n)},i=n(75),a=n(53),o=n(66),s=n(26),u=n(33),l=n(17),p=n(37),c=n(14),f=n(64),m=function(){function e(e,t,n){this._parent=e,this._transformer=t,this.ramlVersion=n}return e.isInstance=function(t){return null!=t&&t.getClassIdentifier&&"function"==typeof t.getClassIdentifier&&f.contains(t.getClassIdentifier(),e.CLASS_IDENTIFIER)},e.prototype.getClassIdentifier=function(){var t=[];return t.concat(e.CLASS_IDENTIFIER)},e.prototype.hasInnerIncludeError=function(){return this._originalNode.hasInnerIncludeError()},e.prototype.keyKind=function(){return this._originalNode.keyKind()},e.prototype.primaryNode=function(){return null},e.prototype.isAnnotatedScalar=function(){return this._originalNode.isAnnotatedScalar()},e.prototype.actual=function(){return this._originalNode?this._originalNode.actual():this},e.prototype.transformer=function(){return this._transformer},e.prototype.originalNode=function(){return this._originalNode},e.prototype.start=function(){return this._originalNode.start()},e.prototype.end=function(){return this._originalNode.end()},e.prototype.value=function(e){throw new Error("The method must be overridden")},e.prototype.includeErrors=function(){return this._originalNode.includeErrors()},e.prototype.includePath=function(){return this._originalNode.includePath()},e.prototype.includeReference=function(){return this._originalNode.includeReference()},e.prototype.setKeyOverride=function(e){this._keyOverride=e},e.prototype.setValueOverride=function(e){this._valueOverride=e},e.prototype.key=function(e){return void 0===e&&(e=!1),this._keyOverride?this._keyOverride:this._originalNode.key(e)},e.prototype.optional=function(){return this.originalNode().optional()},e.prototype.children=function(){throw new Error("The method must be overridden")},e.prototype.parent=function(){return this._parent},e.prototype.unit=function(){return this._originalNode.unit()},e.prototype.includeBaseUnit=function(){return this._originalNode.unit()},e.prototype.anchorId=function(){return this._originalNode.anchorId()},e.prototype.errors=function(){return this._originalNode.errors()},e.prototype.anchoredFrom=function(){return this._originalNode.anchoredFrom()},e.prototype.includedFrom=function(){return this._originalNode.includedFrom()},e.prototype.visit=function(e){e(this)&&this.children().forEach(function(t){return t.visit(e)})},e.prototype.addChild=function(e){},e.prototype.execute=function(e){},e.prototype.dump=function(){return null},e.prototype.dumpToObject=function(){var e=a.serialize2(this,!1);if(this.kind()==i.Kind.MAPPING){var t={};return t[this.key(!0)]=e,t}return e},e.prototype.keyStart=function(){return this._originalNode.keyStart()},e.prototype.keyEnd=function(){return this._originalNode.keyEnd()},e.prototype.valueStart=function(){return this._originalNode.valueStart()},e.prototype.valueEnd=function(){return this._originalNode.valueEnd()},e.prototype.isValueLocal=function(){return this._originalNode.isValueLocal()},e.prototype.kind=function(){return this._originalNode.kind()},e.prototype.valueKind=function(){return this._originalNode.valueKind()},e.prototype.anchorValueKind=function(){return this._originalNode.anchorValueKind()},e.prototype.show=function(e){this._originalNode.show(e)},e.prototype.setHighLevelParseResult=function(e){this._highLevelParseResult=e},e.prototype.highLevelParseResult=function(){return this._highLevelParseResult},e.prototype.setHighLevelNode=function(e){this._highLevelNode=e},e.prototype.highLevelNode=function(){return this._highLevelNode?this._highLevelNode:this._originalNode.highLevelNode()},e.prototype.text=function(e){throw new Error("not implemented")},e.prototype.copy=function(){throw new Error("not implemented")},e.prototype.markup=function(e){throw new Error("not implemented")},e.prototype.nodeDefinition=function(){return s.getDefinitionForLowLevelNode(this)},e.prototype.includesContents=function(){return this._originalNode.includesContents()},e.CLASS_IDENTIFIER="LowLevelASTProxy.LowLevelProxyNode",e}();t.LowLevelProxyNode=m;var d=function(e){function t(t,n,r,i,a){void 0===a&&(a=!0),e.call(this,n,r,i),this.isPrimary=a,this._adoptedNodes=[],this._preserveAnnotations=!1;var o=this.parent()?this.parent().originalNode():null;h.isInstance(t)?this._originalNode=t:this._originalNode=new h(t,o,r,this.ramlVersion),this._adoptedNodes.push(this._originalNode)}return r(t,e),t.isInstance=function(e){return null!=e&&e.getClassIdentifier&&"function"==typeof e.getClassIdentifier&&f.contains(e.getClassIdentifier(),t.CLASS_IDENTIFIER_LowLevelCompositeNode)},t.prototype.getClassIdentifier=function(){var n=e.prototype.getClassIdentifier.call(this);return n.concat(t.CLASS_IDENTIFIER_LowLevelCompositeNode)},t.prototype.adoptedNodes=function(){return this._adoptedNodes},t.prototype.primaryNode=function(){return this.isPrimary?this._originalNode:null},t.prototype.parent=function(){return this._parent},t.prototype.adopt=function(e,t){t||(t=this._transformer);var n=this.parent()?this.parent().originalNode():null,r=new h(e,n,t,this.ramlVersion);this._adoptedNodes.push(r),this._children&&this._children.forEach(function(e){return e._parent=null}),this._children=null,this.highLevelNode()&&this.highLevelNode().resetChildren()},t.prototype.value=function(e){if(this._valueOverride)return this._valueOverride;var t,n=this._adoptedNodes.filter(function(e){return null!=e.value()});return t=n.length>0?n[0].value(e):this._originalNode.value(e),h.isInstance(t)&&(this._valueOverride=t),t},t.prototype.children=function(){var e=this;if(this._children)return this._children;for(var n=[],r=!1,a=!1,o=0,s=this._adoptedNodes;o<s.length;o++){var u=s[o],l=u.children();l&&l.length>0&&(a=!0,l[0].key()&&this.originalNode().valueKind()!=i.Kind.SEQ&&(r=!0))}if(r)n=this.collectChildrenWithKeys();else if(a){n=this.collectChildrenWithKeys();var p={};this._adoptedNodes.forEach(function(r){return r.children().filter(function(e){return!e.key()}).forEach(function(i){var a=r==e.primaryNode(),o=e.buildKey(i);if(a||!p[o]){p[o]=!0;var s=r.transformer()?r.transformer():e.transformer(),u=h.isInstance(i)?i.originalNode():i;n.push(new t(u,e,s,e.ramlVersion,a))}})})}else n=[];return this._children=n,n},t.prototype.buildKey=function(e){var t=a.serialize(e),n=this.nodeDefinition();if(n&&(n.key()==l.Universe08.TraitRef||n.key()==l.Universe08.ResourceTypeRef||n.key()==l.Universe10.TraitRef||n.key()==l.Universe10.ResourceTypeRef)&&t&&"object"==typeof t){var r=Object.keys(t);r.length>0&&(t=r[0])}return null==t?"":o(t)},t.prototype.collectChildrenWithKeys=function(){for(var e=this,n=[],r={},i=0,a=this._adoptedNodes;i<a.length;i++)for(var o=a[i],s=o==this.primaryNode(),c=0,f=o.children();c<f.length;c++){var m=f[c],d=m.originalNode().key();if(d&&o.transformer()){var h=null!=d&&(this._preserveAnnotations||this.isResource())&&u.stringStartsWith(d,"(")&&u.stringEndsWith(d,")");h||(d=o.transformer().transform(d).value)}if(!this.skipKey(d,s)&&d){var y=r.hasOwnProperty(d)&&r[d];y||(y=[],r[d]=y),y.push({node:m.originalNode(),transformer:o.transformer(),isPrimary:s})}}var v=this.unit().highLevel().root().definition().universe().version(),g=this.key()&&"/"==this.key()[0],A=p.getUniverse("RAML10").type(l.Universe10.Method.name),S=A.property(l.Universe10.Method.properties.method.name).enumOptions();return Object.keys(r).forEach(function(i){var a=r[i],o=!0,s=!1,u=S.indexOf(i)>=0;if(a.forEach(function(e){var t=e.node.optional()&&("RAML10"!=v||g&&u);o=o&&t,s=s||e.isPrimary}),s){var l=[];a.filter(function(e){return e.isPrimary}).forEach(function(n){var r=n.transformer?n.transformer:e.transformer();l.push(new t(n.node,e,r,e.ramlVersion,!0))});var p=l[0];a.filter(function(e){return!e.isPrimary}).forEach(function(e){p.adopt(e.node,e.transformer)}),l.forEach(function(e){return n.push(e)})}else if(!o){for(var c=a[0].transformer?a[0].transformer:e.transformer(),p=new t(a[0].node,e,c,e.ramlVersion,!1),f=1;f<a.length;f++)p.adopt(a[f].node,a[f].transformer);n.push(p)}}),n},t.prototype.isResource=function(){return this.highLevelNode()&&c.isResourceType(this.highLevelNode().definition())},t.prototype.skipKey=function(e,t){if(t)return!1;if("RAML08"!=this.ramlVersion)return!1;l.Universe08.Method,l.Universe08.Resource;return!1},t.prototype.valueKind=function(){if(this._originalNode.kind()!=i.Kind.MAPPING)return null;for(var e=0;e<this._adoptedNodes.length;e++){var t=this._adoptedNodes[e],n=t.originalNode().actual();if(n&&null!=n.value)return t.valueKind()}return null},t.prototype.includePath=function(){for(var e=0;e<this._adoptedNodes.length;e++){var t=this._adoptedNodes[e],n=t.includePath();if(null!=n)return n}return null},t.prototype.includeBaseUnit=function(){for(var t=0;t<this._adoptedNodes.length;t++){var n=this._adoptedNodes[t],r=n.includePath();if(null!=r)return n.unit()}return e.prototype.includeBaseUnit.call(this)},t.prototype.includeReference=function(){for(var e=0;e<this._adoptedNodes.length;e++){var t=this._adoptedNodes[e];if(null!=t.value())return t.includeReference()}return null},t.prototype.optional=function(){return f.all(this._adoptedNodes,function(e){return e.optional()})},t.prototype.replaceChild=function(e,n,r,i){void 0===r&&(r=!1),void 0===i&&(i=null),this._children||(this._children=[]);var a=new t(n,this,null,this.ramlVersion);if(null==e)return this._children.push(a),a;var o=this._children.indexOf(e);return o>=0?this._children[o]=a:this._children.push(a),a},t.prototype.removeChild=function(e){if(this._children&&null!=e){var t=this._children.indexOf(e);if(t>=0){for(var n=t;n<this._children.length-1;n++)this._children[n]=this._children[n+1];this._children.pop()}}},t.prototype.setChildren=function(e){var n=this;return null==e?void(this._children=null):void(this._children=e.map(function(e){return t.isInstance(e)?e:new t(e,n,null,n.ramlVersion)}))},t.prototype.preserveAnnotations=function(){if(!this._preserveAnnotations){if(void 0===this.isInsideResource&&(this.isInsideResource=!1,!this.isResource()))for(var e=this._parent;e;){if(e.isResource()){this.isInsideResource=!0;break}e=e.parent()}this.isInsideResource&&(this._preserveAnnotations=!0,this._children=null)}},t.prototype.filterChildren=function(){this.children();var e={},t=[];this._children.forEach(function(n){if(null!=n.key())return void t.push(n);var r=JSON.stringify(a.serialize(n));e[r]||(e[r]=!0,t.push(n))}),this._children=t},t.CLASS_IDENTIFIER_LowLevelCompositeNode="LowLevelASTProxy.LowLevelCompositeNode",t}(m);t.LowLevelCompositeNode=d;var h=function(e){function t(t,n,r,i){e.call(this,n,r,i),this._originalNode=t}return r(t,e),t.isInstance=function(e){return null!=e&&e.getClassIdentifier&&"function"==typeof e.getClassIdentifier&&f.contains(e.getClassIdentifier(),t.CLASS_IDENTIFIER_LowLevelValueTransformingNode)},t.prototype.getClassIdentifier=function(){var n=e.prototype.getClassIdentifier.call(this);return n.concat(t.CLASS_IDENTIFIER_LowLevelValueTransformingNode)},t.prototype.value=function(e){var n=this.originalNode().value(e),r=this.transformer();if(r){var i=r.transform(n,e);n=i.value}return n&&"object"==typeof n?new t(n,this._parent,this._transformer,this.ramlVersion):n},t.prototype.children=function(){var e=this,n=null,r=this.originalNode();if(null!=this._transformer){var i=this._transformer.children(r);null!=i&&(n=i)}return null==n&&(n=r.children()),n.map(function(n){return new t(n,e,e._transformer,e.ramlVersion)})},t.prototype.valueKind=function(){var t=this._transformer&&this._transformer.valueKind(this.originalNode());return null!=t?t:e.prototype.valueKind.call(this)},t.prototype.parent=function(){return this._parent},t.prototype.key=function(t){void 0===t&&(t=!1);var n=e.prototype.key.call(this,t);return null!=this.transformer()?this.transformer().transform(n).value:n},t.CLASS_IDENTIFIER_LowLevelValueTransformingNode="LowLevelASTProxy.LowLevelValueTransformingNode",t}(m);t.LowLevelValueTransformingNode=h},function(e,t,n){"use strict";function r(e){for(var t=-1,n=e.lowLevel().children(),r=0;r<n.length;r++){var i=n[r];if(i.isMapping()){var a=i.asMapping().key.value,o=e.definition().property(a);o&&(o.isFromParentValue()||o.range().hasValueTypeInHierarchy())&&(t=r)}}return t}function i(e,t,n,r){var i=null,a=n&&n.getAdapter(M.RAMLPropertyService).isEmbedMap();if(a&&T.find(e.lowLevel().children(),function(e){return e.key()==n.nameId()})&&(a=!1),r||a){var o=y(e);i=o?o:g.InsertionPoint.atStart()}return i}function a(e,t){e.isStub()||e.clearChildrenCache();var n=e.children(),r=t.property()&&t.property().getAdapter(M.RAMLPropertyService).isEmbedMap();r&&T.find(e.lowLevel().children(),function(e){return e.key()==t.property().nameId()})&&(r=!1);if(!t.isAttr()&&!r||_.isMethodType(e.definition())&&t.property&&_.isIsProperty(t.property())){var i=t.property().nameId(),a=e.definition(),o=(a.allProperties(),e.lowLevel().children());if(_.isTraitsProperty(t.property()))return T.find(o,function(e){return e.isMapping()?void(e.asMapping().key.value===t.property().nameId()):!1});var s=a.propertyIndex(i);if(0>s)return null;for(var u=0;u<o.length;u++){var l=o[u];if(l.isMapping()){var p=l.asMapping().key.value,c=a.propertyIndex(p);if(c>s){var f=u-1;return 0>f?null:(console.log("insert to node: "+f),o[f])}}}return null}for(var m=null,u=0;u<n.length&&n[u].isAttr();u++)m=n[u].lowLevel();return null==m&&(m=e.lowLevel()),m}function o(e,t){if(e.isStub()){if(b.ASTNodeImpl.isInstance(t)){var n=t;if(n.isInEdit)return}if(!e._children)return;return void(e._children=e._children.filter(function(e){return e!=t}))}var r=new S.CompositeCommand;if(b.ASTNodeImpl.isInstance(t)){var i=t;i.property().getAdapter(M.RAMLPropertyService).isMerged()?r.commands.push(S.removeNode(e.lowLevel(),i.lowLevel())):1==e.elementsOfKind(i.property().nameId()).length?r.commands.push(S.removeNode(e.lowLevel(),i.lowLevel().parent().parent())):r.commands.push(S.removeNode(e.lowLevel(),i.lowLevel()))}else r.commands.push(S.removeNode(e.lowLevel(),t.lowLevel()));e.lowLevel().execute(r)}function s(e){var t=(e.lowLevel().root(),new S.CompositeCommand),n=g.createMap([]);t.commands.push(S.initRamlFile(e.lowLevel(),n)),e.lowLevel().execute(t);var r=e.root();r._node=n,r.clearChildrenCache()}function u(e,t){if(t!=e.value()){var n=new S.CompositeCommand;if("string"==typeof t){var r=t;e.property().isFromParentKey()||e.property().isAnnotation()?(e.property().isAnnotation()&&(r="("+r+")"),n.commands.push(S.setKey(e.lowLevel(),r))):r&&0!=r.length||e.isEmbedded()?(r||(r=""),n.commands.push(S.setAttr(e.lowLevel(),r))):(n.commands.push(S.removeNode(e.lowLevel().parent(),e.lowLevel())),e.parent().clearChildrenCache())}else{if(e.property().isFromParentKey())throw new Error("couldn't set structured value to a key: "+e.property().nameId());var i=t;n.commands.push(S.setAttrStructured(e.lowLevel(),i))}e.lowLevel().execute(n)}}function l(e,t){var n=g.createScalar(t),r=e.lowLevel();r.isScalar()?r=r.parent():r.isMapping();var i=new S.CompositeCommand;i.commands.push(S.insertNode(r,n,null,!0)),e.lowLevel().execute(i),e.parent().clearChildrenCache();
}function p(e,t){var n=e.lowLevel();if(n.isScalar())n=n.parent();else if(n.isMapping()){e.lowLevel()}var r=new S.CompositeCommand;r.commands.push(S.insertNode(n,t.lowLevel(),null,!0)),e.lowLevel().execute(r),e.parent().clearChildrenCache()}function c(e){var t=e.lowLevel().parent();if(!e.property().isMultiValue()&&e.isEmbedded())e.setValue("");else{var n=new S.CompositeCommand;n.commands.push(S.removeNode(t,e.lowLevel())),e.lowLevel().execute(n),e.parent().clearChildrenCache()}}function f(e,t){if(!e.property().isMultiValue())throw new Error("setValue(string[]) only apply to multi-values properties");var n=e.parent();if(n&&d(n)){var r=new S.CompositeCommand;return r.commands.push(S.setAttr(n.lowLevel(),t[0])),void n.lowLevel().execute(r)}if(e.isEmpty());else{var i=(n.lowLevel(),n.attributes(e.name()));i.forEach(function(e){return e.remove()})}1==t.length&&e.property().isDescriminator()?n.attrOrCreate(e.name()).setValue(t[0]):t.forEach(function(t){return n.attrOrCreate(e.name()).addValue(t)})}function m(e,t){if(t!=e.name()){var n=new S.CompositeCommand;n.commands.push(S.setKey(e.lowLevel(),t)),e.lowLevel().execute(n)}}function d(e){return e.definition()&&e.definition().isAssignableFrom(N.Universe10.TypeDeclaration.name)&&e.lowLevel()&&e.lowLevel().valueKind()===E.Kind.SCALAR?!0:!1}function h(e,t,n){var a=g.createMapping(t,n);if(e.definition()&&e.definition().isAssignableFrom(N.Universe10.TypeDeclaration.name)&&e.lowLevel()&&(e.lowLevel().valueKind()===E.Kind.SCALAR||!e.lowLevel()._node.value)){var o=t,s=g.createMapping(o,e.lowLevel().value()),u=new S.CompositeCommand;u.commands.push(S.setAttr(e.lowLevel(),"")),e.lowLevel().execute(u),u=new S.CompositeCommand;var l=i(e,s,e.definition().property(o),!0);u.commands.push(S.insertNode(e.lowLevel(),s,l)),e.lowLevel().execute(u),e.resetChildren();var p=e.attr(o)&&e.attr(o).lowLevel();if(p)return u=new S.CompositeCommand,u.commands.push(S.setAttr(p,n)),p.execute(u),void e.clearChildrenCache()}if(e.isStub()){var c=r(e);e.lowLevel().addChild(a,c+1)}else{e.isEmptyRamlFile()&&e.initRamlFile();var u=new S.CompositeCommand,l=i(e,a,e.definition().property(t),!0);u.commands.push(S.insertNode(e.lowLevel(),a,l)),e.lowLevel().execute(u)}e.clearChildrenCache()}function y(e){var t=e.lowLevel().children(),n=r(e);return 0>n?null:t[n]}function v(e,t){!e.isStub()&&e.isEmptyRamlFile()&&e.initRamlFile();var n=t.lowLevel();if(e._children||(e._children=[]),!t.property()){var i=t,o=e.definition().allProperties(),s=null;if(o.forEach(function(e){var t=e.range();t==i.definition()&&(s=e);var n=T.find(i.definition().allSuperTypes(),function(e){return e==t});n&&(s=e)}),!s)throw new Error("Unable to find correct child");i.patchProp(s)}var u=a(e,t),l=new S.CompositeCommand,p=null;if(t.property().getAdapter(M.RAMLPropertyService).isMerged()||t.property().range().hasValueTypeInHierarchy())l.commands.push(S.insertNode(e.lowLevel(),t.lowLevel(),u)),p=e.lowLevel();else{var c=t.property().nameId(),f=e.lowLevel(),m=e.lowLevel().find(c);if(p=m,m){var d=null===m.value()&&m.key&&m.key()===N.Universe10.Api.properties.types.name,h=!d&&t.property().getAdapter(M.RAMLPropertyService).isEmbedMap();l.commands.push(S.insertNode(m,t.lowLevel(),u,h))}else{var y=null;if(t.property().getAdapter(M.RAMLPropertyService).isEmbedMap()){var v="RAML10"==e.definition().universe().version();y=n.isValueMap()&&v?g.createMapNode(c):g.createSeqNode(c),y.addChild(t.lowLevel())}else y=g.createNode(c),y.addChild(t.lowLevel());l.commands.push(S.insertNode(f,y,u)),p=f}}if(e.isStub()){var A=r(e);return 0>A?e._children.push(t):e._children.splice(A,0,t),void l.commands.forEach(function(e){return p.addChild(e.value)})}e.lowLevel().execute(l),e._children.push(t),t.setParent(e)}var g=n(26),A=n(37),S=n(10),T=n(64),E=n(75),b=n(16),N=n(17),_=n(14),M=A;t.removeNodeFrom=o,t.initEmptyRAMLFile=s,t.setValue=u,t.addStringValue=l,t.addStructuredValue=p,t.removeAttr=c,t.setValues=f,t.setKey=m,t.createAttr=h,t.addToNode=v},function(e,t,n){"use strict";function r(e,t){var n=e.root().definition().universe(),i=e.lowLevel().key();if(i&&T(i,t,null,!0,n),e.children().forEach(function(e){return r(e,t)}),y.ASTPropImpl.isInstance(e)){var a=e,o=a.value();if("string"==typeof o){var s=o;T(s,t,a,!1,n)}else e.lowLevel().visit(function(e){if(e.value()){var r=e.value()+"";T(r,t,a,!0,n)}return!0})}else if(y.BasicASTNode.isInstance(e)){var o=e.lowLevel().value();if("string"==typeof o){var s=o;T(s,t,null,!1,n)}else e.lowLevel().visit(function(e){if(e.value()){var r=e.value()+"";T(r,t,null,!0,n)}return!0})}}function i(e,t,n){void 0===n&&(n=[]),e.optional()&&(n=n.concat("/"));var r=e.value();if("string"==typeof r)for(var a=r,o=S(a),s=o.parameterUsages,u=0,l=s;u<l.length;u++){var p=l[u],c=t[p];null==c&&(c=[],t[p]=c),c.push(n)}else for(var f=0,m=e.children();f<m.length;f++){var d=m[f];i(d,t,n.concat(d.key()))}}function a(e,t){var n={},a={};r(t,n),i(t.lowLevel(),a);for(var o=0,s=Object.keys(a);o<s.length;o++){var u=s[o];a[u]=d.unique(a[u])}e.getAdapter(v.RAMLService).setInlinedTemplates(!0),Object.keys(n).forEach(function(r){var i=null;n[r].length>0&&(i=n[r][0].attr);var o=new f.UserDefinedProp(r,i);o.withDomain(e);var s=a[r];o.getAdapter(v.RAMLPropertyService).putMeta("templatePaths",s);var u;if("RAML10"==t.definition().universe().version()){var l=n[r].filter(function(e){return A.isStringTypeType(e.tp)}).length>0;u=l?h.Universe10.StringType.name:h.Universe10.AnyType.name}else u=h.Universe08.StringType.name;var p=d.unique(n[r].map(function(e){return e.tp})).filter(function(e){return e&&e.nameId()!=u});o.withRange(1==p.length?p[0]:t.definition().universe().type(u)),o.withRequired(!0),1==p.length&&"RAML10"==t.definition().universe().version()&&p[0].key()==h.Universe10.SchemaString&&o.getAdapter(v.RAMLPropertyService).setTypeExpression(!0),o.unmerge()});var l=new f.UserDefinedProp("____key",t);return l.withDomain(e),l.withKey(!0),l.withFromParentKey(!0),l.withRange(t.definition().universe().type(h.Universe08.StringType.name)),e}function o(e,t){"RAML08"==t.universe().version()&&e.getAdapter(v.RAMLService).withAllowAny();var n=t.property(t.getAdapter(v.RAMLService).getReferenceIs());return n&&n.range().properties().forEach(function(t){var n=new f.Property(t.nameId());n.unmerge(),n.withDomain(e),n.withRange(t.range()),n.withMultiValue(t.isMultiValue())}),e}function s(e){if(!e)return null;if(e.associatedType())return e.associatedType();var t=e.lowLevel().unit(),n=t?t.path():"";m.setPropertyConstructor(function(t){var n=null,r=e.elementsOfKind("properties").filter(function(e){return e.name()==t});r&&(n=r[0]);var i=new f.UserDefinedProp(t,n);return i.unmerge(),i});try{var r=e.definition();if(e.property()&&e.property().nameId()==h.Universe10.LibraryBase.properties.annotationTypes.name){var i=new E(e.name(),e.definition().universe(),e,n,""),s=u(e);i._superTypes.push(s),0==e.elementsOfKind(h.Universe10.ObjectTypeDeclaration.properties.properties.name).length&&i.getAdapter(v.RAMLService).withAllowAny();var l=r.getAdapter(v.RAMLService).getExtendedType();return l&&i._superTypes.push(l),i}var i=new f.UserDefinedClass(e.name(),e.definition().universe(),e,n,"");if(e.setAssociatedType(i),r.getAdapter(v.RAMLService).isInlinedTemplates())return a(i,e);if(r.getAdapter(v.RAMLService).getReferenceIs())return o(i,r);var p=u(e);p.getAdapter(v.RAMLService).setDeclaringNode(e),e.setAssociatedType(p)}finally{m.setPropertyConstructor(null)}return p}function u(e){return m.toNominal(e.parsedType(),function(t){var n=e.definition().universe().type(t);if(!n){new f.UserDefinedClass("",e.definition().universe(),e,"","")}return n})}function l(e){return function(t){var n=e.type(t);if(!n){new f.UserDefinedClass("",e,null,"","")}return n}}function p(e,t){var n=d.find(e.elementsOfKind("types"),function(e){return e.name()==t.name()});n&&m.setPropertyConstructor(function(e){var t=n.elementsOfKind("properties").filter(function(t){return t.name()==e}),r=null;if(t&&t.length>0)r=t[0];else{var t=n.elementsOfKind("facets").filter(function(t){return t.name()==e});t&&t.length>0&&(r=t[0])}var i=new f.UserDefinedProp(e,r);return i.unmerge(),i});var r=l(e.definition().universe());return m.toNominal(t,r)}var c=this&&this.__extends||function(e,t){function n(){this.constructor=e}for(var r in t)t.hasOwnProperty(r)&&(e[r]=t[r]);e.prototype=null===t?Object.create(t):(n.prototype=t.prototype,new n)},f=n(37),m=f.rt,d=n(64),h=n(17),y=n(16),v=f,g=n(30),A=n(14);m.setPropertyConstructor(function(e){var t=new f.Property(e);return t.unmerge(),t});var S=function(e){for(var t=[],n=0;;){var r=e.indexOf("<<",n);if(-1==r)break;var i=e.indexOf(">>",r),a=0==r&&i==e.length-2,o=e.substring(r+2,i);n=r+2;var s=o.indexOf("|");-1!=s&&(o=o.substring(0,s)),o=o.trim(),t.push(o)}return{parameterUsages:t,isFull:a}},T=function(e,t,n,r,i){var a=S(e),o=a.parameterUsages,s=a.isFull,u=n?n.property().range():null;n&&(n.property().nameId()==h.Universe10.TypeDeclaration.properties.type.name||n.property().nameId()==h.Universe10.TypeDeclaration.properties.schema.name)&&n.property().domain().key()==h.Universe10.TypeDeclaration&&(u=i.type(h.Universe10.SchemaString.name)),!s||r?u=i.type(h.Universe10.StringType.name):null==u&&"RAML10"==i.version()&&(u=i.type(h.Universe10.AnyType.name));for(var l=0,p=o;l<p.length;l++){var c=p[l];if(null==g.RESERVED_TEMPLATE_PARAMETERS[c]){var f=t[c];f?f.push({tp:u,attr:n}):t[c]=[{tp:u,attr:n}]}}},E=function(e){function t(){e.apply(this,arguments)}return c(t,e),t.prototype.allProperties=function(e){void 0===e&&(e={});var t=this.superTypes()[0].allProperties();if(1==t.length&&"annotations"==t[0].nameId()){var n=this.getAdapter(f.RAMLService).getDeclaringNode(),r=new f.UserDefinedProp("value",n);r.withDomain(this),r.withCanBeValue(),r.withRequired(!1);this.superTypes()[0];t=[],r.withRange(r.node().asElement().definition().universe().type("string")),t.push(r)}return t},t.prototype.isAnnotationType=function(){return!0},t}(f.UserDefinedClass);t.typeFromNode=s,t.convertType=p},function(e,t,n){"use strict";function r(e){return e.isBuiltIn()?s[e.nameId()]:null}function i(e,t){void 0===t&&(t=!0);var n=e.definition(),i=(n.nameId(),r(n));if(!i){for(var o=a(n),u=n.allSuperTypes().sort(function(e,t){return o[e.nameId()]-o[t.nameId()]}),l=null,p=0;p<u.length;p++){var c=u[p].nameId();if(i=r(u[p]),"DataElement"!=c){if("hl.BasicNode"!=c&&i)break}else l=c}i||(l=c)}return i||(i=s["hl.BasicNode"]),i(e,t)}function a(e,t,n){void 0===t&&(t={}),void 0===n&&(n={});var r=e.nameId();if(!n[r]){n[r]=!0;var i=null!=t[r]&&t[r]+1||0,o=e.superTypes();return o.forEach(function(e){var r=e.nameId(),o=t[r];(null==o||i>o)&&(t[r]=i,a(e,t,n))}),delete n[r],t}}var o=n(22);t.buildWrapperNode=i;var s={AbstractSecurityScheme:function(e,t){return new o.AbstractSecuritySchemeImpl(e,t)},Annotable:function(e,t){return new o.AnnotableImpl(e,t)},AnnotationRef:function(e){return new o.AnnotationRefImpl(e)},AnnotationTarget:function(e){return new o.AnnotationTargetImpl(e)},AnyType:function(e){return new o.AnyTypeImpl(e)},Api:function(e,t){return new o.ApiImpl(e,t)},ArrayTypeDeclaration:function(e,t){return new o.ArrayTypeDeclarationImpl(e,t)},BasicSecurityScheme:function(e,t){return new o.BasicSecuritySchemeImpl(e,t)},BooleanType:function(e){return new o.BooleanTypeImpl(e)},BooleanTypeDeclaration:function(e,t){return new o.BooleanTypeDeclarationImpl(e,t)},ContentType:function(e){return new o.ContentTypeImpl(e)},CustomSecurityScheme:function(e,t){return new o.CustomSecuritySchemeImpl(e,t)},DateOnlyType:function(e){return new o.DateOnlyTypeImpl(e)},DateOnlyTypeDeclaration:function(e,t){return new o.DateOnlyTypeDeclarationImpl(e,t)},DateTimeOnlyType:function(e){return new o.DateTimeOnlyTypeImpl(e)},DateTimeOnlyTypeDeclaration:function(e,t){return new o.DateTimeOnlyTypeDeclarationImpl(e,t)},DateTimeType:function(e){return new o.DateTimeTypeImpl(e)},DateTimeTypeDeclaration:function(e,t){return new o.DateTimeTypeDeclarationImpl(e,t)},DigestSecurityScheme:function(e,t){return new o.DigestSecuritySchemeImpl(e,t)},DocumentationItem:function(e,t){return new o.DocumentationItemImpl(e,t)},Extension:function(e,t){return new o.ExtensionImpl(e,t)},FileType:function(e){return new o.FileTypeImpl(e)},FileTypeDeclaration:function(e,t){return new o.FileTypeDeclarationImpl(e,t)},FixedUriString:function(e){return new o.FixedUriStringImpl(e)},FragmentDeclaration:function(e,t){return new o.FragmentDeclarationImpl(e,t)},FullUriTemplateString:function(e){return new o.FullUriTemplateStringImpl(e)},IntegerType:function(e){return new o.IntegerTypeImpl(e)},IntegerTypeDeclaration:function(e,t){return new o.IntegerTypeDeclarationImpl(e,t)},Library:function(e,t){return new o.LibraryImpl(e,t)},LibraryBase:function(e,t){return new o.LibraryBaseImpl(e,t)},LocationKind:function(e){return new o.LocationKindImpl(e)},MarkdownString:function(e){return new o.MarkdownStringImpl(e)},Method:function(e,t){return new o.MethodImpl(e,t)},MethodBase:function(e,t){return new o.MethodBaseImpl(e,t)},MimeType:function(e){return new o.MimeTypeImpl(e)},ModelLocation:function(e){return new o.ModelLocationImpl(e)},NullType:function(e){return new o.NullTypeImpl(e)},NumberType:function(e){return new o.NumberTypeImpl(e)},NumberTypeDeclaration:function(e,t){return new o.NumberTypeDeclarationImpl(e,t)},OAuth1SecurityScheme:function(e,t){return new o.OAuth1SecuritySchemeImpl(e,t)},OAuth1SecuritySchemeSettings:function(e,t){return new o.OAuth1SecuritySchemeSettingsImpl(e,t)},OAuth2SecurityScheme:function(e,t){return new o.OAuth2SecuritySchemeImpl(e,t)},OAuth2SecuritySchemeSettings:function(e,t){return new o.OAuth2SecuritySchemeSettingsImpl(e,t)},ObjectTypeDeclaration:function(e,t){return new o.ObjectTypeDeclarationImpl(e,t)},Operation:function(e,t){return new o.OperationImpl(e,t)},Overlay:function(e,t){return new o.OverlayImpl(e,t)},PassThroughSecurityScheme:function(e,t){return new o.PassThroughSecuritySchemeImpl(e,t)},Reference:function(e){return new o.ReferenceImpl(e)},RelativeUriString:function(e){return new o.RelativeUriStringImpl(e)},Resource:function(e,t){return new o.ResourceImpl(e,t)},ResourceBase:function(e,t){return new o.ResourceBaseImpl(e,t)},ResourceType:function(e,t){return new o.ResourceTypeImpl(e,t)},ResourceTypeRef:function(e){return new o.ResourceTypeRefImpl(e)},Response:function(e,t){return new o.ResponseImpl(e,t)},SchemaString:function(e){return new o.SchemaStringImpl(e)},SecuritySchemePart:function(e,t){return new o.SecuritySchemePartImpl(e,t)},SecuritySchemeRef:function(e){return new o.SecuritySchemeRefImpl(e)},SecuritySchemeSettings:function(e,t){return new o.SecuritySchemeSettingsImpl(e,t)},StatusCodeString:function(e){return new o.StatusCodeStringImpl(e)},StringType:function(e){return new o.StringTypeImpl(e)},StringTypeDeclaration:function(e,t){return new o.StringTypeDeclarationImpl(e,t)},TimeOnlyType:function(e){return new o.TimeOnlyTypeImpl(e)},TimeOnlyTypeDeclaration:function(e,t){return new o.TimeOnlyTypeDeclarationImpl(e,t)},Trait:function(e,t){return new o.TraitImpl(e,t)},TraitRef:function(e){return new o.TraitRefImpl(e)},TypeDeclaration:function(e,t){return new o.TypeDeclarationImpl(e,t)},UnionTypeDeclaration:function(e,t){return new o.UnionTypeDeclarationImpl(e,t)},UriTemplate:function(e){return new o.UriTemplateImpl(e)},UsesDeclaration:function(e,t){return new o.UsesDeclarationImpl(e,t)},ValueType:function(e){return new o.ValueTypeImpl(e)},XMLFacetInfo:function(e,t){return new o.XMLFacetInfoImpl(e,t)}}},function(e,t,n){"use strict";function r(e){return e.isBuiltIn()?s[e.nameId()]:null}function i(e,t){void 0===t&&(t=!0);var n=e.definition(),i=(n.nameId(),r(n));if(!i){for(var o=a(n),u=n.allSuperTypes().sort(function(e,t){return o[e.nameId()]-o[t.nameId()]}),l=null,p=0;p<u.length;p++){var c=u[p].nameId();if(i=r(u[p]),"DataElement"!=c){if("hl.BasicNode"!=c&&i)break}else l=c}i||(l=c)}return i||(i=s["hl.BasicNode"]),i(e,t)}function a(e,t,n){void 0===t&&(t={}),void 0===n&&(n={});var r=e.nameId();if(!n[r]){n[r]=!0;var i=null!=t[r]&&t[r]+1||0,o=e.superTypes();return o.forEach(function(e){var r=e.nameId(),o=t[r];(null==o||i>o)&&(t[r]=i,a(e,t,n))}),delete n[r],t}}var o=n(50);t.buildWrapperNode=i;var s={AbstractSecurityScheme:function(e,t){return new o.AbstractSecuritySchemeImpl(e,t)},AnyType:function(e){return new o.AnyTypeImpl(e)},Api:function(e,t){return new o.ApiImpl(e,t)},BasicSecurityScheme:function(e,t){return new o.BasicSecuritySchemeImpl(e,t)},BodyLike:function(e,t){return new o.BodyLikeImpl(e,t)},BooleanType:function(e){return new o.BooleanTypeImpl(e)},BooleanTypeDeclaration:function(e,t){return new o.BooleanTypeDeclarationImpl(e,t)},CustomSecurityScheme:function(e,t){return new o.CustomSecuritySchemeImpl(e,t)},DateTypeDeclaration:function(e,t){return new o.DateTypeDeclarationImpl(e,t)},DigestSecurityScheme:function(e,t){return new o.DigestSecuritySchemeImpl(e,t)},DocumentationItem:function(e,t){return new o.DocumentationItemImpl(e,t)},ExampleString:function(e){return new o.ExampleStringImpl(e)},FileTypeDeclaration:function(e,t){return new o.FileTypeDeclarationImpl(e,t)},FixedUri:function(e){return new o.FixedUriImpl(e)},FullUriTemplateString:function(e){return new o.FullUriTemplateStringImpl(e)},GlobalSchema:function(e,t){return new o.GlobalSchemaImpl(e,t)},IntegerTypeDeclaration:function(e,t){return new o.IntegerTypeDeclarationImpl(e,t)},JSONBody:function(e,t){return new o.JSONBodyImpl(e,t)},JSONExample:function(e){return new o.JSONExampleImpl(e)},JSonSchemaString:function(e){return new o.JSonSchemaStringImpl(e)},MarkdownString:function(e){return new o.MarkdownStringImpl(e)},Method:function(e,t){return new o.MethodImpl(e,t)},MethodBase:function(e,t){return new o.MethodBaseImpl(e,t)},MimeType:function(e){return new o.MimeTypeImpl(e)},NumberType:function(e){return new o.NumberTypeImpl(e)},NumberTypeDeclaration:function(e,t){return new o.NumberTypeDeclarationImpl(e,t)},OAuth1SecurityScheme:function(e,t){return new o.OAuth1SecuritySchemeImpl(e,t)},OAuth1SecuritySchemeSettings:function(e,t){return new o.OAuth1SecuritySchemeSettingsImpl(e,t)},OAuth2SecurityScheme:function(e,t){return new o.OAuth2SecuritySchemeImpl(e,t)},OAuth2SecuritySchemeSettings:function(e,t){return new o.OAuth2SecuritySchemeSettingsImpl(e,t)},Parameter:function(e,t){return new o.ParameterImpl(e,t)},ParameterLocation:function(e){return new o.ParameterLocationImpl(e)},RAMLSimpleElement:function(e,t){return new o.RAMLSimpleElementImpl(e,t)},Reference:function(e){return new o.ReferenceImpl(e)},RelativeUriString:function(e){return new o.RelativeUriStringImpl(e)},Resource:function(e,t){return new o.ResourceImpl(e,t)},ResourceType:function(e,t){return new o.ResourceTypeImpl(e,t)},ResourceTypeRef:function(e){return new o.ResourceTypeRefImpl(e)},Response:function(e,t){return new o.ResponseImpl(e,t)},SchemaString:function(e){return new o.SchemaStringImpl(e)},SecuritySchemePart:function(e,t){return new o.SecuritySchemePartImpl(e,t)},SecuritySchemeRef:function(e){return new o.SecuritySchemeRefImpl(e)},SecuritySchemeSettings:function(e,t){return new o.SecuritySchemeSettingsImpl(e,t)},StatusCodeString:function(e){return new o.StatusCodeStringImpl(e)},StringType:function(e){return new o.StringTypeImpl(e)},StringTypeDeclaration:function(e,t){return new o.StringTypeDeclarationImpl(e,t)},Trait:function(e,t){return new o.TraitImpl(e,t)},TraitRef:function(e){return new o.TraitRefImpl(e)},UriTemplate:function(e){return new o.UriTemplateImpl(e)},ValueType:function(e){return new o.ValueTypeImpl(e)},XMLBody:function(e,t){return new o.XMLBodyImpl(e,t)},XMLExample:function(e){return new o.XMLExampleImpl(e)},XMLSchemaString:function(e){return new o.XMLSchemaStringImpl(e)}}},function(e,t,n){},function(e,t,n){"use strict";function r(e){var t=e.value();if("string"==typeof t||null==t){var n=u.createNode(t,null,e.lowLevel().unit());n._actualNode().startPosition=e.lowLevel().valueStart(),n._actualNode().endPosition=e.lowLevel().valueEnd();var r=new s.StructuredValue(n,e.parent(),e.property());return r}return t}function i(e){var t=e._meta;t.resetPrimitiveValuesMeta();var n=e.highLevel();return n.definition().allProperties().forEach(function(r){var i=r.nameId(),a=n.attributes(i),o=!1,s=!1;if(a.forEach(function(e){o=o||null!=e.value(),s=s||e.optional()}),!o){var u=e.getDefaultsCalculator(),p=u.attributeDefaultIfEnabled(n,r);if(null!=p){var c=u.insertionKind(n,r);c==l.InsertionKind.CALCULATED?t.registerCalculatedValue(i):c==l.InsertionKind.BY_DEFAULT&&t.registerInsertedAsDefaultValue(i)}}}),t}function a(e,t){return t?e.map(function(e){return t(e)}):e.map(function(e){return e.value()})}var o=this&&this.__extends||function(e,t){function n(){this.constructor=e}for(var r in t)t.hasOwnProperty(r)&&(e[r]=t[r]);e.prototype=null===t?Object.create(t):(n.prototype=t.prototype,new n)},s=n(16),u=n(26),l=(n(37),n(69)),p=n(13),c=n(14),f=n(70),m=n(75),d=function(){function e(e,t){void 0===t&&(t=!0),this._node=e,this._meta=new S(!1,!1,c.isMethodType(this.highLevel().definition())&&this.optional()),t&&e.setWrapperNode(this)}return e.isInstance=function(t){if(null!=t&&t.getClassIdentifier&&"function"==typeof t.getClassIdentifier)for(var n=0,r=t.getClassIdentifier();n<r.length;n++){var i=r[n];if(i==e.CLASS_IDENTIFIER)return!0}return!1},e.prototype.getClassIdentifier=function(){var t=[];return t.concat(e.CLASS_IDENTIFIER)},e.prototype.wrapperClassName=function(){return"BasicNodeImpl"},e.prototype.kind=function(){return"BasicNode"},e.prototype.allKinds=function(){return["BasicNode"]},e.prototype.allWrapperClassNames=function(){return["BasicNodeImpl"]},e.prototype.parent=function(){var e=this._node.parent();return e?e.wrapperNode():null},e.prototype.highLevel=function(){return this._node},e.prototype.patchNode=function(e){this._node=e},e.prototype.attributes=function(e,t){var n=this._node.attributes(e);if(!n||0==n.length){var r=this.getDefaultsCalculator().attributeDefaultIfEnabled(this._node,this._node.definition().property(e));return null==r?[]:Array.isArray(r)?r:[r]}return a(n,t)},e.prototype.attribute=function(e,t){var n=this._node.attr(e);if(t&&t!=this.toString&&t!=this.toBoolean&&t!=this.toNumber&&t!=this.toAny)return null==n?null:t(n);var r=n?n.value():null;return null==r&&(r=this.getDefaultsCalculator().attributeDefaultIfEnabled(this._node,this._node.definition().property(e))),null==r?null:t?t(r):r},e.prototype.elements=function(e){var t=this._node.elementsOfKind(e);return t?t.map(function(e){return e.wrapperNode()}):null},e.prototype.element=function(e){var t=this._node.element(e);return t?t.wrapperNode():null},e.prototype.add=function(e){this.highLevel().add(e.highLevel())},e.prototype.addToProp=function(e,t){var n=e.highLevel(),r=this.highLevel().definition().property(t);n._prop=r,this.highLevel().add(n)},e.prototype.remove=function(e){this.highLevel().remove(e.highLevel())},e.prototype.dump=function(){return this.highLevel().dump("yaml")},e.prototype.toString=function(e){var t;return t=e.lowLevel&&e.property?e.value():e,null!=t?t.toString():t},e.prototype.toAny=function(e){return e},e.prototype.toBoolean=function(e){var t;return t=e.lowLevel&&e.property?e.value():e,null!=t?"true"==t.toString():t},e.prototype.toNumber=function(e){var t;if(t=e.lowLevel&&e.property?e.value():e,!t)return t;try{var n=parseFloat(t.toString());return n}catch(r){}return Number.MAX_VALUE},e.prototype.errors=function(){var e=this,t=[],n=this._node.errors();null!=n&&(t=t.concat(n));var r=t.map(function(t){return e.basicError(t)}),i=this.filterErrors(r);return i},e.prototype.filterErrors=function(e){var t=[],n={};e.map(function(e){n[JSON.stringify(e)]=e});for(var r=Object.keys(n),i=0;i<r.length;i++)t.push(n[r[i]]);return t},e.prototype.basicError=function(e){var t=this,n=e.node&&e.node.lowLevel()&&e.node.lowLevel().unit().lineMapper()||this._node.lowLevel().unit().lineMapper(),r=null;try{r=n.position(e.start)}catch(i){console.warn(i)}var a=null;try{a=n.position(e.end)}catch(i){console.warn(i)}var o;o=e.path?e.path:e.node?e.node.lowLevel().unit().path():p.declRoot(this.highLevel()).lowLevel().unit().path();var s={code:e.code,message:e.message,path:o,range:{start:r,end:a},isWarning:e.isWarning};return e.extras&&e.extras.length>0&&(s.trace=e.extras.map(function(e){return t.basicError(e)})),s},e.prototype.definition=function(){return this.highLevel().definition()},e.prototype.runtimeDefinition=function(){return c.isTypeDeclarationSibling(this.highLevel().definition())?this.highLevel().localType():null},e.prototype.toJSON=function(e){var t=h;h=this.attributeDefaults();try{return new f.TCKDumper(e).dump(this)}finally{h=t}},e.prototype.optional=function(){var e=this.highLevel();return null!=e?e.optional():!1},e.prototype.optionalProperties=function(){return this.highLevel()?this.highLevel().optionalProperties():[]},e.prototype.getDefaultsCalculator=function(){return this.defaultsCalculator?this.defaultsCalculator:(this.parent()&&(this.defaultsCalculator=this.parent().getDefaultsCalculator()),this.defaultsCalculator||(this.defaultsCalculator=new l.AttributeDefaultsCalculator(h)),this.defaultsCalculator)},e.prototype.setAttributeDefaults=function(e){this.defaultsCalculator=new l.AttributeDefaultsCalculator(e)},e.prototype.attributeDefaults=function(){return this.getDefaultsCalculator()&&this.getDefaultsCalculator().isEnabled()},e.prototype.meta=function(){return i(this)},e.prototype.RAMLVersion=function(){return this.highLevel().definition().universe().version()},e.CLASS_IDENTIFIER="parserCore.BasicNodeImpl",e}();t.BasicNodeImpl=d;var h=!0,y=function(){function e(e){this._meta=new A,this.attr=e}return e.isInstance=function(t){if(null!=t&&t.getClassIdentifier&&"function"==typeof t.getClassIdentifier)for(var n=0,r=t.getClassIdentifier();n<r.length;n++){var i=r[n];if(i==e.CLASS_IDENTIFIER)return!0}return!1},e.prototype.getClassIdentifier=function(){var t=[];return t.concat(e.CLASS_IDENTIFIER)},e.prototype.highLevel=function(){return this.attr},e.prototype.wrapperClassName=function(){return"AttributeNodeImpl"},e.prototype.kind=function(){return"AttributeNode"},e.prototype.allKinds=function(){return["AttributeNode"]},e.prototype.allWrapperClassNames=function(){return["AttributeNodeImpl"]},e.prototype.optional=function(){var e=this.highLevel();return null!=e?e.optional():!1},e.prototype.meta=function(){return this._meta},e.prototype.RAMLVersion=function(){return this.highLevel().definition().universe().version()},e.prototype.parent=function(){var e=this.attr.parent();return e?e.wrapperNode():null},e.prototype.toJSON=function(e){return new f.TCKDumper(e).dump(this)},e.CLASS_IDENTIFIER="parserCore.AttributeNodeImpl",e}();t.AttributeNodeImpl=y,t.toStructuredValue=r;var v=function(){function e(e,t){this.type=t,Array.isArray(e)?this.children=e:this.node=e}return e.isInstance=function(t){if(null!=t&&t.getClassIdentifier&&"function"==typeof t.getClassIdentifier)for(var n=0,r=t.getClassIdentifier();n<r.length;n++){var i=r[n];if(i==e.CLASS_IDENTIFIER)return!0}return!1},e.prototype.getClassIdentifier=function(){var t=[];return t.concat(e.CLASS_IDENTIFIER)},e.prototype.properties=function(){return this.isArray()?[]:this.getChildren().map(function(e){return new g(e)})},e.prototype.getChildren=function(){return this.node&&this.node.children()||this.children},e.prototype.value=function(){return this.node&&this.node.value()},e.prototype.isScalar=function(){return this.node?0!=this.node.children().length?!1:this.type?this.type.isScalar():!0:!1},e.prototype.toJSON=function(){return(new f.TCKDumper).serializeTypeInstance(this)},e.prototype.isArray=function(){return this.node?this.type?this.type.isArray():this.node&&this.node.valueKind()==m.Kind.SEQ:!1},e.prototype.items=function(){return this.isArray()?this.node.children().map(function(t){return new e(t)}):null},e.CLASS_IDENTIFIER="parserCore.TypeInstanceImpl",e}();t.TypeInstanceImpl=v;var g=function(){function e(e){this.node=e}return e.isInstance=function(t){if(null!=t&&t.getClassIdentifier&&"function"==typeof t.getClassIdentifier)for(var n=0,r=t.getClassIdentifier();n<r.length;n++){var i=r[n];if(i==e.CLASS_IDENTIFIER)return!0}return!1},e.prototype.getClassIdentifier=function(){var t=[];return t.concat(e.CLASS_IDENTIFIER)},e.prototype.name=function(){return this.node.optional()?this.node.key()+"?":this.node.key()},e.prototype.value=function(){if(this.isArray()){var e=this.node.children();return e.length>0?new v(e[0]):null}return new v(this.node)},e.prototype.values=function(){return this.isArray()?this.node.children().map(function(e){return new v(e)}):[new v(this.node)]},e.prototype.isArray=function(){var e=this.node.children();if(e.length>0&&null==e[0].key())return!0;var t=this.node.highLevelNode();if(t){var n=t.property();if(n){var r=n.range();if(r)return r.isArray()}}return this.node.valueKind()==m.Kind.SEQ},e.CLASS_IDENTIFIER="parserCore.TypeInstancePropertyImpl",e}();t.TypeInstancePropertyImpl=g;var A=function(){function e(e,t,n){void 0===e&&(e=!1),void 0===t&&(t=!1),void 0===n&&(n=!1),this._insertedAsDefault=e,this._calculated=t,this._optional=n}return e.prototype.calculated=function(){return this._calculated},e.prototype.insertedAsDefault=function(){return this._insertedAsDefault},e.prototype.setCalculated=function(){this._calculated=!0},e.prototype.setInsertedAsDefault=function(){this._insertedAsDefault=!0},e.prototype.setOptional=function(){this._optional=!0},e.prototype.optional=function(){return this._optional},e.prototype.isDefault=function(){return!(this._insertedAsDefault||this._calculated||this._optional)},e.prototype.toJSON=function(){var e={};return this._calculated&&(e.calculated=!0),this._insertedAsDefault&&(e.insertedAsDefault=!0),this._optional&&(e.optional=!0),e},e}();t.ValueMetadataImpl=A;var S=function(e){function t(){e.apply(this,arguments),this.valuesMeta={}}return o(t,e),t.prototype.primitiveValuesMeta=function(){return this.valuesMeta},t.prototype.registerInsertedAsDefaultValue=function(e){var t=this.valuesMeta[e];null==t?this.valuesMeta[e]=new A(!0):t.setInsertedAsDefault()},t.prototype.registerCalculatedValue=function(e){var t=this.valuesMeta[e];null==t?this.valuesMeta[e]=new A(!1,!0):t.setCalculated()},t.prototype.registerOptionalValue=function(e){var t=this.valuesMeta[e];null==t?this.valuesMeta[e]=new A(!1,!1,!0):t.setOptional()},t.prototype.resetPrimitiveValuesMeta=function(){this.valuesMeta={}},t.prototype.isDefault=function(){return e.prototype.isDefault.call(this)?0==Object.keys(this.valuesMeta).length:!1},t.prototype.toJSON=function(){var t=this,n=e.prototype.toJSON.call(this),r={},i=Object.keys(this.valuesMeta);return i.length>0&&(i.forEach(function(e){var n=t.valuesMeta[e].toJSON();Object.keys(n).length>0&&(r[e]=n)}),n.primitiveValuesMeta=r),n},t}(A);t.NodeMetadataImpl=S,t.fillElementMeta=i,t.attributesToValues=a},function(e,t,n){"use strict";function r(e){try{var t=JSON.parse(e);return t.$schema}catch(n){return s.isXmlScheme(e)}}function i(e,t){if(s.isXmlScheme(e))return p.getXMLSchema(e,new u.ContentProvider(t)).loadSchemaReferencesAsync().then(function(){return t});var n=p.getJSONSchema(e,new u.ContentProvider(t)),r=n.getMissingReferences([]).map(function(e){return n.contentAsync(e)});if(0===r.length)return Promise.resolve(t);var i=Promise.all(r),a=o(i,n);return a.then(function(){return t})}function a(e,t){var n=p.createSchema(e,new u.ContentProvider(t));return n.getMissingReferences([],!0)}function o(e,t){return e.then(function(e){if(e.length>0){var n=t.getMissingReferences(e);if(0===n.length)return[];var r=[];return n.forEach(function(e){r.push(t.contentAsync(e))}),o(Promise.all(r.concat(e)),t)}return Promise.resolve([])})}var s=n(55),u=n(32),l=n(37),p=l.getSchemaUtils();t.isScheme=r,t.startDownloadingReferencesAsync=i,t.getReferences=a},function(e,t,n){"use strict";var r=n(10),i=n(15),a=n(17),o=n(14),s=n(27),u=function(){function e(){this.expandedAbsToNsMap={},this.byPathMap={},this.byNsMap={},this._hasFragments={}}return e.prototype.resolveNamespace=function(e,t){if(null==t)return null;var n=t.absolutePath(),r=this.expandedPathMap(e);if(!r)return null;var i=r[n];return i},e.prototype.expandedPathMap=function(e){var t=e.absolutePath(),n=this.expandedAbsToNsMap[t];
return void 0===n&&(n=this.calculateExpandedNamespaces(e),0==Object.keys(n).length&&(n=null),this.expandedAbsToNsMap[t]=n),n},e.prototype.calculateExpandedNamespaces=function(e){for(var t=this,n=i.dirname(e.absolutePath()),u={},p=[];e;){p.push(new l([],e,""));var c=e;e=null;var f=c.highLevel();if(f.isElement()){var m=f.asElement(),d=m.definition();if(o.isOverlayType(d)||o.isExtensionType(d)){var h=m.attrValue(a.Universe10.Extension.properties["extends"].name);h&&(e=c.resolve(h),e&&s.isWaitingFor(e.absolutePath())&&(e=null))}}}for(var y=0;y<p.length;y++){var v={},g={},A=p[y],S=A.unit,T=S.highLevel();if(T.isElement()){var E=A.steps()+1,b=function(e){if(e){var a=e.children();if(null==e.parent()){var o=e.unit(),s=o.absolutePath();if(v[s])return;v[s]=!0,s!=S.absolutePath()&&(t._hasFragments[S.absolutePath()]=!0);var c=t.pathMap(o);if(c)for(var f=0,m=Object.keys(c);f<m.length;f++){var d=m[f],h=c[d],y=A.namespaceSegments.concat(h.namespaceSegments),T=A.usesNodes.concat(h.usesNodes),N=u[d];if(N){if(N.steps()<E)continue;if(N.steps()==E&&t.lexLessEq(N.namespaceSegments,y))continue}var _,M=h.includePath,w=h.absolutePath();_=i.isAbsolute(A.includePath)||r.isWebPath(A.includePath)?w:i.isAbsolute(M)||r.isWebPath(M)?w:r.isWebPath(n)!=r.isWebPath(w)?w:n.length>0&&w.length>0&&n.charAt(0).toLowerCase()!=w.charAt(0).toLowerCase()?w:i.relative(n,w),_=_.replace(/\\/g,"/");var R=new l(T,h.unit,_);g[R.absolutePath()]||(u[d]=R,p.push(R),g[R.absolutePath()]=!0)}}a.forEach(function(e){e.includedFrom()&&(e=e.parent()),b(e)}),null==e.parent()&&(v[e.unit().absolutePath()]=!1)}};b(S.ast())}}for(var N={},_=0,M=Object.keys(u);_<M.length;_++){for(var w=M[_],A=u[w],R=A.namespace(),y=0;N[R];)R=A.namespace()+y++;R!=A.namespace()&&(A.namespaceSegments=R.split(".")),N[R]=!0}return u},e.prototype.pathMap=function(e){var t=e.absolutePath(),n=this.byPathMap[t];return void 0===n&&(n=this.calculateNamespaces(e),0==Object.keys(n).length&&(n=null),this.byPathMap[t]=n),n},e.prototype.nsMap=function(e){var t=e.absolutePath(),n=this.byNsMap[t];if(void 0===n){var r=this.pathMap(e);if(null==r)n=null;else{n={};for(var i=0,a=Object.keys(r);i<a.length;i++){var o=a[i],s=r[o];n[s.namespace()]=s}}this.byNsMap[t]=n}return n},e.prototype.calculateNamespaces=function(e){var t=i.dirname(e.absolutePath()),n={},s=e.ast(),u=s.children().filter(function(e){return e.key()==a.Universe10.FragmentDeclaration.properties.uses.name});if(s.actual()&&s.actual().usesNode&&(u=[s.actual().usesNode]),0==u.length)return n;for(var p=[],c=0,f=u;c<f.length;c++){var m=f[c];p=p.concat(m.children())}if(0==p.length)return n;for(var d=0,h=p;d<h.length;d++){var m=h[d],y=m.value(),v=e.resolve(y);if(null!=v){var g,u=[m],A=v.absolutePath();g=i.isAbsolute(y)||r.isWebPath(y)?v.absolutePath():i.relative(t,v.absolutePath()),g=g.replace(/\\/g,"/");var S=new l(u,v,g);n[A]=S}}var T=e.highLevel();if(T.isElement()){var E=T.asElement(),b=E.definition();if(o.isOverlayType(b)||o.isExtensionType(b)){var N,_=E.attr(a.Universe10.Extension.properties["extends"].name).value();try{N=e.resolve(_)}catch(M){}if(N){var w=this.pathMap(N);if(w)for(var R=0,I=Object.keys(w);R<I.length;R++){var C=I[R];n[C]=w[C]}}}}return n},e.prototype.lexLessEq=function(e,t){if(e.length>t.length)return!1;if(e.length<t.length)return!0;for(var n=0;n<e.length;n++){var r=e[n],i=t[n];if(i>r)return!0;if(r>i)return!1}return!0},e.prototype.hasFragments=function(e){return this.calculateExpandedNamespaces(e),this._hasFragments[e.absolutePath()]?!0:!1},e}();t.NamespaceResolver=u;var l=function(){function e(e,t,n){this.usesNodes=e,this.unit=t,this.includePath=n,this.namespaceSegments=this.usesNodes.map(function(e){return e.key()})}return e.prototype.steps=function(){return this.namespaceSegments.length},e.prototype.namespace=function(){return this.namespaceSegments.join(".")},e.prototype.absolutePath=function(){return this.unit.absolutePath()},e}();t.UsesInfo=l},function(e,t,n){"use strict";function r(e){var t=C.getUniverse("RAML08"),n=t.type("Method"),r=I.createStubNode(n,null,e);return r}function i(e){var t=C.getUniverse("RAML08"),n=t.type("StringTypeDeclaration"),r=I.createStubNode(n,null,e);return r}function a(e){var t=C.getUniverse("RAML08"),n=t.type("BooleanTypeDeclaration"),r=I.createStubNode(n,null,e);return r}function o(e){var t=C.getUniverse("RAML08"),n=t.type("NumberTypeDeclaration"),r=I.createStubNode(n,null,e);return r}function s(e){var t=C.getUniverse("RAML08"),n=t.type("IntegerTypeDeclaration"),r=I.createStubNode(n,null,e);return r}function u(e){var t=C.getUniverse("RAML08"),n=t.type("DateTypeDeclaration"),r=I.createStubNode(n,null,e);return r}function l(e){var t=C.getUniverse("RAML08"),n=t.type("FileTypeDeclaration"),r=I.createStubNode(n,null,e);return r}function p(e){var t=C.getUniverse("RAML08"),n=t.type("XMLBody"),r=I.createStubNode(n,null,e);return r}function c(e){var t=C.getUniverse("RAML08"),n=t.type("JSONBody"),r=I.createStubNode(n,null,e);return r}function f(e){var t=C.getUniverse("RAML08"),n=t.type("SecuritySchemePart"),r=I.createStubNode(n,null,e);return r}function m(e){var t=C.getUniverse("RAML08"),n=t.type("Trait"),r=I.createStubNode(n,null,e);return r}function d(e){var t=C.getUniverse("RAML08"),n=t.type("OAuth1SecuritySchemeSettings"),r=I.createStubNode(n,null,e);return r}function h(e){var t=C.getUniverse("RAML08"),n=t.type("OAuth2SecuritySchemeSettings"),r=I.createStubNode(n,null,e);return r}function y(e){var t=C.getUniverse("RAML08"),n=t.type("OAuth2SecurityScheme"),r=I.createStubNode(n,null,e);return r}function v(e){var t=C.getUniverse("RAML08"),n=t.type("OAuth1SecurityScheme"),r=I.createStubNode(n,null,e);return r}function g(e){var t=C.getUniverse("RAML08"),n=t.type("BasicSecurityScheme"),r=I.createStubNode(n,null,e);return r}function A(e){var t=C.getUniverse("RAML08"),n=t.type("DigestSecurityScheme"),r=I.createStubNode(n,null,e);return r}function S(e){var t=C.getUniverse("RAML08"),n=t.type("CustomSecurityScheme"),r=I.createStubNode(n,null,e);return r}function T(e){var t=C.getUniverse("RAML08"),n=t.type("GlobalSchema"),r=I.createStubNode(n,null,e);return r}function E(e){var t=C.getUniverse("RAML08"),n=t.type("DocumentationItem"),r=I.createStubNode(n,null,e);return r}function b(e,t,n){return P.loadApi(e,t,n).getOrElse(null)}function N(e,t,n){return P.loadApi(e,t,n).getOrElse(null)}function _(e,t,n){return P.loadApiAsync(e,t,n)}function M(e,t,n){return P.loadRAMLAsync(e,t,n)}function w(e){return P.getLanguageElementByRuntimeType(e)}var R=this&&this.__extends||function(e,t){function n(){this.constructor=e}for(var r in t)t.hasOwnProperty(r)&&(e[r]=t[r]);e.prototype=null===t?Object.create(t):(n.prototype=t.prototype,new n)},I=n(19),C=n(37),L=n(47),P=n(8),O=n(51),D=function(e){function t(){e.apply(this,arguments)}return R(t,e),t.prototype.title=function(){return e.prototype.attribute.call(this,"title",this.toString)},t.prototype.setTitle=function(e){return this.highLevel().attrOrCreate("title").setValue(""+e),this},t.prototype.version=function(){return e.prototype.attribute.call(this,"version",this.toString)},t.prototype.setVersion=function(e){return this.highLevel().attrOrCreate("version").setValue(""+e),this},t.prototype.baseUri=function(){return e.prototype.attribute.call(this,"baseUri",function(e){return new Re(e)})},t.prototype.baseUriParameters_original=function(){return e.prototype.elements.call(this,"baseUriParameters")},t.prototype.uriParameters=function(){return e.prototype.elements.call(this,"uriParameters")},t.prototype.protocols=function(){return e.prototype.attributes.call(this,"protocols",this.toString)},t.prototype.setProtocols=function(e){return this.highLevel().attrOrCreate("protocols").setValue(""+e),this},t.prototype.mediaType=function(){return e.prototype.attribute.call(this,"mediaType",function(e){return new _e(e)})},t.prototype.schemas=function(){return e.prototype.elements.call(this,"schemas")},t.prototype.traits_original=function(){return e.prototype.elements.call(this,"traits")},t.prototype.securedBy=function(){return e.prototype.attributes.call(this,"securedBy",function(e){return new pe(e)})},t.prototype.securitySchemes=function(){return e.prototype.elements.call(this,"securitySchemes")},t.prototype.resourceTypes_original=function(){return e.prototype.elements.call(this,"resourceTypes")},t.prototype.resources=function(){return e.prototype.elements.call(this,"resources")},t.prototype.documentation=function(){return e.prototype.elements.call(this,"documentation")},t.prototype.wrapperClassName=function(){return"ApiImpl"},t.prototype.kind=function(){return"Api"},t.prototype.allKinds=function(){return e.prototype.allKinds.call(this).concat("Api")},t.prototype.allWrapperClassNames=function(){return e.prototype.allWrapperClassNames.call(this).concat("RAML08.ApiImpl")},t.isInstance=function(e){if(null!=e&&e.allWrapperClassNames&&"function"==typeof e.allWrapperClassNames)for(var t=0,n=e.allWrapperClassNames();t<n.length;t++){var r=n[t];if("RAML08.ApiImpl"==r)return!0}return!1},t.prototype.RAMLVersion_original=function(){return"RAML08"},t.prototype.expand=function(){return O.expandTraitsAndResourceTypes(this)},t.prototype.traits=function(){return O.traitsPrimary(this)},t.prototype.allTraits=function(){return O.allTraits(this)},t.prototype.resourceTypes=function(){return O.resourceTypesPrimary(this)},t.prototype.allResourceTypes=function(){return O.allResourceTypes(this)},t.prototype.childResource=function(e){return O.childResource(this,e)},t.prototype.allResources=function(){return O.allResources(this)},t.prototype.baseUriParameters=function(){return O.baseUriParametersPrimary(this)},t.prototype.allBaseUriParameters=function(){return O.baseUriParameters(this)},t.prototype.allProtocols=function(){return O.allProtocols(this)},t.prototype.RAMLVersion=function(){return O.RAMLVersion(this)},t}(L.BasicNodeImpl);t.ApiImpl=D;var x=function(e){function t(){e.apply(this,arguments)}return R(t,e),t.prototype.wrapperClassName=function(){return"ValueTypeImpl"},t.prototype.kind=function(){return"ValueType"},t.prototype.allKinds=function(){return e.prototype.allKinds.call(this).concat("ValueType")},t.prototype.allWrapperClassNames=function(){return e.prototype.allWrapperClassNames.call(this).concat("undefined.ValueTypeImpl")},t.isInstance=function(e){if(null!=e&&e.allWrapperClassNames&&"function"==typeof e.allWrapperClassNames)for(var t=0,n=e.allWrapperClassNames();t<n.length;t++){var r=n[t];if("undefined.ValueTypeImpl"==r)return!0}return!1},t.prototype.RAMLVersion=function(){return"undefined"},t.prototype.value=function(){return this.attr.value()},t}(L.AttributeNodeImpl);t.ValueTypeImpl=x;var U=function(e){function t(){e.apply(this,arguments)}return R(t,e),t.prototype.wrapperClassName=function(){return"AnyTypeImpl"},t.prototype.kind=function(){return"AnyType"},t.prototype.allKinds=function(){return e.prototype.allKinds.call(this).concat("AnyType")},t.prototype.allWrapperClassNames=function(){return e.prototype.allWrapperClassNames.call(this).concat("RAML08.AnyTypeImpl")},t.isInstance=function(e){if(null!=e&&e.allWrapperClassNames&&"function"==typeof e.allWrapperClassNames)for(var t=0,n=e.allWrapperClassNames();t<n.length;t++){var r=n[t];if("RAML08.AnyTypeImpl"==r)return!0}return!1},t.prototype.RAMLVersion=function(){return"RAML08"},t}(x);t.AnyTypeImpl=U;var k=function(e){function t(){e.apply(this,arguments)}return R(t,e),t.prototype.wrapperClassName=function(){return"NumberTypeImpl"},t.prototype.kind=function(){return"NumberType"},t.prototype.allKinds=function(){return e.prototype.allKinds.call(this).concat("NumberType")},t.prototype.allWrapperClassNames=function(){return e.prototype.allWrapperClassNames.call(this).concat("RAML08.NumberTypeImpl")},t.isInstance=function(e){if(null!=e&&e.allWrapperClassNames&&"function"==typeof e.allWrapperClassNames)for(var t=0,n=e.allWrapperClassNames();t<n.length;t++){var r=n[t];if("RAML08.NumberTypeImpl"==r)return!0}return!1},t.prototype.RAMLVersion=function(){return"RAML08"},t.prototype.value=function(){return this.attr.value()},t}(x);t.NumberTypeImpl=k;var F=function(e){function t(){e.apply(this,arguments)}return R(t,e),t.prototype.wrapperClassName=function(){return"BooleanTypeImpl"},t.prototype.kind=function(){return"BooleanType"},t.prototype.allKinds=function(){return e.prototype.allKinds.call(this).concat("BooleanType")},t.prototype.allWrapperClassNames=function(){return e.prototype.allWrapperClassNames.call(this).concat("RAML08.BooleanTypeImpl")},t.isInstance=function(e){if(null!=e&&e.allWrapperClassNames&&"function"==typeof e.allWrapperClassNames)for(var t=0,n=e.allWrapperClassNames();t<n.length;t++){var r=n[t];if("RAML08.BooleanTypeImpl"==r)return!0}return!1},t.prototype.RAMLVersion=function(){return"RAML08"},t.prototype.value=function(){return this.attr.value()},t}(x);t.BooleanTypeImpl=F;var B=function(e){function t(){e.apply(this,arguments)}return R(t,e),t.prototype.wrapperClassName=function(){return"ReferenceImpl"},t.prototype.kind=function(){return"Reference"},t.prototype.allKinds=function(){return e.prototype.allKinds.call(this).concat("Reference")},t.prototype.allWrapperClassNames=function(){return e.prototype.allWrapperClassNames.call(this).concat("RAML08.ReferenceImpl")},t.isInstance=function(e){if(null!=e&&e.allWrapperClassNames&&"function"==typeof e.allWrapperClassNames)for(var t=0,n=e.allWrapperClassNames();t<n.length;t++){var r=n[t];if("RAML08.ReferenceImpl"==r)return!0}return!1},t.prototype.RAMLVersion=function(){return"RAML08"},t.prototype.value=function(){return L.toStructuredValue(this.attr)},t.prototype.structuredValue=function(){return O.structuredValue(this)},t.prototype.name=function(){return O.referenceName(this)},t}(L.AttributeNodeImpl);t.ReferenceImpl=B;var K=function(e){function t(){e.apply(this,arguments)}return R(t,e),t.prototype.wrapperClassName=function(){return"ResourceTypeRefImpl"},t.prototype.kind=function(){return"ResourceTypeRef"},t.prototype.allKinds=function(){return e.prototype.allKinds.call(this).concat("ResourceTypeRef")},t.prototype.allWrapperClassNames=function(){return e.prototype.allWrapperClassNames.call(this).concat("RAML08.ResourceTypeRefImpl")},t.isInstance=function(e){if(null!=e&&e.allWrapperClassNames&&"function"==typeof e.allWrapperClassNames)for(var t=0,n=e.allWrapperClassNames();t<n.length;t++){var r=n[t];if("RAML08.ResourceTypeRefImpl"==r)return!0}return!1},t.prototype.RAMLVersion=function(){return"RAML08"},t.prototype.resourceType=function(){return O.referencedResourceType(this)},t}(B);t.ResourceTypeRefImpl=K;var V=function(e){function t(){e.apply(this,arguments)}return R(t,e),t.prototype.name=function(){return e.prototype.attribute.call(this,"name",this.toString)},t.prototype.setName=function(e){return this.highLevel().attrOrCreate("name").setValue(""+e),this},t.prototype.usage=function(){return e.prototype.attribute.call(this,"usage",this.toString)},t.prototype.setUsage=function(e){return this.highLevel().attrOrCreate("usage").setValue(""+e),this},t.prototype.methods=function(){return e.prototype.elements.call(this,"methods")},t.prototype.is=function(){return e.prototype.attributes.call(this,"is",function(e){return new me(e)})},t.prototype.type=function(){return e.prototype.attribute.call(this,"type",function(e){return new K(e)})},t.prototype.securedBy=function(){return e.prototype.attributes.call(this,"securedBy",function(e){return new pe(e)})},t.prototype.uriParameters=function(){return e.prototype.elements.call(this,"uriParameters")},t.prototype.displayName=function(){return e.prototype.attribute.call(this,"displayName",this.toString)},t.prototype.setDisplayName=function(e){return this.highLevel().attrOrCreate("displayName").setValue(""+e),this},t.prototype.baseUriParameters=function(){return e.prototype.elements.call(this,"baseUriParameters")},t.prototype.description=function(){return e.prototype.attribute.call(this,"description",function(e){return new G(e)})},t.prototype.wrapperClassName=function(){return"ResourceTypeImpl"},t.prototype.kind=function(){return"ResourceType"},t.prototype.allKinds=function(){return e.prototype.allKinds.call(this).concat("ResourceType")},t.prototype.allWrapperClassNames=function(){return e.prototype.allWrapperClassNames.call(this).concat("RAML08.ResourceTypeImpl")},t.isInstance=function(e){if(null!=e&&e.allWrapperClassNames&&"function"==typeof e.allWrapperClassNames)for(var t=0,n=e.allWrapperClassNames();t<n.length;t++){var r=n[t];if("RAML08.ResourceTypeImpl"==r)return!0}return!1},t.prototype.RAMLVersion=function(){return"RAML08"},t.prototype.parametrizedProperties=function(){return O.getTemplateParametrizedProperties(this)},t}(L.BasicNodeImpl);t.ResourceTypeImpl=V;var j=function(e){function t(){e.apply(this,arguments)}return R(t,e),t.prototype.responses=function(){return e.prototype.elements.call(this,"responses")},t.prototype.body=function(){return e.prototype.elements.call(this,"body")},t.prototype.protocols=function(){return e.prototype.attributes.call(this,"protocols",this.toString)},t.prototype.setProtocols=function(e){return this.highLevel().attrOrCreate("protocols").setValue(""+e),this},t.prototype.securedBy=function(){return e.prototype.attributes.call(this,"securedBy",function(e){return new pe(e)})},t.prototype.baseUriParameters=function(){return e.prototype.elements.call(this,"baseUriParameters")},t.prototype.queryParameters=function(){return e.prototype.elements.call(this,"queryParameters")},t.prototype.headers=function(){return e.prototype.elements.call(this,"headers")},t.prototype.description=function(){return e.prototype.attribute.call(this,"description",function(e){return new G(e)})},t.prototype.wrapperClassName=function(){return"MethodBaseImpl"},t.prototype.kind=function(){return"MethodBase"},t.prototype.allKinds=function(){return e.prototype.allKinds.call(this).concat("MethodBase")},t.prototype.allWrapperClassNames=function(){return e.prototype.allWrapperClassNames.call(this).concat("RAML08.MethodBaseImpl")},t.isInstance=function(e){if(null!=e&&e.allWrapperClassNames&&"function"==typeof e.allWrapperClassNames)for(var t=0,n=e.allWrapperClassNames();t<n.length;t++){var r=n[t];if("RAML08.MethodBaseImpl"==r)return!0}return!1},t.prototype.RAMLVersion=function(){return"RAML08"},t}(L.BasicNodeImpl);t.MethodBaseImpl=j;var W=function(e){function t(){e.apply(this,arguments)}return R(t,e),t.prototype.code=function(){return e.prototype.attribute.call(this,"code",function(e){return new Y(e)})},t.prototype.headers=function(){return e.prototype.elements.call(this,"headers")},t.prototype.body=function(){return e.prototype.elements.call(this,"body")},t.prototype.description=function(){return e.prototype.attribute.call(this,"description",function(e){return new G(e)})},t.prototype.wrapperClassName=function(){return"ResponseImpl"},t.prototype.kind=function(){return"Response"},t.prototype.allKinds=function(){return e.prototype.allKinds.call(this).concat("Response")},t.prototype.allWrapperClassNames=function(){return e.prototype.allWrapperClassNames.call(this).concat("RAML08.ResponseImpl")},t.isInstance=function(e){if(null!=e&&e.allWrapperClassNames&&"function"==typeof e.allWrapperClassNames)for(var t=0,n=e.allWrapperClassNames();t<n.length;t++){var r=n[t];if("RAML08.ResponseImpl"==r)return!0}return!1},t.prototype.RAMLVersion=function(){return"RAML08"},t.prototype.isOkRange=function(){return O.isOkRange(this)},t}(L.BasicNodeImpl);t.ResponseImpl=W;var q=function(e){function t(){e.apply(this,arguments)}return R(t,e),t.prototype.wrapperClassName=function(){return"StringTypeImpl"},t.prototype.kind=function(){return"StringType"},t.prototype.allKinds=function(){return e.prototype.allKinds.call(this).concat("StringType")},t.prototype.allWrapperClassNames=function(){return e.prototype.allWrapperClassNames.call(this).concat("RAML08.StringTypeImpl")},t.isInstance=function(e){if(null!=e&&e.allWrapperClassNames&&"function"==typeof e.allWrapperClassNames)for(var t=0,n=e.allWrapperClassNames();t<n.length;t++){var r=n[t];if("RAML08.StringTypeImpl"==r)return!0}return!1},t.prototype.RAMLVersion=function(){return"RAML08"},t.prototype.value=function(){return this.attr.value()},t}(x);t.StringTypeImpl=q;var Y=function(e){function t(){e.apply(this,arguments)}return R(t,e),t.prototype.wrapperClassName=function(){return"StatusCodeStringImpl"},t.prototype.kind=function(){return"StatusCodeString"},t.prototype.allKinds=function(){return e.prototype.allKinds.call(this).concat("StatusCodeString")},t.prototype.allWrapperClassNames=function(){return e.prototype.allWrapperClassNames.call(this).concat("RAML08.StatusCodeStringImpl")},t.isInstance=function(e){if(null!=e&&e.allWrapperClassNames&&"function"==typeof e.allWrapperClassNames)for(var t=0,n=e.allWrapperClassNames();t<n.length;t++){var r=n[t];if("RAML08.StatusCodeStringImpl"==r)return!0}return!1},t.prototype.RAMLVersion=function(){return"RAML08"},t}(q);t.StatusCodeStringImpl=Y;var H=function(e){function t(){e.apply(this,arguments)}return R(t,e),t.prototype.name=function(){return e.prototype.attribute.call(this,"name",this.toString)},t.prototype.setName=function(e){return this.highLevel().attrOrCreate("name").setValue(""+e),this},t.prototype.displayName=function(){return e.prototype.attribute.call(this,"displayName",this.toString)},t.prototype.setDisplayName=function(e){return this.highLevel().attrOrCreate("displayName").setValue(""+e),this},t.prototype.type=function(){return e.prototype.attribute.call(this,"type",this.toString)},t.prototype.setType=function(e){return this.highLevel().attrOrCreate("type").setValue(""+e),this},t.prototype.location=function(){return e.prototype.attribute.call(this,"location",function(e){return new $(e)})},t.prototype.required=function(){return e.prototype.attribute.call(this,"required",this.toBoolean)},t.prototype.setRequired=function(e){return this.highLevel().attrOrCreate("required").setValue(""+e),this},t.prototype["default"]=function(){return e.prototype.attribute.call(this,"default",this.toAny)},t.prototype.setDefault=function(e){return this.highLevel().attrOrCreate("default").setValue(""+e),this},t.prototype.example=function(){return e.prototype.attribute.call(this,"example",this.toString)},t.prototype.setExample=function(e){return this.highLevel().attrOrCreate("example").setValue(""+e),this},t.prototype.repeat=function(){return e.prototype.attribute.call(this,"repeat",this.toBoolean)},t.prototype.setRepeat=function(e){return this.highLevel().attrOrCreate("repeat").setValue(""+e),this},t.prototype.description=function(){return e.prototype.attribute.call(this,"description",function(e){return new G(e)})},t.prototype.wrapperClassName=function(){return"ParameterImpl"},t.prototype.kind=function(){return"Parameter"},t.prototype.allKinds=function(){return e.prototype.allKinds.call(this).concat("Parameter")},t.prototype.allWrapperClassNames=function(){return e.prototype.allWrapperClassNames.call(this).concat("RAML08.ParameterImpl")},t.isInstance=function(e){if(null!=e&&e.allWrapperClassNames&&"function"==typeof e.allWrapperClassNames)for(var t=0,n=e.allWrapperClassNames();t<n.length;t++){var r=n[t];if("RAML08.ParameterImpl"==r)return!0}return!1},t.prototype.RAMLVersion=function(){return"RAML08"},t}(L.BasicNodeImpl);t.ParameterImpl=H;var $=function(){function e(e){this.attr=e}return e.prototype.wrapperClassName=function(){return"ParameterLocationImpl"},e.prototype.kind=function(){return"ParameterLocation"},e.prototype.allKinds=function(){return["ParameterLocation"]},e.prototype.allWrapperClassNames=function(){return["RAML08.ParameterLocationImpl"]},e.isInstance=function(e){if(null!=e&&e.allWrapperClassNames&&"function"==typeof e.allWrapperClassNames)for(var t=0,n=e.allWrapperClassNames();t<n.length;t++){var r=n[t];if("RAML08.ParameterLocationImpl"==r)return!0}return!1},e.prototype.RAMLVersion=function(){return"RAML08"},e}();t.ParameterLocationImpl=$;var G=function(e){function t(){e.apply(this,arguments)}return R(t,e),t.prototype.wrapperClassName=function(){return"MarkdownStringImpl"},t.prototype.kind=function(){return"MarkdownString"},t.prototype.allKinds=function(){return e.prototype.allKinds.call(this).concat("MarkdownString")},t.prototype.allWrapperClassNames=function(){return e.prototype.allWrapperClassNames.call(this).concat("RAML08.MarkdownStringImpl")},t.isInstance=function(e){if(null!=e&&e.allWrapperClassNames&&"function"==typeof e.allWrapperClassNames)for(var t=0,n=e.allWrapperClassNames();t<n.length;t++){var r=n[t];if("RAML08.MarkdownStringImpl"==r)return!0}return!1},t.prototype.RAMLVersion=function(){return"RAML08"},t}(q);t.MarkdownStringImpl=G;var X=function(e){function t(t,n){void 0===n&&(n=!0),e.call(this,"string"==typeof t?i(t):t,n),this.nodeOrKey=t,this.setAsTopLevel=n}return R(t,e),t.prototype.pattern=function(){return e.prototype.attribute.call(this,"pattern",this.toString)},t.prototype.setPattern=function(e){return this.highLevel().attrOrCreate("pattern").setValue(""+e),this},t.prototype["enum"]=function(){return e.prototype.attributes.call(this,"enum",this.toString)},t.prototype.setEnum=function(e){return this.highLevel().attrOrCreate("enum").setValue(""+e),this},t.prototype.minLength=function(){return e.prototype.attribute.call(this,"minLength",this.toNumber)},t.prototype.setMinLength=function(e){return this.highLevel().attrOrCreate("minLength").setValue(""+e),this},t.prototype.maxLength=function(){return e.prototype.attribute.call(this,"maxLength",this.toNumber)},t.prototype.setMaxLength=function(e){return this.highLevel().attrOrCreate("maxLength").setValue(""+e),this},t.prototype.wrapperClassName=function(){return"StringTypeDeclarationImpl"},t.prototype.kind=function(){return"StringTypeDeclaration"},t.prototype.allKinds=function(){return e.prototype.allKinds.call(this).concat("StringTypeDeclaration")},t.prototype.allWrapperClassNames=function(){return e.prototype.allWrapperClassNames.call(this).concat("RAML08.StringTypeDeclarationImpl")},t.isInstance=function(e){if(null!=e&&e.allWrapperClassNames&&"function"==typeof e.allWrapperClassNames)for(var t=0,n=e.allWrapperClassNames();t<n.length;t++){var r=n[t];if("RAML08.StringTypeDeclarationImpl"==r)return!0}return!1},t.prototype.RAMLVersion=function(){return"RAML08"},t}(H);t.StringTypeDeclarationImpl=X;var z=function(e){function t(t,n){void 0===n&&(n=!0),e.call(this,"string"==typeof t?a(t):t,n),this.nodeOrKey=t,this.setAsTopLevel=n}return R(t,e),t.prototype.wrapperClassName=function(){return"BooleanTypeDeclarationImpl"},t.prototype.kind=function(){return"BooleanTypeDeclaration"},t.prototype.allKinds=function(){return e.prototype.allKinds.call(this).concat("BooleanTypeDeclaration")},t.prototype.allWrapperClassNames=function(){return e.prototype.allWrapperClassNames.call(this).concat("RAML08.BooleanTypeDeclarationImpl")},t.isInstance=function(e){if(null!=e&&e.allWrapperClassNames&&"function"==typeof e.allWrapperClassNames)for(var t=0,n=e.allWrapperClassNames();t<n.length;t++){var r=n[t];if("RAML08.BooleanTypeDeclarationImpl"==r)return!0}return!1},t.prototype.RAMLVersion=function(){return"RAML08"},t}(H);t.BooleanTypeDeclarationImpl=z;var J=function(e){function t(t,n){void 0===n&&(n=!0),e.call(this,"string"==typeof t?o(t):t,n),this.nodeOrKey=t,this.setAsTopLevel=n}return R(t,e),t.prototype.minimum=function(){return e.prototype.attribute.call(this,"minimum",this.toNumber)},t.prototype.setMinimum=function(e){return this.highLevel().attrOrCreate("minimum").setValue(""+e),this},t.prototype.maximum=function(){return e.prototype.attribute.call(this,"maximum",this.toNumber)},t.prototype.setMaximum=function(e){return this.highLevel().attrOrCreate("maximum").setValue(""+e),this},t.prototype.wrapperClassName=function(){return"NumberTypeDeclarationImpl"},t.prototype.kind=function(){return"NumberTypeDeclaration"},t.prototype.allKinds=function(){return e.prototype.allKinds.call(this).concat("NumberTypeDeclaration")},t.prototype.allWrapperClassNames=function(){return e.prototype.allWrapperClassNames.call(this).concat("RAML08.NumberTypeDeclarationImpl")},t.isInstance=function(e){if(null!=e&&e.allWrapperClassNames&&"function"==typeof e.allWrapperClassNames)for(var t=0,n=e.allWrapperClassNames();t<n.length;t++){var r=n[t];if("RAML08.NumberTypeDeclarationImpl"==r)return!0}return!1},t.prototype.RAMLVersion=function(){return"RAML08"},t}(H);t.NumberTypeDeclarationImpl=J;var Q=function(e){function t(t,n){void 0===n&&(n=!0),e.call(this,"string"==typeof t?s(t):t,n),this.nodeOrKey=t,this.setAsTopLevel=n}return R(t,e),t.prototype.wrapperClassName=function(){return"IntegerTypeDeclarationImpl"},t.prototype.kind=function(){return"IntegerTypeDeclaration"},t.prototype.allKinds=function(){return e.prototype.allKinds.call(this).concat("IntegerTypeDeclaration")},t.prototype.allWrapperClassNames=function(){return e.prototype.allWrapperClassNames.call(this).concat("RAML08.IntegerTypeDeclarationImpl")},t.isInstance=function(e){if(null!=e&&e.allWrapperClassNames&&"function"==typeof e.allWrapperClassNames)for(var t=0,n=e.allWrapperClassNames();t<n.length;t++){var r=n[t];if("RAML08.IntegerTypeDeclarationImpl"==r)return!0}return!1},t.prototype.RAMLVersion=function(){return"RAML08"},t}(J);t.IntegerTypeDeclarationImpl=Q;var Z=function(e){function t(t,n){void 0===n&&(n=!0),e.call(this,"string"==typeof t?u(t):t,n),this.nodeOrKey=t,this.setAsTopLevel=n}return R(t,e),t.prototype.wrapperClassName=function(){return"DateTypeDeclarationImpl"},t.prototype.kind=function(){return"DateTypeDeclaration"},t.prototype.allKinds=function(){return e.prototype.allKinds.call(this).concat("DateTypeDeclaration")},t.prototype.allWrapperClassNames=function(){return e.prototype.allWrapperClassNames.call(this).concat("RAML08.DateTypeDeclarationImpl")},t.isInstance=function(e){if(null!=e&&e.allWrapperClassNames&&"function"==typeof e.allWrapperClassNames)for(var t=0,n=e.allWrapperClassNames();t<n.length;t++){var r=n[t];if("RAML08.DateTypeDeclarationImpl"==r)return!0}return!1},t.prototype.RAMLVersion=function(){return"RAML08"},t}(H);t.DateTypeDeclarationImpl=Z;var ee=function(e){function t(t,n){void 0===n&&(n=!0),e.call(this,"string"==typeof t?l(t):t,n),this.nodeOrKey=t,this.setAsTopLevel=n}return R(t,e),t.prototype.wrapperClassName=function(){return"FileTypeDeclarationImpl"},t.prototype.kind=function(){return"FileTypeDeclaration"},t.prototype.allKinds=function(){return e.prototype.allKinds.call(this).concat("FileTypeDeclaration")},t.prototype.allWrapperClassNames=function(){return e.prototype.allWrapperClassNames.call(this).concat("RAML08.FileTypeDeclarationImpl")},t.isInstance=function(e){if(null!=e&&e.allWrapperClassNames&&"function"==typeof e.allWrapperClassNames)for(var t=0,n=e.allWrapperClassNames();t<n.length;t++){var r=n[t];if("RAML08.FileTypeDeclarationImpl"==r)return!0}return!1},t.prototype.RAMLVersion=function(){return"RAML08"},t}(H);t.FileTypeDeclarationImpl=ee;var te=function(e){function t(){e.apply(this,arguments)}return R(t,e),t.prototype.name=function(){return e.prototype.attribute.call(this,"name",this.toString)},t.prototype.setName=function(e){return this.highLevel().attrOrCreate("name").setValue(""+e),this},t.prototype.schema=function(){return e.prototype.attribute.call(this,"schema",function(e){return new ne(e)})},t.prototype.example=function(){return e.prototype.attribute.call(this,"example",function(e){return new ae(e)})},t.prototype.formParameters=function(){return e.prototype.elements.call(this,"formParameters")},t.prototype.description=function(){return e.prototype.attribute.call(this,"description",function(e){return new G(e)})},t.prototype.wrapperClassName=function(){return"BodyLikeImpl"},t.prototype.kind=function(){return"BodyLike"},t.prototype.allKinds=function(){return e.prototype.allKinds.call(this).concat("BodyLike")},t.prototype.allWrapperClassNames=function(){return e.prototype.allWrapperClassNames.call(this).concat("RAML08.BodyLikeImpl")},t.isInstance=function(e){if(null!=e&&e.allWrapperClassNames&&"function"==typeof e.allWrapperClassNames)for(var t=0,n=e.allWrapperClassNames();t<n.length;t++){var r=n[t];if("RAML08.BodyLikeImpl"==r)return!0}return!1},t.prototype.RAMLVersion=function(){return"RAML08";
},t.prototype.schemaContent=function(){return O.schemaContent(this)},t}(L.BasicNodeImpl);t.BodyLikeImpl=te;var ne=function(e){function t(){e.apply(this,arguments)}return R(t,e),t.prototype.wrapperClassName=function(){return"SchemaStringImpl"},t.prototype.kind=function(){return"SchemaString"},t.prototype.allKinds=function(){return e.prototype.allKinds.call(this).concat("SchemaString")},t.prototype.allWrapperClassNames=function(){return e.prototype.allWrapperClassNames.call(this).concat("RAML08.SchemaStringImpl")},t.isInstance=function(e){if(null!=e&&e.allWrapperClassNames&&"function"==typeof e.allWrapperClassNames)for(var t=0,n=e.allWrapperClassNames();t<n.length;t++){var r=n[t];if("RAML08.SchemaStringImpl"==r)return!0}return!1},t.prototype.RAMLVersion=function(){return"RAML08"},t}(q);t.SchemaStringImpl=ne;var re=function(e){function t(){e.apply(this,arguments)}return R(t,e),t.prototype.wrapperClassName=function(){return"JSonSchemaStringImpl"},t.prototype.kind=function(){return"JSonSchemaString"},t.prototype.allKinds=function(){return e.prototype.allKinds.call(this).concat("JSonSchemaString")},t.prototype.allWrapperClassNames=function(){return e.prototype.allWrapperClassNames.call(this).concat("RAML08.JSonSchemaStringImpl")},t.isInstance=function(e){if(null!=e&&e.allWrapperClassNames&&"function"==typeof e.allWrapperClassNames)for(var t=0,n=e.allWrapperClassNames();t<n.length;t++){var r=n[t];if("RAML08.JSonSchemaStringImpl"==r)return!0}return!1},t.prototype.RAMLVersion=function(){return"RAML08"},t}(ne);t.JSonSchemaStringImpl=re;var ie=function(e){function t(){e.apply(this,arguments)}return R(t,e),t.prototype.wrapperClassName=function(){return"XMLSchemaStringImpl"},t.prototype.kind=function(){return"XMLSchemaString"},t.prototype.allKinds=function(){return e.prototype.allKinds.call(this).concat("XMLSchemaString")},t.prototype.allWrapperClassNames=function(){return e.prototype.allWrapperClassNames.call(this).concat("RAML08.XMLSchemaStringImpl")},t.isInstance=function(e){if(null!=e&&e.allWrapperClassNames&&"function"==typeof e.allWrapperClassNames)for(var t=0,n=e.allWrapperClassNames();t<n.length;t++){var r=n[t];if("RAML08.XMLSchemaStringImpl"==r)return!0}return!1},t.prototype.RAMLVersion=function(){return"RAML08"},t}(ne);t.XMLSchemaStringImpl=ie;var ae=function(e){function t(){e.apply(this,arguments)}return R(t,e),t.prototype.wrapperClassName=function(){return"ExampleStringImpl"},t.prototype.kind=function(){return"ExampleString"},t.prototype.allKinds=function(){return e.prototype.allKinds.call(this).concat("ExampleString")},t.prototype.allWrapperClassNames=function(){return e.prototype.allWrapperClassNames.call(this).concat("RAML08.ExampleStringImpl")},t.isInstance=function(e){if(null!=e&&e.allWrapperClassNames&&"function"==typeof e.allWrapperClassNames)for(var t=0,n=e.allWrapperClassNames();t<n.length;t++){var r=n[t];if("RAML08.ExampleStringImpl"==r)return!0}return!1},t.prototype.RAMLVersion=function(){return"RAML08"},t}(q);t.ExampleStringImpl=ae;var oe=function(e){function t(){e.apply(this,arguments)}return R(t,e),t.prototype.wrapperClassName=function(){return"JSONExampleImpl"},t.prototype.kind=function(){return"JSONExample"},t.prototype.allKinds=function(){return e.prototype.allKinds.call(this).concat("JSONExample")},t.prototype.allWrapperClassNames=function(){return e.prototype.allWrapperClassNames.call(this).concat("RAML08.JSONExampleImpl")},t.isInstance=function(e){if(null!=e&&e.allWrapperClassNames&&"function"==typeof e.allWrapperClassNames)for(var t=0,n=e.allWrapperClassNames();t<n.length;t++){var r=n[t];if("RAML08.JSONExampleImpl"==r)return!0}return!1},t.prototype.RAMLVersion=function(){return"RAML08"},t}(ae);t.JSONExampleImpl=oe;var se=function(e){function t(){e.apply(this,arguments)}return R(t,e),t.prototype.wrapperClassName=function(){return"XMLExampleImpl"},t.prototype.kind=function(){return"XMLExample"},t.prototype.allKinds=function(){return e.prototype.allKinds.call(this).concat("XMLExample")},t.prototype.allWrapperClassNames=function(){return e.prototype.allWrapperClassNames.call(this).concat("RAML08.XMLExampleImpl")},t.isInstance=function(e){if(null!=e&&e.allWrapperClassNames&&"function"==typeof e.allWrapperClassNames)for(var t=0,n=e.allWrapperClassNames();t<n.length;t++){var r=n[t];if("RAML08.XMLExampleImpl"==r)return!0}return!1},t.prototype.RAMLVersion=function(){return"RAML08"},t}(ae);t.XMLExampleImpl=se;var ue=function(e){function t(t,n){void 0===n&&(n=!0),e.call(this,"string"==typeof t?p(t):t,n),this.nodeOrKey=t,this.setAsTopLevel=n}return R(t,e),t.prototype.schema=function(){return e.prototype.attribute.call(this,"schema",function(e){return new ie(e)})},t.prototype.wrapperClassName=function(){return"XMLBodyImpl"},t.prototype.kind=function(){return"XMLBody"},t.prototype.allKinds=function(){return e.prototype.allKinds.call(this).concat("XMLBody")},t.prototype.allWrapperClassNames=function(){return e.prototype.allWrapperClassNames.call(this).concat("RAML08.XMLBodyImpl")},t.isInstance=function(e){if(null!=e&&e.allWrapperClassNames&&"function"==typeof e.allWrapperClassNames)for(var t=0,n=e.allWrapperClassNames();t<n.length;t++){var r=n[t];if("RAML08.XMLBodyImpl"==r)return!0}return!1},t.prototype.RAMLVersion=function(){return"RAML08"},t}(te);t.XMLBodyImpl=ue;var le=function(e){function t(t,n){void 0===n&&(n=!0),e.call(this,"string"==typeof t?c(t):t,n),this.nodeOrKey=t,this.setAsTopLevel=n}return R(t,e),t.prototype.schema=function(){return e.prototype.attribute.call(this,"schema",function(e){return new re(e)})},t.prototype.wrapperClassName=function(){return"JSONBodyImpl"},t.prototype.kind=function(){return"JSONBody"},t.prototype.allKinds=function(){return e.prototype.allKinds.call(this).concat("JSONBody")},t.prototype.allWrapperClassNames=function(){return e.prototype.allWrapperClassNames.call(this).concat("RAML08.JSONBodyImpl")},t.isInstance=function(e){if(null!=e&&e.allWrapperClassNames&&"function"==typeof e.allWrapperClassNames)for(var t=0,n=e.allWrapperClassNames();t<n.length;t++){var r=n[t];if("RAML08.JSONBodyImpl"==r)return!0}return!1},t.prototype.RAMLVersion=function(){return"RAML08"},t}(te);t.JSONBodyImpl=le;var pe=function(e){function t(){e.apply(this,arguments)}return R(t,e),t.prototype.wrapperClassName=function(){return"SecuritySchemeRefImpl"},t.prototype.kind=function(){return"SecuritySchemeRef"},t.prototype.allKinds=function(){return e.prototype.allKinds.call(this).concat("SecuritySchemeRef")},t.prototype.allWrapperClassNames=function(){return e.prototype.allWrapperClassNames.call(this).concat("RAML08.SecuritySchemeRefImpl")},t.isInstance=function(e){if(null!=e&&e.allWrapperClassNames&&"function"==typeof e.allWrapperClassNames)for(var t=0,n=e.allWrapperClassNames();t<n.length;t++){var r=n[t];if("RAML08.SecuritySchemeRefImpl"==r)return!0}return!1},t.prototype.RAMLVersion=function(){return"RAML08"},t.prototype.securitySchemeName=function(){return O.securitySchemeName(this)},t.prototype.securityScheme=function(){return O.securityScheme(this)},t}(B);t.SecuritySchemeRefImpl=pe;var ce=function(e){function t(){e.apply(this,arguments)}return R(t,e),t.prototype.name=function(){return e.prototype.attribute.call(this,"name",this.toString)},t.prototype.setName=function(e){return this.highLevel().attrOrCreate("name").setValue(""+e),this},t.prototype.type=function(){return e.prototype.attribute.call(this,"type",this.toString)},t.prototype.setType=function(e){return this.highLevel().attrOrCreate("type").setValue(""+e),this},t.prototype.description=function(){return e.prototype.attribute.call(this,"description",function(e){return new G(e)})},t.prototype.describedBy=function(){return e.prototype.element.call(this,"describedBy")},t.prototype.settings=function(){return e.prototype.element.call(this,"settings")},t.prototype.wrapperClassName=function(){return"AbstractSecuritySchemeImpl"},t.prototype.kind=function(){return"AbstractSecurityScheme"},t.prototype.allKinds=function(){return e.prototype.allKinds.call(this).concat("AbstractSecurityScheme")},t.prototype.allWrapperClassNames=function(){return e.prototype.allWrapperClassNames.call(this).concat("RAML08.AbstractSecuritySchemeImpl")},t.isInstance=function(e){if(null!=e&&e.allWrapperClassNames&&"function"==typeof e.allWrapperClassNames)for(var t=0,n=e.allWrapperClassNames();t<n.length;t++){var r=n[t];if("RAML08.AbstractSecuritySchemeImpl"==r)return!0}return!1},t.prototype.RAMLVersion=function(){return"RAML08"},t}(L.BasicNodeImpl);t.AbstractSecuritySchemeImpl=ce;var fe=function(e){function t(t,n){void 0===n&&(n=!0),e.call(this,"string"==typeof t?f(t):t,n),this.nodeOrKey=t,this.setAsTopLevel=n}return R(t,e),t.prototype.displayName=function(){return e.prototype.attribute.call(this,"displayName",this.toString)},t.prototype.setDisplayName=function(e){return this.highLevel().attrOrCreate("displayName").setValue(""+e),this},t.prototype.is=function(){return e.prototype.attributes.call(this,"is",function(e){return new me(e)})},t.prototype.headers=function(){return e.prototype.elements.call(this,"headers")},t.prototype.queryParameters=function(){return e.prototype.elements.call(this,"queryParameters")},t.prototype.responses=function(){return e.prototype.elements.call(this,"responses")},t.prototype.description=function(){return e.prototype.attribute.call(this,"description",function(e){return new G(e)})},t.prototype.wrapperClassName=function(){return"SecuritySchemePartImpl"},t.prototype.kind=function(){return"SecuritySchemePart"},t.prototype.allKinds=function(){return e.prototype.allKinds.call(this).concat("SecuritySchemePart")},t.prototype.allWrapperClassNames=function(){return e.prototype.allWrapperClassNames.call(this).concat("RAML08.SecuritySchemePartImpl")},t.isInstance=function(e){if(null!=e&&e.allWrapperClassNames&&"function"==typeof e.allWrapperClassNames)for(var t=0,n=e.allWrapperClassNames();t<n.length;t++){var r=n[t];if("RAML08.SecuritySchemePartImpl"==r)return!0}return!1},t.prototype.RAMLVersion=function(){return"RAML08"},t}(j);t.SecuritySchemePartImpl=fe;var me=function(e){function t(){e.apply(this,arguments)}return R(t,e),t.prototype.wrapperClassName=function(){return"TraitRefImpl"},t.prototype.kind=function(){return"TraitRef"},t.prototype.allKinds=function(){return e.prototype.allKinds.call(this).concat("TraitRef")},t.prototype.allWrapperClassNames=function(){return e.prototype.allWrapperClassNames.call(this).concat("RAML08.TraitRefImpl")},t.isInstance=function(e){if(null!=e&&e.allWrapperClassNames&&"function"==typeof e.allWrapperClassNames)for(var t=0,n=e.allWrapperClassNames();t<n.length;t++){var r=n[t];if("RAML08.TraitRefImpl"==r)return!0}return!1},t.prototype.RAMLVersion=function(){return"RAML08"},t.prototype.trait=function(){return O.referencedTrait(this)},t}(B);t.TraitRefImpl=me;var de=function(e){function t(t,n){void 0===n&&(n=!0),e.call(this,"string"==typeof t?m(t):t,n),this.nodeOrKey=t,this.setAsTopLevel=n}return R(t,e),t.prototype.name=function(){return e.prototype.attribute.call(this,"name",this.toString)},t.prototype.setName=function(e){return this.highLevel().attrOrCreate("name").setValue(""+e),this},t.prototype.usage=function(){return e.prototype.attribute.call(this,"usage",this.toString)},t.prototype.setUsage=function(e){return this.highLevel().attrOrCreate("usage").setValue(""+e),this},t.prototype.displayName=function(){return e.prototype.attribute.call(this,"displayName",this.toString)},t.prototype.setDisplayName=function(e){return this.highLevel().attrOrCreate("displayName").setValue(""+e),this},t.prototype.wrapperClassName=function(){return"TraitImpl"},t.prototype.kind=function(){return"Trait"},t.prototype.allKinds=function(){return e.prototype.allKinds.call(this).concat("Trait")},t.prototype.allWrapperClassNames=function(){return e.prototype.allWrapperClassNames.call(this).concat("RAML08.TraitImpl")},t.isInstance=function(e){if(null!=e&&e.allWrapperClassNames&&"function"==typeof e.allWrapperClassNames)for(var t=0,n=e.allWrapperClassNames();t<n.length;t++){var r=n[t];if("RAML08.TraitImpl"==r)return!0}return!1},t.prototype.RAMLVersion=function(){return"RAML08"},t.prototype.parametrizedProperties=function(){return O.getTemplateParametrizedProperties(this)},t}(j);t.TraitImpl=de;var he=function(e){function t(){e.apply(this,arguments)}return R(t,e),t.prototype.wrapperClassName=function(){return"SecuritySchemeSettingsImpl"},t.prototype.kind=function(){return"SecuritySchemeSettings"},t.prototype.allKinds=function(){return e.prototype.allKinds.call(this).concat("SecuritySchemeSettings")},t.prototype.allWrapperClassNames=function(){return e.prototype.allWrapperClassNames.call(this).concat("RAML08.SecuritySchemeSettingsImpl")},t.isInstance=function(e){if(null!=e&&e.allWrapperClassNames&&"function"==typeof e.allWrapperClassNames)for(var t=0,n=e.allWrapperClassNames();t<n.length;t++){var r=n[t];if("RAML08.SecuritySchemeSettingsImpl"==r)return!0}return!1},t.prototype.RAMLVersion=function(){return"RAML08"},t}(L.BasicNodeImpl);t.SecuritySchemeSettingsImpl=he;var ye=function(e){function t(t,n){void 0===n&&(n=!0),e.call(this,"string"==typeof t?d(t):t,n),this.nodeOrKey=t,this.setAsTopLevel=n}return R(t,e),t.prototype.requestTokenUri=function(){return e.prototype.attribute.call(this,"requestTokenUri",function(e){return new ve(e)})},t.prototype.authorizationUri=function(){return e.prototype.attribute.call(this,"authorizationUri",function(e){return new ve(e)})},t.prototype.tokenCredentialsUri=function(){return e.prototype.attribute.call(this,"tokenCredentialsUri",function(e){return new ve(e)})},t.prototype.wrapperClassName=function(){return"OAuth1SecuritySchemeSettingsImpl"},t.prototype.kind=function(){return"OAuth1SecuritySchemeSettings"},t.prototype.allKinds=function(){return e.prototype.allKinds.call(this).concat("OAuth1SecuritySchemeSettings")},t.prototype.allWrapperClassNames=function(){return e.prototype.allWrapperClassNames.call(this).concat("RAML08.OAuth1SecuritySchemeSettingsImpl")},t.isInstance=function(e){if(null!=e&&e.allWrapperClassNames&&"function"==typeof e.allWrapperClassNames)for(var t=0,n=e.allWrapperClassNames();t<n.length;t++){var r=n[t];if("RAML08.OAuth1SecuritySchemeSettingsImpl"==r)return!0}return!1},t.prototype.RAMLVersion=function(){return"RAML08"},t}(he);t.OAuth1SecuritySchemeSettingsImpl=ye;var ve=function(e){function t(){e.apply(this,arguments)}return R(t,e),t.prototype.wrapperClassName=function(){return"FixedUriImpl"},t.prototype.kind=function(){return"FixedUri"},t.prototype.allKinds=function(){return e.prototype.allKinds.call(this).concat("FixedUri")},t.prototype.allWrapperClassNames=function(){return e.prototype.allWrapperClassNames.call(this).concat("RAML08.FixedUriImpl")},t.isInstance=function(e){if(null!=e&&e.allWrapperClassNames&&"function"==typeof e.allWrapperClassNames)for(var t=0,n=e.allWrapperClassNames();t<n.length;t++){var r=n[t];if("RAML08.FixedUriImpl"==r)return!0}return!1},t.prototype.RAMLVersion=function(){return"RAML08"},t}(q);t.FixedUriImpl=ve;var ge=function(e){function t(t,n){void 0===n&&(n=!0),e.call(this,"string"==typeof t?h(t):t,n),this.nodeOrKey=t,this.setAsTopLevel=n}return R(t,e),t.prototype.accessTokenUri=function(){return e.prototype.attribute.call(this,"accessTokenUri",function(e){return new ve(e)})},t.prototype.authorizationUri=function(){return e.prototype.attribute.call(this,"authorizationUri",function(e){return new ve(e)})},t.prototype.authorizationGrants=function(){return e.prototype.attributes.call(this,"authorizationGrants",this.toString)},t.prototype.setAuthorizationGrants=function(e){return this.highLevel().attrOrCreate("authorizationGrants").setValue(""+e),this},t.prototype.scopes=function(){return e.prototype.attributes.call(this,"scopes",this.toString)},t.prototype.setScopes=function(e){return this.highLevel().attrOrCreate("scopes").setValue(""+e),this},t.prototype.wrapperClassName=function(){return"OAuth2SecuritySchemeSettingsImpl"},t.prototype.kind=function(){return"OAuth2SecuritySchemeSettings"},t.prototype.allKinds=function(){return e.prototype.allKinds.call(this).concat("OAuth2SecuritySchemeSettings")},t.prototype.allWrapperClassNames=function(){return e.prototype.allWrapperClassNames.call(this).concat("RAML08.OAuth2SecuritySchemeSettingsImpl")},t.isInstance=function(e){if(null!=e&&e.allWrapperClassNames&&"function"==typeof e.allWrapperClassNames)for(var t=0,n=e.allWrapperClassNames();t<n.length;t++){var r=n[t];if("RAML08.OAuth2SecuritySchemeSettingsImpl"==r)return!0}return!1},t.prototype.RAMLVersion=function(){return"RAML08"},t}(he);t.OAuth2SecuritySchemeSettingsImpl=ge;var Ae=function(e){function t(t,n){void 0===n&&(n=!0),e.call(this,"string"==typeof t?y(t):t,n),this.nodeOrKey=t,this.setAsTopLevel=n}return R(t,e),t.prototype.settings=function(){return e.prototype.element.call(this,"settings")},t.prototype.wrapperClassName=function(){return"OAuth2SecuritySchemeImpl"},t.prototype.kind=function(){return"OAuth2SecurityScheme"},t.prototype.allKinds=function(){return e.prototype.allKinds.call(this).concat("OAuth2SecurityScheme")},t.prototype.allWrapperClassNames=function(){return e.prototype.allWrapperClassNames.call(this).concat("RAML08.OAuth2SecuritySchemeImpl")},t.isInstance=function(e){if(null!=e&&e.allWrapperClassNames&&"function"==typeof e.allWrapperClassNames)for(var t=0,n=e.allWrapperClassNames();t<n.length;t++){var r=n[t];if("RAML08.OAuth2SecuritySchemeImpl"==r)return!0}return!1},t.prototype.RAMLVersion=function(){return"RAML08"},t}(ce);t.OAuth2SecuritySchemeImpl=Ae;var Se=function(e){function t(t,n){void 0===n&&(n=!0),e.call(this,"string"==typeof t?v(t):t,n),this.nodeOrKey=t,this.setAsTopLevel=n}return R(t,e),t.prototype.settings=function(){return e.prototype.element.call(this,"settings")},t.prototype.wrapperClassName=function(){return"OAuth1SecuritySchemeImpl"},t.prototype.kind=function(){return"OAuth1SecurityScheme"},t.prototype.allKinds=function(){return e.prototype.allKinds.call(this).concat("OAuth1SecurityScheme")},t.prototype.allWrapperClassNames=function(){return e.prototype.allWrapperClassNames.call(this).concat("RAML08.OAuth1SecuritySchemeImpl")},t.isInstance=function(e){if(null!=e&&e.allWrapperClassNames&&"function"==typeof e.allWrapperClassNames)for(var t=0,n=e.allWrapperClassNames();t<n.length;t++){var r=n[t];if("RAML08.OAuth1SecuritySchemeImpl"==r)return!0}return!1},t.prototype.RAMLVersion=function(){return"RAML08"},t}(ce);t.OAuth1SecuritySchemeImpl=Se;var Te=function(e){function t(t,n){void 0===n&&(n=!0),e.call(this,"string"==typeof t?g(t):t,n),this.nodeOrKey=t,this.setAsTopLevel=n}return R(t,e),t.prototype.wrapperClassName=function(){return"BasicSecuritySchemeImpl"},t.prototype.kind=function(){return"BasicSecurityScheme"},t.prototype.allKinds=function(){return e.prototype.allKinds.call(this).concat("BasicSecurityScheme")},t.prototype.allWrapperClassNames=function(){return e.prototype.allWrapperClassNames.call(this).concat("RAML08.BasicSecuritySchemeImpl")},t.isInstance=function(e){if(null!=e&&e.allWrapperClassNames&&"function"==typeof e.allWrapperClassNames)for(var t=0,n=e.allWrapperClassNames();t<n.length;t++){var r=n[t];if("RAML08.BasicSecuritySchemeImpl"==r)return!0}return!1},t.prototype.RAMLVersion=function(){return"RAML08"},t}(ce);t.BasicSecuritySchemeImpl=Te;var Ee=function(e){function t(t,n){void 0===n&&(n=!0),e.call(this,"string"==typeof t?A(t):t,n),this.nodeOrKey=t,this.setAsTopLevel=n}return R(t,e),t.prototype.wrapperClassName=function(){return"DigestSecuritySchemeImpl"},t.prototype.kind=function(){return"DigestSecurityScheme"},t.prototype.allKinds=function(){return e.prototype.allKinds.call(this).concat("DigestSecurityScheme")},t.prototype.allWrapperClassNames=function(){return e.prototype.allWrapperClassNames.call(this).concat("RAML08.DigestSecuritySchemeImpl")},t.isInstance=function(e){if(null!=e&&e.allWrapperClassNames&&"function"==typeof e.allWrapperClassNames)for(var t=0,n=e.allWrapperClassNames();t<n.length;t++){var r=n[t];if("RAML08.DigestSecuritySchemeImpl"==r)return!0}return!1},t.prototype.RAMLVersion=function(){return"RAML08"},t}(ce);t.DigestSecuritySchemeImpl=Ee;var be=function(e){function t(t,n){void 0===n&&(n=!0),e.call(this,"string"==typeof t?S(t):t,n),this.nodeOrKey=t,this.setAsTopLevel=n}return R(t,e),t.prototype.wrapperClassName=function(){return"CustomSecuritySchemeImpl"},t.prototype.kind=function(){return"CustomSecurityScheme"},t.prototype.allKinds=function(){return e.prototype.allKinds.call(this).concat("CustomSecurityScheme")},t.prototype.allWrapperClassNames=function(){return e.prototype.allWrapperClassNames.call(this).concat("RAML08.CustomSecuritySchemeImpl")},t.isInstance=function(e){if(null!=e&&e.allWrapperClassNames&&"function"==typeof e.allWrapperClassNames)for(var t=0,n=e.allWrapperClassNames();t<n.length;t++){var r=n[t];if("RAML08.CustomSecuritySchemeImpl"==r)return!0}return!1},t.prototype.RAMLVersion=function(){return"RAML08"},t}(ce);t.CustomSecuritySchemeImpl=be;var Ne=function(e){function t(t,n){void 0===n&&(n=!0),e.call(this,"string"==typeof t?r(t):t,n),this.nodeOrKey=t,this.setAsTopLevel=n}return R(t,e),t.prototype.method=function(){return e.prototype.attribute.call(this,"method",this.toString)},t.prototype.setMethod=function(e){return this.highLevel().attrOrCreate("method").setValue(""+e),this},t.prototype.is=function(){return e.prototype.attributes.call(this,"is",function(e){return new me(e)})},t.prototype.wrapperClassName=function(){return"MethodImpl"},t.prototype.kind=function(){return"Method"},t.prototype.allKinds=function(){return e.prototype.allKinds.call(this).concat("Method")},t.prototype.allWrapperClassNames=function(){return e.prototype.allWrapperClassNames.call(this).concat("RAML08.MethodImpl")},t.isInstance=function(e){if(null!=e&&e.allWrapperClassNames&&"function"==typeof e.allWrapperClassNames)for(var t=0,n=e.allWrapperClassNames();t<n.length;t++){var r=n[t];if("RAML08.MethodImpl"==r)return!0}return!1},t.prototype.RAMLVersion=function(){return"RAML08"},t.prototype.parentResource=function(){return O.parentResource(this)},t.prototype.ownerApi=function(){return O.ownerApi(this)},t.prototype.methodId=function(){return O.methodId(this)},t.prototype.allSecuredBy=function(){return O.allSecuredBy(this)},t}(j);t.MethodImpl=Ne;var _e=function(e){function t(){e.apply(this,arguments)}return R(t,e),t.prototype.wrapperClassName=function(){return"MimeTypeImpl"},t.prototype.kind=function(){return"MimeType"},t.prototype.allKinds=function(){return e.prototype.allKinds.call(this).concat("MimeType")},t.prototype.allWrapperClassNames=function(){return e.prototype.allWrapperClassNames.call(this).concat("RAML08.MimeTypeImpl")},t.isInstance=function(e){if(null!=e&&e.allWrapperClassNames&&"function"==typeof e.allWrapperClassNames)for(var t=0,n=e.allWrapperClassNames();t<n.length;t++){var r=n[t];if("RAML08.MimeTypeImpl"==r)return!0}return!1},t.prototype.RAMLVersion=function(){return"RAML08"},t}(q);t.MimeTypeImpl=_e;var Me=function(e){function t(){e.apply(this,arguments)}return R(t,e),t.prototype.wrapperClassName=function(){return"UriTemplateImpl"},t.prototype.kind=function(){return"UriTemplate"},t.prototype.allKinds=function(){return e.prototype.allKinds.call(this).concat("UriTemplate")},t.prototype.allWrapperClassNames=function(){return e.prototype.allWrapperClassNames.call(this).concat("RAML08.UriTemplateImpl")},t.isInstance=function(e){if(null!=e&&e.allWrapperClassNames&&"function"==typeof e.allWrapperClassNames)for(var t=0,n=e.allWrapperClassNames();t<n.length;t++){var r=n[t];if("RAML08.UriTemplateImpl"==r)return!0}return!1},t.prototype.RAMLVersion=function(){return"RAML08"},t}(q);t.UriTemplateImpl=Me;var we=function(e){function t(){e.apply(this,arguments)}return R(t,e),t.prototype.wrapperClassName=function(){return"RelativeUriStringImpl"},t.prototype.kind=function(){return"RelativeUriString"},t.prototype.allKinds=function(){return e.prototype.allKinds.call(this).concat("RelativeUriString")},t.prototype.allWrapperClassNames=function(){return e.prototype.allWrapperClassNames.call(this).concat("RAML08.RelativeUriStringImpl")},t.isInstance=function(e){if(null!=e&&e.allWrapperClassNames&&"function"==typeof e.allWrapperClassNames)for(var t=0,n=e.allWrapperClassNames();t<n.length;t++){var r=n[t];if("RAML08.RelativeUriStringImpl"==r)return!0}return!1},t.prototype.RAMLVersion=function(){return"RAML08"},t}(Me);t.RelativeUriStringImpl=we;var Re=function(e){function t(){e.apply(this,arguments)}return R(t,e),t.prototype.wrapperClassName=function(){return"FullUriTemplateStringImpl"},t.prototype.kind=function(){return"FullUriTemplateString"},t.prototype.allKinds=function(){return e.prototype.allKinds.call(this).concat("FullUriTemplateString")},t.prototype.allWrapperClassNames=function(){return e.prototype.allWrapperClassNames.call(this).concat("RAML08.FullUriTemplateStringImpl")},t.isInstance=function(e){if(null!=e&&e.allWrapperClassNames&&"function"==typeof e.allWrapperClassNames)for(var t=0,n=e.allWrapperClassNames();t<n.length;t++){var r=n[t];if("RAML08.FullUriTemplateStringImpl"==r)return!0}return!1},t.prototype.RAMLVersion=function(){return"RAML08"},t}(Me);t.FullUriTemplateStringImpl=Re;var Ie=function(e){function t(){e.apply(this,arguments)}return R(t,e),t.prototype.wrapperClassName=function(){return"RAMLSimpleElementImpl"},t.prototype.kind=function(){return"RAMLSimpleElement"},t.prototype.allKinds=function(){return e.prototype.allKinds.call(this).concat("RAMLSimpleElement")},t.prototype.allWrapperClassNames=function(){return e.prototype.allWrapperClassNames.call(this).concat("RAML08.RAMLSimpleElementImpl")},t.isInstance=function(e){if(null!=e&&e.allWrapperClassNames&&"function"==typeof e.allWrapperClassNames)for(var t=0,n=e.allWrapperClassNames();t<n.length;t++){var r=n[t];if("RAML08.RAMLSimpleElementImpl"==r)return!0}return!1},t.prototype.RAMLVersion=function(){return"RAML08"},t}(L.BasicNodeImpl);t.RAMLSimpleElementImpl=Ie;var Ce=function(e){function t(t,n){void 0===n&&(n=!0),e.call(this,"string"==typeof t?E(t):t,n),this.nodeOrKey=t,this.setAsTopLevel=n}return R(t,e),t.prototype.title=function(){return e.prototype.attribute.call(this,"title",this.toString)},t.prototype.setTitle=function(e){return this.highLevel().attrOrCreate("title").setValue(""+e),this},t.prototype.content=function(){return e.prototype.attribute.call(this,"content",function(e){return new G(e)})},t.prototype.wrapperClassName=function(){return"DocumentationItemImpl"},t.prototype.kind=function(){return"DocumentationItem"},t.prototype.allKinds=function(){return e.prototype.allKinds.call(this).concat("DocumentationItem")},t.prototype.allWrapperClassNames=function(){return e.prototype.allWrapperClassNames.call(this).concat("RAML08.DocumentationItemImpl")},t.isInstance=function(e){if(null!=e&&e.allWrapperClassNames&&"function"==typeof e.allWrapperClassNames)for(var t=0,n=e.allWrapperClassNames();t<n.length;t++){var r=n[t];if("RAML08.DocumentationItemImpl"==r)return!0}return!1},t.prototype.RAMLVersion=function(){return"RAML08"},t}(Ie);t.DocumentationItemImpl=Ce;var Le=function(e){function t(t,n){void 0===n&&(n=!0),e.call(this,"string"==typeof t?T(t):t,n),this.nodeOrKey=t,this.setAsTopLevel=n}return R(t,e),t.prototype.key=function(){return e.prototype.attribute.call(this,"key",this.toString)},t.prototype.setKey=function(e){return this.highLevel().attrOrCreate("key").setValue(""+e),this},t.prototype.value=function(){return e.prototype.attribute.call(this,"value",function(e){return new ne(e)})},t.prototype.wrapperClassName=function(){return"GlobalSchemaImpl"},t.prototype.kind=function(){return"GlobalSchema"},t.prototype.allKinds=function(){return e.prototype.allKinds.call(this).concat("GlobalSchema")},t.prototype.allWrapperClassNames=function(){return e.prototype.allWrapperClassNames.call(this).concat("RAML08.GlobalSchemaImpl")},t.isInstance=function(e){if(null!=e&&e.allWrapperClassNames&&"function"==typeof e.allWrapperClassNames)for(var t=0,n=e.allWrapperClassNames();t<n.length;t++){var r=n[t];if("RAML08.GlobalSchemaImpl"==r)return!0}return!1},t.prototype.RAMLVersion=function(){return"RAML08"},t}(Ie);t.GlobalSchemaImpl=Le;var Pe=function(e){function t(){e.apply(this,arguments)}return R(t,e),t.prototype.relativeUri=function(){return e.prototype.attribute.call(this,"relativeUri",function(e){return new we(e)})},t.prototype.type=function(){return e.prototype.attribute.call(this,"type",function(e){return new K(e)})},t.prototype.is=function(){return e.prototype.attributes.call(this,"is",function(e){return new me(e)})},t.prototype.securedBy=function(){return e.prototype.attributes.call(this,"securedBy",function(e){return new pe(e)})},t.prototype.uriParameters_original=function(){return e.prototype.elements.call(this,"uriParameters")},t.prototype.methods=function(){return e.prototype.elements.call(this,"methods")},t.prototype.resources=function(){return e.prototype.elements.call(this,"resources")},t.prototype.displayName=function(){return e.prototype.attribute.call(this,"displayName",this.toString)},t.prototype.setDisplayName=function(e){return this.highLevel().attrOrCreate("displayName").setValue(""+e),this},t.prototype.baseUriParameters=function(){return e.prototype.elements.call(this,"baseUriParameters")},t.prototype.description=function(){return e.prototype.attribute.call(this,"description",function(e){return new G(e)})},t.prototype.wrapperClassName=function(){return"ResourceImpl"},t.prototype.kind=function(){return"Resource"},t.prototype.allKinds=function(){return e.prototype.allKinds.call(this).concat("Resource")},t.prototype.allWrapperClassNames=function(){return e.prototype.allWrapperClassNames.call(this).concat("RAML08.ResourceImpl")},t.isInstance=function(e){if(null!=e&&e.allWrapperClassNames&&"function"==typeof e.allWrapperClassNames)for(var t=0,n=e.allWrapperClassNames();t<n.length;t++){var r=n[t];if("RAML08.ResourceImpl"==r)return!0}return!1},t.prototype.RAMLVersion=function(){return"RAML08"},t.prototype.completeRelativeUri=function(){return O.completeRelativeUri(this)},t.prototype.absoluteUri=function(){return O.absoluteUri(this)},t.prototype.parentResource=function(){return O.parent(this)},t.prototype.childResource=function(e){return O.childResource(this,e)},t.prototype.childMethod=function(e){return O.childMethod(this,e)},t.prototype.ownerApi=function(){return O.ownerApi(this)},t.prototype.uriParameters=function(){return O.uriParametersPrimary(this)},t.prototype.allUriParameters=function(){return O.uriParameters(this)},t.prototype.absoluteUriParameters=function(){return O.absoluteUriParameters(this)},t.prototype.allSecuredBy=function(){return O.allSecuredBy(this)},t}(L.BasicNodeImpl);t.ResourceImpl=Pe,t.loadApiSync=b,t.loadRAMLSync=N,t.loadApi=_,t.loadRAML=M,t.getLanguageElementByRuntimeType=w},function(e,t,n){"use strict";function r(e){var t=new re.Project(ie.dirname(e)),n=t.unit(ie.basename(e));return n&&n.isRAMLUnit()?X.fromUnit(n).wrapperNode():null}function i(e){var t=e.highLevel().lowLevel();return Q.LowLevelProxyNode.isInstance(t)?e:J.expandTraitsAndResourceTypes(e)}function a(e){var t="",n=e;do e=n,t=e.relativeUri().value()+t,n=e.parent();while(n.definition().key().name==z.Universe08.Resource.name);return t}function o(e){var t="",n=e;do e=n,t=e.relativeUri().value()+t,n=e.parent();while(n.definition().key().name==z.Universe08.Resource.name);t=t.replace(/\/\//g,"/");var r=n.baseUri(),i=r?r.value():"";return i=i?i:"",ee.stringEndsWith(i,"/")&&(t=t.substring(1)),t=i+t}function s(e){return X.qName(e.highLevel(),e.highLevel().root())}function u(e){return l(e)}function l(e){return f(e,function(e){return ne.isTraitType(e)})}function p(e){return c(e)}function c(e){return f(e,function(e){return ne.isResourceTypeType(e)})}function f(e,t){var n=te.globalDeclarations(e.highLevel()).filter(function(e){return t(e.definition())}),r=e.highLevel().lowLevel();if(!r)return[];var i=r.includePath();i||(i=r.unit().path());var a=n.map(function(e){var t,n=e.lowLevel().unit().path();return n!=i?(t=H.buildWrapperNode(e,!1),t.meta().setCalculated()):t=e.wrapperNode(),t});return a}function m(e){var t=[],n=e;do e=n,t.push(e.relativeUri().value()),n=e.parent();while(n.definition().key().name==z.Universe08.Resource.name);
return t.reverse()}function d(e){return Y.ResourceImpl.isInstance(e.parent())?e.parent():null}function h(e){var t=e.parent();return t.definition().key().name==z.Universe08.Resource.name,null}function y(e,t){if(null==e)return null;var n=e.resources();return n?(n=n.filter(function(e){return e.relativeUri().value()==t}),0==n.length?null:n[0]):null}function v(e,t){if(!e)return null;for(var n=null,r=0;r<t.length;r++){if(n=y(e,t[r]),!n)return null;e=n}return n}function g(e,t){return e?e.methods().filter(function(e){return e.method()==t}):null}function A(e,t,n){var r=v(e,t);return null==r?null:g(r,n)}function S(e){return e.definition().key().name==z.Universe08.Api.name}function T(e){for(var t=e;!S(t);)t=t.parent();return t}function E(e){var t=e.parent();if(Y.ResourceImpl.isInstance(t))return a(t)+" "+e.method().toLowerCase();if(Y.ResourceTypeImpl.isInstance(t))return t.name()+" "+e.method().toLowerCase();throw new Error("Method is supposed to be owned by Resource or ResourceType.\nHere the method is owned by "+e.definition().key().name)}function b(e){var t=e.code().value(),n=Z.validateResponseString(t);if(null!=n)return!1;try{if(parseInt(t.charAt(0))<4)return!0}catch(r){}return!1}function N(e){var t=[],n=function(e){t.push(e),e.resources().forEach(function(e){return n(e)})};return e.resources().forEach(function(e){return n(e)}),t}function _(e){return M(e)}function M(e){var t=e.relativeUri().value(),n=e.uriParameters_original(),r=z.Universe08.Resource.properties.uriParameters.name;return j(n,t,e,r)}function w(e){return R(e)}function R(e){var t=e.baseUri()?e.baseUri().value():"",n=e.baseUriParameters_original(),r=z.Universe08.Api.properties.baseUriParameters.name;return j(n,t,e,r)}function I(e){var t=[],n=e;do e=n,t=M(e).concat(t),n=e.parent();while(n.definition().key().name==z.Universe10.Resource.name);var r=n;r.baseUriParameters();return t=R(r).concat(t)}function C(e){return L(e)}function L(e){return e.protocols().map(function(e){return e.toUpperCase()})}function P(e){return O(e)}function O(e){return e.securedBy()}function D(e){var t=e.highLevel();if(!t)return"";var n=t.value();return n?n.toString():""}function x(e){var t=e.highLevel();if(!t)return null;var n=te.findDeclarationByNode(t,te.LocationKind.VALUE_COMPLETION);if(!n)return null;if(!n.getKind||n.getKind()!=G.NodeKind.NODE)return null;var r=n.wrapperNode();return Y.AbstractSecuritySchemeImpl.isInstance(r)?r:null}function U(e){return e.highLevel().definition().universe().version()}function k(e){var t=e.value().lowLevel();return new $.TypeInstanceImpl(t)}function F(e){var t=e.highLevel().value();return"string"==typeof t||null==t?t:t.valueName()}function B(e){return V(e)}function K(e){return V(e)}function V(e){var t=e.highLevel(),n=t.parent(),r=e.name(),i=te.referenceTargets(t.property(),n).filter(function(e){return X.qName(e,n)==r});return 0==i.length?null:i[0].wrapperNode()}function j(e,t,n,r){var i=n.highLevel(),a=i.definition().property(r);if(!t)return[];var o={};e.forEach(function(e){var t=o[e.name()];t||(t=[],o[e.name()]=t),t.push(e)});for(var s=[],u=0,l={},p=t.indexOf("{");p>=0&&(u=t.indexOf("}",++p),!(0>u));p=t.indexOf("{",u)){var c=t.substring(p,u);if(l[c]=!0,o[c])o[c].forEach(function(e){return s.push(e)});else{var f=new Y.StringTypeDeclarationImpl(c);f.setName(c);var m=f.highLevel();m.setParent(i),f.meta().setCalculated(),m.patchProp(a),s.push(f)}}return Object.keys(o).filter(function(e){return!l[e]}).forEach(function(e){return o[e].forEach(function(e){return s.push(e)})}),s}function W(e){var t=e.schema();if(null==t)return null;var n=t.value();if(!n)return null;var r=e.highLevel().attr(z.Universe08.BodyLike.properties.schema.name);if(!r)return n;var i=te.findDeclarationByNode(r,te.LocationKind.VALUE_COMPLETION);if(!i)return n;if(!i.getKind||i.getKind()!=G.NodeKind.NODE)return n;if(i.definition().key()!=z.Universe08.GlobalSchema)return n;var a=i.attr(z.Universe08.GlobalSchema.properties.value.name);return null==a?null:a.value()}function q(e){var t=e.highLevel();if(null==t)return null;var n=t.lowLevel();if(null==n)return null;var r=n.children().filter(function(e){return e.key().indexOf("<<")>=0});if(0==r.length)return null;var i=new $.TypeInstanceImpl(r);return i}var Y=n(50),H=n(45),$=n(47),G=n(9),X=n(16),z=n(17),J=n(29),Q=n(41),Z=n(30),ee=n(33),te=n(13),ne=n(14),re=n(26),ie=n(15);t.load=r,t.expandTraitsAndResourceTypes=i,t.completeRelativeUri=a,t.absoluteUri=o,t.qName=s,t.traitsPrimary=u,t.allTraits=l,t.resourceTypesPrimary=p,t.allResourceTypes=c,t.relativeUriSegments=m,t.parentResource=d,t.parent=h,t.childResource=y,t.getResource=v,t.childMethod=g,t.getMethod=A,t.ownerApi=T,t.methodId=E,t.isOkRange=b,t.allResources=N;t.uriParametersPrimary=_,t.uriParameters=M,t.baseUriParametersPrimary=w,t.baseUriParameters=R,t.absoluteUriParameters=I,t.protocolsPrimary=C,t.allProtocols=L,t.securedByPrimary=P,t.allSecuredBy=O,t.securitySchemeName=D,t.securityScheme=x,t.RAMLVersion=U,t.structuredValue=k,t.referenceName=F,t.referencedTrait=B,t.referencedResourceType=K,t.schemaContent=W,t.getTemplateParametrizedProperties=q},function(e,t,n){"use strict";function r(e){if(null==e||"string"!=typeof e)return{status:_.NOT_REQUIRED};for(var t="",n={},r=0,i=e.indexOf("<<");i>=0;i=e.indexOf("<<",r)){if(t+=e.substring(r,i),r=e.indexOf(">>",i),0>r)return{status:_.ERROR};r+=">>".length;var a=e.substring(i,r),o=M+i+M;n[o]=a,t+=o}return 0==t.length?{status:_.NOT_REQUIRED}:(t+=e.substring(r,e.length),{resultingString:t,substitutions:n,status:_.OK})}function i(e,t){if(null==e)return{status:_.NOT_REQUIRED};for(var n="",r=0,i=e.indexOf(M);i>=0;i=e.indexOf(M,r)){if(r=e.indexOf(M,i+1),r+=M.length,0>r)return{status:_.ERROR};var a=e.substring(i,r),o=t[a];if(null==o)return{status:_.ERROR};n+=o}return 0==n.length?{status:_.NOT_REQUIRED}:(n+=e.substring(r,e.length),{resultingString:n,substitutions:t,status:_.OK})}function a(e){for(var t=!1,n=0;n<e.length;n++){var r=e.charAt(n);if("|"==r||"("==r||"["==r){t=!0;break}}return t}function o(e,t){var n=e.lowLevel(),r=e.definition().universe().version(),i=u(n),a=v.Universe10.MethodBase.properties.is.name,o=g.find(n.children(),function(e){return e.key()==a});if(null==o){var l=new d.ASTNode(m.newMapping(m.newScalar(a),m.newItems()),i.unit(),i,null,null);o=n.replaceChild(null,l)}var p=g.find(i.children(),function(e){return e.key()==a}),c=null!=p?p.children():[],f=c.concat(t.map(function(e){var t=s(e.node,o);if(null!=t){var n=new y.LowLevelCompositeNode(t,o,e.transformer,r);return n}return null})).filter(function(e){return null!=e});return o.setChildren(f),o.filterChildren(),o}function s(e,t){t=u(t),e=u(e);var n=e.actual();if(null==n)return null;if(e.key()==v.Universe10.MethodBase.properties.is.name&&(n=e.yamlNode().value),null==n)return null;if(n.kind==m.Kind.SEQ&&(n=n.items[0]),null==n)return null;var r=new d.ASTNode(n,e.unit(),t,null,null);return r}function u(e){for(var t=0;2>t&&y.LowLevelProxyNode.isInstance(e);t++)e=e.originalNode();return e}function l(e){return e?null!=e.namespace&&"function"==typeof e.namespace&&null!=e.name&&"function"==typeof e.name&&null!=e.collectionName&&"function"==typeof e.collectionName&&null!=e.referencedUnit&&"function"==typeof e.referencedUnit&&null!=e.mode&&"function"==typeof e.mode:!1}function p(e,t,n,r){if(!e)return null;var i="",a=e,o=e.lastIndexOf(".");o>=0&&(i=e.substring(0,o),a=e.substring(o+1));for(var s,u=!1,l=r.length;l>0;l--){var p=r[l-1],c=p.highLevel();if(c.isElement()&&A.isLibraryType(c.asElement().definition())){if(u)break;u=!0}var f=p;if(i){f=null;var m=n.nsMap(p);if(m){var d=m[i];d&&(f=d.unit)}}if(f){var h=f.highLevel();if(h&&h.isElement()&&(s=g.find(h.asElement().elementsOfKind(t),function(e){return e.name()==a})))break}}return s}var c=n(10),f=n(16),m=n(75),d=n(26),h=n(33),y=n(41),v=n(17),g=n(64),A=n(14),S=n(49),T=n(37),E=T.rt.typeExpressions;!function(e){e[e.DEFAULT=0]="DEFAULT",e[e.PATH=1]="PATH"}(t.PatchMode||(t.PatchMode={}));var b=t.PatchMode,N=function(){function e(e){void 0===e&&(e=b.DEFAULT),this.mode=e,this._outerDependencies={},this._libModels={}}return e.prototype.process=function(e,t,n,r){if(void 0===t&&(t=e),void 0===n&&(n=!1),void 0===r&&(r=!1),!e.lowLevel().libProcessed){var i=e.lowLevel().unit().project().namespaceResolver();this.patchReferences(e,t,i),r&&this.patchNodeName(e,t.lowLevel().unit(),i),n?this.removeUses(e.lowLevel()):this.patchUses(e.lowLevel(),i),this.resetTypes(e),e.resetChildren(),e.lowLevel().libProcessed=!0}},e.prototype.patchReferences=function(e,t,n,r){void 0===t&&(t=e),void 0===n&&(n=new S.NamespaceResolver),void 0===r&&(r=[t.lowLevel().unit()]);var i;if(null!=e.definition().property(v.Universe10.TypeDeclaration.properties.annotations.name)){var a=e.lowLevel();if(!y.LowLevelCompositeNode.isInstance(a))return;var s=v.Universe10.MethodBase.properties.is.name,u=e.attributes(s);a.preserveAnnotations(),e.resetChildren(),0!=u.length&&(i=o(e,u.map(function(e){return e.lowLevel()}).map(function(e){return{node:e,transformer:e.transformer()}})))}for(var l=e.attrs(),p=0,c=l;p<c.length;p++){var f=c[p],m=this.appendUnitIfNeeded(f,r);this.patchReferenceAttr(f,t,n,r),this.popUnitIfNeeded(r,m)}if(A.isTypeDeclarationDescendant(e.definition())){var m=this.appendUnitIfNeeded(e,r);this.patchType(e,t,n,r),this.popUnitIfNeeded(r,m)}for(var d=e.elements(),h=0,g=d;h<g.length;h++){var T=g[h],m=this.appendUnitIfNeeded(T,r);this.patchReferences(T,t,n,r),this.popUnitIfNeeded(r,m)}i&&i.filterChildren()},e.prototype.patchReferenceAttr=function(e,t,n,r){var i=e.property(),a=i.range();if(a.isAssignableFrom(v.Universe10.Reference.name)){var o=e.value();if(null!=o){var s=e.lowLevel();if(y.LowLevelProxyNode.isInstance(s)){var l=s.transformer(),p=A.isAnnotationsProperty(i);if("string"==typeof o){var c=o;if(null!=l){var f=u(s);c=f.value()}p&&(c=c.substring(1,c.length-1));var m=this.resolveReferenceValue(c,t.lowLevel().unit(),r,n,l,a);if(null!=m){var d=p?"("+m.value()+")":m.value();e.lowLevel().setValueOverride(d),this.registerPatchedReference(m)}}else{var h=o,g=h.lowLevel().key(),c=g;if(null!=l){var f=u(h.lowLevel());c=f.key()}if(null!=g){p&&(c=c.substring(1,c.length-1));var m=this.resolveReferenceValue(c,t.lowLevel().unit(),r,n,l,a);if(null!=m){var d=p?"("+m.value()+")":m.value();h.lowLevel().setKeyOverride(d),this.registerPatchedReference(m)}}}}}}},e.prototype.patchType=function(e,t,n,o){var s=this,l=e.definition(),p=e.localType().isExternal();if(!p)for(var c=0,m=e.localType().allSuperTypes();c<m.length;c++){var d=m[c];if(p=d.isExternal())break}if(!p){var h=t.lowLevel().unit(),A=(h.absolutePath(),e.attributes(v.Universe10.TypeDeclaration.properties.type.name));0==A.length&&(A=e.attributes(v.Universe10.TypeDeclaration.properties.schema.name));var S=e.attributes(v.Universe10.ArrayTypeDeclaration.properties.items.name);A=A.concat(S);for(var T=0,b=A;T<b.length;T++){var N=b[T],M=N.lowLevel();if(y.LowLevelProxyNode.isInstance(M)){var w=N.lowLevel().unit(),R=(w.absolutePath(),N.value());if("string"==typeof R){var I=a(R),C=M.transformer(),L=R,P={status:_.NOT_REQUIRED},O=C?C.unitsChain:null;if(null!=C||R.indexOf("<<")>=0){var D=u(M),x=D.value();P=r(x),P.status==_.OK?L=I?P.resultingString:x:C=null}var U;if(O){U=[];for(var k=0,F=O;k<F.length;k++){var B=F[k];U.push(this.appendUnitIfNeeded(B,o))}}var K,V=this.appendUnitIfNeeded(N,o);if(I){var j=!1,W=E.parse(L),q=!1;E.visit(W,function(e){if("name"==e.type){var t,r=e,a=r.value,u={status:_.NOT_REQUIRED};if(P.status==_.OK)if(t=P.substitutions[a],null==t){if(u=i(a,P.substitutions),u.status==_.OK)a=u.resultingString;else if(u.status==_.ERROR)return void(j=!0)}else a=t;if(null==C&&(null!=t||u.status==_.OK))return void(r.value=a);var p=!0;a.indexOf("<<")>=0&&s.isCompoundValue(a)&&(p=!1);var c=s.resolveReferenceValue(a,h,o,n,C,l,p);null!=c&&(r.value=c.value(),q=!0,s.registerPatchedReference(c))}}),K=q&&!j?E.serializeToString(W):R}else if(P.status!=_.OK||null!=C){L.indexOf("<<")>=0&&this.isCompoundValue(L)&&(L=R,C=null);var Y=this.resolveReferenceValue(L,h,o,n,C,l);null!=Y&&(this.registerPatchedReference(Y),K=Y.value())}if(null!=K&&(N.lowLevel().setValueOverride(K),N.overrideValue(null)),this.popUnitIfNeeded(o,V),U)for(var H=0,$=U.reverse();H<$.length;H++){var G=$[H];this.popUnitIfNeeded(o,G)}}else{var X=N.lowLevel();if(X.key()!=N.property().nameId()&&(X=g.find(e.lowLevel().children(),function(e){return e.key()==N.property().nameId()})),X){var z=e.definition().universe().type(v.Universe10.TypeDeclaration.name),J=new f.ASTNodeImpl(X,null,z,null),Q=this.appendUnitIfNeeded(J,o);this.patchReferences(J,t,n,o),this.popUnitIfNeeded(o,Q)}}}}}},e.prototype.resolveReferenceValue=function(e,t,n,r,i,a,o){var s=this;void 0===o&&(o=!0);var u,p=A.isAnnotationRefTypeOrDescendant(a);if(i&&e&&e.indexOf("<<")>=0){var c=!0,f=t.highLevel().types(),m=i.transform(e,!0,function(){return c},function(e,n){var i=s.resolveReferenceValueBasic(e,t,r,n.unitsChain,a);return null==i&&(i=new w(null,e,s.collectionName(a),t,b.DEFAULT)),c=p?null!=f.getAnnotationType(i.value())?!1:!1:null!=f.getType(i.value())?!1:!1,i});u=m.value}return void 0!==u&&l(u)||(u=this.resolveReferenceValueBasic(e,t,r,n,a)),u},e.prototype.patchNodeName=function(e,t,n){var r=e.lowLevel(),i=r.key(),a=e.definition();if(A.isTypeDeclarationSibling(a)){var o=e.localType();o.isAnnotationType()&&(a=o)}var s=this.resolveReferenceValueBasic(i,t,n,[r.unit()],a);null!=s&&r.setKeyOverride(s.value())},e.prototype.resolveReferenceValueBasic=function(e,t,n,r,i){if(null==e||"string"!=typeof e)return null;var a,o,s=A.isTypeDeclarationDescendant(i),u=s&&h.stringEndsWith(e,"?"),l=u?e.substring(0,e.length-1):e,p=l.lastIndexOf(".");if(p>=0){var f=l.substring(0,p);o=l.substring(p+1);for(var m=r.length;m>0;m--){var d=r[m-1],y=n.nsMap(d);if(null!=y){var v=y[f];if(null!=v&&(a=v.unit,null!=a))break}}}else{if(s&&null!=T.rt.builtInTypes().get(l))return null;o=l,a=r[r.length-1]}var g=this.collectionName(i);if(null==a||a.absolutePath()==t.absolutePath())return null;var S=n.resolveNamespace(t,a);if(null==S)return null;var E=S.namespace();if(null==E)return null;if(this.mode==b.PATH){var N=a.absolutePath().replace(/\\/g,"/");c.isWebPath(N)||(N="file://"+N),E=N+"#/"+g}return u&&(o+="?"),new w(E,o,g,a,this.mode)},e.prototype.patchUses=function(e,t){if(y.LowLevelCompositeNode.isInstance(e)){var n=e.unit(),r=t.expandedPathMap(n);if(null!=r){var i=t.pathMap(n);i||(i={});for(var a=e,o=e.children(),s=o.filter(function(e){return e.key()==v.Universe10.FragmentDeclaration.properties.uses.name}),l=u(e),p=l;y.LowLevelProxyNode.isInstance(p);)p=p.originalNode();var c,f=Object.keys(i).map(function(e){return r[e]}),m=Object.keys(r).map(function(e){return r[e]}).filter(function(e){return!i[e.absolutePath()]}),h=e.unit(),g=(h.absolutePath(),{});if(s.length>0)c=s[0],c.children().forEach(function(e){return g[e.key()]=!0});else{var A=d.createMapNode("uses");A._parent=p,A.setUnit(p.unit()),c=a.replaceChild(null,A)}for(var S=0,T=f.concat(m);S<T.length;S++){var E=T[S];E.absolutePath();if(!g[E.namespace()]){var b=E.includePath,N=d.createMapping(E.namespace(),b);N.setUnit(p.unit()),c.replaceChild(null,N)}}}}},e.prototype.removeUses=function(e){if(y.LowLevelCompositeNode.isInstance(e)){var t=e,n=e.children(),r=n.filter(function(e){return e.key()==v.Universe10.FragmentDeclaration.properties.uses.name});r.length>0&&t.removeChild(r[0])}},e.prototype.resetTypes=function(e){for(var t=0,n=e.elements();t<n.length;t++){var r=n[t];this.resetTypes(r)}delete e.lowLevel().actual().types,delete e._ptype,delete e._types,e.setAssociatedType(null)},e.prototype.appendUnitIfNeeded=function(e,t){if(d.CompilationUnit.isInstance(e)){var n=e;return n.absolutePath()!=t[t.length-1].absolutePath()?(t.push(n),!0):!1}var r=u(e.lowLevel()),i=r.unit();if(r.valueKind()==m.Kind.INCLUDE_REF){var a=r.includePath(),o=i.resolve(a);return o?(t.push(o),!0):!1}return i.absolutePath()!=t[t.length-1].absolutePath()?(t.push(i),!0):!1},e.prototype.popUnitIfNeeded=function(e,t){t&&e.pop()},e.prototype.registerPatchedReference=function(e){var t=e.collectionName();if(t){var n=e.referencedUnit().absolutePath(),r=this._outerDependencies[n];null==r&&(r={},this._outerDependencies[n]=r);var i=r[t];null==i&&(i={},r[t]=i),i[e.name()]=e}},e.prototype.collectionName=function(e){var t;return A.isResourceTypeRefType(e)||A.isResourceTypeType(e)?t=T.universesInfo.Universe10.LibraryBase.properties.resourceTypes.name:A.isTraitRefType(e)||A.isTraitType(e)?t=T.universesInfo.Universe10.LibraryBase.properties.traits.name:A.isSecuritySchemeRefType(e)||A.isSecuritySchemaTypeDescendant(e)?t=T.universesInfo.Universe10.LibraryBase.properties.securitySchemes.name:A.isAnnotationRefTypeOrDescendant(e)||e.isAnnotationType()?t=T.universesInfo.Universe10.LibraryBase.properties.annotationTypes.name:A.isTypeDeclarationDescendant(e)&&(t=T.universesInfo.Universe10.LibraryBase.properties.types.name),t},e.prototype.expandLibraries=function(e){if(!e.lowLevel().actual().libExpanded){var t=e.lowLevel(),n=t.unit(),r=(n.absolutePath(),n.project()),i=[],a=t.unit().project().namespaceResolver(),o=a.expandedPathMap(n);if(null!=o){for(var s=Object.keys(o).sort(),u=0,l=s;u<l.length;u++){var p=l[u],c=this._libModels[p];if(null==c){var f=r.unit(p,!0),m=a.resolveNamespace(n,f);f&&null!=m&&null!=m.namespace()&&(c=this.extractLibModel(f))}c&&i.push(c)}for(var d=!1,h=0,y=i;h<y.length;h++)for(var c=y[h],v=0,g=Object.keys(c);v<g.length;v++){var A=g[v],S=c[A];R.isInstance(S)&&(d=this.contributeCollection(e.lowLevel(),S)||d)}if(this.resetTypes(e),e.resetChildren(),d){var T=!1;do T=this.patchDependencies(e);while(T);this.removeUnusedDependencies(e)}}this.removeUses(e.lowLevel()),e.lowLevel().actual().libExpanded=!0,this.resetTypes(e),e.resetChildren()}},e.prototype.patchDependencies=function(e){for(var t=!1,n=e.lowLevel().unit().absolutePath(),r=0,i=e.children();r<i.length;r++){var a=i[r];if(a.isElement()&&!a.lowLevel().libProcessed){var o=a.asElement();this.removeUses(o.lowLevel());var s=a.lowLevel().unit().absolutePath();if(s!=n||null!=a.lowLevel().includePath()){var u=this._outerDependencies[s];if(null!=u){var l=o.property().nameId(),p=u[l];if(null!=p){var c=o.name();null!=p[c]&&(this.process(o,e,!0,!0),t=!0)}}}}}return t},e.prototype.removeUnusedDependencies=function(e){for(var t=e.lowLevel(),n=t.unit().absolutePath(),r=[].concat(e.children()),i=0,a=r;i<a.length;i++){var o=a[i],s=o.lowLevel();if(!o.isElement()||!s.libProcessed){var u=s.unit().absolutePath();u!=n&&s.parent().removeChild(s)}}},e.prototype.contributeCollection=function(e,t){var n=t.name,r=g.find(e.children(),function(e){return e.key()==n});if(null==r){var i=d.createMapNode(n);r=e.replaceChild(null,i)}for(var a=!1,o=0,s=t.array;o<s.length;o++){var l=s[o];r.children().some(function(e){var t=u(e);return t.unit().absolutePath()!=l.lowLevel().unit().absolutePath()?!1:l.lowLevel().key()==t.key()&&l.lowLevel().unit().absolutePath()==t.unit().absolutePath()})||(r.replaceChild(null,l.lowLevel()),a=!0)}return a},e.prototype.extractLibModel=function(e){var t=this._libModels[e.absolutePath()];if(null!=t)return t;t=new I(e),this._libModels[e.absolutePath()]=t;var n=e.highLevel();if(n&&n.isElement())for(var r=0,i=["resourceTypes","traits","types","annotationTypes","securitySchemes"];r<i.length;r++){for(var a=i[r],o=new R(a),s=0,u=n.asElement().elementsOfKind(a);s<u.length;s++){var l=u[s];o.array.push(l)}t[a]=o}return t},e.prototype.isCompoundValue=function(e){var t=e.indexOf("<<");if(0>t)return!1;if(0!=t)return!0;var n=e.indexOf(">>",t);return n+">>".length!=e.length?!0:!1},e}();t.ReferencePatcher=N;var _;!function(e){e[e.OK=0]="OK",e[e.NOT_REQUIRED=1]="NOT_REQUIRED",e[e.ERROR=2]="ERROR"}(_||(_={}));var M="__P_A_R_A_M_E_T_E_R__";t.patchMethodIs=o,t.prepareTraitRefNode=s;var w=function(){function e(e,t,n,r,i){this._namespace=e,this._name=t,this._collectionName=n,this._referencedUnit=r,this._mode=i;var a=this._name.length;"?"==this._name.charAt(a-1)&&(this._name=this._name.substring(0,a-1))}return e.prototype.namespace=function(){return this._namespace},e.prototype.name=function(){return this._name},e.prototype.collectionName=function(){return this._collectionName},e.prototype.referencedUnit=function(){return this._referencedUnit},e.prototype.mode=function(){return this._mode},e.prototype.value=function(){if(null==this._namespace)return this._name;var e=this._mode==b.PATH?"/":".";return this._namespace+e+this._name},e}();t.PatchedReference=w,t.instanceOfPatchedReference=l;var R=function(){function e(e){this.name=e,this.array=[]}return e.isInstance=function(t){return null!=t&&t.getClassIdentifier&&"function"==typeof t.getClassIdentifier&&g.contains(t.getClassIdentifier(),e.CLASS_IDENTIFIER)},e.prototype.getClassIdentifier=function(){var t=[];return t.concat(e.CLASS_IDENTIFIER)},e.CLASS_IDENTIFIER="referencePatcher.ElementsCollection",e}(),I=function(){function e(e){this.unit=e}return e}();t.getDeclaration=p},function(e,t,n){"use strict";function r(e,t){if(void 0===t&&(t=!1),!e)return null;var n=e.kind();if(n==u.Kind.ANCHOR_REF&&(n=e.anchorValueKind()),n==u.Kind.INCLUDE_REF){if(null!=e.unit()){var i=e.includePath(),a=null;try{a=e.unit().resolve(i)}catch(o){}if(null==a)return null;if(a.isRAMLUnit()&&this.canInclude(a)){var s=a.ast();if(s)return r(s,t)}}return null}if(n==u.Kind.SEQ){for(var l=[],p=0,c=e.children();p<c.length;p++){var f=c[p];l.push(r(f,t))}return l}if(n==u.Kind.ANCHOR_REF)return r(e.anchoredFrom(),t);if(n==u.Kind.MAPPING){var m={},d=""+e.key(!0),h=e.valueKind();if(h==u.Kind.INCLUDE_REF){var y=e.children();0==y.length?m[d]=e.value():h=null==y[0].key()?u.Kind.SEQ:u.Kind.MAP}if(h==u.Kind.ANCHOR_REF&&(h=e.anchorValueKind()),h==u.Kind.SCALAR)m[d]=e.value();else if(h==u.Kind.SEQ){var l=[];m[d]=l;for(var v=0,g=e.children();v<g.length;v++){var f=g[v];l.push(r(f,!0))}}else if(h==u.Kind.MAP){var A={};m[d]=A;for(var S=0,T=e.children();S<T.length;S++){var f=T[S],E=""+f.key(!0),b=r(f,!0);A[E]=void 0===b?null:b}}return m[d]}if(n==u.Kind.SCALAR){var N=e.value(!1);return N}if(n==u.Kind.MAP){for(var A={},_=0,M=e.children();_<M.length;_++){var f=M[_],E=""+f.key(!0),b=r(f,!0);A[E]=void 0===b?null:b}return A}}function i(e,t){if(void 0===t&&(t={}),t=t||{},0==e.children().length)return e.value();if(e.children()[0].key()){var n={};if(e.children().forEach(function(e){n[o(e.key(t.rawKey),t)]=i(e,t)}),t&&t.writeErrors){var r=a(e);null!=r&&r.length>0&&(n.__$errors__=r)}return n}var s=[];return e.children().forEach(function(e){s.push(i(e,t))}),s}function a(e){var t=[].concat(e.errors());return e.children().forEach(function(e){var n=e.children();return 0==n.length?void e.errors().forEach(function(e){return t.push(e)}):void(n[0].key()||n.forEach(function(e){0==e.children().length&&e.errors().forEach(function(e){return t.push(e)})}))}),t}function o(e,t){return t&&e&&t.escapeNumericKeys&&0==e.replace(/\d/g,"").trim().length?"__$EscapedKey$__"+e:e}function s(e,t){return e?(t=t||{},t.escapeNumericKeys&&c.stringStartsWith(e,"__$EscapedKey$__")&&0==e.substring("__$EscapedKey$__".length).replace(/\d/g,"").trim().length?e.substring("__$EscapedKey$__".length):e):e}var u=n(75),l=n(10),p=n(16),c=n(33),f=n(26),m=u.YAMLException,d=function(){function e(e,t,n,r,i,a){void 0===a&&(a={}),this._absolutePath=e,this._path=t,this._content=n,this._project=r,this._isTopoLevel=i,this.serializeOptions=a,this._node=new h(this,JSON.parse(this._content),null,a)}return e.prototype.highLevel=function(){return p.fromUnit(this)},e.prototype.absolutePath=function(){return this._absolutePath},e.prototype.clone=function(){return null},e.prototype.contents=function(){return this._content},e.prototype.lexerErrors=function(){return[]},e.prototype.path=function(){return this._content},e.prototype.isTopLevel=function(){return this._isTopoLevel},e.prototype.ast=function(){return this._node},e.prototype.expandedHighLevel=function(){return this.highLevel()},e.prototype.isDirty=function(){return!0},e.prototype.getIncludeNodes=function(){return[]},e.prototype.resolveAsync=function(e){return null},e.prototype.isRAMLUnit=function(){return!0},e.prototype.project=function(){return this._project},e.prototype.updateContent=function(e){},e.prototype.ramlVersion=function(){throw new m("not implemented")},e.prototype.lineMapper=function(){return new l.LineMapperImpl(this.contents(),this.absolutePath())},e.prototype.resolve=function(e){return null},e.prototype.isOverlayOrExtension=function(){return!1},e.prototype.getMasterReferenceNode=function(){return null},e}();t.CompilationUnit=d;var h=function(){function e(e,t,n,r,i){var a=this;void 0===r&&(r={}),this._unit=e,this._object=t,this._parent=n,this.options=r,this._key=i,this._isOptional=!1,this._object instanceof Object&&Object.keys(this._object).forEach(function(e){var t=s(e,a.options);if(t!=e){var n=a._object[e];delete a._object[e],a._object[t]=n}}),this._key&&c.stringEndsWith(this._key,"?")&&(this._isOptional=!0,this._key=this._key.substring(0,this._key.length-1))}return e.prototype.keyKind=function(){return null},e.prototype.isAnnotatedScalar=function(){return!1},e.prototype.hasInnerIncludeError=function(){return!1},e.prototype.start=function(){return-1},e.prototype.end=function(){return-1},e.prototype.value=function(){return this._object},e.prototype.actual=function(){return this._object},e.prototype.includeErrors=function(){return[]},e.prototype.includePath=function(){return null},e.prototype.includeReference=function(){return null},e.prototype.key=function(){return this._key},e.prototype.optional=function(){return this._isOptional},e.prototype.children=function(){var t=this;return this._object?Array.isArray(this._object)?this._object.map(function(n){return new e(t._unit,n,t,t.options)}):this._object instanceof Object?Object.keys(this._object).map(function(n){return new e(t._unit,t._object[n],t,t.options,n)}):[]:[]},e.prototype.parent=function(){return this._parent},e.prototype.unit=function(){return this._unit},e.prototype.includeBaseUnit=function(){return this._unit},e.prototype.anchorId=function(){return null},e.prototype.errors=function(){return[]},e.prototype.anchoredFrom=function(){return this},e.prototype.includedFrom=function(){return this},e.prototype.visit=function(e){e(this)&&this.children().forEach(function(t){return t.visit(e)})},e.prototype.dumpToObject=function(){return this._object},e.prototype.addChild=function(e){},e.prototype.execute=function(e){},e.prototype.dump=function(){return JSON.stringify(this._object)},e.prototype.keyStart=function(){return-1},e.prototype.keyEnd=function(){return-1},e.prototype.valueStart=function(){return-1},e.prototype.valueEnd=function(){return-1},e.prototype.isValueLocal=function(){return!0},e.prototype.kind=function(){return Array.isArray(this._object)?u.Kind.SEQ:this._object instanceof Object?u.Kind.MAP:u.Kind.SCALAR},e.prototype.valueKind=function(){if(!this._object)return null;var e=typeof this._object;return Array.isArray(this._object)?u.Kind.SEQ:"object"==e?u.Kind.MAP:"string"==e||"number"==e||"boolean"==e?u.Kind.SCALAR:null},e.prototype.anchorValueKind=function(){return null},e.prototype.show=function(e){},e.prototype.setHighLevelParseResult=function(e){this._highLevelParseResult=e},e.prototype.highLevelParseResult=function(){return this._highLevelParseResult},e.prototype.setHighLevelNode=function(e){this._highLevelNode=e},e.prototype.highLevelNode=function(){return this._highLevelNode},e.prototype.text=function(e){throw new m("not implemented")},e.prototype.copy=function(){throw new m("not implemented")},e.prototype.markup=function(e){throw new m("not implemented")},e.prototype.nodeDefinition=function(){return f.getDefinitionForLowLevelNode(this)},e.prototype.includesContents=function(){return!1},e}();t.AstNode=h,t.serialize2=r,t.serialize=i},function(e,t,n){"use strict";var r=n(30),i=n(81),a=function(){function e(){this.uriToResources={},this.conflictingUriToResources={}}return e.prototype.validateApi=function(e,t){var n=this,a=e.resources();a.forEach(function(e){n.acceptResource(e);var t=e.resources();t.forEach(function(e){return n.acceptResource(e)})});for(var o in this.conflictingUriToResources){var a=this.conflictingUriToResources[o];if(a.length>1){var s={};a.forEach(function(e){var t=e.highLevel(),n="";null!=t.parent()&&(n+=t.parent().id()+"."),n+=t.localId();var r=s[n];null==r&&(r=[],s[n]=r),r.push(e)});var u=Object.keys(s);u.length>1&&a.forEach(function(e){t.accept(r.createIssue1(i.RESOURCES_SHARE_SAME_URI,{},e.highLevel(),!1))})}}},e.prototype.acceptResource=function(e){var t=e.absoluteUri(),n=this.uriToResources[t];n||(n=[],this.uriToResources[t]=n),n.push(e),n.length>1&&(this.conflictingUriToResources[t]=n)},e}();e.exports=a},function(e,t,n){"use strict";function r(e,t){for(var n=e.getElementsByTagName(t),r=[],i=0;i<n.length;i++){var a=n[i];a.parentNode===e&&r.push(a)}return r}function i(e){try{var t=(new l).parseFromString(e),n=r(t,"xs:schema");return n.length>0}catch(i){return!1}}function a(e){var t={};if(1==e.nodeType){if(e.attributes.length>0)for(var n=0;n<e.attributes.length;n++){var r=e.attributes.item(n);t["@"+r.nodeName]=r.nodeValue}}else 3==e.nodeType&&(t=e.nodeValue);if(e.hasChildNodes())for(var i=0;i<e.childNodes.length;i++){var o=e.childNodes.item(i),s=o.nodeName;if(void 0!=s)if("undefined"==typeof t[s])t[s]=a(o);else{if("undefined"==typeof t[s].push){var u=t[s];t[s]=[],t[s].push(u)}t[s].push(a(o))}}return t}function o(e){if("object"==typeof e)for(var t in e)if("object"==typeof e[t]){for(var n in e[t])if("#text"==n){var r=e[t]["#text"];"string"!=typeof r&&(r=r.join("")),r=r.trim(),0==r.length&&delete e[t]["#text"]}o(e[t])}return e}function s(e){if("object"==typeof e)for(var t in e)if("object"==typeof e[t]){var n=Object.keys(e[t]);1==n.length&&"#text"==n[0]&&(e[t]=e[t]["#text"]),s(e[t])}return e}function u(e){var t=new l.DOMParser;if(!e||0==e.trim().indexOf("<<"))return null;var n=t.parseFromString(e);return s(o(a(n)))}var l=n(72);t.isXmlScheme=i,t.parseXML=u},function(e,t,n){"use strict";function r(e,t,n,r){var i=r.end!==!1,a=r.strict,o="";r.sensitive||(o+="i");var s=e.replace(c,function(e,r,i,a){if(a)return"\\"+a;n.push({name:i,prefix:r||"/"}),r=r?"\\"+r:"";var o=t[i],s=o&&l[o.type]||"[^"+(r||"\\/")+"]+",u=o&&o.required===!1;return Array.isArray(o["enum"])&&o["enum"].length&&(s="(?:"+o["enum"].map(function(e){return String(e).replace(p,"\\$1")}).join("|")+")"),r+"("+s+")"+(u?"?":"")}),u="/"===e.charAt(e.length-1);return a||(s=(u?s.slice(0,-2):s)+"(?:\\/(?=$))?"),s+=i?"$":a&&u?"":"(?=\\/|$)",new RegExp("^"+s+(i?"$":""),o)}function i(e){try{return decodeURIComponent(e)}catch(t){var n=new Error('Failed to decode param "'+e+'"');throw n.status=400,n}}function a(e,t,n){if(n=n||{},"/"===e&&n.end===!1)return o;t=t||{};var a=[],l=r(e,t,a,n),p=s.sanitize()(t),c=u.validate()(t);return function(e){var n=l.exec(e);if(!n)return!1;if(t.mediaTypeExtension&&n.length>1&&!n[n.length-1]){var r=n[n.length-2],o=r.lastIndexOf(".");o>=0&&(n[n.length-2]=r.substring(0,o),n[n.length-1]=r.substring(o))}for(var s=n[0],u={},f=1;f<n.length;f++){var m=a[f-1],d=n[f];u[m.name]=null==d?d:i(d)}return u=p(u),c(u).valid?{path:s,params:u}:!1}}function o(e){return{path:"",params:{}}}var s=n(77),u=n(78),l={number:"[-+]?\\d+(?:\\.\\d+)?",integer:"[-+]?\\d+",date:"(?:Mon|Tue|Wed|Thu|Fri|Sat|Sun), \\d{2} (?:Jan|Feb|Mar|Apr|May|Jun|Jul|Aug|Sep|Oct|Nov|Dec) \\d{4} (?:[0-1]\\d|2[0-3]):[0-5]\\d:[0-5]\\d GMT","boolean":"(?:true|false)"},p=/([.*+?=^!:${}()|[\]\/\\])/g,c=new RegExp(["([.\\/])?\\{([^}]+)\\}",p.source].join("|"),"g");t.ramlPathMatch=a},function(e,t,n){"use strict";function r(e){var t=e[0],n={};return e.forEach(function(e){return n[e.name]=e}),e.forEach(function(e){var t=e.imports;Object.keys(t).forEach(function(e){var r=t[e];t[e]=n[r]})}),t}t.universeDumps={RAML08:r(n(89)),RAML10:r(n(90))}},function(e,t,n){"use strict";function r(e,t){var n=new s.Universe(t,""),r={};return E(e,n,{},r),Object.keys(r).forEach(function(e){A(r[e],n)}),Object.keys(r).forEach(function(e){S(r[e],n)}),Object.keys(r).forEach(function(e){T(r[e],n)}),n.types().forEach(function(e){if(e instanceof s.NodeClass){var t=e;if(t.properties().forEach(function(e){var t=e.range(),n=e;t.hasValueTypeInHierarchy()||t.properties().forEach(function(e){
if(e.getAdapter(p.RAMLPropertyService).isKey()){var t=e.keyPrefix();t&&(n.withKeyRestriction(t),n.merge());var r=e.enumOptions();r&&(n.withEnumOptions(r),n.merge())}})}),t.getAdapter(p.RAMLService).isGlobalDeclaration()){if(t.getAdapter(p.RAMLService).getActuallyExports()&&"$self"!=t.getAdapter(p.RAMLService).getActuallyExports()){var r=t.property(t.getAdapter(p.RAMLService).getActuallyExports()).range();if(r.hasValueTypeInHierarchy()){var i=r.getAdapter(p.RAMLService);i.setGloballyDeclaredBy(t)}}if(t.getAdapter(p.RAMLService).getConvertsToGlobal()){var r=n.type(t.getAdapter(p.RAMLService).getConvertsToGlobal());if(r.hasValueTypeInHierarchy()){var i=r.getAdapter(p.RAMLService);i.setGloballyDeclaredBy(t)}}}}}),n}function i(e,t,n,r,i){var a=s.prop(e.name(),"",t,n,r);e.isMultiValue()&&a.withMultiValue(!0),a.unmerge(),n||console.log(e.name()+":"+t.nameId()+" has undefined type"),n.hasValueTypeInHierarchy()||n.properties().forEach(function(e){if(e.getAdapter(p.RAMLPropertyService).isKey()){var t=e.keyPrefix();t&&(a.withKeyRestriction(t),a.merge());var n=e.enumOptions();n&&(a.withEnumOptions(n),a.merge())}}),b(e,a,i)}var a=this&&this.__extends||function(e,t){function n(){this.constructor=e}for(var r in t)t.hasOwnProperty(r)&&(e[r]=t[r]);e.prototype=null===t?Object.create(t):(n.prototype=t.prototype,new n)},o=n(93),s=n(37),u=n(92),l=n(79),p=s,c=function(){function e(e,t){this._field=e,this._clazz=t}return e.prototype.name=function(){return this._field.name},e.prototype.range=function(){return this._clazz.getModule().typeFor(this._field.type,this._clazz)},e.prototype.isMultiValue=function(){return this._field.type.typeKind==o.TypeKind.ARRAY},e.prototype.isKey=function(){return null!=u.find(this._field.annotations,function(e){return"MetaModel.key"==e.name})},e.prototype.isSimpleValue=function(){return null!=u.find(this._field.annotations,function(e){return"MetaModel.value"==e.name})},e.prototype.annotations=function(){return this._field.annotations},e}(),f=function(){function e(e,t){this._field=e,this._clazz=t}return e.prototype.name=function(){return this._field.name},e.prototype.value=function(){return this._field.valueConstraint},e}(),m=function(){function e(e,t){this._clazz=e,this.mw=t}return e.prototype.typeMeta=function(){return this._clazz.annotations},e.prototype.path=function(){return this.mw.path()},e.prototype.getModule=function(){return this.mw},e.prototype.typeArgs=function(){return this._clazz.typeParameters},e.prototype.typConstraints=function(){var e=this;return this._clazz.typeParameterConstraint.map(function(t){return t?e.mw.classForName(t):null})},e.prototype.methods=function(){return this._clazz.methods},e.prototype.name=function(){return this._clazz.name},e.prototype.members=function(){var e=this;return this._clazz.fields.filter(function(e){return null==e.valueConstraint}).map(function(t){return new c(t,e)})},e.prototype.constraints=function(){var e=this;return this._clazz.fields.filter(function(e){return null!=e.valueConstraint}).map(function(t){return new f(t,e)})},e.prototype.isSubTypeOf=function(e){if(this==e)return!0;var t=!1;return this.getAllSuperTypes().forEach(function(n){t||(t=t||n.isSubTypeOf(e))}),t},e.prototype.getExtendsClauses=function(){return this._clazz["extends"]},e.prototype.getSuperTypes=function(){var e=this,t=[];return this._clazz["extends"].forEach(function(n){var r=e.mw.classForName(n.typeName);r&&t.push(r)}),t},e.prototype.getAllSuperTypes=function(){var e=this,t=[];return this._clazz["extends"].forEach(function(n){var r=e.mw.classForName(n.typeName);if(r){var i=r.getAllSuperTypes();t.push(r),t.concat(i)}}),u.unique(t)},e.prototype.annotationOverridings=function(){return this._clazz.annotationOverridings},e}(),d=function(){function e(){}return e.prototype.members=function(){return[]},e.prototype.methods=function(){return[]},e.prototype.isSubTypeOf=function(e){return!1},e.prototype.getSuperTypes=function(){return[]},e.prototype.getAllSuperTypes=function(){return[]},e.prototype.name=function(){return null},e.prototype.constraints=function(){return[]},e.prototype.typeMeta=function(){return[]},e.prototype.getModule=function(){throw new Error("Not implemented")},e.prototype.annotationOverridings=function(){return{}},e}(),h=function(e){function t(t,n){e.call(this),this._clazz=t,this.mw=n}return a(t,e),t.prototype.getModule=function(){return this.mw},t.prototype.values=function(){return this._clazz.members},t.prototype.name=function(){return this._clazz.name},t}(d),y=function(e){function t(t,n){e.call(this),this._clazz=t,this.mw=n}return a(t,e),t.prototype.elements=function(){return this._clazz},t.prototype.name=function(){return this._clazz.map(function(e){return e.name()}).join("|")},t}(d),v=function(){function e(e){var t=this;this._univers=e,this.name2Class={},this.namespaceToMod={},this._classes=[],e.classes.forEach(function(e){var n=new m(e,t);t._classes.push(n),t.name2Class[e.name]=n,e.moduleName&&(t.name2Class[e.moduleName+"."+e.name]=n)}),e.enumDeclarations.forEach(function(e){var n=new h(e,t);t._classes.push(n),t.name2Class[e.name]=n})}return e.prototype.typeFor=function(e,t){var n=this;switch(e.typeKind){case o.TypeKind.BASIC:var r=e,i=r.typeName;"string"==i&&(i="StringType"),"number"==i&&(i="NumberType"),"boolean"==i&&(i="BooleanType"),"any"==i&&(i="AnyType");var a=u.indexOf(t.typeArgs(),i);if(-1!=a){var s=t.typConstraints()[a];return s?s:this.classForName("ValueType")}return this.classForName(i);case o.TypeKind.UNION:var l=e;return new y(l.options.map(function(e){return n.typeFor(e,t)}),this);case o.TypeKind.ARRAY:var p=e;return this.typeFor(p.base,t)}return null},e.prototype.path=function(){return this._univers.name},e.prototype.classForName=function(e,t){var n=this;if(void 0===t&&(t={}),!e)return null;var r=this.name2Class[e];if(!r&&!t[this.path()]){t[this.path()]=this;var i=e.indexOf(".");if(-1!=i){var a=this.namespaceToMod[e.substring(0,i)];if(!a)throw new Error;return a.classForName(e.substring(i+1),t)}Object.keys(this.namespaceToMod).forEach(function(i){if("MetaModel"!=i){var a=n.namespaceToMod[i].classForName(e,t);a&&(r=a)}})}return r},e.prototype.classes=function(){return this._classes},e}(),g=function(e,t){if(e){var n;if(e instanceof y){throw new Error("Union type support was removed from definition system")}return n=t.type(e.name())}},A=function(e,t){var n=e.classForName("ValueType");e.classes().forEach(function(e){if(e instanceof h){var r=new s.EnumType(e.name(),t,e.getModule().path());return r.values=e.values(),void t.register(r)}if(e.isSubTypeOf(n)){var i=e.getAllSuperTypes();i.push(e);var a=null;if(i.forEach(function(e){var t=e.getExtendsClauses();t.forEach(function(e){if(e.typeKind==o.TypeKind.BASIC){var t=e;if("Reference"==t.basicName){var n=t.typeArguments[0];a=n.typeName;var r=a.indexOf(".");-1!=r&&(a=a.substring(r+1))}}})}),a){var u=new s.ReferenceType(e.name(),e.getModule().path(),a,t);u.setBuiltIn(!0),t.register(u)}else{var l=new s.ValueType(e.name(),t,e.getModule().path());l.setBuiltIn(!0),t.register(l)}}else{var p=new s.NodeClass(e.name(),t,e.getModule().path());p.setBuiltIn(!0),t.register(p)}})},S=function(e,t){e.classes().forEach(function(e){e.getSuperTypes().forEach(function(n){var r=t.type(e.name()),i=t.type(n.name());if(!r||!i){var r=t.type(e.name()),i=t.type(n.name());throw new Error}t.registerSuperClass(r,i)})})},T=function(e,t){e.classes().forEach(function(e){var n=t.type(e.name());e.typeMeta().forEach(function(n){var r=g(e,t);l.handleTypeAnnotation(n,r)}),e.members().forEach(function(e){var r=e.range(),a=g(r,t);null==a&&console.log(r+":"+e.name());var o=e.annotations().map(function(e){return e.name}).indexOf("MetaModel.customHandling")>=0;i(e,n,a,o)}),Object.keys(e.annotationOverridings()).forEach(function(r){var a=[].concat(e.annotationOverridings()[r]),o={};a.forEach(function(e){return o[e.name]=!0});for(var s,u=e.getSuperTypes(),l={},p=0;p<u.length;p++){var c=u[p];if(!l[c.name()]){l[c.name()]=!0,c.getSuperTypes().forEach(function(e){return u.push(e)});var f=c.annotationOverridings()[r];if(f)f.filter(function(e){return!o[e.name]}).forEach(function(e){o[e.name]=!0,a.push(e)});else for(var m=c.members(),d=0;d<m.length;d++){var h=m[d];if(h.name()==r){s=h;break}}if(s){var y=s.annotations();y.filter(function(e){return!o[e.name]}).forEach(function(e){o[e.name]=!0,a.push(e)});break}}}if(s){var v=s.range(),A=g(v,t);null==A&&console.log(v+":"+e.name()),i(s,n,A,!1,a)}}),e.methods().forEach(function(e){}),e.constraints().forEach(function(e){if(e.value().isCallConstraint)throw new Error;var t=e.value();n.addRequirement(e.name(),""+t.value)})}),t.types().forEach(function(e){var n=e;n.getAdapter(p.RAMLService).getAliases().forEach(function(e){return t.registerAlias(e,n)})})},E=function(e,t,n,r){if(-1==e.name.indexOf("metamodel.ts")){if(r[e.name])return r[e.name];var i=new v(e);return n[e.name]=i,r[e.name]=i,Object.keys(e.imports).forEach(function(a){var o=e.imports[a];if(n[o.name])return void(i.namespaceToMod[a]=n[o.name]);var s=E(o,t,n,r);i.namespaceToMod[a]=s}),n[e.name]=null,i}};t.toDefSystem=r;var b=function(e,t,n){n||(n=e.annotations()),n.forEach(function(e){var n=e.name.substring(e.name.lastIndexOf(".")+1);l.annotationHandlers[n]||console.log("Can not find handler for:"),l.annotationHandlers[n](e,t)})}},function(e,t,n){"use strict";var r={Universe08:{GlobalSchema:{name:"GlobalSchema",properties:{key:{name:"key",range:"StringType",domain:"GlobalSchema"},value:{name:"value",range:"SchemaString",domain:"GlobalSchema"}}},Api:{name:"Api",properties:{title:{name:"title",range:"StringType",domain:"Api"},version:{name:"version",range:"StringType",domain:"Api"},baseUri:{name:"baseUri",range:"FullUriTemplateString",domain:"Api"},baseUriParameters:{name:"baseUriParameters",range:"Parameter",domain:"Api"},uriParameters:{name:"uriParameters",range:"Parameter",domain:"Api"},protocols:{name:"protocols",range:"StringType",domain:"Api"},mediaType:{name:"mediaType",range:"MimeType",domain:"Api"},schemas:{name:"schemas",range:"GlobalSchema",domain:"Api"},traits:{name:"traits",range:"Trait",domain:"Api"},securedBy:{name:"securedBy",range:"SecuritySchemeRef",domain:"Api"},securitySchemes:{name:"securitySchemes",range:"AbstractSecurityScheme",domain:"Api"},resourceTypes:{name:"resourceTypes",range:"ResourceType",domain:"Api"},resources:{name:"resources",range:"Resource",domain:"Api"},documentation:{name:"documentation",range:"DocumentationItem",domain:"Api"},RAMLVersion:{name:"RAMLVersion"}}},DocumentationItem:{name:"DocumentationItem",properties:{title:{name:"title",range:"StringType",domain:"DocumentationItem"},content:{name:"content",range:"MarkdownString",domain:"DocumentationItem"}}},ValueType:{name:"ValueType",properties:{}},StringType:{name:"StringType",properties:{}},AnyType:{name:"AnyType",properties:{}},NumberType:{name:"NumberType",properties:{}},BooleanType:{name:"BooleanType",properties:{}},Referencable:{name:"Referencable",properties:{}},Reference:{name:"Reference",properties:{structuredValue:{name:"structuredValue"},name:{name:"name"}}},DeclaresDynamicType:{name:"DeclaresDynamicType",properties:{}},UriTemplate:{name:"UriTemplate",properties:{}},RelativeUriString:{name:"RelativeUriString",properties:{}},FullUriTemplateString:{name:"FullUriTemplateString",properties:{}},FixedUri:{name:"FixedUri",properties:{}},MarkdownString:{name:"MarkdownString",properties:{}},SchemaString:{name:"SchemaString",properties:{}},JSonSchemaString:{name:"JSonSchemaString",properties:{}},XMLSchemaString:{name:"XMLSchemaString",properties:{}},ExampleString:{name:"ExampleString",properties:{}},StatusCodeString:{name:"StatusCodeString",properties:{}},JSONExample:{name:"JSONExample",properties:{}},XMLExample:{name:"XMLExample",properties:{}},TypeInstance:{name:"TypeInstance",properties:{properties:{name:"properties",range:"TypeInstanceProperty",domain:"TypeInstance"},isScalar:{name:"isScalar",range:"BooleanType",domain:"TypeInstance"},value:{name:"value",range:"AnyType",domain:"TypeInstance"}}},TypeInstanceProperty:{name:"TypeInstanceProperty",properties:{name:{name:"name",range:"StringType",domain:"TypeInstanceProperty"},value:{name:"value",range:"TypeInstance",domain:"TypeInstanceProperty"},values:{name:"values",range:"TypeInstance",domain:"TypeInstanceProperty"},isArray:{name:"isArray",range:"BooleanType",domain:"TypeInstanceProperty"}}},RAMLSimpleElement:{name:"RAMLSimpleElement",properties:{}},Parameter:{name:"Parameter",properties:{name:{name:"name",range:"StringType",domain:"Parameter"},displayName:{name:"displayName",range:"StringType",domain:"Parameter"},type:{name:"type",range:"StringType",domain:"Parameter"},location:{name:"location",range:"ParameterLocation",domain:"Parameter"},required:{name:"required",range:"BooleanType",domain:"Parameter"},"default":{name:"default",range:"AnyType",domain:"Parameter"},example:{name:"example",range:"StringType",domain:"Parameter"},repeat:{name:"repeat",range:"BooleanType",domain:"Parameter"},description:{name:"description",range:"MarkdownString",domain:"Parameter"}}},StringTypeDeclaration:{name:"StringTypeDeclaration",properties:{name:{name:"name",range:"StringType",domain:"Parameter"},displayName:{name:"displayName",range:"StringType",domain:"Parameter"},type:{name:"type",range:"StringType",domain:"Parameter"},location:{name:"location",range:"ParameterLocation",domain:"Parameter"},required:{name:"required",range:"BooleanType",domain:"Parameter"},"default":{name:"default",range:"AnyType",domain:"Parameter"},example:{name:"example",range:"StringType",domain:"Parameter"},repeat:{name:"repeat",range:"BooleanType",domain:"Parameter"},description:{name:"description",range:"MarkdownString",domain:"Parameter"},pattern:{name:"pattern",range:"StringType",domain:"StringTypeDeclaration"},"enum":{name:"enum",range:"StringType",domain:"StringTypeDeclaration"},minLength:{name:"minLength",range:"NumberType",domain:"StringTypeDeclaration"},maxLength:{name:"maxLength",range:"NumberType",domain:"StringTypeDeclaration"}}},BooleanTypeDeclaration:{name:"BooleanTypeDeclaration",properties:{name:{name:"name",range:"StringType",domain:"Parameter"},displayName:{name:"displayName",range:"StringType",domain:"Parameter"},type:{name:"type",range:"StringType",domain:"Parameter"},location:{name:"location",range:"ParameterLocation",domain:"Parameter"},required:{name:"required",range:"BooleanType",domain:"Parameter"},"default":{name:"default",range:"AnyType",domain:"Parameter"},example:{name:"example",range:"StringType",domain:"Parameter"},repeat:{name:"repeat",range:"BooleanType",domain:"Parameter"},description:{name:"description",range:"MarkdownString",domain:"Parameter"}}},NumberTypeDeclaration:{name:"NumberTypeDeclaration",properties:{name:{name:"name",range:"StringType",domain:"Parameter"},displayName:{name:"displayName",range:"StringType",domain:"Parameter"},type:{name:"type",range:"StringType",domain:"Parameter"},location:{name:"location",range:"ParameterLocation",domain:"Parameter"},required:{name:"required",range:"BooleanType",domain:"Parameter"},"default":{name:"default",range:"AnyType",domain:"Parameter"},example:{name:"example",range:"StringType",domain:"Parameter"},repeat:{name:"repeat",range:"BooleanType",domain:"Parameter"},description:{name:"description",range:"MarkdownString",domain:"Parameter"},minimum:{name:"minimum",range:"NumberType",domain:"NumberTypeDeclaration"},maximum:{name:"maximum",range:"NumberType",domain:"NumberTypeDeclaration"}}},IntegerTypeDeclaration:{name:"IntegerTypeDeclaration",properties:{name:{name:"name",range:"StringType",domain:"Parameter"},displayName:{name:"displayName",range:"StringType",domain:"Parameter"},type:{name:"type",range:"StringType",domain:"Parameter"},location:{name:"location",range:"ParameterLocation",domain:"Parameter"},required:{name:"required",range:"BooleanType",domain:"Parameter"},"default":{name:"default",range:"AnyType",domain:"Parameter"},example:{name:"example",range:"StringType",domain:"Parameter"},repeat:{name:"repeat",range:"BooleanType",domain:"Parameter"},description:{name:"description",range:"MarkdownString",domain:"Parameter"},minimum:{name:"minimum",range:"NumberType",domain:"NumberTypeDeclaration"},maximum:{name:"maximum",range:"NumberType",domain:"NumberTypeDeclaration"}}},DateTypeDeclaration:{name:"DateTypeDeclaration",properties:{name:{name:"name",range:"StringType",domain:"Parameter"},displayName:{name:"displayName",range:"StringType",domain:"Parameter"},type:{name:"type",range:"StringType",domain:"Parameter"},location:{name:"location",range:"ParameterLocation",domain:"Parameter"},required:{name:"required",range:"BooleanType",domain:"Parameter"},"default":{name:"default",range:"AnyType",domain:"Parameter"},example:{name:"example",range:"StringType",domain:"Parameter"},repeat:{name:"repeat",range:"BooleanType",domain:"Parameter"},description:{name:"description",range:"MarkdownString",domain:"Parameter"}}},FileTypeDeclaration:{name:"FileTypeDeclaration",properties:{name:{name:"name",range:"StringType",domain:"Parameter"},displayName:{name:"displayName",range:"StringType",domain:"Parameter"},type:{name:"type",range:"StringType",domain:"Parameter"},location:{name:"location",range:"ParameterLocation",domain:"Parameter"},required:{name:"required",range:"BooleanType",domain:"Parameter"},"default":{name:"default",range:"AnyType",domain:"Parameter"},example:{name:"example",range:"StringType",domain:"Parameter"},repeat:{name:"repeat",range:"BooleanType",domain:"Parameter"},description:{name:"description",range:"MarkdownString",domain:"Parameter"}}},ParameterLocation:{name:"ParameterLocation",properties:{}},MimeType:{name:"MimeType",properties:{}},BodyLike:{name:"BodyLike",properties:{name:{name:"name",range:"StringType",domain:"BodyLike"},schema:{name:"schema",range:"SchemaString",domain:"BodyLike"},example:{name:"example",range:"ExampleString",domain:"BodyLike"},formParameters:{name:"formParameters",range:"Parameter",domain:"BodyLike"},description:{name:"description",range:"MarkdownString",domain:"BodyLike"},schemaContent:{name:"schemaContent"}}},XMLBody:{name:"XMLBody",properties:{name:{name:"name",range:"StringType",domain:"BodyLike"},schema:{name:"schema",range:"XMLSchemaString",domain:"XMLBody"},example:{name:"example",range:"ExampleString",domain:"BodyLike"},formParameters:{name:"formParameters",range:"Parameter",domain:"BodyLike"},description:{name:"description",range:"MarkdownString",domain:"BodyLike"}}},JSONBody:{name:"JSONBody",properties:{name:{name:"name",range:"StringType",domain:"BodyLike"},schema:{name:"schema",range:"JSonSchemaString",domain:"JSONBody"},example:{name:"example",range:"ExampleString",domain:"BodyLike"},formParameters:{name:"formParameters",range:"Parameter",domain:"BodyLike"},description:{name:"description",range:"MarkdownString",domain:"BodyLike"}}},Response:{name:"Response",properties:{code:{name:"code",range:"StatusCodeString",domain:"Response"},headers:{name:"headers",range:"Parameter",domain:"Response"},body:{name:"body",range:"BodyLike",domain:"Response"},description:{name:"description",range:"MarkdownString",domain:"Response"}}},Resource:{name:"Resource",properties:{relativeUri:{name:"relativeUri",range:"RelativeUriString",domain:"Resource"},type:{name:"type",range:"ResourceTypeRef",domain:"Resource"},is:{name:"is",range:"TraitRef",domain:"Resource"},securedBy:{name:"securedBy",range:"SecuritySchemeRef",domain:"Resource"},uriParameters:{name:"uriParameters",range:"Parameter",domain:"Resource"},methods:{name:"methods",range:"Method",domain:"Resource"},resources:{name:"resources",range:"Resource",domain:"Resource"},displayName:{name:"displayName",range:"StringType",domain:"Resource"},baseUriParameters:{name:"baseUriParameters",range:"Parameter",domain:"Resource"},description:{name:"description",range:"MarkdownString",domain:"Resource"}}},ResourceTypeRef:{name:"ResourceTypeRef",properties:{resourceType:{name:"resourceType"}}},ResourceType:{name:"ResourceType",properties:{name:{name:"name",range:"StringType",domain:"ResourceType"},usage:{name:"usage",range:"StringType",domain:"ResourceType"},methods:{name:"methods",range:"Method",domain:"ResourceType"},is:{name:"is",range:"TraitRef",domain:"ResourceType"},type:{name:"type",range:"ResourceTypeRef",domain:"ResourceType"},securedBy:{name:"securedBy",range:"SecuritySchemeRef",domain:"ResourceType"},uriParameters:{name:"uriParameters",range:"Parameter",domain:"ResourceType"},displayName:{name:"displayName",range:"StringType",domain:"ResourceType"},baseUriParameters:{name:"baseUriParameters",range:"Parameter",domain:"ResourceType"},description:{name:"description",range:"MarkdownString",domain:"ResourceType"},parametrizedProperties:{name:"parametrizedProperties"}}},MethodBase:{name:"MethodBase",properties:{responses:{name:"responses",range:"Response",domain:"MethodBase"},body:{name:"body",range:"BodyLike",domain:"MethodBase"},protocols:{name:"protocols",range:"StringType",domain:"MethodBase"},securedBy:{name:"securedBy",range:"SecuritySchemeRef",domain:"MethodBase"},baseUriParameters:{name:"baseUriParameters",range:"Parameter",domain:"MethodBase"},queryParameters:{name:"queryParameters",range:"Parameter",domain:"MethodBase"},headers:{name:"headers",range:"Parameter",domain:"MethodBase"},description:{name:"description",range:"MarkdownString",domain:"MethodBase"}}},Method:{name:"Method",properties:{responses:{name:"responses",range:"Response",domain:"MethodBase"},body:{name:"body",range:"BodyLike",domain:"MethodBase"},protocols:{name:"protocols",range:"StringType",domain:"MethodBase"},securedBy:{name:"securedBy",range:"SecuritySchemeRef",domain:"MethodBase"},baseUriParameters:{name:"baseUriParameters",range:"Parameter",domain:"MethodBase"},queryParameters:{name:"queryParameters",range:"Parameter",domain:"MethodBase"},headers:{name:"headers",range:"Parameter",domain:"MethodBase"},description:{name:"description",range:"MarkdownString",domain:"MethodBase"},method:{name:"method",range:"StringType",domain:"Method"},is:{name:"is",range:"TraitRef",domain:"Method"}}},Trait:{name:"Trait",properties:{responses:{name:"responses",range:"Response",domain:"MethodBase"},body:{name:"body",range:"BodyLike",domain:"MethodBase"},protocols:{name:"protocols",range:"StringType",domain:"MethodBase"},securedBy:{name:"securedBy",range:"SecuritySchemeRef",domain:"MethodBase"},baseUriParameters:{name:"baseUriParameters",range:"Parameter",domain:"MethodBase"},queryParameters:{name:"queryParameters",range:"Parameter",domain:"MethodBase"},headers:{name:"headers",range:"Parameter",domain:"MethodBase"},description:{name:"description",range:"MarkdownString",domain:"MethodBase"},name:{name:"name",range:"StringType",domain:"Trait"},usage:{name:"usage",range:"StringType",domain:"Trait"},displayName:{name:"displayName",range:"StringType",domain:"Trait"},parametrizedProperties:{name:"parametrizedProperties"}}},TraitRef:{name:"TraitRef",properties:{trait:{name:"trait"}}},SecuritySchemePart:{name:"SecuritySchemePart",properties:{responses:{name:"responses",range:"Response",domain:"SecuritySchemePart"},body:{name:"body",range:"BodyLike",domain:"MethodBase"},protocols:{name:"protocols",range:"StringType",domain:"MethodBase"},securedBy:{name:"securedBy",range:"SecuritySchemeRef",domain:"MethodBase"},baseUriParameters:{name:"baseUriParameters",range:"Parameter",domain:"MethodBase"},queryParameters:{name:"queryParameters",range:"Parameter",domain:"SecuritySchemePart"},headers:{name:"headers",range:"Parameter",domain:"SecuritySchemePart"},description:{name:"description",range:"MarkdownString",domain:"SecuritySchemePart"},displayName:{name:"displayName",range:"StringType",domain:"SecuritySchemePart"},is:{name:"is",range:"TraitRef",domain:"SecuritySchemePart"}}},SecuritySchemeSettings:{name:"SecuritySchemeSettings",properties:{}},AbstractSecurityScheme:{name:"AbstractSecurityScheme",properties:{name:{name:"name",range:"StringType",domain:"AbstractSecurityScheme"},type:{name:"type",range:"StringType",domain:"AbstractSecurityScheme"},description:{name:"description",range:"MarkdownString",domain:"AbstractSecurityScheme"},describedBy:{name:"describedBy",range:"SecuritySchemePart",domain:"AbstractSecurityScheme"},settings:{name:"settings",range:"SecuritySchemeSettings",domain:"AbstractSecurityScheme"}}},SecuritySchemeRef:{name:"SecuritySchemeRef",properties:{securitySchemeName:{name:"securitySchemeName"},securityScheme:{name:"securityScheme"}}},OAuth1SecuritySchemeSettings:{name:"OAuth1SecuritySchemeSettings",properties:{requestTokenUri:{name:"requestTokenUri",range:"FixedUri",domain:"OAuth1SecuritySchemeSettings"},authorizationUri:{name:"authorizationUri",range:"FixedUri",domain:"OAuth1SecuritySchemeSettings"},tokenCredentialsUri:{name:"tokenCredentialsUri",range:"FixedUri",domain:"OAuth1SecuritySchemeSettings"}}},OAuth2SecuritySchemeSettings:{name:"OAuth2SecuritySchemeSettings",properties:{accessTokenUri:{name:"accessTokenUri",range:"FixedUri",domain:"OAuth2SecuritySchemeSettings"},authorizationUri:{name:"authorizationUri",range:"FixedUri",domain:"OAuth2SecuritySchemeSettings"},authorizationGrants:{name:"authorizationGrants",range:"StringType",domain:"OAuth2SecuritySchemeSettings"},scopes:{name:"scopes",range:"StringType",domain:"OAuth2SecuritySchemeSettings"}}},OAuth2SecurityScheme:{name:"OAuth2SecurityScheme",properties:{name:{name:"name",range:"StringType",domain:"AbstractSecurityScheme"},type:{name:"type",range:"StringType",domain:"AbstractSecurityScheme"},description:{name:"description",range:"MarkdownString",domain:"AbstractSecurityScheme"},describedBy:{name:"describedBy",range:"SecuritySchemePart",domain:"AbstractSecurityScheme"},settings:{name:"settings",range:"OAuth2SecuritySchemeSettings",domain:"OAuth2SecurityScheme"}}},OAuth1SecurityScheme:{name:"OAuth1SecurityScheme",properties:{name:{name:"name",range:"StringType",domain:"AbstractSecurityScheme"},type:{name:"type",range:"StringType",domain:"AbstractSecurityScheme"},description:{name:"description",range:"MarkdownString",domain:"AbstractSecurityScheme"},describedBy:{name:"describedBy",range:"SecuritySchemePart",domain:"AbstractSecurityScheme"},settings:{name:"settings",range:"OAuth1SecuritySchemeSettings",domain:"OAuth1SecurityScheme"}}},BasicSecurityScheme:{name:"BasicSecurityScheme",properties:{name:{name:"name",range:"StringType",domain:"AbstractSecurityScheme"},type:{name:"type",range:"StringType",domain:"AbstractSecurityScheme"},description:{name:"description",range:"MarkdownString",domain:"AbstractSecurityScheme"},describedBy:{name:"describedBy",range:"SecuritySchemePart",domain:"AbstractSecurityScheme"},settings:{name:"settings",range:"SecuritySchemeSettings",domain:"AbstractSecurityScheme"}}},DigestSecurityScheme:{name:"DigestSecurityScheme",properties:{name:{name:"name",range:"StringType",domain:"AbstractSecurityScheme"},type:{name:"type",range:"StringType",domain:"AbstractSecurityScheme"},description:{name:"description",range:"MarkdownString",domain:"AbstractSecurityScheme"},describedBy:{name:"describedBy",range:"SecuritySchemePart",domain:"AbstractSecurityScheme"},settings:{name:"settings",range:"SecuritySchemeSettings",domain:"AbstractSecurityScheme"}}},CustomSecurityScheme:{name:"CustomSecurityScheme",properties:{name:{name:"name",range:"StringType",domain:"AbstractSecurityScheme"},type:{name:"type",range:"StringType",domain:"AbstractSecurityScheme"},description:{name:"description",range:"MarkdownString",domain:"AbstractSecurityScheme"},describedBy:{name:"describedBy",range:"SecuritySchemePart",domain:"AbstractSecurityScheme"},settings:{name:"settings",range:"SecuritySchemeSettings",domain:"AbstractSecurityScheme"}}}},Universe10:{Library:{name:"Library",properties:{annotations:{name:"annotations"},uses:{name:"uses"},schemas:{name:"schemas"},types:{name:"types"},traits:{name:"traits"},resourceTypes:{name:"resourceTypes"},annotationTypes:{name:"annotationTypes"},securitySchemes:{name:"securitySchemes"},usage:{name:"usage"},name:{name:"name"}}},LibraryBase:{name:"LibraryBase",properties:{annotations:{name:"annotations"},uses:{name:"uses"},schemas:{name:"schemas"},types:{name:"types"},traits:{name:"traits"},resourceTypes:{name:"resourceTypes"},annotationTypes:{name:"annotationTypes"},securitySchemes:{name:"securitySchemes"}}},Api:{name:"Api",properties:{annotations:{name:"annotations"},uses:{name:"uses"},schemas:{name:"schemas"},types:{name:"types"},traits:{name:"traits"},resourceTypes:{name:"resourceTypes"},annotationTypes:{name:"annotationTypes"},securitySchemes:{name:"securitySchemes"},title:{name:"title"},description:{name:"description"},version:{name:"version"},baseUri:{name:"baseUri"},baseUriParameters:{name:"baseUriParameters"},protocols:{name:"protocols"},mediaType:{name:"mediaType"},securedBy:{name:"securedBy"},resources:{name:"resources"},documentation:{name:"documentation"},RAMLVersion:{name:"RAMLVersion",range:"StringType",domain:"Api"}}},Overlay:{name:"Overlay",properties:{annotations:{name:"annotations"},uses:{name:"uses"},schemas:{name:"schemas"},types:{name:"types"},traits:{name:"traits"},resourceTypes:{name:"resourceTypes"},annotationTypes:{name:"annotationTypes"},securitySchemes:{name:"securitySchemes"},title:{name:"title"},description:{name:"description"},version:{name:"version"},baseUri:{name:"baseUri"},baseUriParameters:{name:"baseUriParameters"},protocols:{name:"protocols"},mediaType:{name:"mediaType"},securedBy:{name:"securedBy"},resources:{name:"resources"},documentation:{name:"documentation"},usage:{name:"usage"},"extends":{name:"extends"}}},Extension:{name:"Extension",properties:{annotations:{name:"annotations"},uses:{name:"uses"},schemas:{name:"schemas"},types:{name:"types"},traits:{name:"traits"},resourceTypes:{name:"resourceTypes"},annotationTypes:{name:"annotationTypes"},securitySchemes:{name:"securitySchemes"},title:{name:"title"},description:{name:"description"},version:{name:"version"},baseUri:{name:"baseUri"},baseUriParameters:{name:"baseUriParameters"},protocols:{name:"protocols"},mediaType:{name:"mediaType"},securedBy:{name:"securedBy"},resources:{name:"resources"},documentation:{name:"documentation"},usage:{name:"usage"},"extends":{name:"extends"}}},UsesDeclaration:{name:"UsesDeclaration",properties:{annotations:{name:"annotations"},key:{name:"key"},value:{name:"value"}}},FragmentDeclaration:{name:"FragmentDeclaration",properties:{annotations:{name:"annotations"},uses:{name:"uses"}}},DocumentationItem:{name:"DocumentationItem",properties:{annotations:{name:"annotations"},title:{name:"title"},content:{name:"content"}}},ValueType:{name:"ValueType",properties:{annotations:{name:"annotations"}}},StringType:{name:"StringType",properties:{annotations:{name:"annotations"}}},AnyType:{name:"AnyType",properties:{annotations:{name:"annotations"}}},NumberType:{name:"NumberType",properties:{annotations:{name:"annotations"}}},IntegerType:{name:"IntegerType",properties:{annotations:{name:"annotations"}}},NullType:{name:"NullType",properties:{annotations:{name:"annotations"}}},TimeOnlyType:{name:"TimeOnlyType",properties:{annotations:{name:"annotations"}}},DateOnlyType:{name:"DateOnlyType",properties:{annotations:{name:"annotations"}}},DateTimeOnlyType:{name:"DateTimeOnlyType",properties:{annotations:{name:"annotations"}}},DateTimeType:{name:"DateTimeType",properties:{annotations:{name:"annotations"}}},FileType:{name:"FileType",properties:{annotations:{name:"annotations"}}},BooleanType:{name:"BooleanType",properties:{annotations:{name:"annotations"}}},Reference:{name:"Reference",properties:{annotations:{name:"annotations"},structuredValue:{name:"structuredValue",range:"TypeInstance",domain:"Reference"},name:{name:"name",range:"StringType",domain:"Reference"}}},UriTemplate:{name:"UriTemplate",properties:{annotations:{name:"annotations"}}},StatusCodeString:{name:"StatusCodeString",properties:{annotations:{name:"annotations"}}},RelativeUriString:{name:"RelativeUriString",properties:{annotations:{name:"annotations"}}},FullUriTemplateString:{name:"FullUriTemplateString",properties:{annotations:{name:"annotations"}}},FixedUriString:{name:"FixedUriString",
properties:{annotations:{name:"annotations"}}},ContentType:{name:"ContentType",properties:{annotations:{name:"annotations"}}},MarkdownString:{name:"MarkdownString",properties:{annotations:{name:"annotations"}}},SchemaString:{name:"SchemaString",properties:{annotations:{name:"annotations"}}},ExampleSpec:{name:"ExampleSpec",properties:{annotations:{name:"annotations"},value:{name:"value"},strict:{name:"strict"},name:{name:"name"},displayName:{name:"displayName"},description:{name:"description"},structuredValue:{name:"structuredValue",range:"TypeInstance",domain:"ExampleSpec"}}},TypeDeclaration:{name:"TypeDeclaration",properties:{annotations:{name:"annotations"},name:{name:"name"},displayName:{name:"displayName"},facets:{name:"facets"},schema:{name:"schema"},type:{name:"type"},location:{name:"location"},locationKind:{name:"locationKind"},"default":{name:"default"},example:{name:"example"},examples:{name:"examples"},required:{name:"required"},description:{name:"description"},xml:{name:"xml"},allowedTargets:{name:"allowedTargets"},isAnnotation:{name:"isAnnotation"},fixedFacets:{name:"fixedFacets",range:"TypeInstance",domain:"TypeDeclaration"},structuredType:{name:"structuredType",range:"TypeInstance",domain:"TypeDeclaration"},parametrizedProperties:{name:"parametrizedProperties",range:"TypeInstance",domain:"TypeDeclaration"}}},XMLFacetInfo:{name:"XMLFacetInfo",properties:{annotations:{name:"annotations"},attribute:{name:"attribute"},wrapped:{name:"wrapped"},name:{name:"name"},namespace:{name:"namespace"},prefix:{name:"prefix"}}},ArrayTypeDeclaration:{name:"ArrayTypeDeclaration",properties:{annotations:{name:"annotations"},name:{name:"name"},displayName:{name:"displayName"},facets:{name:"facets"},schema:{name:"schema"},type:{name:"type"},location:{name:"location"},locationKind:{name:"locationKind"},"default":{name:"default"},example:{name:"example"},examples:{name:"examples"},required:{name:"required"},description:{name:"description"},xml:{name:"xml"},allowedTargets:{name:"allowedTargets"},isAnnotation:{name:"isAnnotation"},uniqueItems:{name:"uniqueItems"},items:{name:"items"},minItems:{name:"minItems"},maxItems:{name:"maxItems"}}},UnionTypeDeclaration:{name:"UnionTypeDeclaration",properties:{annotations:{name:"annotations"},name:{name:"name"},displayName:{name:"displayName"},facets:{name:"facets"},schema:{name:"schema"},type:{name:"type"},location:{name:"location"},locationKind:{name:"locationKind"},"default":{name:"default"},example:{name:"example"},examples:{name:"examples"},required:{name:"required"},description:{name:"description"},xml:{name:"xml"},allowedTargets:{name:"allowedTargets"},isAnnotation:{name:"isAnnotation"}}},ObjectTypeDeclaration:{name:"ObjectTypeDeclaration",properties:{annotations:{name:"annotations"},name:{name:"name"},displayName:{name:"displayName"},facets:{name:"facets"},schema:{name:"schema"},type:{name:"type"},location:{name:"location"},locationKind:{name:"locationKind"},"default":{name:"default"},example:{name:"example"},examples:{name:"examples"},required:{name:"required"},description:{name:"description"},xml:{name:"xml"},allowedTargets:{name:"allowedTargets"},isAnnotation:{name:"isAnnotation"},properties:{name:"properties"},minProperties:{name:"minProperties"},maxProperties:{name:"maxProperties"},additionalProperties:{name:"additionalProperties"},discriminator:{name:"discriminator"},discriminatorValue:{name:"discriminatorValue"}}},StringTypeDeclaration:{name:"StringTypeDeclaration",properties:{annotations:{name:"annotations"},name:{name:"name"},displayName:{name:"displayName"},facets:{name:"facets"},schema:{name:"schema"},type:{name:"type"},location:{name:"location"},locationKind:{name:"locationKind"},"default":{name:"default"},example:{name:"example"},examples:{name:"examples"},required:{name:"required"},description:{name:"description"},xml:{name:"xml"},allowedTargets:{name:"allowedTargets"},isAnnotation:{name:"isAnnotation"},pattern:{name:"pattern"},minLength:{name:"minLength"},maxLength:{name:"maxLength"},"enum":{name:"enum"}}},BooleanTypeDeclaration:{name:"BooleanTypeDeclaration",properties:{annotations:{name:"annotations"},name:{name:"name"},displayName:{name:"displayName"},facets:{name:"facets"},schema:{name:"schema"},type:{name:"type"},location:{name:"location"},locationKind:{name:"locationKind"},"default":{name:"default"},example:{name:"example"},examples:{name:"examples"},required:{name:"required"},description:{name:"description"},xml:{name:"xml"},allowedTargets:{name:"allowedTargets"},isAnnotation:{name:"isAnnotation"}}},NumberTypeDeclaration:{name:"NumberTypeDeclaration",properties:{annotations:{name:"annotations"},name:{name:"name"},displayName:{name:"displayName"},facets:{name:"facets"},schema:{name:"schema"},type:{name:"type"},location:{name:"location"},locationKind:{name:"locationKind"},"default":{name:"default"},example:{name:"example"},examples:{name:"examples"},required:{name:"required"},description:{name:"description"},xml:{name:"xml"},allowedTargets:{name:"allowedTargets"},isAnnotation:{name:"isAnnotation"},minimum:{name:"minimum"},maximum:{name:"maximum"},"enum":{name:"enum"},format:{name:"format"},multipleOf:{name:"multipleOf"}}},IntegerTypeDeclaration:{name:"IntegerTypeDeclaration",properties:{annotations:{name:"annotations"},name:{name:"name"},displayName:{name:"displayName"},facets:{name:"facets"},schema:{name:"schema"},type:{name:"type"},location:{name:"location"},locationKind:{name:"locationKind"},"default":{name:"default"},example:{name:"example"},examples:{name:"examples"},required:{name:"required"},description:{name:"description"},xml:{name:"xml"},allowedTargets:{name:"allowedTargets"},isAnnotation:{name:"isAnnotation"},minimum:{name:"minimum"},maximum:{name:"maximum"},"enum":{name:"enum"},format:{name:"format"},multipleOf:{name:"multipleOf"}}},DateOnlyTypeDeclaration:{name:"DateOnlyTypeDeclaration",properties:{annotations:{name:"annotations"},name:{name:"name"},displayName:{name:"displayName"},facets:{name:"facets"},schema:{name:"schema"},type:{name:"type"},location:{name:"location"},locationKind:{name:"locationKind"},"default":{name:"default"},example:{name:"example"},examples:{name:"examples"},required:{name:"required"},description:{name:"description"},xml:{name:"xml"},allowedTargets:{name:"allowedTargets"},isAnnotation:{name:"isAnnotation"}}},TimeOnlyTypeDeclaration:{name:"TimeOnlyTypeDeclaration",properties:{annotations:{name:"annotations"},name:{name:"name"},displayName:{name:"displayName"},facets:{name:"facets"},schema:{name:"schema"},type:{name:"type"},location:{name:"location"},locationKind:{name:"locationKind"},"default":{name:"default"},example:{name:"example"},examples:{name:"examples"},required:{name:"required"},description:{name:"description"},xml:{name:"xml"},allowedTargets:{name:"allowedTargets"},isAnnotation:{name:"isAnnotation"}}},DateTimeOnlyTypeDeclaration:{name:"DateTimeOnlyTypeDeclaration",properties:{annotations:{name:"annotations"},name:{name:"name"},displayName:{name:"displayName"},facets:{name:"facets"},schema:{name:"schema"},type:{name:"type"},location:{name:"location"},locationKind:{name:"locationKind"},"default":{name:"default"},example:{name:"example"},examples:{name:"examples"},required:{name:"required"},description:{name:"description"},xml:{name:"xml"},allowedTargets:{name:"allowedTargets"},isAnnotation:{name:"isAnnotation"}}},DateTimeTypeDeclaration:{name:"DateTimeTypeDeclaration",properties:{annotations:{name:"annotations"},name:{name:"name"},displayName:{name:"displayName"},facets:{name:"facets"},schema:{name:"schema"},type:{name:"type"},location:{name:"location"},locationKind:{name:"locationKind"},"default":{name:"default"},example:{name:"example"},examples:{name:"examples"},required:{name:"required"},description:{name:"description"},xml:{name:"xml"},allowedTargets:{name:"allowedTargets"},isAnnotation:{name:"isAnnotation"},format:{name:"format"}}},TypeInstance:{name:"TypeInstance",properties:{properties:{name:"properties"},isScalar:{name:"isScalar"},value:{name:"value"},isArray:{name:"isArray"},items:{name:"items"}}},TypeInstanceProperty:{name:"TypeInstanceProperty",properties:{name:{name:"name"},value:{name:"value"},values:{name:"values"},isArray:{name:"isArray"}}},ModelLocation:{name:"ModelLocation",properties:{}},LocationKind:{name:"LocationKind",properties:{}},MimeType:{name:"MimeType",properties:{annotations:{name:"annotations"}}},Response:{name:"Response",properties:{annotations:{name:"annotations"},code:{name:"code"},headers:{name:"headers"},body:{name:"body"},description:{name:"description"}}},Annotable:{name:"Annotable",properties:{annotations:{name:"annotations"}}},AnnotationRef:{name:"AnnotationRef",properties:{annotations:{name:"annotations"},annotation:{name:"annotation",range:"TypeDeclaration",domain:"AnnotationRef"}}},AnnotationTarget:{name:"AnnotationTarget",properties:{annotations:{name:"annotations"}}},TraitRef:{name:"TraitRef",properties:{annotations:{name:"annotations"},trait:{name:"trait",range:"Trait",domain:"TraitRef"}}},Trait:{name:"Trait",properties:{annotations:{name:"annotations"},queryParameters:{name:"queryParameters"},headers:{name:"headers"},queryString:{name:"queryString"},responses:{name:"responses"},body:{name:"body"},protocols:{name:"protocols"},is:{name:"is"},securedBy:{name:"securedBy"},description:{name:"description"},displayName:{name:"displayName"},name:{name:"name"},usage:{name:"usage"},parametrizedProperties:{name:"parametrizedProperties",range:"TypeInstance",domain:"Trait"}}},MethodBase:{name:"MethodBase",properties:{annotations:{name:"annotations"},queryParameters:{name:"queryParameters"},headers:{name:"headers"},queryString:{name:"queryString"},responses:{name:"responses"},body:{name:"body"},protocols:{name:"protocols"},is:{name:"is"},securedBy:{name:"securedBy"},description:{name:"description"},displayName:{name:"displayName"}}},Method:{name:"Method",properties:{annotations:{name:"annotations"},queryParameters:{name:"queryParameters"},headers:{name:"headers"},queryString:{name:"queryString"},responses:{name:"responses"},body:{name:"body"},protocols:{name:"protocols"},is:{name:"is"},securedBy:{name:"securedBy"},description:{name:"description"},displayName:{name:"displayName"},method:{name:"method"},parametrizedProperties:{name:"parametrizedProperties",range:"TypeInstance",domain:"Method"}}},Operation:{name:"Operation",properties:{annotations:{name:"annotations"},queryParameters:{name:"queryParameters"},headers:{name:"headers"},queryString:{name:"queryString"},responses:{name:"responses"}}},SecuritySchemePart:{name:"SecuritySchemePart",properties:{annotations:{name:"annotations"},queryParameters:{name:"queryParameters"},headers:{name:"headers"},queryString:{name:"queryString"},responses:{name:"responses"}}},SecuritySchemeSettings:{name:"SecuritySchemeSettings",properties:{annotations:{name:"annotations"}}},OAuth1SecuritySchemeSettings:{name:"OAuth1SecuritySchemeSettings",properties:{annotations:{name:"annotations"},requestTokenUri:{name:"requestTokenUri"},authorizationUri:{name:"authorizationUri"},tokenCredentialsUri:{name:"tokenCredentialsUri"},signatures:{name:"signatures"}}},OAuth2SecuritySchemeSettings:{name:"OAuth2SecuritySchemeSettings",properties:{annotations:{name:"annotations"},accessTokenUri:{name:"accessTokenUri"},authorizationUri:{name:"authorizationUri"},authorizationGrants:{name:"authorizationGrants"},scopes:{name:"scopes"}}},SecuritySchemeRef:{name:"SecuritySchemeRef",properties:{annotations:{name:"annotations"},securitySchemeName:{name:"securitySchemeName",range:"StringType",domain:"SecuritySchemeRef"},securityScheme:{name:"securityScheme",range:"AbstractSecurityScheme",domain:"SecuritySchemeRef"}}},AbstractSecurityScheme:{name:"AbstractSecurityScheme",properties:{annotations:{name:"annotations"},name:{name:"name"},type:{name:"type"},description:{name:"description"},describedBy:{name:"describedBy"},displayName:{name:"displayName"},settings:{name:"settings"}}},OAuth2SecurityScheme:{name:"OAuth2SecurityScheme",properties:{annotations:{name:"annotations"},name:{name:"name"},type:{name:"type"},description:{name:"description"},describedBy:{name:"describedBy"},displayName:{name:"displayName"},settings:{name:"settings"}}},OAuth1SecurityScheme:{name:"OAuth1SecurityScheme",properties:{annotations:{name:"annotations"},name:{name:"name"},type:{name:"type"},description:{name:"description"},describedBy:{name:"describedBy"},displayName:{name:"displayName"},settings:{name:"settings"}}},PassThroughSecurityScheme:{name:"PassThroughSecurityScheme",properties:{annotations:{name:"annotations"},name:{name:"name"},type:{name:"type"},description:{name:"description"},describedBy:{name:"describedBy"},displayName:{name:"displayName"},settings:{name:"settings"}}},BasicSecurityScheme:{name:"BasicSecurityScheme",properties:{annotations:{name:"annotations"},name:{name:"name"},type:{name:"type"},description:{name:"description"},describedBy:{name:"describedBy"},displayName:{name:"displayName"},settings:{name:"settings"}}},DigestSecurityScheme:{name:"DigestSecurityScheme",properties:{annotations:{name:"annotations"},name:{name:"name"},type:{name:"type"},description:{name:"description"},describedBy:{name:"describedBy"},displayName:{name:"displayName"},settings:{name:"settings"}}},CustomSecurityScheme:{name:"CustomSecurityScheme",properties:{annotations:{name:"annotations"},name:{name:"name"},type:{name:"type"},description:{name:"description"},describedBy:{name:"describedBy"},displayName:{name:"displayName"},settings:{name:"settings"}}},ResourceTypeRef:{name:"ResourceTypeRef",properties:{annotations:{name:"annotations"},resourceType:{name:"resourceType",range:"ResourceType",domain:"ResourceTypeRef"}}},ResourceType:{name:"ResourceType",properties:{annotations:{name:"annotations"},methods:{name:"methods"},is:{name:"is"},type:{name:"type"},description:{name:"description"},securedBy:{name:"securedBy"},uriParameters:{name:"uriParameters"},displayName:{name:"displayName"},name:{name:"name"},usage:{name:"usage"},parametrizedProperties:{name:"parametrizedProperties",range:"TypeInstance",domain:"ResourceType"}}},ResourceBase:{name:"ResourceBase",properties:{annotations:{name:"annotations"},methods:{name:"methods"},is:{name:"is"},type:{name:"type"},description:{name:"description"},securedBy:{name:"securedBy"},uriParameters:{name:"uriParameters"}}},Resource:{name:"Resource",properties:{annotations:{name:"annotations"},methods:{name:"methods"},is:{name:"is"},type:{name:"type"},description:{name:"description"},securedBy:{name:"securedBy"},uriParameters:{name:"uriParameters"},relativeUri:{name:"relativeUri"},displayName:{name:"displayName"},resources:{name:"resources"}}},FileTypeDeclaration:{name:"FileTypeDeclaration",properties:{annotations:{name:"annotations"},name:{name:"name"},displayName:{name:"displayName"},facets:{name:"facets"},schema:{name:"schema"},type:{name:"type"},location:{name:"location"},locationKind:{name:"locationKind"},"default":{name:"default"},example:{name:"example"},examples:{name:"examples"},required:{name:"required"},description:{name:"description"},xml:{name:"xml"},allowedTargets:{name:"allowedTargets"},isAnnotation:{name:"isAnnotation"},fileTypes:{name:"fileTypes"},minLength:{name:"minLength"},maxLength:{name:"maxLength"}}}}};e.exports=r},function(e,t,n){t.XMLHttpRequest=XMLHttpRequest},function(e,t,n){function r(){if(!s){s=!0;for(var e,t=o.length;t;){e=o,o=[];for(var n=-1;++n<t;)e[n]();t=o.length}s=!1}}function i(){}var a=e.exports={},o=[],s=!1;a.nextTick=function(e){o.push(e),s||setTimeout(r,0)},a.title="browser",a.browser=!0,a.env={},a.argv=[],a.version="",a.versions={},a.on=i,a.addListener=i,a.once=i,a.off=i,a.removeListener=i,a.removeAllListeners=i,a.emit=i,a.binding=function(e){throw new Error("process.binding is not supported")},a.cwd=function(){return"/"},a.chdir=function(e){throw new Error("process.chdir is not supported")},a.umask=function(){return 0}},function(e,t,n){(function(t){function n(e){return e.replace(/=/g,"").replace(/\+/g,"-").replace(/\//g,"_")}function r(e){t.isBuffer(e)&&(e=e.toString());var n=i(e).replace(/\-/g,"+").replace(/_/g,"/");return n}function i(e){var n=4,r=e.length,i=e.length%n;if(!i)return e;var a=r,o=n-i,s=r+o,u=t(s);for(u.write(e);o--;)u.write("=",a++);return u.toString()}function a(e,n){return t(r(e),"base64").toString(n)}function o(e,r){return n(t(e,r).toString("base64"))}function s(e){return t(r(e),"base64")}o.toBase64=r,o.fromBase64=n,o.decode=a,o.encode=o,o.toBuffer=s,e.exports=o}).call(t,n(94).Buffer)},function(e,t,n){(function(t){function r(e,t){if(!(this instanceof r))return new r(e,t);"function"==typeof e&&(t=e,e={}),e||(e={});var n=e.encoding,i=!1;n?(n=String(n).toLowerCase(),("u8"===n||"uint8"===n)&&(n="uint8array")):i=!0,p.call(this,{objectMode:!0}),this.encoding=n,this.shouldInferEncoding=i,t&&this.on("finish",function(){t(this.getBody())}),this.body=[]}function i(e){return/Array\]$/.test(Object.prototype.toString.call(e))}function a(e){return"string"==typeof e||i(e)||e&&"function"==typeof e.subarray}function o(e){for(var n=[],r=0;r<e.length;r++){var i=e[r];"string"==typeof i?n.push(i):t.isBuffer(i)?n.push(i):a(i)?n.push(new t(i)):n.push(new t(String(i)))}return t.isBuffer(e[0])?(n=t.concat(n),n=n.toString("utf8")):n=n.join(""),n}function s(e){for(var n=[],r=0;r<e.length;r++){var i=e[r];t.isBuffer(i)?n.push(i):a(i)?n.push(new t(i)):n.push(new t(String(i)))}return t.concat(n)}function u(e){for(var t=[],n=0;n<e.length;n++)t.push.apply(t,e[n]);return t}function l(e){for(var n=0,r=0;r<e.length;r++)"string"==typeof e[r]&&(e[r]=new t(e[r])),n+=e[r].length;for(var i=new f(n),r=0,a=0;r<e.length;r++)for(var o=e[r],s=0;s<o.length;s++)i[a++]=o[s];return i}var p=n(111).Writable,c=n(110);if("undefined"==typeof Uint8Array)var f=n(97).Uint8Array;else var f=Uint8Array;e.exports=r,c(r,p),r.prototype._write=function(e,t,n){this.body.push(e),n()},r.prototype.inferEncoding=function(e){var n=void 0===e?this.body[0]:e;return t.isBuffer(n)?"buffer":"undefined"!=typeof Uint8Array&&n instanceof Uint8Array?"uint8array":Array.isArray(n)?"array":"string"==typeof n?"string":"[object Object]"===Object.prototype.toString.call(n)?"object":"buffer"},r.prototype.getBody=function(){return this.encoding||0!==this.body.length?(this.shouldInferEncoding&&(this.encoding=this.inferEncoding()),"array"===this.encoding?u(this.body):"string"===this.encoding?o(this.body):"buffer"===this.encoding?s(this.body):"uint8array"===this.encoding?l(this.body):this.body):[]};Array.isArray||function(e){return"[object Array]"==Object.prototype.toString.call(e)}}).call(t,n(94).Buffer)},function(e,t,n){var r,i;(function(){function n(e){function t(t,n,r,i,a,o){for(;a>=0&&o>a;a+=e){var s=i?i[a]:a;r=n(r,t[s],s,t)}return r}return function(n,r,i,a){r=b(r,a,4);var o=!C(n)&&E.keys(n),s=(o||n).length,u=e>0?0:s-1;return arguments.length<3&&(i=n[o?o[u]:u],u+=e),t(n,r,i,o,u,s)}}function a(e){return function(t,n,r){n=N(n,r);for(var i=I(t),a=e>0?0:i-1;a>=0&&i>a;a+=e)if(n(t[a],a,t))return a;return-1}}function o(e,t,n){return function(r,i,a){var o=0,s=I(r);if("number"==typeof a)e>0?o=a>=0?a:Math.max(a+s,o):s=a>=0?Math.min(a+1,s):a+s+1;else if(n&&a&&s)return a=n(r,i),r[a]===i?a:-1;if(i!==i)return a=t(d.call(r,o,s),E.isNaN),a>=0?a+o:-1;for(a=e>0?o:s-1;a>=0&&s>a;a+=e)if(r[a]===i)return a;return-1}}function s(e,t){var n=x.length,r=e.constructor,i=E.isFunction(r)&&r.prototype||c,a="constructor";for(E.has(e,a)&&!E.contains(t,a)&&t.push(a);n--;)a=x[n],a in e&&e[a]!==i[a]&&!E.contains(t,a)&&t.push(a)}var u=this,l=u._,p=Array.prototype,c=Object.prototype,f=Function.prototype,m=p.push,d=p.slice,h=c.toString,y=c.hasOwnProperty,v=Array.isArray,g=Object.keys,A=f.bind,S=Object.create,T=function(){},E=function(e){return e instanceof E?e:this instanceof E?void(this._wrapped=e):new E(e)};"undefined"!=typeof e&&e.exports&&(t=e.exports=E),t._=E,E.VERSION="1.8.3";var b=function(e,t,n){if(void 0===t)return e;switch(null==n?3:n){case 1:return function(n){return e.call(t,n)};case 2:return function(n,r){return e.call(t,n,r)};case 3:return function(n,r,i){return e.call(t,n,r,i)};case 4:return function(n,r,i,a){return e.call(t,n,r,i,a)}}return function(){return e.apply(t,arguments)}},N=function(e,t,n){return null==e?E.identity:E.isFunction(e)?b(e,t,n):E.isObject(e)?E.matcher(e):E.property(e)};E.iteratee=function(e,t){return N(e,t,1/0)};var _=function(e,t){return function(n){var r=arguments.length;if(2>r||null==n)return n;for(var i=1;r>i;i++)for(var a=arguments[i],o=e(a),s=o.length,u=0;s>u;u++){var l=o[u];t&&void 0!==n[l]||(n[l]=a[l])}return n}},M=function(e){if(!E.isObject(e))return{};if(S)return S(e);T.prototype=e;var t=new T;return T.prototype=null,t},w=function(e){return function(t){return null==t?void 0:t[e]}},R=Math.pow(2,53)-1,I=w("length"),C=function(e){var t=I(e);return"number"==typeof t&&t>=0&&R>=t};E.each=E.forEach=function(e,t,n){t=b(t,n);var r,i;if(C(e))for(r=0,i=e.length;i>r;r++)t(e[r],r,e);else{var a=E.keys(e);for(r=0,i=a.length;i>r;r++)t(e[a[r]],a[r],e)}return e},E.map=E.collect=function(e,t,n){t=N(t,n);for(var r=!C(e)&&E.keys(e),i=(r||e).length,a=Array(i),o=0;i>o;o++){var s=r?r[o]:o;a[o]=t(e[s],s,e)}return a},E.reduce=E.foldl=E.inject=n(1),E.reduceRight=E.foldr=n(-1),E.find=E.detect=function(e,t,n){var r;return r=C(e)?E.findIndex(e,t,n):E.findKey(e,t,n),void 0!==r&&-1!==r?e[r]:void 0},E.filter=E.select=function(e,t,n){var r=[];return t=N(t,n),E.each(e,function(e,n,i){t(e,n,i)&&r.push(e)}),r},E.reject=function(e,t,n){return E.filter(e,E.negate(N(t)),n)},E.every=E.all=function(e,t,n){t=N(t,n);for(var r=!C(e)&&E.keys(e),i=(r||e).length,a=0;i>a;a++){var o=r?r[a]:a;if(!t(e[o],o,e))return!1}return!0},E.some=E.any=function(e,t,n){t=N(t,n);for(var r=!C(e)&&E.keys(e),i=(r||e).length,a=0;i>a;a++){var o=r?r[a]:a;if(t(e[o],o,e))return!0}return!1},E.contains=E.includes=E.include=function(e,t,n,r){return C(e)||(e=E.values(e)),("number"!=typeof n||r)&&(n=0),E.indexOf(e,t,n)>=0},E.invoke=function(e,t){var n=d.call(arguments,2),r=E.isFunction(t);return E.map(e,function(e){var i=r?t:e[t];return null==i?i:i.apply(e,n)})},E.pluck=function(e,t){return E.map(e,E.property(t))},E.where=function(e,t){return E.filter(e,E.matcher(t))},E.findWhere=function(e,t){return E.find(e,E.matcher(t))},E.max=function(e,t,n){var r,i,a=-(1/0),o=-(1/0);if(null==t&&null!=e){e=C(e)?e:E.values(e);for(var s=0,u=e.length;u>s;s++)r=e[s],r>a&&(a=r)}else t=N(t,n),E.each(e,function(e,n,r){i=t(e,n,r),(i>o||i===-(1/0)&&a===-(1/0))&&(a=e,o=i)});return a},E.min=function(e,t,n){var r,i,a=1/0,o=1/0;if(null==t&&null!=e){e=C(e)?e:E.values(e);for(var s=0,u=e.length;u>s;s++)r=e[s],a>r&&(a=r)}else t=N(t,n),E.each(e,function(e,n,r){i=t(e,n,r),(o>i||i===1/0&&a===1/0)&&(a=e,o=i)});return a},E.shuffle=function(e){for(var t,n=C(e)?e:E.values(e),r=n.length,i=Array(r),a=0;r>a;a++)t=E.random(0,a),t!==a&&(i[a]=i[t]),i[t]=n[a];return i},E.sample=function(e,t,n){return null==t||n?(C(e)||(e=E.values(e)),e[E.random(e.length-1)]):E.shuffle(e).slice(0,Math.max(0,t))},E.sortBy=function(e,t,n){return t=N(t,n),E.pluck(E.map(e,function(e,n,r){return{value:e,index:n,criteria:t(e,n,r)}}).sort(function(e,t){var n=e.criteria,r=t.criteria;if(n!==r){if(n>r||void 0===n)return 1;if(r>n||void 0===r)return-1}return e.index-t.index}),"value")};var L=function(e){return function(t,n,r){var i={};return n=N(n,r),E.each(t,function(r,a){var o=n(r,a,t);e(i,r,o)}),i}};E.groupBy=L(function(e,t,n){E.has(e,n)?e[n].push(t):e[n]=[t]}),E.indexBy=L(function(e,t,n){e[n]=t}),E.countBy=L(function(e,t,n){E.has(e,n)?e[n]++:e[n]=1}),E.toArray=function(e){return e?E.isArray(e)?d.call(e):C(e)?E.map(e,E.identity):E.values(e):[]},E.size=function(e){return null==e?0:C(e)?e.length:E.keys(e).length},E.partition=function(e,t,n){t=N(t,n);var r=[],i=[];return E.each(e,function(e,n,a){(t(e,n,a)?r:i).push(e)}),[r,i]},E.first=E.head=E.take=function(e,t,n){return null==e?void 0:null==t||n?e[0]:E.initial(e,e.length-t)},E.initial=function(e,t,n){return d.call(e,0,Math.max(0,e.length-(null==t||n?1:t)))},E.last=function(e,t,n){return null==e?void 0:null==t||n?e[e.length-1]:E.rest(e,Math.max(0,e.length-t))},E.rest=E.tail=E.drop=function(e,t,n){return d.call(e,null==t||n?1:t)},E.compact=function(e){return E.filter(e,E.identity)};var P=function(e,t,n,r){for(var i=[],a=0,o=r||0,s=I(e);s>o;o++){var u=e[o];if(C(u)&&(E.isArray(u)||E.isArguments(u))){t||(u=P(u,t,n));var l=0,p=u.length;for(i.length+=p;p>l;)i[a++]=u[l++]}else n||(i[a++]=u)}return i};E.flatten=function(e,t){return P(e,t,!1)},E.without=function(e){return E.difference(e,d.call(arguments,1))},E.uniq=E.unique=function(e,t,n,r){E.isBoolean(t)||(r=n,n=t,t=!1),null!=n&&(n=N(n,r));for(var i=[],a=[],o=0,s=I(e);s>o;o++){var u=e[o],l=n?n(u,o,e):u;t?(o&&a===l||i.push(u),a=l):n?E.contains(a,l)||(a.push(l),i.push(u)):E.contains(i,u)||i.push(u)}return i},E.union=function(){return E.uniq(P(arguments,!0,!0))},E.intersection=function(e){for(var t=[],n=arguments.length,r=0,i=I(e);i>r;r++){var a=e[r];if(!E.contains(t,a)){for(var o=1;n>o&&E.contains(arguments[o],a);o++);o===n&&t.push(a)}}return t},E.difference=function(e){var t=P(arguments,!0,!0,1);return E.filter(e,function(e){return!E.contains(t,e)})},E.zip=function(){return E.unzip(arguments)},E.unzip=function(e){for(var t=e&&E.max(e,I).length||0,n=Array(t),r=0;t>r;r++)n[r]=E.pluck(e,r);return n},E.object=function(e,t){for(var n={},r=0,i=I(e);i>r;r++)t?n[e[r]]=t[r]:n[e[r][0]]=e[r][1];return n},E.findIndex=a(1),E.findLastIndex=a(-1),E.sortedIndex=function(e,t,n,r){n=N(n,r,1);for(var i=n(t),a=0,o=I(e);o>a;){var s=Math.floor((a+o)/2);n(e[s])<i?a=s+1:o=s}return a},E.indexOf=o(1,E.findIndex,E.sortedIndex),E.lastIndexOf=o(-1,E.findLastIndex),E.range=function(e,t,n){null==t&&(t=e||0,e=0),n=n||1;for(var r=Math.max(Math.ceil((t-e)/n),0),i=Array(r),a=0;r>a;a++,e+=n)i[a]=e;return i};var O=function(e,t,n,r,i){if(!(r instanceof t))return e.apply(n,i);var a=M(e.prototype),o=e.apply(a,i);return E.isObject(o)?o:a};E.bind=function(e,t){if(A&&e.bind===A)return A.apply(e,d.call(arguments,1));if(!E.isFunction(e))throw new TypeError("Bind must be called on a function");var n=d.call(arguments,2),r=function(){return O(e,r,t,this,n.concat(d.call(arguments)))};return r},E.partial=function(e){var t=d.call(arguments,1),n=function(){for(var r=0,i=t.length,a=Array(i),o=0;i>o;o++)a[o]=t[o]===E?arguments[r++]:t[o];for(;r<arguments.length;)a.push(arguments[r++]);return O(e,n,this,this,a)};return n},E.bindAll=function(e){var t,n,r=arguments.length;if(1>=r)throw new Error("bindAll must be passed function names");for(t=1;r>t;t++)n=arguments[t],e[n]=E.bind(e[n],e);return e},E.memoize=function(e,t){var n=function(r){var i=n.cache,a=""+(t?t.apply(this,arguments):r);return E.has(i,a)||(i[a]=e.apply(this,arguments)),i[a]};return n.cache={},n},E.delay=function(e,t){var n=d.call(arguments,2);return setTimeout(function(){return e.apply(null,n)},t)},E.defer=E.partial(E.delay,E,1),E.throttle=function(e,t,n){var r,i,a,o=null,s=0;n||(n={});var u=function(){s=n.leading===!1?0:E.now(),o=null,a=e.apply(r,i),o||(r=i=null)};return function(){var l=E.now();s||n.leading!==!1||(s=l);var p=t-(l-s);return r=this,i=arguments,0>=p||p>t?(o&&(clearTimeout(o),o=null),s=l,a=e.apply(r,i),o||(r=i=null)):o||n.trailing===!1||(o=setTimeout(u,p)),a}},E.debounce=function(e,t,n){var r,i,a,o,s,u=function(){var l=E.now()-o;t>l&&l>=0?r=setTimeout(u,t-l):(r=null,n||(s=e.apply(a,i),r||(a=i=null)))};return function(){a=this,i=arguments,o=E.now();var l=n&&!r;return r||(r=setTimeout(u,t)),l&&(s=e.apply(a,i),a=i=null),s}},E.wrap=function(e,t){return E.partial(t,e)},E.negate=function(e){return function(){return!e.apply(this,arguments)}},E.compose=function(){var e=arguments,t=e.length-1;return function(){for(var n=t,r=e[t].apply(this,arguments);n--;)r=e[n].call(this,r);return r}},E.after=function(e,t){return function(){return--e<1?t.apply(this,arguments):void 0}},E.before=function(e,t){var n;return function(){return--e>0&&(n=t.apply(this,arguments)),1>=e&&(t=null),n}},E.once=E.partial(E.before,2);var D=!{toString:null}.propertyIsEnumerable("toString"),x=["valueOf","isPrototypeOf","toString","propertyIsEnumerable","hasOwnProperty","toLocaleString"];E.keys=function(e){if(!E.isObject(e))return[];if(g)return g(e);var t=[];for(var n in e)E.has(e,n)&&t.push(n);return D&&s(e,t),t},E.allKeys=function(e){if(!E.isObject(e))return[];var t=[];for(var n in e)t.push(n);return D&&s(e,t),t},E.values=function(e){for(var t=E.keys(e),n=t.length,r=Array(n),i=0;n>i;i++)r[i]=e[t[i]];return r},E.mapObject=function(e,t,n){t=N(t,n);for(var r,i=E.keys(e),a=i.length,o={},s=0;a>s;s++)r=i[s],o[r]=t(e[r],r,e);return o},E.pairs=function(e){for(var t=E.keys(e),n=t.length,r=Array(n),i=0;n>i;i++)r[i]=[t[i],e[t[i]]];return r},E.invert=function(e){for(var t={},n=E.keys(e),r=0,i=n.length;i>r;r++)t[e[n[r]]]=n[r];return t},E.functions=E.methods=function(e){var t=[];for(var n in e)E.isFunction(e[n])&&t.push(n);return t.sort()},E.extend=_(E.allKeys),E.extendOwn=E.assign=_(E.keys),E.findKey=function(e,t,n){t=N(t,n);for(var r,i=E.keys(e),a=0,o=i.length;o>a;a++)if(r=i[a],t(e[r],r,e))return r},E.pick=function(e,t,n){var r,i,a={},o=e;if(null==o)return a;E.isFunction(t)?(i=E.allKeys(o),r=b(t,n)):(i=P(arguments,!1,!1,1),r=function(e,t,n){return t in n},o=Object(o));for(var s=0,u=i.length;u>s;s++){var l=i[s],p=o[l];r(p,l,o)&&(a[l]=p)}return a},E.omit=function(e,t,n){if(E.isFunction(t))t=E.negate(t);else{var r=E.map(P(arguments,!1,!1,1),String);t=function(e,t){return!E.contains(r,t)}}return E.pick(e,t,n)},E.defaults=_(E.allKeys,!0),E.create=function(e,t){var n=M(e);return t&&E.extendOwn(n,t),n},E.clone=function(e){return E.isObject(e)?E.isArray(e)?e.slice():E.extend({},e):e},E.tap=function(e,t){return t(e),e},E.isMatch=function(e,t){var n=E.keys(t),r=n.length;if(null==e)return!r;for(var i=Object(e),a=0;r>a;a++){var o=n[a];if(t[o]!==i[o]||!(o in i))return!1}return!0};var U=function(e,t,n,r){if(e===t)return 0!==e||1/e===1/t;if(null==e||null==t)return e===t;e instanceof E&&(e=e._wrapped),t instanceof E&&(t=t._wrapped);var i=h.call(e);if(i!==h.call(t))return!1;switch(i){case"[object RegExp]":case"[object String]":return""+e==""+t;case"[object Number]":return+e!==+e?+t!==+t:0===+e?1/+e===1/t:+e===+t;case"[object Date]":case"[object Boolean]":return+e===+t}var a="[object Array]"===i;if(!a){if("object"!=typeof e||"object"!=typeof t)return!1;var o=e.constructor,s=t.constructor;if(o!==s&&!(E.isFunction(o)&&o instanceof o&&E.isFunction(s)&&s instanceof s)&&"constructor"in e&&"constructor"in t)return!1}n=n||[],r=r||[];for(var u=n.length;u--;)if(n[u]===e)return r[u]===t;if(n.push(e),r.push(t),a){if(u=e.length,u!==t.length)return!1;for(;u--;)if(!U(e[u],t[u],n,r))return!1}else{var l,p=E.keys(e);if(u=p.length,E.keys(t).length!==u)return!1;for(;u--;)if(l=p[u],!E.has(t,l)||!U(e[l],t[l],n,r))return!1}return n.pop(),r.pop(),!0};E.isEqual=function(e,t){return U(e,t)},E.isEmpty=function(e){return null==e?!0:C(e)&&(E.isArray(e)||E.isString(e)||E.isArguments(e))?0===e.length:0===E.keys(e).length},E.isElement=function(e){return!(!e||1!==e.nodeType)},E.isArray=v||function(e){return"[object Array]"===h.call(e)},E.isObject=function(e){var t=typeof e;return"function"===t||"object"===t&&!!e},E.each(["Arguments","Function","String","Number","Date","RegExp","Error"],function(e){E["is"+e]=function(t){return h.call(t)==="[object "+e+"]"}}),E.isArguments(arguments)||(E.isArguments=function(e){return E.has(e,"callee")}),"function"!=typeof/./&&"object"!=typeof Int8Array&&(E.isFunction=function(e){return"function"==typeof e||!1}),E.isFinite=function(e){return isFinite(e)&&!isNaN(parseFloat(e))},E.isNaN=function(e){return E.isNumber(e)&&e!==+e},E.isBoolean=function(e){return e===!0||e===!1||"[object Boolean]"===h.call(e)},E.isNull=function(e){return null===e},E.isUndefined=function(e){return void 0===e},E.has=function(e,t){return null!=e&&y.call(e,t)},E.noConflict=function(){return u._=l,this},E.identity=function(e){return e},E.constant=function(e){return function(){return e}},E.noop=function(){},E.property=w,E.propertyOf=function(e){return null==e?function(){}:function(t){return e[t]}},E.matcher=E.matches=function(e){
return e=E.extendOwn({},e),function(t){return E.isMatch(t,e)}},E.times=function(e,t,n){var r=Array(Math.max(0,e));t=b(t,n,1);for(var i=0;e>i;i++)r[i]=t(i);return r},E.random=function(e,t){return null==t&&(t=e,e=0),e+Math.floor(Math.random()*(t-e+1))},E.now=Date.now||function(){return(new Date).getTime()};var k={"&":"&amp;","<":"&lt;",">":"&gt;",'"':"&quot;","'":"&#x27;","`":"&#x60;"},F=E.invert(k),B=function(e){var t=function(t){return e[t]},n="(?:"+E.keys(e).join("|")+")",r=RegExp(n),i=RegExp(n,"g");return function(e){return e=null==e?"":""+e,r.test(e)?e.replace(i,t):e}};E.escape=B(k),E.unescape=B(F),E.result=function(e,t,n){var r=null==e?void 0:e[t];return void 0===r&&(r=n),E.isFunction(r)?r.call(e):r};var K=0;E.uniqueId=function(e){var t=++K+"";return e?e+t:t},E.templateSettings={evaluate:/<%([\s\S]+?)%>/g,interpolate:/<%=([\s\S]+?)%>/g,escape:/<%-([\s\S]+?)%>/g};var V=/(.)^/,j={"'":"'","\\":"\\","\r":"r","\n":"n","\u2028":"u2028","\u2029":"u2029"},W=/\\|'|\r|\n|\u2028|\u2029/g,q=function(e){return"\\"+j[e]};E.template=function(e,t,n){!t&&n&&(t=n),t=E.defaults({},t,E.templateSettings);var r=RegExp([(t.escape||V).source,(t.interpolate||V).source,(t.evaluate||V).source].join("|")+"|$","g"),i=0,a="__p+='";e.replace(r,function(t,n,r,o,s){return a+=e.slice(i,s).replace(W,q),i=s+t.length,n?a+="'+\n((__t=("+n+"))==null?'':_.escape(__t))+\n'":r?a+="'+\n((__t=("+r+"))==null?'':__t)+\n'":o&&(a+="';\n"+o+"\n__p+='"),t}),a+="';\n",t.variable||(a="with(obj||{}){\n"+a+"}\n"),a="var __t,__p='',__j=Array.prototype.join,print=function(){__p+=__j.call(arguments,'');};\n"+a+"return __p;\n";try{var o=new Function(t.variable||"obj","_",a)}catch(s){throw s.source=a,s}var u=function(e){return o.call(this,e,E)},l=t.variable||"obj";return u.source="function("+l+"){\n"+a+"}",u},E.chain=function(e){var t=E(e);return t._chain=!0,t};var Y=function(e,t){return e._chain?E(t).chain():t};E.mixin=function(e){E.each(E.functions(e),function(t){var n=E[t]=e[t];E.prototype[t]=function(){var e=[this._wrapped];return m.apply(e,arguments),Y(this,n.apply(E,e))}})},E.mixin(E),E.each(["pop","push","reverse","shift","sort","splice","unshift"],function(e){var t=p[e];E.prototype[e]=function(){var n=this._wrapped;return t.apply(n,arguments),"shift"!==e&&"splice"!==e||0!==n.length||delete n[0],Y(this,n)}}),E.each(["concat","join","slice"],function(e){var t=p[e];E.prototype[e]=function(){return Y(this,t.apply(this._wrapped,arguments))}}),E.prototype.value=function(){return this._wrapped},E.prototype.valueOf=E.prototype.toJSON=E.prototype.value,E.prototype.toString=function(){return""+this._wrapped},r=[],i=function(){return E}.apply(t,r),!(void 0!==i&&(e.exports=i))}).call(this)},function(e,t,n){"use strict";function r(e,t,n,r){if("number"!=typeof e)throw new TypeError("statusCode must be a number but was "+typeof e);if(null===t)throw new TypeError("headers cannot be null");if("object"!=typeof t)throw new TypeError("headers must be an object but was "+typeof t);this.statusCode=e,this.headers={};for(var i in t)this.headers[i.toLowerCase()]=t[i];this.body=n,this.url=r}e.exports=r,r.prototype.getBody=function(e){if(this.statusCode>=300){var t=new Error("Server responded with status code "+this.statusCode+":\n"+this.body.toString());throw t.statusCode=this.statusCode,t.headers=this.headers,t.body=this.body,t.url=this.url,t}return e?this.body.toString(e):this.body}},function(e,t,n){var r="undefined"!=typeof JSON?JSON:n(109);e.exports=function(e,t){t||(t={}),"function"==typeof t&&(t={cmp:t});var n=t.space||"";"number"==typeof n&&(n=Array(n+1).join(" "));var o="boolean"==typeof t.cycles?t.cycles:!1,s=t.replacer||function(e,t){return t},u=t.cmp&&function(e){return function(t){return function(n,r){var i={key:n,value:t[n]},a={key:r,value:t[r]};return e(i,a)}}}(t.cmp),l=[];return function p(e,t,c,f){var m=n?"\n"+new Array(f+1).join(n):"",d=n?": ":":";if(c&&c.toJSON&&"function"==typeof c.toJSON&&(c=c.toJSON()),c=s.call(e,t,c),void 0!==c){if("object"!=typeof c||null===c)return r.stringify(c);if(i(c)){for(var h=[],y=0;y<c.length;y++){var v=p(c,y,c[y],f+1)||r.stringify(null);h.push(m+n+v)}return"["+h.join(",")+m+"]"}if(-1!==l.indexOf(c)){if(o)return r.stringify("__cycle__");throw new TypeError("Converting circular structure to JSON")}l.push(c);for(var g=a(c).sort(u&&u(c)),h=[],y=0;y<g.length;y++){var t=g[y],A=p(c,t,c[t],f+1);if(A){var S=r.stringify(t)+d+A;h.push(m+n+S)}}return l.splice(l.indexOf(c),1),"{"+h.join(",")+m+"}"}}({"":e},"",e,0)};var i=Array.isArray||function(e){return"[object Array]"==={}.toString.call(e)},a=Object.keys||function(e){var t=Object.prototype.hasOwnProperty||function(){return!0},n=[];for(var r in e)t.call(e,r)&&n.push(r);return n}},function(e,t,n){function r(e){if(!e||"object"!=typeof e)throw new TypeError("argument obj is required");var t=e.parameters,n=e.subtype,r=e.suffix,i=e.type;if(!i||!d.test(i))throw new TypeError("invalid type");if(!n||!m.test(n))throw new TypeError("invalid subtype");var a=i+"/"+n;if(r){if(!d.test(r))throw new TypeError("invalid suffix");a+="+"+r}if(t&&"object"==typeof t)for(var s,u=Object.keys(t).sort(),l=0;l<u.length;l++){if(s=u[l],!p.test(s))throw new TypeError("invalid parameter name");a+="; "+s+"="+o(t[s])}return a}function i(e){if(!e)throw new TypeError("argument string is required");if("object"==typeof e&&(e=a(e)),"string"!=typeof e)throw new TypeError("argument string is required to be a string");var t,n,r,i=e.indexOf(";"),o=-1!==i?e.substr(0,i):e,l=s(o),p={};for(u.lastIndex=i;n=u.exec(e);){if(n.index!==i)throw new TypeError("invalid parameter format");i+=n[0].length,t=n[1].toLowerCase(),r=n[2],'"'===r[0]&&(r=r.substr(1,r.length-2).replace(c,"$1")),p[t]=r}if(-1!==i&&i!==e.length)throw new TypeError("invalid parameter format");return l.parameters=p,l}function a(e){return"function"==typeof e.getHeader?e.getHeader("content-type"):"object"==typeof e.headers?e.headers&&e.headers["content-type"]:void 0}function o(e){var t=String(e);if(p.test(t))return t;if(t.length>0&&!l.test(t))throw new TypeError("invalid parameter value");return'"'+t.replace(f,"\\$1")+'"'}function s(e){var t=h.exec(e.toLowerCase());if(!t)throw new TypeError("invalid media type");var n,r=t[1],i=t[2],a=i.lastIndexOf("+");-1!==a&&(n=i.substr(a+1),i=i.substr(0,a));var o={type:r,subtype:i,suffix:n};return o}/*!
	 * media-typer
	 * Copyright(c) 2014 Douglas Christopher Wilson
	 * MIT Licensed
	 */
var u=/; *([!#$%&'\*\+\-\.0-9A-Z\^_`a-z\|~]+) *= *("(?:[ !\u0023-\u005b\u005d-\u007e\u0080-\u00ff]|\\[\u0020-\u007e])*"|[!#$%&'\*\+\-\.0-9A-Z\^_`a-z\|~]+) */g,l=/^[\u0020-\u007e\u0080-\u00ff]+$/,p=/^[!#$%&'\*\+\-\.0-9A-Z\^_`a-z\|~]+$/,c=/\\([\u0000-\u007f])/g,f=/([\\"])/g,m=/^[A-Za-z0-9][A-Za-z0-9!#$&^_.-]{0,126}$/,d=/^[A-Za-z0-9][A-Za-z0-9!#$&^_-]{0,126}$/,h=/^ *([A-Za-z0-9][A-Za-z0-9!#$&^_-]{0,126})\/([A-Za-z0-9][A-Za-z0-9!#$&^_.+-]{0,126}) *$/;t.format=r,t.parse=i},function(e,t,n){(function(t){"use strict";var n=function(e,n,r,i,a,o,s,u){if("production"!==t.env.NODE_ENV&&void 0===n)throw new Error("invariant requires an error message argument");if(!e){var l;if(void 0===n)l=new Error("Minified exception occurred; use the non-minified dev environment for the full error message and additional helpful warnings.");else{var p=[r,i,a,o,s,u],c=0;l=new Error(n.replace(/%s/g,function(){return p[c++]})),l.name="Invariant Violation"}throw l.framesToPop=1,l}};e.exports=n}).call(t,n(61))},function(e,t,n){"use strict";var r=n(37),i=n(17),a=n(14),o=r,s=n(13),u=function(){function e(e){this.enabled=e,this.valueCalculators=[new m,new f,new c,new p,new d,new h,new y],this.unconditionalValueCalculators=[new v]}return e.prototype.attributeDefaultIfEnabled=function(e,t){return this.enabled?this.getAttributeDefault(e,t):this.getUnconditionalAttributeDefault(t,e)},e.prototype.getUnconditionalAttributeDefault=function(e,t){if(!t||!e)return null;for(var n=0;n<this.unconditionalValueCalculators.length;n++){var r=this.unconditionalValueCalculators[n];if(r.matches(e,t)){var i=r.calculate(e,t);if(null!=i)return i}}return null},e.prototype.getAttributeDefault=function(e,t){if(!e||!t)return null;try{return this.getAttributeDefault2(t,e)}catch(n){return console.log(n),null}},e.prototype.getWrapperAttributeDefault=function(e,t){var n=e.highLevel();if(null==n)return null;var r=n.definition().property(t);return null==r?null:this.getAttributeDefault(n,r)},e.prototype.getAttributeDefault2=function(e,t){for(var n=0;n<this.valueCalculators.length;n++){var r=this.valueCalculators[n];if(r.matches(e,t)){var i=r.calculate(e,t);if(null!=i)return i}}return null!=e.defaultValue()?e.defaultValue():null},e.prototype.isEnabled=function(){return this.enabled},e.prototype.insertionKind=function(e,t){for(var n=0;n<this.valueCalculators.length;n++){var r=this.valueCalculators[n];if(r.matches(t,e))return r.kind()}return null!=t.defaultValue()?l.BY_DEFAULT:null},e}();t.AttributeDefaultsCalculator=u,function(e){e[e.CALCULATED=0]="CALCULATED",e[e.BY_DEFAULT=1]="BY_DEFAULT"}(t.InsertionKind||(t.InsertionKind={}));var l=t.InsertionKind,p=function(){function e(){}return e.prototype.calculate=function(e,t){var n=s.declRoot(t);if(n&&a.isApiSibling(n.definition())){var r=n.attr(i.Universe10.Api.properties.mediaType.name);if(r)return r.value()}return null},e.prototype.matches=function(e,t){if(!a.isNameProperty(e))return!1;var n=t.definition();if(!n)return!1;if(!a.isBodyLikeType(n)&&!a.isTypeDeclarationSibling(n))return!1;var r=t.parent();if(null==r)return!1;var i=r.definition();if(null==i)return!1;if(!a.isResponseType(i)&&!a.isMethodBaseSibling(i))return!1;for(var o=r;o;){var s=o.definition();if(a.isTraitType(s))return!1;if(a.isResourceTypeType(s))return!1;o=o.parent()}return!0},e.prototype.kind=function(){return l.CALCULATED},e}(),c=function(){function e(){}return e.prototype.calculate=function(e,t){var n=t.definition();if(null==n)return null;var r=n.getAdapter(o.RAMLService),i=r.getKeyProp();if(null!=i){var a=t.attrValue(i.nameId());return null!=a?a:new u(!0).getAttributeDefault(t,i)}return null},e.prototype.matches=function(e,t){var n=t.definition();return null==n?!1:(a.isTypeDeclarationSibling(n)||n.isAssignableFrom(i.Universe08.Parameter.name)||a.isResourceType(n))&&a.isDisplayNameProperty(e)},e.prototype.kind=function(){return l.CALCULATED},e}(),f=function(){function e(){}return e.prototype.calculate=function(e,t){return"object"},e.prototype.matches=function(e,t){return a.isTypeProperty(e)&&null!=t.definition()&&a.isObjectTypeDeclarationSibling(t.definition())},e.prototype.kind=function(){return l.BY_DEFAULT},e}(),m=function(){function e(){}return e.prototype.calculate=function(e,t){var n=t.definition(),r=t.property();if(null==n)return null;var i=n.getAdapter(o.RAMLService),s=i.getKeyProp();if(null!=s){var u=t.attr(s.nameId());if(null!=u&&u.optional())return!1}if(null!=r){if(a.isHeadersProperty(r)||a.isFormParametersProperty(r)||a.isQueryParametersProperty(r))return"RAML08"==e.domain().universe().version()?!1:!0;if(a.isUriParametersProperty(r)||a.isBaseUriParametersProperty(r))return!0}return null!=e.defaultValue()?e.defaultValue():null},e.prototype.matches=function(e,t){return a.isRequiredProperty(e)},e.prototype.kind=function(){return l.BY_DEFAULT},e}(),d=function(){function e(){}return e.prototype.calculate=function(e,t){if(a.isApiSibling(t.definition()))return null;var n,r=t.definition();if(a.isMethodType(r)){var i=t.parent();i&&(n=i.wrapperNode().securedBy())}if(!n||0==n.length){for(;null!=t&&!a.isApiSibling(t.definition());)t=t.parent();t&&(n=t.wrapperNode().securedBy())}return n&&n.length>0?n:null},e.prototype.matches=function(e,t){var n=t.definition();return null==n?!1:a.isSecuredByProperty(e)},e.prototype.kind=function(){return l.CALCULATED},e}(),h=function(){function e(){}return e.prototype.calculate=function(e,t){for(;null!=t&&!a.isApiSibling(t.definition());)t=t.parent();var n,r=t.attr(i.Universe10.Api.properties.baseUri.name);if(r){var o=r.value();if(o){var s=o.indexOf("://");s>=0&&(n=[o.substring(0,s).toUpperCase()]),n||(n=["HTTP"])}}return n},e.prototype.matches=function(e,t){if(!a.isProtocolsProperty(e))return!1;var n=t.definition(),r=!1;if(a.isApiSibling(n))r=!0;else if(a.isResourceType(n))r=!0;else if(a.isMethodType(n)){var i=t.parent();r=i&&a.isResourceType(i.definition())}return r},e.prototype.kind=function(){return l.CALCULATED},e}(),y=function(){function e(){}return e.prototype.calculate=function(e,t){for(;null!=t&&!a.isApiSibling(t.definition());)t=t.parent();var n=t.attr(i.Universe10.Api.properties.version.name);if(n){var r=n.value();if(r&&r.trim())return[r]}return null},e.prototype.matches=function(e,t){if(!a.isEnumProperty(e))return!1;var n=t.property();if(!n)return!1;if(!a.isBaseUriParametersProperty(n))return!1;var r=t.attr(i.Universe10.TypeDeclaration.properties.name.name),o=r&&r.value();return"version"!=o?!1:!0},e.prototype.kind=function(){return l.CALCULATED},e}(),v=function(){function e(){}return e.prototype.calculate=function(e,t){var n=t.definition();if(null==n)return null;var r=n.getAdapter(o.RAMLService);if(null==r)return null;var i=r.getKeyProp();if(null==i)return null;var a=t.attr(i.nameId());return null==a?null:a.optional()?!1:null},e.prototype.matches=function(e,t){return a.isRequiredProperty(e)},e.prototype.kind=function(){return l.BY_DEFAULT},e}()},function(e,t,n){"use strict";function r(e,t){return void 0===t&&(t=!0),new v({rootNodeDetails:!0,serializeMetadata:t}).dump(e)}var i=this&&this.__extends||function(e,t){function n(){this.constructor=e}for(var r in t)t.hasOwnProperty(r)&&(e[r]=t[r]);e.prototype=null===t?Object.create(t):(n.prototype=t.prototype,new n)},a=n(17),o=n(47),s=n(41),u=n(37),l=n(16),p=n(31),c=n(14),f=n(17),m=n(33),d=n(64),h=n(11),y=n(15);t.dump=r;var v=function(){function e(e){this.options=e,this.nodeTransformers=[new V,new k,new Y,new b,new L,new P,new W,new R,new I,new F,new B,new O,new q,new j],this.nodePropertyTransformers=[new E,new N,new _,new w,new M,new C,new K],this.ignore=new A([new g(c.isResponseType,c.isDisplayNameProperty),new g(c.isApiSibling,c.isDisplayNameProperty),new g(c.isAnnotationRefTypeOrDescendant,c.isAnnotationProperty),new g(c.isSecuritySchemeRefType,c.isSecuritySchemeProperty),new g(c.isTraitRefType,c.isTraitProperty),new g(c.isResourceTypeRefType,c.isResourceTypeProperty),new g(c.isApiSibling,c.isRAMLVersionProperty)]),this.missingProperties=new H,this.options=this.options||{},null==this.options.serializeMetadata&&(this.options.serializeMetadata=!0)}return e.prototype.printMissingProperties=function(){return this.missingProperties.print()},e.prototype.dump=function(e){var t=e.highLevel(),n=t&&t.parent(),r=!n&&this.options.rootNodeDetails,i=this.dumpInternal(e,r);return i},e.prototype.dumpInternal=function(e,t,n){var r=this;if(void 0===t&&(t=!1),null==e)return null;if(o.BasicNodeImpl.isInstance(e)){var i={},a=e,s=a.highLevel().definition();s.allProperties().filter(function(e){return!r.ignore.match(a.definition(),e)}).forEach(function(e){i[e.nameId()]=e}),s.allCustomProperties().filter(function(e){return!r.ignore.match(a.definition(),e)}).forEach(function(e){i[e.nameId()]=e});var u=this.dumpProperties(i,e);if(i.schema&&this.options.dumpSchemaContents&&i.schema.range().key()==f.Universe08.SchemaString){var l=a.highLevel().root().elementsOfKind("schemas");l.forEach(function(e){if(e.name()==u.schema){var t=e.attr("value");t&&(u.schema=t.value(),u.schemaContent=t.value())}})}if(this.serializeScalarsAnnotations(u,a,i),this.serializeMeta(u,a),this.canBeFragment(e)&&h.isFragment(e)){var p=h.asFragment(e),m=p.uses();m.length>0&&(u.uses=m.map(function(e){return e.toJSON()}))}if(c.isTypeDeclarationDescendant(s)){var d=a.highLevel().property();if(d&&!(c.isHeadersProperty(d)||c.isQueryParametersProperty(d)||c.isUriParametersProperty(d)||c.isPropertiesProperty(d)||c.isBaseUriParametersProperty(d))){delete u.required;var y=u.__METADATA__;if(y){var v=y.primitiveValuesMeta;v&&delete v.required}}}this.nodeTransformers.forEach(function(t){t.match(e,n||e.highLevel().property())&&(u=t.transform(u,e))});var g={};if(t){if(s){var A=s.universe().version();g.ramlVersion=A,g.type=s.nameId()}g.specification=u,g.errors=this.dumpErrors(a.errors())}else g=u;return g}if(o.AttributeNodeImpl.isInstance(e)){var i={},S=e,s=S.highLevel().definition();s.allCustomProperties().filter(function(e){return!r.ignore.match(S.highLevel().property().range(),e)}).forEach(function(e){i[e.nameId()]=e});var T=S.highLevel().property().range().isValueType();if(T&&S.value){var E=S.value();if("number"==typeof E||"string"==typeof E||"boolean"==typeof E)return E}var u=this.dumpProperties(i,e);return this.nodeTransformers.forEach(function(t){t.match(e,e.highLevel().property())&&(u=t.transform(u,e))}),this.serializeScalarsAnnotations(u,e,i),this.serializeMeta(u,S),u}return o.TypeInstanceImpl.isInstance(e)?this.serializeTypeInstance(e):o.TypeInstancePropertyImpl.isInstance(e)?this.serializeTypeInstanceProperty(e):e},e.prototype.canBeFragment=function(e){var t=e.definition(),n=[t].concat(t.allSubTypes()),r=n.filter(function(e){return e.getAdapter(u.RAMLService).possibleInterfaces().filter(function(e){return e.nameId()==u.universesInfo.Universe10.FragmentDeclaration.name}).length>0});return r.length>0},e.prototype.dumpErrors=function(e){var t=this;return e.map(function(e){var n=t.dumpErrorBasic(e);return e.trace&&e.trace.length>0&&(n.trace=t.dumpErrors(e.trace)),n}).sort(function(e,t){return e.path!=t.path?e.path.localeCompare(t.path):e.range.start.position!=t.range.start.position?e.range.start.position-t.range.start.position:e.code-t.code})},e.prototype.dumpErrorBasic=function(e){var t={code:e.code,message:e.message,path:e.path,line:e.line,column:e.column,position:e.start,range:e.range};return e.isWarning===!0&&(t.isWarning=!0),t},e.prototype.stringLooksLikeXML=function(e){return"<"===e[0]&&">"===e[e.length-1]},e.prototype.stringLooksLikeJSON=function(e){return"{"===e[0]&&"}"===e[e.length-1]},e.prototype.dumpProperties=function(e,t){var n,r=this,i={};return t.highLevel().isElement()&&(n=t.highLevel().definition()),Object.keys(e).forEach(function(s){var u;if(n&&(u=n.property(s),u||(u=d.find(n.allCustomProperties(),function(e){return e.nameId()==s}))),!t[s])return void r.missingProperties.addProperty(e[s],t.kind());var f=e[s],m=t[s]();if(m&&"structuredType"==s&&"object"==typeof m){m=null;var h=t.highLevel(),v=h.lowLevel();v.children().forEach(function(e){if("type"==e.key()||"schema"==e.key()){var t=h.definition().universe().type(a.Universe10.TypeDeclaration.name),n=h.definition().universe().type(a.Universe10.LibraryBase.name),i=new l.ASTNodeImpl(e,h,t,n.property(a.Universe10.LibraryBase.properties.types.name));i.patchType(p.doDescrimination(i)),m=r.dumpInternal(i.wrapperNode(),!1,u),s=e.key()}})}else if("items"==s&&"object"==typeof m){var g=Array.isArray(m),A=!g;if(g&&(A=null!=d.find(m,function(e){return"object"==typeof e})),A){m=null;var h=t.highLevel(),v=h.lowLevel();v.children().forEach(function(e){if("items"==e.key()){var t=h.definition().universe().type(a.Universe10.TypeDeclaration.name),n=h.definition().universe().type(a.Universe10.LibraryBase.name),i=new l.ASTNodeImpl(e,h,t,n.property(a.Universe10.LibraryBase.properties.types.name));i.patchType(p.doDescrimination(i)),m=r.dumpInternal(i.wrapperNode(),!1,u),s=e.key()}})}}if(n&&n.isAssignableFrom("TypeDeclaration")&&("type"===s||"schema"==s)&&m)if(m.forEach&&"string"==typeof m[0]){var h=t.highLevel(),S=h.localType();if(S&&S.hasExternalInHierarchy()){var T=m[0].trim(),E="{"===T[0]&&"}"===T[T.length-1],b="<"===T[0]&&">"===T[T.length-1];E?i.typePropertyKind="JSON":b&&(i.typePropertyKind="XML")}else i.typePropertyKind="TYPE_EXPRESSION"}else"object"==typeof m&&(i.typePropertyKind="INPLACE");if(("type"===s||"schema"==s)&&m&&m.forEach&&"string"==typeof m[0]){var T=m[0].trim(),E=r.stringLooksLikeJSON(T),b=r.stringLooksLikeXML(T);if(E||b){var N=t.highLevel().lowLevel().includePath&&t.highLevel().lowLevel().includePath();if(N){var _,M=t.highLevel().lowLevel().unit().resolve(N).absolutePath();_=0===M.indexOf("http://")||0===M.indexOf("https://")?M:y.relative(t.highLevel().lowLevel().unit().project().getRootPath(),M),_=_.replace(/\\/g,"/"),i.schemaPath=_}}}if((m||"type"!=s)&&(m||"schema"!=s)&&(m||"items"!=s)){if(t.definition&&c.isTypeDeclarationSibling(t.definition())&&c.isTypeProperty(f)){var w=t[a.Universe10.TypeDeclaration.properties.schema.name]();if(null!=w&&(!Array.isArray(w)||0!=w.length))return;var h=t.highLevel(),v=h.lowLevel(),R=!1;if(v.children().forEach(function(e){return"schema"==e.key()?void(R=!0):void 0}),R)return}if(Array.isArray(m)){for(var I=[],C=0,L=m;C<L.length;C++){var P=L[C],O=r.dumpInternal(P);"examples"===s&&r.options&&r.options.dumpXMLRepresentationOfExamples&&P.expandable&&P.expandable._owner&&(O.asXMLString=P.expandable.asXMLString()),I.push(O)}if(0==I.length&&o.BasicNodeImpl.isInstance(t)&&!r.isDefined(t,s))return;for(var D=0,x=r.nodePropertyTransformers;D<x.length;D++){var U=x[D];U.match(t,f)&&(I=U.transform(I,t))}i[s]=I}else{var P=r.dumpInternal(m);if(null==P&&o.BasicNodeImpl.isInstance(t)&&!r.isDefined(t,s))return;o.BasicNodeImpl.isInstance(t)&&r.nodePropertyTransformers.forEach(function(e){e.match(t,f)&&(P=e.transform(P,t))}),i[s]=P,"example"===s&&r.options&&r.options.dumpXMLRepresentationOfExamples&&m.expandable&&m.expandable._owner&&(P.asXMLString=m.expandable.asXMLString())}}}),i},e.prototype.serializeScalarsAnnotations=function(e,t,n){var r=this;if(t.scalarsAnnotations){for(var i={},a=t.scalarsAnnotations(),o=0,s=Object.keys(n);o<s.length;o++){var u=s[o];if(a[u]){var l=a[u]();if(l.length>0)if(Array.isArray(l[0])){var p=[];l.forEach(function(e,t){p.push(e.map(function(e){return r.dumpInternal(e)}))}),p.filter(function(e){return e.length>0}).length>0&&(i[u]=p)}else i[u]=l.map(function(e){return r.dumpInternal(e)})}}Object.keys(i).length>0&&(e.scalarsAnnotations=i)}},e.prototype.serializeMeta=function(e,t){if(this.options.serializeMetadata){var n=t.meta();n.isDefault()||(e.__METADATA__=n.toJSON())}},e.prototype.serializeTypeInstance=function(e){var t=this;if(e.isScalar())return e.value();if(e.isArray())return e.items().map(function(e){return t.serializeTypeInstance(e)});var n=e.properties();if(0==n.length)return null;var r={};return n.forEach(function(e){return r[e.name()]=t.serializeTypeInstanceProperty(e)}),r},e.prototype.serializeTypeInstanceProperty=function(e){var t=this;if(e.isArray()){var n=e.values(),r=[];return n.forEach(function(e){return r.push(t.serializeTypeInstance(e))}),r}return this.serializeTypeInstance(e.value())},e.prototype.isDefined=function(e,t){var n=e.highLevel();return n.elementsOfKind(t).length>0?!0:n.attributes(t).length>0?!0:!1},e}();t.TCKDumper=v;var g=function(){function e(e,t){this.typeMatcher=e,this.propMatcher=t}return e.prototype.match=function(e,t){return(null==e||this.typeMatcher(e))&&(null==t||this.propMatcher(t))},e}(),A=function(){function e(e){this.matchers=e}return e.prototype.match=function(e,t){for(var n=this.matchers.length,r=0;n>r;r++)if(this.matchers[r].match(e,t))return!0;return!1},e}(),S=function(){function e(e,t){this.matcher=e,this.propName=t}return e.prototype.match=function(e,t){return this.matcher.match(e.definition(),t)},e.prototype.transform=function(e){var t=this;if(Array.isArray(e)&&e.length>0&&e[0][this.propName]){var n={};return e.forEach(function(e){var r=e[t.propName],i=n[r];i?Array.isArray(i)?i.push(e):n[r]=[i,e]:n[r]=e}),n}return e},e}(),T=function(){function e(e,t){this.matcher=e,this.propName=t}return e.prototype.match=function(e,t){return this.matcher.match(e.definition?e.definition():null,t)},e.prototype.transform=function(e){if(Array.isArray(e))return e;var t={};return t[e[this.propName]]=e,t},e}(),E=function(e){function t(){e.call(this,new A([new g(c.isApiSibling,c.isBaseUriParametersProperty),new g(c.isResourceBaseSibling,c.isUriParametersProperty),new g(c.isResourceBaseSibling,c.isQueryParametersProperty),new g(c.isTraitType,c.isQueryParametersProperty),new g(c.isMethodType,c.isQueryParametersProperty),new g(c.isSecuritySchemePartType,c.isQueryParametersProperty),new g(c.isTraitType,c.isHeadersProperty),new g(c.isMethodType,c.isHeadersProperty),new g(c.isSecuritySchemePartType,c.isHeadersProperty),new g(c.isBodyLikeType,c.isFormParametersProperty)]),"name")}return i(t,e),t}(S),b=function(e){function t(){e.call(this,new A([new g(c.isLibraryBaseSibling,c.isTypesProperty),new g(function(e){return c.isLibraryBaseSibling(e)&&c.isRAML10Type(e)},c.isSchemasProperty)]),"name")}return i(t,e),t.prototype.match=function(e,t){var n=null!=e.parent()&&this.matcher.match(e.parent().definition(),t);return n?!0:!1},t}(T),N=(function(e){function t(){e.call(this,new A([new g(c.isLibraryBaseSibling,c.isUsesProperty)]),"name")}return i(t,e),t}(S),function(e){function t(){e.call(this,new A([new g(c.isObjectTypeDeclarationSibling,c.isPropertiesProperty)]),"name")}return i(t,e),t}(S)),_=function(e){function t(){e.call(this,new A([new g(c.isMethodBaseSibling,c.isResponsesProperty)]),"code")}return i(t,e),t}(S),M=function(e){function t(){e.call(this,new A([new g(function(e){return!0},c.isAnnotationsProperty)]),"name")}return i(t,e),t}(S),w=function(e){function t(){e.call(this,new A([new g(c.isResponseType,c.isBodyProperty),new g(c.isMethodBaseSibling,c.isBodyProperty)]),"name")}return i(t,e),t}(S),R=function(e){function t(){e.call(this,new A([new g(c.isTraitType,c.isTraitsProperty)]),"name")}return i(t,e),t}(T),I=function(e){function t(){e.call(this,new A([new g(c.isResourceTypeType,c.isResourceTypesProperty)]),"name")}return i(t,e),t.prototype.transform=function(t){var n=f.Universe10.ResourceBase.properties.methods.name;if(Array.isArray(t))return t;var r=t[n];return r&&r.forEach(function(e){var n=Object.keys(e);if(n.length>0){var r=n[0];t[r]=e[r]}}),delete t[n],e.prototype.transform.call(this,t)},t}(T),C=function(e){function t(){e.call(this,new A([new g(c.isTypeDeclarationSibling,c.isFacetsProperty)]),"name")}return i(t,e),t}(S),L=function(e){function t(){e.call(this,null,"name")}return i(t,e),t.prototype.match=function(e,t){return null!=t&&c.isSecuritySchemesProperty(t)},t}(T),P=function(e){function t(){e.call(this,new A([new g(c.isLibraryBaseSibling,c.isAnnotationTypesProperty)]),"name")}return i(t,e),t.prototype.match=function(e,t){return null!=e.parent()&&this.matcher.match(e.parent().definition(),t)},t}(T),O=function(e){function t(){e.call(this,null,"method")}return i(t,e),t.prototype.match=function(e,t){return null!=e.parent()&&c.isResourceTypeType(e.parent().definition())&&c.isMethodsProperty(t)},t}(T),D=a.Universe10.ExampleSpec.properties.name.name,x=a.Universe10.ExampleSpec.properties.value.name,U="structuredContent",k=(function(){function e(){}return e.prototype.match=function(e,t){return c.isExampleSpecType(e.definition())},e.prototype.transform=function(e){var t=this;if(Array.isArray(e)&&e.length>0){if(e[0][D]){var n={};return e.forEach(function(e){return n[e[D]]=t.getActualExample(e)}),n}var r=e.map(function(e){return t.getActualExample(e)});return r}return e},e.prototype.getActualExample=function(e){return e[U]?e[U]:e[x]},e}(),function(){function e(){}return e.prototype.match=function(e,t){return e.definition&&c.isTypeDeclarationSibling(e.definition())},e.prototype.transform=function(e){var t=Array.isArray(e),n=t?e:[e];return n.forEach(function(e){var t=e.example;t&&(e.example=t.structuredValue,e.structuredExample=t)}),t?n:n[0]},e}()),F=function(){function e(){this.matcher=new g(function(e){return c.isApiType(e)&&c.isRAML08Type(e)},c.isSchemasProperty)}return e.prototype.match=function(e,t){return null!=e.parent()&&this.matcher.match(e.parent().definition(),t)},e.prototype.transform=function(e){if(Array.isArray(e))return e;var t={};return t[e.key]=e.value,t},e.prototype.getActualExample=function(e){return e[U]?e[U]:e[x]},e}(),B=function(){function e(){}return e.prototype.match=function(e,t){return null!=t&&c.isProtocolsProperty(t)},e.prototype.transform=function(e){return"string"==typeof e?e.toUpperCase():Array.isArray(e)?e.map(function(e){return e.toUpperCase()}):e},e}(),K=function(){function e(){this.usecases=new A([new g(c.isApiSibling,c.isMediaTypeProperty)])}return e.prototype.match=function(e,t){return this.usecases.match(e.definition(),t)},e.prototype.transform=function(e){return Array.isArray(e)&&1==e.length?e[0]:e},e}(),V=function(){function e(){}return e.prototype.match=function(e,t){return null!=t&&c.isResourcesProperty(t)},e.prototype.transform=function(e,t){if(Array.isArray(e))return e;var n=e[f.Universe10.Resource.properties.relativeUri.name];if(n){for(var r=n.trim().split("/");r.length>0&&0==r[0].length;)r.shift();e.relativeUriPathSegments=r,e.absoluteUri=t.absoluteUri()}return e},e}(),j=function(){function e(){}return e.prototype.match=function(e,t){return e.parent()&&e.parent().highLevel().lowLevel().libProcessed?c.isAnnotationTypesProperty(t)||c.isTypesProperty(t)||c.isResourceTypesProperty(t)||c.isTraitsProperty(t)||c.isSecuritySchemesProperty(t):!1},e.prototype.transform=function(e,t){for(var n=t.highLevel().lowLevel(),r=n.key(),i=n;s.LowLevelProxyNode.isInstance(i);)i=i.originalNode();var a=i.key(),o=e[Object.keys(e)[0]];return o.name=a,o.displayName==r&&(o.displayName=a),e},e}(),W=function(){function e(){}return e.prototype.match=function(e,t){var n=e.highLevel();if(!n)return!1;var r=n.definition();return r?c.isResourceTypeType(r)||c.isTraitType(r)||c.isMethodType(r)||c.isTypeDeclarationSibling(r):!1},e.prototype.transform=function(e){if(Array.isArray(e))return e;var t=a.Universe10.Trait.properties.parametrizedProperties.name,n=e[t];return n&&(Object.keys(n).forEach(function(t){e[t]=n[t]}),delete e[t]),e},e}(),q=function(){function e(){}return e.prototype.match=function(e,t){return null!=t&&(c.isSecuredByProperty(t)||c.isIsProperty(t)||null!=e.parent()&&(c.isResourceType(e.parent().highLevel().definition())||c.isResourceTypeType(e.parent().highLevel().definition()))&&c.isTypeProperty(t))},e.prototype.transform=function(e){return e?Array.isArray(e)?e:this.toSimpleValue(e):null},e.prototype.toSimpleValue=function(e){var t=e.name,n=e.structuredValue;if(n){var r={};return r[t]=n,r}return t},e}(),Y=function(){function e(){}return e.prototype.match=function(e,t){if(!o.BasicNodeImpl.isInstance(e))return!1;var n=e.highLevel(),r=n.definition();if(!c.isTypeDeclarationDescendant(r))return!1;var i=n.localType();return i&&i.isArray()?!0:!1},e.prototype.transform=function(e){var t=f.Universe10.TypeDeclaration.properties.type.name,n=f.Universe10.ArrayTypeDeclaration.properties.items.name,r=e[t];return 1==r.length&&m.stringEndsWith(r[0],"[]")&&(null==e[n]&&(e[n]=r[0].substring(0,r[0].length-2)),r[0]="array"),e},e}(),H=function(){function e(){this.map={}}return e.prototype.addProperty=function(e,t){var n=this.map[t];n||(n=new $(t),this.map[t]=n),n.addProperty(e)},e.prototype.print=function(){var e=this;return Object.keys(this.map).map(function(t){return e.map[t].print()}).join("\n")+"\n"},e}(),$=function(){function e(e){this.typeName=e,this.map={}}return e.prototype.addProperty=function(e){var t=e.domain().nameId(),n=this.map[t];n||(n=new G(t),this.map[t]=n),n.addProperty(e)},e.prototype.print=function(){var e=this;return this.typeName+":\n"+Object.keys(this.map).map(function(t){return"    "+e.map[t].print()}).join("\n")},e}(),G=function(){function e(e){this.typeName=e,this.map={}}return e.prototype.addProperty=function(e){var t=e.nameId();this.map[t]=e},e.prototype.print=function(){return this.typeName+": "+Object.keys(this.map).sort().join(", ")},e}()},function(e,t,n){!function(t,n){e.exports=n()}(this,function(){function e(e){return e.charAt(0).toUpperCase()+e.substr(1).toLowerCase()}function t(e){return"string"==typeof e?new RegExp("^"+e+"$","i"):e}function n(t,n){return t===t.toUpperCase()?n.toUpperCase():t[0]===t[0].toUpperCase()?e(n):n.toLowerCase()}function r(e,t){return e.replace(/\$(\d{1,2})/g,function(e,n){return t[n]||""})}function i(e,t,i){if(!e.length||l.hasOwnProperty(e))return t;for(var a=i.length;a--;){var o=i[a];if(o[0].test(t))return t.replace(o[0],function(e,t,i){var a=r(o[1],arguments);return""===e?n(i[t-1],a):n(e,a)})}return t}function a(e,t,r){return function(a){var o=a.toLowerCase();return t.hasOwnProperty(o)?n(a,o):e.hasOwnProperty(o)?n(a,e[o]):i(o,a,r)}}function o(e,t,n){var r=1===t?o.singular(e):o.plural(e);return(n?t+" ":"")+r}var s=[],u=[],l={},p={},c={};return o.plural=a(c,p,s),o.singular=a(p,c,u),o.addPluralRule=function(e,n){s.push([t(e),n])},o.addSingularRule=function(e,n){u.push([t(e),n])},o.addUncountableRule=function(e){return"string"==typeof e?void(l[e.toLowerCase()]=!0):(o.addPluralRule(e,"$0"),void o.addSingularRule(e,"$0"))},o.addIrregularRule=function(e,t){t=t.toLowerCase(),e=e.toLowerCase(),c[e]=t,p[t]=e},[["I","we"],["me","us"],["he","they"],["she","they"],["them","them"],["myself","ourselves"],["yourself","yourselves"],["itself","themselves"],["herself","themselves"],["himself","themselves"],["themself","themselves"],["is","are"],["this","these"],["that","those"],["echo","echoes"],["dingo","dingoes"],["volcano","volcanoes"],["tornado","tornadoes"],["torpedo","torpedoes"],["genus","genera"],["viscus","viscera"],["stigma","stigmata"],["stoma","stomata"],["dogma","dogmata"],["lemma","lemmata"],["schema","schemata"],["anathema","anathemata"],["ox","oxen"],["axe","axes"],["die","dice"],["yes","yeses"],["foot","feet"],["eave","eaves"],["goose","geese"],["tooth","teeth"],["quiz","quizzes"],["human","humans"],["proof","proofs"],["carve","carves"],["valve","valves"],["thief","thieves"],["genie","genies"],["groove","grooves"],["pickaxe","pickaxes"],["whiskey","whiskies"]].forEach(function(e){return o.addIrregularRule(e[0],e[1])}),[[/s?$/i,"s"],[/([^aeiou]ese)$/i,"$1"],[/(ax|test)is$/i,"$1es"],[/(alias|[^aou]us|tlas|gas|ris)$/i,"$1es"],[/(e[mn]u)s?$/i,"$1s"],[/([^l]ias|[aeiou]las|[emjzr]as|[iu]am)$/i,"$1"],[/(alumn|syllab|octop|vir|radi|nucle|fung|cact|stimul|termin|bacill|foc|uter|loc|strat)(?:us|i)$/i,"$1i"],[/(alumn|alg|vertebr)(?:a|ae)$/i,"$1ae"],[/(seraph|cherub)(?:im)?$/i,"$1im"],[/(her|at|gr)o$/i,"$1oes"],[/(agend|addend|millenni|dat|extrem|bacteri|desiderat|strat|candelabr|errat|ov|symposi|curricul|automat|quor)(?:a|um)$/i,"$1a"],[/(apheli|hyperbat|periheli|asyndet|noumen|phenomen|criteri|organ|prolegomen|hedr|automat)(?:a|on)$/i,"$1a"],[/sis$/i,"ses"],[/(?:(kni|wi|li)fe|(ar|l|ea|eo|oa|hoo)f)$/i,"$1$2ves"],[/([^aeiouy]|qu)y$/i,"$1ies"],[/([^ch][ieo][ln])ey$/i,"$1ies"],[/(x|ch|ss|sh|zz)$/i,"$1es"],[/(matr|cod|mur|sil|vert|ind|append)(?:ix|ex)$/i,"$1ices"],[/(m|l)(?:ice|ouse)$/i,"$1ice"],[/(pe)(?:rson|ople)$/i,"$1ople"],[/(child)(?:ren)?$/i,"$1ren"],[/eaux$/i,"$0"],[/m[ae]n$/i,"men"],["thou","you"]].forEach(function(e){return o.addPluralRule(e[0],e[1])}),[[/s$/i,""],[/(ss)$/i,"$1"],[/((a)naly|(b)a|(d)iagno|(p)arenthe|(p)rogno|(s)ynop|(t)he)(?:sis|ses)$/i,"$1sis"],[/(^analy)(?:sis|ses)$/i,"$1sis"],[/(wi|kni|(?:after|half|high|low|mid|non|night|[^\w]|^)li)ves$/i,"$1fe"],[/(ar|(?:wo|[ae])l|[eo][ao])ves$/i,"$1f"],[/([^aeiouy]|qu)ies$/i,"$1y"],[/(^[pl]|zomb|^(?:neck)?t|[aeo][lt]|cut)ies$/i,"$1ie"],[/(\b(?:mon|smil))ies$/i,"$1ey"],[/(m|l)ice$/i,"$1ouse"],[/(seraph|cherub)im$/i,"$1"],[/(x|ch|ss|sh|zz|tto|go|cho|alias|[^aou]us|tlas|gas|(?:her|at|gr)o|ris)(?:es)?$/i,"$1"],[/(e[mn]u)s?$/i,"$1"],[/(movie|twelve)s$/i,"$1"],[/(cris|test|diagnos)(?:is|es)$/i,"$1is"],[/(alumn|syllab|octop|vir|radi|nucle|fung|cact|stimul|termin|bacill|foc|uter|loc|strat)(?:us|i)$/i,"$1us"],[/(agend|addend|millenni|dat|extrem|bacteri|desiderat|strat|candelabr|errat|ov|symposi|curricul|quor)a$/i,"$1um"],[/(apheli|hyperbat|periheli|asyndet|noumen|phenomen|criteri|organ|prolegomen|hedr|automat)a$/i,"$1on"],[/(alumn|alg|vertebr)ae$/i,"$1a"],[/(cod|mur|sil|vert|ind)ices$/i,"$1ex"],[/(matr|append)ices$/i,"$1ix"],[/(pe)(rson|ople)$/i,"$1rson"],[/(child)ren$/i,"$1"],[/(eau)x?$/i,"$1"],[/men$/i,"man"]].forEach(function(e){return o.addSingularRule(e[0],e[1])}),["advice","agenda","bison","bream","buffalo","carp","chassis","cod","cooperation","corps","digestion","debris","diabetes","energy","equipment","elk","excretion","expertise","flounder","gallows","garbage","graffiti","headquarters","health","herpes","highjinks","homework","information","jeans","justice","kudos","labour","machinery","mackerel","media","mews","moose","news","pike","plankton","pliers","pollution","premises","rain","rice","salmon","scissors","series","sewage","shambles","shrimp","species","staff","swine","trout","tuna","whiting","wildebeest","wildlife","you",/pox$/i,/ois$/i,/deer$/i,/fish$/i,/sheep$/i,/measles$/i,/[^aeiou]ese$/i].forEach(o.addUncountableRule),o})},function(e,t,n){function r(e){this.options=e||{locator:{}}}function i(e,t,n){function r(t){var r=e[t];!r&&o&&(r=2==e.length?function(n){e(t,n)}:e),i[t]=r&&function(e){r("[xmldom "+t+"]	"+e+s(n))}||function(){}}if(!e){if(t instanceof a)return t;e=t}var i={},o=e instanceof Function;return n=n||{},r("warning"),r("error"),r("fatalError"),i}function a(){this.cdata=!1}function o(e,t){t.lineNumber=e.lineNumber,t.columnNumber=e.columnNumber}function s(e){return e?"\n@"+(e.systemId||"")+"#[line:"+e.lineNumber+",col:"+e.columnNumber+"]":void 0}function u(e,t,n){return"string"==typeof e?e.substr(t,n):e.length>=t+n||t?new java.lang.String(e,t,n)+"":e}function l(e,t){e.currentElement?e.currentElement.appendChild(t):e.doc.appendChild(t)}r.prototype.parseFromString=function(e,t){var n=this.options,r=new p,o=n.domBuilder||new a,s=n.errorHandler,u=n.locator,l=n.xmlns||{},c={lt:"<",gt:">",amp:"&",quot:'"',apos:"'"};return u&&o.setDocumentLocator(u),r.errorHandler=i(s,o,u),r.domBuilder=n.domBuilder||o,/\/x?html?$/.test(t)&&(c.nbsp=" ",c.copy="©",l[""]="http://www.w3.org/1999/xhtml"),l.xml=l.xml||"http://www.w3.org/XML/1998/namespace",e?r.parse(e,l,c):r.errorHandler.error("invalid doc source"),o.doc},a.prototype={startDocument:function(){this.doc=(new c).createDocument(null,null,null),this.locator&&(this.doc.documentURI=this.locator.systemId)},startElement:function(e,t,n,r){var i=this.doc,a=i.createElementNS(e,n||t),s=r.length;l(this,a),this.currentElement=a,this.locator&&o(this.locator,a);for(var u=0;s>u;u++){var e=r.getURI(u),p=r.getValue(u),n=r.getQName(u),c=i.createAttributeNS(e,n);this.locator&&o(r.getLocator(u),c),c.value=c.nodeValue=p,a.setAttributeNode(c)}},endElement:function(e,t,n){var r=this.currentElement;r.tagName;this.currentElement=r.parentNode},startPrefixMapping:function(e,t){},endPrefixMapping:function(e){},processingInstruction:function(e,t){var n=this.doc.createProcessingInstruction(e,t);
this.locator&&o(this.locator,n),l(this,n)},ignorableWhitespace:function(e,t,n){},characters:function(e,t,n){if(e=u.apply(this,arguments)){if(this.cdata)var r=this.doc.createCDATASection(e);else var r=this.doc.createTextNode(e);this.currentElement?this.currentElement.appendChild(r):/^\s*$/.test(e)&&this.doc.appendChild(r),this.locator&&o(this.locator,r)}},skippedEntity:function(e){},endDocument:function(){this.doc.normalize()},setDocumentLocator:function(e){(this.locator=e)&&(e.lineNumber=0)},comment:function(e,t,n){e=u.apply(this,arguments);var r=this.doc.createComment(e);this.locator&&o(this.locator,r),l(this,r)},startCDATA:function(){this.cdata=!0},endCDATA:function(){this.cdata=!1},startDTD:function(e,t,n){var r=this.doc.implementation;if(r&&r.createDocumentType){var i=r.createDocumentType(e,t,n);this.locator&&o(this.locator,i),l(this,i)}},warning:function(e){console.warn("[xmldom warning]	"+e,s(this.locator))},error:function(e){console.error("[xmldom error]	"+e,s(this.locator))},fatalError:function(e){throw console.error("[xmldom fatalError]	"+e,s(this.locator)),e}},"endDTD,startEntity,endEntity,attributeDecl,elementDecl,externalEntityDecl,internalEntityDecl,resolveEntity,getExternalSubset,notationDecl,unparsedEntityDecl".replace(/\w+/g,function(e){a.prototype[e]=function(){return null}});var p=n(85).XMLReader,c=t.DOMImplementation=n(86).DOMImplementation;t.XMLSerializer=n(86).XMLSerializer,t.DOMParser=r},function(e,t,n){t.dot=t.dotCase=n(118),t.swap=t.swapCase=n(119),t.path=t.pathCase=n(121),t.upper=t.upperCase=n(120),t.lower=t.lowerCase=n(122),t.camel=t.camelCase=n(123),t.snake=t.snakeCase=n(125),t.title=t.titleCase=n(124),t.param=t.paramCase=n(129),t.pascal=t.pascalCase=n(126),t.constant=t.constantCase=n(127),t.sentence=t.sentenceCase=n(128),t.isUpper=t.isUpperCase=n(130),t.isLower=t.isLowerCase=n(131),t.ucFirst=t.upperCaseFirst=n(133),t.lcFirst=t.lowerCaseFirst=n(132)},function(e,t,n){"use strict";function r(e,t,n,s){var u=new i(function(i,u){function l(a){r(e,t,{qs:n.qs,headers:n.headers,timeout:n.timeout}).nodeify(function(e,t){var r=e||t.statusCode>=400;if("function"==typeof n.retry&&(r=n.retry(e,t,a+1)),a>=(5|n.maxRetries)&&(r=!1),r){var o=n.retryDelay;"function"==typeof n.retryDelay&&(o=n.retryDelay(e,t,a+1)),o=o||200,setTimeout(function(){l(a+1)},o)}else e?u(e):i(t)})}var p=new window.XMLHttpRequest;if("string"!=typeof e)throw new TypeError("The method must be a string.");if("string"!=typeof t)throw new TypeError("The URL/path must be a string.");if("function"==typeof n&&(s=n,n={}),(null===n||void 0===n)&&(n={}),"object"!=typeof n)throw new TypeError("Options must be an object (or null).");if("function"!=typeof s&&(s=void 0),e=e.toUpperCase(),n.headers=n.headers||{},n.retry&&"GET"===e)return l(0);var c,f=!(!(c=/^([\w-]+:)?\/\/([^\/]+)/.exec(t))||c[2]==window.location.host);if(f||(n.headers["X-Requested-With"]="XMLHttpRequest"),n.qs&&(t=o(t,n.qs)),n.json&&(n.body=JSON.stringify(n.json),n.headers["Content-Type"]="application/json"),n.timeout){p.timeout=n.timeout;var m=Date.now();p.ontimeout=function(){var e=Date.now()-m,t=new Error("Request timed out after "+e+"ms");t.timeout=!0,t.duration=e,u(t)}}p.onreadystatechange=function(){if(4===p.readyState){var e={};p.getAllResponseHeaders().split("\r\n").forEach(function(t){var n=t.split(":");n.length>1&&(e[n[0].toLowerCase()]=n.slice(1).join(":").trim())});var n=new a(p.status,e,p.responseText);n.url=t,i(n)}},p.open(e,t,!0);for(var d in n.headers)p.setRequestHeader(d,n.headers[d]);p.send(n.body?n.body:null)});return u.getBody=function(){return u.then(function(e){return e.getBody()})},u.nodeify(s)}var i=n(112),a=n(65),o=n(91);e.exports=r},function(e,t,n){"use strict";function r(e,t){var n=t?t.endPosition:e.endPosition+1,r={key:e,value:t,startPosition:e.startPosition,endPosition:n,kind:f.MAPPING,parent:null,errors:[]};return r}function i(e,t,n,r){return{errors:[],referencesAnchor:e,value:r,startPosition:t,endPosition:n,kind:f.ANCHOR_REF,parent:null}}function a(e){return void 0===e&&(e=""),{errors:[],startPosition:-1,endPosition:-1,value:e,kind:f.SCALAR,parent:null,doubleQuoted:!1}}function o(){return{errors:[],startPosition:-1,endPosition:-1,items:[],kind:f.SEQ,parent:null}}function s(){return o()}function u(e){return{errors:[],startPosition:-1,endPosition:-1,mappings:e?e:[],kind:f.MAP,parent:null}}var l=n(87),p=n(88),c=function(){function e(e,t){void 0===t&&(t=null),this.name="YAMLException",this.reason=e,this.mark=t,this.message=this.toString(!1)}return e.isInstance=function(t){if(null!=t&&t.getClassIdentifier&&"function"==typeof t.getClassIdentifier)for(var n=0,r=t.getClassIdentifier();n<r.length;n++){var i=r[n];if(i==e.CLASS_IDENTIFIER)return!0}return!1},e.prototype.getClassIdentifier=function(){var t=[];return t.concat(e.CLASS_IDENTIFIER)},e.prototype.toString=function(e){void 0===e&&(e=!1);var t;return t="JS-YAML: "+(this.reason||"(unknown reason)"),!e&&this.mark&&(t+=" "+this.mark.toString()),t},e.CLASS_IDENTIFIER="yaml-ast-parser.YAMLException",e}();t.YAMLException=c,function(e){e[e.SCALAR=0]="SCALAR",e[e.MAPPING=1]="MAPPING",e[e.MAP=2]="MAP",e[e.SEQ=3]="SEQ",e[e.ANCHOR_REF=4]="ANCHOR_REF",e[e.INCLUDE_REF=5]="INCLUDE_REF"}(t.Kind||(t.Kind={}));var f=t.Kind;t.newMapping=r,t.newAnchorRef=i,t.newScalar=a,t.newItems=o,t.newSeq=s,t.newMap=u,t.load=l.load,t.loadAll=l.loadAll,t.safeLoad=l.safeLoad,t.dump=p.dump,t.safeDump=p.safeDump},function(e,t,n){var r,i,a;!function(n,o){"use strict";"object"==typeof e&&"object"==typeof e.exports?e.exports=o():(i=[],r=o,a="function"==typeof r?r.apply(t,i):r,!(void 0!==a&&(e.exports=a)))}("object"==typeof window?window:this,function(){"use strict";function e(e){this.capacity=e>0?+e:Number.MAX_VALUE,this.data=Object.create?Object.create(null):{},this.hash=Object.create?Object.create(null):{},this.linkedList={length:0,head:null,end:null}}function t(n){return this instanceof t?void(this._LRUCacheState=new e(n)):new t(n)}function n(e,t){t!==e.head&&(e.end?e.end===t&&(e.end=t.n):e.end=t,r(t.n,t.p),r(t,e.head),e.head=t,e.head.n=null)}function r(e,t){e!==t&&(e&&(e.p=t),t&&(t.n=e))}var i=t.prototype;return i.get=function(e){var t=this._LRUCacheState,r=t.hash[e];return r?(n(t.linkedList,r),t.data[e]):void 0},i.set=function(e,t){var r=this._LRUCacheState,i=r.hash[e];return void 0===t?this:(i||(r.hash[e]={key:e},r.linkedList.length+=1,i=r.hash[e]),n(r.linkedList,i),r.data[e]=t,r.linkedList.length>r.capacity&&this.remove(r.linkedList.end.key),this)},i.update=function(e,t){this._LRUCacheState;if(this.has(e)){var n=this.get(e);this.set(e,t(n))}return this},i.remove=function(e){var t=this._LRUCacheState,n=t.hash[e];return n?(n===t.linkedList.head&&(t.linkedList.head=n.p),n===t.linkedList.end&&(t.linkedList.end=n.n),r(n.n,n.p),delete t.hash[e],delete t.data[e],t.linkedList.length-=1,this):this},i.removeAll=function(){return this._LRUCacheState=new e(this._LRUCacheState.capacity),this},i.info=function(){var e=this._LRUCacheState;return{capacity:e.capacity,length:e.linkedList.length}},i.keys=function(){for(var e=this._LRUCacheState,t=[],n=e.linkedList.head;n;)t.push(n.key),n=n.p;return t},i.has=function(e){return!!this._LRUCacheState.hash[e]},i.staleKey=function(){return this._LRUCacheState.linkedList.end&&this._LRUCacheState.linkedList.end.key},i.popStale=function(){var e=this.staleKey();if(!e)return null;var t=[e,this._LRUCacheState.data[e]];return this.remove(e),t},t.NAME="LRUCache",t.VERSION="v0.2.0",t})},function(e,t,n){"use strict";function r(e){return null==e}function i(e){return r(e)?"":String(e)}function a(e){return-1===[0,!1,"","0","false"].indexOf(e)}function o(e){return isFinite(e)?Number(e):null}function s(e){return e%1===0?Number(e):null}function u(e){return isNaN(Date.parse(e))?null:new Date(e)}function l(e,t,n){var i=Array.isArray(e)?e:[e],a=i.map(function(e){function i(e,t,n){for(var r=0;r<a.length;r++){var i=a[r],e=i(e,t,n);if(null!=e)return e}return null}var a=[],o=n[e.type];return"function"==typeof o&&a.push(o),Object.keys(e).filter(function(e){return"type"!==e&&"repeat"!==e&&"default"!==e}).forEach(function(n){var r=t[n];"function"==typeof r&&a.push(r(e[n],n))}),function(t,n,a){if(r(t))return null!=e["default"]?i(e["default"],n,a):e.repeat&&!e.required?[]:t;if(e.repeat){var o=Array.isArray(t)?t:[t];return o=o.map(function(e){return i(e,n,a)}),o.some(r)?null:t}if(Array.isArray(t)){if(t.length>1)return null;t=t[0]}return i(t,n,a)}});return function(e,t,n){for(var r=0;r<a.length;r++){var i=a[r],o=i(e,t,n);if(null!=o)return o}return e}}function p(){function e(e){return l(e,n,r)}var t,n={},r={string:i,number:o,integer:s,"boolean":a,date:u},p=function(e){if(!e)return function(){return{}};var t={};return Object.keys(e).forEach(function(n){t[n]=p.rule(e[n])}),function(e){e=e||{};var n={};return Object.keys(t).forEach(function(r){var i=e[r],a=t[r];Object.prototype.hasOwnProperty.call(e,r)&&(n[r]=a(i,r,e))}),n}};return t=p,t.rule=e,t.TYPES=r,t.RULES=n,t}t.sanitize=p},function(e,t,n){(function(e){"use strict";function n(e){return"[object Date]"===v.call(e)&&!isNaN(e.getTime())}function r(e){return"boolean"==typeof e}function i(e){return"string"==typeof e}function a(e){return"number"==typeof e&&e%1===0}function o(e){return"number"==typeof e&&isFinite(e)}function s(e){return function(t){return t>=e}}function u(e){return function(t){return e>=t}}function l(t){return function(n){return e.byteLength(n)>=t}}function p(t){return function(n){return e.byteLength(n)<=t}}function c(e){return e&&0!=e.length?function(t){return e.indexOf(t)>-1}:function(e){return!0}}function f(e){var t="string"==typeof e?new RegExp(e):e;return t.test.bind(t)}function m(e,t,n,r,i){return{valid:e,rule:r,attr:i,value:n,key:t}}function d(e,t){var n=[];return Object.keys(e).forEach(function(r){var i=t[r];if(i){var a=e[r];n.push([r,i(a,r),a])}}),function(e,t,r){for(var i=0;i<n.length;i++){var a=n[i],o=a[0],s=a[1],u=a[2],l=s(e,t,r);if(!l)return m(!1,t,e,o,u)}return m(!0,t,e)}}function h(e,t,n){var r=Array.isArray(e)?e:[e],i=!r.length,a=[],o=[];return r.forEach(function(e){var n=[e.type||"string",d(e,t)];e.required||(i=!0),e.repeat?o.push(n):a.push(n)}),function(e,t,r){if(null==e)return m(i,t,e,"required",!i);var s=Array.isArray(e),u=s?e:[e],l=s?o:a;if(!l.length)return m(!1,t,e,"repeat",!s);var p=null,c=e;return l.some(function(e){var i=u.every(function(i){var a=e[0],o=n[a]&&n[a](i,t,r);return o||(p=m(!1,t,c,"type",a)),o});return i?(u.every(function(n){var r=e[1];return p=r(n,t),p.valid}),!0):!1}),p}}function y(){function e(e){return h(e,d,m)}var t,m={date:n,number:o,integer:a,"boolean":r,string:i},d={minimum:s,maximum:u,minLength:l,maxLength:p,"enum":c,pattern:f},y=function(t){if(!t)return function(e){return{valid:!0,errors:[]}};var n={};return Object.keys(t).forEach(function(r){n[r]=e(t[r])}),function(e){e=e||{};var t=Object.keys(n).map(function(t){var r=e[t],i=n[t];return i(r,t,e)}).filter(function(e){return!e.valid});return{valid:0===t.length,errors:t}}};return t=y,t.rule=e,t.TYPES=m,t.RULES=d,t}var v=Object.prototype.toString;t.validate=y}).call(t,n(94).Buffer)},function(e,t,n){"use strict";function r(e,t){"MetaModel.declaresSubTypeOf"==e.name&&t.getAdapter(u.RAMLService).setExtendedTypeName(e.arguments[0]),"MetaModel.nameAtRuntime"==e.name&&t.setNameAtRuntime(e.arguments[0]),"MetaModel.description"==e.name&&t.withDescription(e.arguments[0]),"MetaModel.inlinedTemplates"==e.name&&t.getAdapter(u.RAMLService).setInlinedTemplates(!0),"MetaModel.requireValue"==e.name&&t.getAdapter(u.RAMLService).withContextRequirement(""+e.arguments[0],""+e.arguments[1]),"MetaModel.referenceIs"==e.name&&t.getAdapter(u.RAMLService).withReferenceIs(""+e.arguments[0]),"MetaModel.actuallyExports"==e.name&&t.getAdapter(u.RAMLService).withActuallyExports(""+e.arguments[0]),"MetaModel.convertsToGlobalOfType"==e.name&&t.getAdapter(u.RAMLService).withConvertsToGlobal(""+e.arguments[0]),"MetaModel.allowAny"==e.name&&t.getAdapter(u.RAMLService).withAllowAny(),"MetaModel.allowQuestion"==e.name&&t.getAdapter(u.RAMLService).withAllowQuestion(),"MetaModel.alias"==e.name&&t.getAdapter(u.RAMLService).addAlias(""+e.arguments[0]),"MetaModel.consumesRefs"==e.name&&t.getAdapter(u.RAMLService).setConsumesRefs(!0),"MetaModel.canInherit"==e.name&&t.getAdapter(u.RAMLService).withCanInherit(""+e.arguments[0]),"MetaModel.definingPropertyIsEnough"==e.name&&t.getAdapter(u.RAMLService).definingPropertyIsEnough(""+e.arguments[0]),"MetaModel.customHandling"==e.name&&t.setCustom(!0),"MetaModel.superclasses"==e.name&&t.getAdapter(u.RAMLService).registerSupertypes(e.arguments[0]),"MetaModel.possibleInterfaces"==e.name&&t.getAdapter(u.RAMLService).registerPossibleInterfaces(e.arguments[0])}function i(e,n){t.annotationHandlers[n.name](n,e)}var a=n(37),o=n(136),s=n(92),u=a;t.handleTypeAnnotation=r,t.annotationHandlers={key:function(e,t){t.withFromParentKey(),t.withKey(!0)},value:function(e,t){t.withFromParentValue()},canBeValue:function(e,t){t.withCanBeValue()},unmerged:function(e,t){t.unmerge()},startFrom:function(e,t){t.withKeyRestriction(e.arguments[0]),t.merge()},oneOf:function(e,t){t.withEnumOptions(e.arguments[0])},oftenKeys:function(e,t){t.withOftenKeys(e.arguments[0])},embeddedInMaps:function(e,t){t.getAdapter(u.RAMLPropertyParserService).withEmbedMap()},system:function(e,t){t.getAdapter(u.RAMLPropertyParserService).withSystem(!0)},required:function(e,t){"false"!=e.arguments[0]&&e.arguments[0]!==!1&&t.withRequired(!0)},noDirectParse:function(e,t){"false"!=e.arguments[0]&&e.arguments[0]!==!1&&t.withNoDirectParse()},setsContextValue:function(e,t){t.addChildValueConstraint(new a.ChildValueConstraint(""+e.arguments[0],""+e.arguments[1]))},defaultValue:function(e,t){t.setDefaultVal(""+e.arguments[0])},defaultIntegerValue:function(e,t){t.setDefaultIntegerVal(e.arguments[0])},defaultBooleanValue:function(e,t){t.setDefaultBooleanVal(e.arguments[0])},facetId:function(e,t){"minItems"==e.arguments[0]&&t.setFacetValidator(function(e,t){if(e instanceof Array){var n=Number.parseInt(""+t.value());if(n>e.length)return"array should contain at least "+t.value()+" items"}return null}),"enum"==e.arguments[0]&&t.setFacetValidator(function(e,t){var n=e+"",r=t;try{if(!r.some(function(e){return e==n}))return"value should be one of :"+r.join(",")}catch(i){return}return null}),"maxItems"==e.arguments[0]&&t.setFacetValidator(function(e,t){if(e instanceof Array){var n=Number.parseInt(""+t);if(n<e.length)return"array should contain not more then "+t.value()+" items"}return null}),"minProperties"==e.arguments[0]&&t.setFacetValidator(function(e,t){if(e instanceof Object){var n=Number.parseInt(""+t);if(n>Object.keys(e).length)return"object should contain at least "+t.value()+" properties"}return null}),"maxProperties"==e.arguments[0]&&t.setFacetValidator(function(e,t){if(e instanceof Object){var n=Number.parseInt(""+t);if(n<Object.keys(e).length)return"object should contain not more then "+t.value()+" properties"}return null}),"uniqueItems"==e.arguments[0]&&t.setFacetValidator(function(e,t){if(t instanceof Array){var n=s.unique(t).length;if(n<t.length)return"array should contain only unique items"}return null}),"minLength"==e.arguments[0]&&t.setFacetValidator(function(e,t){if(("number"==typeof e||"boolean"==typeof e)&&(e=""+e),"string"==typeof e){var n=Number.parseInt(""+t);if(n>e.length)return"string length should be at least "+n}return null}),"maxLength"==e.arguments[0]&&t.setFacetValidator(function(e,t){if(("number"==typeof e||"boolean"==typeof e)&&(e=""+e),"string"==typeof e){var n=Number.parseInt(""+t);if(n<e.length)return"string length should be not more then "+n}return null}),"minimum"==e.arguments[0]&&t.setFacetValidator(function(e,t){if("string"==typeof e&&(e=parseFloat(e)),"number"==typeof e){var n=parseFloat(t);if(n>e)return"value should be not less then "+n}return null}),"maximum"==e.arguments[0]&&t.setFacetValidator(function(e,t){if("string"==typeof e&&(e=parseFloat(e)),"number"==typeof e){var n=parseFloat(t);if(e>n)return"value should be not more then "+n}return null}),"pattern"==e.arguments[0]&&t.setFacetValidator(function(e,t){if(("number"==typeof e||"boolean"==typeof e)&&(e=""+e),"string"==typeof e){var n=new RegExp(t);if(!n.test(e))return"string should match to "+t}return null})},extraMetaKey:function(e,t){"statusCodes"==e.arguments[0]&&(t.withOftenKeys(o.statusCodes.filter(function(e){return e.code.indexOf("x")<0}).map(function(e){return e.code})),t.setValueDocProvider(function(e){var t=s.find(o.statusCodes,function(t){return t.code==e});return t?e+":"+t.description:null})),"headers"==e.arguments[0]&&(t.setValueSuggester(function(e){if(e.property()){var t=e.property().getChildValueConstraints();if(s.find(t,function(e){return"location"==e.name&&"Params.ParameterLocation.HEADERS"==e.value}))return o.headers.map(function(e){return e.header});if(e.property()&&"headers"==e.property().nameId())return o.headers.map(function(e){return e.header})}return null}),t.setValueDocProvider(function(e){var t=s.find(o.headers,function(t){return t.header==e});return t?e+":"+t.description:null})),"methods"==e.arguments[0]&&t.setValueDocProvider(function(e){var t=s.find(o.methods,function(t){return t.method==e.toUpperCase()});return t?e+":"+t.description:null})},requireValue:function(e,t){t.withContextRequirement(""+e.arguments[0],""+e.arguments[1])},allowMultiple:function(e,t){t.withMultiValue(!0)},constraint:function(e,t){},newInstanceName:function(e,t){t.withNewInstanceName(""+e.arguments[0])},declaringFields:function(e,t){t.withThisPropertyDeclaresFields()},describesAnnotation:function(e,t){t.withDescribes(e.arguments[0])},allowNull:function(e,t){t.withAllowNull()},descriminatingProperty:function(e,t){t.withDescriminating(!0)},description:function(e,t){t.withDescription(""+e.arguments[0])},inherited:function(e,t){t.withInherited(!0)},selfNode:function(e,t){t.withSelfNode()},grammarTokenKind:function(e,t){t.getAdapter(u.RAMLPropertyService).withPropertyGrammarType(""+e.arguments[0])},canInherit:function(e,t){t.withInheritedContextValue(""+e.arguments[0])},canBeDuplicator:function(e,t){t.setCanBeDuplicator()},example:function(e,t){t.getAdapter(u.RAMLPropertyService).setExample(!0)},typeExpression:function(e,t){t.getAdapter(u.RAMLPropertyService).setTypeExpression(!0)},hide:function(e,t){0==e.arguments.length?t.getAdapter(u.RAMLPropertyDocumentationService).setHidden(!0):t.getAdapter(u.RAMLPropertyDocumentationService).setHidden(e.arguments[0])},documentationTableLabel:function(e,t){t.getAdapter(u.RAMLPropertyDocumentationService).setDocTableName(""+e.arguments[0])},markdownDescription:function(e,t){t.getAdapter(u.RAMLPropertyDocumentationService).setMarkdownDescription(""+e.arguments[0])},valueDescription:function(e,t){t.getAdapter(u.RAMLPropertyDocumentationService).setValueDescription(null!=e.arguments[0]?""+e.arguments[0]:null)},customHandling:function(e,t){}},t.recordAnnotation=i},function(e,t,n){(function(e){(function(){var r,i=[].slice;r=n(113),t.allowUnsafeEval=function(t){var n;n=e.eval;try{return e.eval=function(e){return r.runInThisContext(e)},t()}finally{e.eval=n}},t.allowUnsafeNewFunction=function(n){var r;r=e.Function;try{return e.Function=t.Function,n()}finally{e.Function=r}},t.Function=function(){var e,t,n,a,o,s,u;for(n=2<=arguments.length?i.call(arguments,0,o=arguments.length-1):(o=0,[]),e=arguments[o++],a=[],s=0,u=n.length;u>s;s++)t=n[s],"string"==typeof t&&(t=t.split(/\s*,\s*/)),a.push.apply(a,t);return r.runInThisContext("(function("+a.join(", ")+") {\n  "+e+"\n})")},t.Function.prototype=e.Function.prototype}).call(this)}).call(t,function(){return this}())},function(e,t,n){e.exports={34:{code:"34",message:""},1104:{code:"1104",message:""},1105:{code:"1105",message:""},1106:{code:"1106",message:""},1107:{code:"1107",message:""},1108:{code:"1108",message:""},1109:{code:"1109",message:""},1110:{code:"1110",message:""},CONTEXT_REQUIREMENT_VIOLATION:{code:"CONTEXT_REQUIREMENT_VIOLATION",message:"{{v1}} should be {{v2}} to use type {{v3}}"},INVALID_PARAMETER_NAME:{code:"INVALID_PARAMETER_NAME",message:"Invalid parameter name: '{{paramName}}' is reserved"},UNUSED_PARAMETER:{code:"UNUSED_PARAMETER",message:"Unused parameter: '{{paramName}}'"},INVALID_PROPERTY_OWNER_TYPE:{code:"INVALID_PROPERTY_OWNER_TYPE",message:"Property '{{propName}}' can only be used if type is {{namesStr}}"},NODE_KEY_IS_A_MAP:{code:"NODE_KEY_IS_A_MAP",message:"Node key can not be a map"},NODE_KEY_IS_A_SEQUENCE:{code:"NODE_KEY_IS_A_SEQUENCE",message:"Node key can not be a sequence"},SEQUENCE_REQUIRED:{code:"SEQUENCE_REQUIRED",message:"Node: '{{name}}' should be wrapped in sequence"},PROPERTY_MUST_BE_A_MAP_10:{code:"PROPERTY_MUST_BE_A_MAP_10",message:"'{{propName}}' should be a map in RAML 1.0"},PROPERTY_MUST_BE_A_MAP:{code:"PROPERTY_MUST_BE_A_MAP",message:"Property '{{propName}}' should be a map"},PROPERTY_MUST_BE_A_SEQUENCE:{code:"PROPERTY_MUST_BE_A_SEQUENCE",message:"Property '{{propName}}' should be a sequence"},INVALID_PROPERTY_RANGE:{code:"INVALID_PROPERTY_RANGE",message:"Property '{{propName}}' must be a {{range}}"},MAP_REQUIRED:{code:"MAP_REQUIRED",message:"should be a map in RAML 1.0"},UNRESOLVED_REFERENCE:{code:"UNRESOLVED_REFERENCE",message:"Reference: '{{ref}}' can not be resolved"},SCALAR_PROHIBITED:{code:"SCALAR_PROHIBITED",message:"Property '{{propName}}' can not have scalar value"},UNKNOWN_NODE:{code:"UNKNOWN_NODE",message:"Unknown node: '{{name}}'"},RECURSIVE_DEFINITION:{code:"RECURSIVE_DEFINITION",message:"Recursive definition: '{{name}}'"},PROPERTY_ALREADY_SPECIFIED:{code:"PROPERTY_ALREADY_SPECIFIED",message:"'{{propName}}' is already specified.`"},ISSUES_IN_THE_LIBRARY:{code:"ISSUES_IN_THE_LIBRARY",message:"Issues in the used library: '{{value}}'"},INVALID_LIBRARY_PATH:{code:"INVALID_LIBRARY_PATH",message:"Can not resolve library from path: '{{path}}'"},EMPTY_FILE:{code:"EMPTY_FILE",message:"Empty file: {{path}}"},SPACES_IN_KEY:{code:"SPACES_IN_KEY",message:"Keys should not have spaces '{{value}}'"},INCLUDE_ERROR:{code:"INCLUDE_ERROR",message:"{{msg}}"},PATH_EXCEEDS_ROOT:{code:"PATH_EXCEEDS_ROOT",message:"Resolved include path exceeds file system root"},ILLEGAL_PATTERN:{code:"ILLEGAL_PATTERN",message:"Illegal pattern: '{{value}}'"},UNKNOWN_FUNCTION:{code:"UNKNOWN_FUNCTION",message:"Unknown function applied to parameter: '{{transformerName}}'"},REQUEST_BODY_DISABLED:{code:"REQUEST_BODY_DISABLED",message:"Request body is disabled for '{{methodName}}' method."},SCALAR_EXPECTED:{code:"SCALAR_EXPECTED",message:"Scalar is expected here"},STRING_EXPECTED:{code:"STRING_EXPECTED",message:"Property '{{propName}}' must be a string"},UNKNOWN_ANNOTATION:{code:"UNKNOWN_ANNOTATION",message:"Unknown annotation: '{{aName}}'"},STRING_EXPECTED_2:{code:"STRING_EXPECTED_2",message:"{{propName}} value should be a string"},SECUREDBY_LIST_08:{code:"SECUREDBY_LIST_08",message:"'securedBy' should be a list in RAML08"},INVALID_ANNOTATION_LOCATION:{code:"INVALID_ANNOTATION_LOCATION",message:"Annotation '{{aName}}' can not be placed at this location, allowed targets are: {{aValues}}"},BOOLEAN_EXPECTED:{code:"BOOLEAN_EXPECTED",message:"'true' or 'false' is expected here"},NUMBER_EXPECTED:{code:"NUMBER_EXPECTED",message:"Value of '{{propName}}' must be a number"},STRING_EXPECTED_3:{code:"STRING_EXPECTED_3",message:"'{{propName}}' must be a string"},STATUS_MUST_BE_3NUMBER:{code:"STATUS_MUST_BE_3NUMBER",message:"Status code should be 3 digits number."},EMPTY_VALUE_NOT_ALLOWED:{code:"EMPTY_VALUE_NOT_ALLOWED",message:"Empty value is not allowed here"},INVALID_VALUE_SCHEMA:{code:"INVALID_VALUE_SCHEMA",message:"Invalid value schema: '{{iValue}}'"},INVALID_VALUE:{code:"INVALID_VALUE",message:"Invalid value: '{{iValue}}'. Allowed values are: {{aValues}}"},SCHEMA_EXCEPTION:{code:"SCHEMA_EXCEPTION",message:"Schema exception: {{msg}}"},SCHEMA_ERROR:{code:"SCHEMA_ERROR",message:"{{msg}}"},MISSING_VERSION:{code:"MISSING_VERSION",message:"Missing 'version'"},URI_PARAMETER_NAME_MISSING:{code:"URI_PARAMETER_NAME_MISSING",message:"URI parameter must have name specified"},URI_EXCEPTION:{code:"URI_EXCEPTION",message:"{{msg}}"},INVALID_MEDIATYPE:{code:"INVALID_MEDIATYPE",message:"Invalid media type '{{mediaType}}'"},MEDIATYPE_EXCEPTION:{code:"MEDIATYPE_EXCEPTION",message:"{{msg}}"},FORM_IN_RESPONSE:{code:"FORM_IN_RESPONSE",message:"Form related media types can not be used in responses"},UNUSED_URL_PARAMETER:{code:"UNUSED_URL_PARAMETER",message:"Unused url parameter {{paramName}}"},UNRECOGNIZED_ELEMENT:{code:"UNRECOGNIZED_ELEMENT",message:"Unrecognized {{referencedToName}}: '{{ref}}'."},TYPES_VARIETY_RESTRICTION:{code:"TYPES_VARIETY_RESTRICTION",message:"Type can be either of: string, number, integer, file, date or boolean"},UNRECOGNIZED_SECURITY_SCHEME:{code:"UNRECOGNIZED_SECURITY_SCHEME",message:"Unrecognized security scheme type: '{{ref}}'. Allowed values are: 'OAuth 1.0', 'OAuth 2.0', 'Basic Authentication', 'DigestSecurityScheme Authentication', 'x-{other}'"},DUPLICATE_TRAIT_REFERENCE:{code:"DUPLICATE_TRAIT_REFERENCE",message:"Duplicate trait reference: '{{refValue}}'."},IS_IS_ARRAY:{code:"IS_IS_ARRAY",message:"Property 'is' must be an array"},RESOURCE_TYPE_NAME:{code:"RESOURCE_TYPE_NAME",message:"Resource type name must be provided"},MULTIPLE_RESOURCE_TYPES:{code:"MULTIPLE_RESOURCE_TYPES",message:"A resource or resourceType can inherit from a single resourceType"},UNKNOWN_RAML_VERSION:{code:"UNKNOWN_RAML_VERSION",message:"Unknown version of RAML expected to see one of '#%RAML 0.8' or '#%RAML 1.0'"},UNKNOWN_TOPL_LEVEL_TYPE:{code:"UNKNOWN_TOPL_LEVEL_TYPE",message:"Unknown top level type: '{{typeName}}'"},REDUNDANT_FRAGMENT_NAME:{code:"REDUNDANT_FRAGMENT_NAME",message:"Redundant fragment name: '{{typeName}}'"},WEB_FORMS:{code:"WEB_FORMS",message:"File type can be only used in web forms"},MISSING_REQUIRED_PROPERTY:{code:"MISSING_REQUIRED_PROPERTY",message:"Missing required property '{{propName}}'"},VALUE_NOT_PROVIDED:{code:"VALUE_NOT_PROVIDED",message:"Value is not provided for parameter: '{{propName}}'"},SUSPICIOUS_DOUBLEQUOTE:{code:"SUSPICIOUS_DOUBLEQUOTE",message:'Suspicious double quoted multiline scalar, it is likely that you forgot closing "{{value}}'},ANNOTATION_TARGET_MUST_BE_A_STRING:{code:"ANNOTATION_TARGET_MUST_BE_A_STRING",message:"Annotation target must be set by a string"},ALLOWED_TARGETS_MUST_BE_ARRAY:{code:"ALLOWED_TARGETS_MUST_BE_ARRAY",message:"'allowedTargets' property value must be an array of type names or a single type name"},UNSUPPORTED_ANNOTATION_TARGET:{code:"UNSUPPORTED_ANNOTATION_TARGET",message:"Unsupported annotation target: '{{aTarget}}'"},SCHEMA_NAME_MUST_BE_STRING:{code:"SCHEMA_NAME_MUST_BE_STRING",message:"Schema '{{name}}' must be a string"},FORM_PARAMS_IN_RESPONSE:{code:"FORM_PARAMS_IN_RESPONSE",message:"Form parameters can not be used in response"},FORM_PARAMS_WITH_EXAMPLE:{code:"FORM_PARAMS_WITH_EXAMPLE",message:"'formParameters' property cannot be used together with the 'example' or 'schema' properties"},AUTHORIZATION_GRANTS_ENUM:{code:"AUTHORIZATION_GRANTS_ENUM",message:"'authorizationGrants' value should be one of 'authorization_code', 'implicit', 'password', 'client_credentials' or to be an abolute URI"},AUTHORIZATION_URI_REQUIRED:{code:"AUTHORIZATION_URI_REQUIRED",message:"'authorizationUri' is required when `authorization_code` or `implicit` grant type are used "},REPEATING_COMPONENTS_IN_ENUM:{code:"REPEATING_COMPONENTS_IN_ENUM",message:"'enum' value contains repeating components"},INTEGER_EXPECTED:{code:"INTEGER_EXPECTED",message:"Integer is expected"},NUMBER_EXPECTED_2:{code:"NUMBER_EXPECTED_2",message:"Number is expected"},RESOURCE_TYPE_NULL:{code:"RESOURCE_TYPE_NULL",message:"Resource type can not be null"},SCALAR_PROHIBITED_2:{code:"SCALAR_PROHIBITED_2",message:"Node '{{name}}' can not be a scalar"},VERSION_NOT_ALLOWED:{code:"VERSION_NOT_ALLOWED",message:"'version' parameter not allowed here",comment:"I dont like the message, but its coming from JS 0.8 parser @Denis"},INVALID_OVERLAY_NODE:{code:"INVALID_OVERLAY_NODE",message:"The '{{nodeId}}' node does not match any node of the master api."},INVALID_OVERRIDE_IN_OVERLAY:{code:"INVALID_OVERRIDE_IN_OVERLAY",message:"Property '{{propName}}' is not allowed to be overriden or added in overlays"},KEYS_SHOULD_BE_UNIQUE:{code:"KEYS_SHOULD_BE_UNIQUE",message:"Keys should be unique"},ALREADY_EXISTS:{code:"ALREADY_EXISTS",message:"{{capitalized}} '{{name}}' already exists"},ALREADY_EXISTS_IN_CONTEXT:{code:"ALREADY_EXISTS_IN_CONTEXT",message:"{{name}}' already exists in this context"},PROPERTY_USED:{code:"PROPERTY_USED",message:"Property already used: '{{propName}}'"},PARENT_PROPERTY_USED:{code:"PARENT_PROPERTY_USED",message:"{{parent}} property already used: '{{propName}}'"},INVALID_JSON_SCHEMA:{code:"INVALID_JSON_SCHEMA",message:"Invalid JSON schema. Potentially, required array containing value '{{propName}}' has invalid location"},EXAMPLE_SCHEMA_FAILURE:{code:"EXAMPLE_SCHEMA_FAILURE",message:"Example does not conform to schema: {{msg}}"},CAN_NOT_PARSE_JSON:{code:"CAN_NOT_PARSE_JSON",message:"Can not parse JSON: {{msg}}"},CAN_NOT_PARSE_XML:{code:"CAN_NOT_PARSE_XML",message:"Can not parse XML: {{msg}}"},OPTIONAL_SCLARAR_PROPERTIES_10:{code:"OPTIONAL_SCLARAR_PROPERTIES_10",message:"Optional scalar properties are not allowed in {{templateNamePlural}} and their descendants: '{{propName}}?'"},OPTIONAL_PROPERTIES_10:{code:"OPTIONAL_PROPERTIES_10",message:"Optional properties are not allowed in '{{propName}}': '{{oPropName}}'"},ONLY_METHODS_CAN_BE_OPTIONAL:{code:"ONLY_METHODS_CAN_BE_OPTIONAL",message:"Only method nodes can be optional"},PROPERTY_UNUSED:{code:"PROPERTY_UNUSED",message:"{{propName}} unused"},CYCLE_IN_DEFINITION:{code:"CYCLE_IN_DEFINITION",message:"{{typeName}} definition contains cycle: {{cycle}}"},SEQUENCE_NOT_ALLOWED_10:{code:"SEQUENCE_NOT_ALLOWED_10",message:"In RAML 1.0 {{propName}} is not allowed to have sequence as definition"},MAP_EXPECTED:{code:"MAP_EXPECTED",message:"Map is expected here"},ERROR_IN_INCLUDED_FILE:{code:"ERROR_IN_INCLUDED_FILE",message:"Error in the included file: {{msg}}"},NODE_SHOULD_HAVE_VALUE:{code:"NODE_SHOULD_HAVE_VALUE",message:"node should have at least one member value"},NAMED_PARAMETER_NEEDS_TYPE:{code:"NAMED_PARAMETER_NEEDS_TYPE",message:"named parameter needs at least one type"},ENUM_IS_EMPTY:{code:"ENUM_IS_EMPTY",message:"enum is empty"},ENUM_MUST_BE_AN_ARRAY:{code:"ENUM_MUST_BE_AN_ARRAY",message:"the value of enum must be an array"},DEFINITION_SHOULD_BE_A_MAP:{code:"DEFINITION_SHOULD_BE_A_MAP",message:"{{typeName}} definition should be a map"},RESOURCES_SHARE_SAME_URI:{code:"RESOURCES_SHARE_SAME_URI",message:"Resources share same URI"},TYPES_AND_SCHEMAS_ARE_EXCLUSIVE:{code:"TYPES_AND_SCHEMAS_ARE_EXCLUSIVE",message:"'types' and 'schemas' are mutually exclusive"},TEMPLATE_PARAMETER_NAME_MUST_CONTAIN_NONWHITESPACE_CHARACTERS:{code:"TEMPLATE_PARAMETER_NAME_MUST_CONTAIN_NONWHITESPACE_CHARACTERS",message:"Trait or resource type parameter name must contain non whitespace characters"},INVALID_SECURITY_SCHEME_SCOPE:{code:"INVALID_SECURITY_SCHEME_SCOPE",message:"The '{{invalidScope}}' scope is not allowed for the '{{securityScheme}}' security scheme. Allowed scopes are: {{allowedScopes}}."}}},function(e,t,n){"use strict";t.decode=t.parse=n(95),t.encode=t.stringify=n(96)},function(e,t,n){"use strict";function r(){return C}function i(e){return e instanceof E.AbstractType}function a(e,t){return void 0===t&&(t=E.builtInRegistry()),b.parseJSONTypeCollection(e,t)}function o(e){return b.parseJSON(null,e,E.builtInRegistry())}function s(e){return e.types||e.annotationTypes?b.parseJSONTypeCollection(e):b.parseJSON(null,e)}function u(e,t){return b.parseJSON(null,e,t?t.getTypeRegistry():E.builtInRegistry())}function l(e){return b.parseTypeCollection(e,E.builtInRegistry())}function p(e,t,n,r,i,a,o){if(void 0===r&&(r=!1),void 0===i&&(i=!1),void 0===a&&(a=!0),void 0===o&&(o=!1),a){var s;if(s=i?n.getAnnotationType(e):n.getType(e),null!=s)return s}return b.parse(e,t,n?n.getTypeRegistry():E.builtInRegistry(),r,i,a,o)}function c(e){return b.storeAsJSON(e)}function f(e,t,n){
void 0===n&&(n=!1),E.autoCloseFlag=n;try{return t.validate(e,n)}finally{E.autoCloseFlag=!1}}function m(e,t){return e.validateType(t.getAnnotationTypeRegistry())}function d(e,t){return t.ac(e)}function h(e){return e.canDoAc()}function y(){return N.getInstance().allPrototypes()}function v(){return E.builtInRegistry()}function g(e){for(var t=[],n=1;n<arguments.length;n++)t[n-1]=arguments[n];return E.derive(e,t)}function A(e){for(var t=[],n=1;n<arguments.length;n++)t[n-1]=arguments[n];return E.union(e,t)}function S(e){I.setPropertyConstructor(e)}function T(e,t){return I.toNominal(e,t)}var E=n(98);t.tsInterfaces=n(99);var b=n(100),N=n(101),_=n(102),M=n(103),w=n(103),R=n(103),I=n(104);t.nominalTypes=n(105),t.nominalInterfaces=n(106),t.typeExpressions=n(107);var C=n(108);t.TOP_LEVEL_EXTRA=t.tsInterfaces.TOP_LEVEL_EXTRA,t.DEFINED_IN_TYPES_EXTRA=t.tsInterfaces.DEFINED_IN_TYPES_EXTRA,t.USER_DEFINED_EXTRA=t.tsInterfaces.USER_DEFINED_EXTRA,t.SOURCE_EXTRA=t.tsInterfaces.SOURCE_EXTRA,t.getSchemaUtils=r,t.isParsedType=i,t.loadTypeCollection=a,t.loadType=o,t.parse=s,t.parseType=u,function(e){e[e.SCALAR=0]="SCALAR",e[e.ARRAY=1]="ARRAY",e[e.MAP=2]="MAP"}(t.NodeKind||(t.NodeKind={}));t.NodeKind;t.parseFromAST=l,t.parseTypeFromAST=p,t.dump=c,t.validate=f,t.validateTypeDefinition=m,t.performAC=d,t.checkACStatus=h,t.builtInFacets=y,t.builtInTypes=v,t.derive=g,t.unify=A;var L=function(){function e(e){this.target=e}return e.prototype.addProperty=function(e,t,n){return this.target.declareProperty(e,t,n),this},e.prototype.closeType=function(){return this.target.addMeta(new _.KnownPropertyRestriction(!1)),this},e.prototype.annotate=function(e,t){return this.target.addMeta(new M.Annotation(e,t)),this},e.prototype.customFacet=function(e,t){return this.target.addMeta(new w.CustomFacet(e,t)),this},e.prototype.customFacetDeclaration=function(e,t,n){return void 0===n&&(n=!0),this.target.addMeta(new R.FacetDeclaration(e,t,n)),this},e.prototype.addSimpleFacet=function(e,t){return this.target.addMeta(N.getInstance().buildFacet(e,t)),this},e.prototype.getResult=function(){return this.target},e}();t.TypeConstructor=L,t.setPropertyConstructor=S,t.toNominal=T},function(e,t,n){var r;(function(e,i){!function(a){function o(e){throw RangeError(P[e])}function s(e,t){for(var n=e.length,r=[];n--;)r[n]=t(e[n]);return r}function u(e,t){var n=e.split("@"),r="";n.length>1&&(r=n[0]+"@",e=n[1]),e=e.replace(L,".");var i=e.split("."),a=s(i,t).join(".");return r+a}function l(e){for(var t,n,r=[],i=0,a=e.length;a>i;)t=e.charCodeAt(i++),t>=55296&&56319>=t&&a>i?(n=e.charCodeAt(i++),56320==(64512&n)?r.push(((1023&t)<<10)+(1023&n)+65536):(r.push(t),i--)):r.push(t);return r}function p(e){return s(e,function(e){var t="";return e>65535&&(e-=65536,t+=x(e>>>10&1023|55296),e=56320|1023&e),t+=x(e)}).join("")}function c(e){return 10>e-48?e-22:26>e-65?e-65:26>e-97?e-97:T}function f(e,t){return e+22+75*(26>e)-((0!=t)<<5)}function m(e,t,n){var r=0;for(e=n?D(e/_):e>>1,e+=D(e/t);e>O*b>>1;r+=T)e=D(e/O);return D(r+(O+1)*e/(e+N))}function d(e){var t,n,r,i,a,s,u,l,f,d,h=[],y=e.length,v=0,g=w,A=M;for(n=e.lastIndexOf(R),0>n&&(n=0),r=0;n>r;++r)e.charCodeAt(r)>=128&&o("not-basic"),h.push(e.charCodeAt(r));for(i=n>0?n+1:0;y>i;){for(a=v,s=1,u=T;i>=y&&o("invalid-input"),l=c(e.charCodeAt(i++)),(l>=T||l>D((S-v)/s))&&o("overflow"),v+=l*s,f=A>=u?E:u>=A+b?b:u-A,!(f>l);u+=T)d=T-f,s>D(S/d)&&o("overflow"),s*=d;t=h.length+1,A=m(v-a,t,0==a),D(v/t)>S-g&&o("overflow"),g+=D(v/t),v%=t,h.splice(v++,0,g)}return p(h)}function h(e){var t,n,r,i,a,s,u,p,c,d,h,y,v,g,A,N=[];for(e=l(e),y=e.length,t=w,n=0,a=M,s=0;y>s;++s)h=e[s],128>h&&N.push(x(h));for(r=i=N.length,i&&N.push(R);y>r;){for(u=S,s=0;y>s;++s)h=e[s],h>=t&&u>h&&(u=h);for(v=r+1,u-t>D((S-n)/v)&&o("overflow"),n+=(u-t)*v,t=u,s=0;y>s;++s)if(h=e[s],t>h&&++n>S&&o("overflow"),h==t){for(p=n,c=T;d=a>=c?E:c>=a+b?b:c-a,!(d>p);c+=T)A=p-d,g=T-d,N.push(x(f(d+A%g,0))),p=D(A/g);N.push(x(f(p,0))),a=m(n,v,r==i),n=0,++r}++n,++t}return N.join("")}function y(e){return u(e,function(e){return I.test(e)?d(e.slice(4).toLowerCase()):e})}function v(e){return u(e,function(e){return C.test(e)?"xn--"+h(e):e})}var g=("object"==typeof t&&t&&!t.nodeType&&t,"object"==typeof e&&e&&!e.nodeType&&e,"object"==typeof i&&i);(g.global===g||g.window===g||g.self===g)&&(a=g);var A,S=2147483647,T=36,E=1,b=26,N=38,_=700,M=72,w=128,R="-",I=/^xn--/,C=/[^\x20-\x7E]/,L=/[\x2E\u3002\uFF0E\uFF61]/g,P={overflow:"Overflow: input needs wider integers to process","not-basic":"Illegal input >= 0x80 (not a basic code point)","invalid-input":"Invalid input"},O=T-E,D=Math.floor,x=String.fromCharCode;A={version:"1.3.2",ucs2:{decode:l,encode:p},decode:d,encode:h,toASCII:v,toUnicode:y},r=function(){return A}.call(t,n,t,e),!(void 0!==r&&(e.exports=r))}(this)}).call(t,n(147)(e),function(){return this}())},function(e,t,n){function r(){}function i(e,t,n,r,i){function p(e){if(e>65535){e-=65536;var t=55296+(e>>10),n=56320+(1023&e);return String.fromCharCode(t,n)}return String.fromCharCode(e)}function d(e){var t=e.slice(1,-1);return t in n?n[t]:"#"===t.charAt(0)?p(parseInt(t.substr(1).replace("x","0x"))):(i.error("entity not found:"+e),e)}function h(t){if(t>b){var n=e.substring(b,t).replace(/&#?\w+;/g,d);S&&y(b),r.characters(n,0,t-b),b=t}}function y(t,n){for(;t>=g&&(n=A.exec(e));)v=n.index,g=v+n[0].length,S.lineNumber++;S.columnNumber=t-v+1}for(var v=0,g=0,A=/.*(?:\r\n?|\n)|.*$/g,S=r.locator,T=[{currentNSMap:t}],E={},b=0;;){try{var N=e.indexOf("<",b);if(0>N){if(!e.substr(b).match(/^\s*$/)){var _=r.doc,M=_.createTextNode(e.substr(b));_.appendChild(M),r.currentElement=M}return}switch(N>b&&h(N),e.charAt(N+1)){case"/":var w=e.indexOf(">",N+3),R=e.substring(N+2,w),I=T.pop();0>w?(R=e.substring(N+2).replace(/[\s<].*/,""),i.error("end tag name: "+R+" is not complete:"+I.tagName),w=N+1+R.length):R.match(/\s</)&&(R=R.replace(/[\s<].*/,""),i.error("end tag name: "+R+" maybe not complete"),w=N+1+R.length);var C=I.localNSMap,L=I.tagName==R,P=L||I.tagName&&I.tagName.toLowerCase()==R.toLowerCase();if(P){if(r.endElement(I.uri,I.localName,R),C)for(var O in C)r.endPrefixMapping(O);L||i.fatalError("end tag name: "+R+" is not match the current start tagName:"+I.tagName)}else T.push(I);w++;break;case"?":S&&y(N),w=f(e,N,r);break;case"!":S&&y(N),w=c(e,N,r,i);break;default:S&&y(N);var D=new m,x=T[T.length-1].currentNSMap,w=o(e,N,D,x,d,i),U=D.length;if(!D.closed&&l(e,w,D.tagName,E)&&(D.closed=!0,n.nbsp||i.warning("unclosed xml attribute")),S&&U){for(var k=a(S,{}),F=0;U>F;F++){var B=D[F];y(B.offset),B.locator=a(S,{})}r.locator=k,s(D,r,x)&&T.push(D),r.locator=S}else s(D,r,x)&&T.push(D);"http://www.w3.org/1999/xhtml"!==D.uri||D.closed?w++:w=u(e,w,D.tagName,d,r)}}catch(K){i.error("element parse error: "+K),w=-1}w>b?b=w:h(Math.max(N,b)+1)}}function a(e,t){return t.lineNumber=e.lineNumber,t.columnNumber=e.columnNumber,t}function o(e,t,n,r,i,a){for(var o,s,u=++t,l=A;;){var p=e.charAt(u);switch(p){case"=":if(l===S)o=e.slice(t,u),l=E;else{if(l!==T)throw new Error("attribute equal must after attrName");l=E}break;case"'":case'"':if(l===E||l===S){if(l===S&&(a.warning('attribute value must after "="'),o=e.slice(t,u)),t=u+1,u=e.indexOf(p,t),!(u>0))throw new Error("attribute value no end '"+p+"' match");s=e.slice(t,u).replace(/&#?\w+;/g,i),n.add(o,s,t-1),l=N}else{if(l!=b)throw new Error('attribute value must after "="');s=e.slice(t,u).replace(/&#?\w+;/g,i),n.add(o,s,t),a.warning('attribute "'+o+'" missed start quot('+p+")!!"),t=u+1,l=N}break;case"/":switch(l){case A:n.setTagName(e.slice(t,u));case N:case _:case M:l=M,n.closed=!0;case b:case S:case T:break;default:throw new Error("attribute invalid close char('/')")}break;case"":return a.error("unexpected end of input"),l==A&&n.setTagName(e.slice(t,u)),u;case">":switch(l){case A:n.setTagName(e.slice(t,u));case N:case _:case M:break;case b:case S:s=e.slice(t,u),"/"===s.slice(-1)&&(n.closed=!0,s=s.slice(0,-1));case T:l===T&&(s=o),l==b?(a.warning('attribute "'+s+'" missed quot(")!!'),n.add(o,s.replace(/&#?\w+;/g,i),t)):("http://www.w3.org/1999/xhtml"===r[""]&&s.match(/^(?:disabled|checked|selected)$/i)||a.warning('attribute "'+s+'" missed value!! "'+s+'" instead!!'),n.add(s,s,t));break;case E:throw new Error("attribute value missed!!")}return u;case"":p=" ";default:if(" ">=p)switch(l){case A:n.setTagName(e.slice(t,u)),l=_;break;case S:o=e.slice(t,u),l=T;break;case b:var s=e.slice(t,u).replace(/&#?\w+;/g,i);a.warning('attribute "'+s+'" missed quot(")!!'),n.add(o,s,t);case N:l=_}else switch(l){case T:n.tagName;"http://www.w3.org/1999/xhtml"===r[""]&&o.match(/^(?:disabled|checked|selected)$/i)||a.warning('attribute "'+o+'" missed value!! "'+o+'" instead2!!'),n.add(o,o,t),t=u,l=S;break;case N:a.warning('attribute space is required"'+o+'"!!');case _:l=S,t=u;break;case E:l=b,t=u;break;case M:throw new Error("elements closed character '/' and '>' must be connected to")}}u++}}function s(e,t,n){for(var r=e.tagName,i=null,a=e.length;a--;){var o=e[a],s=o.qName,u=o.value,l=s.indexOf(":");if(l>0)var c=o.prefix=s.slice(0,l),f=s.slice(l+1),m="xmlns"===c&&f;else f=s,c=null,m="xmlns"===s&&"";o.localName=f,m!==!1&&(null==i&&(i={},p(n,n={})),n[m]=i[m]=u,o.uri="http://www.w3.org/2000/xmlns/",t.startPrefixMapping(m,u))}for(var a=e.length;a--;){o=e[a];var c=o.prefix;c&&("xml"===c&&(o.uri="http://www.w3.org/XML/1998/namespace"),"xmlns"!==c&&(o.uri=n[c||""]))}var l=r.indexOf(":");l>0?(c=e.prefix=r.slice(0,l),f=e.localName=r.slice(l+1)):(c=null,f=e.localName=r);var d=e.uri=n[c||""];if(t.startElement(d,f,r,e),!e.closed)return e.currentNSMap=n,e.localNSMap=i,!0;if(t.endElement(d,f,r),i)for(c in i)t.endPrefixMapping(c)}function u(e,t,n,r,i){if(/^(?:script|textarea)$/i.test(n)){var a=e.indexOf("</"+n+">",t),o=e.substring(t+1,a);if(/[&<]/.test(o))return/^script$/i.test(n)?(i.characters(o,0,o.length),a):(o=o.replace(/&#?\w+;/g,r),i.characters(o,0,o.length),a)}return t+1}function l(e,t,n,r){var i=r[n];return null==i&&(i=e.lastIndexOf("</"+n+">"),t>i&&(i=e.lastIndexOf("</"+n)),r[n]=i),t>i}function p(e,t){for(var n in e)t[n]=e[n]}function c(e,t,n,r){var i=e.charAt(t+2);switch(i){case"-":if("-"===e.charAt(t+3)){var a=e.indexOf("-->",t+4);return a>t?(n.comment(e,t+4,a-t-4),a+3):(r.error("Unclosed comment"),-1)}return-1;default:if("CDATA["==e.substr(t+3,6)){var a=e.indexOf("]]>",t+9);return n.startCDATA(),n.characters(e,t+9,a-t-9),n.endCDATA(),a+3}var o=h(e,t),s=o.length;if(s>1&&/!doctype/i.test(o[0][0])){var u=o[1][0],l=s>3&&/^public$/i.test(o[2][0])&&o[3][0],p=s>4&&o[4][0],c=o[s-1];return n.startDTD(u,l&&l.replace(/^(['"])(.*?)\1$/,"$2"),p&&p.replace(/^(['"])(.*?)\1$/,"$2")),n.endDTD(),c.index+c[0].length}}return-1}function f(e,t,n){var r=e.indexOf("?>",t);if(r){var i=e.substring(t,r).match(/^<\?(\S*)\s*([\s\S]*?)\s*$/);if(i){i[0].length;return n.processingInstruction(i[1],i[2]),r+2}return-1}return-1}function m(e){}function d(e,t){return e.__proto__=t,e}function h(e,t){var n,r=[],i=/'[^']+'|"[^"]+"|[^\s<>\/=]+=?|(\/?\s*>|<)/g;for(i.lastIndex=t,i.exec(e);n=i.exec(e);)if(r.push(n),n[1])return r}var y=/[A-Z_a-z\xC0-\xD6\xD8-\xF6\u00F8-\u02FF\u0370-\u037D\u037F-\u1FFF\u200C-\u200D\u2070-\u218F\u2C00-\u2FEF\u3001-\uD7FF\uF900-\uFDCF\uFDF0-\uFFFD]/,v=new RegExp("[\\-\\.0-9"+y.source.slice(1,-1)+"\\u00B7\\u0300-\\u036F\\u203F-\\u2040]"),g=new RegExp("^"+y.source+v.source+"*(?::"+y.source+v.source+"*)?$"),A=0,S=1,T=2,E=3,b=4,N=5,_=6,M=7;r.prototype={parse:function(e,t,n){var r=this.domBuilder;r.startDocument(),p(t,t={}),i(e,t,n,r,this.errorHandler),r.endDocument()}},m.prototype={setTagName:function(e){if(!g.test(e))throw new Error("invalid tagName:"+e);this.tagName=e},add:function(e,t,n){if(!g.test(e))throw new Error("invalid attribute:"+e);this[this.length++]={qName:e,value:t,offset:n}},length:0,getLocalName:function(e){return this[e].localName},getLocator:function(e){return this[e].locator},getQName:function(e){return this[e].qName},getURI:function(e){return this[e].uri},getValue:function(e){return this[e].value}},d({},d.prototype)instanceof d||(d=function(e,t){function n(){}n.prototype=t,n=new n;for(t in e)n[t]=e[t];return n}),t.XMLReader=r},function(e,t,n){function r(e,t){for(var n in e)t[n]=e[n]}function i(e,t){function n(){}var i=e.prototype;if(Object.create){var a=Object.create(t.prototype);i.__proto__=a}i instanceof t||(n.prototype=t.prototype,n=new n,r(i,n),e.prototype=i=n),i.constructor!=e&&("function"!=typeof e&&console.error("unknow Class:"+e),i.constructor=e)}function a(e,t){if(t instanceof Error)var n=t;else n=this,Error.call(this,ae[e]),this.message=ae[e],Error.captureStackTrace&&Error.captureStackTrace(this,a);return n.code=e,t&&(this.message=this.message+": "+t),n}function o(){}function s(e,t){this._node=e,this._refresh=t,u(this)}function u(e){var t=e._node._inc||e._node.ownerDocument._inc;if(e._inc!=t){var n=e._refresh(e._node);j(e,"length",n.length),r(n,e),e._inc=t}}function l(){}function p(e,t){for(var n=e.length;n--;)if(e[n]===t)return n}function c(e,t,n,r){if(r?t[p(t,r)]=n:t[t.length++]=n,e){n.ownerElement=e;var i=e.ownerDocument;i&&(r&&A(i,e,r),g(i,e,n))}}function f(e,t,n){var r=p(t,n);if(!(r>=0))throw a(se,new Error(e.tagName+"@"+n));for(var i=t.length-1;i>r;)t[r]=t[++r];if(t.length=i,e){var o=e.ownerDocument;o&&(A(o,e,n),n.ownerElement=null)}}function m(e){if(this._features={},e)for(var t in e)this._features=e[t]}function d(){}function h(e){return"<"==e&&"&lt;"||">"==e&&"&gt;"||"&"==e&&"&amp;"||'"'==e&&"&quot;"||"&#"+e.charCodeAt()+";"}function y(e,t){if(t(e))return!0;if(e=e.firstChild)do if(y(e,t))return!0;while(e=e.nextSibling)}function v(){}function g(e,t,n){e&&e._inc++;var r=n.namespaceURI;"http://www.w3.org/2000/xmlns/"==r&&(t._nsMap[n.prefix?n.localName:""]=n.value)}function A(e,t,n,r){e&&e._inc++;var i=n.namespaceURI;"http://www.w3.org/2000/xmlns/"==i&&delete t._nsMap[n.prefix?n.localName:""]}function S(e,t,n){if(e&&e._inc){e._inc++;var r=t.childNodes;if(n)r[r.length++]=n;else{for(var i=t.firstChild,a=0;i;)r[a++]=i,i=i.nextSibling;r.length=a}}}function T(e,t){var n=t.previousSibling,r=t.nextSibling;return n?n.nextSibling=r:e.firstChild=r,r?r.previousSibling=n:e.lastChild=n,S(e.ownerDocument,e),t}function E(e,t,n){var r=t.parentNode;if(r&&r.removeChild(t),t.nodeType===ne){var i=t.firstChild;if(null==i)return t;var a=t.lastChild}else i=a=t;var o=n?n.previousSibling:e.lastChild;i.previousSibling=o,a.nextSibling=n,o?o.nextSibling=i:e.firstChild=i,null==n?e.lastChild=a:n.previousSibling=a;do i.parentNode=e;while(i!==a&&(i=i.nextSibling));return S(e.ownerDocument||e,e),t.nodeType==ne&&(t.firstChild=t.lastChild=null),t}function b(e,t){var n=t.parentNode;if(n){var r=e.lastChild;n.removeChild(t);var r=e.lastChild}var r=e.lastChild;return t.parentNode=e,t.previousSibling=r,t.nextSibling=null,r?r.nextSibling=t:e.firstChild=t,e.lastChild=t,S(e.ownerDocument,e,t),t}function N(){this._nsMap={}}function _(){}function M(){}function w(){}function R(){}function I(){}function C(){}function L(){}function P(){}function O(){}function D(){}function x(){}function U(){}function k(e,t){var n=[],r=9==this.nodeType?this.documentElement:this,i=r.prefix,a=r.namespaceURI;if(a&&null==i){var i=r.lookupPrefix(a);if(null==i)var o=[{namespace:a,prefix:null}]}return B(this,n,e,t,o),n.join("")}function F(e,t,n){var r=e.prefix||"",i=e.namespaceURI;if(!r&&!i)return!1;if("xml"===r&&"http://www.w3.org/XML/1998/namespace"===i||"http://www.w3.org/2000/xmlns/"==i)return!1;for(var a=n.length;a--;){var o=n[a];if(o.prefix==r)return o.namespace!=i}return!0}function B(e,t,n,r,i){if(r){if(e=r(e),!e)return;if("string"==typeof e)return void t.push(e)}switch(e.nodeType){case H:i||(i=[]);var a=(i.length,e.attributes),o=a.length,s=e.firstChild,u=e.tagName;n=q===e.namespaceURI||n,t.push("<",u);for(var l=0;o>l;l++){var p=a.item(l);"xmlns"==p.prefix?i.push({prefix:p.localName,namespace:p.value}):"xmlns"==p.nodeName&&i.push({prefix:"",namespace:p.value})}for(var l=0;o>l;l++){var p=a.item(l);if(F(p,n,i)){var c=p.prefix||"",f=p.namespaceURI,m=c?" xmlns:"+c:" xmlns";t.push(m,'="',f,'"'),i.push({prefix:c,namespace:f})}B(p,t,n,r,i)}if(F(e,n,i)){var c=e.prefix||"",f=e.namespaceURI,m=c?" xmlns:"+c:" xmlns";t.push(m,'="',f,'"'),i.push({prefix:c,namespace:f})}if(s||n&&!/^(?:meta|link|img|br|hr|input)$/i.test(u)){if(t.push(">"),n&&/^script$/i.test(u))for(;s;)s.data?t.push(s.data):B(s,t,n,r,i),s=s.nextSibling;else for(;s;)B(s,t,n,r,i),s=s.nextSibling;t.push("</",u,">")}else t.push("/>");return;case ee:case ne:for(var s=e.firstChild;s;)B(s,t,n,r,i),s=s.nextSibling;return;case $:return t.push(" ",e.name,'="',e.value.replace(/[<&"]/g,h),'"');case G:return t.push(e.data.replace(/[<&]/g,h));case X:return t.push("<![CDATA[",e.data,"]]>");case Z:return t.push("<!--",e.data,"-->");case te:var d=e.publicId,y=e.systemId;if(t.push("<!DOCTYPE ",e.name),d)t.push(' PUBLIC "',d),y&&"."!=y&&t.push('" "',y),t.push('">');else if(y&&"."!=y)t.push(' SYSTEM "',y,'">');else{var v=e.internalSubset;v&&t.push(" [",v,"]"),t.push(">")}return;case Q:return t.push("<?",e.target," ",e.data,"?>");case z:return t.push("&",e.nodeName,";");default:t.push("??",e.nodeName)}}function K(e,t,n){var r;switch(t.nodeType){case H:r=t.cloneNode(!1),r.ownerDocument=e;case ne:break;case $:n=!0}if(r||(r=t.cloneNode(!1)),r.ownerDocument=e,r.parentNode=null,n)for(var i=t.firstChild;i;)r.appendChild(K(e,i,n)),i=i.nextSibling;return r}function V(e,t,n){var r=new t.constructor;for(var i in t){var a=t[i];"object"!=typeof a&&a!=r[i]&&(r[i]=a)}switch(t.childNodes&&(r.childNodes=new o),r.ownerDocument=e,r.nodeType){case H:var s=t.attributes,u=r.attributes=new l,p=s.length;u._ownerElement=r;for(var c=0;p>c;c++)r.setAttributeNode(V(e,s.item(c),!0));break;case $:n=!0}if(n)for(var f=t.firstChild;f;)r.appendChild(V(e,f,n)),f=f.nextSibling;return r}function j(e,t,n){e[t]=n}function W(e){switch(e.nodeType){case H:case ne:var t=[];for(e=e.firstChild;e;)7!==e.nodeType&&8!==e.nodeType&&t.push(W(e)),e=e.nextSibling;return t.join("");default:return e.nodeValue}}var q="http://www.w3.org/1999/xhtml",Y={},H=Y.ELEMENT_NODE=1,$=Y.ATTRIBUTE_NODE=2,G=Y.TEXT_NODE=3,X=Y.CDATA_SECTION_NODE=4,z=Y.ENTITY_REFERENCE_NODE=5,J=Y.ENTITY_NODE=6,Q=Y.PROCESSING_INSTRUCTION_NODE=7,Z=Y.COMMENT_NODE=8,ee=Y.DOCUMENT_NODE=9,te=Y.DOCUMENT_TYPE_NODE=10,ne=Y.DOCUMENT_FRAGMENT_NODE=11,re=Y.NOTATION_NODE=12,ie={},ae={},oe=(ie.INDEX_SIZE_ERR=(ae[1]="Index size error",1),ie.DOMSTRING_SIZE_ERR=(ae[2]="DOMString size error",2),ie.HIERARCHY_REQUEST_ERR=(ae[3]="Hierarchy request error",3)),se=(ie.WRONG_DOCUMENT_ERR=(ae[4]="Wrong document",4),ie.INVALID_CHARACTER_ERR=(ae[5]="Invalid character",5),ie.NO_DATA_ALLOWED_ERR=(ae[6]="No data allowed",6),ie.NO_MODIFICATION_ALLOWED_ERR=(ae[7]="No modification allowed",7),ie.NOT_FOUND_ERR=(ae[8]="Not found",8)),ue=(ie.NOT_SUPPORTED_ERR=(ae[9]="Not supported",9),ie.INUSE_ATTRIBUTE_ERR=(ae[10]="Attribute in use",10));ie.INVALID_STATE_ERR=(ae[11]="Invalid state",11),ie.SYNTAX_ERR=(ae[12]="Syntax error",12),ie.INVALID_MODIFICATION_ERR=(ae[13]="Invalid modification",13),ie.NAMESPACE_ERR=(ae[14]="Invalid namespace",14),ie.INVALID_ACCESS_ERR=(ae[15]="Invalid access",15);a.prototype=Error.prototype,r(ie,a),o.prototype={length:0,item:function(e){return this[e]||null},toString:function(e,t){for(var n=[],r=0;r<this.length;r++)B(this[r],n,e,t);return n.join("")}},s.prototype.item=function(e){return u(this),this[e]},i(s,o),l.prototype={length:0,item:o.prototype.item,getNamedItem:function(e){for(var t=this.length;t--;){var n=this[t];if(n.nodeName==e)return n}},setNamedItem:function(e){var t=e.ownerElement;if(t&&t!=this._ownerElement)throw new a(ue);var n=this.getNamedItem(e.nodeName);return c(this._ownerElement,this,e,n),n},setNamedItemNS:function(e){var t,n=e.ownerElement;if(n&&n!=this._ownerElement)throw new a(ue);return t=this.getNamedItemNS(e.namespaceURI,e.localName),c(this._ownerElement,this,e,t),t},removeNamedItem:function(e){var t=this.getNamedItem(e);return f(this._ownerElement,this,t),t},removeNamedItemNS:function(e,t){var n=this.getNamedItemNS(e,t);return f(this._ownerElement,this,n),n},getNamedItemNS:function(e,t){for(var n=this.length;n--;){var r=this[n];if(r.localName==t&&r.namespaceURI==e)return r}return null}},m.prototype={hasFeature:function(e,t){var n=this._features[e.toLowerCase()];return n&&(!t||t in n)?!0:!1},createDocument:function(e,t,n){var r=new v;if(r.implementation=this,r.childNodes=new o,r.doctype=n,n&&r.appendChild(n),t){var i=r.createElementNS(e,t);r.appendChild(i)}return r},createDocumentType:function(e,t,n){var r=new C;return r.name=e,r.nodeName=e,r.publicId=t,r.systemId=n,r}},d.prototype={firstChild:null,lastChild:null,previousSibling:null,nextSibling:null,attributes:null,parentNode:null,childNodes:null,ownerDocument:null,nodeValue:null,namespaceURI:null,prefix:null,localName:null,insertBefore:function(e,t){return E(this,e,t)},replaceChild:function(e,t){this.insertBefore(e,t),t&&this.removeChild(t)},removeChild:function(e){return T(this,e)},appendChild:function(e){return this.insertBefore(e,null)},hasChildNodes:function(){return null!=this.firstChild},cloneNode:function(e){return V(this.ownerDocument||this,this,e)},normalize:function(){for(var e=this.firstChild;e;){var t=e.nextSibling;t&&t.nodeType==G&&e.nodeType==G?(this.removeChild(t),e.appendData(t.data)):(e.normalize(),e=t)}},isSupported:function(e,t){return this.ownerDocument.implementation.hasFeature(e,t)},hasAttributes:function(){return this.attributes.length>0},lookupPrefix:function(e){for(var t=this;t;){var n=t._nsMap;if(n)for(var r in n)if(n[r]==e)return r;t=t.nodeType==$?t.ownerDocument:t.parentNode}return null},lookupNamespaceURI:function(e){for(var t=this;t;){var n=t._nsMap;if(n&&e in n)return n[e];t=t.nodeType==$?t.ownerDocument:t.parentNode}return null},isDefaultNamespace:function(e){var t=this.lookupPrefix(e);return null==t}},r(Y,d),r(Y,d.prototype),v.prototype={nodeName:"#document",nodeType:ee,doctype:null,documentElement:null,_inc:1,insertBefore:function(e,t){if(e.nodeType==ne){for(var n=e.firstChild;n;){var r=n.nextSibling;this.insertBefore(n,t),n=r}return e}return null==this.documentElement&&e.nodeType==H&&(this.documentElement=e),E(this,e,t),e.ownerDocument=this,e},removeChild:function(e){return this.documentElement==e&&(this.documentElement=null),T(this,e)},importNode:function(e,t){return K(this,e,t)},getElementById:function(e){var t=null;return y(this.documentElement,function(n){return n.nodeType==H&&n.getAttribute("id")==e?(t=n,!0):void 0}),t},createElement:function(e){var t=new N;t.ownerDocument=this,t.nodeName=e,t.tagName=e,t.childNodes=new o;var n=t.attributes=new l;return n._ownerElement=t,t},createDocumentFragment:function(){var e=new D;return e.ownerDocument=this,e.childNodes=new o,e},createTextNode:function(e){var t=new w;return t.ownerDocument=this,t.appendData(e),t},createComment:function(e){var t=new R;return t.ownerDocument=this,t.appendData(e),t},createCDATASection:function(e){var t=new I;return t.ownerDocument=this,t.appendData(e),t},createProcessingInstruction:function(e,t){var n=new x;return n.ownerDocument=this,n.tagName=n.target=e,n.nodeValue=n.data=t,n},createAttribute:function(e){var t=new _;return t.ownerDocument=this,t.name=e,t.nodeName=e,t.localName=e,t.specified=!0,t},createEntityReference:function(e){var t=new O;return t.ownerDocument=this,t.nodeName=e,t},createElementNS:function(e,t){var n=new N,r=t.split(":"),i=n.attributes=new l;return n.childNodes=new o,n.ownerDocument=this,n.nodeName=t,n.tagName=t,n.namespaceURI=e,2==r.length?(n.prefix=r[0],n.localName=r[1]):n.localName=t,i._ownerElement=n,n},createAttributeNS:function(e,t){var n=new _,r=t.split(":");return n.ownerDocument=this,n.nodeName=t,n.name=t,n.namespaceURI=e,n.specified=!0,2==r.length?(n.prefix=r[0],n.localName=r[1]):n.localName=t,n}},i(v,d),N.prototype={nodeType:H,hasAttribute:function(e){return null!=this.getAttributeNode(e)},getAttribute:function(e){var t=this.getAttributeNode(e);return t&&t.value||""},getAttributeNode:function(e){return this.attributes.getNamedItem(e)},setAttribute:function(e,t){var n=this.ownerDocument.createAttribute(e);n.value=n.nodeValue=""+t,this.setAttributeNode(n)},removeAttribute:function(e){var t=this.getAttributeNode(e);t&&this.removeAttributeNode(t)},appendChild:function(e){return e.nodeType===ne?this.insertBefore(e,null):b(this,e)},setAttributeNode:function(e){return this.attributes.setNamedItem(e)},setAttributeNodeNS:function(e){return this.attributes.setNamedItemNS(e)},removeAttributeNode:function(e){return this.attributes.removeNamedItem(e.nodeName)},removeAttributeNS:function(e,t){var n=this.getAttributeNodeNS(e,t);n&&this.removeAttributeNode(n)},hasAttributeNS:function(e,t){return null!=this.getAttributeNodeNS(e,t)},getAttributeNS:function(e,t){var n=this.getAttributeNodeNS(e,t);return n&&n.value||""},setAttributeNS:function(e,t,n){var r=this.ownerDocument.createAttributeNS(e,t);r.value=r.nodeValue=""+n,this.setAttributeNode(r)},getAttributeNodeNS:function(e,t){return this.attributes.getNamedItemNS(e,t)},getElementsByTagName:function(e){return new s(this,function(t){var n=[];return y(t,function(r){r===t||r.nodeType!=H||"*"!==e&&r.tagName!=e||n.push(r)}),n})},getElementsByTagNameNS:function(e,t){return new s(this,function(n){var r=[];return y(n,function(i){i===n||i.nodeType!==H||"*"!==e&&i.namespaceURI!==e||"*"!==t&&i.localName!=t||r.push(i)}),r})}},v.prototype.getElementsByTagName=N.prototype.getElementsByTagName,v.prototype.getElementsByTagNameNS=N.prototype.getElementsByTagNameNS,i(N,d),_.prototype.nodeType=$,i(_,d),M.prototype={data:"",substringData:function(e,t){return this.data.substring(e,e+t)},appendData:function(e){e=this.data+e,this.nodeValue=this.data=e,this.length=e.length},insertData:function(e,t){this.replaceData(e,0,t)},appendChild:function(e){throw new Error(ae[oe])},deleteData:function(e,t){this.replaceData(e,t,"")},replaceData:function(e,t,n){var r=this.data.substring(0,e),i=this.data.substring(e+t);n=r+n+i,this.nodeValue=this.data=n,this.length=n.length}},i(M,d),w.prototype={nodeName:"#text",nodeType:G,splitText:function(e){var t=this.data,n=t.substring(e);t=t.substring(0,e),this.data=this.nodeValue=t,this.length=t.length;var r=this.ownerDocument.createTextNode(n);return this.parentNode&&this.parentNode.insertBefore(r,this.nextSibling),r}},i(w,M),R.prototype={nodeName:"#comment",nodeType:Z},i(R,M),I.prototype={nodeName:"#cdata-section",nodeType:X},i(I,M),C.prototype.nodeType=te,i(C,d),L.prototype.nodeType=re,i(L,d),P.prototype.nodeType=J,i(P,d),O.prototype.nodeType=z,i(O,d),D.prototype.nodeName="#document-fragment",D.prototype.nodeType=ne,i(D,d),x.prototype.nodeType=Q,i(x,d),U.prototype.serializeToString=function(e,t,n){return k.call(e,t,n)},d.prototype.toString=k;try{Object.defineProperty&&(Object.defineProperty(s.prototype,"length",{get:function(){return u(this),this.$$length}}),Object.defineProperty(d.prototype,"textContent",{get:function(){return W(this)},set:function(e){switch(this.nodeType){case H:case ne:for(;this.firstChild;)this.removeChild(this.firstChild);(e||String(e))&&this.appendChild(this.ownerDocument.createTextNode(e));break;default:this.data=e,this.value=e,this.nodeValue=e}}}),j=function(e,t,n){e["$$"+t]=n})}catch(le){}t.DOMImplementation=m,t.XMLSerializer=U},function(e,t,n){"use strict";function r(e){return 10===e||13===e}function i(e){return 9===e||32===e}function a(e){return 9===e||32===e||10===e||13===e}function o(e){return 44===e||91===e||93===e||123===e||125===e}function s(e){var t;return e>=48&&57>=e?e-48:(t=32|e,t>=97&&102>=t?t-97+10:-1)}function u(e){return 120===e?2:117===e?4:85===e?8:0}function l(e){return e>=48&&57>=e?e-48:-1}function p(e){return 48===e?"\x00":97===e?"":98===e?"\b":116===e?"	":9===e?"	":110===e?"\n":118===e?"":102===e?"\f":114===e?"\r":101===e?"":32===e?" ":34===e?'"':47===e?"/":92===e?"\\":78===e?"":95===e?" ":76===e?"\u2028":80===e?"\u2029":""}function c(e){return 65535>=e?String.fromCharCode(e):String.fromCharCode((e-65536>>10)+55296,(e-65536&1023)+56320)}function f(e,t){return new j(t,new W(e.filename,e.input,e.position,e.line-1,e.position-e.lineStart))}function m(e,t,n){var r=A(e,t);if(r){var i=n+t;if(!e.errorMap[i]){var a=new W(e.filename,e.input,t,r.line-1,t-r.start),o=new j(n,a);e.errors.push(o)}}}function d(e,t){var n=f(e,t),r=n.message+n.mark.position;e.errorMap[r]||(e.errors.push(n),e.errorMap[r]=1);for(var i=e.position;;){if(e.position>=e.input.length-1)return;var a=e.input.charAt(e.position);if("\n"==a)return e.position--,void(e.position==i&&(e.position+=1));if("\r"==a)return e.position--,void(e.position==i&&(e.position+=1));e.position++}}function h(e,t){var n=f(e,t);e.onWarning&&e.onWarning.call(null,n)}function y(e,t,n,r){var i,a,o,s,u=e.result;if(-1==u.startPosition&&(u.startPosition=t),n>=t){if(s=e.input.slice(t,n),r)for(i=0,a=s.length;a>i;i+=1)o=s.charCodeAt(i),9===o||o>=32&&1114111>=o||d(e,"expected valid JSON character");u.value+=s,u.endPosition=n}}function v(e,t,n,r,i){if(null!=r){null===t&&(t={startPosition:r.startPosition,endPosition:i.endPosition,parent:null,errors:[],mappings:[],kind:K.Kind.MAP});var a=K.newMapping(r,i);return a.parent=t,r.parent=a,null!=i&&(i.parent=a),!e.ignoreDuplicateKeys&&t.mappings.forEach(function(t){t.key&&t.key.value===(a.key&&a.key.value)&&(m(e,a.key.startPosition,"duplicate key"),m(e,t.key.startPosition,"duplicate key"))}),t.mappings.push(a),t.endPosition=i?i.endPosition:r.endPosition+1,t}}function g(e){var t;t=e.input.charCodeAt(e.position),10===t?e.position++:13===t?(e.position++,10===e.input.charCodeAt(e.position)&&e.position++):d(e,"a line break is expected"),e.line+=1,e.lineStart=e.position,e.lines.push({start:e.lineStart,line:e.line})}function A(e,t){for(var n,r=0;r<e.lines.length&&!(e.lines[r].start>t);r++)n=e.lines[r];return n?n:{start:0,line:0}}function S(e,t,n){for(var a=0,o=e.input.charCodeAt(e.position);0!==o;){for(;i(o);)o=e.input.charCodeAt(++e.position);if(t&&35===o)do o=e.input.charCodeAt(++e.position);while(10!==o&&13!==o&&0!==o);if(!r(o))break;for(g(e),o=e.input.charCodeAt(e.position),a++,e.lineIndent=0;32===o;)e.lineIndent++,o=e.input.charCodeAt(++e.position)}return-1!==n&&0!==a&&e.lineIndent<n&&h(e,"deficient indentation"),a}function T(e){var t,n=e.position;return t=e.input.charCodeAt(n),45!==t&&46!==t||e.input.charCodeAt(n+1)!==t||e.input.charCodeAt(n+2)!==t||(n+=3,t=e.input.charCodeAt(n),0!==t&&!a(t))?!1:!0}function E(e,t,n){1===n?t.value+=" ":n>1&&(t.value+=V.repeat("\n",n-1))}function b(e,t,n){var s,u,l,p,c,f,m,d,h,v=e.kind,g=e.result,A=K.newScalar();if(A.plainScalar=!0,e.result=A,h=e.input.charCodeAt(e.position),a(h)||o(h)||35===h||38===h||42===h||33===h||124===h||62===h||39===h||34===h||37===h||64===h||96===h)return!1;if((63===h||45===h)&&(u=e.input.charCodeAt(e.position+1),a(u)||n&&o(u)))return!1;for(e.kind="scalar",l=p=e.position,c=!1;0!==h;){if(58===h){if(u=e.input.charCodeAt(e.position+1),a(u)||n&&o(u))break}else if(35===h){if(s=e.input.charCodeAt(e.position-1),a(s))break}else{if(e.position===e.lineStart&&T(e)||n&&o(h))break;if(r(h)){if(f=e.line,m=e.lineStart,d=e.lineIndent,S(e,!1,-1),e.lineIndent>=t){c=!0,h=e.input.charCodeAt(e.position);continue}e.position=p,e.line=f,e.lineStart=m,e.lineIndent=d;break}}if(c&&(y(e,l,p,!1),E(e,A,e.line-f),l=p=e.position,c=!1),i(h)||(p=e.position+1),h=e.input.charCodeAt(++e.position),e.position>=e.input.length)return!1}return y(e,l,p,!1),-1!=e.result.startPosition?(A.rawValue=e.input.substring(A.startPosition,A.endPosition),!0):(e.kind=v,e.result=g,!1)}function N(e,t){var n,i,a;if(n=e.input.charCodeAt(e.position),39!==n)return!1;var o=K.newScalar();for(e.kind="scalar",e.result=o,o.startPosition=e.position,e.position++,i=a=e.position;0!==(n=e.input.charCodeAt(e.position));)if(39===n){if(y(e,i,e.position,!0),n=e.input.charCodeAt(++e.position),o.endPosition=e.position,39!==n)return!0;i=a=e.position,e.position++}else r(n)?(y(e,i,a,!0),E(e,o,S(e,!1,t)),i=a=e.position):e.position===e.lineStart&&T(e)?d(e,"unexpected end of the document within a single quoted scalar"):(e.position++,a=e.position,o.endPosition=e.position);d(e,"unexpected end of the stream within a single quoted scalar")}function _(e,t){var n,i,a,o,l,p;if(p=e.input.charCodeAt(e.position),
34!==p)return!1;e.kind="scalar";var f=K.newScalar();for(f.doubleQuoted=!0,e.result=f,f.startPosition=e.position,e.position++,n=i=e.position;0!==(p=e.input.charCodeAt(e.position));){if(34===p)return y(e,n,e.position,!0),e.position++,f.endPosition=e.position,f.rawValue=e.input.substring(f.startPosition,f.endPosition),!0;if(92===p){if(y(e,n,e.position,!0),p=e.input.charCodeAt(++e.position),r(p))S(e,!1,t);else if(256>p&&(e.allowAnyEscape?se[p]:ae[p]))f.value+=e.allowAnyEscape?ue[p]:oe[p],e.position++;else if((l=u(p))>0){for(a=l,o=0;a>0;a--)p=e.input.charCodeAt(++e.position),(l=s(p))>=0?o=(o<<4)+l:d(e,"expected hexadecimal character");f.value+=c(o),e.position++}else d(e,"unknown escape sequence");n=i=e.position}else r(p)?(y(e,n,i,!0),E(e,f,S(e,!1,t)),n=i=e.position):e.position===e.lineStart&&T(e)?d(e,"unexpected end of the document within a double quoted scalar"):(e.position++,i=e.position)}d(e,"unexpected end of the stream within a double quoted scalar")}function M(e,t){var n,r,i,o,s,u,l,p,c,f,m,h=!0,y=e.tag,g=e.anchor;if(m=e.input.charCodeAt(e.position),91===m)o=93,l=!1,r=K.newItems(),r.startPosition=e.position;else{if(123!==m)return!1;o=125,l=!0,r=K.newMap(),r.startPosition=e.position}for(null!==e.anchor&&(r.anchorId=e.anchor,e.anchorMap[e.anchor]=r),m=e.input.charCodeAt(++e.position);0!==m;){if(S(e,!0,t),m=e.input.charCodeAt(e.position),m===o)return e.position++,e.tag=y,e.anchor=g,e.kind=l?"mapping":"sequence",e.result=r,r.endPosition=e.position,!0;if(!h){var A=e.position;d(e,"missed comma between flow collection entries"),e.position=A+1}if(c=p=f=null,s=u=!1,63===m&&(i=e.input.charCodeAt(e.position+1),a(i)&&(s=u=!0,e.position++,S(e,!0,t))),n=e.line,O(e,t,$,!1,!0),c=e.tag,p=e.result,S(e,!0,t),m=e.input.charCodeAt(e.position),!u&&e.line!==n||58!==m||(s=!0,m=e.input.charCodeAt(++e.position),S(e,!0,t),O(e,t,$,!1,!0),f=e.result),l)v(e,r,c,p,f);else if(s){var T=v(e,null,c,p,f);T.parent=r,r.items.push(T)}else p.parent=r,r.items.push(p);r.endPosition=e.position+1,S(e,!0,t),m=e.input.charCodeAt(e.position),44===m?(h=!0,m=e.input.charCodeAt(++e.position)):h=!1}d(e,"unexpected end of the stream within a flow collection")}function w(e,t){var n,a,o,s,u=J,p=!1,c=t,f=0,m=!1;if(s=e.input.charCodeAt(e.position),124===s)a=!1;else{if(62!==s)return!1;a=!0}var h=K.newScalar();for(e.kind="scalar",e.result=h,h.startPosition=e.position;0!==s;)if(s=e.input.charCodeAt(++e.position),43===s||45===s)J===u?u=43===s?Z:Q:d(e,"repeat of a chomping mode identifier");else{if(!((o=l(s))>=0))break;0===o?d(e,"bad explicit indentation width of a block scalar; it cannot be less than one"):p?d(e,"repeat of an indentation width identifier"):(c=t+o-1,p=!0)}if(i(s)){do s=e.input.charCodeAt(++e.position);while(i(s));if(35===s)do s=e.input.charCodeAt(++e.position);while(!r(s)&&0!==s)}for(;0!==s;){for(g(e),e.lineIndent=0,s=e.input.charCodeAt(e.position);(!p||e.lineIndent<c)&&32===s;)e.lineIndent++,s=e.input.charCodeAt(++e.position);if(!p&&e.lineIndent>c&&(c=e.lineIndent),r(s))f++;else{if(e.lineIndent<c){u===Z?h.value+=V.repeat("\n",f):u===J&&p&&(h.value+="\n");break}for(a?i(s)?(m=!0,h.value+=V.repeat("\n",f+1)):m?(m=!1,h.value+=V.repeat("\n",f+1)):0===f?p&&(h.value+=" "):h.value+=V.repeat("\n",f):p&&(h.value+=V.repeat("\n",f+1)),p=!0,f=0,n=e.position;!r(s)&&0!==s;)s=e.input.charCodeAt(++e.position);y(e,n,e.position,!1)}}h.endPosition=e.position;for(var v=e.position-1,A=!1;;){var S=e.input[v];if("\r"==S||"\n"==S){A&&v--;break}if(" "!=S&&"	"!=S)break;v--}return h.endPosition=v,h.rawValue=e.input.substring(h.startPosition,h.endPosition),!0}function R(e,t){var n,r,i,o=e.tag,s=e.anchor,u=K.newItems(),l=!1;for(null!==e.anchor&&(u.anchorId=e.anchor,e.anchorMap[e.anchor]=u),u.startPosition=e.position,i=e.input.charCodeAt(e.position);0!==i&&45===i&&(r=e.input.charCodeAt(e.position+1),a(r));)if(l=!0,e.position++,S(e,!0,-1)&&e.lineIndent<=t)u.items.push(null),i=e.input.charCodeAt(e.position);else if(n=e.line,O(e,t,X,!1,!0),e.result.parent=u,u.items.push(e.result),S(e,!0,-1),i=e.input.charCodeAt(e.position),(e.line===n||e.lineIndent>t)&&0!==i)d(e,"bad indentation of a sequence entry");else if(e.lineIndent<t)break;return u.endPosition=e.position,l?(e.tag=o,e.anchor=s,e.kind="sequence",e.result=u,u.endPosition=e.position,!0):!1}function I(e,t,n){var o,s,u,l,p=e.tag,c=e.anchor,f=K.newMap(),m=null,h=null,y=null,g=!1,A=!1;for(f.startPosition=e.position,null!==e.anchor&&(f.anchorId=e.anchor,e.anchorMap[e.anchor]=f),l=e.input.charCodeAt(e.position);0!==l;){if(o=e.input.charCodeAt(e.position+1),u=e.line,63!==l&&58!==l||!a(o)){if(!O(e,n,G,!1,!0))break;if(e.line===u){for(l=e.input.charCodeAt(e.position);i(l);)l=e.input.charCodeAt(++e.position);if(58===l)l=e.input.charCodeAt(++e.position),a(l)||d(e,"a whitespace character is expected after the key-value separator within a block mapping"),g&&(v(e,f,m,h,null),m=h=y=null),A=!0,g=!1,s=!1,m=e.tag,h=e.result;else{if(!A)return e.tag=p,e.anchor=c,!0;d(e,"can not read an implicit mapping pair; a colon is missed")}}else{if(!A)return e.tag=p,e.anchor=c,!0;for(d(e,"can not read a block mapping entry; a multiline key may not be an implicit key");e.position>0;)if(l=e.input.charCodeAt(--e.position),r(l)){e.position++;break}}}else 63===l?(g&&(v(e,f,m,h,null),m=h=y=null),A=!0,g=!0,s=!0):g?(g=!1,s=!0):d(e,"incomplete explicit mapping pair; a key node is missed"),e.position+=1,l=o;if((e.line===u||e.lineIndent>t)&&(O(e,t,z,!0,s)&&(g?h=e.result:y=e.result),g||(v(e,f,m,h,y),m=h=y=null),S(e,!0,-1),l=e.input.charCodeAt(e.position)),e.lineIndent>t&&0!==l)d(e,"bad indentation of a mapping entry");else if(e.lineIndent<t)break}return g&&v(e,f,m,h,null),A&&(e.tag=p,e.anchor=c,e.kind="mapping",e.result=f),A}function C(e){var t,n,r,i,o=!1,s=!1;if(i=e.input.charCodeAt(e.position),33!==i)return!1;if(null!==e.tag&&d(e,"duplication of a tag property"),i=e.input.charCodeAt(++e.position),60===i?(o=!0,i=e.input.charCodeAt(++e.position)):33===i?(s=!0,n="!!",i=e.input.charCodeAt(++e.position)):n="!",t=e.position,o){do i=e.input.charCodeAt(++e.position);while(0!==i&&62!==i);e.position<e.length?(r=e.input.slice(t,e.position),i=e.input.charCodeAt(++e.position)):d(e,"unexpected end of the stream within a verbatim tag")}else{for(;0!==i&&!a(i);)33===i&&(s?d(e,"tag suffix cannot contain exclamation marks"):(n=e.input.slice(t-1,e.position+1),re.test(n)||d(e,"named tag handle cannot contain such characters"),s=!0,t=e.position+1)),i=e.input.charCodeAt(++e.position);r=e.input.slice(t,e.position),ne.test(r)&&d(e,"tag suffix cannot contain flow indicator characters")}return r&&!ie.test(r)&&d(e,"tag name cannot contain such characters: "+r),o?e.tag=r:H.call(e.tagMap,n)?e.tag=e.tagMap[n]+r:"!"===n?e.tag="!"+r:"!!"===n?e.tag="tag:yaml.org,2002:"+r:d(e,'undeclared tag handle "'+n+'"'),!0}function L(e){var t,n;if(n=e.input.charCodeAt(e.position),38!==n)return!1;for(null!==e.anchor&&d(e,"duplication of an anchor property"),n=e.input.charCodeAt(++e.position),t=e.position;0!==n&&!a(n)&&!o(n);)n=e.input.charCodeAt(++e.position);return e.position===t&&d(e,"name of an anchor node must contain at least one character"),e.anchor=e.input.slice(t,e.position),!0}function P(e){var t,n,r;e.length,e.input;if(r=e.input.charCodeAt(e.position),42!==r)return!1;for(r=e.input.charCodeAt(++e.position),t=e.position;0!==r&&!a(r)&&!o(r);)r=e.input.charCodeAt(++e.position);return e.position<=t&&(d(e,"name of an alias node must contain at least one character"),e.position=t+1),n=e.input.slice(t,e.position),e.anchorMap.hasOwnProperty(n)||(d(e,'unidentified alias "'+n+'"'),e.position<=t&&(e.position=t+1)),e.result=K.newAnchorRef(n,t,e.position,e.anchorMap[n]),S(e,!0,-1),!0}function O(e,t,n,r,i){var a,o,s,u,l,p,c,f,m=1,y=!1,v=!1;if(e.tag=null,e.anchor=null,e.kind=null,e.result=null,a=o=s=z===n||X===n,r&&S(e,!0,-1)&&(y=!0,e.lineIndent>t?m=1:e.lineIndent===t?m=0:e.lineIndent<t&&(m=-1)),1===m)for(;C(e)||L(e);)S(e,!0,-1)?(y=!0,s=a,e.lineIndent>t?m=1:e.lineIndent===t?m=0:e.lineIndent<t&&(m=-1)):s=!1;if(s&&(s=y||i),(1===m||z===n)&&(c=$===n||G===n?t:t+1,f=e.position-e.lineStart,1===m?s&&(R(e,f)||I(e,f,c))||M(e,c)?v=!0:(o&&w(e,c)||N(e,c)||_(e,c)?v=!0:P(e)?(v=!0,(null!==e.tag||null!==e.anchor)&&d(e,"alias node should not have any properties")):b(e,c,$===n)&&(v=!0,null===e.tag&&(e.tag="?")),null!==e.anchor&&(e.anchorMap[e.anchor]=e.result,e.result.anchorId=e.anchor)):0===m&&(v=s&&R(e,f))),null!==e.tag&&"!"!==e.tag)if("!include"==e.tag)e.result||(e.result=K.newScalar(),e.result.startPosition=e.position,e.result.endPosition=e.position,d(e,"!include without value")),e.result.kind=K.Kind.INCLUDE_REF;else if("?"===e.tag)for(u=0,l=e.implicitTypes.length;l>u;u+=1){p=e.implicitTypes[u];var g=e.result.value;if(p.resolve(g)){e.result.valueObject=p.construct(e.result.value),e.tag=p.tag,null!==e.anchor&&(e.result.anchorId=e.anchor,e.anchorMap[e.anchor]=e.result);break}}else H.call(e.typeMap,e.tag)?(p=e.typeMap[e.tag],null!==e.result&&p.kind!==e.kind&&d(e,"unacceptable node kind for !<"+e.tag+'> tag; it should be "'+p.kind+'", not "'+e.kind+'"'),p.resolve(e.result)?(e.result=p.construct(e.result),null!==e.anchor&&(e.result.anchorId=e.anchor,e.anchorMap[e.anchor]=e.result)):d(e,"cannot resolve a node with !<"+e.tag+"> explicit tag")):h(e,"unknown tag !<"+e.tag+">");return null!==e.tag||null!==e.anchor||v}function D(e){var t,n,o,s,u=e.position,l=!1;for(e.version=null,e.checkLineBreaks=e.legacy,e.tagMap={},e.anchorMap={};0!==(s=e.input.charCodeAt(e.position))&&(S(e,!0,-1),s=e.input.charCodeAt(e.position),!(e.lineIndent>0||37!==s));){for(l=!0,s=e.input.charCodeAt(++e.position),t=e.position;0!==s&&!a(s);)s=e.input.charCodeAt(++e.position);for(n=e.input.slice(t,e.position),o=[],n.length<1&&d(e,"directive name must not be less than one character in length");0!==s;){for(;i(s);)s=e.input.charCodeAt(++e.position);if(35===s){do s=e.input.charCodeAt(++e.position);while(0!==s&&!r(s));break}if(r(s))break;for(t=e.position;0!==s&&!a(s);)s=e.input.charCodeAt(++e.position);o.push(e.input.slice(t,e.position))}0!==s&&g(e),H.call(ce,n)?ce[n](e,n,o):(h(e,'unknown document directive "'+n+'"'),e.position++)}return S(e,!0,-1),0===e.lineIndent&&45===e.input.charCodeAt(e.position)&&45===e.input.charCodeAt(e.position+1)&&45===e.input.charCodeAt(e.position+2)?(e.position+=3,S(e,!0,-1)):l&&d(e,"directives end mark is expected"),O(e,e.lineIndent-1,z,!1,!0),S(e,!0,-1),e.checkLineBreaks&&te.test(e.input.slice(u,e.position))&&h(e,"non-ASCII line breaks are interpreted as content"),e.documents.push(e.result),e.position===e.lineStart&&T(e)?void(46===e.input.charCodeAt(e.position)&&(e.position+=3,S(e,!0,-1))):void(e.position<e.length-1&&d(e,"end of the stream or a document separator is expected"))}function x(e,t){e=String(e),t=t||{},0!==e.length&&(10!==e.charCodeAt(e.length-1)&&13!==e.charCodeAt(e.length-1)&&(e+="\n"),65279===e.charCodeAt(0)&&(e=e.slice(1)));var n=new pe(e,t);for(ee.test(n.input)&&d(n,"the stream contains non-printable characters"),n.input+="\x00";32===n.input.charCodeAt(n.position);)n.lineIndent+=1,n.position+=1;for(;n.position<n.length-1;){var r=n.position;if(D(n),n.position<=r)for(;n.position<n.length-1;n.position++){var i=n.input.charAt(n.position);if("\n"==i)break}}return n.documents.forEach(function(e){return e.errors=n.errors}),n.documents}function U(e,t,n){var r,i,a=x(e,n);for(r=0,i=a.length;i>r;r+=1)t(a[r])}function k(e,t){var n=x(e,t);if(0===n.length)return void 0;if(1===n.length){var r=n[0];return r.endPosition=e.length,r.startPosition>r.endPosition&&(r.startPosition=r.endPosition),r}var i=new j("expected a single document in the stream, but found more");return i.mark=new W("","",0,0,0),i.mark.position=n[0].endPosition,n[0].errors.push(i),n[0]}function F(e,t,n){U(e,t,V.extend({schema:q},n))}function B(e,t){return k(e,V.extend({schema:q},t))}for(var K=n(114),V=n(115),j=n(116),W=n(117),q=n(134),Y=n(135),H=Object.prototype.hasOwnProperty,$=1,G=2,X=3,z=4,J=1,Q=2,Z=3,ee=/[\x00-\x08\x0B\x0C\x0E-\x1F\x7F-\x84\x86-\x9F\uD800-\uDFFF\uFFFE\uFFFF]/,te=/[\x85\u2028\u2029]/,ne=/[,\[\]\{\}]/,re=/^(?:!|!!|![a-z\-]+!)$/i,ie=/^(?:!|[^,\[\]\{\}])(?:%[0-9a-f]{2}|[0-9a-z\-#;\/\?:@&=\+\$,_\.!~\*'\(\)\[\]])*$/i,ae=new Array(256),oe=new Array(256),se=new Array(256),ue=new Array(256),le=0;256>le;le++)ue[le]=oe[le]=p(le),ae[le]=oe[le]?1:0,se[le]=1,ae[le]||(ue[le]="\\"+String.fromCharCode(le));var pe=function(){function e(e,t){this.errorMap={},this.errors=[],this.lines=[],this.input=e,this.filename=t.filename||null,this.schema=t.schema||Y,this.onWarning=t.onWarning||null,this.legacy=t.legacy||!1,this.allowAnyEscape=t.allowAnyEscape||!1,this.ignoreDuplicateKeys=t.ignoreDuplicateKeys||!1,this.implicitTypes=this.schema.compiledImplicit,this.typeMap=this.schema.compiledTypeMap,this.length=e.length,this.position=0,this.line=0,this.lineStart=0,this.lineIndent=0,this.documents=[]}return e}(),ce={YAML:function(e,t,n){var r,i,a;null!==e.version&&d(e,"duplication of %YAML directive"),1!==n.length&&d(e,"YAML directive accepts exactly one argument"),r=/^([0-9]+)\.([0-9]+)$/.exec(n[0]),null===r&&d(e,"ill-formed argument of the YAML directive"),i=parseInt(r[1],10),a=parseInt(r[2],10),1!==i&&d(e,"found incompatible YAML document (version 1.2 is required)"),e.version=n[0],e.checkLineBreaks=2>a,2!==a&&d(e,"found incompatible YAML document (version 1.2 is required)")},TAG:function(e,t,n){var r,i;2!==n.length&&d(e,"TAG directive accepts exactly two arguments"),r=n[0],i=n[1],re.test(r)||d(e,"ill-formed tag handle (first argument) of the TAG directive"),H.call(e.tagMap,r)&&d(e,'there is a previously declared suffix for "'+r+'" tag handle'),ie.test(i)||d(e,"ill-formed tag prefix (second argument) of the TAG directive"),e.tagMap[r]=i}};(function(){function e(){}return e})();t.loadAll=U,t.load=k,t.safeLoadAll=F,t.safeLoad=B,e.exports.loadAll=U,e.exports.load=k,e.exports.safeLoadAll=F,e.exports.safeLoad=B},function(e,t,n){"use strict";function r(e,t){var n,r,i,a,o,s,u;if(null===t)return{};for(n={},r=Object.keys(t),i=0,a=r.length;a>i;i+=1)o=r[i],s=String(t[o]),"!!"===o.slice(0,2)&&(o="tag:yaml.org,2002:"+o.slice(2)),u=e.compiledTypeMap[o],u&&C.call(u.styleAliases,s)&&(s=u.styleAliases[s]),n[o]=s;return n}function i(e){var t,n,r;if(t=e.toString(16).toUpperCase(),255>=e)n="x",r=2;else if(65535>=e)n="u",r=4;else{if(!(4294967295>=e))throw new M("code point within a string may not be greater than 0xFFFFFFFF");n="U",r=8}return"\\"+n+_.repeat("0",r-t.length)+t}function a(e){this.schema=e.schema||w,this.indent=Math.max(1,e.indent||2),this.skipInvalid=e.skipInvalid||!1,this.flowLevel=_.isNothing(e.flowLevel)?-1:e.flowLevel,this.styleMap=r(this.schema,e.styles||null),this.implicitTypes=this.schema.compiledImplicit,this.explicitTypes=this.schema.compiledExplicit,this.tag=null,this.result="",this.duplicates=[],this.usedDuplicates=null}function o(e,t){for(var n,r=_.repeat(" ",t),i=0,a=-1,o="",s=e.length;s>i;)a=e.indexOf("\n",i),-1===a?(n=e.slice(i),i=s):(n=e.slice(i,a+1),i=a+1),n.length&&"\n"!==n&&(o+=r),o+=n;return o}function s(e,t){return"\n"+_.repeat(" ",e.indent*t)}function u(e,t){var n,r,i;for(n=0,r=e.implicitTypes.length;r>n;n+=1)if(i=e.implicitTypes[n],i.resolve(t))return!0;return!1}function l(e){this.source=e,this.result="",this.checkpoint=0}function p(e,t,n){var r,i,a,s,p,f,h,y,v,g,A,S,T,E,b,N,_,M,w,R,I;if(0===t.length)return void(e.dump="''");if(0==t.indexOf("!include"))return void(e.dump=""+t);if(0==t.indexOf("!$$$novalue"))return void(e.dump="");if(-1!==te.indexOf(t))return void(e.dump="'"+t+"'");for(r=!0,i=t.length?t.charCodeAt(0):0,a=D===i||D===t.charCodeAt(t.length-1),(W===i||H===i||$===i||z===i)&&(r=!1),a?(r=!1,s=!1,p=!1):(s=!0,p=!0),f=!0,h=new l(t),y=!1,v=0,g=0,A=e.indent*n,S=80,40>A?S-=A:S=40,E=0;E<t.length;E++){if(T=t.charCodeAt(E),r){if(m(T))continue;r=!1}f&&T===K&&(f=!1),b=ee[T],N=d(T),(b||N)&&(T!==P&&T!==U&&T!==K?(s=!1,p=!1):T===P&&(y=!0,f=!1,E>0&&(_=t.charCodeAt(E-1),_===D&&(p=!1,s=!1)),s&&(M=E-v,v=E,M>g&&(g=M))),T!==U&&(f=!1),h.takeUpTo(E),h.escapeChar())}if(r&&u(e,t)&&(r=!1),w="",(s||p)&&(R=0,t.charCodeAt(t.length-1)===P&&(R+=1,t.charCodeAt(t.length-2)===P&&(R+=1)),0===R?w="-":2===R&&(w="+")),p&&S>g&&(s=!1),y||(p=!1),r)e.dump=t;else if(f)e.dump="'"+t+"'";else if(s)I=c(t,S),e.dump=">"+w+"\n"+o(I,A);else if(p)w||(t=t.replace(/\n$/,"")),e.dump="|"+w+"\n"+o(t,A);else{if(!h)throw new Error("Failed to dump scalar value");h.finish(),e.dump='"'+h.result+'"'}}function c(e,t){var n,r="",i=0,a=e.length,o=/\n+$/.exec(e);for(o&&(a=o.index+1);a>i;)n=e.indexOf("\n",i),n>a||-1===n?(r&&(r+="\n\n"),r+=f(e.slice(i,a),t),i=a):(r&&(r+="\n\n"),r+=f(e.slice(i,n),t),i=n+1);return o&&"\n"!==o[0]&&(r+=o[0]),r}function f(e,t){if(""===e)return e;for(var n,r,i,a=/[^\s] [^\s]/g,o="",s=0,u=0,l=a.exec(e);l;)n=l.index,n-u>t&&(r=s!==u?s:n,o&&(o+="\n"),i=e.slice(u,r),o+=i,u=r+1),s=n+1,l=a.exec(e);return o&&(o+="\n"),o+=u!==s&&e.length-u>t?e.slice(u,s)+"\n"+e.slice(s+1):e.slice(u)}function m(e){return L!==e&&P!==e&&O!==e&&j!==e&&G!==e&&X!==e&&J!==e&&Z!==e&&k!==e&&B!==e&&V!==e&&x!==e&&Q!==e&&Y!==e&&K!==e&&U!==e&&F!==e&&q!==e&&!ee[e]&&!d(e)}function d(e){return!(e>=32&&126>=e||133===e||e>=160&&55295>=e||e>=57344&&65533>=e||e>=65536&&1114111>=e)}function h(e,t,n){var r,i,a="",o=e.tag;for(r=0,i=n.length;i>r;r+=1)S(e,t,n[r],!1,!1)&&(0!==r&&(a+=", "),a+=e.dump);e.tag=o,e.dump="["+a+"]"}function y(e,t,n,r){var i,a,o="",u=e.tag;for(i=0,a=n.length;a>i;i+=1)S(e,t+1,n[i],!0,!0)&&(r&&0===i||(o+=s(e,t)),o+="- "+e.dump);e.tag=u,e.dump=o||"[]"}function v(e,t,n){var r,i,a,o,s,u="",l=e.tag,p=Object.keys(n);for(r=0,i=p.length;i>r;r+=1)s="",0!==r&&(s+=", "),a=p[r],o=n[a],S(e,t,a,!1,!1)&&(e.dump.length>1024&&(s+="? "),s+=e.dump+": ",S(e,t,o,!1,!1)&&(s+=e.dump,u+=s));e.tag=l,e.dump="{"+u+"}"}function g(e,t,n,r){var i,a,o,u,l,p,c="",f=e.tag,m=Object.keys(n);for(i=0,a=m.length;a>i;i+=1)p="",r&&0===i||(p+=s(e,t)),o=m[i],u=n[o],S(e,t+1,o,!0,!0)&&(l=null!==e.tag&&"?"!==e.tag||e.dump&&e.dump.length>1024,l&&(p+=e.dump&&P===e.dump.charCodeAt(0)?"?":"? "),p+=e.dump,l&&(p+=s(e,t)),S(e,t+1,u,!0,l)&&(p+=e.dump&&P===e.dump.charCodeAt(0)?":":": ",p+=e.dump,c+=p));e.tag=f,e.dump=c||"{}"}function A(e,t,n){var r,i,a,o,s,u;for(i=n?e.explicitTypes:e.implicitTypes,a=0,o=i.length;o>a;a+=1)if(s=i[a],(s.instanceOf||s.predicate)&&(!s.instanceOf||"object"==typeof t&&t instanceof s.instanceOf)&&(!s.predicate||s.predicate(t))){if(e.tag=n?s.tag:"?",s.represent){if(u=e.styleMap[s.tag]||s.defaultStyle,"[object Function]"===I.call(s.represent))r=s.represent(t,u);else{if(!C.call(s.represent,u))throw new M("!<"+s.tag+'> tag resolver accepts not "'+u+'" style');r=s.represent[u](t,u)}e.dump=r}return!0}return!1}function S(e,t,n,r,i){e.tag=null,e.dump=n,A(e,n,!1)||A(e,n,!0);var a=I.call(e.dump);r&&(r=0>e.flowLevel||e.flowLevel>t),(null!==e.tag&&"?"!==e.tag||2!==e.indent&&t>0)&&(i=!1);var o,s,u="[object Object]"===a||"[object Array]"===a;if(u&&(o=e.duplicates.indexOf(n),s=-1!==o),s&&e.usedDuplicates[o])e.dump="*ref_"+o;else{if(u&&s&&!e.usedDuplicates[o]&&(e.usedDuplicates[o]=!0),"[object Object]"===a)r&&0!==Object.keys(e.dump).length?(g(e,t,e.dump,i),s&&(e.dump="&ref_"+o+(0===t?"\n":"")+e.dump)):(v(e,t,e.dump),s&&(e.dump="&ref_"+o+" "+e.dump));else if("[object Array]"===a)r&&0!==e.dump.length?(y(e,t,e.dump,i),s&&(e.dump="&ref_"+o+(0===t?"\n":"")+e.dump)):(h(e,t,e.dump),s&&(e.dump="&ref_"+o+" "+e.dump));else{if("[object String]"!==a){if(e.skipInvalid)return!1;throw new M("unacceptable kind of an object to dump "+a)}"?"!==e.tag&&p(e,e.dump,t)}null!==e.tag&&"?"!==e.tag&&(e.dump="!<"+e.tag+"> "+e.dump)}return!0}function T(e,t){var n,r,i=[],a=[];for(E(e,i,a),n=0,r=a.length;r>n;n+=1)t.duplicates.push(i[a[n]]);t.usedDuplicates=new Array(r)}function E(e,t,n){var r,i,a;I.call(e);if(null!==e&&"object"==typeof e)if(i=t.indexOf(e),-1!==i)-1===n.indexOf(i)&&n.push(i);else if(t.push(e),Array.isArray(e))for(i=0,a=e.length;a>i;i+=1)E(e[i],t,n);else for(r=Object.keys(e),i=0,a=r.length;a>i;i+=1)E(e[r[i]],t,n)}function b(e,t){t=t||{};var n=new a(t);return T(e,n),S(n,0,e,!0,!0)?n.dump+"\n":""}function N(e,t){return b(e,_.extend({schema:R},t))}var _=n(115),M=n(116),w=n(135),R=n(134),I=Object.prototype.toString,C=Object.prototype.hasOwnProperty,L=9,P=10,O=13,D=32,x=33,U=34,k=35,F=37,B=38,K=39,V=42,j=44,W=45,q=58,Y=62,H=63,$=64,G=91,X=93,z=96,J=123,Q=124,Z=125,ee={};ee[0]="\\0",ee[7]="\\a",ee[8]="\\b",ee[9]="\\t",ee[10]="\\n",ee[11]="\\v",ee[12]="\\f",ee[13]="\\r",ee[27]="\\e",ee[34]='\\"',ee[92]="\\\\",ee[133]="\\N",ee[160]="\\_",ee[8232]="\\L",ee[8233]="\\P";var te=["y","Y","yes","Yes","YES","on","On","ON","n","N","no","No","NO","off","Off","OFF"];l.prototype.takeUpTo=function(e){var t;if(e<this.checkpoint)throw t=new Error("position should be > checkpoint"),t.position=e,t.checkpoint=this.checkpoint,t;return this.result+=this.source.slice(this.checkpoint,e),this.checkpoint=e,this},l.prototype.escapeChar=function(){var e,t;return e=this.source.charCodeAt(this.checkpoint),t=ee[e]||i(e),this.result+=t,this.checkpoint+=1,this},l.prototype.finish=function(){this.source.length>this.checkpoint&&this.takeUpTo(this.source.length)},t.dump=b,t.safeDump=N},function(e,t,n){e.exports=[{classes:[{name:"GlobalSchema",methods:[],typeParameters:[],typeParameterConstraint:[],"implements":[{typeName:"Referencable",nameSpace:"",basicName:"Referencable",typeKind:0,typeArguments:[{typeName:"Sys.SchemaString",nameSpace:"Sys",basicName:"SchemaString",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/api.ts"}],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/api.ts"}],fields:[{name:"key",type:{typeName:"string",nameSpace:"",basicName:"string",typeKind:0,typeArguments:[],modulePath:null},annotations:[{name:"MetaModel.key",arguments:[]},{name:"MetaModel.description",arguments:["Name of the global schema, used to refer on schema content"]}],valueConstraint:null,optional:!1},{name:"value",type:{typeName:"Sys.SchemaString",nameSpace:"Sys",basicName:"SchemaString",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/api.ts"},annotations:[{name:"MetaModel.description",arguments:["Content of the schema"]},{name:"MetaModel.value",arguments:[]}],valueConstraint:null,optional:!1}],isInterface:!1,annotations:[{name:"MetaModel.actuallyExports",arguments:["value"]},{name:"MetaModel.description",arguments:["Content of the schema"]}],"extends":[{typeName:"RAMLSimpleElement",nameSpace:"",basicName:"RAMLSimpleElement",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/api.ts"}],moduleName:"RAMLSpec",annotationOverridings:{}},{name:"Api",methods:[],typeParameters:[],typeParameterConstraint:[],"implements":[],fields:[{name:"title",type:{typeName:"string",nameSpace:"",basicName:"string",typeKind:0,typeArguments:[],modulePath:null},annotations:[{name:"MetaModel.required",arguments:[]},{name:"MetaModel.description",arguments:["The title property is a short plain text description of the RESTful API. The value SHOULD be suitable for use as a title for the contained user documentation."]}],valueConstraint:null,optional:!1},{name:"version",type:{typeName:"string",nameSpace:"",basicName:"string",typeKind:0,typeArguments:[],modulePath:null},annotations:[{name:"MetaModel.description",arguments:["If the RAML API definition is targeted to a specific API version, the API definition MUST contain a version property. The version property is OPTIONAL and should not be used if: The API itself is not versioned. The API definition does not change between versions. The API architect can decide whether a change to user documentation elements, but no change to the API's resources, constitutes a version change. The API architect MAY use any versioning scheme so long as version numbers retain the same format. For example, 'v3', 'v3.0', and 'V3' are all allowed, but are not considered to be equal."]}],valueConstraint:null,optional:!1},{name:"baseUri",type:{typeName:"Sys.FullUriTemplateString",nameSpace:"Sys",basicName:"FullUriTemplateString",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/api.ts"},annotations:[{name:"MetaModel.description",arguments:["(Optional during development; Required after implementation) A RESTful API's resources are defined relative to the API's base URI. The use of the baseUri field is OPTIONAL to allow describing APIs that have not yet been implemented. After the API is implemented (even a mock implementation) and can be accessed at a service endpoint, the API definition MUST contain a baseUri property. The baseUri property's value MUST conform to the URI specification RFC2396 or a Level 1 Template URI as defined in RFC6570. The baseUri property SHOULD only be used as a reference value."]}],valueConstraint:null,optional:!1},{name:"baseUriParameters",type:{base:{typeName:"Params.Parameter",nameSpace:"Params",basicName:"Parameter",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/api.ts"},typeKind:1},annotations:[{name:"MetaModel.setsContextValue",arguments:["location","Params.ParameterLocation.BURI"]},{name:"MetaModel.description",arguments:["Base uri parameters are named parameters which described template parameters in the base uri"]}],valueConstraint:null,optional:!1},{name:"uriParameters",type:{base:{typeName:"Params.Parameter",nameSpace:"Params",basicName:"Parameter",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/api.ts"},typeKind:1},annotations:[{name:"MetaModel.setsContextValue",arguments:["location","Params.ParameterLocation.BURI"]},{name:"MetaModel.description",arguments:["URI parameters can be further defined by using the uriParameters property. The use of uriParameters is OPTIONAL. The uriParameters property MUST be a map in which each key MUST be the name of the URI parameter as defined in the baseUri property. The uriParameters CANNOT contain a key named version because it is a reserved URI parameter name. The value of the uriParameters property is itself a map that specifies  the property's attributes as named parameters"]}],valueConstraint:null,optional:!1},{name:"protocols",type:{base:{typeName:"string",nameSpace:"",basicName:"string",typeKind:0,typeArguments:[],modulePath:null},typeKind:1},annotations:[{name:"MetaModel.oneOf",arguments:[["HTTP","HTTPS"]]},{name:"MetaModel.description",arguments:["A RESTful API can be reached HTTP, HTTPS, or both. The protocols property MAY be used to specify the protocols that an API supports. If the protocols property is not specified, the protocol specified at the baseUri property is used. The protocols property MUST be an array of strings, of values `HTTP` and/or `HTTPS`."]}],valueConstraint:null,optional:!1},{name:"mediaType",type:{typeName:"Bodies.MimeType",nameSpace:"Bodies",basicName:"MimeType",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/api.ts"},annotations:[{name:"MetaModel.oftenKeys",arguments:[["application/json","application/xml","application/x-www-form-urlencoded","multipart/formdata"]]},{name:"MetaModel.description",arguments:["(Optional) The media types returned by API responses, and expected from API requests that accept a body, MAY be defaulted by specifying the mediaType property. This property is specified at the root level of the API definition. The property's value MAY be a single string with a valid media type described in the specification."]},{name:"MetaModel.inherited",arguments:[]}],valueConstraint:null,optional:!1},{name:"schemas",type:{base:{typeName:"GlobalSchema",nameSpace:"",basicName:"GlobalSchema",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/api.ts"},typeKind:1},annotations:[{name:"MetaModel.embeddedInMaps",arguments:[]},{name:"MetaModel.description",arguments:["To better achieve consistency and simplicity, the API definition SHOULD include an OPTIONAL schemas property in the root section. The schemas property specifies collections of schemas that could be used anywhere in the API definition. The value of the schemas property is an array of maps; in each map, the keys are the schema name, and the values are schema definitions. The schema definitions MAY be included inline or by using the RAML !include user-defined data type."]}],valueConstraint:null,optional:!1},{name:"traits",type:{base:{typeName:"Methods.Trait",nameSpace:"Methods",basicName:"Trait",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/api.ts"},typeKind:1},annotations:[{name:"MetaModel.embeddedInMaps",arguments:[]},{name:"MetaModel.description",arguments:["Declarations of traits used in this API"]}],valueConstraint:null,optional:!1},{name:"securedBy",type:{base:{typeName:"Security.SecuritySchemeRef",nameSpace:"Security",basicName:"SecuritySchemeRef",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/api.ts"},typeKind:1},annotations:[{name:"MetaModel.allowNull",arguments:[]},{name:"MetaModel.description",arguments:["A list of the security schemes to apply to all methods, these must be defined in the securitySchemes declaration."]}],valueConstraint:null,optional:!1},{name:"securitySchemes",type:{base:{typeName:"Security.AbstractSecurityScheme",nameSpace:"Security",basicName:"AbstractSecurityScheme",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/api.ts"},typeKind:1},annotations:[{name:"MetaModel.embeddedInMaps",arguments:[]},{name:"MetaModel.description",arguments:["Security schemes that can be applied using securedBy"]}],valueConstraint:null,optional:!1},{name:"resourceTypes",type:{base:{typeName:"Resources.ResourceType",nameSpace:"Resources",basicName:"ResourceType",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/api.ts"},typeKind:1},annotations:[{name:"MetaModel.embeddedInMaps",arguments:[]},{name:"MetaModel.description",arguments:["Declaration of resource types used in this API"]}],valueConstraint:null,optional:!1},{name:"resources",type:{base:{typeName:"Resources.Resource",nameSpace:"Resources",basicName:"Resource",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/api.ts"},typeKind:1},annotations:[{name:"MetaModel.newInstanceName",arguments:["New Resource"]},{name:"MetaModel.description",arguments:["Resources are identified by their relative URI, which MUST begin with a slash (/). A resource defined as a root-level property is called a top-level resource. Its property's key is the resource's URI relative to the baseUri. A resource defined as a child property of another resource is called a nested resource, and its property's key is its URI relative to its parent resource's URI. Every property whose key begins with a slash (/), and is either at the root of the API definition or is the child property of a resource property, is a resource property. The key of a resource, i.e. its relative URI, MAY consist of multiple URI path fragments separated by slashes; e.g. `/bom/items` may indicate the collection of items in a bill of materials as a single resource. However, if the individual URI path fragments are themselves resources, the API definition SHOULD use nested resources to describe this structure; e.g. if `/bom` is itself a resource then `/items` should be a nested resource of `/bom`, while `/bom/items` should not be used."]}],valueConstraint:null,optional:!1},{name:"documentation",type:{base:{typeName:"DocumentationItem",nameSpace:"",basicName:"DocumentationItem",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/api.ts"
},typeKind:1},annotations:[{name:"MetaModel.description",arguments:["The API definition can include a variety of documents that serve as a user guides and reference documentation for the API. Such documents can clarify how the API works or provide business context. Documentation-generators MUST include all the sections in an API definition's documentation property in the documentation output, and they MUST preserve the order in which the documentation is declared. To add user documentation to the API, include the documentation property at the root of the API definition. The documentation property MUST be an array of documents. Each document MUST contain title and content attributes, both of which are REQUIRED. If the documentation property is specified, it MUST include at least one document. Documentation-generators MUST process the content field as if it was defined using Markdown."]}],valueConstraint:null,optional:!1},{name:"RAMLVersion",type:{typeName:"string",nameSpace:"",basicName:"string",typeKind:0,typeArguments:[],modulePath:null},annotations:[{name:"MetaModel.customHandling",arguments:[]},{name:"MetaModel.description",arguments:["Returns AST node of security scheme, this reference refers to, or null."]}],valueConstraint:null,optional:!1}],isInterface:!1,annotations:[],"extends":[],moduleName:"RAMLSpec",annotationOverridings:{}},{name:"DocumentationItem",methods:[],typeParameters:[],typeParameterConstraint:[],"implements":[],fields:[{name:"title",type:{typeName:"string",nameSpace:"",basicName:"string",typeKind:0,typeArguments:[],modulePath:null},annotations:[{name:"MetaModel.description",arguments:["title of documentation section"]},{name:"MetaModel.required",arguments:[]}],valueConstraint:null,optional:!1},{name:"content",type:{typeName:"Sys.MarkdownString",nameSpace:"Sys",basicName:"MarkdownString",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/api.ts"},annotations:[{name:"MetaModel.description",arguments:["Content of documentation section"]},{name:"MetaModel.required",arguments:[]}],valueConstraint:null,optional:!1}],isInterface:!1,annotations:[],"extends":[{typeName:"RAMLSimpleElement",nameSpace:"",basicName:"RAMLSimpleElement",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/api.ts"}],moduleName:"RAMLSpec",annotationOverridings:{}}],aliases:[],enumDeclarations:[],imports:{MetaModel:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/metamodel.ts",Sys:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/systemTypes.ts",Params:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/parameters.ts",Common:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/common.ts",Bodies:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/bodies.ts",Resources:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/resources.ts",Methods:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/methods.ts",Security:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/security.ts"},name:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/api.ts"},{classes:[{name:"SpecPartMetaData",methods:[],typeParameters:[],typeParameterConstraint:[],"implements":[],fields:[],isInterface:!0,annotations:[],"extends":[],moduleName:null,annotationOverridings:{}}],aliases:[],enumDeclarations:[],imports:{},name:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/metamodel.ts"},{classes:[{name:"ValueType",methods:[],typeParameters:[],typeParameterConstraint:[],"implements":[],fields:[],isInterface:!1,annotations:[],"extends":[],moduleName:null,annotationOverridings:{}},{name:"StringType",methods:[],typeParameters:[],typeParameterConstraint:[],"implements":[],fields:[],isInterface:!1,annotations:[{name:"MetaModel.nameAtRuntime",arguments:["string"]}],"extends":[{typeName:"ValueType",nameSpace:"",basicName:"ValueType",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/systemTypes.ts"}],moduleName:null,annotationOverridings:{}},{name:"AnyType",methods:[],typeParameters:[],typeParameterConstraint:[],"implements":[],fields:[],isInterface:!1,annotations:[{name:"MetaModel.nameAtRuntime",arguments:["any"]}],"extends":[{typeName:"ValueType",nameSpace:"",basicName:"ValueType",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/systemTypes.ts"}],moduleName:null,annotationOverridings:{}},{name:"NumberType",methods:[],typeParameters:[],typeParameterConstraint:[],"implements":[],fields:[],isInterface:!1,annotations:[{name:"MetaModel.nameAtRuntime",arguments:["number"]}],"extends":[{typeName:"ValueType",nameSpace:"",basicName:"ValueType",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/systemTypes.ts"}],moduleName:null,annotationOverridings:{}},{name:"BooleanType",methods:[],typeParameters:[],typeParameterConstraint:[],"implements":[],fields:[],isInterface:!1,annotations:[{name:"MetaModel.nameAtRuntime",arguments:["boolean"]}],"extends":[{typeName:"ValueType",nameSpace:"",basicName:"ValueType",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/systemTypes.ts"}],moduleName:null,annotationOverridings:{}},{name:"Referencable",methods:[],typeParameters:["T"],typeParameterConstraint:[null],"implements":[],fields:[],isInterface:!0,annotations:[],"extends":[],moduleName:null,annotationOverridings:{}},{name:"Reference",methods:[],typeParameters:["T"],typeParameterConstraint:[null],"implements":[],fields:[{name:"structuredValue",type:{typeName:"TypeInstance",nameSpace:"",basicName:"TypeInstance",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/systemTypes.ts"},annotations:[{name:"MetaModel.customHandling",arguments:[]},{name:"MetaModel.description",arguments:["Returns a structured object if the reference point to one."]}],valueConstraint:null,optional:!1},{name:"name",type:{typeName:"string",nameSpace:"",basicName:"string",typeKind:0,typeArguments:[],modulePath:null},annotations:[{name:"MetaModel.customHandling",arguments:[]},{name:"MetaModel.description",arguments:["Returns name of referenced object"]}],valueConstraint:null,optional:!1}],isInterface:!1,annotations:[],"extends":[{typeName:"ValueType",nameSpace:"",basicName:"ValueType",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/systemTypes.ts"}],moduleName:null,annotationOverridings:{}},{name:"DeclaresDynamicType",methods:[],typeParameters:["T"],typeParameterConstraint:[null],"implements":[],fields:[],isInterface:!0,annotations:[],"extends":[{typeName:"Referencable",nameSpace:"",basicName:"Referencable",typeKind:0,typeArguments:[{typeName:"T",nameSpace:"",basicName:"T",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/systemTypes.ts"}],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/systemTypes.ts"}],moduleName:null,annotationOverridings:{}},{name:"UriTemplate",methods:[],typeParameters:[],typeParameterConstraint:[],"implements":[],fields:[],isInterface:!1,annotations:[{name:"MetaModel.description",arguments:["This type currently serves both for absolute and relative urls"]}],"extends":[{typeName:"StringType",nameSpace:"",basicName:"StringType",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/systemTypes.ts"}],moduleName:null,annotationOverridings:{}},{name:"RelativeUriString",methods:[],typeParameters:[],typeParameterConstraint:[],"implements":[],fields:[],isInterface:!1,annotations:[{name:"MetaModel.description",arguments:["This  type describes relative uri templates"]}],"extends":[{typeName:"UriTemplate",nameSpace:"",basicName:"UriTemplate",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/systemTypes.ts"}],moduleName:null,annotationOverridings:{}},{name:"FullUriTemplateString",methods:[],typeParameters:[],typeParameterConstraint:[],"implements":[],fields:[],isInterface:!1,annotations:[{name:"MetaModel.description",arguments:["This  type describes absolute uri templates"]}],"extends":[{typeName:"UriTemplate",nameSpace:"",basicName:"UriTemplate",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/systemTypes.ts"}],moduleName:null,annotationOverridings:{}},{name:"FixedUri",methods:[],typeParameters:[],typeParameterConstraint:[],"implements":[],fields:[],isInterface:!1,annotations:[{name:"MetaModel.description",arguments:["This  type describes fixed uris"]}],"extends":[{typeName:"StringType",nameSpace:"",basicName:"StringType",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/systemTypes.ts"}],moduleName:null,annotationOverridings:{}},{name:"MarkdownString",methods:[],typeParameters:[],typeParameterConstraint:[],"implements":[],fields:[],isInterface:!1,annotations:[{name:"MetaModel.innerType",arguments:["markdown"]},{name:"MetaModel.description",arguments:["Mardown string is a string which can contain markdown as an extension this markdown should support links with RAML Pointers since 1.0"]}],"extends":[{typeName:"StringType",nameSpace:"",basicName:"StringType",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/systemTypes.ts"}],moduleName:null,annotationOverridings:{}},{name:"SchemaString",methods:[],typeParameters:[],typeParameterConstraint:[],"implements":[],fields:[],isInterface:!1,annotations:[{name:"MetaModel.description",arguments:["Schema at this moment only two subtypes are supported (json schema and xsd)"]}],"extends":[{typeName:"StringType",nameSpace:"",basicName:"StringType",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/systemTypes.ts"}],moduleName:null,annotationOverridings:{}},{name:"JSonSchemaString",methods:[],typeParameters:[],typeParameterConstraint:[],"implements":[],fields:[],isInterface:!1,annotations:[{name:"MetaModel.functionalDescriminator",arguments:["this.mediaType&&this.mediaType.isJSON()"]},{name:"MetaModel.description",arguments:["JSON schema"]}],"extends":[{typeName:"SchemaString",nameSpace:"",basicName:"SchemaString",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/systemTypes.ts"}],moduleName:null,annotationOverridings:{}},{name:"XMLSchemaString",methods:[],typeParameters:[],typeParameterConstraint:[],"implements":[],fields:[],isInterface:!1,annotations:[{name:"MetaModel.innerType",arguments:["xml"]},{name:"MetaModel.description",arguments:["XSD schema"]}],"extends":[{typeName:"SchemaString",nameSpace:"",basicName:"SchemaString",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/systemTypes.ts"}],moduleName:null,annotationOverridings:{}},{name:"ExampleString",methods:[],typeParameters:[],typeParameterConstraint:[],"implements":[],fields:[],isInterface:!1,annotations:[],"extends":[{typeName:"StringType",nameSpace:"",basicName:"StringType",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/systemTypes.ts"}],moduleName:null,annotationOverridings:{}},{name:"StatusCodeString",methods:[],typeParameters:[],typeParameterConstraint:[],"implements":[],fields:[],isInterface:!1,annotations:[],"extends":[{typeName:"StringType",nameSpace:"",basicName:"StringType",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/systemTypes.ts"}],moduleName:null,annotationOverridings:{}},{name:"JSONExample",methods:[],typeParameters:[],typeParameterConstraint:[],"implements":[],fields:[],isInterface:!1,annotations:[{name:"MetaModel.functionalDescriminator",arguments:["this.mediaType.isJSON()"]}],"extends":[{typeName:"ExampleString",nameSpace:"",basicName:"ExampleString",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/systemTypes.ts"}],moduleName:null,annotationOverridings:{}},{name:"XMLExample",methods:[],typeParameters:[],typeParameterConstraint:[],"implements":[],fields:[],isInterface:!1,annotations:[{name:"MetaModel.functionalDescriminator",arguments:["this.mediaType.isXML()"]}],"extends":[{typeName:"ExampleString",nameSpace:"",basicName:"ExampleString",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/systemTypes.ts"}],moduleName:null,annotationOverridings:{}},{name:"TypeInstance",methods:[],typeParameters:[],typeParameterConstraint:[],"implements":[],fields:[{name:"properties",type:{base:{typeName:"TypeInstanceProperty",nameSpace:"",basicName:"TypeInstanceProperty",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/systemTypes.ts"},typeKind:1},annotations:[{name:"MetaModel.description",arguments:["Array of instance properties"]}],valueConstraint:null,optional:!1},{name:"isScalar",type:{typeName:"boolean",nameSpace:"",basicName:"boolean",typeKind:0,typeArguments:[],modulePath:null},annotations:[{name:"MetaModel.description",arguments:["Whether the type is scalar"]}],valueConstraint:null,optional:!1},{name:"value",type:{typeName:"any",nameSpace:"",basicName:"any",typeKind:0,typeArguments:[],modulePath:null},annotations:[{name:"MetaModel.description",arguments:["For instances of scalar types returns scalar value"]}],valueConstraint:null,optional:!1}],isInterface:!1,annotations:[{name:"MetaModel.customHandling",arguments:[]}],"extends":[],moduleName:null,annotationOverridings:{}},{name:"TypeInstanceProperty",methods:[],typeParameters:[],typeParameterConstraint:[],"implements":[],fields:[{name:"name",type:{typeName:"string",nameSpace:"",basicName:"string",typeKind:0,typeArguments:[],modulePath:null},annotations:[{name:"MetaModel.description",arguments:["Property name"]}],valueConstraint:null,optional:!1},{name:"value",type:{typeName:"TypeInstance",nameSpace:"",basicName:"TypeInstance",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/systemTypes.ts"},annotations:[{name:"MetaModel.description",arguments:["Property value"]}],valueConstraint:null,optional:!1},{name:"values",type:{base:{typeName:"TypeInstance",nameSpace:"",basicName:"TypeInstance",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/systemTypes.ts"},typeKind:1},annotations:[{name:"MetaModel.description",arguments:["Array of values if property value is array"]}],valueConstraint:null,optional:!1},{name:"isArray",type:{typeName:"boolean",nameSpace:"",basicName:"boolean",typeKind:0,typeArguments:[],modulePath:null},annotations:[{name:"MetaModel.description",arguments:["Whether property has array as value"]}],valueConstraint:null,optional:!1}],isInterface:!1,annotations:[{name:"MetaModel.customHandling",arguments:[]}],"extends":[],moduleName:null,annotationOverridings:{}}],aliases:[],enumDeclarations:[],imports:{MetaModel:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/metamodel.ts",Common:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/common.ts"},name:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/systemTypes.ts"},{classes:[{name:"RAMLSimpleElement",methods:[],typeParameters:[],typeParameterConstraint:[],"implements":[],fields:[],isInterface:!1,annotations:[],"extends":[],moduleName:null,annotationOverridings:{}}],aliases:[],enumDeclarations:[],imports:{MetaModel:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/metamodel.ts",Sys:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/systemTypes.ts"},name:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/common.ts"},{classes:[{name:"Parameter",methods:[],typeParameters:[],typeParameterConstraint:[],"implements":[],fields:[{name:"name",type:{typeName:"string",nameSpace:"",basicName:"string",typeKind:0,typeArguments:[],modulePath:null},annotations:[{name:"MetaModel.key",arguments:[]},{name:"MetaModel.description",arguments:["name of the parameter"]},{name:"MetaModel.extraMetaKey",arguments:["headers"]}],valueConstraint:null,optional:!1},{name:"displayName",type:{typeName:"string",nameSpace:"",basicName:"string",typeKind:0,typeArguments:[],modulePath:null},annotations:[{name:"MetaModel.description",arguments:["An alternate, human-friendly name for the parameter"]}],valueConstraint:null,optional:!1},{name:"type",type:{typeName:"string",nameSpace:"",basicName:"string",typeKind:0,typeArguments:[],modulePath:null},annotations:[{name:"MetaModel.defaultValue",arguments:["string"]},{name:"MetaModel.descriminatingProperty",arguments:[]},{name:"MetaModel.description",arguments:["The type attribute specifies the primitive type of the parameter's resolved value. API clients MUST return/throw an error if the parameter's resolved value does not match the specified type. If type is not specified, it defaults to string."]},{name:"MetaModel.canBeDuplicator",arguments:[]}],valueConstraint:null,optional:!1},{name:"location",type:{typeName:"ParameterLocation",nameSpace:"",basicName:"ParameterLocation",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/parameters.ts"},annotations:[{name:"MetaModel.system",arguments:[]},{name:"MetaModel.description",arguments:["Location of the parameter (can not be edited by user)"]}],valueConstraint:null,optional:!1},{name:"required",type:{typeName:"boolean",nameSpace:"",basicName:"boolean",typeKind:0,typeArguments:[],modulePath:null},annotations:[{name:"MetaModel.description",arguments:["Set to true if parameter is required"]},{name:"MetaModel.defaultBooleanValue",arguments:[!0]}],valueConstraint:null,optional:!1},{name:"default",type:{typeName:"any",nameSpace:"",basicName:"any",typeKind:0,typeArguments:[],modulePath:null},annotations:[{name:"MetaModel.description",arguments:["The default attribute specifies the default value to use for the property if the property is omitted or its value is not specified. This SHOULD NOT be interpreted as a requirement for the client to send the default attribute's value if there is no other value to send. Instead, the default attribute's value is the value the server uses if the client does not send a value."]}],valueConstraint:null,optional:!1},{name:"example",type:{typeName:"string",nameSpace:"",basicName:"string",typeKind:0,typeArguments:[],modulePath:null},annotations:[{name:"MetaModel.description",arguments:["(Optional) The example attribute shows an example value for the property. This can be used, e.g., by documentation generators to generate sample values for the property."]}],valueConstraint:null,optional:!1},{name:"repeat",type:{typeName:"boolean",nameSpace:"",basicName:"boolean",typeKind:0,typeArguments:[],modulePath:null},annotations:[{name:"MetaModel.description",arguments:["The repeat attribute specifies that the parameter can be repeated. If the parameter can be used multiple times, the repeat parameter value MUST be set to 'true'. Otherwise, the default value is 'false' and the parameter may not be repeated."]},{name:"MetaModel.defaultBooleanValue",arguments:[!1]}],valueConstraint:null,optional:!1},{name:"description",type:{typeName:"Sys.MarkdownString",nameSpace:"Sys",basicName:"MarkdownString",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/parameters.ts"},annotations:[{name:"MetaModel.description",arguments:["The description attribute describes the intended use or meaning of the $self. This value MAY be formatted using Markdown."]}],valueConstraint:null,optional:!1}],isInterface:!1,annotations:[],"extends":[],moduleName:null,annotationOverridings:{}},{name:"StringTypeDeclaration",methods:[],typeParameters:[],typeParameterConstraint:[],"implements":[],fields:[{name:"type",type:null,annotations:[],valueConstraint:{isCallConstraint:!1,value:"string"},optional:!1},{name:"pattern",type:{typeName:"string",nameSpace:"",basicName:"string",typeKind:0,typeArguments:[],modulePath:null},annotations:[{name:"MetaModel.description",arguments:["(Optional, applicable only for parameters of type string) The pattern attribute is a regular expression that a parameter of type string MUST match. Regular expressions MUST follow the regular expression specification from ECMA 262/Perl 5. The pattern MAY be enclosed in double quotes for readability and clarity."]}],valueConstraint:null,optional:!1},{name:"enum",type:{base:{typeName:"string",nameSpace:"",basicName:"string",typeKind:0,typeArguments:[],modulePath:null},typeKind:1},annotations:[{name:"MetaModel.description",arguments:["(Optional, applicable only for parameters of type string) The enum attribute provides an enumeration of the parameter's valid values. This MUST be an array. If the enum attribute is defined, API clients and servers MUST verify that a parameter's value matches a value in the enum array. If there is no matching value, the clients and servers MUST treat this as an error."]}],valueConstraint:null,optional:!1},{name:"minLength",type:{typeName:"number",nameSpace:"",basicName:"number",typeKind:0,typeArguments:[],modulePath:null},annotations:[{name:"MetaModel.description",arguments:["(Optional, applicable only for parameters of type string) The minLength attribute specifies the parameter value's minimum number of characters."]}],valueConstraint:null,optional:!1},{name:"maxLength",type:{typeName:"number",nameSpace:"",basicName:"number",typeKind:0,typeArguments:[],modulePath:null},annotations:[{name:"MetaModel.description",arguments:["(Optional, applicable only for parameters of type string) The maxLength attribute specifies the parameter value's maximum number of characters."]}],valueConstraint:null,optional:!1}],isInterface:!1,annotations:[{name:"MetaModel.description",arguments:["Value must be a string"]}],"extends":[{typeName:"Parameter",nameSpace:"",basicName:"Parameter",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/parameters.ts"}],moduleName:null,annotationOverridings:{}},{name:"BooleanTypeDeclaration",methods:[],typeParameters:[],typeParameterConstraint:[],"implements":[],fields:[{name:"type",type:null,annotations:[],valueConstraint:{isCallConstraint:!1,value:"boolean"},optional:!1}],isInterface:!1,annotations:[{name:"MetaModel.description",arguments:["Value must be a boolean"]}],"extends":[{typeName:"Parameter",nameSpace:"",basicName:"Parameter",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/parameters.ts"}],moduleName:null,annotationOverridings:{}},{name:"NumberTypeDeclaration",methods:[],typeParameters:[],typeParameterConstraint:[],"implements":[],fields:[{name:"type",type:null,annotations:[],valueConstraint:{isCallConstraint:!1,value:"number"},optional:!1},{name:"minimum",type:{typeName:"number",nameSpace:"",basicName:"number",typeKind:0,typeArguments:[],modulePath:null},annotations:[{name:"MetaModel.description",arguments:["(Optional, applicable only for parameters of type number or integer) The minimum attribute specifies the parameter's minimum value."]}],valueConstraint:null,optional:!1},{name:"maximum",type:{typeName:"number",nameSpace:"",basicName:"number",typeKind:0,typeArguments:[],modulePath:null},annotations:[{name:"MetaModel.description",arguments:["(Optional, applicable only for parameters of type number or integer) The maximum attribute specifies the parameter's maximum value."]}],valueConstraint:null,optional:!1}],isInterface:!1,annotations:[{name:"MetaModel.description",arguments:["Value MUST be a number. Indicate floating point numbers as defined by YAML."]}],"extends":[{typeName:"Parameter",nameSpace:"",basicName:"Parameter",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/parameters.ts"}],moduleName:null,annotationOverridings:{}},{name:"IntegerTypeDeclaration",methods:[],typeParameters:[],typeParameterConstraint:[],"implements":[],fields:[{name:"type",type:null,annotations:[],valueConstraint:{isCallConstraint:!1,value:"integer"},optional:!1}],isInterface:!1,annotations:[{name:"MetaModel.description",arguments:["Value MUST be a integer."]}],"extends":[{typeName:"NumberTypeDeclaration",nameSpace:"",basicName:"NumberTypeDeclaration",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/parameters.ts"}],moduleName:null,annotationOverridings:{}},{name:"DateTypeDeclaration",methods:[],typeParameters:[],typeParameterConstraint:[],"implements":[],fields:[{name:"type",type:null,annotations:[],valueConstraint:{isCallConstraint:!1,value:"date"},optional:!1}],isInterface:!1,annotations:[{name:"MetaModel.description",arguments:["Value MUST be a string representation of a date as defined in RFC2616 Section 3.3. "]}],"extends":[{typeName:"Parameter",nameSpace:"",basicName:"Parameter",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/parameters.ts"}],moduleName:null,annotationOverridings:{}},{name:"FileTypeDeclaration",methods:[],typeParameters:[],typeParameterConstraint:[],"implements":[],fields:[{name:"type",type:null,annotations:[],valueConstraint:{isCallConstraint:!1,value:"file"},optional:!1}],isInterface:!1,annotations:[{name:"MetaModel.requireValue",arguments:["location","ParameterLocation.FORM"]},{name:"MetaModel.description",arguments:["(Applicable only to Form properties) Value is a file. Client generators SHOULD use this type to handle file uploads correctly."]}],"extends":[{typeName:"Parameter",nameSpace:"",basicName:"Parameter",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/parameters.ts"}],moduleName:null,annotationOverridings:{}}],aliases:[],enumDeclarations:[{name:"ParameterLocation",members:["QUERY","HEADERS","URI","FORM","BURI"]}],imports:{MetaModel:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/metamodel.ts",Sys:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/systemTypes.ts",Common:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/common.ts"},name:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/parameters.ts"},{classes:[{name:"MimeType",methods:[],typeParameters:[],typeParameterConstraint:[],"implements":[],fields:[],isInterface:!1,annotations:[{name:"MetaModel.description",arguments:["This sub type of the string represents mime types"]}],"extends":[{typeName:"StringType",nameSpace:"",basicName:"StringType",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/bodies.ts"}],moduleName:null,annotationOverridings:{}},{name:"BodyLike",methods:[],typeParameters:[],typeParameterConstraint:[],"implements":[],fields:[{name:"name",type:{typeName:"string",nameSpace:"",basicName:"string",typeKind:0,typeArguments:[],modulePath:null},annotations:[{name:"MetaModel.key",arguments:[]},{name:"MetaModel.description",arguments:["Mime type of the request or response body"]},{name:"MetaModel.canInherit",arguments:["mediaType"]},{name:"MetaModel.oftenKeys",arguments:[["application/json","application/xml","application/x-www-form-urlencoded","multipart/form-data"]]}],valueConstraint:null,optional:!1},{name:"schema",type:{typeName:"Sys.SchemaString",nameSpace:"Sys",basicName:"SchemaString",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/bodies.ts"},annotations:[{name:"MetaModel.requireValue",arguments:["this.name.isForm()","false"]},{name:"MetaModel.description",arguments:["The structure of a request or response body MAY be further specified by the schema property under the appropriate media type. The schema key CANNOT be specified if a body's media type is application/x-www-form-urlencoded or multipart/form-data. All parsers of RAML MUST be able to interpret JSON Schema and XML Schema. Schema MAY be declared inline or in an external file. However, if the schema is sufficiently large so as to make it difficult for a person to read the API definition, or the schema is reused across multiple APIs or across multiple miles in the same API, the !include user-defined data type SHOULD be used instead of including the content inline. Alternatively, the value of the schema field MAY be the name of a schema specified in the root-level schemas property, or it MAY be declared in an external file and included by using the by using the RAML !include user-defined data type."]}],valueConstraint:null,optional:!1},{name:"example",type:{typeName:"Sys.ExampleString",nameSpace:"Sys",basicName:"ExampleString",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/bodies.ts"},annotations:[{name:"MetaModel.description",arguments:["Documentation generators MUST use body properties' example attributes to generate example invocations."]}],valueConstraint:null,optional:!1},{name:"formParameters",type:{base:{typeName:"Params.Parameter",nameSpace:"Params",basicName:"Parameter",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/bodies.ts"},typeKind:1},annotations:[{name:"MetaModel.setsContextValue",arguments:["location","Params.ParameterLocation.FORM"]},{name:"MetaModel.description",arguments:["Web forms REQUIRE special encoding and custom declaration. If the API's media type is either application/x-www-form-urlencoded or multipart/form-data, the formParameters property MUST specify the name-value pairs that the API is expecting. The formParameters property is a map in which the key is the name of the web form parameter, and the value is itself a map the specifies the web form parameter's attributes."]}],valueConstraint:null,optional:!1},{name:"schemaContent",type:{typeName:"string",nameSpace:"",basicName:"string",typeKind:0,typeArguments:[],modulePath:null},annotations:[{name:"MetaModel.customHandling",arguments:[]},{name:"MetaModel.description",arguments:["Returns schema content for the cases when schema is inlined, when schema is included, and when schema is a reference."]}],valueConstraint:null,optional:!1},{name:"description",type:{typeName:"Sys.MarkdownString",nameSpace:"Sys",basicName:"MarkdownString",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/bodies.ts"
},annotations:[{name:"MetaModel.description",arguments:["Human readable description of the body"]}],valueConstraint:null,optional:!1}],isInterface:!1,annotations:[{name:"MetaModel.canInherit",arguments:["mediaType"]}],"extends":[],moduleName:null,annotationOverridings:{}},{name:"XMLBody",methods:[],typeParameters:[],typeParameterConstraint:[],"implements":[],fields:[{name:"schema",type:{typeName:"Sys.XMLSchemaString",nameSpace:"Sys",basicName:"XMLSchemaString",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/bodies.ts"},annotations:[{name:"MetaModel.description",arguments:["XSD Schema"]}],valueConstraint:null,optional:!1}],isInterface:!1,annotations:[{name:"MetaModel.functionalDescriminator",arguments:["this.mime.isXML()"]},{name:"MetaModel.description",arguments:["Needed to set connection between xml related mime types and xsd schema"]}],"extends":[{typeName:"BodyLike",nameSpace:"",basicName:"BodyLike",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/bodies.ts"}],moduleName:null,annotationOverridings:{}},{name:"JSONBody",methods:[],typeParameters:[],typeParameterConstraint:[],"implements":[],fields:[{name:"schema",type:{typeName:"Sys.JSonSchemaString",nameSpace:"Sys",basicName:"JSonSchemaString",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/bodies.ts"},annotations:[{name:"MetaModel.description",arguments:["JSON Schema"]}],valueConstraint:null,optional:!1}],isInterface:!1,annotations:[{name:"MetaModel.functionalDescriminator",arguments:["this.mime.isJSON()"]},{name:"MetaModel.description",arguments:["Needed to set connection between json related mime types and json schema"]}],"extends":[{typeName:"BodyLike",nameSpace:"",basicName:"BodyLike",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/bodies.ts"}],moduleName:null,annotationOverridings:{}},{name:"Response",methods:[],typeParameters:[],typeParameterConstraint:[],"implements":[],fields:[{name:"code",type:{typeName:"Sys.StatusCodeString",nameSpace:"Sys",basicName:"StatusCodeString",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/bodies.ts"},annotations:[{name:"MetaModel.key",arguments:[]},{name:"MetaModel.extraMetaKey",arguments:["statusCodes"]},{name:"MetaModel.description",arguments:["Responses MUST be a map of one or more HTTP status codes, where each status code itself is a map that describes that status code."]}],valueConstraint:null,optional:!1},{name:"headers",type:{base:{typeName:"Params.Parameter",nameSpace:"Params",basicName:"Parameter",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/bodies.ts"},typeKind:1},annotations:[{name:"MetaModel.setsContextValue",arguments:["location","Params.ParameterLocation.HEADERS"]},{name:"MetaModel.newInstanceName",arguments:["New Header"]},{name:"MetaModel.description",arguments:["An API's methods may support custom header values in responses. The custom, non-standard HTTP headers MUST be specified by the headers property. API's may include the the placeholder token {?} in a header name to indicate that any number of headers that conform to the specified format can be sent in responses. This is particularly useful for APIs that allow HTTP headers that conform to some naming convention to send arbitrary, custom data."]}],valueConstraint:null,optional:!1},{name:"body",type:{base:{typeName:"BodyLike",nameSpace:"",basicName:"BodyLike",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/bodies.ts"},typeKind:1},annotations:[{name:"MetaModel.newInstanceName",arguments:["New Body"]},{name:"MetaModel.description",arguments:["Each response MAY contain a body property, which conforms to the same structure as request body properties (see Body). Responses that can return more than one response code MAY therefore have multiple bodies defined. For APIs without a priori knowledge of the response types for their responses, `*/*` MAY be used to indicate that responses that do not matching other defined data types MUST be accepted. Processing applications MUST match the most descriptive media type first if `*/*` is used."]}],valueConstraint:null,optional:!1},{name:"description",type:{typeName:"Sys.MarkdownString",nameSpace:"Sys",basicName:"MarkdownString",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/bodies.ts"},annotations:[{name:"MetaModel.description",arguments:["The description attribute describes the intended use or meaning of the $self. This value MAY be formatted using Markdown."]}],valueConstraint:null,optional:!1}],isInterface:!1,annotations:[],"extends":[],moduleName:null,annotationOverridings:{}}],aliases:[],enumDeclarations:[],imports:{MetaModel:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/metamodel.ts",Sys:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/systemTypes.ts",Params:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/parameters.ts",Common:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/common.ts"},name:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/bodies.ts"},{classes:[{name:"Resource",methods:[],typeParameters:[],typeParameterConstraint:[],"implements":[],fields:[{name:"relativeUri",type:{typeName:"Sys.RelativeUriString",nameSpace:"Sys",basicName:"RelativeUriString",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/resources.ts"},annotations:[{name:"MetaModel.key",arguments:[]},{name:"MetaModel.startFrom",arguments:["/"]},{name:"MetaModel.description",arguments:["Relative URL of this resource from the parent resource"]}],valueConstraint:null,optional:!1},{name:"type",type:{typeName:"ResourceTypeRef",nameSpace:"",basicName:"ResourceTypeRef",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/resources.ts"},annotations:[{name:"MetaModel.description",arguments:["Instantiation of applyed resource type"]}],valueConstraint:null,optional:!1},{name:"is",type:{base:{typeName:"TraitRef",nameSpace:"",basicName:"TraitRef",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/resources.ts"},typeKind:1},annotations:[{name:"MetaModel.description",arguments:["Instantiation of applyed traits"]}],valueConstraint:null,optional:!1},{name:"securedBy",type:{base:{typeName:"SecuritySchemeRef",nameSpace:"",basicName:"SecuritySchemeRef",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/resources.ts"},typeKind:1},annotations:[{name:"MetaModel.allowNull",arguments:[]},{name:"MetaModel.description",arguments:["securityScheme may also be applied to a resource by using the securedBy key, which is equivalent to applying the securityScheme to all methods that may be declared, explicitly or implicitly, by defining the resourceTypes or traits property for that resource. To indicate that the method may be called without applying any securityScheme, the method may be annotated with the null securityScheme."]}],valueConstraint:null,optional:!1},{name:"uriParameters",type:{base:{typeName:"Params.Parameter",nameSpace:"Params",basicName:"Parameter",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/resources.ts"},typeKind:1},annotations:[{name:"MetaModel.setsContextValue",arguments:["fieldOrParam",!0]},{name:"MetaModel.setsContextValue",arguments:["location","Params.ParameterLocation.URI"]},{name:"MetaModel.description",arguments:["Uri parameters of this resource"]}],valueConstraint:null,optional:!1},{name:"methods",type:{base:{typeName:"Methods.Method",nameSpace:"Methods",basicName:"Method",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/resources.ts"},typeKind:1},annotations:[{name:"MetaModel.newInstanceName",arguments:["New Method"]},{name:"MetaModel.description",arguments:["Methods that can be called on this resource"]}],valueConstraint:null,optional:!1},{name:"resources",type:{base:{typeName:"Resource",nameSpace:"",basicName:"Resource",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/resources.ts"},typeKind:1},annotations:[{name:"MetaModel.newInstanceName",arguments:["New Resource"]},{name:"MetaModel.description",arguments:["Children resources"]}],valueConstraint:null,optional:!1},{name:"displayName",type:{typeName:"string",nameSpace:"",basicName:"string",typeKind:0,typeArguments:[],modulePath:null},annotations:[{name:"MetaModel.description",arguments:["An alternate, human-friendly name for the resource"]}],valueConstraint:null,optional:!1},{name:"baseUriParameters",type:{base:{typeName:"Params.Parameter",nameSpace:"Params",basicName:"Parameter",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/resources.ts"},typeKind:1},annotations:[{name:"MetaModel.setsContextValue",arguments:["fieldOrParam",!0]},{name:"MetaModel.setsContextValue",arguments:["location","Params.ParameterLocation.BURI"]},{name:"MetaModel.description",arguments:["A resource or a method can override a base URI template's values. This is useful to restrict or change the default or parameter selection in the base URI. The baseUriParameters property MAY be used to override any or all parameters defined at the root level baseUriParameters property, as well as base URI parameters not specified at the root level."]}],valueConstraint:null,optional:!1},{name:"description",type:{typeName:"Sys.MarkdownString",nameSpace:"Sys",basicName:"MarkdownString",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/resources.ts"},annotations:[{name:"MetaModel.description",arguments:["The description attribute describes the intended use or meaning of the $self. This value MAY be formatted using Markdown."]}],valueConstraint:null,optional:!1}],isInterface:!1,annotations:[],"extends":[],moduleName:null,annotationOverridings:{}},{name:"ResourceTypeRef",methods:[],typeParameters:[],typeParameterConstraint:[],"implements":[],fields:[{name:"resourceType",type:{typeName:"ResourceType",nameSpace:"",basicName:"ResourceType",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/resources.ts"},annotations:[{name:"MetaModel.customHandling",arguments:[]},{name:"MetaModel.description",arguments:["Returns referenced resource type"]}],valueConstraint:null,optional:!1}],isInterface:!1,annotations:[],"extends":[{typeName:"Reference",nameSpace:"",basicName:"Reference",typeKind:0,typeArguments:[{typeName:"ResourceType",nameSpace:"",basicName:"ResourceType",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/resources.ts"}],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/resources.ts"}],moduleName:null,annotationOverridings:{}},{name:"ResourceType",methods:[],typeParameters:[],typeParameterConstraint:[],"implements":[{typeName:"DeclaresDynamicType",nameSpace:"",basicName:"DeclaresDynamicType",typeKind:0,typeArguments:[{typeName:"ResourceType",nameSpace:"",basicName:"ResourceType",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/resources.ts"}],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/resources.ts"}],fields:[{name:"name",type:{typeName:"string",nameSpace:"",basicName:"string",typeKind:0,typeArguments:[],modulePath:null},annotations:[{name:"MetaModel.key",arguments:[]},{name:"MetaModel.description",arguments:["Name of the resource type"]}],valueConstraint:null,optional:!1},{name:"usage",type:{typeName:"string",nameSpace:"",basicName:"string",typeKind:0,typeArguments:[],modulePath:null},annotations:[{name:"MetaModel.description",arguments:["Instructions on how and when the resource type should be used."]}],valueConstraint:null,optional:!1},{name:"methods",type:{base:{typeName:"Methods.Method",nameSpace:"Methods",basicName:"Method",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/resources.ts"},typeKind:1},annotations:[{name:"MetaModel.description",arguments:["Methods that are part of this resource type definition"]}],valueConstraint:null,optional:!1},{name:"is",type:{base:{typeName:"Security.TraitRef",nameSpace:"Security",basicName:"TraitRef",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/resources.ts"},typeKind:1},annotations:[{name:"MetaModel.description",arguments:["Instantiation of applyed traits"]}],valueConstraint:null,optional:!1},{name:"type",type:{typeName:"ResourceTypeRef",nameSpace:"",basicName:"ResourceTypeRef",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/resources.ts"},annotations:[{name:"MetaModel.description",arguments:["Instantiation of applyed resource type"]}],valueConstraint:null,optional:!1},{name:"securedBy",type:{base:{typeName:"Security.SecuritySchemeRef",nameSpace:"Security",basicName:"SecuritySchemeRef",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/resources.ts"},typeKind:1},annotations:[{name:"MetaModel.allowNull",arguments:[]},{name:"MetaModel.description",arguments:["securityScheme may also be applied to a resource by using the securedBy key, which is equivalent to applying the securityScheme to all methods that may be declared, explicitly or implicitly, by defining the resourceTypes or traits property for that resource. To indicate that the method may be called without applying any securityScheme, the method may be annotated with the null securityScheme."]}],valueConstraint:null,optional:!1},{name:"uriParameters",type:{base:{typeName:"Params.Parameter",nameSpace:"Params",basicName:"Parameter",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/resources.ts"},typeKind:1},annotations:[{name:"MetaModel.setsContextValue",arguments:["location","Params.ParameterLocation.URI"]},{name:"MetaModel.description",arguments:["Uri parameters of this resource"]}],valueConstraint:null,optional:!1},{name:"displayName",type:{typeName:"string",nameSpace:"",basicName:"string",typeKind:0,typeArguments:[],modulePath:null},annotations:[{name:"MetaModel.description",arguments:["An alternate, human-friendly name for the resource type"]}],valueConstraint:null,optional:!1},{name:"baseUriParameters",type:{base:{typeName:"Params.Parameter",nameSpace:"Params",basicName:"Parameter",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/resources.ts"},typeKind:1},annotations:[{name:"MetaModel.setsContextValue",arguments:["fieldOrParam",!0]},{name:"MetaModel.setsContextValue",arguments:["location","Params.ParameterLocation.BURI"]},{name:"MetaModel.description",arguments:["A resource or a method can override a base URI template's values. This is useful to restrict or change the default or parameter selection in the base URI. The baseUriParameters property MAY be used to override any or all parameters defined at the root level baseUriParameters property, as well as base URI parameters not specified at the root level."]}],valueConstraint:null,optional:!1},{name:"parametrizedProperties",type:{typeName:"Sys.TypeInstance",nameSpace:"Sys",basicName:"TypeInstance",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/resources.ts"},annotations:[{name:"MetaModel.customHandling",arguments:[]},{name:"MetaModel.description",arguments:["Returns object representation of parametrized properties of the resource type"]}],valueConstraint:null,optional:!1},{name:"description",type:{typeName:"Sys.MarkdownString",nameSpace:"Sys",basicName:"MarkdownString",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/resources.ts"},annotations:[{name:"MetaModel.description",arguments:["The description attribute describes the intended use or meaning of the $self. This value MAY be formatted using Markdown."]}],valueConstraint:null,optional:!1}],isInterface:!1,annotations:[{name:"MetaModel.inlinedTemplates",arguments:[]},{name:"MetaModel.allowQuestion",arguments:[]}],"extends":[],moduleName:null,annotationOverridings:{}}],aliases:[],enumDeclarations:[],imports:{MetaModel:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/metamodel.ts",Sys:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/systemTypes.ts",Params:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/parameters.ts",Bodies:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/bodies.ts",Common:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/common.ts",Methods:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/methods.ts",Security:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/security.ts"},name:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/resources.ts"},{classes:[{name:"MethodBase",methods:[],typeParameters:[],typeParameterConstraint:[],"implements":[],fields:[{name:"responses",type:{base:{typeName:"Bodies.Response",nameSpace:"Bodies",basicName:"Response",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/methods.ts"},typeKind:1},annotations:[{name:"MetaModel.newInstanceName",arguments:["New Response"]},{name:"MetaModel.description",arguments:["Resource methods MAY have one or more responses. Responses MAY be described using the description property, and MAY include example attributes or schema properties."]}],valueConstraint:null,optional:!1},{name:"body",type:{base:{typeName:"Bodies.BodyLike",nameSpace:"Bodies",basicName:"BodyLike",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/methods.ts"},typeKind:1},annotations:[{name:"MetaModel.newInstanceName",arguments:["New Body"]},{name:"MetaModel.description",arguments:["Some method verbs expect the resource to be sent as a request body. For example, to create a resource, the request must include the details of the resource to create. Resources CAN have alternate representations. For example, an API might support both JSON and XML representations. A method's body is defined in the body property as a hashmap, in which the key MUST be a valid media type."]}],valueConstraint:null,optional:!1},{name:"protocols",type:{base:{typeName:"string",nameSpace:"",basicName:"string",typeKind:0,typeArguments:[],modulePath:null},typeKind:1},annotations:[{name:"MetaModel.oneOf",arguments:[["HTTP","HTTPS"]]},{name:"MetaModel.description",arguments:["A method can override an API's protocols value for that single method by setting a different value for the fields."]}],valueConstraint:null,optional:!1},{name:"securedBy",type:{base:{typeName:"SecuritySchemeRef",nameSpace:"",basicName:"SecuritySchemeRef",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/methods.ts"},typeKind:1},annotations:[{name:"MetaModel.allowNull",arguments:[]},{name:"MetaModel.description",arguments:["A list of the security schemas to apply, these must be defined in the securitySchemes declaration. To indicate that the method may be called without applying any securityScheme, the method may be annotated with the null securityScheme. Security schemas may also be applied to a resource with securedBy, which is equivalent to applying the security schemas to all methods that may be declared, explicitly or implicitly, by defining the resourceTypes or traits property for that resource."]}],valueConstraint:null,optional:!1},{name:"baseUriParameters",type:{base:{typeName:"Params.Parameter",nameSpace:"Params",basicName:"Parameter",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/methods.ts"},typeKind:1},annotations:[{name:"MetaModel.setsContextValue",arguments:["fieldOrParam",!0]},{name:"MetaModel.setsContextValue",arguments:["location","Params.ParameterLocation.BURI"]},{name:"MetaModel.description",arguments:["A resource or a method can override a base URI template's values. This is useful to restrict or change the default or parameter selection in the base URI. The baseUriParameters property MAY be used to override any or all parameters defined at the root level baseUriParameters property, as well as base URI parameters not specified at the root level."]}],valueConstraint:null,optional:!1},{name:"queryParameters",type:{base:{typeName:"Params.Parameter",nameSpace:"Params",basicName:"Parameter",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/methods.ts"},typeKind:1},annotations:[{name:"MetaModel.setsContextValue",arguments:["location","ParameterLocation.QUERY"]},{name:"MetaModel.newInstanceName",arguments:["New query parameter"]},{name:"MetaModel.description",arguments:["An APIs resources MAY be filtered (to return a subset of results) or altered (such as transforming a response body from JSON to XML format) by the use of query strings. If the resource or its method supports a query string, the query string MUST be defined by the queryParameters property"]}],valueConstraint:null,optional:!1},{name:"headers",type:{base:{typeName:"Params.Parameter",nameSpace:"Params",basicName:"Parameter",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/methods.ts"},typeKind:1},annotations:[{name:"MetaModel.setsContextValue",arguments:["location","ParameterLocation.HEADERS"]},{name:"MetaModel.description",arguments:["Headers that allowed at this position"]},{name:"MetaModel.newInstanceName",arguments:["New Header"]}],valueConstraint:null,optional:!1},{name:"description",type:{typeName:"Sys.MarkdownString",nameSpace:"Sys",basicName:"MarkdownString",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/methods.ts"},annotations:[],valueConstraint:null,optional:!1}],isInterface:!1,annotations:[{name:"MetaModel.description",arguments:["Method object allows description of http methods"]}],"extends":[],moduleName:null,annotationOverridings:{}},{name:"Method",methods:[],typeParameters:[],typeParameterConstraint:[],"implements":[],fields:[{name:"method",type:{typeName:"string",nameSpace:"",basicName:"string",typeKind:0,typeArguments:[],modulePath:null},annotations:[{name:"MetaModel.key",arguments:[]},{name:"MetaModel.extraMetaKey",arguments:["methods"]},{name:"MetaModel.oneOf",arguments:[["get","put","post","delete","patch","options","head","trace","connect"]]},{name:"MetaModel.description",arguments:["Method that can be called"]}],valueConstraint:null,optional:!1},{name:"is",type:{base:{typeName:"TraitRef",nameSpace:"",basicName:"TraitRef",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/methods.ts"},typeKind:1},annotations:[{name:"MetaModel.description",arguments:["Instantiation of applyed traits"]}],valueConstraint:null,optional:!1}],isInterface:!1,annotations:[],"extends":[{typeName:"MethodBase",nameSpace:"",basicName:"MethodBase",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/methods.ts"}],moduleName:null,annotationOverridings:{}},{name:"Trait",methods:[],typeParameters:[],typeParameterConstraint:[],"implements":[{typeName:"DeclaresDynamicType",nameSpace:"",basicName:"DeclaresDynamicType",typeKind:0,typeArguments:[{typeName:"Trait",nameSpace:"",basicName:"Trait",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/methods.ts"}],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/methods.ts"}],fields:[{name:"name",type:{typeName:"string",nameSpace:"",basicName:"string",typeKind:0,typeArguments:[],modulePath:null},annotations:[{name:"MetaModel.key",arguments:[]},{name:"MetaModel.description",arguments:["Name of the trait"]}],valueConstraint:null,optional:!1},{name:"usage",type:{typeName:"string",nameSpace:"",basicName:"string",typeKind:0,typeArguments:[],modulePath:null},annotations:[{name:"MetaModel.description",arguments:["Instructions on how and when the trait should be used."]}],valueConstraint:null,optional:!1},{name:"parametrizedProperties",type:{typeName:"Sys.TypeInstance",nameSpace:"Sys",basicName:"TypeInstance",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/methods.ts"},annotations:[{name:"MetaModel.customHandling",arguments:[]},{name:"MetaModel.description",arguments:["Returns object representation of parametrized properties of the trait"]}],valueConstraint:null,optional:!1},{name:"displayName",type:{typeName:"string",nameSpace:"",basicName:"string",typeKind:0,typeArguments:[],modulePath:null},annotations:[{name:"MetaModel.description",arguments:["An alternate, human-friendly name for the trait"]}],valueConstraint:null,optional:!1}],isInterface:!1,annotations:[{name:"MetaModel.inlinedTemplates",arguments:[]},{name:"MetaModel.allowQuestion",arguments:[]}],"extends":[{typeName:"MethodBase",nameSpace:"",basicName:"MethodBase",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/methods.ts"}],moduleName:null,annotationOverridings:{}},{name:"TraitRef",methods:[],typeParameters:[],typeParameterConstraint:[],"implements":[],fields:[{name:"trait",type:{typeName:"Trait",nameSpace:"",basicName:"Trait",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/methods.ts"},annotations:[{name:"MetaModel.customHandling",arguments:[]},{name:"MetaModel.description",arguments:["Returns referenced trait"]}],valueConstraint:null,optional:!1}],isInterface:!1,annotations:[],"extends":[{typeName:"Reference",nameSpace:"",basicName:"Reference",typeKind:0,typeArguments:[{typeName:"Trait",nameSpace:"",basicName:"Trait",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/methods.ts"}],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/methods.ts"}],moduleName:null,annotationOverridings:{}}],aliases:[],enumDeclarations:[],imports:{MetaModel:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/metamodel.ts",Sys:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/systemTypes.ts",Params:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/parameters.ts",Bodies:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/bodies.ts",Common:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/common.ts",Security:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/security.ts"},name:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/methods.ts"},{classes:[{name:"SecuritySchemePart",methods:[],typeParameters:[],typeParameterConstraint:[],"implements":[],fields:[{name:"displayName",type:{typeName:"string",nameSpace:"",basicName:"string",typeKind:0,typeArguments:[],modulePath:null},annotations:[{name:"MetaModel.description",arguments:["An alternate, human-friendly name for the security scheme part"]}],valueConstraint:null,optional:!1},{name:"is",type:{base:{typeName:"TraitRef",nameSpace:"",basicName:"TraitRef",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/security.ts"},typeKind:1},annotations:[{name:"MetaModel.description",arguments:["Instantiation of applyed traits"]}],valueConstraint:null,optional:!1}],isInterface:!1,annotations:[],"extends":[{typeName:"MethodBase",nameSpace:"",basicName:"MethodBase",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/security.ts"}],moduleName:null,annotationOverridings:{headers:[{name:"MetaModel.markdownDescription",arguments:["Optional array of headers, documenting the possible headers that could be accepted."]},{name:"MetaModel.valueDescription",arguments:["Object whose property names are the request header names and whose values describe the values."]}],queryParameters:[{name:"MetaModel.markdownDescription",arguments:["Query parameters, used by the schema in order to authorize the request. Mutually exclusive with queryString."]},{name:"MetaModel.valueDescription",arguments:["Object whose property names are the query parameter names and whose values describe the values."]}],queryString:[{name:"MetaModel.description",arguments:["Specifies the query string, used by the schema in order to authorize the request. Mutually exclusive with queryParameters."]},{name:"MetaModel.valueDescription",arguments:["Type name or type declaration"]}],responses:[{name:"MetaModel.description",arguments:["Optional array of responses, describing the possible responses that could be sent."]}],description:[{name:"MetaModel.description",arguments:["A longer, human-friendly description of the security scheme part"]},{name:"MetaModel.valueDescription",arguments:["Markdown string"]}]}},{name:"SecuritySchemeSettings",methods:[],typeParameters:[],typeParameterConstraint:[],"implements":[],fields:[],isInterface:!1,annotations:[{name:"MetaModel.allowAny",arguments:[]}],"extends":[],moduleName:null,annotationOverridings:{}},{name:"AbstractSecurityScheme",methods:[],typeParameters:[],typeParameterConstraint:[],"implements":[{typeName:"Referencable",nameSpace:"",basicName:"Referencable",typeKind:0,typeArguments:[{typeName:"AbstractSecurityScheme",nameSpace:"",basicName:"AbstractSecurityScheme",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/security.ts"}],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/security.ts"}],fields:[{name:"name",type:{typeName:"string",nameSpace:"",basicName:"string",typeKind:0,typeArguments:[],modulePath:null
},annotations:[{name:"MetaModel.key",arguments:[]},{name:"MetaModel.startFrom",arguments:[""]},{name:"MetaModel.hide",arguments:[]},{name:"MetaModel.description",arguments:["Name of the security scheme"]}],valueConstraint:null,optional:!1},{name:"type",type:{typeName:"string",nameSpace:"",basicName:"string",typeKind:0,typeArguments:[],modulePath:null},annotations:[{name:"MetaModel.required",arguments:[]},{name:"MetaModel.oneOf",arguments:[["OAuth 1.0","OAuth 2.0","Basic Authentication","DigestSecurityScheme Authentication","x-{other}"]]},{name:"MetaModel.descriminatingProperty",arguments:[]},{name:"MetaModel.description",arguments:["The securitySchemes property MUST be used to specify an API's security mechanisms, including the required settings and the authentication methods that the API supports. one authentication method is allowed if the API supports them."]},{name:"MetaModel.valueDescription",arguments:["string<br><br>The value MUST be one of<br>* OAuth 1.0,<br>* OAuth 2.0, <br>* BasicSecurityScheme Authentication<br>* DigestSecurityScheme Authentication<br>* x-&lt;other&gt;"]}],valueConstraint:null,optional:!1},{name:"description",type:{typeName:"Sys.MarkdownString",nameSpace:"Sys",basicName:"MarkdownString",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/security.ts"},annotations:[{name:"MetaModel.description",arguments:["The description attribute MAY be used to describe a security schemes property."]}],valueConstraint:null,optional:!1},{name:"describedBy",type:{typeName:"SecuritySchemePart",nameSpace:"",basicName:"SecuritySchemePart",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/security.ts"},annotations:[{name:"MetaModel.description",arguments:["A description of the request components related to Security that are determined by the scheme: the headers, query parameters or responses. As a best practice, even for standard security schemes, API designers SHOULD describe these properties of security schemes. Including the security scheme description completes an API documentation."]}],valueConstraint:null,optional:!1},{name:"settings",type:{typeName:"SecuritySchemeSettings",nameSpace:"",basicName:"SecuritySchemeSettings",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/security.ts"},annotations:[{name:"MetaModel.description",arguments:["The settings attribute MAY be used to provide security scheme-specific information. The required attributes vary depending on the type of security scheme is being declared. It describes the minimum set of properties which any processing application MUST provide and validate if it chooses to implement the security scheme. Processing applications MAY choose to recognize other properties for things such as token lifetime, preferred cryptographic algorithms, and more."]}],valueConstraint:null,optional:!1}],isInterface:!1,annotations:[{name:"MetaModel.description",arguments:["Declares globally referable security schema definition"]},{name:"MetaModel.actuallyExports",arguments:["$self"]},{name:"MetaModel.referenceIs",arguments:["settings"]}],"extends":[],moduleName:null,annotationOverridings:{}},{name:"SecuritySchemeRef",methods:[],typeParameters:[],typeParameterConstraint:[],"implements":[],fields:[{name:"securitySchemeName",type:{typeName:"string",nameSpace:"",basicName:"string",typeKind:0,typeArguments:[],modulePath:null},annotations:[{name:"MetaModel.customHandling",arguments:[]},{name:"MetaModel.description",arguments:["Returns the name of security scheme, this reference refers to."]}],valueConstraint:null,optional:!1},{name:"securityScheme",type:{typeName:"AbstractSecurityScheme",nameSpace:"",basicName:"AbstractSecurityScheme",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/security.ts"},annotations:[{name:"MetaModel.customHandling",arguments:[]},{name:"MetaModel.description",arguments:["Returns AST node of security scheme, this reference refers to, or null."]}],valueConstraint:null,optional:!1}],isInterface:!1,annotations:[{name:"MetaModel.allowAny",arguments:[]}],"extends":[{typeName:"Reference",nameSpace:"",basicName:"Reference",typeKind:0,typeArguments:[{typeName:"AbstractSecurityScheme",nameSpace:"",basicName:"AbstractSecurityScheme",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/security.ts"}],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/security.ts"}],moduleName:null,annotationOverridings:{}},{name:"OAuth1SecuritySchemeSettings",methods:[],typeParameters:[],typeParameterConstraint:[],"implements":[],fields:[{name:"requestTokenUri",type:{typeName:"Sys.FixedUri",nameSpace:"Sys",basicName:"FixedUri",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/security.ts"},annotations:[{name:"MetaModel.required",arguments:[]},{name:"MetaModel.description",arguments:["The URI of the Temporary Credential Request endpoint as defined in RFC5849 Section 2.1"]},{name:"MetaModel.valueDescription",arguments:["FixedUriString"]}],valueConstraint:null,optional:!1},{name:"authorizationUri",type:{typeName:"Sys.FixedUri",nameSpace:"Sys",basicName:"FixedUri",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/security.ts"},annotations:[{name:"MetaModel.required",arguments:[]},{name:"MetaModel.description",arguments:["The URI of the Resource Owner Authorization endpoint as defined in RFC5849 Section 2.2"]},{name:"MetaModel.valueDescription",arguments:["FixedUriString"]}],valueConstraint:null,optional:!1},{name:"tokenCredentialsUri",type:{typeName:"Sys.FixedUri",nameSpace:"Sys",basicName:"FixedUri",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/security.ts"},annotations:[{name:"MetaModel.required",arguments:[]},{name:"MetaModel.description",arguments:["The URI of the Token Request endpoint as defined in RFC5849 Section 2.3"]},{name:"MetaModel.valueDescription",arguments:["FixedUriString"]}],valueConstraint:null,optional:!1}],isInterface:!1,annotations:[{name:"MetaModel.allowAny",arguments:[]},{name:"MetaModel.functionalDescriminator",arguments:["$parent.type=='OAuth 1.0'"]}],"extends":[{typeName:"SecuritySchemeSettings",nameSpace:"",basicName:"SecuritySchemeSettings",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/security.ts"}],moduleName:null,annotationOverridings:{}},{name:"OAuth2SecuritySchemeSettings",methods:[],typeParameters:[],typeParameterConstraint:[],"implements":[],fields:[{name:"accessTokenUri",type:{typeName:"Sys.FixedUri",nameSpace:"Sys",basicName:"FixedUri",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/security.ts"},annotations:[{name:"MetaModel.required",arguments:[]},{name:"MetaModel.description",arguments:["The URI of the Token Endpoint as defined in RFC6749 Section 3.2. Not required forby implicit grant type."]},{name:"MetaModel.valueDescription",arguments:["FixedUriString"]}],valueConstraint:null,optional:!1},{name:"authorizationUri",type:{typeName:"Sys.FixedUri",nameSpace:"Sys",basicName:"FixedUri",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/security.ts"},annotations:[{name:"MetaModel.required",arguments:[]},{name:"MetaModel.description",arguments:["The URI of the Authorization Endpoint as defined in RFC6749 Section 3.1. Required forby authorization_code and implicit grant types."]},{name:"MetaModel.valueDescription",arguments:["FixedUriString"]}],valueConstraint:null,optional:!1},{name:"authorizationGrants",type:{base:{typeName:"string",nameSpace:"",basicName:"string",typeKind:0,typeArguments:[],modulePath:null},typeKind:1},annotations:[{name:"MetaModel.description",arguments:["A list of the Authorization grants supported by the API as defined in RFC6749 Sections 4.1, 4.2, 4.3 and 4.4, can be any of: authorization_code, password, client_credentials, implicit, or refresh_token."]},{name:"MetaModel.markdownDescription",arguments:["A list of the Authorization grants supported by the API as defined in RFC6749 Sections 4.1, 4.2, 4.3 and 4.4, can be any of:<br>* authorization_code<br>* password<br>* client_credentials <br>* implicit<br>* refresh_token."]}],valueConstraint:null,optional:!1},{name:"scopes",type:{base:{typeName:"string",nameSpace:"",basicName:"string",typeKind:0,typeArguments:[],modulePath:null},typeKind:1},annotations:[{name:"MetaModel.description",arguments:["A list of scopes supported by the security scheme as defined in RFC6749 Section 3.3"]}],valueConstraint:null,optional:!1}],isInterface:!1,annotations:[{name:"MetaModel.allowAny",arguments:[]}],"extends":[{typeName:"SecuritySchemeSettings",nameSpace:"",basicName:"SecuritySchemeSettings",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/security.ts"}],moduleName:null,annotationOverridings:{}},{name:"OAuth2SecurityScheme",methods:[],typeParameters:[],typeParameterConstraint:[],"implements":[],fields:[{name:"type",type:null,annotations:[],valueConstraint:{isCallConstraint:!1,value:"OAuth 2.0"},optional:!1},{name:"settings",type:{typeName:"OAuth2SecuritySchemeSettings",nameSpace:"",basicName:"OAuth2SecuritySchemeSettings",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/security.ts"},annotations:[],valueConstraint:null,optional:!1}],isInterface:!1,annotations:[{name:"MetaModel.description",arguments:["Declares globally referable security schema definition"]},{name:"MetaModel.actuallyExports",arguments:["$self"]},{name:"MetaModel.referenceIs",arguments:["settings"]}],"extends":[{typeName:"AbstractSecurityScheme",nameSpace:"",basicName:"AbstractSecurityScheme",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/security.ts"}],moduleName:null,annotationOverridings:{}},{name:"OAuth1SecurityScheme",methods:[],typeParameters:[],typeParameterConstraint:[],"implements":[],fields:[{name:"type",type:null,annotations:[],valueConstraint:{isCallConstraint:!1,value:"OAuth 1.0"},optional:!1},{name:"settings",type:{typeName:"OAuth1SecuritySchemeSettings",nameSpace:"",basicName:"OAuth1SecuritySchemeSettings",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/security.ts"},annotations:[],valueConstraint:null,optional:!1}],isInterface:!1,annotations:[{name:"MetaModel.description",arguments:["Declares globally referable security schema definition"]},{name:"MetaModel.actuallyExports",arguments:["$self"]},{name:"MetaModel.referenceIs",arguments:["settings"]}],"extends":[{typeName:"AbstractSecurityScheme",nameSpace:"",basicName:"AbstractSecurityScheme",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/security.ts"}],moduleName:null,annotationOverridings:{}},{name:"BasicSecurityScheme",methods:[],typeParameters:[],typeParameterConstraint:[],"implements":[],fields:[{name:"type",type:null,annotations:[],valueConstraint:{isCallConstraint:!1,value:"Basic Authentication"},optional:!1}],isInterface:!1,annotations:[{name:"MetaModel.description",arguments:["Declares globally referable security schema definition"]},{name:"MetaModel.actuallyExports",arguments:["$self"]},{name:"MetaModel.referenceIs",arguments:["settings"]}],"extends":[{typeName:"AbstractSecurityScheme",nameSpace:"",basicName:"AbstractSecurityScheme",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/security.ts"}],moduleName:null,annotationOverridings:{}},{name:"DigestSecurityScheme",methods:[],typeParameters:[],typeParameterConstraint:[],"implements":[],fields:[{name:"type",type:null,annotations:[],valueConstraint:{isCallConstraint:!1,value:"Digest Authentication"},optional:!1}],isInterface:!1,annotations:[{name:"MetaModel.description",arguments:["Declares globally referable security schema definition"]},{name:"MetaModel.actuallyExports",arguments:["$self"]},{name:"MetaModel.referenceIs",arguments:["settings"]}],"extends":[{typeName:"AbstractSecurityScheme",nameSpace:"",basicName:"AbstractSecurityScheme",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/security.ts"}],moduleName:null,annotationOverridings:{}},{name:"CustomSecurityScheme",methods:[],typeParameters:[],typeParameterConstraint:[],"implements":[],fields:[{name:"type",type:null,annotations:[],valueConstraint:{isCallConstraint:!1,value:"x-{other}"},optional:!1}],isInterface:!1,annotations:[{name:"MetaModel.description",arguments:["Declares globally referable security schema definition"]},{name:"MetaModel.actuallyExports",arguments:["$self"]},{name:"MetaModel.referenceIs",arguments:["settings"]}],"extends":[{typeName:"AbstractSecurityScheme",nameSpace:"",basicName:"AbstractSecurityScheme",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/security.ts"}],moduleName:null,annotationOverridings:{}}],aliases:[],enumDeclarations:[],imports:{MetaModel:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/metamodel.ts",Sys:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/systemTypes.ts",Params:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/parameters.ts",Bodies:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/bodies.ts",Common:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/common.ts",Methods:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/methods.ts"},name:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/security.ts"}]},function(e,t,n){e.exports=[{classes:[{name:"Library",methods:[],typeParameters:[],typeParameterConstraint:[],"implements":[],fields:[{name:"usage",type:{typeName:"string",nameSpace:"",basicName:"string",typeKind:0,typeArguments:[],modulePath:null},annotations:[{name:"MetaModel.description",arguments:["contains description of why library exist"]}],valueConstraint:null,optional:!1},{name:"name",type:{typeName:"string",nameSpace:"",basicName:"string",typeKind:0,typeArguments:[],modulePath:null},annotations:[{name:"MetaModel.key",arguments:[]},{name:"MetaModel.description",arguments:["Namespace which the library is imported under"]}],valueConstraint:null,optional:!1}],isInterface:!1,annotations:[],"extends":[{typeName:"LibraryBase",nameSpace:"",basicName:"LibraryBase",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/api.ts"}],moduleName:null,annotationOverridings:{}},{name:"LibraryBase",methods:[],typeParameters:[],typeParameterConstraint:[],"implements":[],fields:[{name:"schemas",type:{base:{typeName:"TypeDeclaration",nameSpace:"",basicName:"TypeDeclaration",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/api.ts"},typeKind:1},annotations:[{name:"MetaModel.embeddedInMaps",arguments:[]},{name:"MetaModel.description",arguments:['Alias for the equivalent "types" property, for compatibility with RAML 0.8. Deprecated - API definitions should use the "types" property, as the "schemas" alias for that property name may be removed in a future RAML version. The "types" property allows for XML and JSON schemas.']}],valueConstraint:null,optional:!1},{name:"types",type:{base:{typeName:"DataModel.TypeDeclaration",nameSpace:"DataModel",basicName:"TypeDeclaration",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/api.ts"},typeKind:1},annotations:[{name:"MetaModel.embeddedInMaps",arguments:[]},{name:"MetaModel.setsContextValue",arguments:["locationKind","DataModel.LocationKind.MODELS"]},{name:"MetaModel.description",arguments:["Declarations of (data) types for use within this API"]},{name:"MetaModel.markdownDescription",arguments:["Declarations of (data) types for use within this API."]},{name:"MetaModel.valueDescription",arguments:["An object whose properties map type names to type declarations; or an array of such objects"]}],valueConstraint:null,optional:!1},{name:"traits",type:{base:{typeName:"Methods.Trait",nameSpace:"Methods",basicName:"Trait",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/api.ts"},typeKind:1},annotations:[{name:"MetaModel.embeddedInMaps",arguments:[]},{name:"MetaModel.description",arguments:["Declarations of traits used in this API"]},{name:"MetaModel.description",arguments:["Declarations of traits for use within this API"]},{name:"MetaModel.markdownDescription",arguments:["Declarations of traits for use within this API."]},{name:"MetaModel.valueDescription",arguments:["An object whose properties map trait names to trait declarations; or an array of such objects"]}],valueConstraint:null,optional:!1},{name:"resourceTypes",type:{base:{typeName:"Resources.ResourceType",nameSpace:"Resources",basicName:"ResourceType",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/api.ts"},typeKind:1},annotations:[{name:"MetaModel.embeddedInMaps",arguments:[]},{name:"MetaModel.description",arguments:["Declaration of resource types used in this API"]},{name:"MetaModel.description",arguments:["Declarations of resource types for use within this API"]},{name:"MetaModel.markdownDescription",arguments:["Declarations of resource types for use within this API."]},{name:"MetaModel.valueDescription",arguments:["An object whose properties map resource type names to resource type declarations; or an array of such objects"]}],valueConstraint:null,optional:!1},{name:"annotationTypes",type:{base:{typeName:"DataModel.TypeDeclaration",nameSpace:"DataModel",basicName:"TypeDeclaration",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/api.ts"},typeKind:1},annotations:[{name:"MetaModel.setsContextValue",arguments:["decls","true"]},{name:"MetaModel.embeddedInMaps",arguments:[]},{name:"MetaModel.description",arguments:["Declarations of annotation types for use by annotations"]},{name:"MetaModel.markdownDescription",arguments:["Declarations of annotation types for use by annotations."]},{name:"MetaModel.valueDescription",arguments:["An object whose properties map annotation type names to annotation type declarations; or an array of such objects"]}],valueConstraint:null,optional:!1},{name:"securitySchemes",type:{base:{typeName:"Security.AbstractSecurityScheme",nameSpace:"Security",basicName:"AbstractSecurityScheme",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/api.ts"},typeKind:1},annotations:[{name:"MetaModel.embeddedInMaps",arguments:[]},{name:"MetaModel.description",arguments:["Security schemas declarations"]},{name:"MetaModel.description",arguments:["Declarations of security schemes for use within this API."]},{name:"MetaModel.markdownDescription",arguments:["Declarations of security schemes for use within this API."]},{name:"MetaModel.valueDescription",arguments:["An object whose properties map security scheme names to security scheme declarations; or an array of such objects"]}],valueConstraint:null,optional:!1}],isInterface:!1,annotations:[{name:"MetaModel.internalClass",arguments:[]}],"extends":[{typeName:"FragmentDeclaration",nameSpace:"",basicName:"FragmentDeclaration",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/api.ts"}],moduleName:null,annotationOverridings:{}},{name:"Api",methods:[],typeParameters:[],typeParameterConstraint:[],"implements":[],fields:[{name:"title",type:{typeName:"string",nameSpace:"",basicName:"string",typeKind:0,typeArguments:[],modulePath:null},annotations:[{name:"MetaModel.required",arguments:[]},{name:"MetaModel.description",arguments:["Short plain-text label for the API"]}],valueConstraint:null,optional:!1},{name:"description",type:{typeName:"Sys.MarkdownString",nameSpace:"Sys",basicName:"MarkdownString",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/api.ts"},annotations:[{name:"MetaModel.description",arguments:["A longer, human-friendly description of the API"]}],valueConstraint:null,optional:!1},{name:"version",type:{typeName:"string",nameSpace:"",basicName:"string",typeKind:0,typeArguments:[],modulePath:null},annotations:[{name:"MetaModel.description",arguments:["The version of the API, e.g. 'v1'"]}],valueConstraint:null,optional:!1},{name:"baseUri",type:{typeName:"Sys.FullUriTemplateString",nameSpace:"Sys",basicName:"FullUriTemplateString",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/api.ts"},annotations:[{name:"MetaModel.description",arguments:["A URI that's to be used as the base of all the resources' URIs. Often used as the base of the URL of each resource, containing the location of the API. Can be a template URI."]}],valueConstraint:null,optional:!1},{name:"baseUriParameters",type:{base:{typeName:"DataModel.TypeDeclaration",nameSpace:"DataModel",basicName:"TypeDeclaration",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/api.ts"},typeKind:1},annotations:[{name:"MetaModel.setsContextValue",arguments:["location","DataModel.ModelLocation.BURI"]},{name:"MetaModel.setsContextValue",arguments:["locationKind","DataModel.LocationKind.APISTRUCTURE"]},{name:"MetaModel.description",arguments:["Named parameters used in the baseUri (template)"]}],valueConstraint:null,optional:!1},{name:"protocols",type:{base:{typeName:"string",nameSpace:"",basicName:"string",typeKind:0,typeArguments:[],modulePath:null},typeKind:1},annotations:[{name:"MetaModel.oneOf",arguments:[["HTTP","HTTPS"]]},{name:"MetaModel.description",arguments:["The protocols supported by the API"]},{name:"MetaModel.valueDescription",arguments:['Array of strings, with each being "HTTP" or "HTTPS", case-insensitive']}],valueConstraint:null,optional:!1},{name:"mediaType",type:{base:{typeName:"Bodies.MimeType",nameSpace:"Bodies",basicName:"MimeType",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/api.ts"},typeKind:1},annotations:[{name:"MetaModel.oftenKeys",arguments:[["application/json","application/xml","application/x-www-form-urlencoded","multipart/form-data"]]},{name:"MetaModel.description",arguments:['The default media type to use for request and response bodies (payloads), e.g. "application/json"']},{name:"MetaModel.inherited",arguments:[]},{name:"MetaModel.valueDescription",arguments:["Media type string"]}],valueConstraint:null,optional:!1},{name:"securedBy",type:{base:{typeName:"Security.SecuritySchemeRef",nameSpace:"Security",basicName:"SecuritySchemeRef",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/api.ts"},typeKind:1},annotations:[{name:"MetaModel.description",arguments:["The security schemes that apply to every resource and method in the API"]}],valueConstraint:null,optional:!1},{name:"resources",type:{base:{typeName:"Resources.Resource",nameSpace:"Resources",basicName:"Resource",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/api.ts"},typeKind:1},annotations:[{name:"MetaModel.documentationTableLabel",arguments:["/&lt;relativeUri&gt;"]},{name:"MetaModel.newInstanceName",arguments:["New Resource"]},{name:"MetaModel.description",arguments:["The resources of the API, identified as relative URIs that begin with a slash (/). Every property whose key begins with a slash (/), and is either at the root of the API definition or is the child property of a resource property, is a resource property, e.g.: /users, /{groupId}, etc"]}],valueConstraint:null,optional:!1},{name:"documentation",type:{base:{typeName:"DocumentationItem",nameSpace:"",basicName:"DocumentationItem",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/api.ts"},typeKind:1},annotations:[{name:"MetaModel.description",arguments:["Additional overall documentation for the API"]}],valueConstraint:null,optional:!1},{name:"RAMLVersion",type:{typeName:"string",nameSpace:"",basicName:"string",typeKind:0,typeArguments:[],modulePath:null},annotations:[{name:"MetaModel.customHandling",arguments:[]},{name:"MetaModel.description",arguments:['Returns RAML version. "RAML10" string is returned for RAML 1.0. "RAML08" string is returned for RAML 0.8.']}],valueConstraint:null,optional:!1}],isInterface:!1,annotations:[],"extends":[{typeName:"LibraryBase",nameSpace:"",basicName:"LibraryBase",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/api.ts"}],moduleName:null,annotationOverridings:{annotations:[{name:"MetaModel.markdownDescription",arguments:['Annotations to be applied to this API. Annotations are any property whose key begins with "(" and ends with ")" and whose name (the part between the beginning and ending parentheses) is a declared annotation name.']}]}},{name:"Overlay",methods:[],typeParameters:[],typeParameterConstraint:[],"implements":[],fields:[{name:"usage",type:{typeName:"string",nameSpace:"",basicName:"string",typeKind:0,typeArguments:[],modulePath:null},annotations:[{name:"MetaModel.description",arguments:["contains description of why overlay exist"]}],valueConstraint:null,optional:!1},{name:"extends",type:{typeName:"string",nameSpace:"",basicName:"string",typeKind:0,typeArguments:[],modulePath:null},annotations:[{name:"MetaModel.required",arguments:[]},{name:"MetaModel.description",arguments:["Location of a valid RAML API definition (or overlay or extension), the overlay is applied to."]}],valueConstraint:null,optional:!1},{name:"title",type:{typeName:"string",nameSpace:"",basicName:"string",typeKind:0,typeArguments:[],modulePath:null},annotations:[{name:"MetaModel.description",arguments:["Short plain-text label for the API"]}],valueConstraint:null,optional:!1}],isInterface:!1,annotations:[],"extends":[{typeName:"Api",nameSpace:"",basicName:"Api",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/api.ts"}],moduleName:null,annotationOverridings:{}},{name:"Extension",methods:[],typeParameters:[],typeParameterConstraint:[],"implements":[],fields:[{name:"usage",type:{typeName:"string",nameSpace:"",basicName:"string",typeKind:0,typeArguments:[],modulePath:null},annotations:[{name:"MetaModel.description",arguments:["contains description of why extension exist"]}],valueConstraint:null,optional:!1},{name:"extends",type:{typeName:"string",nameSpace:"",basicName:"string",typeKind:0,typeArguments:[],modulePath:null},annotations:[{name:"MetaModel.required",arguments:[]},{name:"MetaModel.description",arguments:["Location of a valid RAML API definition (or overlay or extension), the extension is applied to"]}],valueConstraint:null,optional:!1},{name:"title",type:{typeName:"string",nameSpace:"",basicName:"string",typeKind:0,typeArguments:[],modulePath:null},annotations:[{name:"MetaModel.description",arguments:["Short plain-text label for the API"]}],valueConstraint:null,optional:!1}],isInterface:!1,annotations:[],"extends":[{typeName:"Api",nameSpace:"",basicName:"Api",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/api.ts"}],moduleName:null,annotationOverridings:{}},{name:"UsesDeclaration",methods:[],typeParameters:[],typeParameterConstraint:[],"implements":[],fields:[{name:"key",type:{typeName:"string",nameSpace:"",basicName:"string",typeKind:0,typeArguments:[],modulePath:null},annotations:[{name:"MetaModel.key",arguments:[]},{name:"MetaModel.description",arguments:["Name prefix (without dot) used to refer imported declarations"]}],valueConstraint:null,optional:!1},{name:"value",type:{typeName:"string",nameSpace:"",basicName:"string",typeKind:0,typeArguments:[],modulePath:null},annotations:[{name:"MetaModel.description",arguments:["Content of the schema"]},{name:"MetaModel.canBeValue",arguments:[]},{name:"MetaModel.value",arguments:[]}],valueConstraint:null,optional:!1}],isInterface:!1,annotations:[],"extends":[{typeName:"Annotable",nameSpace:"",basicName:"Annotable",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/api.ts"}],moduleName:null,annotationOverridings:{}},{name:"FragmentDeclaration",methods:[],typeParameters:[],typeParameterConstraint:[],"implements":[],fields:[{name:"uses",type:{base:{typeName:"UsesDeclaration",nameSpace:"",basicName:"UsesDeclaration",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/api.ts"},typeKind:1},annotations:[{name:"MetaModel.embeddedInMaps",arguments:[]}],valueConstraint:null,optional:!1}],isInterface:!1,annotations:[],"extends":[{typeName:"Annotable",nameSpace:"",basicName:"Annotable",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/api.ts"}],moduleName:null,annotationOverridings:{}},{name:"DocumentationItem",methods:[],typeParameters:[],typeParameterConstraint:[],"implements":[],fields:[{name:"title",type:{typeName:"string",nameSpace:"",basicName:"string",typeKind:0,typeArguments:[],modulePath:null},annotations:[{name:"MetaModel.description",arguments:["Title of documentation section"]},{name:"MetaModel.required",arguments:[]}],valueConstraint:null,optional:!1},{name:"content",type:{typeName:"Sys.MarkdownString",nameSpace:"Sys",basicName:"MarkdownString",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/api.ts"},annotations:[{name:"MetaModel.description",arguments:["Content of documentation section"]},{name:"MetaModel.required",arguments:[]}],valueConstraint:null,optional:!1}],isInterface:!1,annotations:[{name:"MetaModel.possibleInterfaces",arguments:[["FragmentDeclaration"]]}],"extends":[{typeName:"Annotable",nameSpace:"",basicName:"Annotable",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/api.ts"}],moduleName:null,annotationOverridings:{}}],aliases:[],enumDeclarations:[],imports:{MetaModel:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/metamodel.ts",Sys:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/systemTypes.ts",Methods:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/methods.ts",
Resources:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/resources.ts",Decls:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/declarations.ts",Params:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/parameters.ts",Common:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/common.ts",Bodies:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/bodies.ts",DataModel:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/datamodel.ts",Security:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/security.ts"},name:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/api.ts"},{classes:[{name:"SpecPartMetaData",methods:[],typeParameters:[],typeParameterConstraint:[],"implements":[],fields:[],isInterface:!0,annotations:[],"extends":[],moduleName:null,annotationOverridings:{}}],aliases:[],enumDeclarations:[],imports:{},name:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/metamodel.ts"},{classes:[{name:"ValueType",methods:[{returnType:{typeName:"string",nameSpace:"",basicName:"string",typeKind:0,typeArguments:[],modulePath:null},name:"value",start:170,end:210,text:"\n\n  value():string {\n    return null\n  }",arguments:[]}],typeParameters:[],typeParameterConstraint:[],"implements":[],fields:[],isInterface:!1,annotations:[],"extends":[{typeName:"Annotable",nameSpace:"",basicName:"Annotable",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/systemTypes.ts"}],moduleName:null,annotationOverridings:{}},{name:"StringType",methods:[],typeParameters:[],typeParameterConstraint:[],"implements":[],fields:[],isInterface:!1,annotations:[{name:"MetaModel.nameAtRuntime",arguments:["string"]},{name:"MetaModel.alias",arguments:["string"]}],"extends":[{typeName:"ValueType",nameSpace:"",basicName:"ValueType",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/systemTypes.ts"}],moduleName:null,annotationOverridings:{}},{name:"AnyType",methods:[],typeParameters:[],typeParameterConstraint:[],"implements":[],fields:[],isInterface:!1,annotations:[{name:"MetaModel.nameAtRuntime",arguments:["any"]},{name:"MetaModel.alias",arguments:["any"]}],"extends":[{typeName:"ValueType",nameSpace:"",basicName:"ValueType",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/systemTypes.ts"}],moduleName:null,annotationOverridings:{}},{name:"NumberType",methods:[],typeParameters:[],typeParameterConstraint:[],"implements":[],fields:[],isInterface:!1,annotations:[{name:"MetaModel.nameAtRuntime",arguments:["number"]},{name:"MetaModel.alias",arguments:["number"]}],"extends":[{typeName:"ValueType",nameSpace:"",basicName:"ValueType",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/systemTypes.ts"}],moduleName:null,annotationOverridings:{}},{name:"IntegerType",methods:[],typeParameters:[],typeParameterConstraint:[],"implements":[],fields:[],isInterface:!1,annotations:[{name:"MetaModel.nameAtRuntime",arguments:["integer"]},{name:"MetaModel.alias",arguments:["integer"]}],"extends":[{typeName:"ValueType",nameSpace:"",basicName:"ValueType",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/systemTypes.ts"}],moduleName:null,annotationOverridings:{}},{name:"NullType",methods:[],typeParameters:[],typeParameterConstraint:[],"implements":[],fields:[],isInterface:!1,annotations:[{name:"MetaModel.nameAtRuntime",arguments:["null"]},{name:"MetaModel.alias",arguments:["null"]}],"extends":[{typeName:"ValueType",nameSpace:"",basicName:"ValueType",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/systemTypes.ts"}],moduleName:null,annotationOverridings:{}},{name:"TimeOnlyType",methods:[],typeParameters:[],typeParameterConstraint:[],"implements":[],fields:[],isInterface:!1,annotations:[{name:"MetaModel.nameAtRuntime",arguments:["time-only"]},{name:"MetaModel.alias",arguments:["time-only"]}],"extends":[{typeName:"ValueType",nameSpace:"",basicName:"ValueType",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/systemTypes.ts"}],moduleName:null,annotationOverridings:{}},{name:"DateOnlyType",methods:[],typeParameters:[],typeParameterConstraint:[],"implements":[],fields:[],isInterface:!1,annotations:[{name:"MetaModel.nameAtRuntime",arguments:["date-only"]},{name:"MetaModel.alias",arguments:["date-only"]}],"extends":[{typeName:"ValueType",nameSpace:"",basicName:"ValueType",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/systemTypes.ts"}],moduleName:null,annotationOverridings:{}},{name:"DateTimeOnlyType",methods:[],typeParameters:[],typeParameterConstraint:[],"implements":[],fields:[],isInterface:!1,annotations:[{name:"MetaModel.nameAtRuntime",arguments:["datetime-only"]},{name:"MetaModel.alias",arguments:["datetime-only"]}],"extends":[{typeName:"ValueType",nameSpace:"",basicName:"ValueType",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/systemTypes.ts"}],moduleName:null,annotationOverridings:{}},{name:"DateTimeType",methods:[],typeParameters:[],typeParameterConstraint:[],"implements":[],fields:[],isInterface:!1,annotations:[{name:"MetaModel.nameAtRuntime",arguments:["datetime"]},{name:"MetaModel.alias",arguments:["datetime"]}],"extends":[{typeName:"ValueType",nameSpace:"",basicName:"ValueType",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/systemTypes.ts"}],moduleName:null,annotationOverridings:{}},{name:"FileType",methods:[],typeParameters:[],typeParameterConstraint:[],"implements":[],fields:[],isInterface:!1,annotations:[{name:"MetaModel.nameAtRuntime",arguments:["file"]},{name:"MetaModel.alias",arguments:["file"]}],"extends":[{typeName:"ValueType",nameSpace:"",basicName:"ValueType",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/systemTypes.ts"}],moduleName:null,annotationOverridings:{}},{name:"BooleanType",methods:[],typeParameters:[],typeParameterConstraint:[],"implements":[],fields:[],isInterface:!1,annotations:[{name:"MetaModel.nameAtRuntime",arguments:["boolean"]},{name:"MetaModel.alias",arguments:["boolean"]}],"extends":[{typeName:"ValueType",nameSpace:"",basicName:"ValueType",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/systemTypes.ts"}],moduleName:null,annotationOverridings:{}},{name:"Reference",methods:[],typeParameters:["T"],typeParameterConstraint:[null],"implements":[],fields:[{name:"structuredValue",type:{typeName:"DataModel.TypeInstance",nameSpace:"DataModel",basicName:"TypeInstance",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/systemTypes.ts"},annotations:[{name:"MetaModel.customHandling",arguments:[]},{name:"MetaModel.description",arguments:["Returns a structured object if the reference point to one."]}],valueConstraint:null,optional:!1},{name:"name",type:{typeName:"string",nameSpace:"",basicName:"string",typeKind:0,typeArguments:[],modulePath:null},annotations:[{name:"MetaModel.customHandling",arguments:[]},{name:"MetaModel.description",arguments:["Returns name of referenced object"]}],valueConstraint:null,optional:!1}],isInterface:!1,annotations:[],"extends":[{typeName:"ValueType",nameSpace:"",basicName:"ValueType",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/systemTypes.ts"}],moduleName:null,annotationOverridings:{}},{name:"UriTemplate",methods:[],typeParameters:[],typeParameterConstraint:[],"implements":[],fields:[],isInterface:!1,annotations:[{name:"MetaModel.description",arguments:["This type currently serves both for absolute and relative urls"]}],"extends":[{typeName:"StringType",nameSpace:"",basicName:"StringType",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/systemTypes.ts"}],moduleName:null,annotationOverridings:{}},{name:"StatusCodeString",methods:[],typeParameters:[],typeParameterConstraint:[],"implements":[],fields:[],isInterface:!1,annotations:[],"extends":[{typeName:"StringType",nameSpace:"",basicName:"StringType",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/systemTypes.ts"}],moduleName:null,annotationOverridings:{}},{name:"RelativeUriString",methods:[],typeParameters:[],typeParameterConstraint:[],"implements":[],fields:[],isInterface:!1,annotations:[{name:"MetaModel.description",arguments:["This  type describes relative uri templates"]}],"extends":[{typeName:"UriTemplate",nameSpace:"",basicName:"UriTemplate",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/systemTypes.ts"}],moduleName:null,annotationOverridings:{}},{name:"FullUriTemplateString",methods:[],typeParameters:[],typeParameterConstraint:[],"implements":[],fields:[],isInterface:!1,annotations:[{name:"MetaModel.description",arguments:["This  type describes absolute uri templates"]}],"extends":[{typeName:"UriTemplate",nameSpace:"",basicName:"UriTemplate",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/systemTypes.ts"}],moduleName:null,annotationOverridings:{}},{name:"FixedUriString",methods:[],typeParameters:[],typeParameterConstraint:[],"implements":[],fields:[],isInterface:!1,annotations:[{name:"MetaModel.description",arguments:["This  type describes fixed uris"]}],"extends":[{typeName:"StringType",nameSpace:"",basicName:"StringType",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/systemTypes.ts"}],moduleName:null,annotationOverridings:{}},{name:"ContentType",methods:[],typeParameters:[],typeParameterConstraint:[],"implements":[],fields:[],isInterface:!1,annotations:[],"extends":[{typeName:"StringType",nameSpace:"",basicName:"StringType",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/systemTypes.ts"}],moduleName:null,annotationOverridings:{}},{name:"MarkdownString",methods:[],typeParameters:[],typeParameterConstraint:[],"implements":[],fields:[],isInterface:!1,annotations:[{name:"MetaModel.innerType",arguments:["markdown"]},{name:"MetaModel.description",arguments:["[GitHub Flavored Markdown](https://help.github.com/articles/github-flavored-markdown/)"]}],"extends":[{typeName:"StringType",nameSpace:"",basicName:"StringType",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/systemTypes.ts"}],moduleName:null,annotationOverridings:{}},{name:"SchemaString",methods:[],typeParameters:[],typeParameterConstraint:[],"implements":[],fields:[],isInterface:!1,annotations:[{name:"MetaModel.description",arguments:["Schema at this moment only two subtypes are supported (json schema and xsd)"]},{name:"MetaModel.alias",arguments:["schema"]}],"extends":[{typeName:"StringType",nameSpace:"",basicName:"StringType",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/systemTypes.ts"}],moduleName:null,annotationOverridings:{}}],aliases:[],enumDeclarations:[],imports:{MetaModel:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/metamodel.ts",DataModel:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/datamodel.ts",Common:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/common.ts"},name:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/systemTypes.ts"},{classes:[{name:"ExampleSpec",methods:[],typeParameters:[],typeParameterConstraint:[],"implements":[],fields:[{name:"value",type:{typeName:"any",nameSpace:"",basicName:"any",typeKind:0,typeArguments:[],modulePath:null},annotations:[{name:"MetaModel.example",arguments:[]},{name:"MetaModel.selfNode",arguments:[]},{name:"MetaModel.description",arguments:["String representation of example"]},{name:"MetaModel.required",arguments:[]},{name:"MetaModel.valueDescription",arguments:["* Valid value for this type<br>* String representing the serialized version of a valid value"]}],valueConstraint:null,optional:!1},{name:"structuredValue",type:{typeName:"TypeInstance",nameSpace:"",basicName:"TypeInstance",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/datamodel.ts"},annotations:[{name:"MetaModel.customHandling",arguments:[]},{name:"MetaModel.description",arguments:["Returns object representation of example, if possible"]}],valueConstraint:null,optional:!1},{name:"strict",type:{typeName:"boolean",nameSpace:"",basicName:"boolean",typeKind:0,typeArguments:[],modulePath:null},annotations:[{name:"MetaModel.description",arguments:["By default, examples are validated against any type declaration. Set this to false to allow examples that need not validate."]}],valueConstraint:null,optional:!1},{name:"name",type:{typeName:"string",nameSpace:"",basicName:"string",typeKind:0,typeArguments:[],modulePath:null},annotations:[{name:"MetaModel.key",arguments:[]},{name:"MetaModel.hide",arguments:[]},{name:"MetaModel.description",arguments:["Example identifier, if specified"]}],valueConstraint:null,optional:!1},{name:"displayName",type:{typeName:"string",nameSpace:"",basicName:"string",typeKind:0,typeArguments:[],modulePath:null},annotations:[{name:"MetaModel.description",arguments:["An alternate, human-friendly name for the example"]}],valueConstraint:null,optional:!1},{name:"description",type:{typeName:"Sys.MarkdownString",nameSpace:"Sys",basicName:"MarkdownString",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/datamodel.ts"},annotations:[{name:"MetaModel.description",arguments:["A longer, human-friendly description of the example"]},{name:"MetaModel.valueDescription",arguments:["markdown string"]}],valueConstraint:null,optional:!1}],isInterface:!1,annotations:[{name:"MetaModel.customHandling",arguments:[]},{name:"MetaModel.possibleInterfaces",arguments:[["FragmentDeclaration"]]}],"extends":[{typeName:"Annotable",nameSpace:"",basicName:"Annotable",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/datamodel.ts"}],moduleName:null,annotationOverridings:{annotations:[{name:"MetaModel.markdownDescription",arguments:['Annotations to be applied to this example. Annotations are any property whose key begins with "(" and ends with ")" and whose name (the part between the beginning and ending parentheses) is a declared annotation name.']}]}},{name:"TypeDeclaration",methods:[],typeParameters:[],typeParameterConstraint:[],"implements":[],fields:[{name:"name",type:{typeName:"string",nameSpace:"",basicName:"string",typeKind:0,typeArguments:[],modulePath:null},annotations:[{name:"MetaModel.key",arguments:[]},{name:"MetaModel.description",arguments:["name of the parameter"]},{name:"MetaModel.extraMetaKey",arguments:["headers"]},{name:"MetaModel.hide",arguments:[]}],valueConstraint:null,optional:!1},{name:"displayName",type:{typeName:"string",nameSpace:"",basicName:"string",typeKind:0,typeArguments:[],modulePath:null},annotations:[{name:"MetaModel.description",arguments:["The displayName attribute specifies the type display name. It is a friendly name used only for  display or documentation purposes. If displayName is not specified, it defaults to the element's key (the name of the property itself)."]}],valueConstraint:null,optional:!1},{name:"facets",type:{base:{typeName:"TypeDeclaration",nameSpace:"",basicName:"TypeDeclaration",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/datamodel.ts"},typeKind:1},annotations:[{name:"MetaModel.declaringFields",arguments:[]},{name:"MetaModel.description",arguments:["When extending from a type you can define new facets (which can then be set to concrete values by subtypes)."]},{name:"MetaModel.hide",arguments:[]}],valueConstraint:null,optional:!1},{name:"fixedFacets",type:{typeName:"TypeInstance",nameSpace:"",basicName:"TypeInstance",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/datamodel.ts"},annotations:[{name:"MetaModel.customHandling",arguments:[]},{name:"MetaModel.description",arguments:["Returns facets fixed by the type. Value is an object with properties named after facets fixed. Value of each property is a value of the corresponding facet."]}],valueConstraint:null,optional:!1},{name:"schema",type:{typeName:"string",nameSpace:"",basicName:"string",typeKind:0,typeArguments:[],modulePath:null},annotations:[{name:"MetaModel.typeExpression",arguments:[]},{name:"MetaModel.allowMultiple",arguments:[]},{name:"MetaModel.description",arguments:['Alias for the equivalent "type" property, for compatibility with RAML 0.8. Deprecated - API definitions should use the "type" property, as the "schema" alias for that property name may be removed in a future RAML version. The "type" property allows for XML and JSON schemas.']},{name:"MetaModel.valueDescription",arguments:["Single string denoting the base type or type expression"]}],valueConstraint:null,optional:!1},{name:"type",type:{typeName:"string",nameSpace:"",basicName:"string",typeKind:0,typeArguments:[],modulePath:null},annotations:[{name:"MetaModel.typeExpression",arguments:[]},{name:"MetaModel.allowMultiple",arguments:[]},{name:"MetaModel.canBeValue",arguments:[]},{name:"MetaModel.defaultValue",arguments:["string"]},{name:"MetaModel.descriminatingProperty",arguments:[]},{name:"MetaModel.description",arguments:["A base type which the current type extends, or more generally a type expression."]},{name:"MetaModel.valueDescription",arguments:["string denoting the base type or type expression"]}],valueConstraint:null,optional:!1},{name:"structuredType",type:{typeName:"TypeInstance",nameSpace:"",basicName:"TypeInstance",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/datamodel.ts"},annotations:[{name:"MetaModel.customHandling",arguments:[]},{name:"MetaModel.typeExpression",arguments:[]},{name:"MetaModel.description",arguments:["Inlined supertype definition."]},{name:"MetaModel.valueDescription",arguments:["Inlined supertype definition"]}],valueConstraint:null,optional:!1},{name:"location",type:{typeName:"ModelLocation",nameSpace:"",basicName:"ModelLocation",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/datamodel.ts"},annotations:[{name:"MetaModel.system",arguments:[]},{name:"MetaModel.description",arguments:["Location of the parameter (can not be edited by user)"]},{name:"MetaModel.hide",arguments:[]}],valueConstraint:null,optional:!1},{name:"locationKind",type:{typeName:"LocationKind",nameSpace:"",basicName:"LocationKind",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/datamodel.ts"},annotations:[{name:"MetaModel.system",arguments:[]},{name:"MetaModel.description",arguments:["Kind of location"]},{name:"MetaModel.hide",arguments:[]}],valueConstraint:null,optional:!1},{name:"default",type:{typeName:"any",nameSpace:"",basicName:"any",typeKind:0,typeArguments:[],modulePath:null},annotations:[{name:"MetaModel.description",arguments:["Provides default value for a property"]},{name:"MetaModel.hide",arguments:[]}],valueConstraint:null,optional:!1},{name:"example",type:{typeName:"ExampleSpec",nameSpace:"",basicName:"ExampleSpec",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/datamodel.ts"},annotations:[{name:"MetaModel.example",arguments:[]},{name:"MetaModel.selfNode",arguments:[]},{name:"MetaModel.description",arguments:["An example of this type instance represented as string or yaml map/sequence. This can be used, e.g., by documentation generators to generate sample values for an object of this type. Cannot be present if the examples property is present."]},{name:"MetaModel.valueDescription",arguments:["* Valid value for this type<br>* String representing the serialized version of a valid value"]}],valueConstraint:null,optional:!1},{name:"examples",type:{base:{typeName:"ExampleSpec",nameSpace:"",basicName:"ExampleSpec",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/datamodel.ts"},typeKind:1},annotations:[{name:"MetaModel.example",arguments:[]},{name:"MetaModel.selfNode",arguments:[]},{name:"MetaModel.description",arguments:["An example of this type instance represented as string. This can be used, e.g., by documentation generators to generate sample values for an object of this type. Cannot be present if the example property is present."]},{name:"MetaModel.valueDescription",arguments:["* Valid value for this type<br>* String representing the serialized version of a valid value"]}],valueConstraint:null,optional:!1},{name:"required",type:{typeName:"boolean",nameSpace:"",basicName:"boolean",typeKind:0,typeArguments:[],modulePath:null},annotations:[{name:"MetaModel.requireValue",arguments:["fieldOrParam",!0]},{name:"MetaModel.description",arguments:["Sets if property is optional or not"]},{name:"MetaModel.describesAnnotation",arguments:["required"]},{name:"MetaModel.hide",arguments:[]},{name:"MetaModel.defaultBooleanValue",arguments:[!0]}],valueConstraint:null,optional:!1},{name:"description",type:{typeName:"Sys.MarkdownString",nameSpace:"Sys",basicName:"MarkdownString",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/datamodel.ts"},annotations:[{name:"MetaModel.description",arguments:["A longer, human-friendly description of the type"]},{name:"MetaModel.valueDescription",arguments:["markdown string"]}],valueConstraint:null,optional:!1},{name:"xml",type:{typeName:"XMLFacetInfo",nameSpace:"",basicName:"XMLFacetInfo",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/datamodel.ts"},annotations:[],valueConstraint:null,optional:!1},{name:"allowedTargets",type:{base:{typeName:"AnnotationTarget",nameSpace:"",basicName:"AnnotationTarget",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/datamodel.ts"},typeKind:1},annotations:[{name:"MetaModel.oneOf",arguments:[["API","DocumentationItem","Resource","Method","Response","RequestBody","ResponseBody","TypeDeclaration","NamedExample","ResourceType","Trait","SecurityScheme","SecuritySchemeSettings","AnnotationTypeDeclaration","Library","Overlay","Extension","Scalar"]]},{name:"MetaModel.description",arguments:["Restrictions on where annotations of this type can be applied. If this property is specified, annotations of this type may only be applied on a property corresponding to one of the target names specified as the value of this property."]},{name:"MetaModel.valueDescription",arguments:["An array, or single, of names allowed target nodes."]}],valueConstraint:null,optional:!1},{name:"isAnnotation",type:{typeName:"boolean",nameSpace:"",basicName:"boolean",typeKind:0,typeArguments:[],modulePath:null},annotations:[{name:"MetaModel.description",arguments:["Whether the type represents annotation"]}],valueConstraint:null,optional:!1},{name:"parametrizedProperties",type:{typeName:"TypeInstance",nameSpace:"",basicName:"TypeInstance",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/datamodel.ts"},annotations:[{name:"MetaModel.customHandling",arguments:[]},{name:"MetaModel.description",arguments:["For types defined in traits or resource types returns object representation of parametrized properties"]}],valueConstraint:null,optional:!1}],isInterface:!1,annotations:[{name:"MetaModel.convertsToGlobalOfType",arguments:["SchemaString"]},{name:"MetaModel.canInherit",arguments:["mediaType"]},{name:"MetaModel.possibleInterfaces",arguments:[["FragmentDeclaration"]]}],"extends":[{typeName:"Annotable",nameSpace:"",basicName:"Annotable",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/datamodel.ts"}],moduleName:null,annotationOverridings:{annotations:[{name:"MetaModel.markdownDescription",arguments:['Annotations to be applied to this type. Annotations are any property whose key begins with "(" and ends with ")" and whose name (the part between the beginning and ending parentheses) is a declared annotation name.']}]}},{name:"XMLFacetInfo",methods:[],typeParameters:[],typeParameterConstraint:[],"implements":[],fields:[{name:"attribute",type:{typeName:"boolean",nameSpace:"",basicName:"boolean",typeKind:0,typeArguments:[],modulePath:null},annotations:[{name:"MetaModel.description",arguments:["If attribute is set to true, a type instance should be serialized as an XML attribute. It can only be true for scalar types."]}],valueConstraint:null,optional:!1},{name:"wrapped",type:{typeName:"boolean",nameSpace:"",basicName:"boolean",typeKind:0,typeArguments:[],modulePath:null},annotations:[{name:"MetaModel.description",arguments:["If wrapped is set to true, a type instance should be wrapped in its own XML element. It can not be true for scalar types and it can not be true at the same moment when attribute is true."]}],valueConstraint:null,optional:!1},{name:"name",type:{typeName:"string",nameSpace:"",basicName:"string",typeKind:0,typeArguments:[],modulePath:null},annotations:[{name:"MetaModel.description",arguments:["Allows to override the name of the XML element or XML attribute in it's XML representation."]}],valueConstraint:null,optional:!1},{name:"namespace",type:{typeName:"string",nameSpace:"",basicName:"string",typeKind:0,typeArguments:[],modulePath:null},annotations:[{name:"MetaModel.description",arguments:["Allows to configure the name of the XML namespace."]}],valueConstraint:null,optional:!1},{name:"prefix",type:{typeName:"string",nameSpace:"",basicName:"string",typeKind:0,typeArguments:[],modulePath:null},annotations:[{name:"MetaModel.description",arguments:["Allows to configure the prefix which will be used during serialization to XML."]}],valueConstraint:null,optional:!1}],isInterface:!1,annotations:[],"extends":[{typeName:"Annotable",nameSpace:"",basicName:"Annotable",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/datamodel.ts"}],moduleName:null,annotationOverridings:{}},{name:"ArrayTypeDeclaration",methods:[],typeParameters:[],typeParameterConstraint:[],"implements":[],fields:[{name:"type",type:null,annotations:[],valueConstraint:{isCallConstraint:!1,value:"array"},optional:!1},{name:"uniqueItems",type:{typeName:"boolean",nameSpace:"",basicName:"boolean",typeKind:0,typeArguments:[],modulePath:null},annotations:[{name:"MetaModel.facetId",arguments:["uniqueItems"]},{name:"MetaModel.description",arguments:["Should items in array be unique"]}],valueConstraint:null,optional:!1},{name:"items",type:{typeName:"string",nameSpace:"",basicName:"string",typeKind:0,typeArguments:[],modulePath:null},annotations:[{name:"MetaModel.typeExpression",arguments:[]},{name:"MetaModel.allowMultiple",arguments:[]},{name:"MetaModel.canBeValue",arguments:[]},{name:"MetaModel.description",arguments:["Array component type."]},{name:"MetaModel.valueDescription",arguments:["Inline type declaration or type name."]}],valueConstraint:null,optional:!1},{name:"minItems",type:{typeName:"number",nameSpace:"",basicName:"number",typeKind:0,typeArguments:[],modulePath:null},annotations:[{name:"MetaModel.facetId",arguments:["minItems"]},{name:"MetaModel.description",arguments:["Minimum amount of items in array"]},{name:"MetaModel.valueDescription",arguments:["integer ( >= 0 ). Defaults to 0"]}],valueConstraint:null,optional:!1},{name:"maxItems",type:{typeName:"number",nameSpace:"",basicName:"number",typeKind:0,typeArguments:[],modulePath:null},annotations:[{name:"MetaModel.facetId",arguments:["maxItems"]},{name:"MetaModel.description",arguments:["Maximum amount of items in array"]},{name:"MetaModel.valueDescription",arguments:["integer ( >= 0 ). Defaults to undefined."]}],valueConstraint:null,optional:!1}],isInterface:!1,annotations:[{name:"MetaModel.convertsToGlobalOfType",arguments:["SchemaString"]},{name:"MetaModel.alias",arguments:["array"]},{name:"MetaModel.declaresSubTypeOf",arguments:["TypeDeclaration"]}],"extends":[{typeName:"TypeDeclaration",nameSpace:"",basicName:"TypeDeclaration",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/datamodel.ts"}],moduleName:null,annotationOverridings:{}},{name:"UnionTypeDeclaration",methods:[],typeParameters:[],typeParameterConstraint:[],"implements":[],fields:[{name:"type",type:null,annotations:[],valueConstraint:{isCallConstraint:!1,value:"union"},optional:!1}],isInterface:!1,annotations:[{name:"MetaModel.convertsToGlobalOfType",arguments:["SchemaString"]},{name:"MetaModel.requireValue",arguments:["locationKind","LocationKind.MODELS"]},{name:"MetaModel.declaresSubTypeOf",arguments:["TypeDeclaration"]}],"extends":[{typeName:"TypeDeclaration",nameSpace:"",basicName:"TypeDeclaration",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/datamodel.ts"}],moduleName:null,annotationOverridings:{}},{name:"ObjectTypeDeclaration",methods:[],typeParameters:[],typeParameterConstraint:[],"implements":[],fields:[{name:"type",type:null,annotations:[{name:"MetaModel.hide",arguments:[]}],valueConstraint:{isCallConstraint:!1,value:"object"},optional:!1},{name:"properties",type:{base:{typeName:"TypeDeclaration",nameSpace:"",basicName:"TypeDeclaration",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/datamodel.ts"},typeKind:1},annotations:[{name:"MetaModel.setsContextValue",arguments:["fieldOrParam",!0]},{name:"MetaModel.description",arguments:["The properties that instances of this type may or must have."]},{name:"MetaModel.valueDescription",arguments:["An object whose keys are the properties' names and whose values are property declarations."]}],valueConstraint:null,optional:!1},{name:"minProperties",type:{typeName:"number",nameSpace:"",basicName:"number",typeKind:0,typeArguments:[],modulePath:null},annotations:[{name:"MetaModel.facetId",arguments:["minProperties"]},{name:"MetaModel.description",arguments:["The minimum number of properties allowed for instances of this type."]
}],valueConstraint:null,optional:!1},{name:"maxProperties",type:{typeName:"number",nameSpace:"",basicName:"number",typeKind:0,typeArguments:[],modulePath:null},annotations:[{name:"MetaModel.facetId",arguments:["maxProperties"]},{name:"MetaModel.description",arguments:["The maximum number of properties allowed for instances of this type."]}],valueConstraint:null,optional:!1},{name:"additionalProperties",type:{typeName:"boolean",nameSpace:"",basicName:"boolean",typeKind:0,typeArguments:[],modulePath:null},annotations:[{name:"MetaModel.description",arguments:["A Boolean that indicates if an object instance has additional properties."]}],valueConstraint:null,optional:!1},{name:"discriminator",type:{typeName:"string",nameSpace:"",basicName:"string",typeKind:0,typeArguments:[],modulePath:null},annotations:[{name:"MetaModel.description",arguments:["Type property name to be used as discriminator, or boolean"]}],valueConstraint:null,optional:!1},{name:"discriminatorValue",type:{typeName:"string",nameSpace:"",basicName:"string",typeKind:0,typeArguments:[],modulePath:null},annotations:[{name:"MetaModel.description",arguments:["The value of discriminator for the type."]}],valueConstraint:null,optional:!1}],isInterface:!1,annotations:[{name:"MetaModel.definingPropertyIsEnough",arguments:["properties"]},{name:"MetaModel.setsContextValue",arguments:["field","true"]},{name:"MetaModel.convertsToGlobalOfType",arguments:["SchemaString"]},{name:"MetaModel.declaresSubTypeOf",arguments:["TypeDeclaration"]}],"extends":[{typeName:"TypeDeclaration",nameSpace:"",basicName:"TypeDeclaration",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/datamodel.ts"}],moduleName:null,annotationOverridings:{}},{name:"StringTypeDeclaration",methods:[],typeParameters:[],typeParameterConstraint:[],"implements":[],fields:[{name:"type",type:null,annotations:[],valueConstraint:{isCallConstraint:!1,value:"string"},optional:!1},{name:"pattern",type:{typeName:"string",nameSpace:"",basicName:"string",typeKind:0,typeArguments:[],modulePath:null},annotations:[{name:"MetaModel.facetId",arguments:["pattern"]},{name:"MetaModel.description",arguments:["Regular expression that this string should path"]},{name:"MetaModel.valueDescription",arguments:["regexp"]}],valueConstraint:null,optional:!1},{name:"minLength",type:{typeName:"number",nameSpace:"",basicName:"number",typeKind:0,typeArguments:[],modulePath:null},annotations:[{name:"MetaModel.facetId",arguments:["minLength"]},{name:"MetaModel.description",arguments:["Minimum length of the string"]}],valueConstraint:null,optional:!1},{name:"maxLength",type:{typeName:"number",nameSpace:"",basicName:"number",typeKind:0,typeArguments:[],modulePath:null},annotations:[{name:"MetaModel.facetId",arguments:["maxLength"]},{name:"MetaModel.description",arguments:["Maximum length of the string"]}],valueConstraint:null,optional:!1},{name:"enum",type:{base:{typeName:"string",nameSpace:"",basicName:"string",typeKind:0,typeArguments:[],modulePath:null},typeKind:1},annotations:[{name:"MetaModel.facetId",arguments:["enum"]},{name:"MetaModel.describesAnnotation",arguments:["oneOf"]},{name:"MetaModel.description",arguments:["(Optional, applicable only for parameters of type string) The enum attribute provides an enumeration of the parameter's valid values. This MUST be an array. If the enum attribute is defined, API clients and servers MUST verify that a parameter's value matches a value in the enum array. If there is no matching value, the clients and servers MUST treat this as an error."]},{name:"MetaModel.hide",arguments:[]}],valueConstraint:null,optional:!1}],isInterface:!1,annotations:[{name:"MetaModel.description",arguments:["Value must be a string"]},{name:"MetaModel.declaresSubTypeOf",arguments:["TypeDeclaration"]}],"extends":[{typeName:"TypeDeclaration",nameSpace:"",basicName:"TypeDeclaration",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/datamodel.ts"}],moduleName:null,annotationOverridings:{}},{name:"BooleanTypeDeclaration",methods:[],typeParameters:[],typeParameterConstraint:[],"implements":[],fields:[{name:"type",type:null,annotations:[],valueConstraint:{isCallConstraint:!1,value:"boolean"},optional:!1}],isInterface:!1,annotations:[{name:"MetaModel.description",arguments:["Value must be a boolean"]},{name:"MetaModel.declaresSubTypeOf",arguments:["TypeDeclaration"]}],"extends":[{typeName:"TypeDeclaration",nameSpace:"",basicName:"TypeDeclaration",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/datamodel.ts"}],moduleName:null,annotationOverridings:{}},{name:"NumberTypeDeclaration",methods:[],typeParameters:[],typeParameterConstraint:[],"implements":[],fields:[{name:"type",type:null,annotations:[],valueConstraint:{isCallConstraint:!1,value:"number"},optional:!1},{name:"minimum",type:{typeName:"number",nameSpace:"",basicName:"number",typeKind:0,typeArguments:[],modulePath:null},annotations:[{name:"MetaModel.facetId",arguments:["minimum"]},{name:"MetaModel.description",arguments:["(Optional, applicable only for parameters of type number or integer) The minimum attribute specifies the parameter's minimum value."]}],valueConstraint:null,optional:!1},{name:"maximum",type:{typeName:"number",nameSpace:"",basicName:"number",typeKind:0,typeArguments:[],modulePath:null},annotations:[{name:"MetaModel.facetId",arguments:["maximum"]},{name:"MetaModel.description",arguments:["(Optional, applicable only for parameters of type number or integer) The maximum attribute specifies the parameter's maximum value."]}],valueConstraint:null,optional:!1},{name:"enum",type:{base:{typeName:"string",nameSpace:"",basicName:"string",typeKind:0,typeArguments:[],modulePath:null},typeKind:1},annotations:[{name:"MetaModel.facetId",arguments:["enum"]},{name:"MetaModel.describesAnnotation",arguments:["oneOf"]},{name:"MetaModel.description",arguments:["(Optional, applicable only for parameters of type string) The enum attribute provides an enumeration of the parameter's valid values. This MUST be an array. If the enum attribute is defined, API clients and servers MUST verify that a parameter's value matches a value in the enum array. If there is no matching value, the clients and servers MUST treat this as an error."]},{name:"MetaModel.hide",arguments:[]}],valueConstraint:null,optional:!1},{name:"format",type:{typeName:"string",nameSpace:"",basicName:"string",typeKind:0,typeArguments:[],modulePath:null},annotations:[{name:"MetaModel.oneOf",arguments:[["int32","int64","int","long","float","double","int16","int8"]]},{name:"MetaModel.description",arguments:["Value format"]}],valueConstraint:null,optional:!1},{name:"multipleOf",type:{typeName:"number",nameSpace:"",basicName:"number",typeKind:0,typeArguments:[],modulePath:null},annotations:[{name:"MetaModel.description",arguments:['A numeric instance is valid against "multipleOf" if the result of the division of the instance by this keyword\'s value is an integer.']}],valueConstraint:null,optional:!1}],isInterface:!1,annotations:[{name:"MetaModel.description",arguments:["Value MUST be a number. Indicate floating point numbers as defined by YAML."]},{name:"MetaModel.declaresSubTypeOf",arguments:["TypeDeclaration"]}],"extends":[{typeName:"TypeDeclaration",nameSpace:"",basicName:"TypeDeclaration",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/datamodel.ts"}],moduleName:null,annotationOverridings:{}},{name:"IntegerTypeDeclaration",methods:[],typeParameters:[],typeParameterConstraint:[],"implements":[],fields:[{name:"type",type:null,annotations:[],valueConstraint:{isCallConstraint:!1,value:"integer"},optional:!1},{name:"format",type:{typeName:"string",nameSpace:"",basicName:"string",typeKind:0,typeArguments:[],modulePath:null},annotations:[{name:"MetaModel.oneOf",arguments:[["int32","int64","int","long","int16","int8"]]},{name:"MetaModel.description",arguments:["Value format"]}],valueConstraint:null,optional:!1}],isInterface:!1,annotations:[{name:"MetaModel.description",arguments:["Value MUST be a integer."]},{name:"MetaModel.declaresSubTypeOf",arguments:["TypeDeclaration"]}],"extends":[{typeName:"NumberTypeDeclaration",nameSpace:"",basicName:"NumberTypeDeclaration",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/datamodel.ts"}],moduleName:null,annotationOverridings:{}},{name:"DateOnlyTypeDeclaration",methods:[],typeParameters:[],typeParameterConstraint:[],"implements":[],fields:[{name:"type",type:null,annotations:[],valueConstraint:{isCallConstraint:!1,value:"date-only"},optional:!1}],isInterface:!1,annotations:[{name:"MetaModel.description",arguments:['the "full-date" notation of RFC3339, namely yyyy-mm-dd (no implications about time or timezone-offset)']},{name:"MetaModel.declaresSubTypeOf",arguments:["TypeDeclaration"]}],"extends":[{typeName:"TypeDeclaration",nameSpace:"",basicName:"TypeDeclaration",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/datamodel.ts"}],moduleName:null,annotationOverridings:{}},{name:"TimeOnlyTypeDeclaration",methods:[],typeParameters:[],typeParameterConstraint:[],"implements":[],fields:[{name:"type",type:null,annotations:[],valueConstraint:{isCallConstraint:!1,value:"time-only"},optional:!1}],isInterface:!1,annotations:[{name:"MetaModel.description",arguments:['the "partial-time" notation of RFC3339, namely hh:mm:ss[.ff...] (no implications about date or timezone-offset)']},{name:"MetaModel.declaresSubTypeOf",arguments:["TypeDeclaration"]}],"extends":[{typeName:"TypeDeclaration",nameSpace:"",basicName:"TypeDeclaration",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/datamodel.ts"}],moduleName:null,annotationOverridings:{}},{name:"DateTimeOnlyTypeDeclaration",methods:[],typeParameters:[],typeParameterConstraint:[],"implements":[],fields:[{name:"type",type:null,annotations:[],valueConstraint:{isCallConstraint:!1,value:"datetime-only"},optional:!1}],isInterface:!1,annotations:[{name:"MetaModel.description",arguments:['combined date-only and time-only with a separator of "T", namely yyyy-mm-ddThh:mm:ss[.ff...] (no implications about timezone-offset)']},{name:"MetaModel.declaresSubTypeOf",arguments:["TypeDeclaration"]}],"extends":[{typeName:"TypeDeclaration",nameSpace:"",basicName:"TypeDeclaration",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/datamodel.ts"}],moduleName:null,annotationOverridings:{}},{name:"DateTimeTypeDeclaration",methods:[],typeParameters:[],typeParameterConstraint:[],"implements":[],fields:[{name:"type",type:null,annotations:[],valueConstraint:{isCallConstraint:!1,value:"datetime"},optional:!1},{name:"format",type:{typeName:"string",nameSpace:"",basicName:"string",typeKind:0,typeArguments:[],modulePath:null},annotations:[{name:"MetaModel.oneOf",arguments:[["rfc3339","rfc2616"]]},{name:"MetaModel.description",arguments:["Format used for this date time rfc3339 or rfc2616"]}],valueConstraint:null,optional:!1}],isInterface:!1,annotations:[{name:"MetaModel.description",arguments:['a timestamp, either in the "date-time" notation of RFC3339, if format is omitted or is set to rfc3339, or in the format defined in RFC2616, if format is set to rfc2616.']},{name:"MetaModel.declaresSubTypeOf",arguments:["TypeDeclaration"]}],"extends":[{typeName:"TypeDeclaration",nameSpace:"",basicName:"TypeDeclaration",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/datamodel.ts"}],moduleName:null,annotationOverridings:{}},{name:"TypeInstance",methods:[],typeParameters:[],typeParameterConstraint:[],"implements":[],fields:[{name:"properties",type:{base:{typeName:"TypeInstanceProperty",nameSpace:"",basicName:"TypeInstanceProperty",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/datamodel.ts"},typeKind:1},annotations:[{name:"MetaModel.description",arguments:["Array of instance properties"]}],valueConstraint:null,optional:!1},{name:"isScalar",type:{typeName:"boolean",nameSpace:"",basicName:"boolean",typeKind:0,typeArguments:[],modulePath:null},annotations:[{name:"MetaModel.description",arguments:["Whether the type is scalar"]}],valueConstraint:null,optional:!1},{name:"value",type:{typeName:"any",nameSpace:"",basicName:"any",typeKind:0,typeArguments:[],modulePath:null},annotations:[{name:"MetaModel.description",arguments:["For instances of scalar types returns scalar value"]}],valueConstraint:null,optional:!1},{name:"isArray",type:{typeName:"boolean",nameSpace:"",basicName:"boolean",typeKind:0,typeArguments:[],modulePath:null},annotations:[{name:"MetaModel.description",arguments:["Indicates whether the instance is array"]}],valueConstraint:null,optional:!1},{name:"items",type:{base:{typeName:"TypeInstance",nameSpace:"",basicName:"TypeInstance",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/datamodel.ts"},typeKind:1},annotations:[{name:"MetaModel.description",arguments:["Returns components of array instances"]}],valueConstraint:null,optional:!1}],isInterface:!1,annotations:[{name:"MetaModel.customHandling",arguments:[]}],"extends":[],moduleName:null,annotationOverridings:{}},{name:"TypeInstanceProperty",methods:[],typeParameters:[],typeParameterConstraint:[],"implements":[],fields:[{name:"name",type:{typeName:"string",nameSpace:"",basicName:"string",typeKind:0,typeArguments:[],modulePath:null},annotations:[{name:"MetaModel.description",arguments:["Property name"]}],valueConstraint:null,optional:!1},{name:"value",type:{typeName:"TypeInstance",nameSpace:"",basicName:"TypeInstance",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/datamodel.ts"},annotations:[{name:"MetaModel.description",arguments:["Property value"]}],valueConstraint:null,optional:!1},{name:"values",type:{base:{typeName:"TypeInstance",nameSpace:"",basicName:"TypeInstance",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/datamodel.ts"},typeKind:1},annotations:[{name:"MetaModel.description",arguments:["Array of values if property value is array"]}],valueConstraint:null,optional:!1},{name:"isArray",type:{typeName:"boolean",nameSpace:"",basicName:"boolean",typeKind:0,typeArguments:[],modulePath:null},annotations:[{name:"MetaModel.description",arguments:["Whether property has array as value"]}],valueConstraint:null,optional:!1}],isInterface:!1,annotations:[{name:"MetaModel.customHandling",arguments:[]}],"extends":[],moduleName:null,annotationOverridings:{}}],aliases:[],enumDeclarations:[{name:"ModelLocation",members:["QUERY","HEADERS","URI","FORM","BURI","ANNOTATION","MODEL","SECURITYSCHEMATYPE"]},{name:"LocationKind",members:["APISTRUCTURE","DECLARATIONS","MODELS"]}],imports:{MetaModel:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/metamodel.ts",Sys:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/systemTypes.ts",Bodies:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/bodies.ts",Common:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/common.ts",Declarations:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/declarations.ts"},name:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/datamodel.ts"},{classes:[{name:"MimeType",methods:[],typeParameters:[],typeParameterConstraint:[],"implements":[],fields:[],isInterface:!1,annotations:[{name:"MetaModel.description",arguments:["This sub type of the string represents mime types"]}],"extends":[{typeName:"StringType",nameSpace:"",basicName:"StringType",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/bodies.ts"}],moduleName:null,annotationOverridings:{}},{name:"Response",methods:[],typeParameters:[],typeParameterConstraint:[],"implements":[],fields:[{name:"code",type:{typeName:"Sys.StatusCodeString",nameSpace:"Sys",basicName:"StatusCodeString",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/bodies.ts"},annotations:[{name:"MetaModel.key",arguments:[]},{name:"MetaModel.extraMetaKey",arguments:["statusCodes"]},{name:"MetaModel.description",arguments:["Responses MUST be a map of one or more HTTP status codes, where each status code itself is a map that describes that status code."]},{name:"MetaModel.hide",arguments:[]}],valueConstraint:null,optional:!1},{name:"headers",type:{base:{typeName:"DataModel.TypeDeclaration",nameSpace:"DataModel",basicName:"TypeDeclaration",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/bodies.ts"},typeKind:1},annotations:[{name:"MetaModel.setsContextValue",arguments:["fieldOrParam",!0]},{name:"MetaModel.setsContextValue",arguments:["location","DataModel.ModelLocation.HEADERS"]},{name:"MetaModel.setsContextValue",arguments:["locationKind","DataModel.LocationKind.APISTRUCTURE"]},{name:"MetaModel.newInstanceName",arguments:["New Header"]},{name:"MetaModel.description",arguments:["Detailed information about any response headers returned by this method"]},{name:"MetaModel.valueDescription",arguments:["Object whose property names are the response header names and whose values describe the values."]}],valueConstraint:null,optional:!1},{name:"body",type:{base:{typeName:"DataModel.TypeDeclaration",nameSpace:"DataModel",basicName:"TypeDeclaration",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/bodies.ts"},typeKind:1},annotations:[{name:"MetaModel.newInstanceName",arguments:["New Body"]},{name:"MetaModel.description",arguments:["The body of the response: a body declaration"]},{name:"MetaModel.valueDescription",arguments:["Object whose properties are either<br>* Media types and whose values are type objects describing the request body for that media type, or<br>* a type object describing the request body for the default media type specified in the root mediaType property."]}],valueConstraint:null,optional:!1},{name:"description",type:{typeName:"Sys.MarkdownString",nameSpace:"Sys",basicName:"MarkdownString",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/bodies.ts"},annotations:[{name:"MetaModel.description",arguments:["A longer, human-friendly description of the response"]},{name:"MetaModel.valueDescription",arguments:["Markdown string"]}],valueConstraint:null,optional:!1}],isInterface:!1,annotations:[],"extends":[{typeName:"Annotable",nameSpace:"",basicName:"Annotable",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/bodies.ts"}],moduleName:null,annotationOverridings:{displayName:[{name:"MetaModel.description",arguments:["An alternate, human-friendly name for the response"]}],annotations:[{name:"MetaModel.markdownDescription",arguments:['Annotations to be applied to this response. Annotations are any property whose key begins with "(" and ends with ")" and whose name (the part between the beginning and ending parentheses) is a declared annotation name.']}]}}],aliases:[],enumDeclarations:[],imports:{MetaModel:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/metamodel.ts",Sys:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/systemTypes.ts",DataModel:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/datamodel.ts",Common:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/common.ts"},name:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/bodies.ts"},{classes:[{name:"Annotable",methods:[],typeParameters:[],typeParameterConstraint:[],"implements":[],fields:[{name:"annotations",type:{base:{typeName:"Decls.AnnotationRef",nameSpace:"Decls",basicName:"AnnotationRef",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/common.ts"},typeKind:1},annotations:[{name:"MetaModel.noDirectParse",arguments:[]},{name:"MetaModel.setsContextValue",arguments:["locationKind","datamodel.LocationKind.APISTRUCTURE"]},{name:"MetaModel.setsContextValue",arguments:["location","datamodel.ModelLocation.ANNOTATION"]},{name:"MetaModel.description",arguments:["Most of RAML model elements may have attached annotations decribing additional meta data about this element"]},{name:"MetaModel.documentationTableLabel",arguments:["(&lt;annotationName&gt;)"]},{name:"MetaModel.valueDescription",arguments:["A value corresponding to the declared type of this annotation."]}],valueConstraint:null,optional:!1}],isInterface:!1,annotations:[],"extends":[],moduleName:null,annotationOverridings:{}}],aliases:[],enumDeclarations:[],imports:{MetaModel:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/metamodel.ts",Sys:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/systemTypes.ts",Decls:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/declarations.ts"},name:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/common.ts"},{classes:[{name:"AnnotationRef",methods:[],typeParameters:[],typeParameterConstraint:[],"implements":[],fields:[{name:"annotation",type:{typeName:"DataModel.TypeDeclaration",nameSpace:"DataModel",basicName:"TypeDeclaration",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/declarations.ts"},annotations:[{name:"MetaModel.customHandling",arguments:[]},{name:"MetaModel.description",arguments:["Returns referenced annotation"]}],valueConstraint:null,optional:!1}],isInterface:!1,annotations:[{name:"MetaModel.description",arguments:["Annotations allow you to attach information to your API"]},{name:"MetaModel.tags",arguments:[["annotations"]]}],"extends":[{typeName:"Reference",nameSpace:"",basicName:"Reference",typeKind:0,typeArguments:[{typeName:"DataModel.TypeDeclaration",nameSpace:"DataModel",basicName:"TypeDeclaration",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/declarations.ts"}],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/declarations.ts"}],moduleName:null,annotationOverridings:{}},{name:"AnnotationTarget",methods:[],typeParameters:[],typeParameterConstraint:[],"implements":[],fields:[],isInterface:!1,annotations:[{name:"MetaModel.description",arguments:["Elements to which this Annotation can be applied (enum)"]},{name:"MetaModel.tags",arguments:[["annotations"]]}],"extends":[{typeName:"ValueType",nameSpace:"",basicName:"ValueType",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/declarations.ts"}],moduleName:null,annotationOverridings:{}}],aliases:[],enumDeclarations:[],imports:{MetaModel:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/metamodel.ts",Sys:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/systemTypes.ts",DataModel:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/datamodel.ts",Common:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/common.ts"},name:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/declarations.ts"},{classes:[{name:"TraitRef",methods:[],typeParameters:[],typeParameterConstraint:[],"implements":[],fields:[{name:"trait",type:{typeName:"Trait",nameSpace:"",basicName:"Trait",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/methods.ts"},annotations:[{name:"MetaModel.customHandling",arguments:[]},{name:"MetaModel.description",arguments:["Returns referenced trait"]}],valueConstraint:null,optional:!1}],isInterface:!1,annotations:[],"extends":[{typeName:"Reference",nameSpace:"",basicName:"Reference",typeKind:0,typeArguments:[{typeName:"Trait",nameSpace:"",basicName:"Trait",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/methods.ts"}],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/methods.ts"}],moduleName:null,annotationOverridings:{}},{name:"Trait",methods:[],typeParameters:[],typeParameterConstraint:[],"implements":[],fields:[{name:"name",type:{typeName:"string",nameSpace:"",basicName:"string",typeKind:0,typeArguments:[],modulePath:null},annotations:[{name:"MetaModel.key",arguments:[]},{name:"MetaModel.description",arguments:["Name of the trait"]}],valueConstraint:null,optional:!1},{name:"usage",type:{typeName:"string",nameSpace:"",basicName:"string",typeKind:0,typeArguments:[],modulePath:null},annotations:[{name:"MetaModel.description",arguments:["Instructions on how and when the trait should be used."]}],valueConstraint:null,optional:!1},{name:"parametrizedProperties",type:{typeName:"DataModel.TypeInstance",nameSpace:"DataModel",basicName:"TypeInstance",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/methods.ts"},annotations:[{name:"MetaModel.customHandling",arguments:[]},{name:"MetaModel.description",arguments:["Returns object representation of parametrized properties of the trait"]}],valueConstraint:null,optional:!1}],isInterface:!1,annotations:[{name:"MetaModel.inlinedTemplates",arguments:[]},{name:"MetaModel.allowQuestion",arguments:[]},{name:"MetaModel.possibleInterfaces",arguments:[["FragmentDeclaration"]]}],"extends":[{typeName:"MethodBase",nameSpace:"",basicName:"MethodBase",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/methods.ts"}],moduleName:null,annotationOverridings:{displayName:[{name:"MetaModel.description",arguments:["The displayName attribute specifies the trait display name. It is a friendly name used only for  display or documentation purposes. If displayName is not specified, it defaults to the element's key (the name of the property itself)."]}]}},{name:"MethodBase",methods:[],typeParameters:[],typeParameterConstraint:[],"implements":[],fields:[{name:"body",type:{base:{typeName:"DataModel.TypeDeclaration",nameSpace:"DataModel",basicName:"TypeDeclaration",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/methods.ts"},typeKind:1},annotations:[{name:"MetaModel.newInstanceName",arguments:["New Body"]},{name:"MetaModel.description",arguments:["Some method verbs expect the resource to be sent as a request body. For example, to create a resource, the request must include the details of the resource to create. Resources CAN have alternate representations. For example, an API might support both JSON and XML representations. A method's body is defined in the body property as a hashmap, in which the key MUST be a valid media type."]}],valueConstraint:null,optional:!1},{name:"protocols",type:{base:{typeName:"string",nameSpace:"",basicName:"string",typeKind:0,typeArguments:[],modulePath:null},typeKind:1},annotations:[{name:"MetaModel.oneOf",arguments:[["HTTP","HTTPS"]]},{name:"MetaModel.description",arguments:["A method can override the protocols specified in the resource or at the API root, by employing this property."]},{name:"MetaModel.valueDescription",arguments:["array of strings of value HTTP or HTTPS, or a single string of such kind, case-insensitive"]}],valueConstraint:null,optional:!1},{name:"is",type:{base:{typeName:"TraitRef",nameSpace:"",basicName:"TraitRef",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/methods.ts"},typeKind:1},annotations:[{name:"MetaModel.description",arguments:["Instantiation of applyed traits"]}],valueConstraint:null,optional:!1},{name:"securedBy",type:{base:{typeName:"Security.SecuritySchemeRef",nameSpace:"Security",basicName:"SecuritySchemeRef",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/methods.ts"},typeKind:1},annotations:[{name:"MetaModel.allowNull",arguments:[]},{name:"MetaModel.description",arguments:["securityScheme may also be applied to a resource by using the securedBy key, which is equivalent to applying the securityScheme to all methods that may be declared, explicitly or implicitly, by defining the resourceTypes or traits property for that resource. To indicate that the method may be called without applying any securityScheme, the method may be annotated with the null securityScheme."]}],valueConstraint:null,optional:!1},{name:"description",type:{typeName:"Sys.MarkdownString",nameSpace:"Sys",basicName:"MarkdownString",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/methods.ts"},annotations:[],valueConstraint:null,optional:!1},{name:"displayName",type:{typeName:"string",nameSpace:"",basicName:"string",typeKind:0,typeArguments:[],modulePath:null},annotations:[],valueConstraint:null,optional:!1}],isInterface:!1,annotations:[],"extends":[{typeName:"Operation",nameSpace:"",basicName:"Operation",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/methods.ts"}],moduleName:null,annotationOverridings:{}},{name:"Method",methods:[],typeParameters:[],typeParameterConstraint:[],"implements":[],fields:[{name:"method",type:{typeName:"string",nameSpace:"",basicName:"string",typeKind:0,typeArguments:[],modulePath:null},annotations:[{name:"MetaModel.key",arguments:[]},{name:"MetaModel.extraMetaKey",arguments:["methods"]},{name:"MetaModel.oneOf",arguments:[["get","put","post","delete","options","head","patch"]]},{name:"MetaModel.description",arguments:["Method that can be called"]},{name:"MetaModel.hide",arguments:[]}],valueConstraint:null,optional:!1},{name:"parametrizedProperties",type:{typeName:"DataModel.TypeInstance",nameSpace:"DataModel",basicName:"TypeInstance",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/methods.ts"},annotations:[{name:"MetaModel.customHandling",arguments:[]},{name:"MetaModel.description",arguments:["For types defined in resource types returns object representation of parametrized properties"]}],valueConstraint:null,optional:!1}],isInterface:!1,annotations:[],"extends":[{typeName:"MethodBase",nameSpace:"",basicName:"MethodBase",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/methods.ts"}],moduleName:null,annotationOverridings:{displayName:[{name:"MetaModel.description",arguments:["The displayName attribute specifies the method display name. It is a friendly name used only for  display or documentation purposes. If displayName is not specified, it defaults to the element's key (the name of the property itself)."]
}]}},{name:"Operation",methods:[],typeParameters:[],typeParameterConstraint:[],"implements":[],fields:[{name:"queryParameters",type:{base:{typeName:"DataModel.TypeDeclaration",nameSpace:"DataModel",basicName:"TypeDeclaration",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/methods.ts"},typeKind:1},annotations:[{name:"MetaModel.setsContextValue",arguments:["fieldOrParam",!0]},{name:"MetaModel.setsContextValue",arguments:["location","DataModel.ModelLocation.QUERY"]},{name:"MetaModel.setsContextValue",arguments:["locationKind","DataModel.LocationKind.APISTRUCTURE"]},{name:"MetaModel.newInstanceName",arguments:["New query parameter"]},{name:"MetaModel.description",arguments:["An APIs resources MAY be filtered (to return a subset of results) or altered (such as transforming  a response body from JSON to XML format) by the use of query strings. If the resource or its method supports a query string, the query string MUST be defined by the queryParameters property"]}],valueConstraint:null,optional:!1},{name:"headers",type:{base:{typeName:"DataModel.TypeDeclaration",nameSpace:"DataModel",basicName:"TypeDeclaration",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/methods.ts"},typeKind:1},annotations:[{name:"MetaModel.setsContextValue",arguments:["fieldOrParam",!0]},{name:"MetaModel.setsContextValue",arguments:["location","DataModel.ModelLocation.HEADERS"]},{name:"MetaModel.setsContextValue",arguments:["locationKind","DataModel.LocationKind.APISTRUCTURE"]},{name:"MetaModel.description",arguments:["Headers that allowed at this position"]},{name:"MetaModel.newInstanceName",arguments:["New Header"]}],valueConstraint:null,optional:!1},{name:"queryString",type:{typeName:"DataModel.TypeDeclaration",nameSpace:"DataModel",basicName:"TypeDeclaration",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/methods.ts"},annotations:[{name:"MetaModel.description",arguments:["Specifies the query string needed by this method. Mutually exclusive with queryParameters."]}],valueConstraint:null,optional:!1},{name:"responses",type:{base:{typeName:"Bodies.Response",nameSpace:"Bodies",basicName:"Response",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/methods.ts"},typeKind:1},annotations:[{name:"MetaModel.setsContextValue",arguments:["response","true"]},{name:"MetaModel.newInstanceName",arguments:["New Response"]},{name:"MetaModel.description",arguments:["Information about the expected responses to a request"]},{name:"MetaModel.valueDescription",arguments:["An object whose keys are the HTTP status codes of the responses and whose values describe the responses."]}],valueConstraint:null,optional:!1}],isInterface:!1,annotations:[],"extends":[{typeName:"Annotable",nameSpace:"",basicName:"Annotable",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/methods.ts"}],moduleName:null,annotationOverridings:{}}],aliases:[],enumDeclarations:[],imports:{MetaModel:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/metamodel.ts",Sys:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/systemTypes.ts",Bodies:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/bodies.ts",DataModel:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/datamodel.ts",Security:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/security.ts"},name:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/methods.ts"},{classes:[{name:"SecuritySchemePart",methods:[],typeParameters:[],typeParameterConstraint:[],"implements":[],fields:[],isInterface:!1,annotations:[],"extends":[{typeName:"Operation",nameSpace:"",basicName:"Operation",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/security.ts"}],moduleName:null,annotationOverridings:{annotations:[{name:"MetaModel.description",arguments:['Annotations to be applied to this security scheme part. Annotations are any property whose key begins with "(" and ends with ")" and whose name (the part between the beginning and ending parentheses) is a declared annotation name.']}]}},{name:"SecuritySchemeSettings",methods:[],typeParameters:[],typeParameterConstraint:[],"implements":[],fields:[],isInterface:!1,annotations:[{name:"MetaModel.allowAny",arguments:[]}],"extends":[{typeName:"Annotable",nameSpace:"",basicName:"Annotable",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/security.ts"}],moduleName:null,annotationOverridings:{}},{name:"OAuth1SecuritySchemeSettings",methods:[],typeParameters:[],typeParameterConstraint:[],"implements":[],fields:[{name:"requestTokenUri",type:{typeName:"Sys.FixedUriString",nameSpace:"Sys",basicName:"FixedUriString",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/security.ts"},annotations:[{name:"MetaModel.required",arguments:[]},{name:"MetaModel.description",arguments:["The URI of the Temporary Credential Request endpoint as defined in RFC5849 Section 2.1"]},{name:"MetaModel.valueDescription",arguments:["FixedUriString"]}],valueConstraint:null,optional:!1},{name:"authorizationUri",type:{typeName:"Sys.FixedUriString",nameSpace:"Sys",basicName:"FixedUriString",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/security.ts"},annotations:[{name:"MetaModel.required",arguments:[]},{name:"MetaModel.description",arguments:["The URI of the Resource Owner Authorization endpoint as defined in RFC5849 Section 2.2"]},{name:"MetaModel.valueDescription",arguments:["FixedUriString"]}],valueConstraint:null,optional:!1},{name:"tokenCredentialsUri",type:{typeName:"Sys.FixedUriString",nameSpace:"Sys",basicName:"FixedUriString",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/security.ts"},annotations:[{name:"MetaModel.required",arguments:[]},{name:"MetaModel.description",arguments:["The URI of the Token Request endpoint as defined in RFC5849 Section 2.3"]},{name:"MetaModel.valueDescription",arguments:["FixedUriString"]}],valueConstraint:null,optional:!1},{name:"signatures",type:{base:{typeName:"string",nameSpace:"",basicName:"string",typeKind:0,typeArguments:[],modulePath:null},typeKind:1},annotations:[{name:"MetaModel.oneOf",arguments:[["HMAC-SHA1","RSA-SHA1","PLAINTEXT"]]},{name:"MetaModel.hide",arguments:[]},{name:"MetaModel.description",arguments:["List of the signature methods used by the server. Available methods: HMAC-SHA1, RSA-SHA1, PLAINTEXT"]}],valueConstraint:null,optional:!1}],isInterface:!1,annotations:[{name:"MetaModel.allowAny",arguments:[]},{name:"MetaModel.functionalDescriminator",arguments:["$parent.type=='OAuth 1.0'"]}],"extends":[{typeName:"SecuritySchemeSettings",nameSpace:"",basicName:"SecuritySchemeSettings",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/security.ts"}],moduleName:null,annotationOverridings:{}},{name:"OAuth2SecuritySchemeSettings",methods:[],typeParameters:[],typeParameterConstraint:[],"implements":[],fields:[{name:"accessTokenUri",type:{typeName:"Sys.FixedUriString",nameSpace:"Sys",basicName:"FixedUriString",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/security.ts"},annotations:[{name:"MetaModel.required",arguments:[]},{name:"MetaModel.description",arguments:["The URI of the Token Endpoint as defined in RFC6749 Section 3.2. Not required forby implicit grant type."]},{name:"MetaModel.valueDescription",arguments:["FixedUriString"]}],valueConstraint:null,optional:!1},{name:"authorizationUri",type:{typeName:"Sys.FixedUriString",nameSpace:"Sys",basicName:"FixedUriString",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/security.ts"},annotations:[{name:"MetaModel.description",arguments:["The URI of the Authorization Endpoint as defined in RFC6749 Section 3.1. Required forby authorization_code and implicit grant types."]},{name:"MetaModel.valueDescription",arguments:["FixedUriString"]}],valueConstraint:null,optional:!1},{name:"authorizationGrants",type:{base:{typeName:"string",nameSpace:"",basicName:"string",typeKind:0,typeArguments:[],modulePath:null},typeKind:1},annotations:[{name:"MetaModel.required",arguments:[]},{name:"MetaModel.oftenKeys",arguments:[["authorization_code","password","client_credentials","implicit"]]},{name:"MetaModel.description",arguments:["A list of the Authorization grants supported by the API as defined in RFC6749 Sections 4.1, 4.2, 4.3 and 4.4, can be any of: authorization_code, password, client_credentials, implicit, or any absolute url."]},{name:"MetaModel.markdownDescription",arguments:["A list of the Authorization grants supported by the API as defined in RFC6749 Sections 4.1, 4.2, 4.3 and 4.4, can be any of:<br>* authorization_code<br>* password<br>* client_credentials<br>* implicit <br>*  or any absolute url."]}],valueConstraint:null,optional:!1},{name:"scopes",type:{base:{typeName:"string",nameSpace:"",basicName:"string",typeKind:0,typeArguments:[],modulePath:null},typeKind:1},annotations:[{name:"MetaModel.description",arguments:["A list of scopes supported by the security scheme as defined in RFC6749 Section 3.3"]}],valueConstraint:null,optional:!1}],isInterface:!1,annotations:[{name:"MetaModel.allowAny",arguments:[]}],"extends":[{typeName:"SecuritySchemeSettings",nameSpace:"",basicName:"SecuritySchemeSettings",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/security.ts"}],moduleName:null,annotationOverridings:{}},{name:"SecuritySchemeRef",methods:[],typeParameters:[],typeParameterConstraint:[],"implements":[],fields:[{name:"securitySchemeName",type:{typeName:"string",nameSpace:"",basicName:"string",typeKind:0,typeArguments:[],modulePath:null},annotations:[{name:"MetaModel.customHandling",arguments:[]},{name:"MetaModel.description",arguments:["Returns the name of security scheme, this reference refers to."]}],valueConstraint:null,optional:!1},{name:"securityScheme",type:{typeName:"AbstractSecurityScheme",nameSpace:"",basicName:"AbstractSecurityScheme",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/security.ts"},annotations:[{name:"MetaModel.customHandling",arguments:[]},{name:"MetaModel.description",arguments:["Returns AST node of security scheme, this reference refers to, or null."]}],valueConstraint:null,optional:!1}],isInterface:!1,annotations:[],"extends":[{typeName:"Reference",nameSpace:"",basicName:"Reference",typeKind:0,typeArguments:[{typeName:"AbstractSecurityScheme",nameSpace:"",basicName:"AbstractSecurityScheme",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/security.ts"}],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/security.ts"}],moduleName:null,annotationOverridings:{}},{name:"AbstractSecurityScheme",methods:[],typeParameters:[],typeParameterConstraint:[],"implements":[],fields:[{name:"name",type:{typeName:"string",nameSpace:"",basicName:"string",typeKind:0,typeArguments:[],modulePath:null},annotations:[{name:"MetaModel.key",arguments:[]},{name:"MetaModel.startFrom",arguments:[""]},{name:"MetaModel.hide",arguments:[]},{name:"MetaModel.description",arguments:["Name of the security scheme"]}],valueConstraint:null,optional:!1},{name:"type",type:{typeName:"string",nameSpace:"",basicName:"string",typeKind:0,typeArguments:[],modulePath:null},annotations:[{name:"MetaModel.required",arguments:[]},{name:"MetaModel.oneOf",arguments:[["OAuth 1.0","OAuth 2.0","Basic Authentication","Digest Authentication","Pass Through","x-{other}"]]},{name:"MetaModel.descriminatingProperty",arguments:[]},{name:"MetaModel.description",arguments:["The securitySchemes property MUST be used to specify an API's security mechanisms, including the required settings and the authentication methods that the API supports. one authentication method is allowed if the API supports them."]},{name:"MetaModel.valueDescription",arguments:["string<br><br>The value MUST be one of<br>* OAuth 1.0,<br>* OAuth 2.0,<br>* BasicSecurityScheme Authentication<br>* DigestSecurityScheme Authentication<br>* Pass Through<br>* x-&lt;other&gt;"]}],valueConstraint:null,optional:!1},{name:"description",type:{typeName:"Sys.MarkdownString",nameSpace:"Sys",basicName:"MarkdownString",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/security.ts"},annotations:[{name:"MetaModel.description",arguments:["The description attribute MAY be used to describe a security schemes property."]},{name:"MetaModel.description",arguments:["The description MAY be used to describe a securityScheme."]}],valueConstraint:null,optional:!1},{name:"describedBy",type:{typeName:"SecuritySchemePart",nameSpace:"",basicName:"SecuritySchemePart",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/security.ts"},annotations:[{name:"MetaModel.description",arguments:["A description of the request components related to Security that are determined by the scheme: the headers, query parameters or responses. As a best practice, even for standard security schemes, API designers SHOULD describe these properties of security schemes. Including the security scheme description completes an API documentation."]}],valueConstraint:null,optional:!1},{name:"displayName",type:{typeName:"string",nameSpace:"",basicName:"string",typeKind:0,typeArguments:[],modulePath:null},annotations:[{name:"MetaModel.description",arguments:["The displayName attribute specifies the security scheme display name. It is a friendly name used only for  display or documentation purposes. If displayName is not specified, it defaults to the element's key (the name of the property itself)."]}],valueConstraint:null,optional:!1},{name:"settings",type:{typeName:"SecuritySchemeSettings",nameSpace:"",basicName:"SecuritySchemeSettings",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/security.ts"},annotations:[{name:"MetaModel.description",arguments:["The settings attribute MAY be used to provide security scheme-specific information. The required attributes vary depending on the type of security scheme is being declared. It describes the minimum set of properties which any processing application MUST provide and validate if it chooses to implement the security scheme. Processing applications MAY choose to recognize other properties for things such as token lifetime, preferred cryptographic algorithms, and more."]}],valueConstraint:null,optional:!1}],isInterface:!1,annotations:[{name:"MetaModel.description",arguments:["Declares globally referable security scheme definition"]},{name:"MetaModel.actuallyExports",arguments:["$self"]},{name:"MetaModel.referenceIs",arguments:["settings"]}],"extends":[{typeName:"Annotable",nameSpace:"",basicName:"Annotable",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/security.ts"}],moduleName:null,annotationOverridings:{}},{name:"OAuth2SecurityScheme",methods:[],typeParameters:[],typeParameterConstraint:[],"implements":[],fields:[{name:"type",type:null,annotations:[],valueConstraint:{isCallConstraint:!1,value:"OAuth 2.0"},optional:!1},{name:"settings",type:{typeName:"OAuth2SecuritySchemeSettings",nameSpace:"",basicName:"OAuth2SecuritySchemeSettings",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/security.ts"},annotations:[],valueConstraint:null,optional:!1}],isInterface:!1,annotations:[{name:"MetaModel.description",arguments:["Declares globally referable security scheme definition"]},{name:"MetaModel.actuallyExports",arguments:["$self"]},{name:"MetaModel.referenceIs",arguments:["settings"]}],"extends":[{typeName:"AbstractSecurityScheme",nameSpace:"",basicName:"AbstractSecurityScheme",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/security.ts"}],moduleName:null,annotationOverridings:{}},{name:"OAuth1SecurityScheme",methods:[],typeParameters:[],typeParameterConstraint:[],"implements":[],fields:[{name:"type",type:null,annotations:[],valueConstraint:{isCallConstraint:!1,value:"OAuth 1.0"},optional:!1},{name:"settings",type:{typeName:"OAuth1SecuritySchemeSettings",nameSpace:"",basicName:"OAuth1SecuritySchemeSettings",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/security.ts"},annotations:[],valueConstraint:null,optional:!1}],isInterface:!1,annotations:[{name:"MetaModel.description",arguments:["Declares globally referable security scheme definition"]},{name:"MetaModel.actuallyExports",arguments:["$self"]},{name:"MetaModel.referenceIs",arguments:["settings"]}],"extends":[{typeName:"AbstractSecurityScheme",nameSpace:"",basicName:"AbstractSecurityScheme",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/security.ts"}],moduleName:null,annotationOverridings:{}},{name:"PassThroughSecurityScheme",methods:[],typeParameters:[],typeParameterConstraint:[],"implements":[],fields:[{name:"type",type:null,annotations:[],valueConstraint:{isCallConstraint:!1,value:"Pass Through"},optional:!1},{name:"settings",type:{typeName:"SecuritySchemeSettings",nameSpace:"",basicName:"SecuritySchemeSettings",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/security.ts"},annotations:[],valueConstraint:null,optional:!1}],isInterface:!1,annotations:[{name:"MetaModel.description",arguments:["Declares globally referable security scheme definition"]},{name:"MetaModel.actuallyExports",arguments:["$self"]},{name:"MetaModel.referenceIs",arguments:["settings"]}],"extends":[{typeName:"AbstractSecurityScheme",nameSpace:"",basicName:"AbstractSecurityScheme",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/security.ts"}],moduleName:null,annotationOverridings:{}},{name:"BasicSecurityScheme",methods:[],typeParameters:[],typeParameterConstraint:[],"implements":[],fields:[{name:"type",type:null,annotations:[],valueConstraint:{isCallConstraint:!1,value:"Basic Authentication"},optional:!1}],isInterface:!1,annotations:[{name:"MetaModel.description",arguments:["Declares globally referable security scheme definition"]},{name:"MetaModel.actuallyExports",arguments:["$self"]},{name:"MetaModel.referenceIs",arguments:["settings"]}],"extends":[{typeName:"AbstractSecurityScheme",nameSpace:"",basicName:"AbstractSecurityScheme",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/security.ts"}],moduleName:null,annotationOverridings:{}},{name:"DigestSecurityScheme",methods:[],typeParameters:[],typeParameterConstraint:[],"implements":[],fields:[{name:"type",type:null,annotations:[],valueConstraint:{isCallConstraint:!1,value:"Digest Authentication"},optional:!1}],isInterface:!1,annotations:[{name:"MetaModel.description",arguments:["Declares globally referable security scheme definition"]},{name:"MetaModel.actuallyExports",arguments:["$self"]},{name:"MetaModel.referenceIs",arguments:["settings"]}],"extends":[{typeName:"AbstractSecurityScheme",nameSpace:"",basicName:"AbstractSecurityScheme",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/security.ts"}],moduleName:null,annotationOverridings:{}},{name:"CustomSecurityScheme",methods:[],typeParameters:[],typeParameterConstraint:[],"implements":[],fields:[{name:"type",type:null,annotations:[],valueConstraint:{isCallConstraint:!1,value:"x-{other}"},optional:!1}],isInterface:!1,annotations:[{name:"MetaModel.description",arguments:["Declares globally referable security scheme definition"]},{name:"MetaModel.actuallyExports",arguments:["$self"]},{name:"MetaModel.referenceIs",arguments:["settings"]}],"extends":[{typeName:"AbstractSecurityScheme",nameSpace:"",basicName:"AbstractSecurityScheme",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/security.ts"}],moduleName:null,annotationOverridings:{}}],aliases:[],enumDeclarations:[],imports:{MetaModel:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/metamodel.ts",Sys:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/systemTypes.ts",Methods:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/methods.ts"},name:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/security.ts"},{classes:[{name:"ResourceTypeRef",methods:[],typeParameters:[],typeParameterConstraint:[],"implements":[],fields:[{name:"resourceType",type:{typeName:"ResourceType",nameSpace:"",basicName:"ResourceType",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/resources.ts"},annotations:[{name:"MetaModel.customHandling",arguments:[]},{name:"MetaModel.description",arguments:["Returns referenced resource type"]}],valueConstraint:null,optional:!1}],isInterface:!1,annotations:[],"extends":[{typeName:"Reference",nameSpace:"",basicName:"Reference",typeKind:0,typeArguments:[{typeName:"ResourceType",nameSpace:"",basicName:"ResourceType",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/resources.ts"}],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/resources.ts"}],moduleName:null,annotationOverridings:{}},{name:"ResourceType",methods:[],typeParameters:[],typeParameterConstraint:[],"implements":[],fields:[{name:"displayName",type:{typeName:"string",nameSpace:"",basicName:"string",typeKind:0,typeArguments:[],modulePath:null},annotations:[{name:"MetaModel.description",arguments:["The displayName attribute specifies the resource type display name. It is a friendly name used only for  display or documentation purposes. If displayName is not specified, it defaults to the element's key (the name of the property itself)."]}],valueConstraint:null,optional:!1},{name:"name",type:{typeName:"string",nameSpace:"",basicName:"string",typeKind:0,typeArguments:[],modulePath:null},annotations:[{name:"MetaModel.key",arguments:[]},{name:"MetaModel.description",arguments:["Name of the resource type"]}],valueConstraint:null,optional:!1},{name:"usage",type:{typeName:"string",nameSpace:"",basicName:"string",typeKind:0,typeArguments:[],modulePath:null},annotations:[{name:"MetaModel.description",arguments:["Instructions on how and when the resource type should be used."]}],valueConstraint:null,optional:!1},{name:"parametrizedProperties",type:{typeName:"DataModel.TypeInstance",nameSpace:"DataModel",basicName:"TypeInstance",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/resources.ts"},annotations:[{name:"MetaModel.customHandling",arguments:[]},{name:"MetaModel.description",arguments:["Returns object representation of parametrized properties of the resource type"]}],valueConstraint:null,optional:!1}],isInterface:!1,annotations:[{name:"MetaModel.inlinedTemplates",arguments:[]},{name:"MetaModel.allowQuestion",arguments:[]},{name:"MetaModel.possibleInterfaces",arguments:[["FragmentDeclaration"]]}],"extends":[{typeName:"ResourceBase",nameSpace:"",basicName:"ResourceBase",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/resources.ts"}],moduleName:null,annotationOverridings:{}},{name:"ResourceBase",methods:[],typeParameters:[],typeParameterConstraint:[],"implements":[],fields:[{name:"methods",type:{base:{typeName:"Methods.Method",nameSpace:"Methods",basicName:"Method",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/resources.ts"},typeKind:1},annotations:[{name:"MetaModel.description",arguments:["Methods that are part of this resource type definition"]},{name:"MetaModel.markdownDescription",arguments:["The methods available on this resource."]},{name:"MetaModel.documentationTableLabel",arguments:["get?<br>patch?<br>put?<br>post?<br>delete?<br>options?<br>head?"]},{name:"MetaModel.valueDescription",arguments:["Object describing the method"]}],valueConstraint:null,optional:!1},{name:"is",type:{base:{typeName:"Methods.TraitRef",nameSpace:"Methods",basicName:"TraitRef",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/resources.ts"},typeKind:1},annotations:[{name:"MetaModel.description",arguments:["A list of the traits to apply to all methods declared (implicitly or explicitly) for this resource. Individual methods may override this declaration"]},{name:"MetaModel.valueDescription",arguments:["array, which can contain each of the following elements:<br>* name of unparametrized trait <br>* a key-value pair with trait name as key and a map of trait parameters as value<br>* inline trait declaration <br><br>(or a single element of any above kind)"]}],valueConstraint:null,optional:!1},{name:"type",type:{typeName:"ResourceTypeRef",nameSpace:"",basicName:"ResourceTypeRef",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/resources.ts"},annotations:[{name:"MetaModel.description",arguments:["The resource type which this resource inherits."]},{name:"MetaModel.valueDescription",arguments:["one of the following elements:<br>* name of unparametrized resource type<br>* a key-value pair with resource type name as key and a map of its parameters as value<br>* inline resource type declaration"]}],valueConstraint:null,optional:!1},{name:"description",type:{typeName:"Sys.MarkdownString",nameSpace:"Sys",basicName:"MarkdownString",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/resources.ts"},annotations:[],valueConstraint:null,optional:!1},{name:"securedBy",type:{base:{typeName:"Security.SecuritySchemeRef",nameSpace:"Security",basicName:"SecuritySchemeRef",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/resources.ts"},typeKind:1},annotations:[{name:"MetaModel.allowNull",arguments:[]},{name:"MetaModel.description",arguments:["The security schemes that apply to all methods declared (implicitly or explicitly) for this resource."]},{name:"MetaModel.valueDescription",arguments:["array of security scheme names or a single security scheme name"]}],valueConstraint:null,optional:!1},{name:"uriParameters",type:{base:{typeName:"DataModel.TypeDeclaration",nameSpace:"DataModel",basicName:"TypeDeclaration",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/resources.ts"},typeKind:1},annotations:[{name:"MetaModel.setsContextValue",arguments:["location","DataModel.ModelLocation.URI"]},{name:"MetaModel.setsContextValue",arguments:["locationKind","DataModel.LocationKind.APISTRUCTURE"]},{name:"MetaModel.setsContextValue",arguments:["fieldOrParam",!0]},{name:"MetaModel.description",arguments:["Detailed information about any URI parameters of this resource"]},{name:"MetaModel.valueDescription",arguments:["object whose property names are the URI parameter names and whose values describe the values"]}],valueConstraint:null,optional:!1}],isInterface:!1,annotations:[],"extends":[{typeName:"Annotable",nameSpace:"",basicName:"Annotable",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/resources.ts"}],moduleName:null,annotationOverridings:{}},{name:"Resource",methods:[],typeParameters:[],typeParameterConstraint:[],"implements":[],fields:[{name:"relativeUri",type:{typeName:"Sys.RelativeUriString",nameSpace:"Sys",basicName:"RelativeUriString",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/resources.ts"},annotations:[{name:"MetaModel.key",arguments:[]},{name:"MetaModel.startFrom",arguments:["/"]},{name:"MetaModel.description",arguments:["Relative URL of this resource from the parent resource"]},{name:"MetaModel.hide",arguments:[]}],valueConstraint:null,optional:!1},{name:"displayName",type:{typeName:"string",nameSpace:"",basicName:"string",typeKind:0,typeArguments:[],modulePath:null},annotations:[{name:"MetaModel.description",arguments:["The displayName attribute specifies the resource display name. It is a friendly name used only for  display or documentation purposes. If displayName is not specified, it defaults to the element's key (the name of the property itself)."]}],valueConstraint:null,optional:!1},{name:"resources",type:{base:{typeName:"Resource",nameSpace:"",basicName:"Resource",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/resources.ts"},typeKind:1},annotations:[{name:"MetaModel.newInstanceName",arguments:["New Resource"]},{name:"MetaModel.description",arguments:['A nested resource is identified as any property whose name begins with a slash ("/") and is therefore treated as a relative URI.']},{name:"MetaModel.documentationTableLabel",arguments:["/&lt;relativeUri&gt;"]},{name:"MetaModel.valueDescription",arguments:["object describing the nested resource"]}],valueConstraint:null,optional:!1}],isInterface:!1,annotations:[],"extends":[{typeName:"ResourceBase",nameSpace:"",basicName:"ResourceBase",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/resources.ts"}],moduleName:null,annotationOverridings:{description:[{name:"MetaModel.description",arguments:["A longer, human-friendly description of the resource."]},{name:"MetaModel.valueDescription",arguments:["Markdown string"]}],annotations:[{name:"MetaModel.markdownDescription",arguments:['Annotations to be applied to this resource. Annotations are any property whose key begins with "(" and ends with ")" and whose name (the part between the beginning and ending parentheses) is a declared annotation name.']}]}}],aliases:[],enumDeclarations:[],imports:{MetaModel:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/metamodel.ts",Sys:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/systemTypes.ts",DataModel:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/datamodel.ts",
Security:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/security.ts",Methods:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/methods.ts"},name:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/resources.ts"},{classes:[{name:"FileTypeDeclaration",methods:[],typeParameters:[],typeParameterConstraint:[],"implements":[],fields:[{name:"type",type:null,annotations:[],valueConstraint:{isCallConstraint:!1,value:"file"},optional:!1},{name:"fileTypes",type:{base:{typeName:"Sys.ContentType",nameSpace:"Sys",basicName:"ContentType",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/parameters.ts"},typeKind:1},annotations:[{name:"MetaModel.description",arguments:["It should also include a new property: fileTypes, which should be a list of valid content-type strings for the file. The file type */* should be a valid value."]}],valueConstraint:null,optional:!1},{name:"minLength",type:{typeName:"number",nameSpace:"",basicName:"number",typeKind:0,typeArguments:[],modulePath:null},annotations:[{name:"MetaModel.description",arguments:["The minLength attribute specifies the parameter value's minimum number of bytes."]}],valueConstraint:null,optional:!1},{name:"maxLength",type:{typeName:"number",nameSpace:"",basicName:"number",typeKind:0,typeArguments:[],modulePath:null},annotations:[{name:"MetaModel.description",arguments:["The maxLength attribute specifies the parameter value's maximum number of bytes."]}],valueConstraint:null,optional:!1}],isInterface:!1,annotations:[{name:"MetaModel.description",arguments:["(Applicable only to Form properties) Value is a file. Client generators SHOULD use this type to handle file uploads correctly."]}],"extends":[{typeName:"TypeDeclaration",nameSpace:"",basicName:"TypeDeclaration",typeKind:0,typeArguments:[],modulePath:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/parameters.ts"}],moduleName:null,annotationOverridings:{}}],aliases:[],enumDeclarations:[],imports:{MetaModel:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/metamodel.ts",Sys:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/systemTypes.ts",DataModel:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/datamodel.ts"},name:"/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/parameters.ts"}]},function(e,t,n){"use strict";function r(e,t){e=e.split("?");var n=e[0],r=(e[1]||"").split("#")[0],o=e[1]&&e[1].split("#").length>1?"#"+e[1].split("#")[1]:"",s=i(r);for(var u in t)s[u]=t[u];return r=a(s),""!==r&&(r="?"+r),n+r+o}var i=n(162).parse,a=n(162).stringify;e.exports=r},function(e,t,n){var r,i;(function(){function n(e){function t(t,n,r,i,a,o){for(;a>=0&&o>a;a+=e){var s=i?i[a]:a;r=n(r,t[s],s,t)}return r}return function(n,r,i,a){r=b(r,a,4);var o=!C(n)&&E.keys(n),s=(o||n).length,u=e>0?0:s-1;return arguments.length<3&&(i=n[o?o[u]:u],u+=e),t(n,r,i,o,u,s)}}function a(e){return function(t,n,r){n=N(n,r);for(var i=I(t),a=e>0?0:i-1;a>=0&&i>a;a+=e)if(n(t[a],a,t))return a;return-1}}function o(e,t,n){return function(r,i,a){var o=0,s=I(r);if("number"==typeof a)e>0?o=a>=0?a:Math.max(a+s,o):s=a>=0?Math.min(a+1,s):a+s+1;else if(n&&a&&s)return a=n(r,i),r[a]===i?a:-1;if(i!==i)return a=t(d.call(r,o,s),E.isNaN),a>=0?a+o:-1;for(a=e>0?o:s-1;a>=0&&s>a;a+=e)if(r[a]===i)return a;return-1}}function s(e,t){var n=x.length,r=e.constructor,i=E.isFunction(r)&&r.prototype||c,a="constructor";for(E.has(e,a)&&!E.contains(t,a)&&t.push(a);n--;)a=x[n],a in e&&e[a]!==i[a]&&!E.contains(t,a)&&t.push(a)}var u=this,l=u._,p=Array.prototype,c=Object.prototype,f=Function.prototype,m=p.push,d=p.slice,h=c.toString,y=c.hasOwnProperty,v=Array.isArray,g=Object.keys,A=f.bind,S=Object.create,T=function(){},E=function(e){return e instanceof E?e:this instanceof E?void(this._wrapped=e):new E(e)};"undefined"!=typeof e&&e.exports&&(t=e.exports=E),t._=E,E.VERSION="1.8.3";var b=function(e,t,n){if(void 0===t)return e;switch(null==n?3:n){case 1:return function(n){return e.call(t,n)};case 2:return function(n,r){return e.call(t,n,r)};case 3:return function(n,r,i){return e.call(t,n,r,i)};case 4:return function(n,r,i,a){return e.call(t,n,r,i,a)}}return function(){return e.apply(t,arguments)}},N=function(e,t,n){return null==e?E.identity:E.isFunction(e)?b(e,t,n):E.isObject(e)?E.matcher(e):E.property(e)};E.iteratee=function(e,t){return N(e,t,1/0)};var _=function(e,t){return function(n){var r=arguments.length;if(2>r||null==n)return n;for(var i=1;r>i;i++)for(var a=arguments[i],o=e(a),s=o.length,u=0;s>u;u++){var l=o[u];t&&void 0!==n[l]||(n[l]=a[l])}return n}},M=function(e){if(!E.isObject(e))return{};if(S)return S(e);T.prototype=e;var t=new T;return T.prototype=null,t},w=function(e){return function(t){return null==t?void 0:t[e]}},R=Math.pow(2,53)-1,I=w("length"),C=function(e){var t=I(e);return"number"==typeof t&&t>=0&&R>=t};E.each=E.forEach=function(e,t,n){t=b(t,n);var r,i;if(C(e))for(r=0,i=e.length;i>r;r++)t(e[r],r,e);else{var a=E.keys(e);for(r=0,i=a.length;i>r;r++)t(e[a[r]],a[r],e)}return e},E.map=E.collect=function(e,t,n){t=N(t,n);for(var r=!C(e)&&E.keys(e),i=(r||e).length,a=Array(i),o=0;i>o;o++){var s=r?r[o]:o;a[o]=t(e[s],s,e)}return a},E.reduce=E.foldl=E.inject=n(1),E.reduceRight=E.foldr=n(-1),E.find=E.detect=function(e,t,n){var r;return r=C(e)?E.findIndex(e,t,n):E.findKey(e,t,n),void 0!==r&&-1!==r?e[r]:void 0},E.filter=E.select=function(e,t,n){var r=[];return t=N(t,n),E.each(e,function(e,n,i){t(e,n,i)&&r.push(e)}),r},E.reject=function(e,t,n){return E.filter(e,E.negate(N(t)),n)},E.every=E.all=function(e,t,n){t=N(t,n);for(var r=!C(e)&&E.keys(e),i=(r||e).length,a=0;i>a;a++){var o=r?r[a]:a;if(!t(e[o],o,e))return!1}return!0},E.some=E.any=function(e,t,n){t=N(t,n);for(var r=!C(e)&&E.keys(e),i=(r||e).length,a=0;i>a;a++){var o=r?r[a]:a;if(t(e[o],o,e))return!0}return!1},E.contains=E.includes=E.include=function(e,t,n,r){return C(e)||(e=E.values(e)),("number"!=typeof n||r)&&(n=0),E.indexOf(e,t,n)>=0},E.invoke=function(e,t){var n=d.call(arguments,2),r=E.isFunction(t);return E.map(e,function(e){var i=r?t:e[t];return null==i?i:i.apply(e,n)})},E.pluck=function(e,t){return E.map(e,E.property(t))},E.where=function(e,t){return E.filter(e,E.matcher(t))},E.findWhere=function(e,t){return E.find(e,E.matcher(t))},E.max=function(e,t,n){var r,i,a=-(1/0),o=-(1/0);if(null==t&&null!=e){e=C(e)?e:E.values(e);for(var s=0,u=e.length;u>s;s++)r=e[s],r>a&&(a=r)}else t=N(t,n),E.each(e,function(e,n,r){i=t(e,n,r),(i>o||i===-(1/0)&&a===-(1/0))&&(a=e,o=i)});return a},E.min=function(e,t,n){var r,i,a=1/0,o=1/0;if(null==t&&null!=e){e=C(e)?e:E.values(e);for(var s=0,u=e.length;u>s;s++)r=e[s],a>r&&(a=r)}else t=N(t,n),E.each(e,function(e,n,r){i=t(e,n,r),(o>i||i===1/0&&a===1/0)&&(a=e,o=i)});return a},E.shuffle=function(e){for(var t,n=C(e)?e:E.values(e),r=n.length,i=Array(r),a=0;r>a;a++)t=E.random(0,a),t!==a&&(i[a]=i[t]),i[t]=n[a];return i},E.sample=function(e,t,n){return null==t||n?(C(e)||(e=E.values(e)),e[E.random(e.length-1)]):E.shuffle(e).slice(0,Math.max(0,t))},E.sortBy=function(e,t,n){return t=N(t,n),E.pluck(E.map(e,function(e,n,r){return{value:e,index:n,criteria:t(e,n,r)}}).sort(function(e,t){var n=e.criteria,r=t.criteria;if(n!==r){if(n>r||void 0===n)return 1;if(r>n||void 0===r)return-1}return e.index-t.index}),"value")};var L=function(e){return function(t,n,r){var i={};return n=N(n,r),E.each(t,function(r,a){var o=n(r,a,t);e(i,r,o)}),i}};E.groupBy=L(function(e,t,n){E.has(e,n)?e[n].push(t):e[n]=[t]}),E.indexBy=L(function(e,t,n){e[n]=t}),E.countBy=L(function(e,t,n){E.has(e,n)?e[n]++:e[n]=1}),E.toArray=function(e){return e?E.isArray(e)?d.call(e):C(e)?E.map(e,E.identity):E.values(e):[]},E.size=function(e){return null==e?0:C(e)?e.length:E.keys(e).length},E.partition=function(e,t,n){t=N(t,n);var r=[],i=[];return E.each(e,function(e,n,a){(t(e,n,a)?r:i).push(e)}),[r,i]},E.first=E.head=E.take=function(e,t,n){return null==e?void 0:null==t||n?e[0]:E.initial(e,e.length-t)},E.initial=function(e,t,n){return d.call(e,0,Math.max(0,e.length-(null==t||n?1:t)))},E.last=function(e,t,n){return null==e?void 0:null==t||n?e[e.length-1]:E.rest(e,Math.max(0,e.length-t))},E.rest=E.tail=E.drop=function(e,t,n){return d.call(e,null==t||n?1:t)},E.compact=function(e){return E.filter(e,E.identity)};var P=function(e,t,n,r){for(var i=[],a=0,o=r||0,s=I(e);s>o;o++){var u=e[o];if(C(u)&&(E.isArray(u)||E.isArguments(u))){t||(u=P(u,t,n));var l=0,p=u.length;for(i.length+=p;p>l;)i[a++]=u[l++]}else n||(i[a++]=u)}return i};E.flatten=function(e,t){return P(e,t,!1)},E.without=function(e){return E.difference(e,d.call(arguments,1))},E.uniq=E.unique=function(e,t,n,r){E.isBoolean(t)||(r=n,n=t,t=!1),null!=n&&(n=N(n,r));for(var i=[],a=[],o=0,s=I(e);s>o;o++){var u=e[o],l=n?n(u,o,e):u;t?(o&&a===l||i.push(u),a=l):n?E.contains(a,l)||(a.push(l),i.push(u)):E.contains(i,u)||i.push(u)}return i},E.union=function(){return E.uniq(P(arguments,!0,!0))},E.intersection=function(e){for(var t=[],n=arguments.length,r=0,i=I(e);i>r;r++){var a=e[r];if(!E.contains(t,a)){for(var o=1;n>o&&E.contains(arguments[o],a);o++);o===n&&t.push(a)}}return t},E.difference=function(e){var t=P(arguments,!0,!0,1);return E.filter(e,function(e){return!E.contains(t,e)})},E.zip=function(){return E.unzip(arguments)},E.unzip=function(e){for(var t=e&&E.max(e,I).length||0,n=Array(t),r=0;t>r;r++)n[r]=E.pluck(e,r);return n},E.object=function(e,t){for(var n={},r=0,i=I(e);i>r;r++)t?n[e[r]]=t[r]:n[e[r][0]]=e[r][1];return n},E.findIndex=a(1),E.findLastIndex=a(-1),E.sortedIndex=function(e,t,n,r){n=N(n,r,1);for(var i=n(t),a=0,o=I(e);o>a;){var s=Math.floor((a+o)/2);n(e[s])<i?a=s+1:o=s}return a},E.indexOf=o(1,E.findIndex,E.sortedIndex),E.lastIndexOf=o(-1,E.findLastIndex),E.range=function(e,t,n){null==t&&(t=e||0,e=0),n=n||1;for(var r=Math.max(Math.ceil((t-e)/n),0),i=Array(r),a=0;r>a;a++,e+=n)i[a]=e;return i};var O=function(e,t,n,r,i){if(!(r instanceof t))return e.apply(n,i);var a=M(e.prototype),o=e.apply(a,i);return E.isObject(o)?o:a};E.bind=function(e,t){if(A&&e.bind===A)return A.apply(e,d.call(arguments,1));if(!E.isFunction(e))throw new TypeError("Bind must be called on a function");var n=d.call(arguments,2),r=function(){return O(e,r,t,this,n.concat(d.call(arguments)))};return r},E.partial=function(e){var t=d.call(arguments,1),n=function(){for(var r=0,i=t.length,a=Array(i),o=0;i>o;o++)a[o]=t[o]===E?arguments[r++]:t[o];for(;r<arguments.length;)a.push(arguments[r++]);return O(e,n,this,this,a)};return n},E.bindAll=function(e){var t,n,r=arguments.length;if(1>=r)throw new Error("bindAll must be passed function names");for(t=1;r>t;t++)n=arguments[t],e[n]=E.bind(e[n],e);return e},E.memoize=function(e,t){var n=function(r){var i=n.cache,a=""+(t?t.apply(this,arguments):r);return E.has(i,a)||(i[a]=e.apply(this,arguments)),i[a]};return n.cache={},n},E.delay=function(e,t){var n=d.call(arguments,2);return setTimeout(function(){return e.apply(null,n)},t)},E.defer=E.partial(E.delay,E,1),E.throttle=function(e,t,n){var r,i,a,o=null,s=0;n||(n={});var u=function(){s=n.leading===!1?0:E.now(),o=null,a=e.apply(r,i),o||(r=i=null)};return function(){var l=E.now();s||n.leading!==!1||(s=l);var p=t-(l-s);return r=this,i=arguments,0>=p||p>t?(o&&(clearTimeout(o),o=null),s=l,a=e.apply(r,i),o||(r=i=null)):o||n.trailing===!1||(o=setTimeout(u,p)),a}},E.debounce=function(e,t,n){var r,i,a,o,s,u=function(){var l=E.now()-o;t>l&&l>=0?r=setTimeout(u,t-l):(r=null,n||(s=e.apply(a,i),r||(a=i=null)))};return function(){a=this,i=arguments,o=E.now();var l=n&&!r;return r||(r=setTimeout(u,t)),l&&(s=e.apply(a,i),a=i=null),s}},E.wrap=function(e,t){return E.partial(t,e)},E.negate=function(e){return function(){return!e.apply(this,arguments)}},E.compose=function(){var e=arguments,t=e.length-1;return function(){for(var n=t,r=e[t].apply(this,arguments);n--;)r=e[n].call(this,r);return r}},E.after=function(e,t){return function(){return--e<1?t.apply(this,arguments):void 0}},E.before=function(e,t){var n;return function(){return--e>0&&(n=t.apply(this,arguments)),1>=e&&(t=null),n}},E.once=E.partial(E.before,2);var D=!{toString:null}.propertyIsEnumerable("toString"),x=["valueOf","isPrototypeOf","toString","propertyIsEnumerable","hasOwnProperty","toLocaleString"];E.keys=function(e){if(!E.isObject(e))return[];if(g)return g(e);var t=[];for(var n in e)E.has(e,n)&&t.push(n);return D&&s(e,t),t},E.allKeys=function(e){if(!E.isObject(e))return[];var t=[];for(var n in e)t.push(n);return D&&s(e,t),t},E.values=function(e){for(var t=E.keys(e),n=t.length,r=Array(n),i=0;n>i;i++)r[i]=e[t[i]];return r},E.mapObject=function(e,t,n){t=N(t,n);for(var r,i=E.keys(e),a=i.length,o={},s=0;a>s;s++)r=i[s],o[r]=t(e[r],r,e);return o},E.pairs=function(e){for(var t=E.keys(e),n=t.length,r=Array(n),i=0;n>i;i++)r[i]=[t[i],e[t[i]]];return r},E.invert=function(e){for(var t={},n=E.keys(e),r=0,i=n.length;i>r;r++)t[e[n[r]]]=n[r];return t},E.functions=E.methods=function(e){var t=[];for(var n in e)E.isFunction(e[n])&&t.push(n);return t.sort()},E.extend=_(E.allKeys),E.extendOwn=E.assign=_(E.keys),E.findKey=function(e,t,n){t=N(t,n);for(var r,i=E.keys(e),a=0,o=i.length;o>a;a++)if(r=i[a],t(e[r],r,e))return r},E.pick=function(e,t,n){var r,i,a={},o=e;if(null==o)return a;E.isFunction(t)?(i=E.allKeys(o),r=b(t,n)):(i=P(arguments,!1,!1,1),r=function(e,t,n){return t in n},o=Object(o));for(var s=0,u=i.length;u>s;s++){var l=i[s],p=o[l];r(p,l,o)&&(a[l]=p)}return a},E.omit=function(e,t,n){if(E.isFunction(t))t=E.negate(t);else{var r=E.map(P(arguments,!1,!1,1),String);t=function(e,t){return!E.contains(r,t)}}return E.pick(e,t,n)},E.defaults=_(E.allKeys,!0),E.create=function(e,t){var n=M(e);return t&&E.extendOwn(n,t),n},E.clone=function(e){return E.isObject(e)?E.isArray(e)?e.slice():E.extend({},e):e},E.tap=function(e,t){return t(e),e},E.isMatch=function(e,t){var n=E.keys(t),r=n.length;if(null==e)return!r;for(var i=Object(e),a=0;r>a;a++){var o=n[a];if(t[o]!==i[o]||!(o in i))return!1}return!0};var U=function(e,t,n,r){if(e===t)return 0!==e||1/e===1/t;if(null==e||null==t)return e===t;e instanceof E&&(e=e._wrapped),t instanceof E&&(t=t._wrapped);var i=h.call(e);if(i!==h.call(t))return!1;switch(i){case"[object RegExp]":case"[object String]":return""+e==""+t;case"[object Number]":return+e!==+e?+t!==+t:0===+e?1/+e===1/t:+e===+t;case"[object Date]":case"[object Boolean]":return+e===+t}var a="[object Array]"===i;if(!a){if("object"!=typeof e||"object"!=typeof t)return!1;var o=e.constructor,s=t.constructor;if(o!==s&&!(E.isFunction(o)&&o instanceof o&&E.isFunction(s)&&s instanceof s)&&"constructor"in e&&"constructor"in t)return!1}n=n||[],r=r||[];for(var u=n.length;u--;)if(n[u]===e)return r[u]===t;if(n.push(e),r.push(t),a){if(u=e.length,u!==t.length)return!1;for(;u--;)if(!U(e[u],t[u],n,r))return!1}else{var l,p=E.keys(e);if(u=p.length,E.keys(t).length!==u)return!1;for(;u--;)if(l=p[u],!E.has(t,l)||!U(e[l],t[l],n,r))return!1}return n.pop(),r.pop(),!0};E.isEqual=function(e,t){return U(e,t)},E.isEmpty=function(e){return null==e?!0:C(e)&&(E.isArray(e)||E.isString(e)||E.isArguments(e))?0===e.length:0===E.keys(e).length},E.isElement=function(e){return!(!e||1!==e.nodeType)},E.isArray=v||function(e){return"[object Array]"===h.call(e)},E.isObject=function(e){var t=typeof e;return"function"===t||"object"===t&&!!e},E.each(["Arguments","Function","String","Number","Date","RegExp","Error"],function(e){E["is"+e]=function(t){return h.call(t)==="[object "+e+"]"}}),E.isArguments(arguments)||(E.isArguments=function(e){return E.has(e,"callee")}),"function"!=typeof/./&&"object"!=typeof Int8Array&&(E.isFunction=function(e){return"function"==typeof e||!1}),E.isFinite=function(e){return isFinite(e)&&!isNaN(parseFloat(e))},E.isNaN=function(e){return E.isNumber(e)&&e!==+e},E.isBoolean=function(e){return e===!0||e===!1||"[object Boolean]"===h.call(e)},E.isNull=function(e){return null===e},E.isUndefined=function(e){return void 0===e},E.has=function(e,t){return null!=e&&y.call(e,t)},E.noConflict=function(){return u._=l,this},E.identity=function(e){return e},E.constant=function(e){return function(){return e}},E.noop=function(){},E.property=w,E.propertyOf=function(e){return null==e?function(){}:function(t){return e[t]}},E.matcher=E.matches=function(e){return e=E.extendOwn({},e),function(t){return E.isMatch(t,e)}},E.times=function(e,t,n){var r=Array(Math.max(0,e));t=b(t,n,1);for(var i=0;e>i;i++)r[i]=t(i);return r},E.random=function(e,t){return null==t&&(t=e,e=0),e+Math.floor(Math.random()*(t-e+1))},E.now=Date.now||function(){return(new Date).getTime()};var k={"&":"&amp;","<":"&lt;",">":"&gt;",'"':"&quot;","'":"&#x27;","`":"&#x60;"},F=E.invert(k),B=function(e){var t=function(t){return e[t]},n="(?:"+E.keys(e).join("|")+")",r=RegExp(n),i=RegExp(n,"g");return function(e){return e=null==e?"":""+e,r.test(e)?e.replace(i,t):e}};E.escape=B(k),E.unescape=B(F),E.result=function(e,t,n){var r=null==e?void 0:e[t];return void 0===r&&(r=n),E.isFunction(r)?r.call(e):r};var K=0;E.uniqueId=function(e){var t=++K+"";return e?e+t:t},E.templateSettings={evaluate:/<%([\s\S]+?)%>/g,interpolate:/<%=([\s\S]+?)%>/g,escape:/<%-([\s\S]+?)%>/g};var V=/(.)^/,j={"'":"'","\\":"\\","\r":"r","\n":"n","\u2028":"u2028","\u2029":"u2029"},W=/\\|'|\r|\n|\u2028|\u2029/g,q=function(e){return"\\"+j[e]};E.template=function(e,t,n){!t&&n&&(t=n),t=E.defaults({},t,E.templateSettings);var r=RegExp([(t.escape||V).source,(t.interpolate||V).source,(t.evaluate||V).source].join("|")+"|$","g"),i=0,a="__p+='";e.replace(r,function(t,n,r,o,s){return a+=e.slice(i,s).replace(W,q),i=s+t.length,n?a+="'+\n((__t=("+n+"))==null?'':_.escape(__t))+\n'":r?a+="'+\n((__t=("+r+"))==null?'':__t)+\n'":o&&(a+="';\n"+o+"\n__p+='"),t}),a+="';\n",t.variable||(a="with(obj||{}){\n"+a+"}\n"),a="var __t,__p='',__j=Array.prototype.join,print=function(){__p+=__j.call(arguments,'');};\n"+a+"return __p;\n";try{var o=new Function(t.variable||"obj","_",a)}catch(s){throw s.source=a,s}var u=function(e){return o.call(this,e,E)},l=t.variable||"obj";return u.source="function("+l+"){\n"+a+"}",u},E.chain=function(e){var t=E(e);return t._chain=!0,t};var Y=function(e,t){return e._chain?E(t).chain():t};E.mixin=function(e){E.each(E.functions(e),function(t){var n=E[t]=e[t];E.prototype[t]=function(){var e=[this._wrapped];return m.apply(e,arguments),Y(this,n.apply(E,e))}})},E.mixin(E),E.each(["pop","push","reverse","shift","sort","splice","unshift"],function(e){var t=p[e];E.prototype[e]=function(){var n=this._wrapped;return t.apply(n,arguments),"shift"!==e&&"splice"!==e||0!==n.length||delete n[0],Y(this,n)}}),E.each(["concat","join","slice"],function(e){var t=p[e];E.prototype[e]=function(){return Y(this,t.apply(this._wrapped,arguments))}}),E.prototype.value=function(){return this._wrapped},E.prototype.valueOf=E.prototype.toJSON=E.prototype.value,E.prototype.toString=function(){return""+this._wrapped},r=[],i=function(){return E}.apply(t,r),!(void 0!==i&&(e.exports=i))}).call(this)},function(e,t,n){"use strict";function r(e,t){return{name:e,methods:[],typeParameters:[],typeParameterConstraint:[],"implements":[],fields:[],isInterface:t,annotations:[],"extends":[],moduleName:null,annotationOverridings:{}}}function i(e,t,n){return a.parseStruct(e,t,n)}t.helpers=n(137);var a=n(138),o=function(){function e(){}return e}();t.EnumDeclaration=o,function(e){e[e.BASIC=0]="BASIC",e[e.ARRAY=1]="ARRAY",e[e.UNION=2]="UNION"}(t.TypeKind||(t.TypeKind={}));t.TypeKind;t.classDecl=r,t.parseStruct=i},function(e,t,n){(function(e,r){/*!
	 * The buffer module from node.js, for the browser.
	 *
	 * @author   Feross Aboukhadijeh <feross@feross.org> <http://feross.org>
	 * @license  MIT
	 */
"use strict";function i(){function e(){}try{var t=new Uint8Array(1);return t.foo=function(){return 42},t.constructor=e,42===t.foo()&&t.constructor===e&&"function"==typeof t.subarray&&0===t.subarray(1,1).byteLength}catch(n){return!1}}function a(){return e.TYPED_ARRAY_SUPPORT?2147483647:1073741823}function e(t){return this instanceof e?(e.TYPED_ARRAY_SUPPORT||(this.length=0,this.parent=void 0),"number"==typeof t?o(this,t):"string"==typeof t?s(this,t,arguments.length>1?arguments[1]:"utf8"):u(this,t)):arguments.length>1?new e(t,arguments[1]):new e(t)}function o(t,n){if(t=h(t,0>n?0:0|y(n)),!e.TYPED_ARRAY_SUPPORT)for(var r=0;n>r;r++)t[r]=0;return t}function s(e,t,n){("string"!=typeof n||""===n)&&(n="utf8");var r=0|g(t,n);return e=h(e,r),e.write(t,n),e}function u(t,n){if(e.isBuffer(n))return l(t,n);if(z(n))return p(t,n);if(null==n)throw new TypeError("must start with number, buffer, array or string");if("undefined"!=typeof ArrayBuffer){if(n.buffer instanceof ArrayBuffer)return c(t,n);if(n instanceof ArrayBuffer)return f(t,n)}return n.length?m(t,n):d(t,n)}function l(e,t){var n=0|y(t.length);return e=h(e,n),t.copy(e,0,0,n),e}function p(e,t){var n=0|y(t.length);e=h(e,n);for(var r=0;n>r;r+=1)e[r]=255&t[r];return e}function c(e,t){var n=0|y(t.length);e=h(e,n);for(var r=0;n>r;r+=1)e[r]=255&t[r];return e}function f(t,n){return e.TYPED_ARRAY_SUPPORT?(n.byteLength,t=e._augment(new Uint8Array(n))):t=c(t,new Uint8Array(n)),t}function m(e,t){var n=0|y(t.length);e=h(e,n);for(var r=0;n>r;r+=1)e[r]=255&t[r];return e}function d(e,t){var n,r=0;"Buffer"===t.type&&z(t.data)&&(n=t.data,r=0|y(n.length)),e=h(e,r);for(var i=0;r>i;i+=1)e[i]=255&n[i];return e}function h(t,n){e.TYPED_ARRAY_SUPPORT?(t=e._augment(new Uint8Array(n)),t.__proto__=e.prototype):(t.length=n,t._isBuffer=!0);var r=0!==n&&n<=e.poolSize>>>1;return r&&(t.parent=J),t}function y(e){if(e>=a())throw new RangeError("Attempt to allocate Buffer larger than maximum size: 0x"+a().toString(16)+" bytes");return 0|e}function v(t,n){if(!(this instanceof v))return new v(t,n);var r=new e(t,n);return delete r.parent,r}function g(e,t){"string"!=typeof e&&(e=""+e);var n=e.length;if(0===n)return 0;for(var r=!1;;)switch(t){case"ascii":case"binary":case"raw":case"raws":return n;case"utf8":case"utf-8":return W(e).length;case"ucs2":case"ucs-2":case"utf16le":case"utf-16le":return 2*n;case"hex":return n>>>1;case"base64":return H(e).length;default:if(r)return W(e).length;t=(""+t).toLowerCase(),r=!0}}function A(e,t,n){var r=!1;if(t=0|t,n=void 0===n||n===1/0?this.length:0|n,e||(e="utf8"),0>t&&(t=0),n>this.length&&(n=this.length),t>=n)return"";for(;;)switch(e){case"hex":return L(this,t,n);case"utf8":case"utf-8":return w(this,t,n);case"ascii":return I(this,t,n);case"binary":return C(this,t,n);case"base64":return M(this,t,n);case"ucs2":case"ucs-2":case"utf16le":case"utf-16le":return P(this,t,n);default:if(r)throw new TypeError("Unknown encoding: "+e);e=(e+"").toLowerCase(),r=!0}}function S(e,t,n,r){n=Number(n)||0;var i=e.length-n;r?(r=Number(r),r>i&&(r=i)):r=i;var a=t.length;if(a%2!==0)throw new Error("Invalid hex string");r>a/2&&(r=a/2);for(var o=0;r>o;o++){var s=parseInt(t.substr(2*o,2),16);if(isNaN(s))throw new Error("Invalid hex string");e[n+o]=s}return o}function T(e,t,n,r){return $(W(t,e.length-n),e,n,r)}function E(e,t,n,r){return $(q(t),e,n,r)}function b(e,t,n,r){return E(e,t,n,r)}function N(e,t,n,r){return $(H(t),e,n,r)}function _(e,t,n,r){return $(Y(t,e.length-n),e,n,r)}function M(e,t,n){return 0===t&&n===e.length?G.fromByteArray(e):G.fromByteArray(e.slice(t,n))}function w(e,t,n){n=Math.min(e.length,n);for(var r=[],i=t;n>i;){var a=e[i],o=null,s=a>239?4:a>223?3:a>191?2:1;if(n>=i+s){var u,l,p,c;switch(s){case 1:128>a&&(o=a);break;case 2:u=e[i+1],128===(192&u)&&(c=(31&a)<<6|63&u,c>127&&(o=c));break;case 3:u=e[i+1],l=e[i+2],128===(192&u)&&128===(192&l)&&(c=(15&a)<<12|(63&u)<<6|63&l,c>2047&&(55296>c||c>57343)&&(o=c));break;case 4:u=e[i+1],l=e[i+2],p=e[i+3],128===(192&u)&&128===(192&l)&&128===(192&p)&&(c=(15&a)<<18|(63&u)<<12|(63&l)<<6|63&p,c>65535&&1114112>c&&(o=c))}}null===o?(o=65533,s=1):o>65535&&(o-=65536,r.push(o>>>10&1023|55296),o=56320|1023&o),r.push(o),i+=s}return R(r)}function R(e){var t=e.length;if(Q>=t)return String.fromCharCode.apply(String,e);for(var n="",r=0;t>r;)n+=String.fromCharCode.apply(String,e.slice(r,r+=Q));return n}function I(e,t,n){var r="";n=Math.min(e.length,n);for(var i=t;n>i;i++)r+=String.fromCharCode(127&e[i]);return r}function C(e,t,n){var r="";n=Math.min(e.length,n);for(var i=t;n>i;i++)r+=String.fromCharCode(e[i]);return r}function L(e,t,n){var r=e.length;(!t||0>t)&&(t=0),(!n||0>n||n>r)&&(n=r);for(var i="",a=t;n>a;a++)i+=j(e[a]);return i}function P(e,t,n){for(var r=e.slice(t,n),i="",a=0;a<r.length;a+=2)i+=String.fromCharCode(r[a]+256*r[a+1]);return i}function O(e,t,n){if(e%1!==0||0>e)throw new RangeError("offset is not uint");if(e+t>n)throw new RangeError("Trying to access beyond buffer length")}function D(t,n,r,i,a,o){if(!e.isBuffer(t))throw new TypeError("buffer must be a Buffer instance");if(n>a||o>n)throw new RangeError("value is out of bounds");if(r+i>t.length)throw new RangeError("index out of range")}function x(e,t,n,r){0>t&&(t=65535+t+1);for(var i=0,a=Math.min(e.length-n,2);a>i;i++)e[n+i]=(t&255<<8*(r?i:1-i))>>>8*(r?i:1-i)}function U(e,t,n,r){0>t&&(t=4294967295+t+1);for(var i=0,a=Math.min(e.length-n,4);a>i;i++)e[n+i]=t>>>8*(r?i:3-i)&255}function k(e,t,n,r,i,a){if(t>i||a>t)throw new RangeError("value is out of bounds");if(n+r>e.length)throw new RangeError("index out of range");if(0>n)throw new RangeError("index out of range")}function F(e,t,n,r,i){return i||k(e,t,n,4,3.4028234663852886e38,-3.4028234663852886e38),X.write(e,t,n,r,23,4),n+4}function B(e,t,n,r,i){return i||k(e,t,n,8,1.7976931348623157e308,-1.7976931348623157e308),X.write(e,t,n,r,52,8),n+8}function K(e){if(e=V(e).replace(ee,""),e.length<2)return"";for(;e.length%4!==0;)e+="=";return e}function V(e){return e.trim?e.trim():e.replace(/^\s+|\s+$/g,"")}function j(e){return 16>e?"0"+e.toString(16):e.toString(16)}function W(e,t){t=t||1/0;for(var n,r=e.length,i=null,a=[],o=0;r>o;o++){if(n=e.charCodeAt(o),n>55295&&57344>n){if(!i){if(n>56319){(t-=3)>-1&&a.push(239,191,189);continue}if(o+1===r){(t-=3)>-1&&a.push(239,191,189);continue}i=n;continue}if(56320>n){(t-=3)>-1&&a.push(239,191,189),i=n;continue}n=(i-55296<<10|n-56320)+65536}else i&&(t-=3)>-1&&a.push(239,191,189);if(i=null,128>n){if((t-=1)<0)break;a.push(n)}else if(2048>n){if((t-=2)<0)break;a.push(n>>6|192,63&n|128)}else if(65536>n){if((t-=3)<0)break;a.push(n>>12|224,n>>6&63|128,63&n|128)}else{if(!(1114112>n))throw new Error("Invalid code point");if((t-=4)<0)break;a.push(n>>18|240,n>>12&63|128,n>>6&63|128,63&n|128)}}return a}function q(e){for(var t=[],n=0;n<e.length;n++)t.push(255&e.charCodeAt(n));return t}function Y(e,t){for(var n,r,i,a=[],o=0;o<e.length&&!((t-=2)<0);o++)n=e.charCodeAt(o),r=n>>8,i=n%256,a.push(i),a.push(r);return a}function H(e){return G.toByteArray(K(e))}function $(e,t,n,r){for(var i=0;r>i&&!(i+n>=t.length||i>=e.length);i++)t[i+n]=e[i];return i}var G=n(179),X=n(174),z=n(175);t.Buffer=e,t.SlowBuffer=v,t.INSPECT_MAX_BYTES=50,e.poolSize=8192;var J={};e.TYPED_ARRAY_SUPPORT=void 0!==r.TYPED_ARRAY_SUPPORT?r.TYPED_ARRAY_SUPPORT:i(),e.TYPED_ARRAY_SUPPORT?(e.prototype.__proto__=Uint8Array.prototype,e.__proto__=Uint8Array):(e.prototype.length=void 0,e.prototype.parent=void 0),e.isBuffer=function(e){return!(null==e||!e._isBuffer)},e.compare=function(t,n){if(!e.isBuffer(t)||!e.isBuffer(n))throw new TypeError("Arguments must be Buffers");if(t===n)return 0;for(var r=t.length,i=n.length,a=0,o=Math.min(r,i);o>a&&t[a]===n[a];)++a;return a!==o&&(r=t[a],i=n[a]),i>r?-1:r>i?1:0},e.isEncoding=function(e){switch(String(e).toLowerCase()){case"hex":case"utf8":case"utf-8":case"ascii":case"binary":case"base64":case"raw":case"ucs2":case"ucs-2":case"utf16le":case"utf-16le":return!0;default:return!1}},e.concat=function(t,n){if(!z(t))throw new TypeError("list argument must be an Array of Buffers.");if(0===t.length)return new e(0);var r;if(void 0===n)for(n=0,r=0;r<t.length;r++)n+=t[r].length;var i=new e(n),a=0;for(r=0;r<t.length;r++){var o=t[r];o.copy(i,a),a+=o.length}return i},e.byteLength=g,e.prototype.toString=function(){var e=0|this.length;return 0===e?"":0===arguments.length?w(this,0,e):A.apply(this,arguments)},e.prototype.equals=function(t){if(!e.isBuffer(t))throw new TypeError("Argument must be a Buffer");return this===t?!0:0===e.compare(this,t)},e.prototype.inspect=function(){var e="",n=t.INSPECT_MAX_BYTES;return this.length>0&&(e=this.toString("hex",0,n).match(/.{2}/g).join(" "),this.length>n&&(e+=" ... ")),"<Buffer "+e+">"},e.prototype.compare=function(t){if(!e.isBuffer(t))throw new TypeError("Argument must be a Buffer");return this===t?0:e.compare(this,t)},e.prototype.indexOf=function(t,n){function r(e,t,n){for(var r=-1,i=0;n+i<e.length;i++)if(e[n+i]===t[-1===r?0:i-r]){if(-1===r&&(r=i),i-r+1===t.length)return n+r}else r=-1;return-1}if(n>2147483647?n=2147483647:-2147483648>n&&(n=-2147483648),n>>=0,0===this.length)return-1;if(n>=this.length)return-1;if(0>n&&(n=Math.max(this.length+n,0)),"string"==typeof t)return 0===t.length?-1:String.prototype.indexOf.call(this,t,n);if(e.isBuffer(t))return r(this,t,n);if("number"==typeof t)return e.TYPED_ARRAY_SUPPORT&&"function"===Uint8Array.prototype.indexOf?Uint8Array.prototype.indexOf.call(this,t,n):r(this,[t],n);throw new TypeError("val must be string, number or Buffer")},e.prototype.get=function(e){return console.log(".get() is deprecated. Access using array indexes instead."),this.readUInt8(e)},e.prototype.set=function(e,t){return console.log(".set() is deprecated. Access using array indexes instead."),this.writeUInt8(e,t)},e.prototype.write=function(e,t,n,r){if(void 0===t)r="utf8",n=this.length,t=0;else if(void 0===n&&"string"==typeof t)r=t,n=this.length,t=0;else if(isFinite(t))t=0|t,isFinite(n)?(n=0|n,void 0===r&&(r="utf8")):(r=n,n=void 0);else{var i=r;r=t,t=0|n,n=i}var a=this.length-t;if((void 0===n||n>a)&&(n=a),e.length>0&&(0>n||0>t)||t>this.length)throw new RangeError("attempt to write outside buffer bounds");r||(r="utf8");for(var o=!1;;)switch(r){case"hex":return S(this,e,t,n);case"utf8":case"utf-8":return T(this,e,t,n);case"ascii":return E(this,e,t,n);case"binary":return b(this,e,t,n);case"base64":return N(this,e,t,n);case"ucs2":case"ucs-2":case"utf16le":case"utf-16le":return _(this,e,t,n);default:if(o)throw new TypeError("Unknown encoding: "+r);r=(""+r).toLowerCase(),o=!0}},e.prototype.toJSON=function(){return{type:"Buffer",data:Array.prototype.slice.call(this._arr||this,0)}};var Q=4096;e.prototype.slice=function(t,n){var r=this.length;t=~~t,n=void 0===n?r:~~n,0>t?(t+=r,0>t&&(t=0)):t>r&&(t=r),0>n?(n+=r,0>n&&(n=0)):n>r&&(n=r),t>n&&(n=t);var i;if(e.TYPED_ARRAY_SUPPORT)i=e._augment(this.subarray(t,n));else{var a=n-t;i=new e(a,void 0);for(var o=0;a>o;o++)i[o]=this[o+t]}return i.length&&(i.parent=this.parent||this),i},e.prototype.readUIntLE=function(e,t,n){e=0|e,t=0|t,n||O(e,t,this.length);for(var r=this[e],i=1,a=0;++a<t&&(i*=256);)r+=this[e+a]*i;return r},e.prototype.readUIntBE=function(e,t,n){e=0|e,t=0|t,n||O(e,t,this.length);for(var r=this[e+--t],i=1;t>0&&(i*=256);)r+=this[e+--t]*i;return r},e.prototype.readUInt8=function(e,t){return t||O(e,1,this.length),this[e]},e.prototype.readUInt16LE=function(e,t){return t||O(e,2,this.length),this[e]|this[e+1]<<8},e.prototype.readUInt16BE=function(e,t){return t||O(e,2,this.length),this[e]<<8|this[e+1]},e.prototype.readUInt32LE=function(e,t){return t||O(e,4,this.length),(this[e]|this[e+1]<<8|this[e+2]<<16)+16777216*this[e+3]},e.prototype.readUInt32BE=function(e,t){return t||O(e,4,this.length),16777216*this[e]+(this[e+1]<<16|this[e+2]<<8|this[e+3])},e.prototype.readIntLE=function(e,t,n){e=0|e,t=0|t,n||O(e,t,this.length);for(var r=this[e],i=1,a=0;++a<t&&(i*=256);)r+=this[e+a]*i;return i*=128,r>=i&&(r-=Math.pow(2,8*t)),r},e.prototype.readIntBE=function(e,t,n){e=0|e,t=0|t,n||O(e,t,this.length);for(var r=t,i=1,a=this[e+--r];r>0&&(i*=256);)a+=this[e+--r]*i;return i*=128,a>=i&&(a-=Math.pow(2,8*t)),a},e.prototype.readInt8=function(e,t){return t||O(e,1,this.length),128&this[e]?-1*(255-this[e]+1):this[e]},e.prototype.readInt16LE=function(e,t){t||O(e,2,this.length);var n=this[e]|this[e+1]<<8;return 32768&n?4294901760|n:n},e.prototype.readInt16BE=function(e,t){t||O(e,2,this.length);var n=this[e+1]|this[e]<<8;return 32768&n?4294901760|n:n},e.prototype.readInt32LE=function(e,t){return t||O(e,4,this.length),this[e]|this[e+1]<<8|this[e+2]<<16|this[e+3]<<24},e.prototype.readInt32BE=function(e,t){return t||O(e,4,this.length),this[e]<<24|this[e+1]<<16|this[e+2]<<8|this[e+3]},e.prototype.readFloatLE=function(e,t){return t||O(e,4,this.length),X.read(this,e,!0,23,4)},e.prototype.readFloatBE=function(e,t){return t||O(e,4,this.length),X.read(this,e,!1,23,4)},e.prototype.readDoubleLE=function(e,t){return t||O(e,8,this.length),X.read(this,e,!0,52,8)},e.prototype.readDoubleBE=function(e,t){return t||O(e,8,this.length),X.read(this,e,!1,52,8)},e.prototype.writeUIntLE=function(e,t,n,r){e=+e,t=0|t,n=0|n,r||D(this,e,t,n,Math.pow(2,8*n),0);var i=1,a=0;for(this[t]=255&e;++a<n&&(i*=256);)this[t+a]=e/i&255;return t+n},e.prototype.writeUIntBE=function(e,t,n,r){e=+e,t=0|t,n=0|n,r||D(this,e,t,n,Math.pow(2,8*n),0);var i=n-1,a=1;for(this[t+i]=255&e;--i>=0&&(a*=256);)this[t+i]=e/a&255;return t+n},e.prototype.writeUInt8=function(t,n,r){return t=+t,n=0|n,r||D(this,t,n,1,255,0),e.TYPED_ARRAY_SUPPORT||(t=Math.floor(t)),this[n]=255&t,n+1},e.prototype.writeUInt16LE=function(t,n,r){return t=+t,n=0|n,r||D(this,t,n,2,65535,0),e.TYPED_ARRAY_SUPPORT?(this[n]=255&t,this[n+1]=t>>>8):x(this,t,n,!0),n+2},e.prototype.writeUInt16BE=function(t,n,r){return t=+t,n=0|n,r||D(this,t,n,2,65535,0),e.TYPED_ARRAY_SUPPORT?(this[n]=t>>>8,this[n+1]=255&t):x(this,t,n,!1),n+2},e.prototype.writeUInt32LE=function(t,n,r){return t=+t,n=0|n,r||D(this,t,n,4,4294967295,0),e.TYPED_ARRAY_SUPPORT?(this[n+3]=t>>>24,this[n+2]=t>>>16,this[n+1]=t>>>8,this[n]=255&t):U(this,t,n,!0),n+4},e.prototype.writeUInt32BE=function(t,n,r){return t=+t,n=0|n,r||D(this,t,n,4,4294967295,0),e.TYPED_ARRAY_SUPPORT?(this[n]=t>>>24,this[n+1]=t>>>16,this[n+2]=t>>>8,this[n+3]=255&t):U(this,t,n,!1),n+4},e.prototype.writeIntLE=function(e,t,n,r){if(e=+e,t=0|t,!r){var i=Math.pow(2,8*n-1);D(this,e,t,n,i-1,-i)}var a=0,o=1,s=0>e?1:0;for(this[t]=255&e;++a<n&&(o*=256);)this[t+a]=(e/o>>0)-s&255;return t+n},e.prototype.writeIntBE=function(e,t,n,r){if(e=+e,t=0|t,!r){var i=Math.pow(2,8*n-1);D(this,e,t,n,i-1,-i)}var a=n-1,o=1,s=0>e?1:0;for(this[t+a]=255&e;--a>=0&&(o*=256);)this[t+a]=(e/o>>0)-s&255;return t+n},e.prototype.writeInt8=function(t,n,r){return t=+t,n=0|n,r||D(this,t,n,1,127,-128),e.TYPED_ARRAY_SUPPORT||(t=Math.floor(t)),0>t&&(t=255+t+1),this[n]=255&t,n+1},e.prototype.writeInt16LE=function(t,n,r){return t=+t,n=0|n,r||D(this,t,n,2,32767,-32768),e.TYPED_ARRAY_SUPPORT?(this[n]=255&t,this[n+1]=t>>>8):x(this,t,n,!0),n+2},e.prototype.writeInt16BE=function(t,n,r){return t=+t,n=0|n,r||D(this,t,n,2,32767,-32768),e.TYPED_ARRAY_SUPPORT?(this[n]=t>>>8,this[n+1]=255&t):x(this,t,n,!1),n+2},e.prototype.writeInt32LE=function(t,n,r){return t=+t,n=0|n,r||D(this,t,n,4,2147483647,-2147483648),e.TYPED_ARRAY_SUPPORT?(this[n]=255&t,this[n+1]=t>>>8,this[n+2]=t>>>16,this[n+3]=t>>>24):U(this,t,n,!0),n+4},e.prototype.writeInt32BE=function(t,n,r){return t=+t,n=0|n,r||D(this,t,n,4,2147483647,-2147483648),0>t&&(t=4294967295+t+1),e.TYPED_ARRAY_SUPPORT?(this[n]=t>>>24,this[n+1]=t>>>16,this[n+2]=t>>>8,this[n+3]=255&t):U(this,t,n,!1),n+4},e.prototype.writeFloatLE=function(e,t,n){return F(this,e,t,!0,n)},e.prototype.writeFloatBE=function(e,t,n){return F(this,e,t,!1,n)},e.prototype.writeDoubleLE=function(e,t,n){return B(this,e,t,!0,n)},e.prototype.writeDoubleBE=function(e,t,n){return B(this,e,t,!1,n)},e.prototype.copy=function(t,n,r,i){if(r||(r=0),i||0===i||(i=this.length),n>=t.length&&(n=t.length),n||(n=0),i>0&&r>i&&(i=r),i===r)return 0;if(0===t.length||0===this.length)return 0;if(0>n)throw new RangeError("targetStart out of bounds");if(0>r||r>=this.length)throw new RangeError("sourceStart out of bounds");if(0>i)throw new RangeError("sourceEnd out of bounds");i>this.length&&(i=this.length),t.length-n<i-r&&(i=t.length-n+r);var a,o=i-r;if(this===t&&n>r&&i>n)for(a=o-1;a>=0;a--)t[a+n]=this[a+r];else if(1e3>o||!e.TYPED_ARRAY_SUPPORT)for(a=0;o>a;a++)t[a+n]=this[a+r];else t._set(this.subarray(r,r+o),n);return o},e.prototype.fill=function(e,t,n){if(e||(e=0),t||(t=0),n||(n=this.length),t>n)throw new RangeError("end < start");if(n!==t&&0!==this.length){if(0>t||t>=this.length)throw new RangeError("start out of bounds");if(0>n||n>this.length)throw new RangeError("end out of bounds");var r;if("number"==typeof e)for(r=t;n>r;r++)this[r]=e;else{var i=W(e.toString()),a=i.length;for(r=t;n>r;r++)this[r]=i[r%a]}return this}},e.prototype.toArrayBuffer=function(){if("undefined"!=typeof Uint8Array){if(e.TYPED_ARRAY_SUPPORT)return new e(this).buffer;for(var t=new Uint8Array(this.length),n=0,r=t.length;r>n;n+=1)t[n]=this[n];return t.buffer}throw new TypeError("Buffer.toArrayBuffer not supported in this browser")};var Z=e.prototype;e._augment=function(t){return t.constructor=e,t._isBuffer=!0,t._set=t.set,t.get=Z.get,t.set=Z.set,t.write=Z.write,t.toString=Z.toString,t.toLocaleString=Z.toString,t.toJSON=Z.toJSON,t.equals=Z.equals,t.compare=Z.compare,t.indexOf=Z.indexOf,t.copy=Z.copy,t.slice=Z.slice,t.readUIntLE=Z.readUIntLE,t.readUIntBE=Z.readUIntBE,t.readUInt8=Z.readUInt8,t.readUInt16LE=Z.readUInt16LE,t.readUInt16BE=Z.readUInt16BE,t.readUInt32LE=Z.readUInt32LE,t.readUInt32BE=Z.readUInt32BE,t.readIntLE=Z.readIntLE,t.readIntBE=Z.readIntBE,t.readInt8=Z.readInt8,t.readInt16LE=Z.readInt16LE,t.readInt16BE=Z.readInt16BE,t.readInt32LE=Z.readInt32LE,t.readInt32BE=Z.readInt32BE,t.readFloatLE=Z.readFloatLE,t.readFloatBE=Z.readFloatBE,t.readDoubleLE=Z.readDoubleLE,t.readDoubleBE=Z.readDoubleBE,t.writeUInt8=Z.writeUInt8,t.writeUIntLE=Z.writeUIntLE,t.writeUIntBE=Z.writeUIntBE,t.writeUInt16LE=Z.writeUInt16LE,t.writeUInt16BE=Z.writeUInt16BE,t.writeUInt32LE=Z.writeUInt32LE,t.writeUInt32BE=Z.writeUInt32BE,t.writeIntLE=Z.writeIntLE,t.writeIntBE=Z.writeIntBE,t.writeInt8=Z.writeInt8,t.writeInt16LE=Z.writeInt16LE,t.writeInt16BE=Z.writeInt16BE,t.writeInt32LE=Z.writeInt32LE,t.writeInt32BE=Z.writeInt32BE,t.writeFloatLE=Z.writeFloatLE,t.writeFloatBE=Z.writeFloatBE,t.writeDoubleLE=Z.writeDoubleLE,t.writeDoubleBE=Z.writeDoubleBE,t.fill=Z.fill,t.inspect=Z.inspect,t.toArrayBuffer=Z.toArrayBuffer,t};var ee=/[^+\/0-9A-Za-z-_]/g}).call(t,n(94).Buffer,function(){return this}())},function(e,t,n){"use strict";function r(e,t){return Object.prototype.hasOwnProperty.call(e,t)}e.exports=function(e,t,n,i){t=t||"&",n=n||"=";var a={};if("string"!=typeof e||0===e.length)return a;var o=/\+/g;e=e.split(t);var s=1e3;i&&"number"==typeof i.maxKeys&&(s=i.maxKeys);var u=e.length;s>0&&u>s&&(u=s);for(var l=0;u>l;++l){var p,c,f,m,d=e[l].replace(o,"%20"),h=d.indexOf(n);h>=0?(p=d.substr(0,h),c=d.substr(h+1)):(p=d,c=""),f=decodeURIComponent(p),m=decodeURIComponent(c),r(a,f)?Array.isArray(a[f])?a[f].push(m):a[f]=[a[f],m]:a[f]=m}return a}},function(e,t,n){"use strict";var r=function(e){switch(typeof e){case"string":return e;case"boolean":return e?"true":"false";case"number":return isFinite(e)?e:"";default:return""}};e.exports=function(e,t,n,i){return t=t||"&",n=n||"=",null===e&&(e=void 0),"object"==typeof e?Object.keys(e).map(function(i){var a=encodeURIComponent(r(i))+n;return Array.isArray(e[i])?e[i].map(function(e){return a+encodeURIComponent(r(e))}).join(t):a+encodeURIComponent(r(e[i]))}).join(t):i?encodeURIComponent(r(i))+n+encodeURIComponent(r(e)):""}},function(e,t,n){function r(e){if(k&&M){var t,n=k(e);for(t=0;t<n.length;t+=1)M(e,n[t],{value:e[n[t]],writable:!1,enumerable:!1,configurable:!1})}}function i(e){function t(t){M(e,t,{get:function(){return e._getter(t)},set:function(n){e._setter(t,n)},enumerable:!0,configurable:!1})}if(M){if(e.length>R)throw new RangeError("Array too large for polyfill");var n;for(n=0;n<e.length;n+=1)t(n)}}function a(e,t){var n=32-t;return e<<n>>n}function o(e,t){var n=32-t;return e<<n>>>n}function s(e){return[255&e]}function u(e){return a(e[0],8)}function l(e){return[255&e]}function p(e){return o(e[0],8)}function c(e){return e=U(Number(e)),[0>e?0:e>255?255:255&e]}function f(e){return[e>>8&255,255&e]}function m(e){return a(e[0]<<8|e[1],16)}function d(e){return[e>>8&255,255&e]}function h(e){return o(e[0]<<8|e[1],16)}function y(e){return[e>>24&255,e>>16&255,e>>8&255,255&e]}function v(e){return a(e[0]<<24|e[1]<<16|e[2]<<8|e[3],32)}function g(e){return[e>>24&255,e>>16&255,e>>8&255,255&e]}function A(e){return o(e[0]<<24|e[1]<<16|e[2]<<8|e[3],32)}function S(e,t,n){function r(e){var t=P(e),n=e-t;return.5>n?t:n>.5?t+1:t%2?t+1:t}var i,a,o,s,u,l,p,c=(1<<t-1)-1;for(e!==e?(a=(1<<t)-1,o=x(2,n-1),i=0):e===1/0||e===-(1/0)?(a=(1<<t)-1,o=0,i=0>e?1:0):0===e?(a=0,o=0,i=1/e===-(1/0)?1:0):(i=0>e,e=L(e),e>=x(2,1-c)?(a=D(P(O(e)/C),1023),o=r(e/x(2,a)*x(2,n)),o/x(2,n)>=2&&(a+=1,o=1),a>c?(a=(1<<t)-1,o=0):(a+=c,o-=x(2,n))):(a=0,o=r(e/x(2,1-c-n)))),u=[],s=n;s;s-=1)u.push(o%2?1:0),o=P(o/2);for(s=t;s;s-=1)u.push(a%2?1:0),a=P(a/2);for(u.push(i?1:0),u.reverse(),l=u.join(""),p=[];l.length;)p.push(parseInt(l.substring(0,8),2)),l=l.substring(8);return p}function T(e,t,n){var r,i,a,o,s,u,l,p,c=[];for(r=e.length;r;r-=1)for(a=e[r-1],i=8;i;i-=1)c.push(a%2?1:0),a>>=1;return c.reverse(),o=c.join(""),s=(1<<t-1)-1,u=parseInt(o.substring(0,1),2)?-1:1,l=parseInt(o.substring(1,1+t),2),p=parseInt(o.substring(1+t),2),l===(1<<t)-1?0!==p?NaN:u*(1/0):l>0?u*x(2,l-s)*(1+p/x(2,n)):0!==p?u*x(2,-(s-1))*(p/x(2,n)):0>u?-0:0}function E(e){return T(e,11,52)}function b(e){return S(e,11,52)}function N(e){return T(e,8,23)}function _(e){return S(e,8,23)}var M,w=void 0,R=1e5,I=function(){var e=Object.prototype.toString,t=Object.prototype.hasOwnProperty;return{Class:function(t){return e.call(t).replace(/^\[object *|\]$/g,"")},HasProperty:function(e,t){return t in e},HasOwnProperty:function(e,n){return t.call(e,n)},IsCallable:function(e){return"function"==typeof e},ToInt32:function(e){return e>>0},ToUint32:function(e){return e>>>0}}}(),C=Math.LN2,L=Math.abs,P=Math.floor,O=Math.log,D=Math.min,x=Math.pow,U=Math.round;M=Object.defineProperty&&function(){try{return Object.defineProperty({},"x",{}),!0}catch(e){return!1}}()?Object.defineProperty:function(e,t,n){if(!e===Object(e))throw new TypeError("Object.defineProperty called on non-object");return I.HasProperty(n,"get")&&Object.prototype.__defineGetter__&&Object.prototype.__defineGetter__.call(e,t,n.get),I.HasProperty(n,"set")&&Object.prototype.__defineSetter__&&Object.prototype.__defineSetter__.call(e,t,n.set),I.HasProperty(n,"value")&&(e[t]=n.value),e};var k=Object.getOwnPropertyNames||function(e){if(e!==Object(e))throw new TypeError("Object.getOwnPropertyNames called on non-object");var t,n=[];for(t in e)I.HasOwnProperty(e,t)&&n.push(t);return n};!function(){function e(e,t,o){var s;return s=function(e,t,a){var o,u,l,p;if(arguments.length&&"number"!=typeof arguments[0])if("object"==typeof arguments[0]&&arguments[0].constructor===s)for(o=arguments[0],this.length=o.length,this.byteLength=this.length*this.BYTES_PER_ELEMENT,this.buffer=new n(this.byteLength),this.byteOffset=0,l=0;l<this.length;l+=1)this._setter(l,o._getter(l));else if("object"!=typeof arguments[0]||(arguments[0]instanceof n||"ArrayBuffer"===I.Class(arguments[0]))){if("object"!=typeof arguments[0]||!(arguments[0]instanceof n||"ArrayBuffer"===I.Class(arguments[0])))throw new TypeError("Unexpected argument type(s)");if(this.buffer=e,this.byteOffset=I.ToUint32(t),this.byteOffset>this.buffer.byteLength)throw new RangeError("byteOffset out of range");if(this.byteOffset%this.BYTES_PER_ELEMENT)throw new RangeError("ArrayBuffer length minus the byteOffset is not a multiple of the element size.");if(arguments.length<3){if(this.byteLength=this.buffer.byteLength-this.byteOffset,this.byteLength%this.BYTES_PER_ELEMENT)throw new RangeError("length of buffer minus byteOffset not a multiple of the element size");this.length=this.byteLength/this.BYTES_PER_ELEMENT}else this.length=I.ToUint32(a),this.byteLength=this.length*this.BYTES_PER_ELEMENT;if(this.byteOffset+this.byteLength>this.buffer.byteLength)throw new RangeError("byteOffset and length reference an area beyond the end of the buffer")}else for(u=arguments[0],this.length=I.ToUint32(u.length),this.byteLength=this.length*this.BYTES_PER_ELEMENT,this.buffer=new n(this.byteLength),this.byteOffset=0,l=0;l<this.length;l+=1)p=u[l],this._setter(l,Number(p));else{if(this.length=I.ToInt32(arguments[0]),0>a)throw new RangeError("ArrayBufferView size is not a small enough positive integer");this.byteLength=this.length*this.BYTES_PER_ELEMENT,this.buffer=new n(this.byteLength),this.byteOffset=0}this.constructor=s,r(this),i(this)},s.prototype=new a,s.prototype.BYTES_PER_ELEMENT=e,s.prototype._pack=t,s.prototype._unpack=o,s.BYTES_PER_ELEMENT=e,s.prototype._getter=function(e){if(arguments.length<1)throw new SyntaxError("Not enough arguments");if(e=I.ToUint32(e),e>=this.length)return w;var t,n,r=[];for(t=0,n=this.byteOffset+e*this.BYTES_PER_ELEMENT;t<this.BYTES_PER_ELEMENT;t+=1,n+=1)r.push(this.buffer._bytes[n]);return this._unpack(r)},s.prototype.get=s.prototype._getter,s.prototype._setter=function(e,t){if(arguments.length<2)throw new SyntaxError("Not enough arguments");if(e=I.ToUint32(e),e>=this.length)return w;var n,r,i=this._pack(t);for(n=0,r=this.byteOffset+e*this.BYTES_PER_ELEMENT;n<this.BYTES_PER_ELEMENT;n+=1,r+=1)this.buffer._bytes[r]=i[n]},s.prototype.set=function(e,t){if(arguments.length<1)throw new SyntaxError("Not enough arguments");var n,r,i,a,o,s,u,l,p,c;if("object"==typeof arguments[0]&&arguments[0].constructor===this.constructor){if(n=arguments[0],i=I.ToUint32(arguments[1]),i+n.length>this.length)throw new RangeError("Offset plus length of array is out of range");if(l=this.byteOffset+i*this.BYTES_PER_ELEMENT,p=n.length*this.BYTES_PER_ELEMENT,n.buffer===this.buffer){for(c=[],o=0,s=n.byteOffset;p>o;o+=1,s+=1)c[o]=n.buffer._bytes[s];for(o=0,u=l;p>o;o+=1,u+=1)this.buffer._bytes[u]=c[o]}else for(o=0,s=n.byteOffset,u=l;p>o;o+=1,s+=1,u+=1)this.buffer._bytes[u]=n.buffer._bytes[s]}else{if("object"!=typeof arguments[0]||"undefined"==typeof arguments[0].length)throw new TypeError("Unexpected argument type(s)");if(r=arguments[0],a=I.ToUint32(r.length),i=I.ToUint32(arguments[1]),i+a>this.length)throw new RangeError("Offset plus length of array is out of range");for(o=0;a>o;o+=1)s=r[o],this._setter(i+o,Number(s))}},s.prototype.subarray=function(e,t){function n(e,t,n){return t>e?t:e>n?n:e}e=I.ToInt32(e),t=I.ToInt32(t),arguments.length<1&&(e=0),arguments.length<2&&(t=this.length),0>e&&(e=this.length+e),0>t&&(t=this.length+t),e=n(e,0,this.length),t=n(t,0,this.length);var r=t-e;return 0>r&&(r=0),new this.constructor(this.buffer,this.byteOffset+e*this.BYTES_PER_ELEMENT,r)},s}var n=function(e){if(e=I.ToInt32(e),0>e)throw new RangeError("ArrayBuffer size is not a small enough positive integer");this.byteLength=e,this._bytes=[],this._bytes.length=e;var t;for(t=0;t<this.byteLength;t+=1)this._bytes[t]=0;r(this)};t.ArrayBuffer=t.ArrayBuffer||n;var a=function(){},o=e(1,s,u),S=e(1,l,p),T=e(1,c,p),M=e(2,f,m),R=e(2,d,h),C=e(4,y,v),L=e(4,g,A),P=e(4,_,N),O=e(8,b,E);t.Int8Array=t.Int8Array||o,t.Uint8Array=t.Uint8Array||S,t.Uint8ClampedArray=t.Uint8ClampedArray||T,t.Int16Array=t.Int16Array||M,t.Uint16Array=t.Uint16Array||R,t.Int32Array=t.Int32Array||C,t.Uint32Array=t.Uint32Array||L,t.Float32Array=t.Float32Array||P,t.Float64Array=t.Float64Array||O}(),function(){function e(e,t){return I.IsCallable(e.get)?e.get(t):e[t]}function n(n){return function(r,i){if(r=I.ToUint32(r),r+n.BYTES_PER_ELEMENT>this.byteLength)throw new RangeError("Array index out of range");r+=this.byteOffset;var o,s=new t.Uint8Array(this.buffer,r,n.BYTES_PER_ELEMENT),u=[];for(o=0;o<n.BYTES_PER_ELEMENT;o+=1)u.push(e(s,o));return Boolean(i)===Boolean(a)&&u.reverse(),e(new n(new t.Uint8Array(u).buffer),0)}}function i(n){return function(r,i,o){if(r=I.ToUint32(r),r+n.BYTES_PER_ELEMENT>this.byteLength)throw new RangeError("Array index out of range");var s,u,l=new n([i]),p=new t.Uint8Array(l.buffer),c=[];for(s=0;s<n.BYTES_PER_ELEMENT;s+=1)c.push(e(p,s));Boolean(o)===Boolean(a)&&c.reverse(),u=new t.Uint8Array(this.buffer,r,n.BYTES_PER_ELEMENT),u.set(c)}}var a=function(){var n=new t.Uint16Array([4660]),r=new t.Uint8Array(n.buffer);return 18===e(r,0)}(),o=function(e,n,i){if(0===arguments.length)e=new t.ArrayBuffer(0);else if(!(e instanceof t.ArrayBuffer||"ArrayBuffer"===I.Class(e)))throw new TypeError("TypeError");if(this.buffer=e||new t.ArrayBuffer(0),this.byteOffset=I.ToUint32(n),this.byteOffset>this.buffer.byteLength)throw new RangeError("byteOffset out of range");if(arguments.length<3?this.byteLength=this.buffer.byteLength-this.byteOffset:this.byteLength=I.ToUint32(i),this.byteOffset+this.byteLength>this.buffer.byteLength)throw new RangeError("byteOffset and length reference an area beyond the end of the buffer");r(this)};o.prototype.getUint8=n(t.Uint8Array),o.prototype.getInt8=n(t.Int8Array),o.prototype.getUint16=n(t.Uint16Array),o.prototype.getInt16=n(t.Int16Array),o.prototype.getUint32=n(t.Uint32Array),o.prototype.getInt32=n(t.Int32Array),o.prototype.getFloat32=n(t.Float32Array),o.prototype.getFloat64=n(t.Float64Array),o.prototype.setUint8=i(t.Uint8Array),o.prototype.setInt8=i(t.Int8Array),o.prototype.setUint16=i(t.Uint16Array),o.prototype.setInt16=i(t.Int16Array),o.prototype.setUint32=i(t.Uint32Array),o.prototype.setInt32=i(t.Int32Array),o.prototype.setFloat32=i(t.Float32Array),o.prototype.setFloat64=i(t.Float64Array),t.DataView=t.DataView||o}()},function(e,t,n){"use strict";function r(){return new b(b.OK,"","",null)}function i(e,t,n,r,i){void 0===n&&(n={}),void 0===r&&(r=b.ERROR),void 0===i&&(i=!1);var a=N(e,n);return new b(r,e.code,a,t,i)}function a(){return te}function o(e,t){return new Z(e,t)}function s(e,t){return new ee(e,t)}function u(e,n){var r=new J(e);return n.forEach(function(e){return r.addSuper(e)}),r.isSubTypeOf(t.NIL)&&(r.nullable=!0),r}function l(e){return u(e,[t.OBJECT])}function p(e,t,n){if(t.isScalar()&&n.isScalar()){if(-1!=t.allSubTypes().indexOf(n))return t;if(-1!=n.allSubTypes().indexOf(t))return n}var r=t.oneMeta(I.Discriminator),i=n.oneMeta(I.Discriminator);if(r&&i&&r.property===i.property){var a=t.descValue(),o=n.descValue();if(a!==o){var s=e[r.property];if(s===a)return t;if(s===o)return n}}return null}function c(e){return parseFloat(e)!=parseInt(e)||isNaN(e)?!1:!0}function f(e){for(var t=[];null!=e;){if(null!=e.name()){t.push(e.name());break}if(!(e instanceof J))break;var n=e.contextMeta();if(null==n)break;t.push(n.path()),e=n._owner}return t.reverse()}function m(e,n,a){var o=n.metaOfType(I.Discriminator);if(0==o.length)return null;var s=o[0].value(),u=S.find([n].concat(n.allSuperTypes()),function(e){return e.getExtra(t.GLOBAL)});if(!u)return null;var l=u.name(),p=n.metaOfType(I.DiscriminatorValue);if(0!=p.length&&(l=p[0].value()),l){if(e.hasOwnProperty(s)){var c=e[s];if(c!=l){var f=i(b.CODE_INCORRECT_DISCRIMINATOR,this,{rootType:u.name(),value:c,propName:s},b.WARNING);return d(f,{name:s,child:a}),f}return r()}var m=i(b.CODE_MISSING_DISCRIMINATOR,this,{rootType:u.name(),propName:s});return d(m,a),m}}function d(e,t){if(e.getValidationPath()){for(var n=h(t),r=n;r.child;)r=r.child;r.child=e.getValidationPath(),e.setValidationPath(n)}else e.setValidationPath(t);e.getSubStatuses().forEach(function(e){d(e,t)})}function h(e){if(e){for(var t=e,n=null,r=null;t;)if(n){var i={name:t.name};r.child=i,t=t.child,r=i}else n={name:t.name},r=n,t=t.child,r=n;return n}return null}function y(e){for(var t=E.getAnnotationValidationPlugins(),n=[],r=0,i=t;r<i.length;r++){var a=i[r],o=a.process(e);o&&o.forEach(function(t){n.push(g(t,a.id(),e.entry()))})}return n}function v(e,t){for(var n=E.getTypeValidationPlugins(),r=[],i=0,a=n;i<a.length;i++){var o=a[i],s=o.process(e,t);s&&s.forEach(function(t){r.push(g(t,o.id(),e))})}return r}function g(e,t,n){
var r=e.isWarning?b.WARNING:b.ERROR,i=e.issueCode||t,a=e.message||"The "+t+" plugin reports an error",o=new b(r,i,a,n);return o.setValidationPath(e.path),o}var A=this&&this.__extends||function(e,t){function n(){this.constructor=e}for(var r in t)t.hasOwnProperty(r)&&(e[r]=t[r]);e.prototype=null===t?Object.create(t):(n.prototype=t.prototype,new n)},S=n(187),T=n(108),E=n(99);t.messageRegistry=n(185);var b=function(){function e(e,t,n,r,i){void 0===i&&(i=!1),this.takeNodeFromSource=i,this.subStatus=[],this.severity=e,this.code=t,this.message=n,this.source=r}return e.prototype.getValidationPath=function(){return this.vp},e.prototype.getValidationPathAsString=function(){if(!this.vp)return"";for(var e="",t=this.vp;t;)e+=t.name,t.child&&(e+="/"),t=t.child;return e},e.prototype.setValidationPath=function(e){this.vp=e},e.prototype.addSubStatus=function(t,n){void 0===n&&(n=null),n&&d(t,{name:n}),this.subStatus.push(t);var r=e.OK;t.isOk()||(t.isError()?r=e.ERROR:t.isWarning()?r=e.WARNING:t.isInfo()&&(r=e.INFO)),this.severity<r&&(this.severity=r,this.message=t.getMessage())},e.prototype.getErrors=function(){if(this.isError()||this.isWarning()){if(this.subStatus.length>0){var e=[];return this.subStatus.forEach(function(t){return e=e.concat(t.getErrors())}),e}return[this]}return[]},e.prototype.getSubStatuses=function(){return this.subStatus},e.prototype.getSeverity=function(){return this.severity},e.prototype.getMessage=function(){return this.message},e.prototype.setMessage=function(e){this.message=e},e.prototype.getSource=function(){return this.source},e.prototype.getCode=function(){return this.code},e.prototype.setCode=function(e){this.code=e},e.prototype.isWarning=function(){return this.severity==e.WARNING},e.prototype.isError=function(){return this.severity==e.ERROR},e.prototype.isOk=function(){return this.severity===e.OK},e.prototype.isInfo=function(){return this.severity===e.INFO},e.prototype.setSource=function(e){this.source=e},e.prototype.toString=function(){return this.isOk()?"OK":this.message},e.prototype.getExtra=function(e){return this.takeNodeFromSource&&e==E.SOURCE_EXTRA&&this.source instanceof _?this.source.node():null},e.prototype.putExtra=function(e,t){},e.CODE_CONFLICTING_TYPE_KIND=4,e.CODE_INCORRECT_DISCRIMINATOR=t.messageRegistry.INCORRECT_DISCRIMINATOR,e.CODE_MISSING_DISCRIMINATOR=t.messageRegistry.MISSING_DISCRIMINATOR,e.ERROR=3,e.INFO=1,e.OK=0,e.WARNING=2,e}();t.Status=b,t.ok=r,t.SCHEMA_AND_TYPE=E.SCHEMA_AND_TYPE_EXTRA,t.GLOBAL=E.GLOBAL_EXTRA,t.TOPLEVEL=E.TOP_LEVEL_EXTRA,t.SOURCE_EXTRA=E.SOURCE_EXTRA;var N=function(e,t){for(var n="",r=e.message,i=0,a=r.indexOf("{{");a>=0;a=r.indexOf("{{",i)){if(n+=r.substring(i,a),i=r.indexOf("}}",a),0>i){i=a;break}a+="{{".length;var o=r.substring(a,i);i+="}}".length;var s=t[o];if(void 0===s)throw new Error("Message parameter '"+o+"' has no value specified.");n+=s}return n+=r.substring(i,r.length)};t.error=i;var _=function(){function e(e){this._inheritable=e,this._annotations=[]}return e.prototype.node=function(){return this._node},e.prototype.setNode=function(e){this._node=e},e.prototype.owner=function(){return this._owner},e.prototype.isInheritable=function(){return this._inheritable},e.prototype.validateSelf=function(e){for(var t=r(),n=0,i=this._annotations;n<i.length;n++){var a=i[n],o=a.validateSelf(e);o.isOk()||t.addSubStatus(o)}for(var s=new ye(this,e),u=y(s),l=0,p=u;l<p.length;l++){var c=p[l];t.addSubStatus(c)}return d(t,{name:this.facetName()}),t},e.prototype.requiredTypes=function(){return[]},e.prototype.annotations=function(){return this._annotations},e.prototype.addAnnotation=function(e){this._annotations.push(e)},e}();t.TypeInformation=_;var M=null,w=function(e){function t(t){void 0===t&&(t=!0),e.call(this,t)}return A(t,e),t.prototype.intersect=function(e,n){var r=e.id()+""+n.id();if(t.intersections.hasOwnProperty(r))return t.intersections[r];var i=s(r,[e,n]);return t.intersections[r]=i,i},t.prototype.release=function(e){delete t.intersections[e.name()]},t.prototype.nothing=function(e,t){return void 0===t&&(t="Conflicting restrictions"),new ie(M,t,e)},t.prototype.composeWith=function(e){return null},t.prototype.preoptimize=function(){null===M&&(M=new re(null,null,"top")),M=M.push(this);try{return this.innerOptimize()}finally{M=M.pop()}},t.prototype.innerOptimize=function(){return this},t.prototype.tryCompose=function(e){null===M&&(M=new re(null,null,"top")),M=M.push(this);try{return this.composeWith(e)}finally{M=M.pop()}},t.prototype.kind=function(){return E.MetaInformationKind.Constraint},t.prototype.conflictMessage=function(e,t){return null},t.intersections={},t}(_);t.Constraint=w;var R=n(102),I=n(103),C=n(101),L=n(102),P=n(103),O=n(103),D=n(102),x=n(102),U=n(141),k=n(103),F=n(102);t.autoCloseFlag=!1;var B=function(){function e(e){void 0===e&&(e=null),this._parent=e,this._types={},this.typeList=[]}return e.prototype.put=function(e,t){this._types[e]=t},e.prototype.addType=function(e){e.isAnonymous()||(this._types[e.name()]=e,this.typeList.push(e))},e.prototype.get=function(e){return this._types.hasOwnProperty(e)?this._types[e]:null!=this._parent?this._parent.get(e):null},e.prototype.types=function(){return this.typeList},e.prototype.typeMap=function(){return this._types},e.prototype.parent=function(){return this._parent},e}();t.TypeRegistry=B;var K=function(){function e(){}return e.prototype.getInfos=function(e){if(e.getExtra("PInfos"))return e.getExtra("PInfos");var t={};return e.meta().forEach(function(e){if(e instanceof R.HasProperty){var n=e.value();t[n]={name:n,type:null}}}),e.meta().forEach(function(e){if(e instanceof R.PropertyIs){var n=e.propertyName();t[n]&&(t[n].type=e.value())}}),e.putExtra("PInfos",t),t},e.prototype.validate=function(e,t){var n=this,r=this.getInfos(e),i=!1;return Object.keys(r).forEach(function(e){i=i||n.validateInfo(r[e],t)}),i},e.prototype.validateInfo=function(e,t){var n=this;if(t.some(function(t){return t==e}))return!0;if(e.type instanceof Z){var r=e.type,i=!0;return r.options().forEach(function(r){n.validate(r,[e].concat(t))||(i=!1)}),i}return e.type.isArray()?void 0:this.validate(e.type,[e].concat(t))},e.prototype.validateType=function(e){var t=this,n=this.getInfos(e),r=[];return Object.keys(n).forEach(function(e){t.validateInfo(n[e],[])&&r.push(e)}),r},e}(),V=function(e){function n(n,r,i){e.call(this,b.ERROR,t.messageRegistry.RESTRICTIONS_CONFLICT.code,null,i),this._conflicting=n,this._stack=r,this.source=i,this.computeMessage()}return A(n,e),n.prototype.computeMessage=function(){var e=null;if(null!=this._stack&&this._stack.getRestriction()instanceof R.MinMaxRestriction){var t=this._stack.getRestriction();e=this._conflicting.conflictMessage(t.facetPath(),t.value())}null==e&&(e=this._conflicting+" and "+(null!=this._stack?this._stack.getRestriction().toString():""));var n="";if(this.source instanceof W){for(var r=[],i=this._stack;i;){var a=i.getRestriction();if(a instanceof D.PropertyIs){var o={name:a.propId()};r.length>0&&(o.child=r[r.length-1]),r.push(o)}i=i.pop()}d(this,r.pop());var s=R.anotherRestrictionComponent();n=s?" between types '"+f(this.source)+"' and '"+f(s)+"'":" in type '"+f(this.source)+"'"}this.message="Restrictions conflict"+n+": "+e},n.prototype.getConflictDescription=function(){var e="";return e+="Restrictions coflict:\n",e+=this._stack.getRestriction()+" conflicts with "+this._conflicting+"\n",e+="at\n",e+=this._stack.pop()},n.prototype.getConflicting=function(){return this._conflicting},n.prototype.getStack=function(){return this._stack},n.prototype.toRestriction=function(){return new ie(this._stack,this.message,this._conflicting)},n}(b);t.RestrictionsConflict=V;var j=0;t.VALIDATED_TYPE=null;var W=function(){function e(e){this._name=e,this.metaInfo=[],this._subTypes=[],this.innerid=j++,this.extras={},this._locked=!1}return e.prototype.getExtra=function(e){return this.extras[e]},e.prototype.putExtra=function(e,t){this.extras[e]=t},e.prototype.id=function(){return this.innerid},e.prototype.knownProperties=function(){return this.metaOfType(F.MatchesProperty)},e.prototype.lock=function(){this._locked=!0},e.prototype.isLocked=function(){return this._locked},e.prototype.allFacets=function(){return this.meta()},e.prototype.declaredFacets=function(){return this.declaredMeta()},e.prototype.isSubTypeOf=function(e){return e===t.ANY||this===e||this.superTypes().some(function(t){return t.isSubTypeOf(e)})},e.prototype.isSuperTypeOf=function(e){return this===e||-1!=this.allSubTypes().indexOf(e)},e.prototype.addMeta=function(e){this.metaInfo.push(e),e._owner=this},e.prototype.name=function(){return this._name},e.prototype.label=function(){return this._name},e.prototype.subTypes=function(){return this._subTypes},e.prototype.superTypes=function(){return[]},e.prototype.addSupertypeAnnotation=function(e,t){if(e&&0!=e.length){this.supertypeAnnotations||(this.supertypeAnnotations=[]);var n=this.supertypeAnnotations[t];n||(n={},this.supertypeAnnotations[t]=n);for(var r=0,i=e;r<i.length;r++){var a=i[r];n[a.facetName()]=a}}},e.prototype.validateType=function(e){var n=this;void 0===e&&(e=a());var r=new b(b.OK,"","",this);if(this.validateHierarchy(r),this.getExtra(E.PARSE_ERROR)&&r.addSubStatus(this.getExtra(E.PARSE_ERROR)),r.isOk()){if(r.addSubStatus(this.checkConfluent()),this.isExternal()){var o=this.allSuperTypes(),s=o.filter(function(e){return e instanceof de});this instanceof de&&s.push(this),s.forEach(function(e){if(e.isJSON())try{T.getJSONSchema(e.schema(),e.getContentProvider&&e.getContentProvider())}catch(t){if(t instanceof he){var a=t;r.addSubStatus(i(a.messageEntry,n,a.parameters))}else r.addSubStatus(new b(b.ERROR,"",t.message,n))}})}r.isOk()&&this.superTypes().forEach(function(t){if(t.isAnonymous()){var n=t.validateType(e);n.isOk()||(d(n,{name:"type"}),r.addSubStatus(n))}})}if(this.getExtra(t.SCHEMA_AND_TYPE)&&r.addSubStatus(i(t.messageRegistry.SCHEMA_AND_TYPE,this)),r.isOk()&&this.validateMeta(e).getErrors().forEach(function(e){return r.addSubStatus(e)}),this.isObject()){var u={};this.restrictions().forEach(function(e){e.owner()!=n&&e instanceof R.HasProperty&&(u[e.value()]=!0)}),this.declaredMeta().forEach(function(e){e instanceof R.HasProperty&&delete u[e.value()]}),this.declaredMeta().forEach(function(e){if(e instanceof R.PropertyIs){var a=e;u.hasOwnProperty(a.propertyName())&&r.addSubStatus(i(t.messageRegistry.REQUIRED_OVERRIDE_OPTIONAL,n,{propertyName:a.propertyName()}))}});var l=(new K).validateType(this);l.length>0&&l.forEach(function(e){var a=i(t.messageRegistry.CYCLIC_DEPENDENCY,n,{typeName:e});d(a,{name:e}),r.addSubStatus(a)})}if(this.supertypeAnnotations)for(var p=0;p<this.supertypeAnnotations.length;p++)for(var c=this.supertypeAnnotations[p],f=0,m=Object.keys(c);f<m.length;f++){var h=m[f],g=c[h],A=g.validateSelf(e);A.isOk()||(d(A,{name:"type",child:{name:p}}),r.addSubStatus(A))}for(var S=v(this,e),N=0,_=S;N<_.length;N++){var M=_[N];r.addSubStatus(M)}for(var w=new ge(this,e),I=y(w),C=0,L=I;C<L.length;C++){var M=L[C];r.addSubStatus(M)}return r},e.prototype.validateHierarchy=function(e){var n=this;if(this.isAnonymous()||this.getExtra(E.TOP_LEVEL_EXTRA)&&a().get(this.name())&&e.addSubStatus(i(t.messageRegistry.REDEFINIG_BUILDTIN,this,{typeName:this.name()})),this.isSubTypeOf(t.RECURRENT)&&e.addSubStatus(i(t.messageRegistry.RECURRENT_DEFINITION,this),"type"),this.isSubTypeOf(t.UNKNOWN)&&e.addSubStatus(i(t.messageRegistry.INHERITING_UNKNOWN_TYPE,this),"type"),this.isUnion()){var r=this.typeFamily();r.some(function(e){return e.isSubTypeOf(t.RECURRENT)})&&e.addSubStatus(i(t.messageRegistry.RECURRENT_UNION_OPTION,this),"type"),r.some(function(e){return e.isSubTypeOf(t.UNKNOWN)})&&e.addSubStatus(i(t.messageRegistry.UNKNOWN_UNION_OPTION,this),"type")}if(this.isArray()){var o=this.familyWithArray(),s=this.getExtra(E.HAS_ITEMS)?"items":"type";if(-1!=o.indexOf(this)||o.some(function(e){return e===t.RECURRENT}))e.addSubStatus(i(t.messageRegistry.RECURRENT_ARRAY_DEFINITION,this),s);else if(o.some(function(e){return e===t.UNKNOWN})){var u=this.oneMeta(x.ComponentShouldBeOfType).value().name();e.addSubStatus(i(t.messageRegistry.UNKNOWN_ARRAY_COMPONENT,this,{componentTypeName:u}),s)}}var l=this.superTypes(),p=!1,c=!1;if(l.length>1&&l.forEach(function(e){e.isExternal()?p=!0:c=!0}),p&&c&&e.addSubStatus(i(t.messageRegistry.EXTERNALS_MIX,this)),this instanceof Z){var f=this;f.options().forEach(function(r){r.isExternal()&&e.addSubStatus(i(t.messageRegistry.EXTERNALS_MIX,n))})}if(this.isExternal()&&this.getExtra(E.HAS_FACETS)){var m=i(t.messageRegistry.EXTERNAL_FACET,this,{name:this.getExtra(E.HAS_FACETS)});d(m,{name:this.getExtra(E.HAS_FACETS)}),e.addSubStatus(m)}},e.prototype.familyWithArray=function(){var e=this.allSuperTypes(),t=this.oneMeta(x.ComponentShouldBeOfType);if(t){var n=t.value();e=e.concat(n.familyWithArray())}return e},e.prototype.validateMeta=function(e){var t=new b(b.OK,"","",this);return this.declaredMeta().forEach(function(n){n.validateSelf(e).getErrors().forEach(function(e){return t.addSubStatus(e)})}),this.validateFacets(t),t},e.prototype.validateFacets=function(e){var n=this,r={},a={},o={};this.meta().forEach(function(e){if(e instanceof P.FacetDeclaration){var t=e;r[t.actualName()]=t,t.isOptional()||t.owner()!==n&&(o[t.actualName()]=t),t.owner()!=n&&(a[t.actualName()]=t)}}),this.declaredMeta().forEach(function(r){if(r instanceof P.FacetDeclaration){var o=r;if(o.owner()==n){var s=o.actualName();a.hasOwnProperty(s)&&e.addSubStatus(i(t.messageRegistry.OVERRIDE_FACET,n,{name:s}));var u=C.getInstance().facetPrototypeWithName(s);(u&&u.isApplicable(n)||"type"==s||"properties"==o.facetName()||"schema"==s||"facets"==s||"uses"==s)&&e.addSubStatus(i(t.messageRegistry.OVERRIDE_BUILTIN_FACET,n,{name:s})),"("==s.charAt(0)&&e.addSubStatus(i(t.messageRegistry.FACET_START_BRACKET,n,{name:s}))}}});var s={};this.meta().forEach(function(e){e instanceof D.PropertyIs&&(s[e.propId()]=!0)}),this.meta().forEach(function(a){if(a instanceof O.CustomFacet){var s=a;if(r.hasOwnProperty(s.facetName())){var u=r[s.facetName()].value();e.addSubStatus(u.validateDirect(s.value(),!1,!1)),delete o[s.facetName()]}else n.isExternal()?e.addSubStatus(i(t.messageRegistry.FACET_PROHIBITED_FOR_EXTERNALS,s,{facetName:s.facetName()},b.ERROR,!0)):e.addSubStatus(i(t.messageRegistry.UNKNOWN_FACET,s,{facetName:s.facetName()},b.ERROR,!0))}}),Object.getOwnPropertyNames(o).length>0&&e.addSubStatus(i(t.messageRegistry.MISSING_REQUIRED_FACETS,this,{facetsList:Object.keys(o).map(function(e){return"'"+e+"'"}).join(",")}))},e.prototype.allSuperTypes=function(){var e=[];return this.fillSuperTypes(e),e},e.prototype.fillSuperTypes=function(e){this.superTypes().forEach(function(t){S.contains(e,t)||(e.push(t),t.fillSuperTypes(e))})},e.prototype.allSubTypes=function(){var e=[];return this.fillSubTypes(e),e},e.prototype.fillSubTypes=function(e){this.subTypes().forEach(function(t){S.contains(e,t)||(e.push(t),t.fillSubTypes(e))})},e.prototype.inherit=function(e){var t=new J(e);return t.addSuper(this),t},e.prototype.isAnonymous=function(){return!this._name||0===this._name.length},e.prototype.isEmpty=function(){return this.metaInfo.length>2?!1:0==this.metaInfo.filter(function(e){return e instanceof k.NotScalar?!1:e instanceof I.DiscriminatorValue?e.isStrict():!0}).length},e.prototype.isArray=function(){return this===t.ARRAY||-1!=this.allSuperTypes().indexOf(t.ARRAY)},e.prototype.propertySet=function(){var e=[];return this.meta().forEach(function(t){if(t instanceof D.PropertyIs){var n=t;e.push(n.propertyName())}}),S.uniq(e)},e.prototype.checkConfluent=function(){if(this.computeConfluent)return r();this.computeConfluent=!0;var e=R.anotherRestrictionComponentsCount();try{var t=R.optimize(this.restrictions()),n=S.find(t,function(e){return e instanceof ne});if(n){var i=null,a=null;if(n instanceof ie){var o=n;i=o.getStack(),a=o.another()}var s=new V(a,i,this);return s}return r()}finally{this.computeConfluent=!1,R.releaseAnotherRestrictionComponent(e)}},e.prototype.isObject=function(){return this==t.OBJECT||-1!=this.allSuperTypes().indexOf(t.OBJECT)},e.prototype.isExternal=function(){return this==t.EXTERNAL||-1!=this.allSuperTypes().indexOf(t.EXTERNAL)},e.prototype.isBoolean=function(){return this==t.BOOLEAN||-1!=this.allSuperTypes().indexOf(t.BOOLEAN)},e.prototype.isString=function(){return this==t.STRING||-1!=this.allSuperTypes().indexOf(t.STRING)},e.prototype.isNumber=function(){return this==t.NUMBER||-1!=this.allSuperTypes().indexOf(t.NUMBER)},e.prototype.isFile=function(){return this==t.FILE||-1!=this.allSuperTypes().indexOf(t.FILE)},e.prototype.isScalar=function(){return this==t.SCALAR||-1!=this.allSuperTypes().indexOf(t.SCALAR)},e.prototype.isDateTime=function(){return this==t.DATETIME||-1!=this.allSuperTypes().indexOf(t.DATETIME)},e.prototype.isDateOnly=function(){return this==t.DATE_ONLY||-1!=this.allSuperTypes().indexOf(t.DATE_ONLY)},e.prototype.isTimeOnly=function(){return this==t.TIME_ONLY||-1!=this.allSuperTypes().indexOf(t.TIME_ONLY)},e.prototype.isInteger=function(){return this==t.INTEGER||-1!=this.allSuperTypes().indexOf(t.INTEGER)},e.prototype.isDateTimeOnly=function(){return this==t.DATETIME_ONLY||-1!=this.allSuperTypes().indexOf(t.DATETIME_ONLY)},e.prototype.isUnknown=function(){return this==t.UNKNOWN||-1!=this.allSuperTypes().indexOf(t.UNKNOWN)},e.prototype.isRecurrent=function(){return this==t.RECURRENT||-1!=this.allSuperTypes().indexOf(t.RECURRENT)},e.prototype.isBuiltin=function(){return-1!=this.metaInfo.indexOf(X)},e.prototype.exampleObject=function(){return U.example(this)},e.prototype.isPolymorphic=function(){return this.meta().some(function(e){return e instanceof Y})},e.prototype.restrictions=function(e){if(void 0===e&&(e=!1),this.isUnion()){var t=[];return this.superTypes().forEach(function(e){t=t.concat(e.restrictions())}),t=t.concat(this.meta().filter(function(e){return e instanceof w}))}var n=[],r=null;return this.meta().forEach(function(t){if(t instanceof w){if(t instanceof ae&&e){if(r)return;r=t}n.push(t)}}),n},e.prototype.customFacets=function(){return this.declaredMeta().filter(function(e){return e instanceof I.CustomFacet})},e.prototype.allCustomFacets=function(){return this.meta().filter(function(e){return e instanceof I.CustomFacet})},e.prototype.isUnion=function(){var e=!1;return this.isBuiltin()?!1:(this.allSuperTypes().forEach(function(t){return e=e||t instanceof Z}),e)},e.prototype.meta=function(){return[].concat(this.metaInfo)},e.prototype.validateDirect=function(e,n,r,a){var o=this;void 0===n&&(n=!1),void 0===r&&(r=!0),void 0===a&&(a=null);var s=t.VALIDATED_TYPE;try{var u=t.autoCloseFlag;n&&(t.autoCloseFlag=!0),t.VALIDATED_TYPE=this;var l=new b(b.OK,"","",this);if(!(r||null!==e&&void 0!==e||this.nullable))return i(t.messageRegistry.OBJECT_EXPECTED,this);if(this.restrictions(!0).forEach(function(t){return l.addSubStatus(t.check(e,a))}),(n||t.autoCloseFlag)&&this.isObject()&&!this.oneMeta(L.KnownPropertyRestriction)){var p=new L.KnownPropertyRestriction(!1);p.patchOwner(this),p.check(e).getErrors().forEach(function(e){var t=new b(b.WARNING,e.getCode(),e.getMessage(),o);d(t,e.getValidationPath()),l.addSubStatus(t)})}}finally{t.autoCloseFlag=u,t.VALIDATED_TYPE=s}return l},e.prototype.validate=function(e,n,a){void 0===n&&(n=!1),void 0===a&&(a=!0);var o=t.autoCloseFlag;if(!(a||null!==e&&void 0!==e||this.nullable))return i(t.messageRegistry.NULL_NOT_ALLOWED,this);n&&(t.autoCloseFlag=!0);try{for(var s,u=[],l=this.subTypes().concat(this),p=0,c=l;p<c.length;p++){var f=c[p],d=m(e,f),h=f.validateDirect(e,n||o);if(d){if(d.isOk())return h;u.push(d)}else if(h.isOk())return h;s=h}if(0==u.length)return s;var y=r();return u.forEach(function(e){return y.addSubStatus(e)}),u.pop()}finally{t.autoCloseFlag=o}},e.prototype.declareMapProperty=function(e,t){return null!=t&&this.addMeta(new R.MapPropertyIs(e,t)),t},e.prototype.closeUnknownProperties=function(){this.addMeta(new L.KnownPropertyRestriction(!1))},e.prototype.canDoAc=function(){for(var e=S.uniq(this.typeFamily()),t=new b(b.OK,"","",this),n=0;n<e.length;n++)for(var r=0;r<e.length;r++)if(n!=r){var i=e[n],a=e[r],o=this.emptyIntersectionOrDiscriminator(i,a);t.addSubStatus(o)}return t},e.prototype.emptyIntersectionOrDiscriminator=function(e,t){if(t===e)return r();if(t.isScalar()&&e.isScalar())return r();var n=s("",[e,t]),i=n.checkConfluent();return i.isOk()?this.checkDiscriminator(e,t):r()},e.prototype.checkDiscriminator=function(e,n){var a=i(t.messageRegistry.DISCRIMINATOR_NEEDED,this,{name1:e.name(),name2:n.name()}),o=e.oneMeta(I.Discriminator),s=n.oneMeta(I.Discriminator);if(null!=o&&null!=s&&o.value()===s.value()){var u=e.name(),l=n.name(),p=e.oneMeta(I.DiscriminatorValue);null!=p&&(u=p.value());var c=n.oneMeta(I.DiscriminatorValue);if(null!=c&&(l=c.value()),u!==l)return r();a=i(t.messageRegistry.SAME_DISCRIMINATOR_VALUE,this,{name1:e.name(),name2:n.name()})}return a},e.prototype.ac=function(e){if(!this.isPolymorphic()&&!this.isUnion())return this;if(this.isBuiltin())return this;var n=S.uniq(this.typeFamily());if(0==n.length)return t.NOTHING;if(this.isScalar())return this.isNumber()?"number"==typeof e?this:t.NOTHING:this.isString()?"string"==typeof e?this:t.NOTHING:this.isBoolean()?"boolean"==typeof e?this:t.NOTHING:this;if(1===n.length)return n[0];var r=[];n.forEach(function(t){var n=t.validateDirect(e,!0);n.isOk()&&r.push(t)});var i=this.discriminate(e,r);return i?i:t.NOTHING},e.prototype.declareProperty=function(e,t,n){return n||this.addMeta(new R.HasProperty(e)),null!=t&&this.addMeta(new R.PropertyIs(e,t)),this},e.prototype.discriminate=function(e,t){for(var n=[].concat(t),r=[].concat(t);n.length>1;){var i=!1;e:for(var a=0;a<r.length;a++)for(var o=0;o<r.length;o++){var s=r[a],u=r[o];if(s!=u){var l=p(e,s,u);if(l===s){r=r.filter(function(e){return e!=u}),i=!0;break e}if(l===u){r=r.filter(function(e){return e!=s}),i=!0;break e}r=r.filter(function(e){return e!=s&&e!=u}),i=!0;break e}}n=r}return 1==n.length?n[0]:null},e.prototype.oneMeta=function(e){return S.find(this.meta(),function(t){return t instanceof e})},e.prototype.metaOfType=function(e){return this.meta().filter(function(t){return t instanceof e})},e.prototype.declaredMeta=function(){return this.metaInfo},e.prototype.descValue=function(){var e=this.oneMeta(I.DiscriminatorValue);return e?e.value():this.name()},e.prototype.isAbstractOrInternal=function(){return this.metaInfo.some(function(e){return e instanceof H||e instanceof $})},e.prototype.typeFamily=function(){if(this.isUnion()){var e=[];return this.allSuperTypes().forEach(function(t){if(t instanceof Z)for(var n=t.allOptions(),r=0;r<n.length;r++)e=e.concat(n[r].typeFamily())}),S.unique(e)}var t=[];return this.isAbstractOrInternal()||t.push(this),this.allSubTypes().forEach(function(e){e.isAbstractOrInternal()||t.push(e)}),S.unique(t)},e.prototype.hasPropertiesFacet=function(){return this.metaInfo.some(function(e){return e instanceof I.HasPropertiesFacet})},e}();t.AbstractType=W;var q=function(e){function n(){e.apply(this,arguments)}return A(n,e),n.prototype.requiredType=function(){return t.ANY},n.prototype.kind=function(){return E.MetaInformationKind.Modifier},n}(_);t.Modifier=q;var Y=function(e){function t(){e.call(this,!0)}return A(t,e),t.prototype.facetName=function(){return"polymorphic"},t.prototype.value=function(){return!0},t}(q);t.Polymorphic=Y;var H=function(e){function t(){e.call(this,!1)}return A(t,e),t.prototype.value=function(){return!0},t.prototype.facetName=function(){return"abstract"},t}(q);t.Abstract=H;var $=function(e){function t(){e.call(this,!1)}return A(t,e),t.prototype.facetName=function(){return"abstract"},t.prototype.value=function(){return!0},t}(q);t.Internal=$;var G=function(e){function t(){e.call(this,!1)}return A(t,e),t.prototype.facetName=function(){return"builtIn"},t.prototype.value=function(){return!0},t}(q),X=new G,z=function(e){function t(){e.apply(this,arguments)}return A(t,e),t.prototype.kind=function(){return"root"},t}(W);t.RootType=z;var J=function(e){function t(){e.apply(this,arguments),this._superTypes=[]}return A(t,e),t.prototype.superTypes=function(){return this._superTypes},t.prototype.knownProperties=function(){var e=this.metaOfType(F.MatchesProperty);return this.superTypes().forEach(function(t){e=e.concat(t.knownProperties())}),e},t.prototype.kind=function(){return"inherited"},t.prototype.meta=function(){var t=this,n=e.prototype.meta.call(this),r=!1;return this.superTypes().forEach(function(e){e.meta().forEach(function(e){if(e instanceof L.KnownPropertyRestriction){if(r)return;var i=new L.KnownPropertyRestriction(!1);return i.patchOwner(t),void n.push(i)}e.isInheritable()&&n.push(e)})}),n},t.prototype.addSuper=function(e){this._superTypes.push(e),e.isLocked()||e._subTypes.push(this),e.nullable&&(this.nullable=!0)},t.prototype.label=function(){var t=this.metaOfType(x.ComponentShouldBeOfType);return t.length>0?t[0].value().label()+"[]":e.prototype.label.call(this)},t.prototype.contextMeta=function(){return this._contextMeta},t.prototype.setContextMeta=function(e){this._contextMeta=e},t.prototype.patch=function(e){for(var t in e)e.hasOwnProperty(t)&&(this[t]=e[t])},t}(W);t.InheritedType=J;var Q=function(e){function t(t,n){e.call(this,t),this._options=n}return A(t,e),t.prototype.allOptions=function(){var e=this,t=[];return this._options.forEach(function(n){n.kind()==e.kind()?t=t.concat(n.allOptions()):t.push(n)}),S.unique(t)},t.prototype.options=function(){return this._options},t}(W);t.DerivedType=Q;var Z=function(e){function n(t,n){var r=this;e.call(this,t,n),this.options().forEach(function(e){e.nullable&&(r.nullable=!0)})}return A(n,e),n.prototype.kind=function(){return"union"},n.prototype.isSubTypeOf=function(e){var t=!0;return this.allOptions().forEach(function(n){n.isSubTypeOf(e)||(t=!1)}),t},n.prototype.validate=function(e){return this.validateDirect(e)},n.prototype.typeFamily=function(){var e=[];return this.allOptions().forEach(function(t){e=e.concat(t.typeFamily())}),e},n.prototype.knownProperties=function(){var e=this.metaOfType(F.MatchesProperty);return this.options().forEach(function(t){e=e.concat(t.knownProperties())}),e},n.prototype.validateDirect=function(e,t){void 0===t&&(t=!1);var n=new b(b.OK,"","",this);return this.restrictions().forEach(function(t){return n.addSubStatus(t.check(e,null))}),n},n.prototype.isUnion=function(){return!0},n.prototype.restrictions=function(){return[new pe(this.allOptions().map(function(e){return new ce(e.restrictions())}),t.messageRegistry.UNION_TYPE_FAILURE,t.messageRegistry.UNION_TYPE_FAILURE_DETAILS)]},n.prototype.label=function(){return this.options().map(function(e){return e.label()}).join("|")},n}(Q);t.UnionType=Z;var ee=function(e){function t(){e.apply(this,arguments)}return A(t,e),t.prototype.kind=function(){return"intersection"},t.prototype.restrictions=function(){var e=[];return this.allOptions().forEach(function(t){return e=e.concat(t.restrictions())}),[new ce(e)]},t.prototype.label=function(){return this.options().map(function(e){return e.label()}).join("&")},t}(Q);t.IntersectionType=ee;var te=new B;t.builtInRegistry=a,t.union=o,t.intersect=s,t.derive=u,t.deriveObjectType=l;var ne=function(e){function n(){e.apply(this,arguments)}return A(n,e),n.prototype.check=function(e){return null===e||void 0===e?r():i(t.messageRegistry.NOTHING,this)},n.prototype.requiredType=function(){return t.ANY},n.prototype.facetName=function(){return"nothing"},n.prototype.value=function(){return"!!!"},n}(w);t.NothingRestriction=ne;var re=function(){function e(e,t,n){this._previous=e,this._restriction=t,this.id=n}return e.prototype.getRestriction=function(){return this._restriction},e.prototype.pop=function(){return this._previous},e.prototype.push=function(t){return new e(this,t,t.toString())},e}();t.RestrictionStackEntry=re;var ie=function(e){function t(t,n,r){e.call(this),this._entry=t,this._message=n,this._another=r}return A(t,e),t.prototype.getMessage=function(){return this._message},t.prototype.getStack=function(){return this._entry},t.prototype.another=function(){return this._another},t}(ne);t.NothingRestrictionWithLocation=ie;var ae=function(e){function t(){e.apply(this,arguments)}return A(t,e),t}(w);t.GenericTypeOf=ae;var oe=function(e){function n(t){e.call(this),this.val=t}return A(n,e),n.prototype.check=function(e){var n=typeof e;return null===e||void 0===e?r():(Array.isArray(e)&&(n="array"),n===this.val?r():i(t.messageRegistry.TYPE_EXPECTED,this,{typeName:this.val}))},n.prototype.value=function(){return this.val},n.prototype.requiredType=function(){return t.ANY},n.prototype.facetName=function(){return"typeOf"},n.prototype.composeWith=function(e){if(e instanceof n){var t=e;return t.val==this.val?this:this.nothing(e)}return null},n.prototype.toString=function(){return"should be of type "+this.val},n}(ae);t.TypeOfRestriction=oe;var se=function(e){function n(){e.call(this)}return A(n,e),n.prototype.check=function(e){return"number"==typeof e&&c(e)?r():i(t.messageRegistry.INTEGER_EXPECTED,this)},n.prototype.requiredType=function(){return t.ANY},n.prototype.value=function(){return!0},n.prototype.facetName=function(){return"should be integer"},n}(ae);t.IntegerRestriction=se;var ue=function(e){function n(){e.call(this)}return A(n,e),n.prototype.check=function(e){return null===e||void 0==e||"null"===e?r():i(t.messageRegistry.NULL_EXPECTED,this)},n.prototype.requiredType=function(){return t.ANY},n.prototype.value=function(){return!0},n.prototype.facetName=function(){return"should be null"},n}(ae);t.NullRestriction=ue;var le=function(e){function n(){e.call(this)}return A(n,e),n.prototype.check=function(e){return e?"number"==typeof e||"boolean"==typeof e||"string"==typeof e?r():i(t.messageRegistry.SCALAR_EXPECTED,this):r()},n.prototype.requiredType=function(){return t.ANY},n.prototype.facetName=function(){return"should be scalar"},n.prototype.value=function(){return!0},n}(ae);t.ScalarRestriction=le;var pe=function(e){function n(t,n,r){e.call(this),this.val=t,this._extraMessage=n,this._extraOptionMessage=r}return A(n,e),n.prototype.check=function(e,t){for(var n=this,a=new b(b.OK,"","",this),o=[],s=0;s<this.val.length;s++){var u=this.val[s].check(e,t);if(u.isOk())return r();o.push(u)}if(o.length>0){for(var l=0,p=o;l<p.length;l++){var c=p[l],f=null,m=c.getSource();if(m instanceof _){var d=m.owner();d&&(f=d.label())}c.getErrors().forEach(function(e){var t=e.getMessage(),r=e.getCode();if(f&&(t=f+": "+t),n._extraOptionMessage){var o=i(n._extraOptionMessage,n,{msg:t});t=o.getMessage(),r=o.getCode()}e.setMessage(t),e.setCode(r),a.addSubStatus(e)})}if(this._extraMessage){var h=0;o.forEach(function(e){return h=Math.max(h,e.getSeverity())}),a.addSubStatus(new b(h,this._extraMessage.code,this._extraMessage.message,this))}}return a},n.prototype.value=function(){return this.val.map(function(e){return e.value()})},n.prototype.requiredType=function(){return t.ANY},n.prototype.facetName=function(){return"or"},n}(w);t.OrRestriction=pe;var ce=function(e){function n(t){e.call(this),this.val=t}return A(n,e),n.prototype.value=function(){return this.val.map(function(e){return e.value()})},n.prototype.options=function(){return this.val},n.prototype.check=function(e,t){for(var n=0;n<this.val.length;n++){var i=this.val[n].check(e,t);if(!i.isOk())return i}return r()},n.prototype.requiredType=function(){return t.ANY},n.prototype.facetName=function(){return"and"},n}(w);t.AndRestriction=ce,t.ANY=new z("any"),t.SCALAR=t.ANY.inherit("scalar"),t.OBJECT=t.ANY.inherit("object"),t.ARRAY=t.ANY.inherit("array"),t.NIL=t.ANY.inherit("nil"),t.EXTERNAL=t.ANY.inherit("external"),t.NUMBER=t.SCALAR.inherit("number"),t.INTEGER=t.NUMBER.inherit("integer"),t.BOOLEAN=t.SCALAR.inherit("boolean"),t.STRING=t.SCALAR.inherit("string"),t.DATE_ONLY=t.SCALAR.inherit("date-only"),t.TIME_ONLY=t.SCALAR.inherit("time-only"),t.DATETIME_ONLY=t.SCALAR.inherit("datetime-only"),t.DATETIME=t.SCALAR.inherit("datetime"),t.FILE=t.SCALAR.inherit("file"),t.NOTHING=new z("nothing"),t.UNION=t.ANY.inherit("union"),t.UNKNOWN=t.NOTHING.inherit("unknown"),t.REFERENCE=t.NOTHING.inherit("reference"),t.RECURRENT=t.NOTHING.inherit("recurrent"),t.ANY.addMeta(X),t.NIL.addMeta(X),
t.UNION.addMeta(X),t.SCALAR.addMeta(X),t.OBJECT.addMeta(X),t.ARRAY.addMeta(X),t.NUMBER.addMeta(X),t.INTEGER.addMeta(X),t.BOOLEAN.addMeta(X),t.STRING.addMeta(X),t.EXTERNAL.addMeta(X),t.UNKNOWN.addMeta(X),t.RECURRENT.addMeta(X),t.DATE_ONLY.addMeta(X),t.TIME_ONLY.addMeta(X),t.DATETIME_ONLY.addMeta(X),t.DATETIME.addMeta(X),t.FILE.addMeta(X),t.UNKNOWN.addMeta(X),t.UNKNOWN.lock(),t.RECURRENT.addMeta(X),t.RECURRENT.lock(),t.EXTERNAL.lock(),t.UNION.lock(),t.REFERENCE.lock(),te.addType(t.ANY),te.addType(t.SCALAR),te.addType(t.OBJECT),te.addType(t.ARRAY),te.addType(t.NUMBER),te.addType(t.INTEGER),te.addType(t.BOOLEAN),te.addType(t.NIL),te.addType(t.STRING),te.addType(t.DATE_ONLY),te.addType(t.TIME_ONLY),te.addType(t.DATETIME_ONLY),te.addType(t.DATETIME),te.addType(t.FILE),t.NOTHING.addMeta(new ne),t.NUMBER.addMeta(new oe("number")),t.NUMBER.addMeta(new P.FacetDeclaration("format",t.STRING,!0)),t.BOOLEAN.addMeta(new oe("boolean")),t.OBJECT.addMeta(new oe("object")),t.ARRAY.addMeta(new oe("array")),t.STRING.addMeta(new oe("string")),t.INTEGER.addMeta(new se),t.NIL.addMeta(new ue);var fe=n(142);t.DATE_ONLY.addMeta(new fe.DateOnlyR),t.TIME_ONLY.addMeta(new fe.TimeOnlyR),t.DATETIME_ONLY.addMeta(new fe.DateTimeOnlyR),t.DATETIME.addMeta(new fe.DateTimeR),t.FILE.addMeta(new oe("string"));var me=t.ARRAY.inherit("");me.addMeta(new x.ComponentShouldBeOfType(t.STRING)),t.FILE.addMeta(new P.FacetDeclaration("fileTypes",me,!0)),t.FILE.addMeta(new P.FacetDeclaration("minLength",t.INTEGER,!0)),t.FILE.addMeta(new P.FacetDeclaration("maxLength",t.INTEGER,!0)),t.DATETIME.addMeta(new P.FacetDeclaration("format",t.STRING,!0)),t.NIL.nullable=!0,t.SCALAR.addMeta(new le),te.types().forEach(function(e){return e.lock()});var de=function(e){function n(n,r,i,a,o){void 0===o&&(o=null),e.call(this,n),this._content=r,this.json=i,this.provider=a,this.addMeta(new R.MatchToSchema(r,o?o:a)),this.addSuper(t.EXTERNAL)}return A(n,e),n.prototype.getContentProvider=function(){return this.provider},n.prototype.setContentProvider=function(e){this.provider=e},n.prototype.kind=function(){return"external"},n.prototype.isJSON=function(){return this.json},n.prototype.schema=function(){return this._content},n}(J);t.ExternalType=de,t.typePath=f;var he=function(e){function t(t,n){void 0===n&&(n={}),e.call(this),this.messageEntry=t,this.parameters=n,this.message=N(t,n)}return A(t,e),t}(Error);t.ValidationError=he,t.setValidationPath=d,t.patchPath=h;var ye=function(){function e(e,t){this._facet=e,this.reg=t}return e.prototype.kind=function(){return"AnnotatedFacet"},e.prototype.annotationsMap=function(){var e=this;return this._annotationsMap||(this._annotationsMap={},this.annotations().forEach(function(t){return e._annotationsMap[t.name()]=t})),this._annotationsMap},e.prototype.annotations=function(){var e=this;return this._annotations||(this._annotations=this._facet.annotations().map(function(t){return new Ae(t,e.reg)})),this._annotations},e.prototype.value=function(){return this._facet.value()},e.prototype.name=function(){return this._facet.facetName()},e.prototype.entry=function(){return this._facet},e}();t.AnnotatedFacet=ye;var ve=n(100),ge=function(){function e(e,t){this._type=e,this.reg=t}return e.prototype.kind=function(){return"AnnotatedType"},e.prototype.annotationsMap=function(){var e=this;return this._annotationsMap||(this._annotationsMap={},this.annotations().forEach(function(t){var n=t.name(),r=n.lastIndexOf(".");r>=0&&(n=n.substring(r+1)),e._annotationsMap[n]=t})),this._annotationsMap},e.prototype.annotations=function(){var e=this;return this._annotations||(this._annotations=this._type.meta().filter(function(e){return e.kind()==E.MetaInformationKind.Annotation}).map(function(t){return new Ae(t,e.reg)})),this._annotations},e.prototype.value=function(){return ve.storeAsJSON(this._type)},e.prototype.name=function(){return this._type.name()},e.prototype.entry=function(){return this._type},e}();t.AnnotatedType=ge;var Ae=function(){function e(e,t){this.actual=e}return e.prototype.name=function(){return this.actual.facetName()},e.prototype.value=function(){return this.actual.value()},e.prototype.definition=function(){var e=te.get(this.actual.facetName());return e},e.prototype.annotation=function(){return this.actual},e}();t.AnnotationInstance=Ae,t.applyAnnotationValidationPlugins=y,t.applyTypeValidationPlugins=v},function(e,t,n){(function(e){"use strict";function n(){var t=e.ramlValidation;if(t){var n=t.typeValidators;if(Array.isArray(n))return n}return[]}function r(){var t=e.ramlValidation;if(t){var n=t.typesystemAnnotationValidators;if(Array.isArray(n))return n}return[]}t.REPEAT="repeat",t.PARSE_ERROR="parseError",t.TOP_LEVEL_EXTRA="topLevel",t.DEFINED_IN_TYPES_EXTRA="definedInTypes",t.USER_DEFINED_EXTRA="USER_DEFINED",t.SOURCE_EXTRA="SOURCE",t.SCHEMA_AND_TYPE_EXTRA="SCHEMA",t.GLOBAL_EXTRA="GLOBAL",t.HAS_FACETS="HAS_FACETS",t.HAS_ITEMS="HAS_ITEMS",function(e){e[e.Description=0]="Description",e[e.NotScalar=1]="NotScalar",e[e.DisplayName=2]="DisplayName",e[e.Usage=3]="Usage",e[e.Annotation=4]="Annotation",e[e.FacetDeclaration=5]="FacetDeclaration",e[e.CustomFacet=6]="CustomFacet",e[e.Example=7]="Example",e[e.Required=8]="Required",e[e.HasPropertiesFacet=9]="HasPropertiesFacet",e[e.AllowedTargets=10]="AllowedTargets",e[e.Examples=11]="Examples",e[e.XMLInfo=12]="XMLInfo",e[e.Default=13]="Default",e[e.Constraint=14]="Constraint",e[e.Modifier=15]="Modifier",e[e.Discriminator=16]="Discriminator",e[e.DiscriminatorValue=17]="DiscriminatorValue"}(t.MetaInformationKind||(t.MetaInformationKind={}));t.MetaInformationKind;t.getTypeValidationPlugins=n,t.getAnnotationValidationPlugins=r}).call(t,function(){return this}())},function(e,t,n){"use strict";function r(e,t,n,r){return void 0===n&&(n=S.builtInRegistry()),v(e,new O(null,t,!1,r),n)}function i(e,t,n){return void 0===t&&(t=S.builtInRegistry()),u(new O(null,e,!1,n),t)}function a(e){return"?"==e.charAt(e.length-1)}function o(e,t){void 0===t&&(t=S.builtInRegistry());var n=e.provider&&e.provider();return u(new O(null,e,!1,n),t)}function s(e){return new k(e)}function u(e,t){var n=new x;if(e.anchor){if(e.anchor().__$$)return e.anchor().__$$;e.anchor().__$$=n}var r=e.childWithKey("types");r&&r.kind()===P.ARRAY&&(r=s(r));var i=e.childWithKey("schemas");i&&i.kind()===P.ARRAY&&(i=s(i));var a=new U(r,i,t,n);r&&r.kind()!==P.SCALAR&&r.children().filter(function(e){return e.key()&&!0}).forEach(function(e){var t=S.derive(e.key(),[S.REFERENCE]);n.add(t),a.addType(t)}),i&&i.kind()!==P.SCALAR&&i.children().filter(function(e){return e.key()&&!0}).forEach(function(e){var t=S.derive(e.key(),[S.REFERENCE]);n.add(t),a.addType(t)});var o=e.childWithKey("uses");o&&o.kind()===P.ARRAY&&(o=s(o)),o&&o.kind()===P.MAP&&o.children().forEach(function(e){n.addLibrary(e.key(),u(e,t))}),r&&r.kind()!==P.SCALAR&&r.children().filter(function(e){return e.key()&&!0}).forEach(function(e){a.get(e.key())}),i&&i.kind()!==P.SCALAR&&i.children().filter(function(e){return e.key()&&!0}).forEach(function(e){a.get(e.key())}),a.types().forEach(function(e){return n.add(e)});var r=e.childWithKey("annotationTypes");return r&&r.kind()===P.ARRAY&&(r=s(r)),null!=r&&r.kind()===P.MAP&&r.children().forEach(function(e){n.addAnnotationType(v(e.key(),e,a,!1,!0,!1))}),n}function l(e,t){var n=new D,r=!1,i=e.childWithKey("required");if(i){var o=i.value();"boolean"==typeof o&&(r=!0),o===!1&&(n.optional=!0,n.id=e.key())}var s=e.key();return!r&&a(e.key())&&(s=s.substr(0,s.length-1),n.optional=!0),0==s.length||"/.*/"===s?n.additonal=!0:"/"==s.charAt(0)&&"/"==s.charAt(s.length-1)&&(s=s.substring(1,s.length-1),n.regExp=!0),n.type=v(null,e,t,!1,!1,!1),n.id=s,n}function p(e){var t=new F;t.name=e.name(),t.superTypes=e.superTypes().map(function(e){return m(e)}),t.annotations=[],t.customFacets=[],t.facetDeclarations=[],t.basicFacets=[],t.properties=[];var n={};return e.declaredMeta().forEach(function(e){if(e instanceof w.Annotation)t.annotations.push(e);else if(e instanceof w.CustomFacet)t.customFacets.push(e);else if(e instanceof w.NotScalar)t.notAScalar=!0;else if(e instanceof R.FacetDeclaration)t.facetDeclarations.push(e);else if(e instanceof b.HasProperty)if(n.hasOwnProperty(e.value()))n[e.value()].optional=!1;else{var r=new D;r.optional=!1,r.id=e.value(),r.type=S.ANY,n[e.value()]=r}else if(e instanceof b.AdditionalPropertyIs){var r=new D;r.optional=!1,r.id="/.*/",r.additonal=!0,r.type=e.value(),n["/.*/"]=r}else if(e instanceof b.MapPropertyIs){var r=new D;r.optional=!1,r.id=e.regexpValue(),r.regExp=!0,r.type=e.value(),n[e.regexpValue()]=r}else if(e instanceof b.PropertyIs)if(n.hasOwnProperty(e.propertyName()))n[e.propertyName()].type=e.value();else{var r=new D;r.optional=!0,r.id=e.propertyName(),r.type=e.value(),n[e.propertyName()]=r}else e instanceof b.KnownPropertyRestriction?t.additionalProperties=e.value():e instanceof w.DiscriminatorValue?e.isStrict()&&t.basicFacets.push(e):e instanceof w.HasPropertiesFacet||t.basicFacets.push(e)}),Object.keys(n).forEach(function(e){return t.properties.push(n[e])}),t}function c(e){return e instanceof N.AbstractType?p(e).toJSON():f(e)}function f(e){var t={},n={};e.types().forEach(function(e){n[e.name()]=c(e)}),Object.keys(n).length>0&&(t.types=n);var n={};return e.annotationTypes().forEach(function(e){n[e.name()]=c(e)}),Object.keys(n).length>0&&(t.annotationTypes=n),t}function m(e){if(e.isAnonymous()){if(e.isArray()){var t=e.oneMeta(b.ComponentShouldBeOfType);if(t){var n=t.value();return n.isAnonymous()&&n.isUnion()?"("+m(n)+")[]":m(n)+"[]"}}return e.isUnion()?e.options().map(function(e){return m(e)}).join(" | "):e.superTypes().map(function(e){return m(e)}).join(" , ")}return e.name()}function d(e,t){if(t===S.ANY||e===t||e.superTypes().some(function(e){return d(e,t)}))return!0;if(e.isUnion()&&e.options){var n=e.options();if(n.some(function(e){return d(e,t)}))return!0}if(t.isUnion()&&t.options){var n=t.options();if(n.some(function(t){return e==t}))return!0}return!1}function h(e,t){var n=e.requiredType(),r=e.requiredTypes();return r&&r.length>0?r.some(function(e){return d(t,e)}):d(t,n)}function y(e,t){for(var n=t.children(),r=0,i=n;r<i.length;r++){var a=i[r],o=a.key();if(o&&"("==o.charAt(0)&&")"==o.charAt(o.length-1)){var s=o.substring(1,o.length-1),u=new w.Annotation(s,a.value());u.setOwnerFacet(e),e.addAnnotation(u)}}}function v(e,t,n,r,i,a,o){void 0===n&&(n=S.builtInRegistry()),void 0===r&&(r=!1),void 0===i&&(i=!1),void 0===a&&(a=!0),void 0===o&&(o=!1);var p=t.childWithKey("uses");if(p&&(p.kind()===P.ARRAY&&(p=s(p)),p.kind()===P.MAP)){var c=new x;p.children().forEach(function(e){c.addLibrary(e.key(),u(e,S.builtInRegistry()))}),n=new U(null,null,n,c)}var f=t.contentProvider?t.contentProvider():null;if(t.kind()==P.SCALAR){var m,d=t.value();if(m=null==d||"Null"==d||"NULL"==d?S.STRING:_.parseToType(""+d,n,f),null==e)return m;var A=S.derive(e,[m]);return n instanceof U&&(A=g(A,n)),A}if(t.kind()==P.ARRAY){var b=[];t.children().forEach(function(e){b.push(_.parseToType(""+e.value(),n,f))});var A=S.derive(e,b);return n instanceof U&&(A=g(A,n)),A}var N=[],R=t.childWithKey("type"),I=!1;R?t.childWithKey("schema")&&(I=!0):R=t.childWithKey("schema");var O=[];if(!R||o)N=r?t.childWithKey("properties")?[S.OBJECT]:[S.ANY]:t.childWithKey("properties")?[S.OBJECT]:[S.STRING];else{var D=[],k=R.childWithKey("value");if(!k||k.kind()!=P.SCALAR&&k.kind()!=P.ARRAY||(D=[R.children().filter(function(e){var t=e.key();return t?"("==t.charAt(0)&&")"==t.charAt(t.length-1):!1})],R=k),R.kind()==P.SCALAR){var d=R.value();if(null==d||"Null"==d||"NULL"==d)N=[S.STRING];else{var F=R.contentProvider?R.contentProvider():null;N=[_.parseToType(""+d,n,f,F)]}}else R.kind()==P.ARRAY?N=R.children().map(function(e){var t=e.childWithKey("value");return!t||t.kind()!=P.SCALAR&&t.kind()!=P.ARRAY?D.push([]):(D.push(e.children().filter(function(e){var t=e.key();return t?"("==t.charAt(0)&&")"==t.charAt(t.length-1):!1})),e=t),e.value()}).map(function(e){return _.parseToType(""+e,n,f)}):R.kind()==P.MAP&&(N=[v("",R,n,!1,!1,!1)]);if(D.length>0&&D.filter(function(e){return e.length>0}).length>0)for(var B=0,K=D;B<K.length;B++){var V=K[B],j=[];O.push(j);for(var W=0,q=V;W<q.length;W++){var Y=q[W],H=Y.key(),$=H.substring(1,H.length-1),G=new w.Annotation($,Y.value());j.push(G)}}}for(var X=S.derive(e,N),z=0;z<O.length;z++){var J=O[z];X.addSupertypeAnnotation(J,z)}n instanceof U&&(X=g(X,n));var Q=X,Z=null;if(t.children().forEach(function(e){var t=e.key();k=e.childWithKey("value");var r=e;if("example"!=t&&k&&(r=k),t&&"type"!==t&&"uses"!==t&&"schema"!==t&&("properties"!=t&&"additionalProperties"!=t||!X.isSubTypeOf(S.OBJECT))){var a;if("items"==t){if(X.isSubTypeOf(S.ARRAY)){var o=[];if(r.kind()==P.SCALAR){var s=r.value();o=null==s||"Null"==s||"NULL"==s?[S.STRING]:[_.parseToType(""+s,n,f)]}else r.kind()==P.ARRAY?o=r.children().map(function(e){var t=e.childWithKey("value");return!t||t.kind()!=P.SCALAR&&t.kind()!=P.ARRAY?D.push([]):(D.push(e.children().filter(function(e){var t=e.key();return t?"("==t.charAt(0)&&")"==t.charAt(t.length-1):!1})),e=t),e.value()}).map(function(e){return _.parseToType(""+e,n,f)}):r.kind()==P.MAP&&(o=[v("",r,n,!1,!1,!1)]);var u=1==o.length?o[0]:S.derive("",o);return a=new C.ComponentShouldBeOfType(u),Q.addMeta(a),Q.putExtra(E.HAS_ITEMS,!0),k&&y(a,e),a}}else{if("facets"===t)return void(Z=t);if("default"==t||"xml"==t||"required"==t)Z=t;else if("("==t.charAt(0)&&")"==t.charAt(t.length-1))return void X.addMeta(new w.Annotation(t.substr(1,t.length-2),r.value()));if(a=M.getInstance().buildFacet(t,r.value()),a&&("format"!=t||h(a,X)))a.setNode(r),X.addMeta(a);else if(i&&"allowedTargets"===t)X.addMeta(new w.AllowedTargets(r.value()));else{var l=new w.CustomFacet(t,r.value());l.setNode(r),X.addMeta(l)}}a&&y(a,e)}}),0==X.metaOfType(w.DiscriminatorValue).length&&X.addMeta(new w.DiscriminatorValue(X.name(),!1)),X.isSubTypeOf(S.OBJECT)){var ee=t.childWithKey("properties"),te=!1;if(ee)if(X.addMeta(new w.HasPropertiesFacet),ee.kind()==P.MAP)ee.children().forEach(function(e){te=!0,l(e,n).add(X)});else{var ne=S.error(T.PROPERTIES_MAP,Q);ne.setValidationPath({name:"properties"}),X.putExtra(E.PARSE_ERROR,ne)}var re=t.childWithKey("additionalProperties");if(re)if(k=re.childWithKey("value"),k&&(re=k),"boolean"==typeof re.value())X.addMeta(new L.KnownPropertyRestriction(re.value()));else{var ne=S.error(T.ADDITIONAL_PROPERTIES_BOOLEAN,Q);ne.setValidationPath({name:"additionalProperties"}),X.putExtra(E.PARSE_ERROR,ne)}}var ee=t.childWithKey("facets");if(ee)if(ee.kind()==P.MAP)ee.children().forEach(function(e){var t=l(e,n);X.addMeta(new w.FacetDeclaration(t.id,t.type,t.optional))});else{var ne=S.error(T.FACETS_MAP,Q);ne.setValidationPath({name:"facets"}),X.putExtra(E.PARSE_ERROR,ne)}return X.isAnonymous()&&X.isEmpty()&&1==X.superTypes().length?X.superTypes()[0]:(t.kind()!=P.SCALAR&&X.addMeta(new w.NotScalar),I&&Q.putExtra(S.SCHEMA_AND_TYPE,!0),Q.putExtra(S.GLOBAL,a),Q.putExtra(S.SOURCE_EXTRA,t),Q.putExtra(E.HAS_FACETS,Z),Q)}function g(e,t){for(var n,r=t;r&&!(n=r.typeMap()[e.name()]);)r=r.parent();return null!=n&&n.isSubTypeOf(S.REFERENCE)?null!=n&&n.isSubTypeOf(S.REFERENCE)&&(n.patch(e),e=n):t.addType(e),e.putExtra(E.TOP_LEVEL_EXTRA,!0),e}var A=this&&this.__extends||function(e,t){function n(){this.constructor=e}for(var r in t)t.hasOwnProperty(r)&&(e[r]=t[r]);e.prototype=null===t?Object.create(t):(n.prototype=t.prototype,new n)},S=n(98),T=S.messageRegistry,E=n(99),b=n(102),N=n(98),_=n(140),M=n(101),w=n(103),R=n(103),I=n(98),C=n(102),L=n(102);!function(e){e[e.SCALAR=0]="SCALAR",e[e.ARRAY=1]="ARRAY",e[e.MAP=2]="MAP"}(t.NodeKind||(t.NodeKind={}));var P=t.NodeKind,O=function(){function e(e,t,n,r){void 0===n&&(n=!1),this._key=e,this.obj=t,this.inArr=n,this.provider=r}return e.prototype.value=function(){return this.obj},e.prototype.key=function(){if(!this._key&&this.kind()===P.MAP&&this.inArr){var e=Object.keys(this.obj);if(1===e.length)return e[0]}return this._key},e.prototype.childWithKey=function(t){return null==this.obj?null:this.obj.hasOwnProperty(t)?new e(t,this.obj[t],!1,this.contentProvider()):null},e.prototype.children=function(){var t=this;return Array.isArray(this.obj)?this.obj.map(function(n){return new e(null,n,!0,t.contentProvider())}):this.obj&&"object"==typeof this.obj?Object.keys(this.obj).map(function(n){return new e(n,t.obj[n],!1,t.provider)}):[]},e.prototype.kind=function(){return this.obj?Array.isArray(this.obj)?P.ARRAY:"object"==typeof this.obj?P.MAP:P.SCALAR:P.SCALAR},e.prototype.contentProvider=function(){return this.provider},e}();t.parseJSON=r,t.parseJSONTypeCollection=i;var D=function(){function e(){}return e.prototype.add=function(e){this.optional||this.additonal||this.regExp||this.type.isSubTypeOf(S.NIL)||e.addMeta(new b.HasProperty(this.id));var t;t=this.additonal?new b.AdditionalPropertyIs(this.type):this.regExp?new b.MapPropertyIs(this.id,this.type):new b.PropertyIs(this.id,this.type,this.optional),null!=t&&(e.addMeta(t),this.type instanceof S.InheritedType&&null==this.type.name()&&this.type.setContextMeta(t))},e}();t.PropertyBean=D;var x=function(){function e(){this._types=[],this._typeMap={},this.uses={},this._annotationTypes=[],this._annotationTypeMap={}}return e.prototype.library=function(e){return this.uses[e]},e.prototype.addLibrary=function(e,t){this.uses[e]=t},e.prototype.add=function(e){this._types.push(e),this._typeMap[e.name()]=e},e.prototype.getType=function(e){return this._typeMap.hasOwnProperty(e)?this._typeMap[e]:null},e.prototype.addAnnotationType=function(e){this._annotationTypes.push(e),this._annotationTypeMap[e.name()]=e},e.prototype.getAnnotationType=function(e){return this._annotationTypeMap.hasOwnProperty(e)?this._annotationTypeMap[e]:null},e.prototype.types=function(){return this._types},e.prototype.annotationTypes=function(){return this._annotationTypes},e.prototype.getAnnotationTypeRegistry=function(){var e=this,t=new I.TypeRegistry(S.builtInRegistry());return this.annotationTypes().forEach(function(e){return t.addType(e)}),Object.keys(this.uses).forEach(function(n){e.uses[n].annotationTypes().forEach(function(e){return t.put(n+"."+e.name(),e)})}),t},e.prototype.getTypeRegistry=function(){var e=this,t=new I.TypeRegistry(S.builtInRegistry());return this.types().forEach(function(e){return t.addType(e)}),Object.keys(this.uses).forEach(function(n){e.uses[n].types().forEach(function(e){return t.put(n+"."+e.name(),e)})}),t},e}();t.TypeCollection=x;var U=function(e){function t(t,n,r,i){e.call(this,r),this.toParse=t,this.schemas=n,this._c=i,this.parsing={}}return A(t,e),t.prototype.get=function(t){var n=e.prototype.get.call(this,t);if(!n||n.isSubTypeOf(S.REFERENCE)){var r=this.toParse?this.toParse.childWithKey(t):null;if(r||(r=this.schemas?this.schemas.childWithKey(t):null),r){if(this.parsing[t]){var i=S.derive(t,[S.RECURRENT]);return n&&n.isSubTypeOf(S.REFERENCE)?n.patch(i):n=i,n}this.parsing[t]=!0;try{var a=v(t,r,this)}finally{delete this.parsing[t]}return a}var o=t.indexOf(".");if(-1!=o){var s=t.substring(0,o),u=t.substr(o+1),l=this._c.library(s);if(l){var p=l.getType(u);if(p)return p}}}return n},t}(S.TypeRegistry);t.AccumulatingRegistry=U,t.parseTypes=o;var k=function(){function e(e){this.n=e}return e.prototype.key=function(){return null},e.prototype.value=function(){return null},e.prototype.childWithKey=function(e){for(var t=this.children(),n=0;n<t.length;n++)if(t[n].key()==e)return t[n];return null},e.prototype.children=function(){return this.n.children().map(function(e){var t=e.children();return 1==t.length?t[0]:e})},e.prototype.kind=function(){return P.MAP},e}();t.parseTypeCollection=u,t.parsePropertyBean=l;var F=function(){function e(){}return e.prototype.toJSON=function(){var e={};if(this.superTypes&&this.superTypes.length>0&&(1==this.superTypes.length?e.type=this.superTypes[0]:e.type=this.superTypes),this.customFacets&&this.customFacets.forEach(function(t){return e[t.facetName()]=t.value()}),this.annotations&&this.annotations.forEach(function(t){return e["("+t.facetName()+")"]=t.value()}),this.facetDeclarations&&this.facetDeclarations.length>0){var t={};this.facetDeclarations.forEach(function(e){var n=e.facetName();e.isOptional()&&(n+="?");var r=null;r=e.type().isAnonymous()?e.type().isEmpty()?m(e.type()):p(e.type()).toJSON():m(e.type()),t[n]=r}),e.facets=t}if(this.properties&&this.properties.length>0){var n={};this.properties.forEach(function(e){var t=e.id;e.optional&&(t+="?"),e.additonal&&(t="/.*/"),e.regExp&&(t="/"+t+"/");var r=null;r=e.type.isAnonymous()?e.type.isEmpty()?m(e.type):p(e.type).toJSON():m(e.type),n[t]=r}),e.properties=n}return this.basicFacets&&this.basicFacets.forEach(function(t){e[t.facetName()]=t.value()}),1==Object.keys(e).length&&!this.notAScalar&&e.type?e.type:(void 0!==this.additionalProperties&&(e.additionalProperties=this.additionalProperties),e)},e}();t.TypeProto=F,t.toProto=p,t.storeAsJSON=c,t.parse=v},function(e,t,n){"use strict";function r(){return h?h:h=new d}var i=n(98),a=n(103),o=n(98),s=n(102),u=n(103),l=n(103),p=n(103),c=n(103),f=n(102),m=function(){function e(e,t){this._construct=e,this._constructWithValue=t}return e.prototype.isSimple=function(){return null!=this._constructWithValue},e.prototype.newInstance=function(){return this._construct()},e.prototype.createWithValue=function(e){return this._constructWithValue(e)},e.prototype.isApplicable=function(e){var t=this.newInstance(),n=t.requiredType(),r=t.requiredTypes();return r&&r.length>0?r.some(function(t){return e.isSubTypeOf(t)}):e.isSubTypeOf(n)},e.prototype.isInheritable=function(){return this.newInstance().isInheritable()},e.prototype.isConstraint=function(){return this.newInstance()instanceof i.Constraint},e.prototype.isMeta=function(){return!this.isConstraint()},e.prototype.name=function(){return this.newInstance().facetName()},e}();t.FacetPrototype=m;var d=function(){function e(){var e=this;this.constraints=[new m(function(){return new s.MinProperties(1)},function(e){return new s.MinProperties(e)}),new m(function(){return new s.MaxProperties(1)},function(e){return new s.MaxProperties(e)}),new m(function(){return new s.MinItems(1)},function(e){return new s.MinItems(e)}),new m(function(){return new s.MaxItems(1)},function(e){return new s.MaxItems(e)}),new m(function(){return new s.MinLength(1)},function(e){return new s.MinLength(e)}),new m(function(){return new s.MaxLength(1)},function(e){return new s.MaxLength(e)}),new m(function(){return new s.Minimum(1)},function(e){return new s.Minimum(e)}),new m(function(){return new f.MultipleOf(1)},function(e){return new f.MultipleOf(e)}),new m(function(){return new s.Maximum(1)},function(e){return new s.Maximum(e)}),new m(function(){return new s.Enum([""])},function(e){return new s.Enum(e)}),new m(function(){return new s.Pattern(".")},function(e){return new s.Pattern(e)}),new m(function(){return new s.Format("")},function(e){return new s.Format(e)}),new m(function(){return new s.PropertyIs("x",i.ANY)},null),new m(function(){return new s.AdditionalPropertyIs(i.ANY)},null),new m(function(){return new s.MapPropertyIs(".",i.ANY)},null),new m(function(){return new s.HasProperty("x")},null),new m(function(){return new s.UniqueItems(!0)},function(e){return new s.UniqueItems(e)}),new m(function(){return new s.ComponentShouldBeOfType(i.ANY)},null),new m(function(){return new s.KnownPropertyRestriction(!1)},function(e){return new s.KnownPropertyRestriction(e)})],this.meta=[new m(function(){return new a.Discriminator("kind")},function(e){return new a.Discriminator(e)}),new m(function(){return new a.DiscriminatorValue("x")},function(e){return new a.DiscriminatorValue(e)}),new m(function(){return new u.Default("")},function(e){return new u.Default(e)}),new m(function(){return new c.Usage("")},function(e){return new c.Usage(e)}),new m(function(){return new u.Example("")},function(e){return new u.Example(e)}),new m(function(){return new p.Required(!0)},function(e){return new p.Required(e)}),new m(function(){return new a.Examples({})},function(e){return new a.Examples(e)}),new m(function(){return new u.Description("")},function(e){return new u.Description(e)}),new m(function(){return new u.DisplayName("")},function(e){return new u.DisplayName(e)}),new m(function(){return new o.Abstract},function(e){return new o.Abstract}),new m(function(){return new o.Polymorphic},function(e){return new o.Polymorphic}),new m(function(){return new l.XMLInfo({})},function(e){return new l.XMLInfo(e)})],this.known={},this.allPrototypes().forEach(function(t){return e.known[t.name()]=t})}return e.prototype.allPrototypes=function(){return this.meta.concat(this.constraints)},e.prototype.buildFacet=function(e,t){return this.known.hasOwnProperty(e)&&this.known[e].isSimple()?this.known[e].createWithValue(t):null},e.prototype.facetPrototypeWithName=function(e){return this.known.hasOwnProperty(e)?this.known[e]:null},e.prototype.applyableTo=function(e){return this.allPrototypes().filter(function(t){return t.isApplicable(e)})},e.prototype.allMeta=function(){return this.allPrototypes().filter(function(e){return e.isMeta()})},e}();t.Registry=d;var h;t.getInstance=r},function(e,t,n){"use strict";function r(){return E.length>0?E[E.length-1]:null}function i(e){for(var t;e;)t=e.owner(),e=t instanceof c.InheritedType?t.contextMeta():null;E.push(t)}function a(e){for(void 0===e&&(e=0);E.length>e;)E.pop()}function o(){return E.length}function s(e){return parseFloat(e)!=parseInt(e)||isNaN(e)?!1:!0}function u(e){e=e.map(function(e){return e.preoptimize()});var t=[];e.forEach(function(e){if(e instanceof h.AndRestriction){var n=e;n.options().forEach(function(e){t.push(e)})}else t.push(e)});for(var n=!0;n;){n=!1;for(var r=0;r<t.length;r++){for(var i=0;i<t.length;i++){var a=t[r],o=t[i];if(a!==o){var s=a.tryCompose(o);if(s){var u=t.filter(function(e){return e!==a&&e!==o});u.push(s),n=!0,t=u;break}}}if(n)break}}return t}function l(e){if(!e.isSubTypeOf(c.UNKNOWN))return null;if(null!=e.name())return e;for(var t=0,n=e.superTypes();t<n.length;t++){var r=n[t],i=l(r);if(null!=i)return i}return e}var p=this&&this.__extends||function(e,t){function n(){this.constructor=e}for(var r in t)t.hasOwnProperty(r)&&(e[r]=t[r]);e.prototype=null===t?Object.create(t):(n.prototype=t.prototype,new n)},c=n(98),f=c.messageRegistry,m=n(108),d=n(187),h=n(98),y=n(98),v=function(e){function t(t){e.call(this),this._type=t}return p(t,e),t.prototype.matches=function(e){return!1},t.prototype.check=function(e,t){throw new Error("Should be never called")},t.prototype.patchPath=function(e){if(e){for(var t=e,n=null,r=null;t;)if(n){var i={name:t.name};r.child=i,t=t.child,r=i}else n={name:t.name},r=n;return n.child={name:this.propId()},n}return{name:this.propId()}},t.prototype.validateProp=function(e,t,n,r){var i=e[t],a=n.validate(i,!1,!1);if(!a.isOk()){if(n.isUnknown()||n.isRecurrent()){var o=c.error(f.VALIDATING_AGAINS_UNKNOWN,this,{typeName:n.name()});return c.setValidationPath(o,this.patchPath(r)),o}var o=new y.Status(y.Status.OK,"","",this);return a.getErrors().forEach(function(e){return o.addSubStatus(e)}),c.setValidationPath(o,this.patchPath(r)),o}return c.ok()},t.prototype.validateSelf=function(e){if(this._type.isExternal()){var t=c.error(f.EXTERNAL_IN_PROPERTY_DEFINITION,this);return c.setValidationPath(t,{name:this.propId()}),t}if(this._type.isSubTypeOf(c.UNKNOWN)||this._type.isSubTypeOf(c.RECURRENT)){var n=l(this._type),t=c.error(f.UNKNOWN_IN_PROPERTY_DEFINITION,this,{propName:this.propId(),typeName:n.name()});return c.setValidationPath(t,{name:this.propId(),child:{name:"type"}}),t}if(this._type.isAnonymous()){var r=this._type.validateType(e);if(!r.isOk()){var t=c.error(f.ERROR_IN_RANGE,this,{propName:this.propId(),msg:r.getMessage()});return r.getErrors().forEach(function(e){t.addSubStatus(e)}),c.setValidationPath(t,{name:this.propId()}),t}return r}if(this._type.isUnion()){var i=d.find(this._type.typeFamily(),function(e){return e.isSubTypeOf(c.UNKNOWN)});if(i){var t=c.error(f.UNKNOWN_IN_PROPERTY_DEFINITION,this,{propName:this.propId(),typeName:i.name()});return c.setValidationPath(t,{name:this.propId()}),t}}return c.ok()},t}(c.Constraint);t.MatchesProperty=v;var g=function(e){function t(t,n){e.call(this),this._value=t,this.provider=n}return p(t,e),t.prototype.value=function(){return this._value},t.prototype.check=function(e){var t=null,n=this.value();if("{"==n.charAt(0))try{t=m.getJSONSchema(n,this.provider)}catch(r){return c.error(f.INCORRECT_SCHEMA,this,{msg:r.message})}if("<"==n.charAt(0))try{t=m.getXMLSchema(n,this.provider)}catch(r){return c.ok()}if(t)try{t.validateObject(e)}catch(r){return"!_PERF_!"==r.message?c.error(f.UNABLE_TO_VALIDATE_XML,this,{},c.Status.WARNING):"Cannot assign to read only property '__$validated' of object"==r.message?c.ok():"Object.keys called on non-object"==r.message?c.ok():"Maximum call stack size exceeded"==r.message?c.error(f.CIRCULAR_REFS_IN_JSON_SCHEMA,this):c.error(f.EXAMPLE_SCHEMA_FAILURE,this,{msg:r.message})}return c.ok()},t.prototype.facetName=function(){return"schema"},t.prototype.requiredType=function(){return c.EXTERNAL},t}(c.Constraint);t.MatchToSchema=g;var A=function(e){function t(t){e.call(this),this._value=t}return p(t,e),t.prototype.facetName=function(){return"closed"},t.prototype.requiredType=function(){return c.OBJECT},t.prototype.value=function(){return this._value},t.prototype.patchOwner=function(e){this._owner=e},t.prototype.check=function(e){var t=this;if(this._value===!1&&e&&"object"==typeof e&&!Array.isArray(e)){var n={};Object.getOwnPropertyNames(e).forEach(function(e){return n[e]=!0});var r=this.owner().knownProperties();Object.getOwnPropertyNames(e).forEach(function(e){r.forEach(function(t){t.matches(e)&&delete n[e]})});var i=Object.keys(n);if((this.owner().hasPropertiesFacet()||r.length>0)&&i.length>0){var a=new c.Status(c.Status.OK,"","",this);return i.forEach(function(e){var n=c.error(f.UNKNOWN_PROPERTY,t,{propName:e});c.setValidationPath(n,{name:e}),a.addSubStatus(n)}),a}}return c.ok()},t.prototype.composeWith=function(e){if(!this._value)return null;if(e instanceof t){var n=e;if(d.isEqual(this.owner().propertySet(),n.owner().propertySet()))return n}if(e instanceof S){var r=e,i=r.value(),a=this.owner().propertySet();if(-1==a.indexOf(i))return this.nothing(r)}},t}(c.Constraint);t.KnownPropertyRestriction=A;var S=function(e){function t(t){e.call(this),this.name=t}return p(t,e),t.prototype.check=function(e){return e&&"object"==typeof e&&!Array.isArray(e)?e.hasOwnProperty(this.name)?c.ok():c.error(f.REQUIRED_PROPERTY_MISSING,this,{propName:this.name}):c.ok()},t.prototype.requiredType=function(){return c.OBJECT},t.prototype.facetName=function(){return"hasProperty"},t.prototype.value=function(){return this.name},t.prototype.composeWith=function(e){if(e instanceof t){var n=e;if(n.name===this.name)return this}return null},t}(c.Constraint);t.HasProperty=S;var T=function(e){function t(t,n,r){void 0===r&&(r=!1),e.call(this,n),this.name=t,this.type=n,this.optional=r}return p(t,e),t.prototype.matches=function(e){return e===this.name},t.prototype.path=function(){return this.name},t.prototype.check=function(e,t){if(e&&"object"==typeof e&&e.hasOwnProperty(this.name)){var n=this.validateProp(e,this.name,this.type,t);return!n.isOk()&&this.optional&&null==e[this.name]?c.ok():n}return c.ok()},t.prototype.requiredType=function(){return c.OBJECT},t.prototype.propId=function(){return this.name},t.prototype.propertyName=function(){return this.name},t.prototype.facetName=function(){return"propertyIs"},t.prototype.value=function(){return this.type},t.prototype.composeWith=function(e){if(e instanceof t){var n=e;if(n.name===this.name){if(-1!=this.type.typeFamily().indexOf(n.type))return n;if(-1!=n.type.typeFamily().indexOf(this.type))return this;i(e);var r=this.intersect(this.type,n.type);try{var a=r.checkConfluent();if(!a.isOk()){var o=a;return o.toRestriction()}return new t(this.name,r)}finally{this.release(r)}}}return null},t}(v);t.PropertyIs=T;var E=[];t.anotherRestrictionComponent=r,t.releaseAnotherRestrictionComponent=a,t.anotherRestrictionComponentsCount=o;var b=function(e){function t(t,n){e.call(this,n),this.regexp=t,this.type=n}return p(t,e),t.prototype.path=function(){
return"/"+this.regexp+"/"},t.prototype.matches=function(e){return e.match(this.regexp)?!0:!1},t.prototype.requiredType=function(){return c.OBJECT},t.prototype.propId=function(){return"["+this.regexp+"]"},t.prototype.facetName=function(){return"mapPropertyIs"},t.prototype.value=function(){return this.type},t.prototype.regexpValue=function(){return this.regexp},t.prototype.validateSelf=function(t){var n=this.checkValue();return n?c.error(f.INVALID_REGEXP,this,{msg:n}):e.prototype.validateSelf.call(this,t)},t.prototype.checkValue=function(){try{new RegExp(this.regexp)}catch(e){return e.message}return null},t.prototype.composeWith=function(e){if(e instanceof t){var n=e;if(n.regexp===this.regexp){if(-1!=this.type.typeFamily().indexOf(n.type))return n;if(-1!=n.type.typeFamily().indexOf(this.type))return this;var r=this.intersect(this.type,n.type);try{var i=r.checkConfluent();if(!i.isOk()){var a=i;return a.toRestriction()}return new t(this.regexp,r)}finally{this.release(r)}}}return null},t.prototype.check=function(e,t){if(e&&"object"==typeof e){var n={};null!=this._owner&&this._owner.meta().filter(function(e){return e instanceof T}).forEach(function(e){n[e.propertyName()]=!0});for(var r=new c.Status(c.Status.OK,"","",this),i=0,a=Object.getOwnPropertyNames(e);i<a.length;i++){var o=a[i];if(!n[o]&&o.match(this.regexp)){var s=this.validateProp(e,o,this.type,t);s.isOk()||r.addSubStatus(s)}}return r}return c.ok()},t}(v);t.MapPropertyIs=b;var N=function(e){function t(t){e.call(this,t),this.type=t}return p(t,e),t.prototype.path=function(){return this.facetName()},t.prototype.matches=function(e){return!0},t.prototype.requiredType=function(){return c.OBJECT},t.prototype.propId=function(){return"[]"},t.prototype.facetName=function(){return"additionalProperties"},t.prototype.value=function(){return this.type},t.prototype.match=function(e){for(var t=this.owner().metaOfType(T),n=this.owner().metaOfType(b),r=0;r<t.length;r++)if(t[r].matches(e))return!0;for(var r=0;r<n.length;r++)if(n[r].matches(e))return!0;return!1},t.prototype.composeWith=function(e){if(e instanceof t){var n=e;if(-1!=this.type.typeFamily().indexOf(n.type))return n;if(-1!=n.type.typeFamily().indexOf(this.type))return this;var r=this.intersect(this.type,n.type);try{var i=r.checkConfluent();if(!i.isOk()){var a=i;return a.toRestriction()}return new t(r)}finally{this.release(r)}}return null},t.prototype.check=function(e,t){var n=this,r=this.type,i=new c.Status(c.Status.OK,"","",this);return e&&"object"==typeof e&&Object.getOwnPropertyNames(e).forEach(function(a){if(!n.match(a)){var o=n.validateProp(e,a,r,t);o.isOk()||i.addSubStatus(o)}}),i},t}(v);t.AdditionalPropertyIs=N;var _=function(e){function t(){e.apply(this,arguments)}return p(t,e),t.prototype.requiredTypes=function(){return[]},t.prototype.checkOwner=function(e){var t=!1;if(e.isUnion())for(var n=e.typeFamily(),r=0,i=n;r<i.length;r++){var a=i[r];if(this.owner().isSubTypeOf(a)){t=!0;break}}else t=this.owner().isSubTypeOf(e);return t},t.prototype.validateSelf=function(t){var n=this,r=e.prototype.validateSelf.call(this,t),i=!1;if(this.checkOwner(this.requiredType()))if(this.requiredTypes()&&this.requiredTypes().length>0){var a=(this.owner(),d.find(this.requiredTypes(),function(e){return n.checkOwner(e)}));a&&(i=!0)}else i=!0;var o;if(i)o=this.checkValue();else{var s=this.requiredType().name();this.requiredTypes()&&this.requiredTypes().length>0&&(s="["+this.requiredTypes().map(function(e){return e.name()}).join()+"]");var o=c.error(f.FACET_USAGE_RESTRICTION,this,{facetName:this.facetName(),typeNames:s})}if(o&&!o.isOk())return c.setValidationPath(o,{name:this.facetName()}),o;var u=[r,o].filter(function(e){return e&&!e.isOk()});if(0==u.length)return c.ok();if(1==u.length)return u[0];for(var l=c.ok(),p=0,m=u;p<m.length;p++){var h=m[p];l.addSubStatus(h)}return l},t}(c.Constraint);t.FacetRestriction=_;var M=function(e){function t(t,n,r,i,a,o){e.call(this),this._facetName=t,this._value=n,this._max=r,this._opposite=i,this._requiredType=a,this._isInt=o}return p(t,e),t.prototype.facetName=function(){return this._facetName},t.prototype.isIntConstraint=function(){return this._isInt},t.prototype.isMax=function(){return this._max},t.prototype.value=function(){return this._value},t.prototype.check=function(e){var t=this.extractValue(e);if("number"==typeof t)if(this.isMax()){if(this.value()<t)return this.createError()}else if(this.value()>t)return this.createError();return c.ok()},t.prototype.createError=function(){return new y.Status(y.Status.ERROR,f.MINMAX_RESTRICTION_VIOLATION.code,this.toString(),this)},t.prototype.minValue=function(){return this._isInt?0:Number.NEGATIVE_INFINITY},t.prototype.requiredType=function(){return this._requiredType},t.prototype.checkValue=function(){return"number"!=typeof this._value?c.error(f.FACET_REQUIRE_NUMBER,this,{facetName:this.facetName()},c.Status.ERROR,!0):this.isIntConstraint()&&!s(this.value())?c.error(f.FACET_REQUIRE_INTEGER,this,{facetName:this.facetName()},c.Status.ERROR,!0):this.value()<this.minValue()?c.error(f.MIN_VALUE,this,{facetName:this.facetName(),minValue:this.minValue()},c.Status.ERROR,!0):void 0},t.prototype.composeWith=function(e){if(e instanceof t){var n=e;if(n.facetName()==this.facetName()&&n.isMax()==this.isMax())return this.isMax()?this.value()<n.value()?n:this:this.value()>n.value()?n:this;if(n.facetName()===this._opposite)if(this.isMax()){if(n.value()>this.value())return this.nothing(e)}else if(n.value()<this.value())return this.nothing(e)}return null},t.prototype.facetPath=function(){var e=[this.facetName()],t=this._owner;if(null!=t&&t instanceof c.InheritedType){var n=t;e=c.typePath(n).concat(e)}return e.join(".")},t.prototype.toString=function(){return"'"+this.facetPath()+"="+this.value()+"' i.e. "+this.textMessagePart()+" "+this.value()},t.prototype.conflictMessage=function(e,t){var n=this.isMax()?["less","higher"]:["higher","less"];return"['"+this.facetPath()+"="+this.value()+"' is "+n[0]+" than '"+e+"="+t+"'. The "+this._opposite+" cannot be "+n[1]+" than the "+this.facetName()+".]"},t}(_);t.MinMaxRestriction=M;var w=function(e){function t(t){e.call(this),this._value=t}return p(t,e),t.prototype.value=function(){return this._value},t.prototype.check=function(e){if("number"==typeof e){var t=e/this.value();if(!s(t))return c.error(f.EVEN_RATIO,this,{val1:e,val2:this.value()})}return c.ok()},t.prototype.composeWith=function(e){return null},t.prototype.facetName=function(){return"multipleOf"},t.prototype.checkValue=function(){return"number"!=typeof this._value?c.error(f.FACET_REQUIRE_NUMBER,this,{facetName:this.facetName()},c.Status.ERROR,!0):null},t.prototype.requiredType=function(){return c.NUMBER},t}(_);t.MultipleOf=w;var R=function(e){function t(t){e.call(this,"maximum",t,!0,"minimum",c.NUMBER,!1)}return p(t,e),t.prototype.extractValue=function(e){return e},t.prototype.textMessagePart=function(){return"value should not be more than"},t}(M);t.Maximum=R;var I=function(e){function t(t){e.call(this,"minimum",t,!1,"maximum",c.NUMBER,!1)}return p(t,e),t.prototype.extractValue=function(e){return e},t.prototype.textMessagePart=function(){return"value should not be less than"},t}(M);t.Minimum=I;var C=function(e){function t(t){e.call(this,"maxItems",t,!0,"minItems",c.ARRAY,!0)}return p(t,e),t.prototype.extractValue=function(e){return Array.isArray(e)?e.length:void 0},t.prototype.textMessagePart=function(){return"array items count should not be more than"},t}(M);t.MaxItems=C;var L=function(e){function t(t){e.call(this,"minItems",t,!1,"maxItems",c.ARRAY,!0)}return p(t,e),t.prototype.extractValue=function(e){return Array.isArray(e)?e.length:void 0},t.prototype.textMessagePart=function(){return"array items count should not be less than"},t}(M);t.MinItems=L;var P=function(e){function t(t){e.call(this,"maxLength",t,!0,"minLength",new c.UnionType("string and file",[c.STRING,c.FILE]),!0)}return p(t,e),t.prototype.extractValue=function(e){return"string"==typeof e?e.length:0},t.prototype.textMessagePart=function(){return"string length should not be more than"},t}(M);t.MaxLength=P;var O=function(e){function t(t){e.call(this,"minLength",t,!1,"maxLength",new c.UnionType("string and file",[c.STRING,c.FILE]),!0)}return p(t,e),t.prototype.extractValue=function(e){return"string"==typeof e?e.length:0},t.prototype.textMessagePart=function(){return"string length should not be less than"},t}(M);t.MinLength=O;var D=function(e){function t(t){e.call(this,"maxProperties",t,!0,"minProperties",c.OBJECT,!0)}return p(t,e),t.prototype.extractValue=function(e){return Object.keys(e).length},t.prototype.textMessagePart=function(){return"object properties count should not be more than"},t}(M);t.MaxProperties=D;var x=function(e){function t(t){e.call(this,"minProperties",t,!1,"maxProperties",c.OBJECT,!0)}return p(t,e),t.prototype.extractValue=function(e){return Object.keys(e).length},t.prototype.textMessagePart=function(){return"object properties count should not be less than"},t}(M);t.MinProperties=x;var U=function(e){function t(t){e.call(this),this._value=t}return p(t,e),t.prototype.facetName=function(){return"uniqueItems"},t.prototype.requiredType=function(){return c.ARRAY},t.prototype.check=function(e){if(!this._value)return c.ok();if(Array.isArray(e)){var t=e;if(d.unique(t).length!=t.length)return c.error(f.MUST_BE_UNIQUE,this)}return c.ok()},t.prototype.composeWith=function(e){if(e instanceof t){var n=e;if(n._value==this._value)return this}return null},t.prototype.value=function(){return this._value},t.prototype.checkValue=function(){return"boolean"!=typeof this._value?c.error(f.UNIQUE_ITEMS_BOOLEAN,this):null},t.prototype.toString=function(){return"items should be unique"},t}(_);t.UniqueItems=U;var k=function(e){function t(t){e.call(this),this.type=t}return p(t,e),t.prototype.facetName=function(){return"items"},t.prototype.requiredType=function(){return c.ARRAY},t.prototype.toString=function(){return"items should be of type "+this.type},t.prototype.check=function(e){var t=new c.Status(c.Status.OK,"","",this);if(Array.isArray(e))for(var n=e,r=0;r<n.length;r++){var i=this.type.validate(n[r],!1,!1);if(!i.isOk()){var a=this.type;if(a.isUnknown()||a.isRecurrent()){var o=c.error(f.ARRAY_AGAINST_UNKNOWN,this,{typeName:a.name()});return o}}c.setValidationPath(i,{name:""+r}),t.addSubStatus(i)}return t},t.prototype.validateSelf=function(t){var n=e.prototype.validateSelf.call(this,t);if(this.type.isAnonymous()){var r=this.type.validateType(t);return r.isOk()||n.addSubStatus(c.error(f.INVALID_COMPONENT_TYPE,this,{msg:n.getMessage()})),n}if(this.type.isExternal())n.addSubStatus(c.error(f.EXTERNAL_AS_COMPONENT,this));else if(this.type.isSubTypeOf(c.UNKNOWN)||this.type.isSubTypeOf(c.RECURRENT))n.addSubStatus(c.error(f.UNKNOWN_AS_COMPONENT,this,{typeName:this.type.name()}));else if(this.type.isUnion()){var i=d.find(this.type.typeFamily(),function(e){return e.isSubTypeOf(c.UNKNOWN)});i&&n.addSubStatus(c.error(f.UNKNOWN_AS_COMPONENT,this,{typeName:i.name()}))}return n},t.prototype.composeWith=function(e){if(e instanceof t){var n=e;if(-1!=this.type.typeFamily().indexOf(n.type))return n;if(-1!=n.type.typeFamily().indexOf(this.type))return this;var r=this.intersect(this.type,n.type);try{var i=r.checkConfluent();if(!i.isOk()){var a=i;return a.toRestriction()}return new t(r)}finally{this.release(r)}}return null},t.prototype.checkValue=function(){return null},t.prototype.value=function(){return this.type},t}(_);t.ComponentShouldBeOfType=k;var F=function(e){function t(t){e.call(this),this._value=t}return p(t,e),t.prototype.facetName=function(){return"pattern"},t.prototype.requiredType=function(){return c.STRING},t.prototype.check=function(e){if("string"==typeof e){var t=e;try{var n=t.match(this._value),r=!1;if(n)for(var i=0,a=n;i<a.length;i++){var o=a[i];if(o.length==t.length){r=!0;break}}if(!r)return c.error(f.PATTERN_VIOLATION,this,{value:this.value()})}catch(s){}}return c.ok()},t.prototype.composeWith=function(e){if(e instanceof t){var n=e;return n._value===this._value?this:this.nothing(e,"pattern restrictions can not be composed at one type")}return null},t.prototype.value=function(){return this._value},t.prototype.checkValue=function(){try{new RegExp(this._value)}catch(e){return c.error(f.INVALID_REGEXP,this,{msg:e.message},c.Status.ERROR,!0)}return null},t.prototype.toString=function(){return"should pass reg exp:"+this.value},t}(_);t.Pattern=F;var B=function(e){function t(t){e.call(this),this._value=t}return p(t,e),t.prototype.facetName=function(){return"format"},t.prototype.requiredType=function(){return c.SCALAR},t.prototype.requiredTypes=function(){return[c.NUMBER,c.INTEGER,c.DATETIME]},t.prototype.check=function(e){return c.ok()},t.prototype.composeWith=function(e){if(e instanceof t){var n=e;return n._value===this._value?this:this.nothing(e,"Format restrictions can not be composed at one type")}return null},t.prototype.value=function(){return this._value},t.prototype.checkValue=function(){var e=this;try{var t=[];if(this.owner().isSubTypeOf(c.INTEGER))t=["int32","int64","int","int16","int8"];else if(this.owner().isSubTypeOf(c.NUMBER))t=["int32","int64","int","long","float","double","int16","int8"];else{if(!this.owner().isSubTypeOf(c.DATETIME))return null;t=["rfc3339","rfc2616"]}var n=d.find(t,function(t){return t==e.value()});if(!n)return c.error(f.ALLOWED_FORMAT_VALUES,this,{allowedValues:t.map(function(e){return"'"+e+"'"}).join(", ")},c.Status.ERROR,!0)}catch(r){return new y.Status(y.Status.ERROR,"",r.message,this)}return null},t.prototype.toString=function(){return"should have format:"+this.value},t}(_);t.Format=B;var K=function(e){function t(t){e.call(this),this._value=t}return p(t,e),t.prototype.facetName=function(){return"enum"},t.prototype.requiredType=function(){return c.SCALAR},t.prototype.check=function(e){if(!this.checkStatus){var t=this.value();if(Array.isArray(t)||(t=[t]),!t.some(function(t){return t==e})){var n=Array.isArray(this._value)?this._value.map(function(e){return"'"+e+"'"}).join(", "):"'"+this._value+"'";return c.error(f.ENUM_RESTRICTION,this,{values:n})}}return c.ok()},t.prototype.composeWith=function(e){if(e instanceof t){var n=e,r=d.intersection(this._value,n._value);return 0==r.length?this.nothing(e):new t(r)}return null},t.prototype.value=function(){return this._value},t.prototype.checkValue=function(){var e=this;if(!this.owner().isSubTypeOf(this.requiredType()))return c.error(f.ENUM_OWNER_TYPES,this,{typeNames:this.requiredType().name()},c.Status.ERROR,!0);if(this.requiredTypes()&&this.requiredTypes().length>0){var t=this.owner(),n=d.find(this.requiredTypes(),function(e){return t.isSubTypeOf(e)});if(!n){var r="["+this.requiredTypes().map(function(e){return"'"+e.name()+"'"}).join(", ")+"]";return c.error(f.ENUM_OWNER_TYPES,this,{typeNames:r},c.Status.ERROR,!0)}}if(!Array.isArray(this._value))return c.error(f.ENUM_ARRAY,this,{},c.Status.ERROR,!0);var i=null;this.checkStatus=!0;try{this._value.forEach(function(t){var n=e.owner().validate(t);n.isOk()||(i=n)})}finally{this.checkStatus=!1}return i},t.prototype.toString=function(){var e=Array.isArray(this._value)?this._value.map(function(e){return"'"+e+"'"}).join(", "):"'"+this._value+"'";return"value should be one of: "+e},t}(_);t.Enum=K,t.optimize=u},function(e,t,n){"use strict";function r(e,t){return f.serializeToXML(e,t)}function i(e,t){if("string"==typeof e&&(t.isObject()||t.isArray()||t.isExternal()||t.isUnion())){var n=e,r=n.trim().charAt(0);if("{"==r||"["==r||"null"==n.trim())try{return JSON.parse(n)}catch(i){if(t.isObject()||t.isArray()){var a=s.error(u.CAN_NOT_PARSE_JSON,this,{msg:i.message});return a}}if("<"==r)try{var o=f.readObject(n,t),l=f.getXmlErrors(o);if(l){var p=s.error(u.INVALID_XML,null);return l.forEach(function(e){return p.addSubStatus(e)}),p}return o}catch(i){}}return t.getExtra(m.REPEAT)&&(e=[e]),e}function a(e,t,n){t?s.setValidationPath(e,{name:"examples",child:{name:n}}):s.setValidationPath(e,{name:"examples",child:{name:n,child:{name:"value"}}})}var o=this&&this.__extends||function(e,t){function n(){this.constructor=e}for(var r in t)t.hasOwnProperty(r)&&(e[r]=t[r]);e.prototype=null===t?Object.create(t):(n.prototype=t.prototype,new n)},s=n(98),u=s.messageRegistry,l=n(98),p=n(102),c=n(187),f=n(144),m=n(99),d=function(e){function t(t,n,r){void 0===r&&(r=!1),e.call(this,r),this._name=t,this._value=n}return o(t,e),t.prototype.value=function(){return this._value},t.prototype.requiredType=function(){return s.ANY},t.prototype.facetName=function(){return this._name},t.prototype.kind=function(){return null},t}(s.TypeInformation);t.MetaInfo=d;var h=function(e){function t(t){e.call(this,"description",t)}return o(t,e),t.prototype.kind=function(){return m.MetaInformationKind.Description},t}(d);t.Description=h;var y=function(e){function t(){e.call(this,"notScalar",!0)}return o(t,e),t.prototype.kind=function(){return m.MetaInformationKind.NotScalar},t}(d);t.NotScalar=y;var v=function(e){function t(t){e.call(this,"displayName",t)}return o(t,e),t.prototype.kind=function(){return m.MetaInformationKind.DisplayName},t}(d);t.DisplayName=v;var g=function(e){function t(t){e.call(this,"usage",t)}return o(t,e),t.prototype.kind=function(){return m.MetaInformationKind.Usage},t}(d);t.Usage=g;var A=function(e){function t(t,n){e.call(this,t,n)}return o(t,e),t.prototype.validateSelf=function(t,n){void 0===n&&(n=!1);var r=t.get(this.facetName());if(!r)return s.error(u.UNKNOWN_ANNOTATION,this,{facetName:this.facetName()});var i=s.ok(),a=this.value();a||r.isString()&&(a="");var o=r.metaOfType(M),l=n?"Example":"TypeDeclaration";if(o.length>0){var p=[],c=o.filter(function(e){var t=e.value();return Array.isArray(t)?(p=p.concat(t),t.indexOf(l)>=0):(p.push(t),t==l)});if(0==c.length){var f=p.map(function(e){return"'"+e+"'"}).join(", "),m=s.error(u.INVALID_ANNOTATION_LOCATION,this,{aName:e.prototype.facetName.call(this),aValues:f});i.addSubStatus(m)}}var d=r.validateDirect(a,!0,!1);if(!d.isOk()){var h=s.error(u.INVALID_ANNOTATION_VALUE,this,{msg:d.getMessage()});h.addSubStatus(d),i.addSubStatus(h)}return s.setValidationPath(i,{name:"("+this.facetName()+")"}),i},t.prototype.kind=function(){return m.MetaInformationKind.Annotation},t.prototype.ownerFacet=function(){return this._ownerFacet},t.prototype.setOwnerFacet=function(e){this._ownerFacet=e},t}(d);t.Annotation=A;var S=function(e){function t(t,n,r){e.call(this,t,n,!0),this.name=t,this._type=n,this.optional=r}return o(t,e),t.prototype.actualName=function(){return"?"==this.name.charAt(this.name.length-1)?this.name.substr(0,this.name.length-1):this.name},t.prototype.isOptional=function(){return this.optional},t.prototype.type=function(){return this._type},t.prototype.kind=function(){return m.MetaInformationKind.FacetDeclaration},t}(d);t.FacetDeclaration=S;var T=function(e){function t(t,n){e.call(this,t,n,!0)}return o(t,e),t.prototype.kind=function(){return m.MetaInformationKind.CustomFacet},t}(d);t.CustomFacet=T;var E=[{propName:"strict",propType:"boolean",messageEntry:u.STRICT_BOOLEAN},{propName:"displayName",propType:"string",messageEntry:u.DISPLAY_NAME_STRING},{propName:"description",propType:"string",messageEntry:u.DESCRIPTION_STRING}],b=function(e){function t(t){e.call(this,"example",t)}return o(t,e),t.prototype.validateSelf=function(e){var t=s.ok();t.addSubStatus(this.validateValue(e));var n=this.validateAnnotations(e);return s.setValidationPath(n,{name:this.facetName()}),t.addSubStatus(n),t},t.prototype.validateValue=function(e){var t=this.value(),n=!1,r=s.ok();if("object"==typeof t&&t&&t.value){for(var a=0,o=E;a<o.length;a++){var l=o[a],p=l.propName,c=l.propType,f=t[p];if(f&&typeof f!=c&&("object"==typeof f&&Object.keys(f).forEach(function(t){if("("==t.charAt(0)&&")"==t.charAt(t.length-1)){var n=new A(t.substring(1,t.length-1),f[t]),i=n.validateSelf(e,!0);s.setValidationPath(i,{name:"example",child:{name:p,child:{name:t}}}),r.addSubStatus(i)}}),!f.value&&typeof f.value!=c)){var m=s.error(l.messageEntry,this),d=f.value?{name:"value"}:null;s.setValidationPath(m,{name:"example",child:{name:p,child:d}}),r.addSubStatus(m)}}if(t.strict===!1||"object"==typeof t.strict&&t.strict.value===!1)return r;t=t.value,n=!0}var h=i(t,this.owner());if(h instanceof s.Status&&!h.isOk())return s.setValidationPath(h,{name:"example"}),r.addSubStatus(h),r;var y=this.owner().validateDirect(h,!0,!1);if(!y.isOk()){"string"==typeof this.value();var v=s.error(u.INVALID_EXMAPLE,this,{msg:y.getMessage()});y.getErrors().forEach(function(e){v.addSubStatus(e),n?s.setValidationPath(e,{name:"example",child:{name:"value"}}):s.setValidationPath(e,{name:"example"})}),r.addSubStatus(v)}return r},t.prototype.validateAnnotations=function(e){var t=s.ok(),n=this.value();if("object"==typeof n&&n&&n.value)for(var r=Object.keys(n).filter(function(e){return e.length>2&&"("==e.charAt(0)&&")"==e.charAt(e.length-1)}),i=0,a=r;i<a.length;i++){var o=a[i],u=n[o],l=o.substring(1,o.length-1),p=new A(l,u);t.addSubStatus(p.validateSelf(e,!0))}return t},t.prototype.example=function(){var e=this.value();return"object"==typeof e&&e&&e.value&&(e=e.value),i(e,this.owner())},t.prototype.asXMLString=function(){var e=this.value();if("string"==typeof e&&0===e.trim().indexOf("<"))return e;var t=i(e,this.owner());return r(t,this.owner())},t.prototype.kind=function(){return m.MetaInformationKind.Example},t}(d);t.Example=b;var N=function(e){function t(t){e.call(this,"required",t)}return o(t,e),t.prototype.validateSelf=function(t){var n=e.prototype.validateSelf.call(this,t);return"boolean"!=typeof this.value()&&(n=s.error(u.REQUIRED_BOOLEAN,this),s.setValidationPath(n,{name:this.facetName()})),n},t.prototype.kind=function(){return m.MetaInformationKind.Required},t}(d);t.Required=N;var _=function(e){function t(){e.call(this,"hasPropertiesFacet",null)}return o(t,e),t.prototype.kind=function(){return m.MetaInformationKind.HasPropertiesFacet},t}(d);t.HasPropertiesFacet=_;var M=function(e){function t(t){e.call(this,"allowedTargets",t)}return o(t,e),t.prototype.kind=function(){return m.MetaInformationKind.AllowedTargets},t}(d);t.AllowedTargets=M;var w=function(e){function t(t){e.call(this,"examples",t)}return o(t,e),t.prototype.examples=function(){var e=this,t=this.value(),n=[];return Object.keys(t).forEach(function(r){if("object"==typeof t[r]&&t[r]){var a=t[r].value;a||(a=t[r]);var o=i(a,e.owner());n.push(o)}}),n},t.prototype.asXMLStrings=function(){var e=this,t=this.value(),n={};return Object.keys(t).forEach(function(a){var o=t[a];if("string"==typeof o&&0===o.trim().indexOf("<"))return void(n[a]=o);var s=i(o,e.owner());n[a]=r(s,e.owner())}),n},t.prototype.validateSelf=function(e){var t=this;if("object"==typeof this.value()){var n=new l.Status(l.Status.OK,"","",this),r=this.value();return r&&Object.keys(r).forEach(function(o){var u=r[o];if(u){"object"==typeof u&&u.value&&Object.keys(u).forEach(function(t){if("("==t.charAt(0)&&")"==t.charAt(t.length-1)){var i=new A(t.substring(1,t.length-1),r[o][t]),a=i.validateSelf(e,!0);s.setValidationPath(a,{name:"examples",child:{name:o,child:{name:t}}}),n.addSubStatus(a)}});var l=u.value,p=!l;if(p)l=u;else{for(var c=0,f=E;c<f.length;c++){var m=f[c];t.checkScalarProperty(u,o,m,e,n)}if(u.strict===!1||"object"==typeof u.strict&&u.strict.value===!1)return}var d=i(l,t.owner());if(d instanceof s.Status)return a(d,p,o),void n.addSubStatus(d);var h=t.owner().validate(d,!0,!1);h.getErrors().forEach(function(e){n.addSubStatus(e),a(e,p,o)})}}),n}return s.error(u.EXMAPLES_MAP,this)},t.prototype.checkScalarProperty=function(e,t,n,r,i){var a=n.propName,o=n.propType,u=e[a];if(u&&typeof u!=o){var l=null;if("object"==typeof u&&(l={name:"value"},Object.keys(u).forEach(function(n){if("("==n.charAt(0)&&")"==n.charAt(n.length-1)){var o=new A(n.substring(1,n.length-1),e[a][n]),u=o.validateSelf(r,!0);s.setValidationPath(u,{name:"examples",child:{name:t,child:{name:a,child:{name:n}}}}),i.addSubStatus(u)}})),!u.value&&typeof u.value!=o){var p=s.error(n.messageEntry,this);s.setValidationPath(p,{name:"examples",child:{name:t,child:{name:a,child:l}}}),i.addSubStatus(p)}}},t.prototype.kind=function(){return m.MetaInformationKind.Examples},t}(d);t.Examples=w;var R=function(e){function t(t){e.call(this,"xml",t)}return o(t,e),t.prototype.kind=function(){return m.MetaInformationKind.XMLInfo},t}(d);t.XMLInfo=R;var I=function(e){function t(t){e.call(this,"default",t)}return o(t,e),t.prototype.validateSelf=function(t){var n=e.prototype.validateSelf.call(this,t),r=this.owner().validateDirect(this.value(),!0);return r.isOk()||(n=s.error(u.INVALID_DEFAULT_VALUE,this,{msg:r.getMessage()}),s.setValidationPath(n,{name:this.facetName()})),n},t.prototype.kind=function(){return m.MetaInformationKind.Default},t}(d);t.Default=I;var C=function(e){function t(t){e.call(this,!0),this.property=t}return o(t,e),t.prototype.requiredType=function(){return s.OBJECT},t.prototype.value=function(){return this.property},t.prototype.facetName=function(){return"discriminator"},t.prototype.validateSelf=function(t){var n=this,r=e.prototype.validateSelf.call(this,t);if(this.owner().isUnion())r=s.error(u.DISCRIMINATOR_FOR_UNION,this);else if(this.owner().isSubTypeOf(s.OBJECT))if(this.owner().getExtra(s.GLOBAL)===!1)r=s.error(u.DISCRIMINATOR_FOR_INLINE,this);else{var i=c.find(this.owner().meta(),function(e){return e instanceof p.PropertyIs&&e.propertyName()==n.value()});i?i.value().isScalar()||(r=s.error(u.SCALAR_FOR_DISCRIMINATOR,this)):r=s.error(u.UNKNOWN_FOR_DISCRIMINATOR,this,{value:this.value()},s.Status.WARNING)}else r=s.error(u.DISCRIMINATOR_FOR_OBJECT,this);return r.getValidationPath()||s.setValidationPath(r,{name:this.facetName()}),r},t.prototype.kind=function(){return m.MetaInformationKind.Discriminator},t}(s.TypeInformation);t.Discriminator=C;var L=function(e){function t(t,n){void 0===n&&(n=!0),e.call(this,!1),this._value=t,this.strict=n}return o(t,e),t.prototype.check=function(e,t){var n=this.owner(),r=this.value(),i=n.metaOfType(C);if(0==i.length)return s.ok();var a=i[0].value();if(r){if(e.hasOwnProperty(a)){var o=e[a];if(o!=r){var u=s.error(l.Status.CODE_INCORRECT_DISCRIMINATOR,this,{rootType:n.name(),value:o,propName:a},l.Status.WARNING);return s.setValidationPath(u,{name:a,child:t}),u}return s.ok()}var p=s.error(l.Status.CODE_MISSING_DISCRIMINATOR,this,{rootType:n.name(),propName:a});return s.setValidationPath(p,t),p}},t.prototype.facetName=function(){return"discriminatorValue"},t.prototype.validateSelf=function(t){var n=e.prototype.validateSelf.call(this,t);if(this.strict){var r=this.owner().oneMeta(C);if(this.owner().isSubTypeOf(s.OBJECT))if(this.owner().getExtra(s.GLOBAL)===!1)n.addSubStatus(s.error(u.DISCRIMINATOR_FOR_INLINE,this));else if(r){var i=c.find(this.owner().meta(),function(e){return e instanceof p.PropertyIs&&e.propertyName()==r.value()});if(i){var a=i.value().validate(this.value());a.isOk()||n.addSubStatus(s.error(u.INVALID_DISCRIMINATOR_VALUE,this,{msg:a.getMessage()}))}}else n.addSubStatus(s.error(u.DISCRIMINATOR_VALUE_WITHOUT_DISCRIMINATOR,this));else n.addSubStatus(s.error(u.DISCRIMINATOR_FOR_OBJECT,this))}return n.getValidationPath()||s.setValidationPath(n,{name:this.facetName()}),n},t.prototype.requiredType=function(){return s.OBJECT},t.prototype.value=function(){return this._value},t.prototype.kind=function(){return m.MetaInformationKind.DiscriminatorValue},t.prototype.isStrict=function(){return this.strict},t}(s.Constraint);t.DiscriminatorValue=L},function(e,t,n){"use strict";function r(e){o=e}function i(e,t,n){void 0===n&&(n=null);var r=null;if(e.getExtra(c))return e.getExtra(c);if(!e){var f=t("any");f||(r=new u.StructuredType(e.name()))}if(e.isBuiltin()){var m="any"!=e.name()&&"array"!=e.name()?t(e.name()):null;r=m?m:e.isScalar()?new u.ValueType(e.name(),null):new u.StructuredType(e.name())}else if(e.isObject())r=new u.StructuredType(e.name(),null);else if(e.isArray()){var d=new u.Array(e.name(),null);r=d,e.putExtra(c,r);var h=e.oneMeta(p.ComponentShouldBeOfType),y=h?h.value():s.ANY;d.setComponent(i(y,t))}else if(e instanceof s.UnionType){var v=new u.Union(e.name(),null);0==e.superTypes().length&&v._superTypes.push(i(s.UNION,t,n)),e.putExtra(c,v),e.options().forEach(function(n){if(null==v.left)v.left=i(n,t);else if(null==v.right)v.right=i(n,t);else{var r=new u.Union(e.name(),null);r.left=v.right,r.right=i(n,t),v.right=r}}),r=v}else if(e.isScalar())r=new u.ValueType(e.name(),null);else if(e instanceof s.ExternalType){var g=e,A=new u.ExternalType(g.name());A.schemaString=g.schema(),r=A}if(r||(r=new u.StructuredType(e.name())),e.superTypes().forEach(function(e){var n=i(e,t);e.isBuiltin()?r._superTypes.push(n):r.addSuperType(n)}),e.isEmpty()){if(e.isArray()&&1==e.superTypes().length&&e.superTypes()[0].isAnonymous()){var S=r.superTypes()[0];S.setName(e.name()),S._subTypes=S._subTypes.filter(function(e){return e!=r}),r=S}if(e.isUnion()&&1==e.superTypes().length&&e.superTypes()[0].isAnonymous()){var S=r.superTypes()[0];S.setName(e.name()),S._subTypes=S._subTypes.filter(function(e){return e!=r}),r=S}}e.putExtra(c,r);var T=l.toProto(e);T.properties.forEach(function(e){var n=o?o(e.id):new u.Property(e.id);n.withDomain(r),n.withRange(i(e.type,t)),e.optional||n.withRequired(!0)}),T.facetDeclarations.forEach(function(e){var n=o?o(e.facetName()):new u.Property(e.facetName());n.withRange(i(e.type(),t)),r.addFacet(n)}),e.customFacets().forEach(function(e){r.fixFacet(e.facetName(),e.value())});for(var E=e.metaOfType(p.FacetRestriction),b=0,N=E;b<N.length;b++){var _=N[b];r.fixFacet(_.facetName(),_.value())}return r.addAdapter(e),e.isEmpty()&&r.addAdapter(new u.Empty),r._validator=a(e),e.isBuiltin()?r.buildIn=!0:e.subTypes().forEach(function(e){i(e,t,n)}),r}function a(e){return function(t){return e.validate(t,!1).getErrors()}}var o,s=n(98),u=n(105),l=n(100),p=n(102),c="nominal";t.setPropertyConstructor=r,t.toNominal=i},function(e,t,n){(function(e){"use strict";function r(t){e.extraInjectors.push(t)}var i=this&&this.__extends||function(e,t){function n(){this.constructor=e}for(var r in t)t.hasOwnProperty(r)&&(e[r]=t[r]);e.prototype=null===t?Object.create(t):(n.prototype=t.prototype,new n)},a=n(106),o=n(99),s=n(143);e.extraInjectors=[],t.registerInjector=r;var u=function(){function t(){var t=this;this.adapters=[],e.extraInjectors.forEach(function(e){return e.inject(t)})}return t.prototype.addAdapter=function(e){this.adapters.push(e)},t.prototype.getAdapter=function(e){var t=null;return this.adapters.forEach(function(n){n instanceof e&&(t=n)}),t},t.prototype.getAdapters=function(){return this.adapters},t}();t.Adaptable=u;var l=function(e){function t(t,n){void 0===n&&(n=""),e.call(this),this._name=t,this._description=n,this._tags=[],this._annotations=[]}return i(t,e),t.prototype.nameId=function(){return this._name},t.prototype.description=function(){return this._description},t.prototype.addAnnotation=function(e){this._annotations.push(e)},t.prototype.removeAnnotation=function(e){this._annotations=this._annotations.filter(function(t){return t!=e})},t.prototype.annotations=function(){return[].concat(this._annotations)},t.prototype.tags=function(){return this._tags},t.prototype.withDescription=function(e){return this._description=e,this},t.prototype.setName=function(e){this._name=e},t}(u);t.Described=l;var p=function(e){function t(t,n){e.call(this,t.nameId()),this.type=t,this.parameters=n}return i(t,e),t.prototype.parameterNames=function(){return Object.keys(this.parameters)},t.prototype.parameter=function(e){return this.parameters[e]},t.prototype.getType=function(){return this.type},t}(l);t.Annotation=p;var c=function(){function e(){}return e}();t.Empty=c;var f=function(){function e(){}return e.prototype.type=function(e){return null},e.prototype.version=function(){return"Empty"},e.prototype.types=function(){return[]},e.prototype.matched=function(){return{}},e}(),m=new f,d=n(141),h=function(e){function t(t,n,r){void 0===n&&(n=m),void 0===r&&(r=""),e.call(this,t),this._universe=n,this._path=r,this._customProperties=[],this._facets=[],this._superTypes=[],this._subTypes=[],this._requirements=[],this.fixedFacets={},this.uc=!1}return i(t,e),t.prototype.properties=function(){
return[]},t.prototype.externalInHierarchy=function(){var e=this.allSuperTypes(),t=null;return e.forEach(function(e){e instanceof T&&(t=e)}),t},t.prototype.addFacet=function(e){this._facets.push(e)},t.prototype.validate=function(e){if(!this._validator)throw new Error("Validate can be used only on runtime types instances");return this._validator(e)},t.prototype.allFacets=function(e){if(void 0===e&&(e={}),this._allFacets)return this._allFacets;if(e[this.nameId()])return[];e[this.typeId()]=this;var n={};return this.superTypes().length>0&&this.superTypes().forEach(function(r){r instanceof t&&r.allFacets(e).forEach(function(e){return n[e.nameId()]=e})}),this._facets.forEach(function(e){return n[e.nameId()]=e}),this._allFacets=Object.keys(n).map(function(e){return n[e]}),this._allFacets},t.prototype.facets=function(){return[].concat(this._facets)},t.prototype.facet=function(e){return s.find(this.allFacets(),function(t){return t.nameId()==e})},t.prototype.typeId=function(){return this.nameId()},t.prototype.allProperties=function(e){if(void 0===e&&(e={}),this._props)return this._props;if(e[this.typeId()])return[];e[this.typeId()]=this;var n={};this.superTypes().length>0&&this.superTypes().forEach(function(r){r instanceof t?r.allProperties(e).forEach(function(e){return n[e.nameId()]=e}):r.allProperties().forEach(function(e){return n[e.nameId()]=e})});for(var r in this.getFixedFacets())delete n[r];return this.properties().forEach(function(e){return n[e.nameId()]=e}),this._props=Object.keys(n).map(function(e){return n[e]}),this._props},t.prototype.property=function(e){return s.find(this.allProperties(),function(t){return t.nameId()==e})},t.prototype.hasValueTypeInHierarchy=function(){return null!=s.find(this.allSuperTypes(),function(e){var t=e;if(t.uc)return!1;t.uc=!0;try{return e.hasValueTypeInHierarchy()}finally{t.uc=!1}})},t.prototype.isAnnotationType=function(){return!1},t.prototype.hasStructure=function(){return!1},t.prototype.key=function(){return this._key?this._key:this._universe&&(this._key=this.universe().matched()[this.nameId()],!this._key)?null:this._key},t.prototype.hasArrayInHierarchy=function(){var e=null!=s.find(this.allSuperTypes(),function(e){return e instanceof S});return e},t.prototype.arrayInHierarchy=function(){var e=this.allSuperTypes(),t=null;return e.forEach(function(e){e instanceof S&&(t=e)}),t},t.prototype.unionInHierarchy=function(){var e=this.allSuperTypes(),t=null;return e.forEach(function(e){e instanceof A&&(t=e)}),t},t.prototype.hasExternalInHierarchy=function(){return null!=s.find(this.allSuperTypes(),function(e){var t=e;if(t.uc)return!1;t.uc=!0;try{return e instanceof T}finally{t.uc=!1}})},t.prototype.hasUnionInHierarchy=function(){return null!=s.find(this.allSuperTypes(),function(e){var t=e;if(t.uc)return!1;t.uc=!0;try{return e.hasUnionInHierarchy()}finally{t.uc=!1}})},t.prototype.fixFacet=function(e,t){this.fixedFacets[e]=t},t.prototype.getFixedFacets=function(){var e={};for(var t in this.fixedFacets)e[t]=this.fixedFacets[t];return this.contributeFacets(e),e},t.prototype.allFixedFacets=function(){if(this._af)return this._af;var e=this.allSuperTypes();e.push(this);var t={};return e.forEach(function(e){for(var n=e.getFixedFacets(),r=0,i=Object.keys(n);r<i.length;r++){var a=i[r];t[a]=n[a]}}),this._af=t,t},t.prototype.contributeFacets=function(e){},t.prototype.getPath=function(){return this._path},t.prototype.setNameAtRuntime=function(e){this._nameAtRuntime=e},t.prototype.getNameAtRuntime=function(){return this._nameAtRuntime},t.prototype.universe=function(){return this._universe?this._universe:new f},t.prototype.superTypes=function(){return[].concat(this._superTypes)},t.prototype.isAssignableFrom=function(e){if(this.nameId()==e)return this.isUserDefined()?!1:!0;for(var t=this.allSuperTypes(),n=0;n<t.length;n++)if(t[n].nameId()==e)return!0;return!1},t.prototype.annotationType=function(){return null},t.prototype.subTypes=function(){return[].concat(this._subTypes)},t.prototype.allSubTypes=function(){var e=[];return this.subTypes().forEach(function(t){e.push(t),e=e.concat(t.allSubTypes())}),s.unique(e)},t.prototype.allSuperTypes=function(){if(this._allSupers)return this._allSupers;var e=[];return this.allSuperTypesRecurrent(this,{},e),this._allSupers=s.unique(e),this._allSupers},t.prototype.allSuperTypesRecurrent=function(e,t,n){var r=this;e.superTypes().forEach(function(e){t[e.typeId()]||(n.push(e),t[e.typeId()]=e,r.allSuperTypesRecurrent(e,t,n))})},t.prototype.addSuperType=function(e){e._subTypes.push(this),this._superTypes.push(e)},t.prototype.addRequirement=function(e,t){this._requirements.push(new a.ValueRequirement(e,t))},t.prototype.valueRequirements=function(){return this._requirements},t.prototype.requiredProperties=function(){return this.allProperties().filter(function(e){return e.isRequired()})},t.prototype.printDetails=function(e,n){var r=this;e||(e=""),n||(n={hideProperties:!1,hideSuperTypeProperties:!1,printStandardSuperclasses:!1});var i="  ",a="",o=this.getTypeClassName();a+=e+this.nameId()+"["+o+"]\n";var u=this.properties();u&&u.length>0&&!n.hideProperties&&(a+=e+i+"Properties:\n",u.forEach(function(n){var r="",o=n.range();o instanceof l&&(r+=o.nameId()),o instanceof t&&(r+="[",r+=o.getTypeClassName(),r+="]"),a+=e+i+i+n.nameId()+" : "+r+"\n"}));var p=this.superTypes(),c=p;return p&&!n.printStandardSuperclasses&&(c=s.filter(p,function(e){var n=e instanceof l?e.nameId():"",i=e instanceof t?e.getTypeClassName():"";return!r.isStandardSuperclass(n,i)})),c&&c.length>0&&(a+=e+i+"Super types:\n",c.forEach(function(t){a+=t.printDetails(e+i+i,{hideProperties:n.hideSuperTypeProperties,hideSuperTypeProperties:n.hideSuperTypeProperties,printStandardSuperclasses:n.printStandardSuperclasses})})),a},t.prototype.getTypeClassName=function(){return this.constructor.toString().match(/\w+/g)[1]},t.prototype.isStandardSuperclass=function(e,t){return"TypeDeclaration"===e&&"NodeClass"===t?!0:"ObjectTypeDeclaration"===e&&"NodeClass"===t?!0:"RAMLLanguageElement"===e&&"NodeClass"===t?!0:!1},t.prototype.examples=function(e){return d.exampleFromNominal(this,e)},t.prototype.isGenuineUserDefinedType=function(){return this.buildIn?!1:this.properties()&&this.properties().length>0?!0:this.getFixedFacets()&&Object.keys(this.getFixedFacets()).length>0?!0:this.isTopLevel()&&this.nameId()&&this.nameId().length>0},t.prototype.genuineUserDefinedTypeInHierarchy=function(){if(this.isGenuineUserDefinedType())return this;var e=null,t=this.allSuperTypes();return t.forEach(function(t){!e&&t.isGenuineUserDefinedType()&&(e=t)}),e},t.prototype.hasGenuineUserDefinedTypeInHierarchy=function(){return null!=s.find(this.allSuperTypes(),function(e){var t=e;if(t.uc)return!1;t.uc=!0;try{return e.isGenuineUserDefinedType()}finally{t.uc=!1}})},t.prototype.customProperties=function(){return[].concat(this._customProperties)},t.prototype.allCustomProperties=function(){var e=[];return this.superTypes().forEach(function(t){return e=e.concat(t.allCustomProperties())}),e=e.concat(this.customProperties())},t.prototype.registerCustomProperty=function(e){if(e.domain()!=this)throw new Error("Should be already owned by this");if(-1!=this._customProperties.indexOf(e))throw new Error("Already included");this._customProperties.push(e)},t.prototype.setCustom=function(e){this._isCustom=e},t.prototype.isCustom=function(){return this._isCustom},t.prototype.isUnion=function(){return!1},t.prototype.union=function(){return null},t.prototype.isExternal=function(){return!1},t.prototype.external=function(){return null},t.prototype.isArray=function(){return!1},t.prototype.isObject=function(){if("object"==this.nameId())return!0;for(var e=0,t=this.allSuperTypes();e<t.length;e++){var n=t[e];if(n.isObject())return!0}return!1},t.prototype.array=function(){return null},t.prototype.isValueType=function(){return!1},t.prototype.kind=function(){var e=[];return this.isObject()&&e.push("object"),this.isArray()&&e.push("array"),this.isValueType()&&e.push("value"),this.isUnion()&&e.push("union"),this.isAnnotationType()&&e.push("annotation"),this.isExternal()&&e.push("external"),e},t.prototype.isBuiltIn=function(){return this.buildIn},t.prototype.setBuiltIn=function(e){this.buildIn=e},t.prototype.isTopLevel=function(){return this.getExtra(o.DEFINED_IN_TYPES_EXTRA)||this.getExtra(o.TOP_LEVEL_EXTRA)?!0:!1},t.prototype.isUserDefined=function(){return this.getExtra(o.USER_DEFINED_EXTRA)&&!this.buildIn},t.prototype.putExtra=function(e,t){var n=this.getExtraAdapter();n&&n.putExtra(e,t)},t.prototype.getExtra=function(e){var t=this.getExtraAdapter();return t?t.getExtra(e):null},t.prototype.getExtraAdapter=function(){if(this.getAdapters()){var e=s.find(this.getAdapters(),function(e){return e.getExtra&&"function"==typeof e.getExtra&&e.putExtra&&"function"==typeof e.putExtra?!0:void 0});return e}return null},t}(l);t.AbstractType=h;var y=function(e){function t(t,n,r,i){void 0===n&&(n=null),void 0===r&&(r=""),void 0===i&&(i=""),e.call(this,t,n,r)}return i(t,e),t.prototype.hasStructure=function(){return!1},t.prototype.hasValueTypeInHierarchy=function(){return!0},t.prototype.isValueType=function(){return!0},t.prototype.isUnionType=function(){return!1},t.prototype.isObject=function(){return!1},t}(h);t.ValueType=y;var v=function(e){function t(){e.apply(this,arguments),this._properties=[]}return i(t,e),t.prototype.hasStructure=function(){return!0},t.prototype.propertyIndex=function(e){for(var t=this.properties(),n=0;n<t.length;n++)if(t[n].nameId()==e)return n;return-1},t.prototype.addProperty=function(e,t){return new g(e).withDomain(this).withRange(t)},t.prototype.allPropertyIndex=function(e){for(var t=this.allProperties(),n=0;n<t.length;n++)if(t[n].nameId()==e)return n;return-1},t.prototype.properties=function(){return[].concat(this._properties)},t.prototype.registerProperty=function(e){if(e.domain()!=this)throw new Error("Should be already owned by this");if(-1!=this._properties.indexOf(e))throw new Error("Already included");this._properties.push(e)},t}(h);t.StructuredType=v;var g=function(e){function t(){e.apply(this,arguments),this._keyShouldStartFrom=null,this._isRequired=!1,this._isMultiValue=!1,this._descriminates=!1,this._defaultBooleanValue=null,this._defaultIntegerValue=null}return i(t,e),t.prototype.withMultiValue=function(e){return void 0===e&&(e=!0),this._isMultiValue=e,this},t.prototype.withDescriminating=function(e){return this._descriminates=e,this},t.prototype.withRequired=function(e){return this._isRequired=e,this},t.prototype.isRequired=function(){return this._isRequired},t.prototype.withKeyRestriction=function(e){return this._keyShouldStartFrom=e,this},t.prototype.withDomain=function(e,t){return void 0===t&&(t=!1),this._ownerClass=e,t?e.registerCustomProperty(this):e.registerProperty(this),this},t.prototype.setDefaultVal=function(e){return this._defaultValue=e,this},t.prototype.setDefaultBooleanVal=function(e){return this._defaultBooleanValue=e,this},t.prototype.setDefaultIntegerVal=function(e){return this._defaultIntegerValue=e,this},t.prototype.defaultValue=function(){return null!=this._defaultValue?this._defaultValue:null!=this._defaultBooleanValue?this._defaultBooleanValue:null!=this._defaultIntegerValue?this._defaultIntegerValue:null},t.prototype.isPrimitive=function(){return!1},t.prototype.withRange=function(e){return this._nodeRange=e,this},t.prototype.isValueProperty=function(){return this._nodeRange.hasValueTypeInHierarchy()},t.prototype.enumOptions=function(){return this._enumOptions&&"string"==typeof this._enumOptions?[this._enumOptions+""]:this._enumOptions},t.prototype.keyPrefix=function(){return this._keyShouldStartFrom},t.prototype.withEnumOptions=function(e){return this._enumOptions=e,this},t.prototype.withKeyRegexp=function(e){return this._keyRegexp=e,this},t.prototype.getKeyRegexp=function(){return this._keyRegexp},t.prototype.matchKey=function(e){if(null==e)return!1;if(null!=this._groupName)return this._groupName==e;if(null!=this._keyShouldStartFrom&&0==e.indexOf(this._keyShouldStartFrom))return!0;if(this._enumOptions&&-1!=this._enumOptions.indexOf(e))return!0;if(this.getKeyRegexp())try{if(new RegExp(this.getKeyRegexp()).test(e))return!0}catch(t){}return!1},t.prototype.getFacetValidator=function(){return this.facetValidator},t.prototype.setFacetValidator=function(e){this.facetValidator=e},t.prototype.domain=function(){return this._ownerClass},t.prototype.range=function(){return this._nodeRange},t.prototype.isMultiValue=function(){return this.range()&&this.range().hasArrayInHierarchy()?!0:this._isMultiValue},t.prototype.isDescriminator=function(){return this._descriminates},t}(l);t.Property=g;var A=function(e){function t(){e.apply(this,arguments)}return i(t,e),t.prototype.key=function(){return null},t.prototype.leftType=function(){return this.left},t.prototype.rightType=function(){return this.right},t.prototype.isUserDefined=function(){return!0},t.prototype.unionInHierarchy=function(){return this},t.prototype.union=function(){return this},t.prototype.hasUnionInHierarchy=function(){return!0},t.prototype.isUnion=function(){return!0},t.prototype.isObject=function(){return this.leftType().isObject()&&this.rightType().isObject()},t.prototype.hasArrayInHierarchy=function(){return this.left&&this.right?this.left.hasArrayInHierarchy()||this.right.hasArrayInHierarchy():this.left?this.left.hasArrayInHierarchy():this.right?this.right.hasArrayInHierarchy():void 0},t}(h);t.Union=A;var S=function(e){function t(){e.apply(this,arguments)}return i(t,e),t.prototype.hasArrayInHierarchy=function(){return!0},t.prototype.isArray=function(){return!0},t.prototype.isObject=function(){return!1},t.prototype.arrayInHierarchy=function(){return this},t.prototype.array=function(){return this},t.prototype.isUserDefined=function(){return!0},t.prototype.componentType=function(){return this.component},t.prototype.setComponent=function(e){this.component=e},t.prototype.key=function(){return null},t}(h);t.Array=S;var T=function(e){function t(){e.apply(this,arguments)}return i(t,e),t.prototype.externalInHierarchy=function(){return this},t.prototype.typeId=function(){return this.schemaString},t.prototype.schema=function(){return this.schemaString},t.prototype.isUserDefined=function(){return!0},t.prototype.hasExternalInHierarchy=function(){return!0},t.prototype.isExternal=function(){return!0},t.prototype.external=function(){return this},t}(v);t.ExternalType=T}).call(t,function(){return this}())},function(e,t,n){"use strict";var r=function(){function e(e,t){this.name=e,this.value=t}return e}();t.ValueRequirement=r},function(e,t,n){"use strict";function r(e,t){o.visit(e,t)}function i(e){return o.serializeToString(e)}function a(e){return o.parse(e)}var o=n(140);t.visit=r,t.serializeToString=i,t.parse=a},function(e,t,n){(function(e){"use strict";function r(e,t){var n=N(t,e),r=y?g.getValue(n):!1;if(r&&r.provider)return r;var i=new T(e,t);return g.setValue(n,i),i}function i(e,t){var n=(N(t,e),y?g.getValue(e):!1);if(n)return n;var r=new b(e,t);return y&&g.setValue(e,r),r}function a(e,t){var n=N(t,e),r=y?g.getValue(n):!1;if(r)return r;try{var i=new T(e,t);return y&&g.setValue(n,i),i}catch(a){try{var i=new b(e,t);return y&&g.setValue(n,i),i}catch(a){return y&&g.setValue(n,new m.ValidationError(d.messageRegistry.CAN_NOT_PARSE_SCHEMA)),null}}}function o(e,t){for(var n=e.getElementsByTagName(t),r=[],i=0;i<n.length;i++){var a=n[i];a.parentNode===e&&r.push(a)}return r}var s=n(139),u=n(139),l=n(143),p=n(145),c=n(146),f=n(186).DOMParser,m=n(98),d=n(98),h=function(){function e(){}return e}();t.ValidationResult=h;var y=!0,v=function(){function e(){this.errors={}}return e.prototype.getValue=function(e){return this.errors[e]},e.prototype.setValue=function(e,t){this.errors[e]=t},e}(),g=new v;e.cleanCache=function(){g=new v};var A=function(){function e(){}return e.prototype.contextPath=function(){return""},e.prototype.normalizePath=function(e){return""},e.prototype.content=function(e){return""},e.prototype.hasAsyncRequests=function(){return!1},e.prototype.resolvePath=function(e,t){return""},e.prototype.isAbsolutePath=function(e){return!1},e.prototype.contentAsync=function(e){var t=this;return{then:function(n){return n(t.content(e))},resolve:function(){return null}}},e.prototype.promiseResolve=function(e){return{then:function(t){return t(e)},resolve:function(){return null}}},e}(),S=function(e,t,n){return"__EXAMPLE_"+e+t+n},T=function(){function e(e,t){if(this.schema=e,this.provider=t,t?this.provider=t:this.provider=new A,!e||0==e.trim().length||"{"!=e.trim().charAt(0))throw new m.ValidationError(d.messageRegistry.INVALID_JSON_SCHEMA);var r;try{var r=JSON.parse(e)}catch(i){throw new m.ValidationError(d.messageRegistry.INVALID_JSON_SCHEMA_DETAILS,{msg:i.message})}if(r){try{var a=n(188);this.setupId(r,this.provider.contextPath());var o=""+r.$schema;-1==o.indexOf("http://json-schema.org/draft-04/")?r=a.v4(r):this.fixRequired(r)}catch(s){throw new m.ValidationError(d.messageRegistry.INVALID_JSON_SCHEMA_DETAILS,{msg:s.message})}delete r.$schema,this.jsonSchema=r}}return e.prototype.fixRequired=function(e){},e.prototype.getType=function(){return"source.json"},e.prototype.validateObject=function(e){this.validate(JSON.stringify(e))},e.prototype.getMissingReferences=function(e,t){var n=this;void 0===t&&(t=!1);var r=[],i=c.getValidator();e.forEach(function(e){return i.setRemoteReference(e.reference,e.content||{})});var a=null;if(this.jsonSchema.id&&"string"==typeof this.jsonSchema.id){a=this.jsonSchema.id;var o=a.indexOf("#");-1!=o&&(a=a.substr(0,o))}try{i.validateSchema(this.jsonSchema)}catch(s){return[]}var r=i.getMissingRemoteReferences(),u=[];return r&&(u=l.filter(r,function(e){return!i.isResourceLoaded(e)&&e!=a})),t?u.map(function(e){return n.provider.normalizePath(e)}):u},e.prototype.getSchemaPath=function(e,t){if(void 0===t&&(t=!1),!e)return"";if(!e.id)return"";var n=e.id.trim();if(n.lastIndexOf("#")!==n.length-1)return n;var r=n.substr(0,n.length-1);return t?this.provider.normalizePath(r):r},e.prototype.patchSchema=function(e){var t=this;if(!e)return e;if(!e.id)return e;var n=e.id.trim();n.lastIndexOf("#")!==n.length-1&&(n+="#",e.id=n);var r=n.substr(0,n.length-1);if(!this.provider.isAbsolutePath(r))return e;r=this.provider.normalizePath(r);var i=[];this.collectRefContainers(e,i),i.forEach(function(e){var n=e.$ref;if("string"==typeof n&&0!==n.indexOf("#")){-1===n.indexOf("#")&&(n+="#");var i=t.provider.resolvePath(r,n);e.$ref=i}})},e.prototype.collectRefContainers=function(e,t){var n=this;Object.keys(e).forEach(function(r){return"$ref"===r?void t.push(e):void(e[r]&&"object"==typeof e[r]&&n.collectRefContainers(e[r],t))})},e.prototype.validate=function(e,t){var r=this;void 0===t&&(t=[]);var i=S(e,this.schema,this.provider.contextPath()),a=g.getValue(i);if(a){if(a instanceof Error)throw a}else{var o=c.getValidator();t.forEach(function(e){return o.setRemoteReference(e.reference,e.content)}),o.validate(JSON.parse(e),this.jsonSchema);var s=o.getMissingRemoteReferences().filter(function(e){return!l.find(t,function(t){return e===t.reference})});if(!s||0===s.length)return void this.acceptErrors(i,o.getLastErrors(),!0);var u=[];s.forEach(function(e){var t,i={reference:e};try{var a=n(188),o=JSON.parse(r.provider.content(e));r.setupId(o,r.provider.normalizePath(e)),t=a.v4(o),delete t.$schema,i.content=t}catch(s){i.error=s}finally{u.push(i)}}),this.provider.hasAsyncRequests()||(u.forEach(function(e){t.push(e)}),this.validate(e,t))}},e.prototype.setupId=function(e,t){if(t&&e){if(e.id)return e.id=e.id.trim(),void(e.id.indexOf("#")<0&&(e.id=e.id+"#"));e.id=t.replace(/\\/g,"/")+"#",this.patchSchema(e)}},e.prototype.acceptErrors=function(e,t,n){if(void 0===n&&(n=!1),t&&t.length>0){var r=t.map(function(e){return e.message+" "+e.params}).join(", "),i=new m.ValidationError(d.messageRegistry.CONTENT_DOES_NOT_MATCH_THE_SCHEMA,{msg:r});if(i.errors=t,g.setValue(e,i),n)throw i}else g.setValue(e,1)},e.prototype.contentAsync=function(e){var t,r=this,i=n(188),a=this.provider.contentAsync(e);if(!a)return this.provider.promiseResolve({reference:e,content:null,error:new m.ValidationError(d.messageRegistry.REFERENCE_NOT_FOUND,{ref:e})});var o=a.then(function(n){var a={reference:e};try{var o=JSON.parse(n);r.setupId(o,r.provider.normalizePath(e)),t=i.v4(o),delete t.$schema,a.content=t}catch(s){a.error=s}return a});return o},e}();t.JSONSchemaObject=T;var E=10,b=function(){function e(e,t){if(this.schema=e,this.provider=t,this.extraElementData=null,this.references={},this.contentToResult={},t||(this.provider=new A),"<"!=e.charAt(0))throw new m.ValidationError(d.messageRegistry.INVALID_XML_SCHEMA);this.schemaString=this.handleReferenceElement(e)}return e.prototype.getType=function(){return"text.xml"},e.prototype.validateObject=function(e){if(this.extraElementData){var t=Object.keys(e)[0],n=new m.ValidationError(d.messageRegistry.EXTERNAL_TYPE_ERROR,{typeName:this.extraElementData.requestedName,objectName:t});if(!this.extraElementData.type&&!this.extraElementData.originalName)return void this.acceptErrors("key",[n],!0);if(this.extraElementData.originalName&&t!==this.extraElementData.originalName)return void this.acceptErrors("key",[n],!0);if(this.extraElementData.type){var r=e[t];delete e[t],e[this.extraElementData.name]=r}}this.validate(p.jsonToXml(e))},e.prototype.collectReferences=function(e,t,n){var r,i=this;r=(new f).parseFromString(e);var a=o(r,"xs:schema")[0],s=o(a,"xs:import"),l=o(a,"xs:include"),p=s.concat(l);return p.forEach(function(e){var r=e.getAttribute("schemaLocation");if(r){var a=i.provider.resolvePath(t,r),o=n[a];if(!o){var s,l=Object.keys(n).length,p=i.provider.content(a);try{s=i.collectReferences(p,a,n)}catch(c){s=p}o=new u.XMLSchemaReference(a,l,s),n[a]=o}e.setAttribute("schemaLocation","file_"+o.virtualIndex+".xsd")}}),r.toString()},e.prototype.getMissingReferences=function(){var e,t=this;e=(new f).parseFromString(this.schemaString);var n=o(e,"xs:schema")[0],r=o(n,"xs:import"),i=o(n,"xs:include"),a=r.concat(i),s=[];return a.forEach(function(e){var n=e.getAttribute("schemaLocation");if(n){var r=t.provider.resolvePath(t.provider.contextPath(),n);s.push(r)}}),s},e.prototype.collectReferencesAsync=function(e,t,n){var r,i=this;r=(new f).parseFromString(e);var a=o(r,"xs:schema")[0],s=o(a,"xs:import"),l=o(a,"xs:include"),p=s.concat(l);return Promise.all(p.map(function(e){var r=e.getAttribute("schemaLocation");if(r){var a=i.provider.resolvePath(t,r),o=n[a];return o?(e.setAttribute("schemaLocation","file_"+o.virtualIndex+".xsd"),{}):i.provider.contentAsync(a).then(function(t){return i.collectReferencesAsync(t,a,n).then(function(e){return e},function(e){return t}).then(function(t){var r=Object.keys(n).length;return o=new u.XMLSchemaReference(a,r,t),n[a]=o,e.setAttribute("schemaLocation","file_"+o.virtualIndex+".xsd"),{}})})}return{}})).then(function(e){return Promise.resolve(r.toString())})},e.prototype.loadSchemaReferencesAsync=function(){return this.collectReferencesAsync(this.schemaString,this.provider.contextPath(),{})},e.prototype.validate=function(e){try{var t=this.contentToResult[e];if(t===!1)return;if(t)throw t;var n={},r=this.collectReferences(this.schemaString,this.provider.contextPath(),n),i=new s.XMLValidator(r);if(this.provider.hasAsyncRequests())return;var a=i.validate(e,Object.keys(n).map(function(e){return n[e]}));this.acceptErrors("key",a,!0),this.contentToResult[e]=!1,Object.keys(this.contentToResult).length>E&&(this.contentToResult={})}catch(o){throw this.contentToResult[e]=o,o}},e.prototype.handleReferenceElement=function(e){var t=(new f).parseFromString(e),n=o(t,"xs:schema")[0],r=o(n,"xs:element"),i=l.find(r,function(e){return"true"===e.getAttribute("extraelement")});if(!i)return e;var a={};return a.name=i.getAttribute("name"),a.type=i.getAttribute("type"),a.originalName=i.getAttribute("originalname"),a.requestedName=i.getAttribute("requestedname"),a.type||n.removeChild(i),i.removeAttribute("originalname"),i.removeAttribute("requestedname"),i.removeAttribute("extraelement"),this.extraElementData=a,t.toString()},e.prototype.acceptErrors=function(e,t,n){if(void 0===n&&(n=!1),t&&t.length>0){var r=t.map(function(e){return e.message}).join(", "),i=new m.ValidationError(d.messageRegistry.CONTENT_DOES_NOT_MATCH_THE_SCHEMA,{msg:r});if(i.errors=t,g.setValue(e,i),n)throw i}else;},e}();t.XMLSchemaObject=b,t.getJSONSchema=r;var N=function(e,t){var n="";e&&(n=e.contextPath());var r="__SCHEMA_"+t+n;return r};t.getXMLSchema=i,t.createSchema=a}).call(t,function(){return this}())},function(e,t,n){t.parse=n(148),t.stringify=n(149)},function(e,t,n){"function"==typeof Object.create?e.exports=function(e,t){e.super_=t,e.prototype=Object.create(t.prototype,{constructor:{value:e,enumerable:!1,writable:!0,configurable:!0}})}:e.exports=function(e,t){e.super_=t;var n=function(){};n.prototype=t.prototype,e.prototype=new n,e.prototype.constructor=e}},function(e,t,n){var r=function(){try{return n(177)}catch(e){}}();t=e.exports=n(150),t.Stream=r||t,t.Readable=t,t.Writable=n(151),t.Duplex=n(152),t.Transform=n(153),t.PassThrough=n(154)},function(e,t,n){"use strict";e.exports=n(155)},function(module,exports,__webpack_require__){function Context(){}var indexOf=__webpack_require__(189),Object_keys=function(e){if(Object.keys)return Object.keys(e);var t=[];for(var n in e)t.push(n);return t},forEach=function(e,t){if(e.forEach)return e.forEach(t);for(var n=0;n<e.length;n++)t(e[n],n,e)},defineProp=function(){try{return Object.defineProperty({},"_",{}),function(e,t,n){Object.defineProperty(e,t,{writable:!0,enumerable:!1,configurable:!0,value:n})}}catch(e){return function(e,t,n){e[t]=n}}}(),globals=["Array","Boolean","Date","Error","EvalError","Function","Infinity","JSON","Math","NaN","Number","Object","RangeError","ReferenceError","RegExp","String","SyntaxError","TypeError","URIError","decodeURI","decodeURIComponent","encodeURI","encodeURIComponent","escape","eval","isFinite","isNaN","parseFloat","parseInt","undefined","unescape"];Context.prototype={};var Script=exports.Script=function(e){return this instanceof Script?void(this.code=e):new Script(e)};Script.prototype.runInContext=function(e){if(!(e instanceof Context))throw new TypeError("needs a 'context' argument.");var t=document.createElement("iframe");t.style||(t.style={}),t.style.display="none",document.body.appendChild(t);var n=t.contentWindow,r=n.eval,i=n.execScript;!r&&i&&(i.call(n,"null"),r=n.eval),forEach(Object_keys(e),function(t){n[t]=e[t]}),forEach(globals,function(t){e[t]&&(n[t]=e[t])});var a=Object_keys(n),o=r.call(n,this.code);return forEach(Object_keys(n),function(t){(t in e||-1===indexOf(a,t))&&(e[t]=n[t])}),forEach(globals,function(t){t in e||defineProp(e,t,n[t])}),document.body.removeChild(t),o},Script.prototype.runInThisContext=function(){return eval(this.code)},Script.prototype.runInNewContext=function(e){var t=Script.createContext(e),n=this.runInContext(t);return forEach(Object_keys(t),function(n){e[n]=t[n]}),n},forEach(Object_keys(Script.prototype),function(e){exports[e]=Script[e]=function(t){var n=Script(t);return n[e].apply(n,[].slice.call(arguments,1))}}),exports.createScript=function(e){return exports.Script(e)},exports.createContext=Script.createContext=function(e){var t=new Context;return"object"==typeof e&&forEach(Object_keys(e),function(n){t[n]=e[n]}),t}},function(e,t,n){"use strict";function r(e,t){var n=t?t.endPosition:e.endPosition+1,r={key:e,value:t,startPosition:e.startPosition,endPosition:n,kind:l.MAPPING,parent:null,errors:[]};return r}function i(e,t,n,r){return{errors:[],referencesAnchor:e,value:r,startPosition:t,endPosition:n,kind:l.ANCHOR_REF,parent:null}}function a(e){return void 0===e&&(e=""),{errors:[],startPosition:-1,endPosition:-1,value:e,kind:l.SCALAR,parent:null,doubleQuoted:!1,rawValue:e}}function o(){return{errors:[],startPosition:-1,endPosition:-1,items:[],kind:l.SEQ,parent:null}}function s(){return o()}function u(e){return{errors:[],startPosition:-1,endPosition:-1,mappings:e?e:[],kind:l.MAP,parent:null}}!function(e){e[e.SCALAR=0]="SCALAR",e[e.MAPPING=1]="MAPPING",e[e.MAP=2]="MAP",e[e.SEQ=3]="SEQ",e[e.ANCHOR_REF=4]="ANCHOR_REF",e[e.INCLUDE_REF=5]="INCLUDE_REF"}(t.Kind||(t.Kind={}));var l=t.Kind;t.newMapping=r,t.newAnchorRef=i,t.newScalar=a,t.newItems=o,t.newSeq=s,t.newMap=u},function(e,t,n){"use strict";function r(e){return"undefined"==typeof e||null===e}function i(e){return"object"==typeof e&&null!==e}function a(e){return Array.isArray(e)?e:r(e)?[]:[e]}function o(e,t){var n,r,i,a;if(t)for(a=Object.keys(t),n=0,r=a.length;r>n;n+=1)i=a[n],e[i]=t[i];return e}function s(e,t){var n,r="";for(n=0;t>n;n+=1)r+=e;return r}function u(e){return 0===e&&Number.NEGATIVE_INFINITY===1/e}t.isNothing=r,t.isObject=i,t.toArray=a,t.extend=o,t.repeat=s,t.isNegativeZero=u},function(e,t,n){"use strict";var r=function(){function e(e,t){void 0===t&&(t=null),this.name="YAMLException",this.reason=e,this.mark=t,this.message=this.toString(!1)}return e.prototype.toString=function(e){void 0===e&&(e=!1);var t;return t="JS-YAML: "+(this.reason||"(unknown reason)"),!e&&this.mark&&(t+=" "+this.mark.toString()),t},e}();e.exports=r},function(e,t,n){"use strict";var r=n(115),i=function(){function e(e,t,n,r,i){this.name=e,this.buffer=t,this.position=n,this.line=r,this.column=i}return e.prototype.getSnippet=function(e,t){void 0===e&&(e=0),void 0===t&&(t=75);var n,i,a,o,s;if(!this.buffer)return null;for(e=e||4,t=t||75,n="",i=this.position;i>0&&-1==="\x00\r\n\u2028\u2029".indexOf(this.buffer.charAt(i-1));)if(i-=1,this.position-i>t/2-1){n=" ... ",i+=5;break}for(a="",o=this.position;o<this.buffer.length&&-1==="\x00\r\n\u2028\u2029".indexOf(this.buffer.charAt(o));)if(o+=1,o-this.position>t/2-1){a=" ... ",o-=5;break}return s=this.buffer.slice(i,o),r.repeat(" ",e)+n+s+a+"\n"+r.repeat(" ",e+this.position-i+n.length)+"^"},e.prototype.toString=function(e){void 0===e&&(e=!0);var t,n="";return this.name&&(n+='in "'+this.name+'" '),n+="at line "+(this.line+1)+", column "+(this.column+1),e||(t=this.getSnippet(),t&&(n+=":\n"+t)),n},e}();e.exports=i},function(e,t,n){var r=n(128);e.exports=function(e,t){return r(e,t,".")}},function(e,t,n){var r=n(120),i=n(122);e.exports=function(e,t){if(null==e)return"";for(var n="",a=0;a<e.length;a++){var o=e[a],s=r(o,t);n+=s===o?i(o,t):s}return n}},function(e,t,n){var r={tr:{regexp:/[\u0069]/g,map:{i:"İ"}},az:{regexp:/[\u0069]/g,map:{i:"İ"}},lt:{regexp:/[\u0069\u006A\u012F]\u0307|\u0069\u0307[\u0300\u0301\u0303]/g,map:{"i̇":"I","j̇":"J","į̇":"Į","i̇̀":"Ì","i̇́":"Í","i̇̃":"Ĩ"}}};e.exports=function(e,t){var n=r[t];return e=null==e?"":String(e),n&&(e=e.replace(n.regexp,function(e){return n.map[e]})),e.toUpperCase()}},function(e,t,n){var r=n(128);e.exports=function(e,t){return r(e,t,"/")}},function(e,t,n){var r={tr:{regexp:/\u0130|\u0049|\u0049\u0307/g,map:{"İ":"i",I:"ı","İ":"i"}},az:{regexp:/[\u0130]/g,map:{"İ":"i",I:"ı","İ":"i"}},lt:{regexp:/[\u0049\u004A\u012E\u00CC\u00CD\u0128]/g,map:{I:"i̇",J:"j̇","Į":"į̇","Ì":"i̇̀","Í":"i̇́","Ĩ":"i̇̃"}}};e.exports=function(e,t){var n=r[t];return e=null==e?"":String(e),n&&(e=e.replace(n.regexp,function(e){return n.map[e]})),e.toLowerCase()}},function(e,t,n){var r=n(120),i=n(128);e.exports=function(e,t,n){var a=i(e,t);return n||(a=a.replace(/(\d) (?=\d)/g,"$1_")),a.replace(/ (.)/g,function(e,n){return r(n,t)})}},function(e,t,n){var r=n(120),i=n(128);e.exports=function(e,t){return i(e,t).replace(/^.| ./g,function(e){return r(e,t)})}},function(e,t,n){var r=n(128);e.exports=function(e,t){return r(e,t,"_")}},function(e,t,n){var r=n(123),i=n(133);e.exports=function(e,t){return i(r(e,t),t)}},function(e,t,n){var r=n(120),i=n(125);e.exports=function(e,t){return r(i(e,t),t)}},function(e,t,n){var r=n(122),i=n(159),a=n(160),o=n(161);e.exports=function(e,t,n){function s(e,t,r){return 0===t||t===r.length-e.length?"":n}return null==e?"":(n=n||" ",e=String(e).replace(a,"$1 $2").replace(o,"$1 $2").replace(i,s),r(e,t))}},function(e,t,n){var r=n(128);e.exports=function(e,t){return r(e,t,"-")}},function(e,t,n){var r=n(120);e.exports=function(e,t){return r(e,t)===e}},function(e,t,n){var r=n(122);e.exports=function(e,t){return r(e,t)===e};
},function(e,t,n){var r=n(122);e.exports=function(e,t){return null==e?"":(e=String(e),r(e.charAt(0),t)+e.substr(1))}},function(e,t,n){var r=n(120);e.exports=function(e,t){return null==e?"":(e=String(e),r(e.charAt(0),t)+e.substr(1))}},function(e,t,n){"use strict";var r=n(157),i=new r({include:[n(158)],implicit:[n(166),n(167)],explicit:[n(168),n(169),n(170),n(171)]});e.exports=i},function(e,t,n){"use strict";var r=n(157),i=new r({include:[n(134)],explicit:[n(172),n(173)]});r.DEFAULT=i,e.exports=i},function(e,t,n){var r;r=function(){"use strict";var e=n(181),t={},r={},i=n(182),a=n(183),o=n(184);return e.forEach(function(e){var n,i=parseInt(e.code,10);i.toString()===e.code&&(n=e.phrase.toUpperCase().replace(/[^A-Z]/g,"_"),t[i]=e.phrase,r[n]=e.code)}),{statusCodes:e,statusCodesToPhrases:t,statusPhrasesToCodes:r,methods:i,headers:a,relations:o}}.call(t,n,t,e),!(void 0!==r&&(e.exports=r))},function(e,t,n){"use strict";function r(e,t){if(e.typeKind==a.TypeKind.ARRAY)return t?[]:[r(e.base)[0]+"[]"];if(e.typeKind==a.TypeKind.BASIC){var n=e,i=n.basicName,o=n.nameSpace&&n.nameSpace.trim();return null!=o&&o.length>0&&"RamlWrapper"!=o&&(i=o+"."+i),n.typeArguments&&0!=n.typeArguments.length&&(i+="<"+n.typeArguments.map(function(e){return r(e)}).join(", ")+">"),t?n.nameSpace&&t[n.nameSpace]?[i]:[]:[i]}if(e.typeKind==a.TypeKind.UNION){var s=e,u=[];return s.options.forEach(function(e){return u=u.concat(r(e,t))}),u}return[]}function i(e){return o.getHelperMethods(e)}var a=n(93),o=n(163),s={RamlWrapper:!0},u=function(){function e(e,t,n,r,i){this.originalName=e,this.wrapperMethodName=t,this.returnType=n,this.args=r,this.meta=i}return e.prototype.targetWrappers=function(){var e=!0,t=[];return this.args.forEach(function(n){var i=r(n.type,s);if(0!=i.length)return e&&0==t.length?void(t=t.concat(i)):(t=[],void(e=!1))}),t},e.prototype.callArgs=function(){return this.args.map(function(e){return 0==r(e.type,s).length?e:{name:"this",type:null,optional:!1,defaultValue:void 0}})},e}();t.HelperMethod=u,t.flatten=r,t.getHelperMethods=i},function(e,t,n){"use strict";function r(e){return A.createSourceFile("sample.ts",e,A.ScriptTarget.ES3,!0)}function i(e,n,s){var u=r(e),l={classes:[],aliases:[],enumDeclarations:[],imports:{},name:s};n[s]=l;var p=null;return t.tsm.Matching.visit(u,function(r){if(r.kind==A.SyntaxKind.ModuleDeclaration){var u=r;p=u.name.text}if(r.kind==A.SyntaxKind.ImportEqualsDeclaration){var c=r,f=c.name.text;if("RamlWrapper"==f)return;var m=c.moduleReference,d=m.expression,h=d.text,v=S.resolve(S.dirname(s)+"/",h)+".ts";if(!S.existsSync(v))throw new Error("Path "+h+" resolve to "+v+"do not exists");if(!n[v]){var g=S.readFileSync(v);i(g,n,v)}l.imports[f]=n[v]}if(r.kind==A.SyntaxKind.TypeAliasDeclaration){var T=r;if(T.name){var N=T.name.text,_=y(T.type,s);l.aliases.push({name:N,type:_})}}if(r.kind==A.SyntaxKind.EnumDeclaration){var M=r,w=[];M.members&&M.members.forEach(function(e){w.push(e.name.text)}),M.name&&l.enumDeclarations.push({name:M.name.text,members:w})}var R=r.kind==A.SyntaxKind.InterfaceDeclaration,I=r.kind==A.SyntaxKind.ClassDeclaration;if(R||I){var C=r;if(C){var L={},P=E.classDecl(C.name.text,R);return P.moduleName=p,l.classes.push(P),C.members.forEach(function(t){if(t.kind==A.SyntaxKind.MethodDeclaration){var n=t,r=o(n,e,s);P.methods.push(r)}var i=b.doMatch(t);if(i){var u=a(i,s);if("$"==u.name)P.annotations=u.annotations;else if("$"!=u.name.charAt(0)||"$ref"==u.name)L[u.name]=u,P.fields.push(u);else{var l=u.name.substr(1),p=L[l];if(p)p.annotations=u.annotations;else if("$$"!=u.name){var c=P.annotationOverridings[l];c||(c=[]),P.annotationOverridings[l]=c.concat(u.annotations)}}}}),C.typeParameters&&C.typeParameters.forEach(function(e){P.typeParameters.push(e.name.text),null==e.constraint?P.typeParameterConstraint.push(null):P.typeParameterConstraint.push(e.constraint.typeName.text)}),C.heritageClauses&&C.heritageClauses.forEach(function(e){e.types.forEach(function(t){if(e.token==A.SyntaxKind.ExtendsKeyword)P["extends"].push(y(t,s));else{if(e.token!=A.SyntaxKind.ImplementsKeyword)throw new Error("Unknown token class heritage");P["implements"].push(y(t,s))}})}),t.tsm.Matching.SKIP}}}),l}function a(e,t){return{name:e.name.text,type:y(e.type,t),annotations:"$"==e.name.text.charAt(0)?l(e.initializer):[],valueConstraint:"$"!=e.name.text.charAt(0)?u(e.initializer):null,optional:null!=e.questionToken}}function o(e,t,n){var r=e.name.text,i=t.substring(e.pos,e.end),a=[];e.parameters.forEach(function(e){a.push(s(e,t,n))});var o={returnType:y(e.type,n),name:r,start:e.pos,end:e.end,text:i,arguments:a};return o}function s(e,t,n){var r=t.substring(e.pos,e.end);return{name:e.name.text,start:e.pos,end:e.end,text:r,type:y(e.type,n)}}function u(e){return null==e?null:e.kind==A.SyntaxKind.CallExpression?{isCallConstraint:!0,value:p(e)}:{isCallConstraint:!1,value:c(e)}}function l(e){if(null==e)return[];if(e.kind==A.SyntaxKind.ArrayLiteralExpression){var t=e,n=[];return t.elements.forEach(function(e){n.push(p(e))}),n}throw new Error("Only Array Literals supported now")}function p(e){if(e.kind==A.SyntaxKind.CallExpression){var t=e,n=f(t.expression),r={name:n,arguments:[]};return t.arguments.forEach(function(e){r.arguments.push(c(e))}),r}throw new Error("Only call expressions may be annotations")}function c(e){if(e.kind==A.SyntaxKind.StringLiteral){var t=e;return t.text}if(e.kind==A.SyntaxKind.NoSubstitutionTemplateLiteral){var n=e;return n.text}if(e.kind==A.SyntaxKind.ArrayLiteralExpression){var r=e,i=[];return r.elements.forEach(function(e){i.push(c(e))}),i}if(e.kind==A.SyntaxKind.TrueKeyword)return!0;if(e.kind==A.SyntaxKind.PropertyAccessExpression){var a=e;return c(a.expression)+"."+c(a.name)}if(e.kind==A.SyntaxKind.Identifier){var o=e;return o.text}if(e.kind==A.SyntaxKind.FalseKeyword)return!1;if(e.kind==A.SyntaxKind.NumericLiteral){var s=e;return Number(s.text)}if(e.kind==A.SyntaxKind.BinaryExpression){var u=e;if(u.operatorToken.kind=A.SyntaxKind.PlusToken)return c(u.left)+c(u.right)}throw new Error("Unknown value in annotation")}function f(e){if(e.kind==A.SyntaxKind.Identifier)return e.text;if(e.kind==A.SyntaxKind.PropertyAccessExpression){var t=e;return f(t.expression)+"."+f(t.name)}throw new Error("Only simple identifiers are supported now")}function m(e,t){var n=e.indexOf("."),r=-1!=n?e.substring(0,n):"",i=-1!=n?e.substring(n+1):e;return{typeName:e,nameSpace:r,basicName:i,typeKind:T.TypeKind.BASIC,typeArguments:[],modulePath:t}}function d(e){return{base:e,typeKind:T.TypeKind.ARRAY}}function h(e){return{options:e,typeKind:T.TypeKind.UNION}}function y(e,t){if(null==e)return null;if(e.kind==A.SyntaxKind.StringKeyword)return m("string",null);if(e.kind==A.SyntaxKind.NumberKeyword)return m("number",null);if(e.kind==A.SyntaxKind.BooleanKeyword)return m("boolean",null);if(e.kind==A.SyntaxKind.AnyKeyword)return m("any",null);if(e.kind==A.SyntaxKind.VoidKeyword)return m("void",null);if(e.kind==A.SyntaxKind.TypeReference){var n=e,r=m(g(n.typeName),t);return n.typeArguments&&n.typeArguments.forEach(function(e){r.typeArguments.push(y(e,t))}),r}if(e.kind==A.SyntaxKind.ArrayType){var i=e;return d(y(i.elementType,t))}if(e.kind==A.SyntaxKind.UnionType){var a=e;return h(a.types.map(function(e){return y(e,t)}))}if(e.kind==A.SyntaxKind.ExpressionWithTypeArguments){var o=e,r=m(v(o.expression),t);return o.typeArguments&&o.typeArguments.forEach(function(e){r.typeArguments.push(y(e,t))}),r}throw new Error("Case not supported: "+e.kind)}function v(e){return e.name?e.name.text:e.text}function g(e){if(e.kind==A.SyntaxKind.Identifier)return e.text;var t=e;return g(t.left)+"."+g(t.right)}var A=n(156);t.tsm=n(164),t.helperMethodExtractor=n(163);var S=n(165),T=n(93),E=n(93),b=t.tsm.Matching.field();t.parseStruct=i,t.parseArg=c,t.buildType=y},function(e,t,n){e.exports=__WEBPACK_EXTERNAL_MODULE_139__},function(e,t,n){"use strict";function r(e,t,n,r){void 0===n&&(n=null),void 0===r&&(r=null);try{var i=e.trim();if(i.length>0){var o="{"==i.charAt(0);if(o||"<"==i.charAt(0)&&i.length>1&&"<"!=i.charAt(1))return new c.ExternalType("",i,o,n,r);var s=p.parse(e),u=a(s,t);return u}return c.derive(e,[c.STRING])}catch(l){return c.derive(e,[c.UNKNOWN])}}function i(e,t){for(;e>0;){var n=c.derive("",[c.ARRAY]);n.addMeta(new f.ComponentShouldBeOfType(t)),t=n,e--}return t}function a(e,t){if("union"==e.type){var n=e;return c.union("",[a(n.first,t),a(n.rest,t)])}if("parens"==e.type){var r=e,o=a(r.expr,t);return i(r.arr,o)}var s=e;if("?"==s.value.charAt(s.value.length-1)){var u=t.get(s.value.substr(0,s.value.length-1));u||(u=c.derive(s.value,[c.UNKNOWN])),u=c.union(s.value,[u,c.NIL]);var l=s.arr;return i(l,u)}var u=t.get(s.value);u||(u=c.derive(s.value,[c.UNKNOWN]));var l=s.arr;return i(l,u)}function o(e){if(e.isSubTypeOf(c.ARRAY)){var t=e.oneMeta(f.ComponentShouldBeOfType);return t?t.value().isUnion()?"("+o(t.value())+")[]":o(t.value())+"[]":"array"}if(e instanceof c.UnionType){var n=e;return n.options().map(function(e){return o(e)}).join(" | ")}return e.isAnonymous()&&e.isEmpty()?e.superTypes().map(function(e){return o(e)}).join(" , "):e.name()}function s(e,t){if(t(e),"union"==e.type){var n=e;s(n.first,t),s(n.rest,t)}else if("parens"==e.type){var r=e;s(r.expr,t)}}function u(e){var t,n=0;if("name"==e.type){var r=e;t=r.value,n=r.arr}else if("union"==e.type){var i=e;t=u(i.first)+" | "+u(i.rest)}else if("parens"==e.type){var a=e;t="("+u(a.expr)+")",n=a.arr}for(;--n>=0;)t+="[]";return t}function l(e){return p.parse(e)}var p=n(178),c=n(98),f=n(102);t.parseToType=r,t.storeToString=o,t.visit=s,t.serializeToString=u,t.parse=l},function(e,t,n){"use strict";function r(e){var t=e.oneMeta(l.Example);if(t)return t.example();if(e.getExtra(f))return null;e.putExtra(f,!0);try{var n=e.oneMeta(l.Examples);if(n){var i=n.examples();if(i&&i.length>0)return i[0]}var a=e.oneMeta(l.Default);if(a)return a.value();if(e.isObject()){var o={};return e.meta().forEach(function(e){if(e instanceof c.PropertyIs){var t=e,n=r(t.value());o[t.propertyName()]=n}}),e.superTypes().forEach(function(e){if(e.oneMeta(l.Example)||e.oneMeta(l.Examples)){var t=r(e);t&&"object"==typeof t&&Object.keys(t).forEach(function(e){o[e]=t[e]})}}),o}if(e.isArray()){var s=e.oneMeta(p.ComponentShouldBeOfType),u=[];return s&&u.push(r(s.value())),u}return e.isUnion()?r(e.typeFamily()[0]):e.isNumber()?1:e.isBoolean()?!0:"some value"}finally{e.putExtra(f,!1)}}function i(e,t){var n=e[t];return null!=n&&"object"==typeof n?n.value:n}function a(e){var t=[];if(!e||"object"!=typeof e)return t;for(var n=0,r=Object.keys(e).filter(function(e){return e.length>0&&"("==e.charAt(0)&&")"==e.charAt(e.length-1)});n<r.length;n++){var i=r[n],a=i.substring(1,i.length-1),o=e[i],s=new l.Annotation(a,o);t.push(s)}return t}function o(e){var t=[],n=e.oneMeta(l.Examples);if(n){var r=n.value();if(r&&"object"==typeof r){var i;Object.keys(r).forEach(function(e){var a=Array.isArray(r)?null:e,o=r[e],s=d({asXMLString:function(){return i||(i=n.asXMLStrings()),i[e]}},o,a);t.push(s)})}}var a=e.oneMeta(l.Example);if(a){var o=a.example();null!=o&&t.push(d(a,a.value(),void 0,!0))}return t}function s(e,t){var n=e.getAdapter(u.InheritedType);if(n){var i=o(n);if(i&&i.length>0)return i;if(t&&e.isUserDefined()&&!e.isGenuineUserDefinedType()&&e.genuineUserDefinedTypeInHierarchy()){var a=e.genuineUserDefinedTypeInHierarchy(),s=a.getAdapter(u.InheritedType);if(s){var l=o(s);if(l&&l.length>0)return l}}}return n?[new m(r(n),void 0,void 0,void 0,!1,void 0,void 0,!0)]:[]}var u=n(98),l=n(103),p=n(102),c=n(102),f="exampleCalculation";t.example=r;var m=function(){function e(e,t,n,r,i,a,o,s){void 0===t&&(t=void 0),void 0===n&&(n=void 0),void 0===r&&(r=void 0),void 0===i&&(i=!0),void 0===a&&(a={}),void 0===o&&(o=!1),void 0===s&&(s=!1),this._value=e,this._name=t,this._displayName=n,this._description=r,this._strict=i,this._annotations=a,this._isSingle=o,this._empty=s,this._scalarsAnnotations={}}return e.prototype.isEmpty=function(){return this._empty},e.prototype.isJSONString=function(){return"string"==typeof this._value&&(0==(this._value+"").trim().indexOf("{")||0==(this._value+"").trim().indexOf("["))},e.prototype.isXMLString=function(){return"string"==typeof this._value&&0==(this._value+"").trim().indexOf("<")},e.prototype.asXMLString=function(){return this.isXMLString()?this._value:this._owner?this._owner.asXMLString():null},e.prototype.isYAML=function(){return"string"==typeof this._value?!(this.isJSONString()||this.isXMLString()):!0},e.prototype.asString=function(){return"string"==typeof this._value?""+this._value:this.expandAsString()},e.prototype.asJSON=function(){if(this.isJSONString())try{return JSON.parse(this._value)}catch(e){return null}return this.isYAML()?this._value:this.expandAsString()},e.prototype.original=function(){return this._value},e.prototype.expandAsString=function(){return JSON.stringify(this.expandAsJSON(),null,2)},e.prototype.expandAsJSON=function(){return this._value},e.prototype.isSingle=function(){return this._isSingle},e.prototype.strict=function(){return this._strict},e.prototype.description=function(){return this._description},e.prototype.displayName=function(){return this._displayName},e.prototype.annotations=function(){return this._annotations},e.prototype.name=function(){return this._name},e.prototype.scalarsAnnotations=function(){return this._scalarsAnnotations},e.prototype.registerScalarAnnotatoion=function(e,t){var n=this._scalarsAnnotations[t];n||(n={},this._scalarsAnnotations[t]=n),n[e.facetName()]=e},e}(),d=function(e,t,n,r){void 0===n&&(n=null),void 0===r&&(r=!1);var o;if(null!=t){var s=t.value;if(s){var u=i(t,"displayName"),l=i(t,"description"),p=i(t,"strict"),c={};a(t).forEach(function(e){c[e.facetName()]=e}),o=new m(s,n,u,l,p,c,r);for(var f=0,d=a(t.displayName);f<d.length;f++){var h=d[f];o.registerScalarAnnotatoion(h,"displayName")}for(var y=0,v=a(t.description);y<v.length;y++){var h=v[y];o.registerScalarAnnotatoion(h,"description")}for(var g=0,A=a(t.strict);g<A.length;g++){var h=A[g];o.registerScalarAnnotatoion(h,"strict")}}else s=t,o=new m(s,n,void 0,void 0,!0,void 0,r)}return o&&(o._owner=e),o};t.exampleFromNominal=s},function(e,t,n){"use strict";function r(e){return a(e,"YYYY-MM-DD")}function i(e){return a("11 "+e.trim(),"YY HH:mm:ss")}function a(e,t){if(!s.isValid(e,t))return!1;var n=s.parse(e,t,!1),r=s.format(n,t,!1);return r.trim()==e.trim()}var o=this&&this.__extends||function(e,t){function n(){this.constructor=e}for(var r in t)t.hasOwnProperty(r)&&(e[r]=t[r]);e.prototype=null===t?Object.create(t):(n.prototype=t.prototype,new n)},s=n(202),u=n(98),l=u.messageRegistry,p=function(e){function t(){e.apply(this,arguments)}return o(t,e),t.prototype.check=function(e){return"string"==typeof e&&r(e)?u.ok():u.error(l.INVALID_DATEONLY,this)},t.prototype.requiredType=function(){return u.STRING},t.prototype.value=function(){return!0},t.prototype.facetName=function(){return"should be date-only"},t}(u.GenericTypeOf);t.DateOnlyR=p;var c=function(e){function t(){e.apply(this,arguments)}return o(t,e),t.prototype.check=function(e){if("string"==typeof e){var t=/^([0-9][0-9]:[0-9][0-9]:[0-9][0-9])(.[0-9]+)?$/,n=e.match(t);if(!n)return u.error(l.INVALID_TIMEONLY,this);var r=n[1];return i(r)?u.ok():u.error(l.INVALID_TIMEONLY,this)}return u.error(l.INVALID_TIMEONLY,this)},t.prototype.requiredType=function(){return u.STRING},t.prototype.value=function(){return!0},t.prototype.facetName=function(){return"should be time-only"},t}(u.GenericTypeOf);t.TimeOnlyR=c;var f=function(e){function t(){e.apply(this,arguments)}return o(t,e),t.prototype.check=function(e){if("string"==typeof e){var t=/^(\d{4}-\d{2}-\d{2})T([0-9][0-9]:[0-9][0-9]:[0-9][0-9])(.[0-9]+)?$/,n=e.match(t);if(!n||n.length<3)return u.error(l.INVALID_DATETIMEONLY,this);var a=n[1],o=n[2];return r(a)&&i(o)?u.ok():u.error(l.INVALID_DATETIMEONLY,this)}return u.error(l.INVALID_DATETIMEONLY,this)},t.prototype.requiredType=function(){return u.STRING},t.prototype.value=function(){return!0},t.prototype.facetName=function(){return"should be datetime-only"},t}(u.GenericTypeOf);t.DateTimeOnlyR=f;var m=/(Mon|Tue|Wed|Thu|Fri|Sat|Sun)\,[ ]+\d{2}[ ]+(Jan|Feb|Mar|Apr|May|Jun|Jul|Aug|Sep|Oct|Nov|Dec)[ ]+\d{4}[ ]+\d{2}:\d{2}:\d{2}[ ]+GMT/,d=/(Monday|Tuesday|Wednesday|Thursday|Friday|Saturday|Sunday)\,[ ]+\d{2}-(Jan|Feb|Mar|Apr|May|Jun|Jul|Aug|Sep|Oct|Nov|Dec)-\d{2}[ ]+\d{2}:\d{2}:\d{2}[ ]+GMT/,h=/(Mon|Tue|Wed|Thu|Fri|Sat|Sun)\,[ ]+(Jan|Feb|Mar|Apr|May|Jun|Jul|Aug|Sep|Oct|Nov|Dec)[ ]+\d{1,2}[ ]+\d{2}:\d{2}:\d{2}[ ]+GMT/,y=/^(\d{4}-\d{2}-\d{2})T(\d{2}:\d{2}:\d{2})(?:\.\d{1,3})?((?:[\+\-]\d{2}:\d{2})|Z)$/,v=function(e){function t(){e.apply(this,arguments)}return o(t,e),t.prototype.check=function(e){var t=u.VALIDATED_TYPE,n=!1;if(t.allFacets().forEach(function(e){"format"==e.facetName()&&"rfc2616"===e.value()&&(n=!0)}),"string"==typeof e){if(!n){var a=e.match(y);if(!a||a.length<3)return u.error(l.INVALID_RFC3339,this);var o=a[1],s=a[2];return r(o)&&i(s)?u.ok():u.error(l.INVALID_RFC3339,this)}return e.match(m)||e.match(d)||e.match(h)?u.ok():u.error(l.INVALID_RFC2616,this)}return u.error(l.INVALID_DATTIME,this)},t.prototype.requiredType=function(){return u.STRING},t.prototype.value=function(){return!0},t.prototype.facetName=function(){return"should be datetime-only"},t}(u.GenericTypeOf);t.DateTimeR=v},function(e,t,n){"use strict";function r(e,t){return o.find(e,t)}function i(e,t){return o.filter(e,t)}function a(e){return o.unique(e)}var o=n(187);t.find=r,t.filter=i,t.unique=a},function(e,t,n){"use strict";function r(e,t,n,r){void 0===n&&(n=0),void 0===r&&(r=!0);for(var i="<"+e,a=0;n>a;a++)i="    "+i;return t&&Object.keys(t).length>0&&Object.keys(t).forEach(function(e){"string"==typeof t[e]&&(i=i+" "+e+'="'+t[e]+'"')}),i=i+">"+(r?"\n":"")}function i(e,t){void 0===t&&(t=0);for(var n="</"+e,r=0;t>r&&r>-1;r++)n="    "+n;var n=(t>-1?"\n":"")+n+">\n";return n}function a(e,t){t=m(t);var n=I(t),a=E(t),s=r(n,o(e,a)),u={};if(u[n]=e,t.isArray()){t.meta().filter(function(e){return e instanceof x.ComponentShouldBeOfType})[0];s+=p(u,t,1,!0)}else s+=l(e,a,1);var s=s+i(n);return s}function o(e,t){var n={},r=D.filter(t,function(e){return C(e.value()).attribute});return r.forEach(function(t){var r=t.propId(),i=R(t);e[r]&&(n[i]=e[r].toString())}),n}function s(e,t,n){var a=Object.keys(e)[0],p=e[a],c=null;if(t.isScalar()){var f=E(t);c=r(a,o(p,f),n,!t.isScalar())+p.toString()}else{if(t.isUnion())return s(e,u(p,t),n);var f=E(t);c=r(a,o(p,f),n,!t.isScalar())+l(p,f,n+1)}return c+=i(a,t.isScalar()?-1:n)}function u(e,t){var n=t.typeFamily(),r=[],i=null;return n.forEach(function(t){var n=a(e,t);if(n){var i=c(n,t);if(i){var o=f(i);r.push({type:t,errors:o&&o.length||0})}}}),i=r.length>0?r[0]:{type:n[0]},r.forEach(function(e){e.errors<i.errors&&(i=e)}),i.type}function l(e,t,n){var r=D.filter(t,function(e){return!C(e.value()).attribute}),i="";return r.forEach(function(t){var r=R(t),a=t.propId(),o={};o[r]=e[a],i+=t.value().isArray()?p(o,t.value(),n):e[a]||""===e[a]?s(o,t.value(),n):""}),i}function p(e,t,n,a){void 0===a&&(a=!1);var o=Object.keys(e)[0],u=e[o],l=C(t),p=a||l.wrapped,c="",f=w(t),m=f&&f.name(),d=n;return p&&!a&&(c=r(o,null,n),d+=1),u&&P(u)&&u.forEach(function(e){var t={};t[p?m:o]=e,c+=s(t,f,d)}),p&&(c+=i(o,n)),c}function c(e,t){var n=null,r={};return r.explicitChildren=!1,r.explicitArray=!1,r.explicitRoot=h(t)||!t.isExternal(),O.parseString(e,r,function(e,t){if(n=t,e)throw new Error}),n=h(t)?n:v(n,m(t))}function f(e){var t=e[F];return delete e[F],t&&0!==t.length?t.map(function(e){return new k.Status(k.Status.ERROR,"",e,{})}):null}function m(e){return e&&d(e)&&e.superTypes()&&0!==e.superTypes().length?1===e.superTypes().length?e.superTypes()[0]:D.find(e.allSuperTypes(),function(e){return"object"===e.name()})||e:e}function d(e){return e&&D.find(B,function(t){return e.name()===t})?!0:!1}function h(e){return y(e)?!0:D.find(e.allSuperTypes(),function(e){return y(e)})?!0:!1}function y(e){return e.isExternal()&&e._content&&"string"==typeof e._content&&0===e._content.trim().indexOf("<")?!0:!1}function v(e,t){var n=Object.keys(e)[0],r=e[n],i=[],a=I(t);a!==n&&i.push('Unexpected root node "'+n+'", "'+a+'" is expected.');var o;if(t.isArray()){var s=[],u=[],l=t.meta().filter(function(e){return e instanceof x.ComponentShouldBeOfType})[0],p=l&&l.value().name();u.push(p),o=_(r,t,i,!0),T(r,i,s,u)}else o=S(r,t.isUnion()?A(r,t):t,i);return o[F]=i,o}function g(e,t){var n,r=[];n=S(e,t,r);var i=t.validateDirect(n,!0,!1).getErrors();return r.length+(i&&i.length)}function A(e,t){var n=[];if(t.typeFamily().forEach(function(t){return n.push({type:t,errors:g(JSON.parse(JSON.stringify(e)),t)})}),0===n.length)return t;var r=n[0];return n.forEach(function(e){e.errors<r.errors&&(r=e)}),r.type}function S(e,t,n){var r={};if(!t)return e;if(t.isScalar())return L(t,e,n);if(t.isUnion())return S(e,A(e,t),n);var i=E(t),a=[],o=[];return b(e,i,a).forEach(function(e){return r[Object.keys(e)[0]]=e[Object.keys(e)[0]]}),N(e,i,o,n).forEach(function(e){return r[Object.keys(e)[0]]=e[Object.keys(e)[0]]}),T(e,n,a,o),r}function T(e,t,n,r,i){if(void 0===i&&(i=!1),"object"==typeof e){e.$||(e.$={}),n.forEach(function(t){delete e.$[t]}),r.forEach(function(t){delete e[t]});var a=Object.keys(e.$);delete e.$;var o=Object.keys(e);a.forEach(function(e){t.push('Unexpected attribute "'+e+'".')}),o.forEach(function(n){t.push('Unexpected element "'+n+'".'),i&&delete e[n]})}}function E(e){return e.meta().filter(function(e){return e instanceof x.PropertyIs}).map(function(e){return e})||[]}function b(e,t,n){var r=e.$;if(!r)return[];var i=D.filter(t,function(e){return C(e.value()).attribute});return i.map(function(e){var t={},i=e.propId(),a=R(e);n.push(a);var o=r[a];return t[i]=L(e.value(),o),null===t[i]?null:t}).filter(function(e){return e})}function N(e,t,n,r){var i=D.filter(t,function(e){return!C(e.value()).attribute});return i.map(function(t){var i={},a=(C(t.value()),t.propId()),o=R(t);n.push(o);var s=e[o];return t.value().isArray()?i[a]=_(e[o],t.value(),r):i[a]=s||""===s?S(s,t.value(),r):null,null===i[a]?null:i}).filter(function(e){return e})}function _(e,t,n,r){void 0===r&&(r=!1);var i=C(t),a=r||i.wrapped,o=w(t),s=o&&o.name();if(a){var u=e;e=e&&e[s],T(u,n,[],[s],!0)}return e?(e=M(e),e=P(e)?e.map(function(e){return S(e,o,n)}):"object"==typeof e&&e||[]):[]}function M(e){return P(e)?e:"object"==typeof e?[e]:[]}function w(e){if(!e||!e.isArray())return null;var t=e.meta().filter(function(e){return e instanceof x.ComponentShouldBeOfType});return t&&t.length>0&&t[0].value()}function R(e){var t=C(e.value()),n=e.propId(),r=t.name||n;return t.namespace&&(r=t.namespace+":"+r),(t.prefix||"")+r}function I(e){var t=C(e),n=e.name();""===n&&e.isUnion()&&(n="object");var r=t.name||n;return(t.prefix||"")+r}function C(e){var t=e.meta().filter(function(e){return e instanceof U.XMLInfo}).map(function(e){return e})[0],n={attribute:!1,wrapped:!1,name:!1,namespace:!1,prefix:!1};if(!t)return n;var r=t.value();return r?(Object.keys(n).forEach(function(e){n[e]=r[e]||n[e]}),n):n}function L(e,t,n){if(void 0===n&&(n=[]),"object"==typeof t){var r=L(e,t._);return delete t._,T(t,n,[],[],!0),r}if(!t&&""!==t.trim())return null;if(e.isNumber()){var i=parseFloat(t);if(!isNaN(i))return i}if(e.isBoolean()){if("true"===t)return!0;if("false"===t)return!1}return"string"==typeof t?t:null}function P(e){return e?"object"==typeof e&&"number"==typeof e.length:!1}var O=n(209),D=n(187),x=n(102),U=n(103),k=n(98),F="@unexpected_root_attributes_and_elements",B=["application/x-www-form-urlencoded","application/json","application/xml","multipart/form-data"];t.serializeToXML=a,t.readObject=c,t.getXmlErrors=f},function(e,t,n){"use strict";function r(e){if(!e)return"";var t=Object.keys(e)[0],n=e[t];if(!n&&""!==n)return"";var i="<"+t,a=n.$||{};return Object.keys(a).forEach(function(e){i=i+" "+e+'="'+a[e]+'"'}),i+=">","string"==typeof n?i+=n:Object.keys(n).forEach(function(e){if("$"!==e)if("object"!=typeof n[e]||n[e].length)if("string"!=typeof n[e]&&n[e]){if("array"==typeof n[e]||n[e].length)for(var t=n[e],a=0;a<t.length;a++){var o=t[a],s={};s[e]=o,i+=r(s)}}else{var s={};s[e]=n[e]||"",i+=r(s)}else{var s={};s[e]=n[e],i+=r(s)}}),i=i+"</"+t+">"}function i(e){return new u(e)}function a(e){var t=e&&Object.keys(e)[0];if(t){var n=e[t];o(n)}return r(e)}function o(e){if(e&&"string"!=typeof e){var t=[];Object.keys(e).forEach(function(n){if("$"!=n)if(0===n.indexOf("@")){var r={key:n,value:e[n]};t.push(r)}else if(s(e[n])){var i=e[n];i.forEach(function(e){return o(e)})}else"string"!=typeof e[n]&&o(e[n])}),e.$||(e.$={});var n=e.$;t.forEach(function(t){delete e[t.key];var r=t.key.substring(1);n[r]=t.value})}}function s(e){return e?"object"==typeof e&&"number"==typeof e.length:!1}var u;try{u=n(139).XMLValidator}catch(l){}if(!u){var p=function(){function e(e){}return e.prototype.validate=function(e,t){return[]},e}();u=p}t.getValidator=i,t.jsonToXml=a},function(e,t,n){"use strict";function r(){return new i}var i;try{i=n(176).JSONValidator}catch(a){}if(!i){var o=function(){function e(){}return e.prototype.setRemoteReference=function(e,t){},e.prototype.validateSchema=function(e){},e.prototype.getMissingRemoteReferences=function(){return[]},e.prototype.isResourceLoaded=function(e){return!0},e.prototype.validate=function(e,t){},e.prototype.getLastErrors=function(){return[]},e}();i=o}t.getValidator=r},function(e,t,n){e.exports=function(e){return e.webpackPolyfill||(e.deprecate=function(){},e.paths=[],e.children=[],e.webpackPolyfill=1),e}},function(e,t,n){var r,i,a,o,s={'"':'"',"\\":"\\","/":"/",b:"\b",f:"\f",n:"\n",r:"\r",t:"	"},u=function(e){throw{name:"SyntaxError",message:e,at:r,text:a}},l=function(e){return e&&e!==i&&u("Expected '"+e+"' instead of '"+i+"'"),i=a.charAt(r),r+=1,i},p=function(){var e,t="";for("-"===i&&(t="-",l("-"));i>="0"&&"9">=i;)t+=i,l();if("."===i)for(t+=".";l()&&i>="0"&&"9">=i;)t+=i;if("e"===i||"E"===i)for(t+=i,l(),("-"===i||"+"===i)&&(t+=i,l());i>="0"&&"9">=i;)t+=i,l();return e=+t,isFinite(e)?e:void u("Bad number")},c=function(){var e,t,n,r="";if('"'===i)for(;l();){if('"'===i)return l(),r;if("\\"===i)if(l(),"u"===i){for(n=0,t=0;4>t&&(e=parseInt(l(),16),isFinite(e));t+=1)n=16*n+e;r+=String.fromCharCode(n)}else{if("string"!=typeof s[i])break;r+=s[i]}else r+=i}u("Bad string")},f=function(){for(;i&&" ">=i;)l()},m=function(){switch(i){case"t":return l("t"),l("r"),l("u"),l("e"),!0;case"f":return l("f"),l("a"),l("l"),l("s"),l("e"),!1;case"n":return l("n"),l("u"),l("l"),l("l"),null}u("Unexpected '"+i+"'")},d=function(){var e=[];if("["===i){if(l("["),f(),"]"===i)return l("]"),e;for(;i;){if(e.push(o()),f(),"]"===i)return l("]"),e;l(","),f()}}u("Bad array")},h=function(){var e,t={};if("{"===i){if(l("{"),f(),"}"===i)return l("}"),t;for(;i;){if(e=c(),f(),l(":"),Object.hasOwnProperty.call(t,e)&&u('Duplicate key "'+e+'"'),t[e]=o(),f(),"}"===i)return l("}"),t;l(","),f()}}u("Bad object")};o=function(){switch(f(),i){case"{":return h();case"[":return d();case'"':return c();case"-":return p();default:return i>="0"&&"9">=i?p():m()}},e.exports=function(e,t){var n;return a=e,r=0,i=" ",n=o(),f(),i&&u("Syntax error"),"function"==typeof t?function s(e,n){var r,i,a=e[n];if(a&&"object"==typeof a)for(r in a)Object.prototype.hasOwnProperty.call(a,r)&&(i=s(a,r),void 0!==i?a[r]=i:delete a[r]);return t.call(e,n,a)}({"":n},""):n}},function(e,t,n){function r(e){return u.lastIndex=0,u.test(e)?'"'+e.replace(u,function(e){var t=l[e];return"string"==typeof t?t:"\\u"+("0000"+e.charCodeAt(0).toString(16)).slice(-4)})+'"':'"'+e+'"'}function i(e,t){var n,u,l,p,c,f=a,m=t[e];switch(m&&"object"==typeof m&&"function"==typeof m.toJSON&&(m=m.toJSON(e)),"function"==typeof s&&(m=s.call(t,e,m)),typeof m){case"string":return r(m);case"number":return isFinite(m)?String(m):"null";case"boolean":case"null":return String(m);case"object":if(!m)return"null";if(a+=o,c=[],"[object Array]"===Object.prototype.toString.apply(m)){for(p=m.length,n=0;p>n;n+=1)c[n]=i(n,m)||"null";return l=0===c.length?"[]":a?"[\n"+a+c.join(",\n"+a)+"\n"+f+"]":"["+c.join(",")+"]",a=f,l}if(s&&"object"==typeof s)for(p=s.length,n=0;p>n;n+=1)u=s[n],"string"==typeof u&&(l=i(u,m),l&&c.push(r(u)+(a?": ":":")+l));else for(u in m)Object.prototype.hasOwnProperty.call(m,u)&&(l=i(u,m),l&&c.push(r(u)+(a?": ":":")+l));return l=0===c.length?"{}":a?"{\n"+a+c.join(",\n"+a)+"\n"+f+"}":"{"+c.join(",")+"}",a=f,l}}var a,o,s,u=/[\\\"\x00-\x1f\x7f-\x9f\u00ad\u0600-\u0604\u070f\u17b4\u17b5\u200c-\u200f\u2028-\u202f\u2060-\u206f\ufeff\ufff0-\uffff]/g,l={"\b":"\\b","	":"\\t","\n":"\\n","\f":"\\f","\r":"\\r",'"':'\\"',"\\":"\\\\"};e.exports=function(e,t,n){var r;if(a="",o="","number"==typeof n)for(r=0;n>r;r+=1)o+=" ";else"string"==typeof n&&(o=n);if(s=t,t&&"function"!=typeof t&&("object"!=typeof t||"number"!=typeof t.length))throw new Error("JSON.stringify");return i("",{"":e})}},function(e,t,n){(function(t){"use strict";function r(e,t){D=D||n(152),e=e||{},this.objectMode=!!e.objectMode,t instanceof D&&(this.objectMode=this.objectMode||!!e.readableObjectMode);var r=e.highWaterMark,i=this.objectMode?16:16384;this.highWaterMark=r||0===r?r:i,this.highWaterMark=~~this.highWaterMark,this.buffer=[],this.length=0,this.pipes=null,this.pipesCount=0,this.flowing=null,this.ended=!1,this.endEmitted=!1,this.reading=!1,this.sync=!0,this.needReadable=!1,this.emittedReadable=!1,this.readableListening=!1,this.resumeScheduled=!1,this.defaultEncoding=e.defaultEncoding||"utf8",this.ranOut=!1,this.awaitDrain=0,this.readingMore=!1,this.decoder=null,this.encoding=null,e.encoding&&(O||(O=n(206).StringDecoder),this.decoder=new O(e.encoding),this.encoding=e.encoding)}function i(e){return D=D||n(152),this instanceof i?(this._readableState=new r(e,this),this.readable=!0,e&&"function"==typeof e.read&&(this._read=e.read),void R.call(this)):new i(e)}function a(e,t,n,r,i){var a=l(t,n);if(a)e.emit("error",a);else if(null===n)t.reading=!1,p(e,t);else if(t.objectMode||n&&n.length>0)if(t.ended&&!i){var s=new Error("stream.push() after EOF");e.emit("error",s)}else if(t.endEmitted&&i){var s=new Error("stream.unshift() after end event");e.emit("error",s)}else{var u;!t.decoder||i||r||(n=t.decoder.write(n),u=!t.objectMode&&0===n.length),i||(t.reading=!1),u||(t.flowing&&0===t.length&&!t.sync?(e.emit("data",n),e.read(0)):(t.length+=t.objectMode?1:n.length,i?t.buffer.unshift(n):t.buffer.push(n),t.needReadable&&c(e))),m(e,t)}else i||(t.reading=!1);return o(t)}function o(e){return!e.ended&&(e.needReadable||e.length<e.highWaterMark||0===e.length)}function s(e){return e>=x?e=x:(e--,e|=e>>>1,e|=e>>>2,e|=e>>>4,e|=e>>>8,e|=e>>>16,e++),e}function u(e,t){return 0===t.length&&t.ended?0:t.objectMode?0===e?0:1:null===e||isNaN(e)?t.flowing&&t.buffer.length?t.buffer[0].length:t.length:0>=e?0:(e>t.highWaterMark&&(t.highWaterMark=s(e)),e>t.length?t.ended?t.length:(t.needReadable=!0,0):e)}function l(e,t){var n=null;return w.isBuffer(t)||"string"==typeof t||null===t||void 0===t||e.objectMode||(n=new TypeError("Invalid non-string/buffer chunk")),n}function p(e,t){if(!t.ended){if(t.decoder){var n=t.decoder.end();n&&n.length&&(t.buffer.push(n),t.length+=t.objectMode?1:n.length)}t.ended=!0,c(e)}}function c(e){var t=e._readableState;t.needReadable=!1,t.emittedReadable||(P("emitReadable",t.flowing),t.emittedReadable=!0,t.sync?_(f,e):f(e))}function f(e){P("emit readable"),e.emit("readable"),A(e)}function m(e,t){t.readingMore||(t.readingMore=!0,_(d,e,t))}function d(e,t){for(var n=t.length;!t.reading&&!t.flowing&&!t.ended&&t.length<t.highWaterMark&&(P("maybeReadMore read 0"),e.read(0),n!==t.length);)n=t.length;t.readingMore=!1}function h(e){return function(){var t=e._readableState;P("pipeOnDrain",t.awaitDrain),t.awaitDrain&&t.awaitDrain--,0===t.awaitDrain&&I(e,"data")&&(t.flowing=!0,A(e))}}function y(e){P("readable nexttick read 0"),e.read(0)}function v(e,t){t.resumeScheduled||(t.resumeScheduled=!0,_(g,e,t))}function g(e,t){t.reading||(P("resume read 0"),e.read(0)),t.resumeScheduled=!1,e.emit("resume"),A(e),t.flowing&&!t.reading&&e.read(0)}function A(e){var t=e._readableState;if(P("flow",t.flowing),t.flowing)do var n=e.read();while(null!==n&&t.flowing)}function S(e,t){var n,r=t.buffer,i=t.length,a=!!t.decoder,o=!!t.objectMode;if(0===r.length)return null;
if(0===i)n=null;else if(o)n=r.shift();else if(!e||e>=i)n=a?r.join(""):1===r.length?r[0]:w.concat(r,i),r.length=0;else if(e<r[0].length){var s=r[0];n=s.slice(0,e),r[0]=s.slice(e)}else if(e===r[0].length)n=r.shift();else{n=a?"":new w(e);for(var u=0,l=0,p=r.length;p>l&&e>u;l++){var s=r[0],c=Math.min(e-u,s.length);a?n+=s.slice(0,c):s.copy(n,u,0,c),c<s.length?r[0]=s.slice(c):r.shift(),u+=c}}return n}function T(e){var t=e._readableState;if(t.length>0)throw new Error("endReadable called on non-empty stream");t.endEmitted||(t.ended=!0,_(E,t,e))}function E(e,t){e.endEmitted||0!==e.length||(e.endEmitted=!0,t.readable=!1,t.emit("end"))}function b(e,t){for(var n=0,r=e.length;r>n;n++)t(e[n],n)}function N(e,t){for(var n=0,r=e.length;r>n;n++)if(e[n]===t)return n;return-1}e.exports=i;var _=n(203),M=n(205),w=n(94).Buffer;i.ReadableState=r;var R,I=(n(204),function(e,t){return e.listeners(t).length});!function(){try{R=n(177)}catch(e){}finally{R||(R=n(204).EventEmitter)}}();var w=n(94).Buffer,C=n(216);C.inherits=n(110);var L=n(180),P=void 0;P=L&&L.debuglog?L.debuglog("stream"):function(){};var O;C.inherits(i,R);var D,D;i.prototype.push=function(e,t){var n=this._readableState;return n.objectMode||"string"!=typeof e||(t=t||n.defaultEncoding,t!==n.encoding&&(e=new w(e,t),t="")),a(this,n,e,t,!1)},i.prototype.unshift=function(e){var t=this._readableState;return a(this,t,e,"",!0)},i.prototype.isPaused=function(){return this._readableState.flowing===!1},i.prototype.setEncoding=function(e){return O||(O=n(206).StringDecoder),this._readableState.decoder=new O(e),this._readableState.encoding=e,this};var x=8388608;i.prototype.read=function(e){P("read",e);var t=this._readableState,n=e;if(("number"!=typeof e||e>0)&&(t.emittedReadable=!1),0===e&&t.needReadable&&(t.length>=t.highWaterMark||t.ended))return P("read: emitReadable",t.length,t.ended),0===t.length&&t.ended?T(this):c(this),null;if(e=u(e,t),0===e&&t.ended)return 0===t.length&&T(this),null;var r=t.needReadable;P("need readable",r),(0===t.length||t.length-e<t.highWaterMark)&&(r=!0,P("length less than watermark",r)),(t.ended||t.reading)&&(r=!1,P("reading or ended",r)),r&&(P("do read"),t.reading=!0,t.sync=!0,0===t.length&&(t.needReadable=!0),this._read(t.highWaterMark),t.sync=!1),r&&!t.reading&&(e=u(n,t));var i;return i=e>0?S(e,t):null,null===i&&(t.needReadable=!0,e=0),t.length-=e,0!==t.length||t.ended||(t.needReadable=!0),n!==e&&t.ended&&0===t.length&&T(this),null!==i&&this.emit("data",i),i},i.prototype._read=function(e){this.emit("error",new Error("not implemented"))},i.prototype.pipe=function(e,n){function r(e){P("onunpipe"),e===c&&a()}function i(){P("onend"),e.end()}function a(){P("cleanup"),e.removeListener("close",u),e.removeListener("finish",l),e.removeListener("drain",y),e.removeListener("error",s),e.removeListener("unpipe",r),c.removeListener("end",i),c.removeListener("end",a),c.removeListener("data",o),v=!0,!f.awaitDrain||e._writableState&&!e._writableState.needDrain||y()}function o(t){P("ondata");var n=e.write(t);!1===n&&(1!==f.pipesCount||f.pipes[0]!==e||1!==c.listenerCount("data")||v||(P("false write response, pause",c._readableState.awaitDrain),c._readableState.awaitDrain++),c.pause())}function s(t){P("onerror",t),p(),e.removeListener("error",s),0===I(e,"error")&&e.emit("error",t)}function u(){e.removeListener("finish",l),p()}function l(){P("onfinish"),e.removeListener("close",u),p()}function p(){P("unpipe"),c.unpipe(e)}var c=this,f=this._readableState;switch(f.pipesCount){case 0:f.pipes=e;break;case 1:f.pipes=[f.pipes,e];break;default:f.pipes.push(e)}f.pipesCount+=1,P("pipe count=%d opts=%j",f.pipesCount,n);var m=(!n||n.end!==!1)&&e!==t.stdout&&e!==t.stderr,d=m?i:a;f.endEmitted?_(d):c.once("end",d),e.on("unpipe",r);var y=h(c);e.on("drain",y);var v=!1;return c.on("data",o),e._events&&e._events.error?M(e._events.error)?e._events.error.unshift(s):e._events.error=[s,e._events.error]:e.on("error",s),e.once("close",u),e.once("finish",l),e.emit("pipe",c),f.flowing||(P("pipe resume"),c.resume()),e},i.prototype.unpipe=function(e){var t=this._readableState;if(0===t.pipesCount)return this;if(1===t.pipesCount)return e&&e!==t.pipes?this:(e||(e=t.pipes),t.pipes=null,t.pipesCount=0,t.flowing=!1,e&&e.emit("unpipe",this),this);if(!e){var n=t.pipes,r=t.pipesCount;t.pipes=null,t.pipesCount=0,t.flowing=!1;for(var i=0;r>i;i++)n[i].emit("unpipe",this);return this}var a=N(t.pipes,e);return-1===a?this:(t.pipes.splice(a,1),t.pipesCount-=1,1===t.pipesCount&&(t.pipes=t.pipes[0]),e.emit("unpipe",this),this)},i.prototype.on=function(e,t){var n=R.prototype.on.call(this,e,t);if("data"===e&&!1!==this._readableState.flowing&&this.resume(),"readable"===e&&!this._readableState.endEmitted){var r=this._readableState;r.readableListening||(r.readableListening=!0,r.emittedReadable=!1,r.needReadable=!0,r.reading?r.length&&c(this,r):_(y,this))}return n},i.prototype.addListener=i.prototype.on,i.prototype.resume=function(){var e=this._readableState;return e.flowing||(P("resume"),e.flowing=!0,v(this,e)),this},i.prototype.pause=function(){return P("call pause flowing=%j",this._readableState.flowing),!1!==this._readableState.flowing&&(P("pause"),this._readableState.flowing=!1,this.emit("pause")),this},i.prototype.wrap=function(e){var t=this._readableState,n=!1,r=this;e.on("end",function(){if(P("wrapped end"),t.decoder&&!t.ended){var e=t.decoder.end();e&&e.length&&r.push(e)}r.push(null)}),e.on("data",function(i){if(P("wrapped data"),t.decoder&&(i=t.decoder.write(i)),(!t.objectMode||null!==i&&void 0!==i)&&(t.objectMode||i&&i.length)){var a=r.push(i);a||(n=!0,e.pause())}});for(var i in e)void 0===this[i]&&"function"==typeof e[i]&&(this[i]=function(t){return function(){return e[t].apply(e,arguments)}}(i));var a=["error","close","destroy","pause","resume"];return b(a,function(t){e.on(t,r.emit.bind(r,t))}),r._read=function(t){P("wrapped _read",t),n&&(n=!1,e.resume())},r},i._fromList=S}).call(t,n(61))},function(e,t,n){(function(t){"use strict";function r(){}function i(e,t,n){this.chunk=e,this.encoding=t,this.callback=n,this.next=null}function a(e,t){I=I||n(152),e=e||{},this.objectMode=!!e.objectMode,t instanceof I&&(this.objectMode=this.objectMode||!!e.writableObjectMode);var r=e.highWaterMark,i=this.objectMode?16:16384;this.highWaterMark=r||0===r?r:i,this.highWaterMark=~~this.highWaterMark,this.needDrain=!1,this.ending=!1,this.ended=!1,this.finished=!1;var a=e.decodeStrings===!1;this.decodeStrings=!a,this.defaultEncoding=e.defaultEncoding||"utf8",this.length=0,this.writing=!1,this.corked=0,this.sync=!0,this.bufferProcessing=!1,this.onwrite=function(e){d(t,e)},this.writecb=null,this.writelen=0,this.bufferedRequest=null,this.lastBufferedRequest=null,this.pendingcb=0,this.prefinished=!1,this.errorEmitted=!1,this.bufferedRequestCount=0,this.corkedRequestsFree=new E(this),this.corkedRequestsFree.next=new E(this)}function o(e){return I=I||n(152),this instanceof o||this instanceof I?(this._writableState=new a(e,this),this.writable=!0,e&&("function"==typeof e.write&&(this._write=e.write),"function"==typeof e.writev&&(this._writev=e.writev)),void w.call(this)):new o(e)}function s(e,t){var n=new Error("write after end");e.emit("error",n),b(t,n)}function u(e,t,n,r){var i=!0;if(!_.isBuffer(n)&&"string"!=typeof n&&null!==n&&void 0!==n&&!t.objectMode){var a=new TypeError("Invalid non-string/buffer chunk");e.emit("error",a),b(r,a),i=!1}return i}function l(e,t,n){return e.objectMode||e.decodeStrings===!1||"string"!=typeof t||(t=new _(t,n)),t}function p(e,t,n,r,a){n=l(t,n,r),_.isBuffer(n)&&(r="buffer");var o=t.objectMode?1:n.length;t.length+=o;var s=t.length<t.highWaterMark;if(s||(t.needDrain=!0),t.writing||t.corked){var u=t.lastBufferedRequest;t.lastBufferedRequest=new i(n,r,a),u?u.next=t.lastBufferedRequest:t.bufferedRequest=t.lastBufferedRequest,t.bufferedRequestCount+=1}else c(e,t,!1,o,n,r,a);return s}function c(e,t,n,r,i,a,o){t.writelen=r,t.writecb=o,t.writing=!0,t.sync=!0,n?e._writev(i,t.onwrite):e._write(i,a,t.onwrite),t.sync=!1}function f(e,t,n,r,i){--t.pendingcb,n?b(i,r):i(r),e._writableState.errorEmitted=!0,e.emit("error",r)}function m(e){e.writing=!1,e.writecb=null,e.length-=e.writelen,e.writelen=0}function d(e,t){var n=e._writableState,r=n.sync,i=n.writecb;if(m(n),t)f(e,n,r,t,i);else{var a=g(n);a||n.corked||n.bufferProcessing||!n.bufferedRequest||v(e,n),r?N(h,e,n,a,i):h(e,n,a,i)}}function h(e,t,n,r){n||y(e,t),t.pendingcb--,r(),S(e,t)}function y(e,t){0===t.length&&t.needDrain&&(t.needDrain=!1,e.emit("drain"))}function v(e,t){t.bufferProcessing=!0;var n=t.bufferedRequest;if(e._writev&&n&&n.next){var r=t.bufferedRequestCount,i=new Array(r),a=t.corkedRequestsFree;a.entry=n;for(var o=0;n;)i[o]=n,n=n.next,o+=1;c(e,t,!0,t.length,i,"",a.finish),t.pendingcb++,t.lastBufferedRequest=null,t.corkedRequestsFree=a.next,a.next=null}else{for(;n;){var s=n.chunk,u=n.encoding,l=n.callback,p=t.objectMode?1:s.length;if(c(e,t,!1,p,s,u,l),n=n.next,t.writing)break}null===n&&(t.lastBufferedRequest=null)}t.bufferedRequestCount=0,t.bufferedRequest=n,t.bufferProcessing=!1}function g(e){return e.ending&&0===e.length&&null===e.bufferedRequest&&!e.finished&&!e.writing}function A(e,t){t.prefinished||(t.prefinished=!0,e.emit("prefinish"))}function S(e,t){var n=g(t);return n&&(0===t.pendingcb?(A(e,t),t.finished=!0,e.emit("finish")):A(e,t)),n}function T(e,t,n){t.ending=!0,S(e,t),n&&(t.finished?b(n):e.once("finish",n)),t.ended=!0,e.writable=!1}function E(e){var t=this;this.next=null,this.entry=null,this.finish=function(n){var r=t.entry;for(t.entry=null;r;){var i=r.callback;e.pendingcb--,i(n),r=r.next}e.corkedRequestsFree?e.corkedRequestsFree.next=t:e.corkedRequestsFree=t}}e.exports=o;var b=n(203),N=!t.browser&&["v0.10","v0.9."].indexOf(t.version.slice(0,5))>-1?setImmediate:b,_=n(94).Buffer;o.WritableState=a;var M=n(216);M.inherits=n(110);var w,R={deprecate:n(210)};!function(){try{w=n(177)}catch(e){}finally{w||(w=n(204).EventEmitter)}}();var _=n(94).Buffer;M.inherits(o,w);var I;a.prototype.getBuffer=function(){for(var e=this.bufferedRequest,t=[];e;)t.push(e),e=e.next;return t},function(){try{Object.defineProperty(a.prototype,"buffer",{get:R.deprecate(function(){return this.getBuffer()},"_writableState.buffer is deprecated. Use _writableState.getBuffer instead.")})}catch(e){}}();var I;o.prototype.pipe=function(){this.emit("error",new Error("Cannot pipe. Not readable."))},o.prototype.write=function(e,t,n){var i=this._writableState,a=!1;return"function"==typeof t&&(n=t,t=null),_.isBuffer(e)?t="buffer":t||(t=i.defaultEncoding),"function"!=typeof n&&(n=r),i.ended?s(this,n):u(this,i,e,n)&&(i.pendingcb++,a=p(this,i,e,t,n)),a},o.prototype.cork=function(){var e=this._writableState;e.corked++},o.prototype.uncork=function(){var e=this._writableState;e.corked&&(e.corked--,e.writing||e.corked||e.finished||e.bufferProcessing||!e.bufferedRequest||v(this,e))},o.prototype.setDefaultEncoding=function(e){if("string"==typeof e&&(e=e.toLowerCase()),!(["hex","utf8","utf-8","ascii","binary","base64","ucs2","ucs-2","utf16le","utf-16le","raw"].indexOf((e+"").toLowerCase())>-1))throw new TypeError("Unknown encoding: "+e);this._writableState.defaultEncoding=e},o.prototype._write=function(e,t,n){n(new Error("not implemented"))},o.prototype._writev=null,o.prototype.end=function(e,t,n){var r=this._writableState;"function"==typeof e?(n=e,e=null,t=null):"function"==typeof t&&(n=t,t=null),null!==e&&void 0!==e&&this.write(e,t),r.corked&&(r.corked=1,this.uncork()),r.ending||r.finished||T(this,r,n)}}).call(t,n(61))},function(e,t,n){"use strict";function r(e){return this instanceof r?(l.call(this,e),p.call(this,e),e&&e.readable===!1&&(this.readable=!1),e&&e.writable===!1&&(this.writable=!1),this.allowHalfOpen=!0,e&&e.allowHalfOpen===!1&&(this.allowHalfOpen=!1),void this.once("end",i)):new r(e)}function i(){this.allowHalfOpen||this._writableState.ended||s(a,this)}function a(e){e.end()}var o=Object.keys||function(e){var t=[];for(var n in e)t.push(n);return t};e.exports=r;var s=n(203),u=n(216);u.inherits=n(110);var l=n(150),p=n(151);u.inherits(r,l);for(var c=o(p.prototype),f=0;f<c.length;f++){var m=c[f];r.prototype[m]||(r.prototype[m]=p.prototype[m])}},function(e,t,n){"use strict";function r(e){this.afterTransform=function(t,n){return i(e,t,n)},this.needTransform=!1,this.transforming=!1,this.writecb=null,this.writechunk=null,this.writeencoding=null}function i(e,t,n){var r=e._transformState;r.transforming=!1;var i=r.writecb;if(!i)return e.emit("error",new Error("no writecb in Transform class"));r.writechunk=null,r.writecb=null,null!==n&&void 0!==n&&e.push(n),i(t);var a=e._readableState;a.reading=!1,(a.needReadable||a.length<a.highWaterMark)&&e._read(a.highWaterMark)}function a(e){if(!(this instanceof a))return new a(e);s.call(this,e),this._transformState=new r(this);var t=this;this._readableState.needReadable=!0,this._readableState.sync=!1,e&&("function"==typeof e.transform&&(this._transform=e.transform),"function"==typeof e.flush&&(this._flush=e.flush)),this.once("prefinish",function(){"function"==typeof this._flush?this._flush(function(e){o(t,e)}):o(t)})}function o(e,t){if(t)return e.emit("error",t);var n=e._writableState,r=e._transformState;if(n.length)throw new Error("calling transform done when ws.length != 0");if(r.transforming)throw new Error("calling transform done when still transforming");return e.push(null)}e.exports=a;var s=n(152),u=n(216);u.inherits=n(110),u.inherits(a,s),a.prototype.push=function(e,t){return this._transformState.needTransform=!1,s.prototype.push.call(this,e,t)},a.prototype._transform=function(e,t,n){throw new Error("not implemented")},a.prototype._write=function(e,t,n){var r=this._transformState;if(r.writecb=n,r.writechunk=e,r.writeencoding=t,!r.transforming){var i=this._readableState;(r.needTransform||i.needReadable||i.length<i.highWaterMark)&&this._read(i.highWaterMark)}},a.prototype._read=function(e){var t=this._transformState;null!==t.writechunk&&t.writecb&&!t.transforming?(t.transforming=!0,this._transform(t.writechunk,t.writeencoding,t.afterTransform)):t.needTransform=!0}},function(e,t,n){"use strict";function r(e){return this instanceof r?void i.call(this,e):new r(e)}e.exports=r;var i=n(153),a=n(216);a.inherits=n(110),a.inherits(r,i),r.prototype._transform=function(e,t,n){n(null,e)}},function(e,t,n){"use strict";e.exports=n(190),n(191),n(192),n(193),n(194),n(195)},function(e,t,n){e.exports=__WEBPACK_EXTERNAL_MODULE_156__},function(e,t,n){"use strict";function r(e,t,n){var i=[];return e.include.forEach(function(e){n=r(e,t,n)}),e[t].forEach(function(e){n.forEach(function(t,n){t.tag===e.tag&&i.push(n)}),n.push(e)}),n.filter(function(e,t){return-1===i.indexOf(t)})}function i(){function e(e){r[e.tag]=e}var t,n,r={};for(t=0,n=arguments.length;n>t;t+=1)arguments[t].forEach(e);return r}var a=n(115),o=n(116),s=n(198),u=function(){function e(e){this.include=e.include||[],this.implicit=e.implicit||[],this.explicit=e.explicit||[],this.implicit.forEach(function(e){if(e.loadKind&&"scalar"!==e.loadKind)throw new o("There is a non-scalar type in the implicit list of a schema. Implicit resolving of such types is not supported.")}),this.compiledImplicit=r(this,"implicit",[]),this.compiledExplicit=r(this,"explicit",[]),this.compiledTypeMap=i(this.compiledImplicit,this.compiledExplicit)}return e.DEFAULT=null,e.create=function(){var t,n;switch(arguments.length){case 1:t=e.DEFAULT,n=arguments[0];break;case 2:t=arguments[0],n=arguments[1];break;default:throw new o("Wrong number of arguments for Schema.create function")}if(t=a.toArray(t),n=a.toArray(n),!t.every(function(t){return t instanceof e}))throw new o("Specified list of super schemas (or a single Schema object) contains a non-Schema object.");if(!n.every(function(e){return e instanceof s}))throw new o("Specified list of YAML types (or a single Type object) contains a non-Type object.");return new e({include:t,explicit:n})},e}();e.exports=u},function(e,t,n){"use strict";var r=n(157);e.exports=new r({include:[n(197)]})},function(e,t,n){e.exports=/[^\u0041-\u005A\u0061-\u007A\u00AA\u00B5\u00BA\u00C0-\u00D6\u00D8-\u00F6\u00F8-\u02C1\u02C6-\u02D1\u02E0-\u02E4\u02EC\u02EE\u0370-\u0374\u0376\u0377\u037A-\u037D\u0386\u0388-\u038A\u038C\u038E-\u03A1\u03A3-\u03F5\u03F7-\u0481\u048A-\u0527\u0531-\u0556\u0559\u0561-\u0587\u05D0-\u05EA\u05F0-\u05F2\u0620-\u064A\u066E\u066F\u0671-\u06D3\u06D5\u06E5\u06E6\u06EE\u06EF\u06FA-\u06FC\u06FF\u0710\u0712-\u072F\u074D-\u07A5\u07B1\u07CA-\u07EA\u07F4\u07F5\u07FA\u0800-\u0815\u081A\u0824\u0828\u0840-\u0858\u08A0\u08A2-\u08AC\u0904-\u0939\u093D\u0950\u0958-\u0961\u0971-\u0977\u0979-\u097F\u0985-\u098C\u098F\u0990\u0993-\u09A8\u09AA-\u09B0\u09B2\u09B6-\u09B9\u09BD\u09CE\u09DC\u09DD\u09DF-\u09E1\u09F0\u09F1\u0A05-\u0A0A\u0A0F\u0A10\u0A13-\u0A28\u0A2A-\u0A30\u0A32\u0A33\u0A35\u0A36\u0A38\u0A39\u0A59-\u0A5C\u0A5E\u0A72-\u0A74\u0A85-\u0A8D\u0A8F-\u0A91\u0A93-\u0AA8\u0AAA-\u0AB0\u0AB2\u0AB3\u0AB5-\u0AB9\u0ABD\u0AD0\u0AE0\u0AE1\u0B05-\u0B0C\u0B0F\u0B10\u0B13-\u0B28\u0B2A-\u0B30\u0B32\u0B33\u0B35-\u0B39\u0B3D\u0B5C\u0B5D\u0B5F-\u0B61\u0B71\u0B83\u0B85-\u0B8A\u0B8E-\u0B90\u0B92-\u0B95\u0B99\u0B9A\u0B9C\u0B9E\u0B9F\u0BA3\u0BA4\u0BA8-\u0BAA\u0BAE-\u0BB9\u0BD0\u0C05-\u0C0C\u0C0E-\u0C10\u0C12-\u0C28\u0C2A-\u0C33\u0C35-\u0C39\u0C3D\u0C58\u0C59\u0C60\u0C61\u0C85-\u0C8C\u0C8E-\u0C90\u0C92-\u0CA8\u0CAA-\u0CB3\u0CB5-\u0CB9\u0CBD\u0CDE\u0CE0\u0CE1\u0CF1\u0CF2\u0D05-\u0D0C\u0D0E-\u0D10\u0D12-\u0D3A\u0D3D\u0D4E\u0D60\u0D61\u0D7A-\u0D7F\u0D85-\u0D96\u0D9A-\u0DB1\u0DB3-\u0DBB\u0DBD\u0DC0-\u0DC6\u0E01-\u0E30\u0E32\u0E33\u0E40-\u0E46\u0E81\u0E82\u0E84\u0E87\u0E88\u0E8A\u0E8D\u0E94-\u0E97\u0E99-\u0E9F\u0EA1-\u0EA3\u0EA5\u0EA7\u0EAA\u0EAB\u0EAD-\u0EB0\u0EB2\u0EB3\u0EBD\u0EC0-\u0EC4\u0EC6\u0EDC-\u0EDF\u0F00\u0F40-\u0F47\u0F49-\u0F6C\u0F88-\u0F8C\u1000-\u102A\u103F\u1050-\u1055\u105A-\u105D\u1061\u1065\u1066\u106E-\u1070\u1075-\u1081\u108E\u10A0-\u10C5\u10C7\u10CD\u10D0-\u10FA\u10FC-\u1248\u124A-\u124D\u1250-\u1256\u1258\u125A-\u125D\u1260-\u1288\u128A-\u128D\u1290-\u12B0\u12B2-\u12B5\u12B8-\u12BE\u12C0\u12C2-\u12C5\u12C8-\u12D6\u12D8-\u1310\u1312-\u1315\u1318-\u135A\u1380-\u138F\u13A0-\u13F4\u1401-\u166C\u166F-\u167F\u1681-\u169A\u16A0-\u16EA\u1700-\u170C\u170E-\u1711\u1720-\u1731\u1740-\u1751\u1760-\u176C\u176E-\u1770\u1780-\u17B3\u17D7\u17DC\u1820-\u1877\u1880-\u18A8\u18AA\u18B0-\u18F5\u1900-\u191C\u1950-\u196D\u1970-\u1974\u1980-\u19AB\u19C1-\u19C7\u1A00-\u1A16\u1A20-\u1A54\u1AA7\u1B05-\u1B33\u1B45-\u1B4B\u1B83-\u1BA0\u1BAE\u1BAF\u1BBA-\u1BE5\u1C00-\u1C23\u1C4D-\u1C4F\u1C5A-\u1C7D\u1CE9-\u1CEC\u1CEE-\u1CF1\u1CF5\u1CF6\u1D00-\u1DBF\u1E00-\u1F15\u1F18-\u1F1D\u1F20-\u1F45\u1F48-\u1F4D\u1F50-\u1F57\u1F59\u1F5B\u1F5D\u1F5F-\u1F7D\u1F80-\u1FB4\u1FB6-\u1FBC\u1FBE\u1FC2-\u1FC4\u1FC6-\u1FCC\u1FD0-\u1FD3\u1FD6-\u1FDB\u1FE0-\u1FEC\u1FF2-\u1FF4\u1FF6-\u1FFC\u2071\u207F\u2090-\u209C\u2102\u2107\u210A-\u2113\u2115\u2119-\u211D\u2124\u2126\u2128\u212A-\u212D\u212F-\u2139\u213C-\u213F\u2145-\u2149\u214E\u2183\u2184\u2C00-\u2C2E\u2C30-\u2C5E\u2C60-\u2CE4\u2CEB-\u2CEE\u2CF2\u2CF3\u2D00-\u2D25\u2D27\u2D2D\u2D30-\u2D67\u2D6F\u2D80-\u2D96\u2DA0-\u2DA6\u2DA8-\u2DAE\u2DB0-\u2DB6\u2DB8-\u2DBE\u2DC0-\u2DC6\u2DC8-\u2DCE\u2DD0-\u2DD6\u2DD8-\u2DDE\u2E2F\u3005\u3006\u3031-\u3035\u303B\u303C\u3041-\u3096\u309D-\u309F\u30A1-\u30FA\u30FC-\u30FF\u3105-\u312D\u3131-\u318E\u31A0-\u31BA\u31F0-\u31FF\u3400-\u4DB5\u4E00-\u9FCC\uA000-\uA48C\uA4D0-\uA4FD\uA500-\uA60C\uA610-\uA61F\uA62A\uA62B\uA640-\uA66E\uA67F-\uA697\uA6A0-\uA6E5\uA717-\uA71F\uA722-\uA788\uA78B-\uA78E\uA790-\uA793\uA7A0-\uA7AA\uA7F8-\uA801\uA803-\uA805\uA807-\uA80A\uA80C-\uA822\uA840-\uA873\uA882-\uA8B3\uA8F2-\uA8F7\uA8FB\uA90A-\uA925\uA930-\uA946\uA960-\uA97C\uA984-\uA9B2\uA9CF\uAA00-\uAA28\uAA40-\uAA42\uAA44-\uAA4B\uAA60-\uAA76\uAA7A\uAA80-\uAAAF\uAAB1\uAAB5\uAAB6\uAAB9-\uAABD\uAAC0\uAAC2\uAADB-\uAADD\uAAE0-\uAAEA\uAAF2-\uAAF4\uAB01-\uAB06\uAB09-\uAB0E\uAB11-\uAB16\uAB20-\uAB26\uAB28-\uAB2E\uABC0-\uABE2\uAC00-\uD7A3\uD7B0-\uD7C6\uD7CB-\uD7FB\uF900-\uFA6D\uFA70-\uFAD9\uFB00-\uFB06\uFB13-\uFB17\uFB1D\uFB1F-\uFB28\uFB2A-\uFB36\uFB38-\uFB3C\uFB3E\uFB40\uFB41\uFB43\uFB44\uFB46-\uFBB1\uFBD3-\uFD3D\uFD50-\uFD8F\uFD92-\uFDC7\uFDF0-\uFDFB\uFE70-\uFE74\uFE76-\uFEFC\uFF21-\uFF3A\uFF41-\uFF5A\uFF66-\uFFBE\uFFC2-\uFFC7\uFFCA-\uFFCF\uFFD2-\uFFD7\uFFDA-\uFFDC\u0030-\u0039\u00B2\u00B3\u00B9\u00BC-\u00BE\u0660-\u0669\u06F0-\u06F9\u07C0-\u07C9\u0966-\u096F\u09E6-\u09EF\u09F4-\u09F9\u0A66-\u0A6F\u0AE6-\u0AEF\u0B66-\u0B6F\u0B72-\u0B77\u0BE6-\u0BF2\u0C66-\u0C6F\u0C78-\u0C7E\u0CE6-\u0CEF\u0D66-\u0D75\u0E50-\u0E59\u0ED0-\u0ED9\u0F20-\u0F33\u1040-\u1049\u1090-\u1099\u1369-\u137C\u16EE-\u16F0\u17E0-\u17E9\u17F0-\u17F9\u1810-\u1819\u1946-\u194F\u19D0-\u19DA\u1A80-\u1A89\u1A90-\u1A99\u1B50-\u1B59\u1BB0-\u1BB9\u1C40-\u1C49\u1C50-\u1C59\u2070\u2074-\u2079\u2080-\u2089\u2150-\u2182\u2185-\u2189\u2460-\u249B\u24EA-\u24FF\u2776-\u2793\u2CFD\u3007\u3021-\u3029\u3038-\u303A\u3192-\u3195\u3220-\u3229\u3248-\u324F\u3251-\u325F\u3280-\u3289\u32B1-\u32BF\uA620-\uA629\uA6E6-\uA6EF\uA830-\uA835\uA8D0-\uA8D9\uA900-\uA909\uA9D0-\uA9D9\uAA50-\uAA59\uABF0-\uABF9\uFF10-\uFF19]+/g},function(e,t,n){e.exports=/([\u0061-\u007A\u00B5\u00DF-\u00F6\u00F8-\u00FF\u0101\u0103\u0105\u0107\u0109\u010B\u010D\u010F\u0111\u0113\u0115\u0117\u0119\u011B\u011D\u011F\u0121\u0123\u0125\u0127\u0129\u012B\u012D\u012F\u0131\u0133\u0135\u0137\u0138\u013A\u013C\u013E\u0140\u0142\u0144\u0146\u0148\u0149\u014B\u014D\u014F\u0151\u0153\u0155\u0157\u0159\u015B\u015D\u015F\u0161\u0163\u0165\u0167\u0169\u016B\u016D\u016F\u0171\u0173\u0175\u0177\u017A\u017C\u017E-\u0180\u0183\u0185\u0188\u018C\u018D\u0192\u0195\u0199-\u019B\u019E\u01A1\u01A3\u01A5\u01A8\u01AA\u01AB\u01AD\u01B0\u01B4\u01B6\u01B9\u01BA\u01BD-\u01BF\u01C6\u01C9\u01CC\u01CE\u01D0\u01D2\u01D4\u01D6\u01D8\u01DA\u01DC\u01DD\u01DF\u01E1\u01E3\u01E5\u01E7\u01E9\u01EB\u01ED\u01EF\u01F0\u01F3\u01F5\u01F9\u01FB\u01FD\u01FF\u0201\u0203\u0205\u0207\u0209\u020B\u020D\u020F\u0211\u0213\u0215\u0217\u0219\u021B\u021D\u021F\u0221\u0223\u0225\u0227\u0229\u022B\u022D\u022F\u0231\u0233-\u0239\u023C\u023F\u0240\u0242\u0247\u0249\u024B\u024D\u024F-\u0293\u0295-\u02AF\u0371\u0373\u0377\u037B-\u037D\u0390\u03AC-\u03CE\u03D0\u03D1\u03D5-\u03D7\u03D9\u03DB\u03DD\u03DF\u03E1\u03E3\u03E5\u03E7\u03E9\u03EB\u03ED\u03EF-\u03F3\u03F5\u03F8\u03FB\u03FC\u0430-\u045F\u0461\u0463\u0465\u0467\u0469\u046B\u046D\u046F\u0471\u0473\u0475\u0477\u0479\u047B\u047D\u047F\u0481\u048B\u048D\u048F\u0491\u0493\u0495\u0497\u0499\u049B\u049D\u049F\u04A1\u04A3\u04A5\u04A7\u04A9\u04AB\u04AD\u04AF\u04B1\u04B3\u04B5\u04B7\u04B9\u04BB\u04BD\u04BF\u04C2\u04C4\u04C6\u04C8\u04CA\u04CC\u04CE\u04CF\u04D1\u04D3\u04D5\u04D7\u04D9\u04DB\u04DD\u04DF\u04E1\u04E3\u04E5\u04E7\u04E9\u04EB\u04ED\u04EF\u04F1\u04F3\u04F5\u04F7\u04F9\u04FB\u04FD\u04FF\u0501\u0503\u0505\u0507\u0509\u050B\u050D\u050F\u0511\u0513\u0515\u0517\u0519\u051B\u051D\u051F\u0521\u0523\u0525\u0527\u0561-\u0587\u1D00-\u1D2B\u1D6B-\u1D77\u1D79-\u1D9A\u1E01\u1E03\u1E05\u1E07\u1E09\u1E0B\u1E0D\u1E0F\u1E11\u1E13\u1E15\u1E17\u1E19\u1E1B\u1E1D\u1E1F\u1E21\u1E23\u1E25\u1E27\u1E29\u1E2B\u1E2D\u1E2F\u1E31\u1E33\u1E35\u1E37\u1E39\u1E3B\u1E3D\u1E3F\u1E41\u1E43\u1E45\u1E47\u1E49\u1E4B\u1E4D\u1E4F\u1E51\u1E53\u1E55\u1E57\u1E59\u1E5B\u1E5D\u1E5F\u1E61\u1E63\u1E65\u1E67\u1E69\u1E6B\u1E6D\u1E6F\u1E71\u1E73\u1E75\u1E77\u1E79\u1E7B\u1E7D\u1E7F\u1E81\u1E83\u1E85\u1E87\u1E89\u1E8B\u1E8D\u1E8F\u1E91\u1E93\u1E95-\u1E9D\u1E9F\u1EA1\u1EA3\u1EA5\u1EA7\u1EA9\u1EAB\u1EAD\u1EAF\u1EB1\u1EB3\u1EB5\u1EB7\u1EB9\u1EBB\u1EBD\u1EBF\u1EC1\u1EC3\u1EC5\u1EC7\u1EC9\u1ECB\u1ECD\u1ECF\u1ED1\u1ED3\u1ED5\u1ED7\u1ED9\u1EDB\u1EDD\u1EDF\u1EE1\u1EE3\u1EE5\u1EE7\u1EE9\u1EEB\u1EED\u1EEF\u1EF1\u1EF3\u1EF5\u1EF7\u1EF9\u1EFB\u1EFD\u1EFF-\u1F07\u1F10-\u1F15\u1F20-\u1F27\u1F30-\u1F37\u1F40-\u1F45\u1F50-\u1F57\u1F60-\u1F67\u1F70-\u1F7D\u1F80-\u1F87\u1F90-\u1F97\u1FA0-\u1FA7\u1FB0-\u1FB4\u1FB6\u1FB7\u1FBE\u1FC2-\u1FC4\u1FC6\u1FC7\u1FD0-\u1FD3\u1FD6\u1FD7\u1FE0-\u1FE7\u1FF2-\u1FF4\u1FF6\u1FF7\u210A\u210E\u210F\u2113\u212F\u2134\u2139\u213C\u213D\u2146-\u2149\u214E\u2184\u2C30-\u2C5E\u2C61\u2C65\u2C66\u2C68\u2C6A\u2C6C\u2C71\u2C73\u2C74\u2C76-\u2C7B\u2C81\u2C83\u2C85\u2C87\u2C89\u2C8B\u2C8D\u2C8F\u2C91\u2C93\u2C95\u2C97\u2C99\u2C9B\u2C9D\u2C9F\u2CA1\u2CA3\u2CA5\u2CA7\u2CA9\u2CAB\u2CAD\u2CAF\u2CB1\u2CB3\u2CB5\u2CB7\u2CB9\u2CBB\u2CBD\u2CBF\u2CC1\u2CC3\u2CC5\u2CC7\u2CC9\u2CCB\u2CCD\u2CCF\u2CD1\u2CD3\u2CD5\u2CD7\u2CD9\u2CDB\u2CDD\u2CDF\u2CE1\u2CE3\u2CE4\u2CEC\u2CEE\u2CF3\u2D00-\u2D25\u2D27\u2D2D\uA641\uA643\uA645\uA647\uA649\uA64B\uA64D\uA64F\uA651\uA653\uA655\uA657\uA659\uA65B\uA65D\uA65F\uA661\uA663\uA665\uA667\uA669\uA66B\uA66D\uA681\uA683\uA685\uA687\uA689\uA68B\uA68D\uA68F\uA691\uA693\uA695\uA697\uA723\uA725\uA727\uA729\uA72B\uA72D\uA72F-\uA731\uA733\uA735\uA737\uA739\uA73B\uA73D\uA73F\uA741\uA743\uA745\uA747\uA749\uA74B\uA74D\uA74F\uA751\uA753\uA755\uA757\uA759\uA75B\uA75D\uA75F\uA761\uA763\uA765\uA767\uA769\uA76B\uA76D\uA76F\uA771-\uA778\uA77A\uA77C\uA77F\uA781\uA783\uA785\uA787\uA78C\uA78E\uA791\uA793\uA7A1\uA7A3\uA7A5\uA7A7\uA7A9\uA7FA\uFB00-\uFB06\uFB13-\uFB17\uFF41-\uFF5A])([\u0041-\u005A\u00C0-\u00D6\u00D8-\u00DE\u0100\u0102\u0104\u0106\u0108\u010A\u010C\u010E\u0110\u0112\u0114\u0116\u0118\u011A\u011C\u011E\u0120\u0122\u0124\u0126\u0128\u012A\u012C\u012E\u0130\u0132\u0134\u0136\u0139\u013B\u013D\u013F\u0141\u0143\u0145\u0147\u014A\u014C\u014E\u0150\u0152\u0154\u0156\u0158\u015A\u015C\u015E\u0160\u0162\u0164\u0166\u0168\u016A\u016C\u016E\u0170\u0172\u0174\u0176\u0178\u0179\u017B\u017D\u0181\u0182\u0184\u0186\u0187\u0189-\u018B\u018E-\u0191\u0193\u0194\u0196-\u0198\u019C\u019D\u019F\u01A0\u01A2\u01A4\u01A6\u01A7\u01A9\u01AC\u01AE\u01AF\u01B1-\u01B3\u01B5\u01B7\u01B8\u01BC\u01C4\u01C7\u01CA\u01CD\u01CF\u01D1\u01D3\u01D5\u01D7\u01D9\u01DB\u01DE\u01E0\u01E2\u01E4\u01E6\u01E8\u01EA\u01EC\u01EE\u01F1\u01F4\u01F6-\u01F8\u01FA\u01FC\u01FE\u0200\u0202\u0204\u0206\u0208\u020A\u020C\u020E\u0210\u0212\u0214\u0216\u0218\u021A\u021C\u021E\u0220\u0222\u0224\u0226\u0228\u022A\u022C\u022E\u0230\u0232\u023A\u023B\u023D\u023E\u0241\u0243-\u0246\u0248\u024A\u024C\u024E\u0370\u0372\u0376\u0386\u0388-\u038A\u038C\u038E\u038F\u0391-\u03A1\u03A3-\u03AB\u03CF\u03D2-\u03D4\u03D8\u03DA\u03DC\u03DE\u03E0\u03E2\u03E4\u03E6\u03E8\u03EA\u03EC\u03EE\u03F4\u03F7\u03F9\u03FA\u03FD-\u042F\u0460\u0462\u0464\u0466\u0468\u046A\u046C\u046E\u0470\u0472\u0474\u0476\u0478\u047A\u047C\u047E\u0480\u048A\u048C\u048E\u0490\u0492\u0494\u0496\u0498\u049A\u049C\u049E\u04A0\u04A2\u04A4\u04A6\u04A8\u04AA\u04AC\u04AE\u04B0\u04B2\u04B4\u04B6\u04B8\u04BA\u04BC\u04BE\u04C0\u04C1\u04C3\u04C5\u04C7\u04C9\u04CB\u04CD\u04D0\u04D2\u04D4\u04D6\u04D8\u04DA\u04DC\u04DE\u04E0\u04E2\u04E4\u04E6\u04E8\u04EA\u04EC\u04EE\u04F0\u04F2\u04F4\u04F6\u04F8\u04FA\u04FC\u04FE\u0500\u0502\u0504\u0506\u0508\u050A\u050C\u050E\u0510\u0512\u0514\u0516\u0518\u051A\u051C\u051E\u0520\u0522\u0524\u0526\u0531-\u0556\u10A0-\u10C5\u10C7\u10CD\u1E00\u1E02\u1E04\u1E06\u1E08\u1E0A\u1E0C\u1E0E\u1E10\u1E12\u1E14\u1E16\u1E18\u1E1A\u1E1C\u1E1E\u1E20\u1E22\u1E24\u1E26\u1E28\u1E2A\u1E2C\u1E2E\u1E30\u1E32\u1E34\u1E36\u1E38\u1E3A\u1E3C\u1E3E\u1E40\u1E42\u1E44\u1E46\u1E48\u1E4A\u1E4C\u1E4E\u1E50\u1E52\u1E54\u1E56\u1E58\u1E5A\u1E5C\u1E5E\u1E60\u1E62\u1E64\u1E66\u1E68\u1E6A\u1E6C\u1E6E\u1E70\u1E72\u1E74\u1E76\u1E78\u1E7A\u1E7C\u1E7E\u1E80\u1E82\u1E84\u1E86\u1E88\u1E8A\u1E8C\u1E8E\u1E90\u1E92\u1E94\u1E9E\u1EA0\u1EA2\u1EA4\u1EA6\u1EA8\u1EAA\u1EAC\u1EAE\u1EB0\u1EB2\u1EB4\u1EB6\u1EB8\u1EBA\u1EBC\u1EBE\u1EC0\u1EC2\u1EC4\u1EC6\u1EC8\u1ECA\u1ECC\u1ECE\u1ED0\u1ED2\u1ED4\u1ED6\u1ED8\u1EDA\u1EDC\u1EDE\u1EE0\u1EE2\u1EE4\u1EE6\u1EE8\u1EEA\u1EEC\u1EEE\u1EF0\u1EF2\u1EF4\u1EF6\u1EF8\u1EFA\u1EFC\u1EFE\u1F08-\u1F0F\u1F18-\u1F1D\u1F28-\u1F2F\u1F38-\u1F3F\u1F48-\u1F4D\u1F59\u1F5B\u1F5D\u1F5F\u1F68-\u1F6F\u1FB8-\u1FBB\u1FC8-\u1FCB\u1FD8-\u1FDB\u1FE8-\u1FEC\u1FF8-\u1FFB\u2102\u2107\u210B-\u210D\u2110-\u2112\u2115\u2119-\u211D\u2124\u2126\u2128\u212A-\u212D\u2130-\u2133\u213E\u213F\u2145\u2183\u2C00-\u2C2E\u2C60\u2C62-\u2C64\u2C67\u2C69\u2C6B\u2C6D-\u2C70\u2C72\u2C75\u2C7E-\u2C80\u2C82\u2C84\u2C86\u2C88\u2C8A\u2C8C\u2C8E\u2C90\u2C92\u2C94\u2C96\u2C98\u2C9A\u2C9C\u2C9E\u2CA0\u2CA2\u2CA4\u2CA6\u2CA8\u2CAA\u2CAC\u2CAE\u2CB0\u2CB2\u2CB4\u2CB6\u2CB8\u2CBA\u2CBC\u2CBE\u2CC0\u2CC2\u2CC4\u2CC6\u2CC8\u2CCA\u2CCC\u2CCE\u2CD0\u2CD2\u2CD4\u2CD6\u2CD8\u2CDA\u2CDC\u2CDE\u2CE0\u2CE2\u2CEB\u2CED\u2CF2\uA640\uA642\uA644\uA646\uA648\uA64A\uA64C\uA64E\uA650\uA652\uA654\uA656\uA658\uA65A\uA65C\uA65E\uA660\uA662\uA664\uA666\uA668\uA66A\uA66C\uA680\uA682\uA684\uA686\uA688\uA68A\uA68C\uA68E\uA690\uA692\uA694\uA696\uA722\uA724\uA726\uA728\uA72A\uA72C\uA72E\uA732\uA734\uA736\uA738\uA73A\uA73C\uA73E\uA740\uA742\uA744\uA746\uA748\uA74A\uA74C\uA74E\uA750\uA752\uA754\uA756\uA758\uA75A\uA75C\uA75E\uA760\uA762\uA764\uA766\uA768\uA76A\uA76C\uA76E\uA779\uA77B\uA77D\uA77E\uA780\uA782\uA784\uA786\uA78B\uA78D\uA790\uA792\uA7A0\uA7A2\uA7A4\uA7A6\uA7A8\uA7AA\uFF21-\uFF3A\u0030-\u0039\u00B2\u00B3\u00B9\u00BC-\u00BE\u0660-\u0669\u06F0-\u06F9\u07C0-\u07C9\u0966-\u096F\u09E6-\u09EF\u09F4-\u09F9\u0A66-\u0A6F\u0AE6-\u0AEF\u0B66-\u0B6F\u0B72-\u0B77\u0BE6-\u0BF2\u0C66-\u0C6F\u0C78-\u0C7E\u0CE6-\u0CEF\u0D66-\u0D75\u0E50-\u0E59\u0ED0-\u0ED9\u0F20-\u0F33\u1040-\u1049\u1090-\u1099\u1369-\u137C\u16EE-\u16F0\u17E0-\u17E9\u17F0-\u17F9\u1810-\u1819\u1946-\u194F\u19D0-\u19DA\u1A80-\u1A89\u1A90-\u1A99\u1B50-\u1B59\u1BB0-\u1BB9\u1C40-\u1C49\u1C50-\u1C59\u2070\u2074-\u2079\u2080-\u2089\u2150-\u2182\u2185-\u2189\u2460-\u249B\u24EA-\u24FF\u2776-\u2793\u2CFD\u3007\u3021-\u3029\u3038-\u303A\u3192-\u3195\u3220-\u3229\u3248-\u324F\u3251-\u325F\u3280-\u3289\u32B1-\u32BF\uA620-\uA629\uA6E6-\uA6EF\uA830-\uA835\uA8D0-\uA8D9\uA900-\uA909\uA9D0-\uA9D9\uAA50-\uAA59\uABF0-\uABF9\uFF10-\uFF19])/g},function(e,t,n){e.exports=/([\u0030-\u0039\u00B2\u00B3\u00B9\u00BC-\u00BE\u0660-\u0669\u06F0-\u06F9\u07C0-\u07C9\u0966-\u096F\u09E6-\u09EF\u09F4-\u09F9\u0A66-\u0A6F\u0AE6-\u0AEF\u0B66-\u0B6F\u0B72-\u0B77\u0BE6-\u0BF2\u0C66-\u0C6F\u0C78-\u0C7E\u0CE6-\u0CEF\u0D66-\u0D75\u0E50-\u0E59\u0ED0-\u0ED9\u0F20-\u0F33\u1040-\u1049\u1090-\u1099\u1369-\u137C\u16EE-\u16F0\u17E0-\u17E9\u17F0-\u17F9\u1810-\u1819\u1946-\u194F\u19D0-\u19DA\u1A80-\u1A89\u1A90-\u1A99\u1B50-\u1B59\u1BB0-\u1BB9\u1C40-\u1C49\u1C50-\u1C59\u2070\u2074-\u2079\u2080-\u2089\u2150-\u2182\u2185-\u2189\u2460-\u249B\u24EA-\u24FF\u2776-\u2793\u2CFD\u3007\u3021-\u3029\u3038-\u303A\u3192-\u3195\u3220-\u3229\u3248-\u324F\u3251-\u325F\u3280-\u3289\u32B1-\u32BF\uA620-\uA629\uA6E6-\uA6EF\uA830-\uA835\uA8D0-\uA8D9\uA900-\uA909\uA9D0-\uA9D9\uAA50-\uAA59\uABF0-\uABF9\uFF10-\uFF19])([^\u0030-\u0039\u00B2\u00B3\u00B9\u00BC-\u00BE\u0660-\u0669\u06F0-\u06F9\u07C0-\u07C9\u0966-\u096F\u09E6-\u09EF\u09F4-\u09F9\u0A66-\u0A6F\u0AE6-\u0AEF\u0B66-\u0B6F\u0B72-\u0B77\u0BE6-\u0BF2\u0C66-\u0C6F\u0C78-\u0C7E\u0CE6-\u0CEF\u0D66-\u0D75\u0E50-\u0E59\u0ED0-\u0ED9\u0F20-\u0F33\u1040-\u1049\u1090-\u1099\u1369-\u137C\u16EE-\u16F0\u17E0-\u17E9\u17F0-\u17F9\u1810-\u1819\u1946-\u194F\u19D0-\u19DA\u1A80-\u1A89\u1A90-\u1A99\u1B50-\u1B59\u1BB0-\u1BB9\u1C40-\u1C49\u1C50-\u1C59\u2070\u2074-\u2079\u2080-\u2089\u2150-\u2182\u2185-\u2189\u2460-\u249B\u24EA-\u24FF\u2776-\u2793\u2CFD\u3007\u3021-\u3029\u3038-\u303A\u3192-\u3195\u3220-\u3229\u3248-\u324F\u3251-\u325F\u3280-\u3289\u32B1-\u32BF\uA620-\uA629\uA6E6-\uA6EF\uA830-\uA835\uA8D0-\uA8D9\uA900-\uA909\uA9D0-\uA9D9\uAA50-\uAA59\uABF0-\uABF9\uFF10-\uFF19])/g},function(e,t,n){"use strict";var r=n(199),i=n(200),a=n(201);e.exports={formats:a,parse:i,stringify:r}},function(e,t,n){"use strict";function r(e){var t=[],n=l.readFileSync(u.resolve(e)).toString(),r=o.createSourceFile("sample.ts",n,o.ScriptTarget.ES3,!0);return s.Matching.visit(r,function(r){var s=r;if(s.kind==o.SyntaxKind.FunctionDeclaration){var u=i(s,n);if(!u)return;var l=s.name.text,f=l;u.name?f=u.name:u.name=l;var f=u.name?u.name:l,m=s.parameters?s.parameters.map(function(t){return a(t,e)}):[],d=(u.override?u.override:!1,p.buildType(s.type,e));t.push(new c.HelperMethod(l,f,d,m,u))}}),t}function i(e,t){var n=o.getLeadingCommentRanges(t,e.pos);if(!n)return null;var r=n.map(function(e){return t.substring(e.pos,e.end)}).join("\n"),i=r.indexOf("__$helperMethod__");if(0>i)return null;i+="__$helperMethod__".length;var a=r.indexOf("__$meta__");
if(0>a)return{comment:f(r.substring(i))};var s=f(r.substring(i,a)),u=r.indexOf("{",a);if(0>u)return{comment:s};try{var l=JSON.parse(f(r.substring(u)));return l.comment=s.trim().length>0?s:null,l.override=l.override||!1,l.primary=l.primary||!1,l.deprecated=l.deprecated||!1,l}catch(p){console.log(p)}return{}}function a(e,t){var n,r=e.name.text,i=p.buildType(e.type,t),a=null!=e.questionToken;return null!=e.initializer&&(n=p.parseArg(e.initializer),a=!0),{name:r,type:i,defaultValue:n,optional:a}}var o=n(156),s=n(164),u=n(15),l=n(196),p=n(138),c=n(137);t.getHelperMethods=r;var f=function(e){return e.replace(/^\s*\/\*+/g,"").replace(/\*+\/\s*$/g,"").split("\n").map(function(e){return e.replace(/^\s*\/\//g,"").replace(/^\s*\* {0,1}/g,"")}).join("\n").trim()}},function(e,t,n){"use strict";var r,i=this&&this.__extends||function(e,t){function n(){this.constructor=e}for(var r in t)t.hasOwnProperty(r)&&(e[r]=t[r]);e.prototype=null===t?Object.create(t):(n.prototype=t.prototype,new n)},a=n(156);!function(e){function t(n,r){var i=r(n);if(i)return i==e.SKIP?null:i;var o=a.forEachChild(n,function(e){var n=t(e,r);return n?n:void 0});return o}function n(e,t){void 0===t&&(t=function(e){return!0});for(var n=e.split("."),i=null,a=0;a<n.length;a++){var s=n[a],u=s.indexOf("(*)"),l=!1;-1!=u&&(s=s.substr(0,u),l=!0),i=null==i?"*"==s?o():r(s):new N(i,"*"==s?o():r(s),t),l&&(i=new T(i,t))}return i}function r(e){return new A(e)}function o(){return new S}function s(e,t){return void 0===t&&(t=function(e){return!0}),new T(e,t)}function u(e,t){return void 0===t&&(t=function(e){return!0}),new g(e,t)}function l(e,t,n){return void 0===n&&(n=function(e){return!0}),new y(e,t,n)}function p(e,t,n){return void 0===n&&(n=function(e){return!0}),new v(e,t,n)}function c(){return new h}function f(){return new d}var m=function(){function e(){}return e.prototype.match=function(e){throw new Error},e.prototype.nodeType=function(){throw new Error},e.prototype.doMatch=function(e){return e?this.nodeType()==e.kind?this.match(e):void 0:null},e}();e.BasicMatcher=m;var d=function(e){function t(){e.call(this)}return i(t,e),t.prototype.match=function(e){return e},t.prototype.nodeType=function(){return a.SyntaxKind.ClassDeclaration},t}(m);e.ClassDeclarationMatcher=d;var h=function(e){function t(){e.apply(this,arguments)}return i(t,e),t.prototype.match=function(e){return e},t.prototype.nodeType=function(){return a.SyntaxKind.PropertyDeclaration},t}(m);e.FieldMatcher=h;var y=function(e){function t(t,n,r){e.call(this),this.left=t,this.right=n,this.tr=r}return i(t,e),t.prototype.match=function(e){return e.operatorToken.kind==a.SyntaxKind.EqualsToken&&this.left.doMatch(e.left)&&this.right.doMatch(e.right)?this.tr(e):null},t.prototype.nodeType=function(){return a.SyntaxKind.BinaryExpression},t}(m);e.AssignmentExpressionMatcher=y;var v=function(e){function t(t,n,r){e.call(this),this.left=t,this.right=n,this.tr=r}return i(t,e),t.prototype.match=function(e){return this.left.doMatch(e.name)&&this.right.doMatch(e.initializer)?this.tr(e):void 0},t.prototype.nodeType=function(){return a.SyntaxKind.VariableDeclaration},t}(m);e.VariableDeclarationMatcher=v;var g=function(e){function t(t,n){e.call(this),this.expression=t,this.tr=n}return i(t,e),t.prototype.match=function(e){var t=this.expression.doMatch(e.expression);if(t){var n=this.tr(e.expression);return 1==n?t:n}return null},t.prototype.nodeType=function(){return a.SyntaxKind.ExpressionStatement},t}(m),A=function(e){function t(t){e.call(this),this.val=t}return i(t,e),t.prototype.match=function(e){return e.text==this.val?!0:null},t.prototype.nodeType=function(){return a.SyntaxKind.Identifier},t}(m),S=function(){function e(){}return e.prototype.doMatch=function(e){return!0},e.prototype.nodeType=function(){return null},e}(),T=function(e){function t(t,n){e.call(this),this.calleeMatcher=t,this.tr=n}return i(t,e),t.prototype.match=function(e){return this.calleeMatcher.doMatch(e.expression)?this.tr(e):null},t.prototype.nodeType=function(){return a.SyntaxKind.CallExpression},t}(m);e.SKIP={},e.visit=t;var E=function(){function e(e,t){this._base=t,this.arguments=null,this.name=e}return e}();e.PathNode=E;var b=function(){function e(e,t){this._baseNode=t,this.path=[],this.base=e}return e.prototype.start=function(){return this._baseNode.pos},e.prototype.startLocation=function(){return this._baseNode.getSourceFile().getLineAndCharacterOfPosition(this.start())},e.prototype.endLocation=function(){return this._baseNode.getSourceFile().getLineAndCharacterOfPosition(this.end())},e.prototype.end=function(){var e=this.path[this.path.length-1]._callExpression;return e?e.end:this.start()},e.prototype.toString=function(){return this.path.map(function(e){return e.name}).join(".")},e}();e.CallPath=b;var N=function(e){function t(t,n,r){e.call(this),this.objectMatcher=t,this.propertyMatcher=n,this.tr=r}return i(t,e),t.prototype.match=function(e){return this.objectMatcher.doMatch(e.expression)&&this.propertyMatcher.doMatch(e.name)?this.tr(e):null},t.prototype.nodeType=function(){return a.SyntaxKind.PropertyAccessExpression},t}(m);e.memberFromExp=n;var _=function(){function e(e){this.rootMatcher=e}return e.prototype.doMatch=function(e){if(e.kind==a.SyntaxKind.CallExpression){var t=e,n=this.doMatch(t.expression);if(n)return n.path.length>0&&null==n.path[n.path.length-1].arguments?(n.path[n.path.length-1].arguments=t.arguments,n.path[n.path.length-1]._callExpression=t,n):null}else if(e.kind==a.SyntaxKind.PropertyAccessExpression){var r=e,i=this.doMatch(r.expression);if(i)return r.name.kind==a.SyntaxKind.Identifier?(i.path.push(new E(r.name.text,r.name)),i):null}else if(e.kind==a.SyntaxKind.Identifier){var o=e;if(this.rootMatcher.doMatch(o))return new b(o.text,o)}return null},e.prototype.nodeType=function(){return null},e}();e.CallBaseMatcher=_,e.ident=r,e.anyNode=o,e.call=s,e.exprStmt=u,e.assign=l,e.varDecl=p,e.field=c,e.classDeclaration=f}(r=t.Matching||(t.Matching={}))},function(e,t,n){"use strict";function r(e,t){return s.resolve(e,t)}function i(e){return u.readFileSync(e).toString()}function a(e){return s.dirname(e)}function o(e){return u.existsSync(e)}var s=n(15),u=n(196);t.resolve=r,t.readFileSync=i,t.dirname=a,t.existsSync=o},function(e,t,n){"use strict";function r(e){if(null===e)return!1;var t;return t=s.exec(e),null===t?!1:!0}function i(e){var t,n,r,i,a,o,u,l,p,c,f=0,m=null;if(t=s.exec(e),null===t)throw new Error("Date resolve error");if(n=+t[1],r=+t[2]-1,i=+t[3],!t[4])return new Date(Date.UTC(n,r,i));if(a=+t[4],o=+t[5],u=+t[6],t[7]){for(f=t[7].slice(0,3);f.length<3;)f+="0";f=+f}return t[9]&&(l=+t[10],p=+(t[11]||0),m=6e4*(60*l+p),"-"===t[9]&&(m=-m)),c=new Date(Date.UTC(n,r,i,a,o,u,f)),m&&c.setTime(c.getTime()-m),c}function a(e){return e.toISOString()}var o=n(198),s=new RegExp("^([0-9][0-9][0-9][0-9])-([0-9][0-9]?)-([0-9][0-9]?)(?:(?:[Tt]|[ \\t]+)([0-9][0-9]?):([0-9][0-9]):([0-9][0-9])(?:\\.([0-9]*))?(?:[ \\t]*(Z|([-+])([0-9][0-9]?)(?::([0-9][0-9]))?))?)?$");e.exports=new o("tag:yaml.org,2002:timestamp",{kind:"scalar",resolve:r,construct:i,instanceOf:Date,represent:a})},function(e,t,n){"use strict";function r(e){return"<<"===e||null===e}var i=n(198);e.exports=new i("tag:yaml.org,2002:merge",{kind:"scalar",resolve:r})},function(e,t,n){"use strict";function r(e){if(null===e)return!1;var t,n,r=0,i=e.length,a=l;for(n=0;i>n;n++)if(t=a.indexOf(e.charAt(n)),!(t>64)){if(0>t)return!1;r+=6}return r%8===0}function i(e){var t,n,r=e.replace(/[\r\n=]/g,""),i=r.length,a=l,o=0,u=[];for(t=0;i>t;t++)t%4===0&&t&&(u.push(o>>16&255),u.push(o>>8&255),u.push(255&o)),o=o<<6|a.indexOf(r.charAt(t));return n=i%4*6,0===n?(u.push(o>>16&255),u.push(o>>8&255),u.push(255&o)):18===n?(u.push(o>>10&255),u.push(o>>2&255)):12===n&&u.push(o>>4&255),s?new s(u):u}function a(e){var t,n,r="",i=0,a=e.length,o=l;for(t=0;a>t;t++)t%3===0&&t&&(r+=o[i>>18&63],r+=o[i>>12&63],r+=o[i>>6&63],r+=o[63&i]),i=(i<<8)+e[t];return n=a%3,0===n?(r+=o[i>>18&63],r+=o[i>>12&63],r+=o[i>>6&63],r+=o[63&i]):2===n?(r+=o[i>>10&63],r+=o[i>>4&63],r+=o[i<<2&63],r+=o[64]):1===n&&(r+=o[i>>2&63],r+=o[i<<4&63],r+=o[64],r+=o[64]),r}function o(e){return s&&s.isBuffer(e)}var s=n(94).Buffer,u=n(198),l="ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/=\n\r";e.exports=new u("tag:yaml.org,2002:binary",{kind:"scalar",resolve:r,construct:i,predicate:o,represent:a})},function(e,t,n){"use strict";function r(e){if(null===e)return!0;var t,n,r,i,a,u=[],l=e;for(t=0,n=l.length;n>t;t+=1){if(r=l[t],a=!1,"[object Object]"!==s.call(r))return!1;for(i in r)if(o.call(r,i)){if(a)return!1;a=!0}if(!a)return!1;if(-1!==u.indexOf(i))return!1;u.push(i)}return!0}function i(e){return null!==e?e:[]}var a=n(198),o=Object.prototype.hasOwnProperty,s=Object.prototype.toString;e.exports=new a("tag:yaml.org,2002:omap",{kind:"sequence",resolve:r,construct:i})},function(e,t,n){"use strict";function r(e){if(null===e)return!0;var t,n,r,i,a,s=e;for(a=new Array(s.length),t=0,n=s.length;n>t;t+=1){if(r=s[t],"[object Object]"!==o.call(r))return!1;if(i=Object.keys(r),1!==i.length)return!1;a[t]=[i[0],r[i[0]]]}return!0}function i(e){if(null===e)return[];var t,n,r,i,a,o=e;for(a=new Array(o.length),t=0,n=o.length;n>t;t+=1)r=o[t],i=Object.keys(r),a[t]=[i[0],r[i[0]]];return a}var a=n(198),o=Object.prototype.toString;e.exports=new a("tag:yaml.org,2002:pairs",{kind:"sequence",resolve:r,construct:i})},function(e,t,n){"use strict";function r(e){if(null===e)return!0;var t,n=e;for(t in n)if(o.call(n,t)&&null!==n[t])return!1;return!0}function i(e){return null!==e?e:{}}var a=n(198),o=Object.prototype.hasOwnProperty;e.exports=new a("tag:yaml.org,2002:set",{kind:"mapping",resolve:r,construct:i})},function(e,t,n){"use strict";function r(){return!0}function i(){return void 0}function a(){return""}function o(e){return"undefined"==typeof e}var s=n(198);e.exports=new s("tag:yaml.org,2002:js/undefined",{kind:"scalar",resolve:r,construct:i,predicate:o,represent:a})},function(e,t,n){"use strict";function r(e){if(null===e)return!1;if(0===e.length)return!1;var t=e,n=/\/([gim]*)$/.exec(e),r="";if("/"===t[0]){if(n&&(r=n[1]),r.length>3)return!1;if("/"!==t[t.length-r.length-1])return!1;t=t.slice(1,t.length-r.length-1)}try{new RegExp(t,r);return!0}catch(i){return!1}}function i(e){var t=e,n=/\/([gim]*)$/.exec(e),r="";return"/"===t[0]&&(n&&(r=n[1]),t=t.slice(1,t.length-r.length-1)),new RegExp(t,r)}function a(e){var t="/"+e.source+"/";return e.global&&(t+="g"),e.multiline&&(t+="m"),e.ignoreCase&&(t+="i"),t}function o(e){return"[object RegExp]"===Object.prototype.toString.call(e)}var s=n(198);e.exports=new s("tag:yaml.org,2002:js/regexp",{kind:"scalar",resolve:r,construct:i,predicate:o,represent:a})},function(e,t,n){t.read=function(e,t,n,r,i){var a,o,s=8*i-r-1,u=(1<<s)-1,l=u>>1,p=-7,c=n?i-1:0,f=n?-1:1,m=e[t+c];for(c+=f,a=m&(1<<-p)-1,m>>=-p,p+=s;p>0;a=256*a+e[t+c],c+=f,p-=8);for(o=a&(1<<-p)-1,a>>=-p,p+=r;p>0;o=256*o+e[t+c],c+=f,p-=8);if(0===a)a=1-l;else{if(a===u)return o?NaN:(m?-1:1)*(1/0);o+=Math.pow(2,r),a-=l}return(m?-1:1)*o*Math.pow(2,a-r)},t.write=function(e,t,n,r,i,a){var o,s,u,l=8*a-i-1,p=(1<<l)-1,c=p>>1,f=23===i?Math.pow(2,-24)-Math.pow(2,-77):0,m=r?0:a-1,d=r?1:-1,h=0>t||0===t&&0>1/t?1:0;for(t=Math.abs(t),isNaN(t)||t===1/0?(s=isNaN(t)?1:0,o=p):(o=Math.floor(Math.log(t)/Math.LN2),t*(u=Math.pow(2,-o))<1&&(o--,u*=2),t+=o+c>=1?f/u:f*Math.pow(2,1-c),t*u>=2&&(o++,u/=2),o+c>=p?(s=0,o=p):o+c>=1?(s=(t*u-1)*Math.pow(2,i),o+=c):(s=t*Math.pow(2,c-1)*Math.pow(2,i),o=0));i>=8;e[n+m]=255&s,m+=d,s/=256,i-=8);for(o=o<<i|s,l+=i;l>0;e[n+m]=255&o,m+=d,o/=256,l-=8);e[n+m-d]|=128*h}},function(e,t,n){var r={}.toString;e.exports=Array.isArray||function(e){return"[object Array]"==r.call(e)}},function(e,t,n){if("undefined"==typeof __WEBPACK_EXTERNAL_MODULE_176__){var r=new Error('Cannot find module "RAML.JsonValidation"');throw r.code="MODULE_NOT_FOUND",r}e.exports=__WEBPACK_EXTERNAL_MODULE_176__},function(e,t,n){function r(){i.call(this)}e.exports=r;var i=n(204).EventEmitter,a=n(224);a(r,i),r.Readable=n(218),r.Writable=n(219),r.Duplex=n(220),r.Transform=n(221),r.PassThrough=n(222),r.Stream=r,r.prototype.pipe=function(e,t){function n(t){e.writable&&!1===e.write(t)&&l.pause&&l.pause()}function r(){l.readable&&l.resume&&l.resume()}function a(){p||(p=!0,e.end())}function o(){p||(p=!0,"function"==typeof e.destroy&&e.destroy())}function s(e){if(u(),0===i.listenerCount(this,"error"))throw e}function u(){l.removeListener("data",n),e.removeListener("drain",r),l.removeListener("end",a),l.removeListener("close",o),l.removeListener("error",s),e.removeListener("error",s),l.removeListener("end",u),l.removeListener("close",u),e.removeListener("close",u)}var l=this;l.on("data",n),e.on("drain",r),e._isStdio||t&&t.end===!1||(l.on("end",a),l.on("close",o));var p=!1;return l.on("error",s),e.on("error",s),l.on("end",u),l.on("close",u),e.on("close",u),e.emit("pipe",l),e}},function(e,t,n){"use strict";var r=function(){function e(e,t){function n(){this.constructor=e}n.prototype=t.prototype,e.prototype=new n}function t(e,n,r,i){this.message=e,this.expected=n,this.found=r,this.location=i,this.name="SyntaxError","function"==typeof Error.captureStackTrace&&Error.captureStackTrace(this,t)}function n(e){function n(t){var n,r,i=$[t];if(i)return i;for(n=t-1;!$[n];)n--;for(i=$[n],i={line:i.line,column:i.column,seenCR:i.seenCR};t>n;)r=e.charAt(n),"\n"===r?(i.seenCR||i.line++,i.column=1,i.seenCR=!1):"\r"===r||"\u2028"===r||"\u2029"===r?(i.line++,i.column=1,i.seenCR=!0):(i.column++,i.seenCR=!1),n++;return $[t]=i,i}function r(e,t){var r=n(e),i=n(t);return{start:{offset:e,line:r.line,column:r.column},end:{offset:t,line:i.line,column:i.column}}}function i(e){G>Y||(Y>G&&(G=Y,X=[]),X.push(e))}function a(e,n,r,i){function a(e){var t=1;for(e.sort(function(e,t){return e.description<t.description?-1:e.description>t.description?1:0});t<e.length;)e[t-1]===e[t]?e.splice(t,1):t++}function o(e,t){function n(e){function t(e){return e.charCodeAt(0).toString(16).toUpperCase()}return e.replace(/\\/g,"\\\\").replace(/"/g,'\\"').replace(/\x08/g,"\\b").replace(/\t/g,"\\t").replace(/\n/g,"\\n").replace(/\f/g,"\\f").replace(/\r/g,"\\r").replace(/[\x00-\x07\x0B\x0E\x0F]/g,function(e){return"\\x0"+t(e)}).replace(/[\x10-\x1F\x80-\xFF]/g,function(e){return"\\x"+t(e)}).replace(/[\u0100-\u0FFF]/g,function(e){return"\\u0"+t(e)}).replace(/[\u1000-\uFFFF]/g,function(e){return"\\u"+t(e)})}var r,i,a,o=new Array(e.length);for(a=0;a<e.length;a++)o[a]=e[a].description;return r=e.length>1?o.slice(0,-1).join(", ")+" or "+o[e.length-1]:o[0],i=t?'"'+n(t)+'"':"end of input","Expected "+r+" but "+i+" found."}return null!==n&&a(n),new t(null!==e?e:o(n,r),n,r,i)}function o(){var t,n,r,a,u,p,c,f;return t=Y,n=l(),n!==m?(r=s(),r!==m?(a=Y,u=l(),u!==m?(124===e.charCodeAt(Y)?(p=y,Y++):(p=m,0===z&&i(v)),p!==m?(c=l(),c!==m?(f=o(),f!==m?(u=[u,p,c,f],a=u):(Y=a,a=m)):(Y=a,a=m)):(Y=a,a=m)):(Y=a,a=m),a===m&&(a=null),a!==m?(H=t,n=g(r,a),t=n):(Y=t,t=m)):(Y=t,t=m)):(Y=t,t=m),t}function s(){var t,n,r,a,s,p,c,f,d,h;if(t=Y,40===e.charCodeAt(Y)?(n=A,Y++):(n=m,0===z&&i(S)),n!==m)if(r=l(),r!==m)if(a=o(),a!==m)if(s=l(),s!==m)if(41===e.charCodeAt(Y)?(p=T,Y++):(p=m,0===z&&i(E)),p!==m){for(c=[],f=Y,d=l(),d!==m?(e.substr(Y,2)===b?(h=b,Y+=2):(h=m,0===z&&i(N)),h!==m?(d=[d,h],f=d):(Y=f,f=m)):(Y=f,f=m);f!==m;)c.push(f),f=Y,d=l(),d!==m?(e.substr(Y,2)===b?(h=b,Y+=2):(h=m,0===z&&i(N)),h!==m?(d=[d,h],f=d):(Y=f,f=m)):(Y=f,f=m);c!==m?(H=t,n=_(a,c),t=n):(Y=t,t=m)}else Y=t,t=m;else Y=t,t=m;else Y=t,t=m;else Y=t,t=m;else Y=t,t=m;return t===m&&(t=u()),t}function u(){var t,n,r,a,o,s;if(z++,t=Y,n=[],r=p(),r!==m)for(;r!==m;)n.push(r),r=p();else n=m;if(n!==m){for(r=[],a=Y,o=l(),o!==m?(e.substr(Y,2)===b?(s=b,Y+=2):(s=m,0===z&&i(N)),s!==m?(o=[o,s],a=o):(Y=a,a=m)):(Y=a,a=m);a!==m;)r.push(a),a=Y,o=l(),o!==m?(e.substr(Y,2)===b?(s=b,Y+=2):(s=m,0===z&&i(N)),s!==m?(o=[o,s],a=o):(Y=a,a=m)):(Y=a,a=m);r!==m?(H=t,n=w(n,r),t=n):(Y=t,t=m)}else Y=t,t=m;return z--,t===m&&(n=m,0===z&&i(M)),t}function l(){var t,n;for(z++,t=[],I.test(e.charAt(Y))?(n=e.charAt(Y),Y++):(n=m,0===z&&i(C));n!==m;)t.push(n),I.test(e.charAt(Y))?(n=e.charAt(Y),Y++):(n=m,0===z&&i(C));return z--,t===m&&(n=m,0===z&&i(R)),t}function p(){var t;return L.test(e.charAt(Y))?(t=e.charAt(Y),Y++):(t=m,0===z&&i(P)),t===m&&(95===e.charCodeAt(Y)?(t=O,Y++):(t=m,0===z&&i(D)),t===m&&(45===e.charCodeAt(Y)?(t=x,Y++):(t=m,0===z&&i(U)),t===m&&(46===e.charCodeAt(Y)?(t=k,Y++):(t=m,0===z&&i(F)),t===m&&(B.test(e.charAt(Y))?(t=e.charAt(Y),Y++):(t=m,0===z&&i(K)),t===m&&(V.test(e.charAt(Y))?(t=e.charAt(Y),Y++):(t=m,0===z&&i(j)),t===m&&(63===e.charCodeAt(Y)?(t=W,Y++):(t=m,0===z&&i(q)))))))),t}var c,f=arguments.length>1?arguments[1]:{},m={},d={Term:o},h=o,y="|",v={type:"literal",value:"|",description:'"|"'},g=function(e,t){return t?{type:"union",first:e,rest:t[3]}:e},A="(",S={type:"literal",value:"(",description:'"("'},T=")",E={type:"literal",value:")",description:'")"'},b="[]",N={type:"literal",value:"[]",description:'"[]"'},_=function(e,t){return{type:"parens",expr:e,arr:t.length}},M={type:"other",description:"name"},w=function(e,t){return{type:"name",value:e.join(""),arr:t.length}},R={type:"other",description:"whitespace"},I=/^[ \t\n\r]/,C={type:"class",value:"[ \\t\\n\\r]",description:"[ \\t\\n\\r]"},L=/^[A-Z]/,P={type:"class",value:"[A-Z]",description:"[A-Z]"},O="_",D={type:"literal",value:"_",description:'"_"'},x="-",U={type:"literal",value:"-",description:'"-"'},k=".",F={type:"literal",value:".",description:'"."'},B=/^[a-z:#\/]/,K={type:"class",value:"[a-z]",description:"[a-z]"},V=/^[0-9]/,j={type:"class",value:"[0-9]",description:"[0-9]"},W="?",q={type:"literal",value:"?",description:'"?"'},Y=0,H=0,$=[{line:1,column:1,seenCR:!1}],G=0,X=[],z=0;if("startRule"in f){if(!(f.startRule in d))throw new Error("Can't start parsing from rule \""+f.startRule+'".');h=d[f.startRule]}if(c=h(),c!==m&&Y===e.length)return c;throw c!==m&&Y<e.length&&i({type:"end",description:"end of input"}),a(null,X,G<e.length?e.charAt(G):null,G<e.length?r(G,G+1):r(G,G))}return e(t,Error),{SyntaxError:t,parse:n}}();e.exports=r},function(e,t,n){var r="ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/";!function(e){"use strict";function t(e){var t=e.charCodeAt(0);return t===o||t===c?62:t===s||t===f?63:u>t?-1:u+10>t?t-u+26+26:p+26>t?t-p:l+26>t?t-l+26:void 0}function n(e){function n(e){l[c++]=e}var r,i,o,s,u,l;if(e.length%4>0)throw new Error("Invalid string. Length must be a multiple of 4");var p=e.length;u="="===e.charAt(p-2)?2:"="===e.charAt(p-1)?1:0,l=new a(3*e.length/4-u),o=u>0?e.length-4:e.length;var c=0;for(r=0,i=0;o>r;r+=4,i+=3)s=t(e.charAt(r))<<18|t(e.charAt(r+1))<<12|t(e.charAt(r+2))<<6|t(e.charAt(r+3)),n((16711680&s)>>16),n((65280&s)>>8),n(255&s);return 2===u?(s=t(e.charAt(r))<<2|t(e.charAt(r+1))>>4,n(255&s)):1===u&&(s=t(e.charAt(r))<<10|t(e.charAt(r+1))<<4|t(e.charAt(r+2))>>2,n(s>>8&255),n(255&s)),l}function i(e){function t(e){return r.charAt(e)}function n(e){return t(e>>18&63)+t(e>>12&63)+t(e>>6&63)+t(63&e)}var i,a,o,s=e.length%3,u="";for(i=0,o=e.length-s;o>i;i+=3)a=(e[i]<<16)+(e[i+1]<<8)+e[i+2],u+=n(a);switch(s){case 1:a=e[e.length-1],u+=t(a>>2),u+=t(a<<4&63),u+="==";break;case 2:a=(e[e.length-2]<<8)+e[e.length-1],u+=t(a>>10),u+=t(a>>4&63),u+=t(a<<2&63),u+="="}return u}var a="undefined"!=typeof Uint8Array?Uint8Array:Array,o="+".charCodeAt(0),s="/".charCodeAt(0),u="0".charCodeAt(0),l="a".charCodeAt(0),p="A".charCodeAt(0),c="-".charCodeAt(0),f="_".charCodeAt(0);e.toByteArray=n,e.fromByteArray=i}("undefined"==typeof t?this.base64js={}:t)},function(e,t,n){},function(e,t,n){e.exports=[{code:"1xx",phrase:"**Informational**",description:'"indicates an interim response for communicating connection status or request progress prior to completing the requested action and sending a final response." ~ [sure](http://www.urbandictionary.com/define.php?term=sure)',spec_title:"RFC7231#6.2",spec_href:"http://tools.ietf.org/html/rfc7231#section-6.2"},{code:"100",phrase:"Continue",description:'"indicates that the initial part of a request has been received and has not yet been rejected by the server."',spec_title:"RFC7231#6.2.1",spec_href:"http://tools.ietf.org/html/rfc7231#section-6.2.1"},{code:"101",phrase:"Switching Protocols",description:'"indicates that the server understands and is willing to comply with the client\'s request, via the Upgrade header field, for a change in the application protocol being used on this connection."',spec_title:"RFC7231#6.2.2",spec_href:"http://tools.ietf.org/html/rfc7231#section-6.2.2"},{code:"2xx",phrase:"**Successful**",description:'"indicates that the client\'s request was successfully received, understood, and accepted." ~ [cool](https://twitter.com/DanaDanger/status/183316183494311936)',spec_title:"RFC7231#6.3",spec_href:"http://tools.ietf.org/html/rfc7231#section-6.3"},{code:"200",phrase:"OK",description:'"indicates that the request has succeeded."',spec_title:"RFC7231#6.3.1",spec_href:"http://tools.ietf.org/html/rfc7231#section-6.3.1"},{code:"201",phrase:"Created",description:'"indicates that the request has been fulfilled and has resulted in one or more new resources being created."',spec_title:"RFC7231#6.3.2",spec_href:"http://tools.ietf.org/html/rfc7231#section-6.3.2"},{code:"202",phrase:"Accepted",description:'"indicates that the request has been accepted for processing, but the processing has not been completed."',spec_title:"RFC7231#6.3.3",spec_href:"http://tools.ietf.org/html/rfc7231#section-6.3.3"},{code:"203",phrase:"Non-Authoritative Information",description:'"indicates that the request was successful but the enclosed payload has been modified from that of the origin server\'s 200 (OK) response by a transforming proxy."',spec_title:"RFC7231#6.3.4",spec_href:"http://tools.ietf.org/html/rfc7231#section-6.3.4"},{code:"204",phrase:"No Content",description:'"indicates that the server has successfully fulfilled the request and that there is no additional content to send in the response payload body."',spec_title:"RFC7231#6.3.5",spec_href:"http://tools.ietf.org/html/rfc7231#section-6.3.5"},{code:"205",phrase:"Reset Content",description:'"indicates that the server has fulfilled the request and desires that the user agent reset the "document view", which caused the request to be sent, to its original state as received from the origin server."',spec_title:"RFC7231#6.3.6",spec_href:"http://tools.ietf.org/html/rfc7231#section-6.3.6"},{code:"206",phrase:"Partial Content",description:'"indicates that the server is successfully fulfilling a range request for the target resource by transferring one or more parts of the selected representation that correspond to the satisfiable ranges found in the requests\'s Range header field."',spec_title:"RFC7233#4.1",spec_href:"http://tools.ietf.org/html/rfc7233#section-4.1"},{code:"3xx",phrase:"**Redirection**",description:'"indicates that further action needs to be taken by the user agent in order to fulfill the request." ~ [ask that dude over there](https://twitter.com/DanaDanger/status/183316183494311936)',spec_title:"RFC7231#6.4",spec_href:"http://tools.ietf.org/html/rfc7231#section-6.4"},{code:"300",phrase:"Multiple Choices",description:'"indicates that the target resource has more than one representation, each with its own more specific identifier, and information about the alternatives is being provided so that the user (or user agent) can select a preferred representation by redirecting its request to one or more of those identifiers."',spec_title:"RFC7231#6.4.1",spec_href:"http://tools.ietf.org/html/rfc7231#section-6.4.1"},{code:"301",phrase:"Moved Permanently",description:'"indicates that the target resource has been assigned a new permanent URI and any future references to this resource ought to use one of the enclosed URIs."',spec_title:"RFC7231#6.4.2",spec_href:"http://tools.ietf.org/html/rfc7231#section-6.4.2"},{code:"302",phrase:"Found",description:'"indicates that the target resource resides temporarily under a different URI."',spec_title:"RFC7231#6.4.3",spec_href:"http://tools.ietf.org/html/rfc7231#section-6.4.3"},{code:"303",phrase:"See Other",description:'"indicates that the server is redirecting the user agent to a different resource, as indicated by a URI in the Location header field, that is intended to provide an indirect response to the original request."',spec_title:"RFC7231#6.4.4",spec_href:"http://tools.ietf.org/html/rfc7231#section-6.4.4"},{code:"304",phrase:"Not Modified",description:'"indicates that a conditional GET request has been received and would have resulted in a 200 (OK) response if it were not for the fact that the condition has evaluated to false."',spec_title:"RFC7232#4.1",spec_href:"http://tools.ietf.org/html/rfc7232#section-4.1"},{code:"305",phrase:"Use Proxy",description:"*deprecated*",spec_title:"RFC7231#6.4.5",spec_href:"http://tools.ietf.org/html/rfc7231#section-6.4.5"},{code:"307",phrase:"Temporary Redirect",description:'"indicates that the target resource resides temporarily under a different URI and the user agent MUST NOT change the request method if it performs an automatic redirection to that URI."',spec_title:"RFC7231#6.4.7",spec_href:"http://tools.ietf.org/html/rfc7231#section-6.4.7"},{code:"4xx",phrase:"**Client Error**",description:'"indicates that the client seems to have erred." ~ [*you* fucked up](https://twitter.com/DanaDanger/status/183316183494311936)',spec_title:"RFC7231#6.5",spec_href:"http://tools.ietf.org/html/rfc7231#section-6.5"},{code:"400",phrase:"Bad Request",description:'"indicates that the server cannot or will not process the request because the received syntax is invalid, nonsensical, or exceeds some limitation on what the server is willing to process."',spec_title:"RFC7231#6.5.1",spec_href:"http://tools.ietf.org/html/rfc7231#section-6.5.1"},{code:"401",phrase:"Unauthorized",description:'"indicates that the request has not been applied because it lacks valid authentication credentials for the target resource."',spec_title:"RFC7235#6.3.1",spec_href:"http://tools.ietf.org/html/rfc7235#section-3.1"},{code:"402",phrase:"Payment Required",description:"*reserved*",spec_title:"RFC7231#6.5.2",spec_href:"http://tools.ietf.org/html/rfc7231#section-6.5.2"},{code:"403",phrase:"Forbidden",description:'"indicates that the server understood the request but refuses to authorize it."',spec_title:"RFC7231#6.5.3",spec_href:"http://tools.ietf.org/html/rfc7231#section-6.5.3"},{code:"404",phrase:"Not Found",description:'"indicates that the origin server did not find a current representation for the target resource or is not willing to disclose that one exists."',spec_title:"RFC7231#6.5.4",spec_href:"http://tools.ietf.org/html/rfc7231#section-6.5.4"},{code:"405",phrase:"Method Not Allowed",description:'"indicates that the method specified in the request-line is known by the origin server but not supported by the target resource."',spec_title:"RFC7231#6.5.5",spec_href:"http://tools.ietf.org/html/rfc7231#section-6.5.5"},{code:"406",phrase:"Not Acceptable",description:'"indicates that the target resource does not have a current representation that would be acceptable to the user agent, according to the proactive negotiation header fields received in the request, and the server is unwilling to supply a default representation."',spec_title:"RFC7231#6.5.6",spec_href:"http://tools.ietf.org/html/rfc7231#section-6.5.6"},{code:"407",phrase:"Proxy Authentication Required",description:'"is similar to 401 (Unauthorized), but indicates that the client needs to authenticate itself in order to use a proxy."',spec_title:"RFC7231#6.3.2",spec_href:"http://tools.ietf.org/html/rfc7231#section-6.3.2"},{code:"408",phrase:"Request Timeout",description:'"indicates that the server did not receive a complete request message within the time that it was prepared to wait."',spec_title:"RFC7231#6.5.7",spec_href:"http://tools.ietf.org/html/rfc7231#section-6.5.7"},{code:"409",phrase:"Conflict",description:'"indicates that the request could not be completed due to a conflict with the current state of the resource."',spec_title:"RFC7231#6.5.8",spec_href:"http://tools.ietf.org/html/rfc7231#section-6.5.8"},{code:"410",phrase:"Gone",description:'"indicates that access to the target resource is no longer available at the origin server and that this condition is likely to be permanent."',spec_title:"RFC7231#6.5.9",spec_href:"http://tools.ietf.org/html/rfc7231#section-6.5.9"},{code:"411",phrase:"Length Required",description:'"indicates that the server refuses to accept the request without a defined Content-Length."',spec_title:"RFC7231#6.5.10",spec_href:"http://tools.ietf.org/html/rfc7231#section-6.5.10"},{code:"412",phrase:"Precondition Failed",description:'"indicates that one or more preconditions given in the request header fields evaluated to false when tested on the server."',spec_title:"RFC7232#4.2",spec_href:"http://tools.ietf.org/html/rfc7232#section-4.2"},{code:"413",phrase:"Payload Too Large",description:'"indicates that the server is refusing to process a request because the request payload is larger than the server is willing or able to process."',spec_title:"RFC7231#6.5.11",spec_href:"http://tools.ietf.org/html/rfc7231#section-6.5.11"},{code:"414",phrase:"URI Too Long",description:'"indicates that the server is refusing to service the request because the request-target is longer than the server is willing to interpret."',spec_title:"RFC7231#6.5.12",spec_href:"http://tools.ietf.org/html/rfc7231#section-6.5.12"},{code:"415",phrase:"Unsupported Media Type",description:'"indicates that the origin server is refusing to service the request because the payload is in a format not supported by the target resource for this method."',spec_title:"RFC7231#6.5.13",spec_href:"http://tools.ietf.org/html/rfc7231#section-6.5.13"},{code:"416",phrase:"Range Not Satisfiable",description:'"indicates that none of the ranges in the request\'s Range header field overlap the current extent of the selected resource or that the set of ranges requested has been rejected due to invalid ranges or an excessive request of small or overlapping ranges."',spec_title:"RFC7233#4.4",spec_href:"http://tools.ietf.org/html/rfc7233#section-4.4"},{code:"417",phrase:"Expectation Failed",description:'"indicates that the expectation given in the request\'s Expect header field could not be met by at least one of the inbound servers."',spec_title:"RFC7231#6.5.14",spec_href:"http://tools.ietf.org/html/rfc7231#section-6.5.14"},{code:"426",phrase:"Upgrade Required",description:'"indicates that the server refuses to perform the request using the current protocol but might be willing to do so after the client upgrades to a different protocol."',spec_title:"RFC7231#6.5.15",spec_href:"http://tools.ietf.org/html/rfc7231#section-6.5.15"},{code:"5xx",phrase:"**Server Error**",description:'"indicates that the server is aware that it has erred or is incapable of performing the requested method." ~ [*we* fucked up](https://twitter.com/DanaDanger/status/183316183494311936)',spec_title:"RFC7231#6.6",spec_href:"http://tools.ietf.org/html/rfc7231#section-6.6"},{code:"500",phrase:"Internal Server Error",description:'"indicates that the server encountered an unexpected condition that prevented it from fulfilling the request."',spec_title:"RFC7231#6.6.1",spec_href:"http://tools.ietf.org/html/rfc7231#section-6.6.1"},{code:"501",phrase:"Not Implemented",description:'"indicates that the server does not support the functionality required to fulfill the request."',spec_title:"RFC7231#6.6.2",spec_href:"http://tools.ietf.org/html/rfc7231#section-6.6.2"},{code:"502",phrase:"Bad Gateway",description:'"indicates that the server, while acting as a gateway or proxy, received an invalid response from an inbound server it accessed while attempting to fulfill the request."',spec_title:"RFC7231#6.6.3",spec_href:"http://tools.ietf.org/html/rfc7231#section-6.6.3"},{code:"503",phrase:"Service Unavailable",description:'"indicates that the server is currently unable to handle the request due to a temporary overload or scheduled maintenance, which will likely be alleviated after some delay."',spec_title:"RFC7231#6.6.4",
spec_href:"http://tools.ietf.org/html/rfc7231#section-6.6.4"},{code:"504",phrase:"Gateway Time-out",description:'"indicates that the server, while acting as a gateway or proxy, did not receive a timely response from an upstream server it needed to access in order to complete the request."',spec_title:"RFC7231#6.6.5",spec_href:"http://tools.ietf.org/html/rfc7231#section-6.6.5"},{code:"505",phrase:"HTTP Version Not Supported",description:'"indicates that the server does not support, or refuses to support, the protocol version that was used in the request message."',spec_title:"RFC7231#6.6.6",spec_href:"http://tools.ietf.org/html/rfc7231#section-6.6.6"},{code:"102",phrase:"Processing",description:'"is an interim response used to inform the client that the server has accepted the complete request, but has not yet completed it."',spec_title:"RFC5218#10.1",spec_href:"http://tools.ietf.org/html/rfc2518#section-10.1"},{code:"207",phrase:"Multi-Status",description:'"provides status for multiple independent operations."',spec_title:"RFC5218#10.2",spec_href:"http://tools.ietf.org/html/rfc2518#section-10.2"},{code:"226",phrase:"IM Used",description:'"The server has fulfilled a GET request for the resource, and the response is a representation of the result of one or more instance-manipulations applied to the current instance."',spec_title:"RFC3229#10.4.1",spec_href:"http://tools.ietf.org/html/rfc3229#section-10.4.1"},{code:"308",phrase:"Permanent Redirect",description:'"The target resource has been assigned a new permanent URI and any future references to this resource SHOULD use one of the returned URIs. [...] This status code is similar to 301 Moved Permanently (Section 7.3.2 of rfc7231), except that it does not allow rewriting the request method from POST to GET."',spec_title:"RFC7238",spec_href:"http://tools.ietf.org/html/rfc7238"},{code:"422",phrase:"Unprocessable Entity",description:'"means the server understands the content type of the request entity (hence a 415(Unsupported Media Type) status code is inappropriate), and the syntax of the request entity is correct (thus a 400 (Bad Request) status code is inappropriate) but was unable to process the contained instructions."',spec_title:"RFC5218#10.3",spec_href:"http://tools.ietf.org/html/rfc2518#section-10.3"},{code:"423",phrase:"Locked",description:'"means the source or destination resource of a method is locked."',spec_title:"RFC5218#10.4",spec_href:"http://tools.ietf.org/html/rfc2518#section-10.4"},{code:"424",phrase:"Failed Dependency",description:'"means that the method could not be performed on the resource because the requested action depended on another action and that action failed."',spec_title:"RFC5218#10.5",spec_href:"http://tools.ietf.org/html/rfc2518#section-10.5"},{code:"428",phrase:"Precondition Required",description:'"indicates that the origin server requires the request to be conditional."',spec_title:"RFC6585#3",spec_href:"http://tools.ietf.org/html/rfc6585#section-3"},{code:"429",phrase:"Too Many Requests",description:'"indicates that the user has sent too many requests in a given amount of time ("rate limiting")."',spec_title:"RFC6585#4",spec_href:"http://tools.ietf.org/html/rfc6585#section-4"},{code:"431",phrase:"Request Header Fields Too Large",description:'"indicates that the server is unwilling to process the request because its header fields are too large."',spec_title:"RFC6585#5",spec_href:"http://tools.ietf.org/html/rfc6585#section-5"},{code:"451",phrase:"Unavailable For Legal Reasons",description:'"This status code indicates that the server is denying access to the resource in response to a legal demand."',spec_title:"draft-tbray-http-legally-restricted-status",spec_href:"http://tools.ietf.org/html/draft-tbray-http-legally-restricted-status"},{code:"506",phrase:"Variant Also Negotiates",description:'"indicates that the server has an internal configuration error: the chosen variant resource is configured to engage in transparent content negotiation itself, and is therefore not a proper end point in the negotiation process."',spec_title:"RFC2295#8.1",spec_href:"http://tools.ietf.org/html/rfc2295#section-8.1"},{code:"507",phrase:"Insufficient Storage",description:'"means the method could not be performed on the resource because the server is unable to store the representation needed to successfully complete the request."',spec_title:"RFC5218#10.6",spec_href:"http://tools.ietf.org/html/rfc2518#section-10.6"},{code:"511",phrase:"Network Authentication Required",description:'"indicates that the client needs to authenticate to gain network access."',spec_title:"RFC6585#6",spec_href:"http://tools.ietf.org/html/rfc6585#section-6"},{code:"7xx",phrase:"**Developer Error**",description:"[err](http://www.urbandictionary.com/define.php?term=err)",spec_title:"7xx-rfc",spec_href:"http://documentup.com/joho/7XX-rfc"}]},function(e,t,n){e.exports=[{method:"CONNECT",description:'"requests that the recipient establish a tunnel to the destination origin server identified by the request-target and, if successful, thereafter restrict its behavior to blind forwarding of packets, in both directions, until the connection is closed."',safe:!0,idempotent:!0,cacheable:!1,spec_title:"RFC7231#4.3.6",spec_href:"http://tools.ietf.org/html/rfc7231#section-4.3.6"},{method:"DELETE",description:'"requests that the origin server remove the association between the target resource and its current functionality."',safe:!1,idempotent:!0,cacheable:!1,spec_title:"RFC7231#4.3.5",spec_href:"http://tools.ietf.org/html/rfc7231#section-4.3.5"},{method:"GET",description:'"requests transfer of a current selected representation for the target resource."',safe:!0,idempotent:!0,cacheable:!0,spec_title:"RFC7231#4.3.1",spec_href:"http://tools.ietf.org/html/rfc7231#section-4.3.1"},{method:"HEAD",description:'"is identical to GET except that the server MUST NOT send a message body in the response (i.e., the response terminates at the end of the header block)."',safe:!0,idempotent:!0,cacheable:!0,spec_title:"RFC7231#4.3.2",spec_href:"http://tools.ietf.org/html/rfc7231#section-4.3.2"},{method:"OPTIONS",description:'"requests information about the communication options available on the request/response chain identified by the effective request URI."',safe:!0,idempotent:!0,cacheable:!1,spec_title:"RFC7231#4.3.7",spec_href:"http://tools.ietf.org/html/rfc7231#section-4.3.7"},{method:"POST",description:'"requests that the target resource process the representation enclosed in the request according to the resource\'s own specific semantics."',safe:!1,idempotent:!1,cacheable:!1,spec_title:"RFC7231#4.3.3",spec_href:"http://tools.ietf.org/html/rfc7231#section-4.3.3"},{method:"PUT",description:'"requests that the state of the target resource be created or replaced with the state defined by the representation enclosed in the request message payload."',safe:!1,idempotent:!0,cacheable:!1,spec_title:"RFC7231#4.3.4",spec_href:"http://tools.ietf.org/html/rfc7231#section-4.3.4"},{method:"TRACE",description:'"is used to invoke a remote, application-layer loopback of the request message."',safe:!0,idempotent:!0,cacheable:!1,spec_title:"RFC7231#4.3.8",spec_href:"http://tools.ietf.org/html/rfc7231#section-4.3.8"},{method:"ACL",description:"",safe:!1,idempotent:!0,cacheable:"",spec_title:"RFC3744#8.1",spec_href:"http://tools.ietf.org/html/rfc3744#section-8.1"},{method:"BASELINE-CONTROL",description:"",safe:!1,idempotent:!0,cacheable:"",spec_title:"RFC3253#12.6",spec_href:"http://tools.ietf.org/html/rfc3253#section-12.6"},{method:"BIND",description:"",safe:!1,idempotent:!0,cacheable:"",spec_title:"RFC5842#4",spec_href:"http://tools.ietf.org/html/rfc5842#section-4"},{method:"CHECKIN",description:"",safe:!1,idempotent:!0,cacheable:"",spec_title:"RFC3253#4.4",spec_href:"http://tools.ietf.org/html/rfc3253#section-4.4"},{method:"CHECKOUT",description:"",safe:!1,idempotent:!0,cacheable:"",spec_title:"RFC3253#4.3",spec_href:"http://tools.ietf.org/html/rfc3253#section-4.3"},{method:"COPY",description:"",safe:!1,idempotent:!0,cacheable:"",spec_title:"RFC4918#9.8",spec_href:"http://tools.ietf.org/html/rfc4918#section-9.8"},{method:"LABEL",description:"",safe:!1,idempotent:!0,cacheable:"",spec_title:"RFC3253#8.2",spec_href:"http://tools.ietf.org/html/rfc3253#section-8.2"},{method:"LINK",description:"",safe:!1,idempotent:!0,cacheable:"",spec_title:"RFC2068#19.6.1.2",spec_href:"http://tools.ietf.org/html/rfc2068#section-19.6.1.2"},{method:"LOCK",description:"",safe:!1,idempotent:!1,cacheable:"",spec_title:"RFC4918#9.10",spec_href:"http://tools.ietf.org/html/rfc4918#section-9.10"},{method:"MERGE",description:"",safe:!1,idempotent:!0,cacheable:"",spec_title:"RFC3253#11.2",spec_href:"http://tools.ietf.org/html/rfc3253#section-11.2"},{method:"MKACTIVITY",description:"",safe:!1,idempotent:!0,cacheable:"",spec_title:"RFC3253#13.5",spec_href:"http://tools.ietf.org/html/rfc3253#section-13.5"},{method:"MKCALENDAR",description:"",safe:!1,idempotent:!0,cacheable:"",spec_title:"RFC4791#5.3.1",spec_href:"http://tools.ietf.org/html/rfc4791#section-5.3.1"},{method:"MKCOL",description:"",safe:!1,idempotent:!0,cacheable:"",spec_title:"RFC4918#9.3",spec_href:"http://tools.ietf.org/html/rfc4918#section-9.3"},{method:"MKREDIRECTREF",description:"",safe:!1,idempotent:!0,cacheable:"",spec_title:"RFC4437#6",spec_href:"http://tools.ietf.org/html/rfc4437#section-6"},{method:"MKWORKSPACE",description:"",safe:!1,idempotent:!0,cacheable:"",spec_title:"RFC3253#6.3",spec_href:"http://tools.ietf.org/html/rfc3253#section-6.3"},{method:"MOVE",description:"",safe:!1,idempotent:!0,cacheable:"",spec_title:"RFC4918#9.9",spec_href:"http://tools.ietf.org/html/rfc4918#section-9.9"},{method:"ORDERPATCH",description:"",safe:!1,idempotent:!0,cacheable:"",spec_title:"RFC3648#7",spec_href:"http://tools.ietf.org/html/rfc3648#section-7"},{method:"PATCH",description:'"requests that a set of changes described in the request entity be applied to the resource identified by the Request-URI."',safe:!1,idempotent:!1,cacheable:!1,spec_title:"RFC5789",spec_href:"http://tools.ietf.org/html/rfc5789#section-2"},{method:"PROPFIND",description:"",safe:!0,idempotent:!0,cacheable:"",spec_title:"RFC4918#9.1",spec_href:"http://tools.ietf.org/html/rfc4918#section-9.1"},{method:"PROPPATCH",description:"",safe:!1,idempotent:!0,cacheable:"",spec_title:"RFC4918#9.2",spec_href:"http://tools.ietf.org/html/rfc4918#section-9.2"},{method:"REBIND",description:"",safe:!1,idempotent:!0,cacheable:"",spec_title:"RFC5842#6",spec_href:"http://tools.ietf.org/html/rfc5842#section-6"},{method:"REPORT",description:"",safe:!0,idempotent:!0,cacheable:"",spec_title:"RFC3253#3.6",spec_href:"http://tools.ietf.org/html/rfc3253#section-3.6"},{method:"SEARCH",description:"",safe:!0,idempotent:!0,cacheable:"",spec_title:"RFC5323#2",spec_href:"http://tools.ietf.org/html/rfc5323#section-2"},{method:"UNBIND",description:"",safe:!1,idempotent:!0,cacheable:"",spec_title:"RFC5842#5",spec_href:"http://tools.ietf.org/html/rfc5842#section-5"},{method:"UNCHECKOUT",description:"",safe:!1,idempotent:!0,cacheable:"",spec_title:"RFC3253#4.5",spec_href:"http://tools.ietf.org/html/rfc3253#section-4.5"},{method:"UNLINK",description:"",safe:!1,idempotent:!0,cacheable:"",spec_title:"RFC2068#19.6.1.3",spec_href:"http://tools.ietf.org/html/rfc2068#section-19.6.1.3"},{method:"UNLOCK",description:"",safe:!1,idempotent:!0,cacheable:"",spec_title:"RFC4918#9.11",spec_href:"http://tools.ietf.org/html/rfc4918#section-9.11"},{method:"UPDATE",description:"",safe:!1,idempotent:!0,cacheable:"",spec_title:"RFC3253#7.1",spec_href:"http://tools.ietf.org/html/rfc3253#section-7.1"},{method:"UPDATEREDIRECTREF",description:"",safe:!1,idempotent:!0,cacheable:"",spec_title:"RFC4437#7",spec_href:"http://tools.ietf.org/html/rfc4437#section-7"},{method:"VERSION-CONTROL",description:"",safe:!1,idempotent:!0,cacheable:"",spec_title:"RFC3253#3.5",spec_href:"http://tools.ietf.org/html/rfc3253#section-3.5"}]},function(e,t,n){e.exports=[{header:"Content-Encoding",description:'"indicates what content codings have been applied to the representation, beyond those inherent in the media type, and thus what decoding mechanisms have to be applied in order to obtain data in the media type referenced by the Content-Type header field."',spec_title:"RFC7231#3.1.2.2",spec_href:"http://tools.ietf.org/html/rfc7231#section-3.1.2.2"},{header:"Content-Language",description:'"describes the natural language(s) of the intended audience for the representation."',spec_title:"RFC7231#3.1.3.2",spec_href:"http://tools.ietf.org/html/rfc7231#section-3.1.3.2"},{header:"Content-Location",description:'"references a URI that can be used as an identifier for a specific resource corresponding to the representation in this message\'s payload."',spec_title:"RFC7231#3.1.4.2",spec_href:"http://tools.ietf.org/html/rfc7231#section-3.1.4.2"},{header:"Content-Type",description:'"indicates the media type of the associated representation: either the representation enclosed in the message payload or the selected representation, as determined by the message semantics."',spec_title:"RFC7231#3.1.1.5",spec_href:"http://tools.ietf.org/html/rfc7231#section-3.1.1.5"},{header:"Content-Length",description:'"can provide the anticipated size, as a decimal number of octets, for a potential payload body."',spec_title:"RFC7230#3.3.2",spec_href:"http://tools.ietf.org/html/rfc7230#section-3.3.2"},{header:"Content-Range",description:'"is sent in a single part 206 (Partial Content) response to indicate the partial range of the selected representation enclosed as the message payload, sent in each part of a multipart 206 response to indicate the range enclosed within each body part, and sent in 416 (Range Not Satisfiable) responses to provide information about the selected representation."',spec_title:"RFC7233#4.2",spec_href:"http://tools.ietf.org/html/rfc7233#section-4.2"},{header:"Transfer-Encoding",description:'"lists the transfer coding names corresponding to the sequence of transfer codings that have been (or will be) applied to the payload body in order to form the message body."',spec_title:"RFC7230#3.3.1",spec_href:"http://tools.ietf.org/html/rfc7230#section-3.3.1"},{header:"Cache-Control",description:'"is used to specify directives for caches along the request/response chain."',spec_title:"RFC7234#7.2",spec_href:"http://tools.ietf.org/html/rfc7234#section-7.2"},{header:"Expect",description:'"is used to indicate that particular server behaviors are required by the client."',spec_title:"RFC7231#5.1.1",spec_href:"http://tools.ietf.org/html/rfc7231#section-5.1.1"},{header:"Host",description:'"provides the host and port information from the target URI, enabling the origin server to distinguish among resources while servicing requests for multiple host names on a single IP address."',spec_title:"RFC7230#5.4",spec_href:"http://tools.ietf.org/html/rfc7230#section-5.4"},{header:"Max-Forwards",description:'"provides a mechanism with the TRACE and OPTIONS methods to limit the number of times that the request is forwarded by proxies."',spec_title:"RFC7231#5.1.2",spec_href:"http://tools.ietf.org/html/rfc7231#section-5.1.2"},{header:"Pragma",description:'"allows backwards compatibility with HTTP/1.0 caches, so that clients can specify a "no-cache" request that they will understand (as Cache-Control was not defined until HTTP/1.1)."',spec_title:"RFC7234#7.4",spec_href:"http://tools.ietf.org/html/rfc7234#section-7.4"},{header:"Range",description:'"modifies the method semantics to request transfer of only one or more subranges of the selected representation data, rather than the entire selected representation data."',spec_title:"RFC7233#3.1",spec_href:"http://tools.ietf.org/html/rfc7233#section-3.1"},{header:"TE",description:'"indicates what transfer codings, besides chunked, the client is willing to accept in response, and whether or not the client is willing to accept trailer fields in a chunked transfer coding."',spec_title:"RFC7230#4.3",spec_href:"http://tools.ietf.org/html/rfc7230#section-4.3"},{header:"If-Match",description:'"can be used to make a request method conditional on the current existence or value of an entity-tag for one or more representations of the target resource."',spec_title:"RFC7232#3.1",spec_href:"http://tools.ietf.org/html/rfc7232#section-3.1"},{header:"If-Modified-Since",description:'"can be used with GET or HEAD to make the method conditional by modification date: if the selected representation has not been modified since the time specified in this field, then do not perform the request method; instead, respond as detailed below."',spec_title:"RFC7232#3.3",spec_href:"http://tools.ietf.org/html/rfc7232#section-3.3"},{header:"If-None-Match",description:'"can be used to make a request method conditional on not matching any of the current entity-tag values for representations of the target resource."',spec_title:"RFC7232#3.2",spec_href:"http://tools.ietf.org/html/rfc7232#section-3.2"},{header:"If-Range",description:'"Informally, its meaning is: if the representation is unchanged, send me the part(s) that I am requesting in Range; otherwise, send me the entire representation."',spec_title:"RFC7233#3.2",spec_href:"http://tools.ietf.org/html/rfc7233#section-3.2"},{header:"If-Unmodified-Since",description:'"can be used to make a request method conditional by modification date: if the selected representation has been modified since the time specified in this field, then the server MUST NOT perform the requested operation and MUST instead respond with the 412 (Precondition Failed) status code."',spec_title:"RFC7232#3.4",spec_href:"http://tools.ietf.org/html/rfc7232#section-3.4"},{header:"Accept",description:'"can be used to specify certain media types which are acceptable for the response."',spec_title:"RFC7231#5.3.2",spec_href:"http://tools.ietf.org/html/rfc7231#section-5.3.2"},{header:"Accept-Charset",description:'"can be sent by a user agent to indicate what charsets are acceptable in textual response content."',spec_title:"RFC7231#5.3.3",spec_href:"http://tools.ietf.org/html/rfc7231#section-5.3.3"},{header:"Accept-Encoding",description:'"can be used by user agents to indicate what response content-codings are acceptable in the response."',spec_title:"RFC7231#5.3.4",spec_href:"http://tools.ietf.org/html/rfc7231#section-5.3.4"},{header:"Accept-Language",description:'"can be used by user agents to indicate the set of natural languages that are preferred in the response."',spec_title:"RFC7231#5.3.5",spec_href:"http://tools.ietf.org/html/rfc7231#section-5.3.5"},{header:"Authorization",description:'"allows a user agent to authenticate itself with a server -- usually, but not necessarily, after receiving a 401 (Unauthorized) response."',spec_title:"RFC7235#4.1",spec_href:"http://tools.ietf.org/html/rfc7235#section-4.1"},{header:"Proxy-Authorization",description:'"allows the client to identify itself (or its user) to a proxy that requires authentication."',spec_title:"RFC7235#4.3",spec_href:"http://tools.ietf.org/html/rfc7235#section-4.3"},{header:"DNT",description:'"defined as the means for expressing a user\'s tracking preference via HTTP."',spec_title:"Tracking Preference Expression (DNT)",spec_href:"http://www.w3.org/TR/tracking-dnt/#dnt-header-field"},{header:"From",description:'"contains an Internet email address for a human user who controls the requesting user agent."',spec_title:"RFC7231#5.5.1",spec_href:"http://tools.ietf.org/html/rfc7231#section-5.5.1"},{header:"Referer",description:'"allows the user agent to specify a URI reference for the resource from which the target URI was obtained (i.e., the "referrer", though the field name is misspelled)."',spec_title:"RFC7231#5.5.2",spec_href:"http://tools.ietf.org/html/rfc7231#section-5.5.2"},{header:"User-Agent",description:'"contains information about the user agent originating the request, which is often used by servers to help identify the scope of reported interoperability problems, to work around or tailor responses to avoid particular user agent limitations, and for analytics regarding browser or operating system use."',spec_title:"RFC7231#5.5.3",spec_href:"http://tools.ietf.org/html/rfc7231#section-5.5.3"},{header:"Age",description:'"conveys the sender\'s estimate of the amount of time since the response was generated or successfully validated at the origin server."',spec_title:"RFC7234#5.1",spec_href:"http://tools.ietf.org/html/rfc7234#section-5.1"},{header:"Cache-Control",description:'"is used to specify directives for caches along the request/response chain."',spec_title:"RFC7234#7.2",spec_href:"http://tools.ietf.org/html/rfc7234#section-7.2"},{header:"Expires",description:'"gives the date/time after which the response is considered stale."',spec_title:"RFC7234#7.3",spec_href:"http://tools.ietf.org/html/rfc7234#section-7.3"},{header:"Date",description:'"represents the date and time at which the message was originated"',spec_title:"RFC7231#7.1.1.2",spec_href:"http://tools.ietf.org/html/rfc7231#section-7.1.1.2"},{header:"Location",description:'"is used in some responses to refer to a specific resource in relation to the response."',spec_title:"RFC7231#7.1.2",spec_href:"http://tools.ietf.org/html/rfc7231#section-7.1.2"},{header:"Retry-After",description:'"indicates how long the user agent ought to wait before making a follow-up request."',spec_title:"RFC7231#7.1.3",spec_href:"http://tools.ietf.org/html/rfc7231#section-7.1.3"},{header:"Tk",description:'"defined as an OPTIONAL means for indicating the tracking status that applied to the corresponding request and as a REQUIRED means for indicating that a state-changing request has resulted in an interactive change to the tracking status. "',spec_title:"Tracking Preference Expression (DNT)",spec_href:"http://www.w3.org/TR/tracking-dnt/#response-header-field"},{header:"Vary",description:'"describes what parts of a request message, aside from the method and request target, might influence the origin server\'s process for selecting and representing the response."',spec_title:"RFC7231#7.1.4",spec_href:"http://tools.ietf.org/html/rfc7231#section-7.1.4"},{header:"Warning",description:'"is used to carry additional information about the status or transformation of a message that might not be reflected in the message."',spec_title:"RFC7234#7.6",spec_href:"http://tools.ietf.org/html/rfc7234#section-7.6"},{header:"ETag",description:'"provides the current entity-tag for the selected representation, as determined at the conclusion of handling the request."',spec_title:"RFC7232#2.3",spec_href:"http://tools.ietf.org/html/rfc7232#section-2.3"},{header:"Last-Modified",description:'"provides a timestamp indicating the date and time at which the origin server believes the selected representation was last modified, as determined at the conclusion of handling the request."',spec_title:"RFC7232#2.2",spec_href:"http://tools.ietf.org/html/rfc7232#section-2.2"},{header:"WWW-Authenticate",description:'"consists of at least one challenge that indicates the authentication scheme(s) and parameters applicable to the effective request URI."',spec_title:"RFC7235#4.4",spec_href:"http://tools.ietf.org/html/rfc7235#section-4.4"},{header:"Proxy-Authenticate",description:'"consists of at least one challenge that indicates the authentication scheme(s) and parameters applicable to the proxy for this effective request URI."',spec_title:"RFC7235#4.2",spec_href:"http://tools.ietf.org/html/rfc7235#section-4.2"},{header:"Accept-Ranges",description:'"allows a server to indicate that it supports range requests for the target resource."',spec_title:"RFC7233#2.3",spec_href:"http://tools.ietf.org/html/rfc7233#section-2.3"},{header:"Allow",description:'"lists the set of methods advertised as supported by the target resource."',spec_title:"RFC7231#7.4.1",spec_href:"http://tools.ietf.org/html/rfc7231#section-7.4.1"},{header:"Server",description:'"contains information about the software used by the origin server to handle the request, which is often used by clients to help identify the scope of reported interoperability problems, to work around or tailor requests to avoid particular server limitations, and for analytics regarding server or operating system use."',spec_title:"RFC7231#7.4.2",spec_href:"http://tools.ietf.org/html/rfc7231#section-7.4.2"},{header:"Accept-Patch",description:'"used to specify the patch document formats accepted by the server."',spec_title:"RFC5789#3.1",spec_href:"http://tools.ietf.org/html/rfc5789#section-3.1"},{header:"Accept-Post",description:'"indicates server support for specific media types for entity bodies in HTTP POST requests."',spec_title:"draft-wilde-accept-post",spec_href:"http://tools.ietf.org/html/draft-wilde-accept-post"},{header:"Access-Control-Allow-Credentials",description:'"indicates whether the response to request can be exposed when the omit credentials flag is unset"',spec_title:"CORS",spec_href:"http://www.w3.org/TR/cors/#access-control-allow-credentials-response-header"},{header:"Access-Control-Allow-Headers",description:'"indicates, as part of the response to a preflight request, which header field names can be used during the actual request"',spec_title:"CORS",spec_href:"http://www.w3.org/TR/cors/#access-control-allow-headers-response-header"},{header:"Access-Control-Allow-Methods",description:'"indicates, as part of the response to a preflight request, which methods can be used during the actual request"',spec_title:"CORS",spec_href:"http://www.w3.org/TR/cors/#access-control-allow-methods-response-header"},{header:"Access-Control-Allow-Origin",description:'"indicates whether a resource can be shared"',spec_title:"CORS",spec_href:"http://www.w3.org/TR/cors/#access-control-allow-origin-response-header"},{header:"Access-Control-Expose-Headers",description:'"indicates which headers are safe to expose to the API of a CORS API specification"',spec_title:"CORS",spec_href:"http://www.w3.org/TR/cors/#access-control-expose-headers-response-header"},{header:"Access-Control-Max-Age",description:'"indicates how long the results of a preflight request can be cached in a preflight result cache"',spec_title:"CORS",spec_href:"http://www.w3.org/TR/cors/#access-control-max-age-response-header"},{header:"Access-Control-Request-Headers",description:'"indicates which headers will be used in the actual request as part of the preflight request"',spec_title:"CORS",spec_href:"http://www.w3.org/TR/cors/#access-control-request-headers-request-header"},{header:"Access-Control-Request-Method",description:'"indicates which method will be used in the actual request as part of the preflight request"',spec_title:"CORS",spec_href:"http://www.w3.org/TR/cors/#access-control-request-method-request-header"},{header:"Content-Disposition",description:'"standard"',spec_title:"RFC6266",spec_href:"http://tools.ietf.org/html/rfc6266"},{header:"Content-Security-Policy",description:'"is the preferred mechanism for delivering a CSP policy"',spec_title:"CSP",spec_href:"http://www.w3.org/TR/CSP/#content-security-policy-header-field"},{header:"Content-Security-Policy-Report-Only",description:'"lets servers experiment with policies by monitoring (rather than enforcing) a policy"',spec_title:"CSP",spec_href:"http://www.w3.org/TR/CSP/#content-security-policy-report-only-header-field"},{header:"Cookie",description:'"standard"',spec_title:"RFC6265",spec_href:"http://tools.ietf.org/html/rfc6265"},{header:"Forwarded",description:'"standard"',spec_title:"RFC7239",spec_href:"http://tools.ietf.org/html/rfc7239"},{header:"Link",description:'"provides a means for serialising one or more links in HTTP headers."',spec_title:"RFC5988#5",spec_href:"http://tools.ietf.org/html/rfc5988#section-5"},{header:"Origin",description:'"standard"',spec_title:"RFC6454",spec_href:"http://tools.ietf.org/html/rfc6454"},{header:"Prefer",description:'"is used to indicate that particular server behaviors are preferred by the client, but not required for successful completion of the request."',spec_title:"draft-snell-http-prefer#2",spec_href:"http://tools.ietf.org/html/draft-snell-http-prefer#section-2"},{header:"Preference-Applied",description:'"MAY be included within a response message as an indication as to which Prefer tokens were honored by the server and applied to the processing of a request."',spec_title:"draft-snell-http-prefer#3",spec_href:"http://tools.ietf.org/html/draft-snell-http-prefer#section-3"},{header:"Set-Cookie",description:'"standard"',spec_title:"RFC6265",spec_href:"http://tools.ietf.org/html/rfc6265"},{header:"Strict-Transport-Security",description:'"standard"',spec_title:"RFC6797",spec_href:"http://tools.ietf.org/html/rfc6797"},{header:"Via",description:'""',spec_title:"RFC7230#5.7.1",spec_href:"http://tools.ietf.org/html/rfc7230#section-5.7.1"},{header:"A-IM",description:'""',spec_title:"RFC3229#10.5.3",spec_href:"http://tools.ietf.org/html/rfc3229#section-10.5.3"},{header:"Accept-Features",description:'"can be used by a user agent to give information about the presence or absence of certain features in the feature set of the current request."',spec_title:"RFC2295#8.2",spec_href:"http://tools.ietf.org/html/rfc2295#section-8.2"},{header:"Alt-Svc",description:'"is advertising the availability of alternate services to HTTP/1.1 and HTTP/2.0 clients by adding an Alt-Svc header field to responses."',spec_title:"draft-nottingham-httpbis-alt-svc",spec_href:"http://tools.ietf.org/html/draft-nottingham-httpbis-alt-svc"},{header:"Alternates",description:'"is used to convey the list of variants bound to a negotiable resource."',spec_title:"RFC2295#8.3",spec_href:"http://tools.ietf.org/html/rfc2295#section-8.3"},{header:"Apply-To-Redirect-Ref",description:'""',spec_title:"RFC4437",spec_href:"http://tools.ietf.org/html/rfc4437"},{header:"CH",description:'"describes an example list of client preferences that the server can use to adapt and optimize the resource to satisfy a given request."',spec_title:"draft-grigorik-http-client-hints",spec_href:"http://tools.ietf.org/html/draft-grigorik-http-client-hints"},{header:"Content-Base",description:'"obsoleted"',spec_title:"RFC2068",spec_href:"http://tools.ietf.org/html/rfc2068"},{header:"Cookie2",description:'"obsoleted"',spec_title:"RFC2965",spec_href:"http://tools.ietf.org/html/rfc2965"},{header:"DASL",description:'"standard"',spec_title:"RFC5323",spec_href:"http://tools.ietf.org/html/rfc5323"},{header:"DAV",description:'"standard"',spec_title:"RFC4918",spec_href:"http://tools.ietf.org/html/rfc4918"},{header:"Delta-Base",description:'""',spec_title:"RFC3229#10.5.1",spec_href:"http://tools.ietf.org/html/rfc3229#section-10.5.1"},{header:"Depth",description:'"standard"',spec_title:"RFC4918",spec_href:"http://tools.ietf.org/html/rfc4918"},{header:"Destination",description:'"standard"',spec_title:"RFC4918",spec_href:"http://tools.ietf.org/html/rfc4918"},{header:"IM",description:'""',spec_title:"RFC3229#10.5.2",spec_href:"http://tools.ietf.org/html/rfc3229#section-10.5.2"},{header:"If",description:'"standard"',spec_title:"RFC4918",spec_href:"http://tools.ietf.org/html/rfc4918"},{header:"If-Schedule-Tag-Match",description:'"standard"',spec_title:"RFC6638",spec_href:"http://tools.ietf.org/html/rfc6638"},{header:"Last-Event-ID",description:'"The value of the event source\'s last event ID string, encoded as UTF-8."',spec_title:"Server-Sent Events",spec_href:"http://www.w3.org/TR/eventsource/#last-event-id"},{header:"Link-Template",description:'"provides a means for serialising one or more links into HTTP headers."',spec_title:"draft-nottingham-link-template",spec_href:"http://tools.ietf.org/html/draft-nottingham-link-template"},{header:"Lock-Token",description:'"standard"',spec_title:"RFC4918",spec_href:"http://tools.ietf.org/html/rfc4918"},{header:"Negotiate",description:'"can contain directives for any content negotiation process initiated by the request."',spec_title:"RFC2295#8.4",spec_href:"http://tools.ietf.org/html/rfc2295#section-8.4"
},{header:"Nice",description:'"indicates that a request is less important than a request that doesn\'t bear this header."',spec_title:"draft-thomson-http-nice",spec_href:"http://tools.ietf.org/html/draft-thomson-http-nice"},{header:"Overwrite",description:'"standard"',spec_title:"RFC4918",spec_href:"http://tools.ietf.org/html/rfc4918"},{header:"Redirect-Ref",description:'""',spec_title:"RFC4437",spec_href:"http://tools.ietf.org/html/rfc4437"},{header:"Schedule-Reply",description:'"standard"',spec_title:"RFC6638",spec_href:"http://tools.ietf.org/html/rfc6638"},{header:"Schedule-Tag",description:'"standard"',spec_title:"RFC6638",spec_href:"http://tools.ietf.org/html/rfc6638"},{header:"Sec-WebSocket-Accept",description:'"standard"',spec_title:"RFC6455",spec_href:"http://tools.ietf.org/html/rfc6455"},{header:"Sec-WebSocket-Extensions",description:'"standard"',spec_title:"RFC6455",spec_href:"http://tools.ietf.org/html/rfc6455"},{header:"Sec-WebSocket-Key",description:'"standard"',spec_title:"RFC6455",spec_href:"http://tools.ietf.org/html/rfc6455"},{header:"Sec-WebSocket-Protocol",description:'"standard"',spec_title:"RFC6455",spec_href:"http://tools.ietf.org/html/rfc6455"},{header:"Sec-WebSocket-Version",description:'"standard"',spec_title:"RFC6455",spec_href:"http://tools.ietf.org/html/rfc6455"},{header:"Set-Cookie2",description:'"obsoleted"',spec_title:"RFC2965",spec_href:"http://tools.ietf.org/html/rfc2965"},{header:"SLUG",description:'"standard"',spec_title:"RFC5023",spec_href:"http://tools.ietf.org/html/rfc5023"},{header:"TCN",description:'"is used by a server to signal that the resource is transparently negotiated."',spec_title:"RFC2295#8.5",spec_href:"http://tools.ietf.org/html/rfc2295#section-8.5"},{header:"Timeout",description:'"standard"',spec_title:"RFC4918",spec_href:"http://tools.ietf.org/html/rfc4918"},{header:"Variant-Vary",description:'"can be used in a choice response to record any vary information which applies to the variant data (the entity body combined with some of the entity headers) contained in the response, rather than to the response as a whole."',spec_title:"RFC2295#8.6",spec_href:"http://tools.ietf.org/html/rfc2295#section-8.6"},{header:"X-Frame-Options",description:'"indicates a policy that specifies whether the browser should render the transmitted resource within a <frame> or an <iframe>. Servers can declare this policy in the header of their HTTP responses to prevent clickjacking attacks, which ensures that their content is not embedded into other pages or frames."',spec_title:"RFC7034",spec_href:"http://tools.ietf.org/html/rfc7034"}]},function(e,t,n){e.exports=[{relation:"about",description:'"Refers to a resource that is the subject of the link\'s context."',spec_title:"RFC6903",spec_href:"http://tools.ietf.org/html/rfc6903"},{relation:"alternate",description:'"Refers to a substitute for this context"',spec_title:"HTML5links",spec_href:"http://www.w3.org/TR/html5/links.html#link-type-alternate"},{relation:"appendix",description:'"Refers to an appendix."',spec_title:"HTML401",spec_href:"http://www.w3.org/TR/1999/REC-html401-19991224"},{relation:"archives",description:'"Refers to a collection of records, documents, or other materials of historical interest."',spec_title:"HTML5linksWD",spec_href:"http://www.w3.org/TR/2011/WD-html5-20110113/links.html#rel-archives"},{relation:"author",description:'"Refers to the context\'s author."',spec_title:"HTML5links",spec_href:"http://www.w3.org/TR/html5/links.html#link-type-author"},{relation:"bookmark",description:'"Gives a permanent link to use for bookmarking purposes."',spec_title:"HTML5links",spec_href:"http://www.w3.org/TR/html5/links.html#link-type-bookmark"},{relation:"canonical",description:'"Designates the preferred version of a resource (the IRI and its contents)."',spec_title:"RFC6596",spec_href:"http://tools.ietf.org/html/rfc6596"},{relation:"chapter",description:'"Refers to a chapter in a collection of resources."',spec_title:"HTML401",spec_href:"http://www.w3.org/TR/1999/REC-html401-19991224"},{relation:"collection",description:'"The target IRI points to a resource which represents the collection resource for the context IRI."',spec_title:"RFC6573",spec_href:"http://tools.ietf.org/html/rfc6573"},{relation:"contents",description:'"Refers to a table of contents."',spec_title:"HTML401",spec_href:"http://www.w3.org/TR/1999/REC-html401-19991224"},{relation:"copyright",description:'"Refers to a copyright statement that applies to the link\'s context."',spec_title:"HTML401",spec_href:"http://www.w3.org/TR/1999/REC-html401-19991224"},{relation:"create-form",description:'"The target IRI points to a resource where a submission form can be obtained."',spec_title:"RFC6861",spec_href:"http://tools.ietf.org/html/rfc6861"},{relation:"current",description:'"Refers to a resource containing the most recent item(s) in a collection of resources."',spec_title:"RFC5005",spec_href:"http://tools.ietf.org/html/rfc5005"},{relation:"describedby",description:'"Refers to a resource providing information about the link\'s context."',spec_title:"POWDER",spec_href:"http://www.w3.org/TR/powder-dr/#assoc-linking"},{relation:"describes",description:"\"The relationship A 'describes' B asserts that resource A provides a description of resource B. There are no constraints on the format or representation of either A or B, neither are there any further constraints on either resource.\"",spec_title:"RFC6892",spec_href:"http://tools.ietf.org/html/rfc6892"},{relation:"disclosure",description:'"Refers to a list of patent disclosures made with respect to material for which `disclosure` relation is specified."',spec_title:"RFC6579",spec_href:"http://tools.ietf.org/html/rfc6579"},{relation:"duplicate",description:'"Refers to a resource whose available representations are byte-for-byte identical with the corresponding representations of the context IRI."',spec_title:"RFC6249",spec_href:"http://tools.ietf.org/html/rfc6249"},{relation:"edit",description:'"Refers to a resource that can be used to edit the link\'s context."',spec_title:"RFC5023",spec_href:"http://tools.ietf.org/html/rfc5023"},{relation:"edit-form",description:'"The target IRI points to a resource where a submission form for editing associated resource can be obtained."',spec_title:"RFC6861",spec_href:"http://tools.ietf.org/html/rfc6861"},{relation:"edit-media",description:'"Refers to a resource that can be used to edit media associated with the link\'s context."',spec_title:"RFC5023",spec_href:"http://tools.ietf.org/html/rfc5023"},{relation:"enclosure",description:'"Identifies a related resource that is potentially large and might require special handling."',spec_title:"RFC4287",spec_href:"http://tools.ietf.org/html/rfc4287"},{relation:"first",description:'"An IRI that refers to the furthest preceding resource in a series of resources."',spec_title:"RFC5988",spec_href:"http://tools.ietf.org/html/rfc5988"},{relation:"glossary",description:'"Refers to a glossary of terms."',spec_title:"HTML401",spec_href:"http://www.w3.org/TR/1999/REC-html401-19991224"},{relation:"help",description:'"Refers to context-sensitive help."',spec_title:"HTML5links",spec_href:"http://www.w3.org/TR/html5/links.html#link-type-help"},{relation:"hosts",description:'"Refers to a resource hosted by the server indicated by the link context."',spec_title:"RFC6690",spec_href:"http://tools.ietf.org/html/rfc6690"},{relation:"hub",description:'"Refers to a hub that enables registration for notification of updates to the context."',spec_title:"pubsubhubbub",spec_href:"http://pubsubhubbub.googlecode.com"},{relation:"icon",description:'"Refers to an icon representing the link\'s context."',spec_title:"HTML5links",spec_href:"http://www.w3.org/TR/html5/links.html#link-type-icon"},{relation:"index",description:'"Refers to an index."',spec_title:"HTML401",spec_href:"http://www.w3.org/TR/1999/REC-html401-19991224"},{relation:"item",description:'"The target IRI points to a resource that is a member of the collection represented by the context IRI."',spec_title:"RFC6573",spec_href:"http://tools.ietf.org/html/rfc6573"},{relation:"last",description:'"An IRI that refers to the furthest following resource in a series of resources."',spec_title:"RFC5988",spec_href:"http://tools.ietf.org/html/rfc5988"},{relation:"latest-version",description:'"Points to a resource containing the latest (e.g., current) version of the context."',spec_title:"RFC5829",spec_href:"http://tools.ietf.org/html/rfc5829"},{relation:"license",description:'"Refers to a license associated with this context."',spec_title:"RFC4946",spec_href:"http://tools.ietf.org/html/rfc4946"},{relation:"lrdd",description:'"Refers to further information about the link\'s context, expressed as a LRDD (Link-based Resource Descriptor Document) resource. See [RFC6415](http://tools.ietf.org/html/rfc6415) for information about processing this relation type in host-meta documents. When used elsewhere, it refers to additional links and other metadata. Multiple instances indicate additional LRDD resources. LRDD resources MUST have an "application/xrd+xml" representation, and MAY have others."',spec_title:"RFC6415",spec_href:"http://tools.ietf.org/html/rfc6415"},{relation:"monitor",description:'"Refers to a resource that can be used to monitor changes in an HTTP resource."',spec_title:"RFC5989",spec_href:"http://tools.ietf.org/html/rfc5989"},{relation:"monitor-group",description:'"Refers to a resource that can be used to monitor changes in a specified group of HTTP resources."',spec_title:"RFC5989",spec_href:"http://tools.ietf.org/html/rfc5989"},{relation:"next",description:'"Indicates that the link\'s context is a part of a series, and that the next in the series is the link target."',spec_title:"HTML5links",spec_href:"http://www.w3.org/TR/html5/links.html#link-type-next"},{relation:"next-archive",description:'"Refers to the immediately following archive resource."',spec_title:"RFC5005",spec_href:"http://tools.ietf.org/html/rfc5005"},{relation:"nofollow",description:'"Indicates that the context’s original author or publisher does not endorse the link target."',spec_title:"HTML5links",spec_href:"http://www.w3.org/TR/html5/links.html#link-type-nofollow"},{relation:"noreferrer",description:'"Indicates that no referrer information is to be leaked when following the link."',spec_title:"HTML5links",spec_href:"http://www.w3.org/TR/html5/links.html#link-type-noreferrer"},{relation:"payment",description:'"Indicates a resource where payment is accepted."',spec_title:"RFC5988",spec_href:"http://tools.ietf.org/html/rfc5988"},{relation:"predecessor-version",description:'"Points to a resource containing the predecessor version in the version history."',spec_title:"RFC5829",spec_href:"http://tools.ietf.org/html/rfc5829"},{relation:"prefetch",description:'"Indicates that the link target should be preemptively cached."',spec_title:"HTML5links",spec_href:"http://www.w3.org/TR/html5/links.html#link-type-prefetch"},{relation:"prev",description:'"Indicates that the link\'s context is a part of a series, and that the previous in the series is the link target."',spec_title:"HTML5links",spec_href:"http://www.w3.org/TR/html5/links.html#link-type-prev"},{relation:"preview",description:'"Refers to a resource that provides a preview of the link\'s context."',spec_title:"RFC6903",spec_href:"http://tools.ietf.org/html/rfc6903"},{relation:"previous",description:'"Refers to the previous resource in an ordered series of resources. Synonym for `prev`."',spec_title:"HTML401",spec_href:"http://www.w3.org/TR/1999/REC-html401-19991224"},{relation:"prev-archive",description:'"Refers to the immediately preceding archive resource."',spec_title:"RFC5005",spec_href:"http://tools.ietf.org/html/rfc5005"},{relation:"privacy-policy",description:'"Refers to a privacy policy associated with the link\'s context."',spec_title:"RFC6903",spec_href:"http://tools.ietf.org/html/rfc6903"},{relation:"profile",description:"Identifying that a resource representation conforms to a certain profile, without affecting the non-profile semantics of the resource representation",spec_title:"RFC6906",spec_href:"http://tools.ietf.org/html/rfc6906"},{relation:"related",description:'"Identifies a related resource."',spec_title:"RFC4287",spec_href:"http://tools.ietf.org/html/rfc4287"},{relation:"replies",description:'"Identifies a resource that is a reply to the context of the link."',spec_title:"RFC4685",spec_href:"http://tools.ietf.org/html/rfc4685"},{relation:"search",description:'"Refers to a resource that can be used to search through the link\'s context and related resources."',spec_title:"OpenSearch",spec_href:"http://www.opensearch.org/Specifications/OpenSearch/1.1"},{relation:"section",description:'"Refers to a section in a collection of resources."',spec_title:"HTML401",spec_href:"http://www.w3.org/TR/1999/REC-html401-19991224"},{relation:"self",description:'"Conveys an identifier for the link\'s context."',spec_title:"RFC4287",spec_href:"http://tools.ietf.org/html/rfc4287"},{relation:"service",description:'"Indicates a URI that can be used to retrieve a service document."',spec_title:"RFC5023",spec_href:"http://tools.ietf.org/html/rfc5023"},{relation:"start",description:'"Refers to the first resource in a collection of resources."',spec_title:"HTML401",spec_href:"http://www.w3.org/TR/1999/REC-html401-19991224"},{relation:"stylesheet",description:'"Refers to a stylesheet."',spec_title:"HTML5links",spec_href:"http://www.w3.org/TR/html5/links.html#link-type-stylesheet"},{relation:"subsection",description:'"Refers to a resource serving as a subsection in a collection of resources."',spec_title:"HTML401",spec_href:"http://www.w3.org/TR/1999/REC-html401-19991224"},{relation:"successor-version",description:'"Points to a resource containing the successor version in the version history."',spec_title:"RFC5829",spec_href:"http://tools.ietf.org/html/rfc5829"},{relation:"tag",description:'"Gives a tag (identified by the given address) that applies to the current document."',spec_title:"HTML5links",spec_href:"http://www.w3.org/TR/html5/links.html#link-type-tag"},{relation:"terms-of-service",description:'"Refers to the terms of service associated with the link\'s context."',spec_title:"RFC6903",spec_href:"http://tools.ietf.org/html/rfc6903"},{relation:"type",description:'"Refers to a resource identifying the abstract semantic type of which the link\'s context is considered to be an instance."',spec_title:"RFC6903",spec_href:"http://tools.ietf.org/html/rfc6903"},{relation:"up",description:'"Refers to a parent document in a hierarchy of documents."',spec_title:"RFC5988",spec_href:"http://tools.ietf.org/html/rfc5988"},{relation:"version-history",description:'"Points to a resource containing the version history for the context."',spec_title:"RFC5829",spec_href:"http://tools.ietf.org/html/rfc5829"},{relation:"via",description:'"Identifies a resource that is the source of the information in the link\'s context."',spec_title:"RFC4287",spec_href:"http://tools.ietf.org/html/rfc4287"},{relation:"working-copy",description:'"Points to a working copy for this resource."',spec_title:"RFC5829",spec_href:"http://tools.ietf.org/html/rfc5829"},{relation:"working-copy-of",description:'"Points to the versioned resource from which this working copy was obtained."',spec_title:"RFC5829",spec_href:"http://tools.ietf.org/html/rfc5829"}]},function(e,t,n){e.exports={12:{code:"12",message:""},24:{code:"24",message:""},25:{code:"25",message:""},SCHEMA_AND_TYPE:{code:"SCHEMA_AND_TYPE",message:"'schema' and 'type' are mutually exclusive"},REQUIRED_OVERRIDE_OPTIONAL:{code:"REQUIRED_OVERRIDE_OPTIONAL",message:"Can not override required property '{{propertyName}}' to be optional"},CYCLIC_DEPENDENCY:{code:"CYCLIC_DEPENDENCY",message:"'{{typeName}}' has cyclic dependency"},REDEFINIG_BUILDTIN:{code:"REDEFINIG_BUILDTIN",message:"Redefining a built in type: {{typeName}}"},RECURRENT_DEFINITION:{code:"RECURRENT_DEFINITION",message:"Recurrent type definition"},INHERITING_UNKNOWN_TYPE:{code:"INHERITING_UNKNOWN_TYPE",message:"Inheriting from unknown type"},RECURRENT_UNION_OPTION:{code:"RECURRENT_UNION_OPTION",message:"Recurrent type as an option of union type"},UNKNOWN_UNION_OPTION:{code:"UNKNOWN_UNION_OPTION",message:"Unknown type as an option of union type"},RECURRENT_ARRAY_DEFINITION:{code:"RECURRENT_ARRAY_DEFINITION",message:"Recurrent array type definition"},UNKNOWN_ARRAY_COMPONENT:{code:"UNKNOWN_ARRAY_COMPONENT",message:"Referring to unknown type '{{componentTypeName}}' as an array component type"},EXTERNALS_MIX:{code:"EXTERNALS_MIX",message:"It is not allowed to mix RAML types with externals"},EXTERNAL_FACET:{code:"EXTERNAL_FACET",message:"External types can not declare facet '{{name}}'"},OVERRIDE_FACET:{code:"OVERRIDE_FACET",message:"Facet '{{name}}' can not be overriden"},OVERRIDE_BUILTIN_FACET:{code:"OVERRIDE_BUILTIN_FACET",message:"Built in facet '{{name}}' can not be overriden"},FACET_START_BRACKET:{code:"FACET_START_BRACKET",message:"Facet '{{name}}' can not start from '('"},FACET_PROHIBITED_FOR_EXTERNALS:{code:"FACET_PROHIBITED_FOR_EXTERNALS",message:"'{{facetName}}' facet is prohibited for external types"},UNKNOWN_FACET:{code:"UNKNOWN_FACET",message:"Specifying unknown facet: '{{facetName}}'"},MISSING_REQUIRED_FACETS:{code:"MISSING_REQUIRED_FACETS",message:"Missing required facets: {{facetsList}}"},OBJECT_EXPECTED:{code:"OBJECT_EXPECTED",message:"object is expected"},NULL_NOT_ALLOWED:{code:"NULL_NOT_ALLOWED",message:"Null or undefined value is not allowed"},DISCRIMINATOR_NEEDED:{code:"DISCRIMINATOR_NEEDED",message:"Can not discriminate types '{{name1}}' and '{{name2}}' without discriminator"},SAME_DISCRIMINATOR_VALUE:{code:"SAME_DISCRIMINATOR_VALUE",message:"Types '{{name1}}' and '{{name2}}' have same discriminator value"},NOTHING:{code:"NOTHING",message:"nothing"},TYPE_EXPECTED:{code:"TYPE_EXPECTED",message:"{{typeName}} is expected"},INTEGER_EXPECTED:{code:"INTEGER_EXPECTED",message:"integer is expected"},NULL_EXPECTED:{code:"NULL_EXPECTED",message:"null is expected"},SCALAR_EXPECTED:{code:"SCALAR_EXPECTED",message:"scalar is expected"},INCORRECT_DISCRIMINATOR:{code:"INCORRECT_DISCRIMINATOR",message:"None of the '{{rootType}}' type known subtypes declare '{{value}}' as value of discriminating property '{{propName}}'."},MISSING_DISCRIMINATOR:{code:"MISSING_DISCRIMINATOR",message:"Instance of '{{rootType}}' subtype misses value of the discriminating property '{{propName}}'."},INVALID_DATEONLY:{code:"INVALID_DATEONLY",message:"'date-only' instance should match 'yyyy-mm-dd' pattern"},INVALID_TIMEONLY:{code:"INVALID_TIMEONLY",message:"'time-only' instance should match 'hh:mm:ss[.ff...]' pattern"},INVALID_DATETIMEONLY:{code:"INVALID_DATETIMEONLY",message:"'datetime-only' instance should match 'yyyy-mm-ddThh:mm:ss[.ff...]' pattern"},INVALID_RFC3339:{code:"INVALID_RFC3339",message:"Valid rfc3339 formatted string is expected"},INVALID_RFC2616:{code:"INVALID_RFC2616",message:"Valid rfc2616 formatted string is expected"},INVALID_DATTIME:{code:"INVALID_DATTIME",message:"Valid datetime formatted string is expected"},UNKNOWN_ANNOTATION:{code:"UNKNOWN_ANNOTATION",message:"Using unknown annotation type: '{{facetName}}'"},INVALID_ANNOTATION_VALUE:{code:"INVALID_ANNOTATION_VALUE",message:"Invalid annotation value {{msg}}"},CAN_NOT_PARSE_JSON:{code:"CAN_NOT_PARSE_JSON",message:"Can not parse JSON example: {{msg}}"},INVALID_XML:{code:"INVALID_XML",message:"Invalid XML."},STRICT_BOOLEAN:{code:"STRICT_BOOLEAN",message:"'strict' should be boolean"},DISPLAY_NAME_STRING:{code:"DISPLAY_NAME_STRING",message:"'displayName' should be string"},DESCRIPTION_STRING:{code:"DESCRIPTION_STRING",message:"'description' should be string"},INVALID_EXMAPLE:{code:"INVALID_EXMAPLE",message:"Using invalid 'example': {{msg}}"},ADDITIONAL_PROPERTIES_BOOLEAN:{code:"REQUIRED_BOOLEAN",message:"Value of 'additionalProperties' facet should be boolean"},REQUIRED_BOOLEAN:{code:"REQUIRED_BOOLEAN",message:"Value of 'required' facet should be boolean"},UNIQUE_ITEMS_BOOLEAN:{code:"UNIQUE_ITEMS_BOOLEAN",message:"Value of 'uniqueItems' facet should be boolean"},EXMAPLES_MAP:{code:"EXMAPLES_MAP",message:"'examples' value should be a map"},INVALID_DEFAULT_VALUE:{code:"INVALID_DEFAULT_VALUE",message:"Using invalid 'defaultValue': {{msg}}"},DISCRIMINATOR_FOR_UNION:{code:"DISCRIMINATOR_FOR_UNION",message:"You can not specify 'discriminator' for union types"},DISCRIMINATOR_FOR_OBJECT:{code:"DISCRIMINATOR_FOR_OBJECT",message:"You only can use 'discriminator' with object types"},DISCRIMINATOR_FOR_INLINE:{code:"DISCRIMINATOR_FOR_INLINE",message:"You can not specify 'discriminator' for inline type declarations"},UNKNOWN_FOR_DISCRIMINATOR:{code:"UNKNOWN_FOR_DISCRIMINATOR",message:"Using unknown property '{{value}}' as discriminator"},SCALAR_FOR_DISCRIMINATOR:{code:"SCALAR_FOR_DISCRIMINATOR",message:"It is only allowed to use scalar properties as discriminators"},DISCRIMINATOR_VALUE_WITHOUT_DISCRIMINATOR:{code:"DISCRIMINATOR_VALUE_WITHOUT_DISCRIMINATOR",message:"You can not use 'discriminatorValue' without declaring 'discriminator'"},INVALID_DISCRIMINATOR_VALUE:{code:"INVALID_DISCRIMINATOR_VALUE",message:"Using invalid 'disciminatorValue': {{msg}}"},PROPERTIES_MAP:{code:"PROPERTIES_MAP",message:"'properties' should be a map"},FACETS_MAP:{code:"FACETS_MAP",message:"'facets' should be a map"},VALIDATING_AGAINS_UNKNOWN:{code:"VALIDATING_AGAINS_UNKNOWN",message:"Validating instance against unknown type: '{{typeName}}'"},EXTERNAL_IN_PROPERTY_DEFINITION:{code:"EXTERNAL_IN_PROPERTY_DEFINITION",message:"It is not allowed to use external types in property definitions"},UNKNOWN_IN_PROPERTY_DEFINITION:{code:"UNKNOWN_IN_PROPERTY_DEFINITION",message:"Property '{{propName}}' refers to unknown type '{{typeName}}'"},ERROR_IN_RANGE:{code:"ERROR_IN_RANGE",message:"Property '{{propName}}' range type has error: {{msg}}"},INCORRECT_SCHEMA:{code:"INCORRECT_SCHEMA",message:"Incorrect schema: {{msg}}"},UNABLE_TO_VALIDATE_XML:{code:"UNABLE_TO_VALIDATE_XML",message:"Unable to validate example against schema (xmllint)"},CIRCULAR_REFS_IN_JSON_SCHEMA:{code:"CIRCULAR_REFS_IN_JSON_SCHEMA",message:"JSON schema contains circular references"},EXAMPLE_SCHEMA_FAILURE:{code:"EXAMPLE_SCHEMA_FAILURE",message:"Example does not conform to schema: {{msg}}"},UNKNOWN_PROPERTY:{code:"UNKNOWN_PROPERTY",message:"Unknown property: '{{propName}}'"},REQUIRED_PROPERTY_MISSING:{code:"REQUIRED_PROPERTY_MISSING",message:"Required property '{{propName}}' is missing"},INVALID_REGEXP:{code:"INVALID_REGEXP",message:"{{msg}}"},FACET_USAGE_RESTRICTION:{code:"FACET_USAGE_RESTRICTION",message:"{{facetName}} facet can only be used with {{typeNames}} types"},FACET_REQUIRE_NUMBER:{code:"FACET_REQUIRE_NUMBER",message:"'{{facetName}}' value should be a number"},FACET_REQUIRE_INTEGER:{code:"FACET_REQUIRE_INTEGER",message:"'{{facetName}}' value should be an integer"},MIN_VALUE:{code:"MIN_VALUE",message:"'{{facetName}}' value should be at least {{minValue}}"},EVEN_RATIO:{code:"EVEN_RATIO",message:"result of division of {{val1}} on {{val2}} should be integer"},MUST_BE_UNIQUE:{code:"MUST_BE_UNIQUE",message:"items should be unique"},ARRAY_AGAINST_UNKNOWN:{code:"ARRAY_AGAINST_UNKNOWN",message:"Array instance is validated against unknown type: '{{typeName}}'"},INVALID_COMPONENT_TYPE:{code:"INVALID_COMPONENT_TYPE",message:"Component type has error: {{msg}}"},EXTERNAL_AS_COMPONENT:{code:"EXTERNAL_AS_COMPONENT",message:"It is not allowed to use external types in component type definitions"},UNKNOWN_AS_COMPONENT:{code:"UNKNOWN_AS_COMPONENT",message:"Component refers to unknown type {{typeName}}"},PATTERN_VIOLATION:{code:"PATTERN_VIOLATION",message:"String should match to '{{value}}'"},ALLOWED_FORMAT_VALUES:{code:"ALLOWED_FORMAT_VALUES",message:"Following format values are allowed: {{allowedValues}}"},ENUM_RESTRICTION:{code:"ENUM_RESTRICTION",message:"value should be one of: {{values}}"},ENUM_OWNER_TYPES:{code:"ENUM_OWNER_TYPES",message:"'enum' facet can only be used with: {{typeNames}}"},ENUM_ARRAY:{code:"ENUM_ARRAY",message:"'enum' facet value must be defined by array"},RESTRICTIONS_CONFLICT:{code:"RESTRICTIONS_CONFLICT",message:null},MINMAX_RESTRICTION_VIOLATION:{code:"MINMAX_RESTRICTION_VIOLATION",message:null},UNION_TYPE_FAILURE:{code:"UNION_TYPE_FAILURE",message:"Union type options do not pass validation"},UNION_TYPE_FAILURE_DETAILS:{code:"UNION_TYPE_FAILURE_DETAILS",message:"Union type option does not pass validation ({{msg}})"},INVALID_JSON_SCHEMA_DETAILS:{code:"INVALID_JSON_SCHEMA_DETAILS",message:"Invalid JSON schema: {{msg}}"},INVALID_JSON_SCHEMA:{code:"INVALID_JSON_SCHEMA",message:"Invalid JSON schema"},REFERENCE_NOT_FOUND:{code:"REFERENCE_NOT_FOUND",message:"Reference not found: {{ref}}"},INVALID_XML_SCHEMA:{code:"INVALID_XML_SCHEMA",message:"Invalid XML schema content"},INVALID_ANNOTATION_LOCATION:{code:"INVALID_ANNOTATION_LOCATION",message:"Annotation '{{aName}}' can not be placed at this location, allowed targets are: {{aValues}}"},CONTENT_DOES_NOT_MATCH_THE_SCHEMA:{code:"CONTENT_DOES_NOT_MATCH_THE_SCHEMA",message:"Content is not valid according to schema: {{msg}}"},EXTERNAL_TYPE_ERROR:{code:"EXTERNAL_TYPE_ERROR",message:"Referenced type '{{typeName}}' does not match '{{objectName}}' root node"},CAN_NOT_PARSE_SCHEMA:{code:"CAN_NOT_PARSE_SCHEMA",message:"Can not parse schema"}}},function(e,t,n){function r(e){this.options=e||{locator:{}}}function i(e,t,n){function r(t){var r=e[t];!r&&o&&(r=2==e.length?function(n){e(t,n)}:e),i[t]=r&&function(e){r("[xmldom "+t+"]	"+e+s(n))}||function(){}}if(!e){if(t instanceof a)return t;e=t}var i={},o=e instanceof Function;return n=n||{},r("warning"),r("error"),r("fatalError"),i}function a(){this.cdata=!1}function o(e,t){t.lineNumber=e.lineNumber,t.columnNumber=e.columnNumber}function s(e){return e?"\n@"+(e.systemId||"")+"#[line:"+e.lineNumber+",col:"+e.columnNumber+"]":void 0}function u(e,t,n){return"string"==typeof e?e.substr(t,n):e.length>=t+n||t?new java.lang.String(e,t,n)+"":e}function l(e,t){e.currentElement?e.currentElement.appendChild(t):e.document.appendChild(t)}r.prototype.parseFromString=function(e,t){var n=this.options,r=new p,o=n.domBuilder||new a,s=n.errorHandler,u=n.locator,l=n.xmlns||{},c={lt:"<",gt:">",amp:"&",quot:'"',apos:"'"};return u&&o.setDocumentLocator(u),r.errorHandler=i(s,o,u),r.domBuilder=n.domBuilder||o,/\/x?html?$/.test(t)&&(c.nbsp=" ",c.copy="©",l[""]="http://www.w3.org/1999/xhtml"),l.xml=l.xml||"http://www.w3.org/XML/1998/namespace",e?r.parse(e,l,c):r.errorHandler.error("invalid document source"),o.document},a.prototype={startDocument:function(){this.document=(new c).createDocument(null,null,null),this.locator&&(this.document.documentURI=this.locator.systemId)},startElement:function(e,t,n,r){var i=this.document,a=i.createElementNS(e,n||t),s=r.length;l(this,a),this.currentElement=a,this.locator&&o(this.locator,a);for(var u=0;s>u;u++){var e=r.getURI(u),p=r.getValue(u),n=r.getQName(u),c=i.createAttributeNS(e,n);c.getOffset&&o(c.getOffset(1),c),c.value=c.nodeValue=p,a.setAttributeNode(c)}},endElement:function(e,t,n){var r=this.currentElement;r.tagName;this.currentElement=r.parentNode},startPrefixMapping:function(e,t){},endPrefixMapping:function(e){},processingInstruction:function(e,t){var n=this.document.createProcessingInstruction(e,t);this.locator&&o(this.locator,n),l(this,n)},ignorableWhitespace:function(e,t,n){},characters:function(e,t,n){if(e=u.apply(this,arguments),this.currentElement&&e){if(this.cdata){var r=this.document.createCDATASection(e);this.currentElement.appendChild(r)}else{var r=this.document.createTextNode(e);this.currentElement.appendChild(r)}this.locator&&o(this.locator,r)}},skippedEntity:function(e){},endDocument:function(){this.document.normalize()},setDocumentLocator:function(e){(this.locator=e)&&(e.lineNumber=0)},comment:function(e,t,n){e=u.apply(this,arguments);var r=this.document.createComment(e);this.locator&&o(this.locator,r),l(this,r)},startCDATA:function(){this.cdata=!0},endCDATA:function(){this.cdata=!1},startDTD:function(e,t,n){var r=this.document.implementation;if(r&&r.createDocumentType){var i=r.createDocumentType(e,t,n);this.locator&&o(this.locator,i),l(this,i)}},warning:function(e){console.warn("[xmldom warning]	"+e,s(this.locator))},error:function(e){console.error("[xmldom error]	"+e,s(this.locator))},fatalError:function(e){throw console.error("[xmldom fatalError]	"+e,s(this.locator)),e}},"endDTD,startEntity,endEntity,attributeDecl,elementDecl,externalEntityDecl,internalEntityDecl,resolveEntity,getExternalSubset,notationDecl,unparsedEntityDecl".replace(/\w+/g,function(e){a.prototype[e]=function(){return null}});var p=n(207).XMLReader,c=t.DOMImplementation=n(208).DOMImplementation;t.XMLSerializer=n(208).XMLSerializer,t.DOMParser=r},function(e,t,n){var r,i;(function(){function n(e){function t(t,n,r,i,a,o){for(;a>=0&&o>a;a+=e){var s=i?i[a]:a;r=n(r,t[s],s,t)}return r}return function(n,r,i,a){r=b(r,a,4);var o=!C(n)&&E.keys(n),s=(o||n).length,u=e>0?0:s-1;return arguments.length<3&&(i=n[o?o[u]:u],u+=e),t(n,r,i,o,u,s)}}function a(e){return function(t,n,r){n=N(n,r);for(var i=I(t),a=e>0?0:i-1;a>=0&&i>a;a+=e)if(n(t[a],a,t))return a;return-1}}function o(e,t,n){return function(r,i,a){var o=0,s=I(r);if("number"==typeof a)e>0?o=a>=0?a:Math.max(a+s,o):s=a>=0?Math.min(a+1,s):a+s+1;else if(n&&a&&s)return a=n(r,i),r[a]===i?a:-1;if(i!==i)return a=t(d.call(r,o,s),E.isNaN),a>=0?a+o:-1;for(a=e>0?o:s-1;a>=0&&s>a;a+=e)if(r[a]===i)return a;return-1}}function s(e,t){var n=x.length,r=e.constructor,i=E.isFunction(r)&&r.prototype||c,a="constructor";for(E.has(e,a)&&!E.contains(t,a)&&t.push(a);n--;)a=x[n],a in e&&e[a]!==i[a]&&!E.contains(t,a)&&t.push(a)}var u=this,l=u._,p=Array.prototype,c=Object.prototype,f=Function.prototype,m=p.push,d=p.slice,h=c.toString,y=c.hasOwnProperty,v=Array.isArray,g=Object.keys,A=f.bind,S=Object.create,T=function(){},E=function(e){return e instanceof E?e:this instanceof E?void(this._wrapped=e):new E(e)};"undefined"!=typeof e&&e.exports&&(t=e.exports=E),t._=E,E.VERSION="1.8.3";var b=function(e,t,n){if(void 0===t)return e;switch(null==n?3:n){case 1:return function(n){return e.call(t,n)};case 2:return function(n,r){return e.call(t,n,r)};case 3:return function(n,r,i){return e.call(t,n,r,i)};case 4:return function(n,r,i,a){return e.call(t,n,r,i,a)}}return function(){return e.apply(t,arguments)}},N=function(e,t,n){return null==e?E.identity:E.isFunction(e)?b(e,t,n):E.isObject(e)?E.matcher(e):E.property(e)};E.iteratee=function(e,t){return N(e,t,1/0)};var _=function(e,t){return function(n){var r=arguments.length;if(2>r||null==n)return n;for(var i=1;r>i;i++)for(var a=arguments[i],o=e(a),s=o.length,u=0;s>u;u++){var l=o[u];t&&void 0!==n[l]||(n[l]=a[l])}return n}},M=function(e){if(!E.isObject(e))return{};if(S)return S(e);T.prototype=e;var t=new T;return T.prototype=null,t},w=function(e){return function(t){return null==t?void 0:t[e]}},R=Math.pow(2,53)-1,I=w("length"),C=function(e){var t=I(e);return"number"==typeof t&&t>=0&&R>=t};E.each=E.forEach=function(e,t,n){t=b(t,n);var r,i;if(C(e))for(r=0,i=e.length;i>r;r++)t(e[r],r,e);else{var a=E.keys(e);for(r=0,i=a.length;i>r;r++)t(e[a[r]],a[r],e)}return e},E.map=E.collect=function(e,t,n){t=N(t,n);for(var r=!C(e)&&E.keys(e),i=(r||e).length,a=Array(i),o=0;i>o;o++){var s=r?r[o]:o;a[o]=t(e[s],s,e)}return a},E.reduce=E.foldl=E.inject=n(1),E.reduceRight=E.foldr=n(-1),E.find=E.detect=function(e,t,n){var r;return r=C(e)?E.findIndex(e,t,n):E.findKey(e,t,n),void 0!==r&&-1!==r?e[r]:void 0},E.filter=E.select=function(e,t,n){var r=[];return t=N(t,n),E.each(e,function(e,n,i){t(e,n,i)&&r.push(e)}),r},E.reject=function(e,t,n){return E.filter(e,E.negate(N(t)),n)},E.every=E.all=function(e,t,n){t=N(t,n);for(var r=!C(e)&&E.keys(e),i=(r||e).length,a=0;i>a;a++){var o=r?r[a]:a;if(!t(e[o],o,e))return!1}return!0},E.some=E.any=function(e,t,n){t=N(t,n);for(var r=!C(e)&&E.keys(e),i=(r||e).length,a=0;i>a;a++){var o=r?r[a]:a;if(t(e[o],o,e))return!0;
}return!1},E.contains=E.includes=E.include=function(e,t,n,r){return C(e)||(e=E.values(e)),("number"!=typeof n||r)&&(n=0),E.indexOf(e,t,n)>=0},E.invoke=function(e,t){var n=d.call(arguments,2),r=E.isFunction(t);return E.map(e,function(e){var i=r?t:e[t];return null==i?i:i.apply(e,n)})},E.pluck=function(e,t){return E.map(e,E.property(t))},E.where=function(e,t){return E.filter(e,E.matcher(t))},E.findWhere=function(e,t){return E.find(e,E.matcher(t))},E.max=function(e,t,n){var r,i,a=-(1/0),o=-(1/0);if(null==t&&null!=e){e=C(e)?e:E.values(e);for(var s=0,u=e.length;u>s;s++)r=e[s],r>a&&(a=r)}else t=N(t,n),E.each(e,function(e,n,r){i=t(e,n,r),(i>o||i===-(1/0)&&a===-(1/0))&&(a=e,o=i)});return a},E.min=function(e,t,n){var r,i,a=1/0,o=1/0;if(null==t&&null!=e){e=C(e)?e:E.values(e);for(var s=0,u=e.length;u>s;s++)r=e[s],a>r&&(a=r)}else t=N(t,n),E.each(e,function(e,n,r){i=t(e,n,r),(o>i||i===1/0&&a===1/0)&&(a=e,o=i)});return a},E.shuffle=function(e){for(var t,n=C(e)?e:E.values(e),r=n.length,i=Array(r),a=0;r>a;a++)t=E.random(0,a),t!==a&&(i[a]=i[t]),i[t]=n[a];return i},E.sample=function(e,t,n){return null==t||n?(C(e)||(e=E.values(e)),e[E.random(e.length-1)]):E.shuffle(e).slice(0,Math.max(0,t))},E.sortBy=function(e,t,n){return t=N(t,n),E.pluck(E.map(e,function(e,n,r){return{value:e,index:n,criteria:t(e,n,r)}}).sort(function(e,t){var n=e.criteria,r=t.criteria;if(n!==r){if(n>r||void 0===n)return 1;if(r>n||void 0===r)return-1}return e.index-t.index}),"value")};var L=function(e){return function(t,n,r){var i={};return n=N(n,r),E.each(t,function(r,a){var o=n(r,a,t);e(i,r,o)}),i}};E.groupBy=L(function(e,t,n){E.has(e,n)?e[n].push(t):e[n]=[t]}),E.indexBy=L(function(e,t,n){e[n]=t}),E.countBy=L(function(e,t,n){E.has(e,n)?e[n]++:e[n]=1}),E.toArray=function(e){return e?E.isArray(e)?d.call(e):C(e)?E.map(e,E.identity):E.values(e):[]},E.size=function(e){return null==e?0:C(e)?e.length:E.keys(e).length},E.partition=function(e,t,n){t=N(t,n);var r=[],i=[];return E.each(e,function(e,n,a){(t(e,n,a)?r:i).push(e)}),[r,i]},E.first=E.head=E.take=function(e,t,n){return null==e?void 0:null==t||n?e[0]:E.initial(e,e.length-t)},E.initial=function(e,t,n){return d.call(e,0,Math.max(0,e.length-(null==t||n?1:t)))},E.last=function(e,t,n){return null==e?void 0:null==t||n?e[e.length-1]:E.rest(e,Math.max(0,e.length-t))},E.rest=E.tail=E.drop=function(e,t,n){return d.call(e,null==t||n?1:t)},E.compact=function(e){return E.filter(e,E.identity)};var P=function(e,t,n,r){for(var i=[],a=0,o=r||0,s=I(e);s>o;o++){var u=e[o];if(C(u)&&(E.isArray(u)||E.isArguments(u))){t||(u=P(u,t,n));var l=0,p=u.length;for(i.length+=p;p>l;)i[a++]=u[l++]}else n||(i[a++]=u)}return i};E.flatten=function(e,t){return P(e,t,!1)},E.without=function(e){return E.difference(e,d.call(arguments,1))},E.uniq=E.unique=function(e,t,n,r){E.isBoolean(t)||(r=n,n=t,t=!1),null!=n&&(n=N(n,r));for(var i=[],a=[],o=0,s=I(e);s>o;o++){var u=e[o],l=n?n(u,o,e):u;t?(o&&a===l||i.push(u),a=l):n?E.contains(a,l)||(a.push(l),i.push(u)):E.contains(i,u)||i.push(u)}return i},E.union=function(){return E.uniq(P(arguments,!0,!0))},E.intersection=function(e){for(var t=[],n=arguments.length,r=0,i=I(e);i>r;r++){var a=e[r];if(!E.contains(t,a)){for(var o=1;n>o&&E.contains(arguments[o],a);o++);o===n&&t.push(a)}}return t},E.difference=function(e){var t=P(arguments,!0,!0,1);return E.filter(e,function(e){return!E.contains(t,e)})},E.zip=function(){return E.unzip(arguments)},E.unzip=function(e){for(var t=e&&E.max(e,I).length||0,n=Array(t),r=0;t>r;r++)n[r]=E.pluck(e,r);return n},E.object=function(e,t){for(var n={},r=0,i=I(e);i>r;r++)t?n[e[r]]=t[r]:n[e[r][0]]=e[r][1];return n},E.findIndex=a(1),E.findLastIndex=a(-1),E.sortedIndex=function(e,t,n,r){n=N(n,r,1);for(var i=n(t),a=0,o=I(e);o>a;){var s=Math.floor((a+o)/2);n(e[s])<i?a=s+1:o=s}return a},E.indexOf=o(1,E.findIndex,E.sortedIndex),E.lastIndexOf=o(-1,E.findLastIndex),E.range=function(e,t,n){null==t&&(t=e||0,e=0),n=n||1;for(var r=Math.max(Math.ceil((t-e)/n),0),i=Array(r),a=0;r>a;a++,e+=n)i[a]=e;return i};var O=function(e,t,n,r,i){if(!(r instanceof t))return e.apply(n,i);var a=M(e.prototype),o=e.apply(a,i);return E.isObject(o)?o:a};E.bind=function(e,t){if(A&&e.bind===A)return A.apply(e,d.call(arguments,1));if(!E.isFunction(e))throw new TypeError("Bind must be called on a function");var n=d.call(arguments,2),r=function(){return O(e,r,t,this,n.concat(d.call(arguments)))};return r},E.partial=function(e){var t=d.call(arguments,1),n=function(){for(var r=0,i=t.length,a=Array(i),o=0;i>o;o++)a[o]=t[o]===E?arguments[r++]:t[o];for(;r<arguments.length;)a.push(arguments[r++]);return O(e,n,this,this,a)};return n},E.bindAll=function(e){var t,n,r=arguments.length;if(1>=r)throw new Error("bindAll must be passed function names");for(t=1;r>t;t++)n=arguments[t],e[n]=E.bind(e[n],e);return e},E.memoize=function(e,t){var n=function(r){var i=n.cache,a=""+(t?t.apply(this,arguments):r);return E.has(i,a)||(i[a]=e.apply(this,arguments)),i[a]};return n.cache={},n},E.delay=function(e,t){var n=d.call(arguments,2);return setTimeout(function(){return e.apply(null,n)},t)},E.defer=E.partial(E.delay,E,1),E.throttle=function(e,t,n){var r,i,a,o=null,s=0;n||(n={});var u=function(){s=n.leading===!1?0:E.now(),o=null,a=e.apply(r,i),o||(r=i=null)};return function(){var l=E.now();s||n.leading!==!1||(s=l);var p=t-(l-s);return r=this,i=arguments,0>=p||p>t?(o&&(clearTimeout(o),o=null),s=l,a=e.apply(r,i),o||(r=i=null)):o||n.trailing===!1||(o=setTimeout(u,p)),a}},E.debounce=function(e,t,n){var r,i,a,o,s,u=function(){var l=E.now()-o;t>l&&l>=0?r=setTimeout(u,t-l):(r=null,n||(s=e.apply(a,i),r||(a=i=null)))};return function(){a=this,i=arguments,o=E.now();var l=n&&!r;return r||(r=setTimeout(u,t)),l&&(s=e.apply(a,i),a=i=null),s}},E.wrap=function(e,t){return E.partial(t,e)},E.negate=function(e){return function(){return!e.apply(this,arguments)}},E.compose=function(){var e=arguments,t=e.length-1;return function(){for(var n=t,r=e[t].apply(this,arguments);n--;)r=e[n].call(this,r);return r}},E.after=function(e,t){return function(){return--e<1?t.apply(this,arguments):void 0}},E.before=function(e,t){var n;return function(){return--e>0&&(n=t.apply(this,arguments)),1>=e&&(t=null),n}},E.once=E.partial(E.before,2);var D=!{toString:null}.propertyIsEnumerable("toString"),x=["valueOf","isPrototypeOf","toString","propertyIsEnumerable","hasOwnProperty","toLocaleString"];E.keys=function(e){if(!E.isObject(e))return[];if(g)return g(e);var t=[];for(var n in e)E.has(e,n)&&t.push(n);return D&&s(e,t),t},E.allKeys=function(e){if(!E.isObject(e))return[];var t=[];for(var n in e)t.push(n);return D&&s(e,t),t},E.values=function(e){for(var t=E.keys(e),n=t.length,r=Array(n),i=0;n>i;i++)r[i]=e[t[i]];return r},E.mapObject=function(e,t,n){t=N(t,n);for(var r,i=E.keys(e),a=i.length,o={},s=0;a>s;s++)r=i[s],o[r]=t(e[r],r,e);return o},E.pairs=function(e){for(var t=E.keys(e),n=t.length,r=Array(n),i=0;n>i;i++)r[i]=[t[i],e[t[i]]];return r},E.invert=function(e){for(var t={},n=E.keys(e),r=0,i=n.length;i>r;r++)t[e[n[r]]]=n[r];return t},E.functions=E.methods=function(e){var t=[];for(var n in e)E.isFunction(e[n])&&t.push(n);return t.sort()},E.extend=_(E.allKeys),E.extendOwn=E.assign=_(E.keys),E.findKey=function(e,t,n){t=N(t,n);for(var r,i=E.keys(e),a=0,o=i.length;o>a;a++)if(r=i[a],t(e[r],r,e))return r},E.pick=function(e,t,n){var r,i,a={},o=e;if(null==o)return a;E.isFunction(t)?(i=E.allKeys(o),r=b(t,n)):(i=P(arguments,!1,!1,1),r=function(e,t,n){return t in n},o=Object(o));for(var s=0,u=i.length;u>s;s++){var l=i[s],p=o[l];r(p,l,o)&&(a[l]=p)}return a},E.omit=function(e,t,n){if(E.isFunction(t))t=E.negate(t);else{var r=E.map(P(arguments,!1,!1,1),String);t=function(e,t){return!E.contains(r,t)}}return E.pick(e,t,n)},E.defaults=_(E.allKeys,!0),E.create=function(e,t){var n=M(e);return t&&E.extendOwn(n,t),n},E.clone=function(e){return E.isObject(e)?E.isArray(e)?e.slice():E.extend({},e):e},E.tap=function(e,t){return t(e),e},E.isMatch=function(e,t){var n=E.keys(t),r=n.length;if(null==e)return!r;for(var i=Object(e),a=0;r>a;a++){var o=n[a];if(t[o]!==i[o]||!(o in i))return!1}return!0};var U=function(e,t,n,r){if(e===t)return 0!==e||1/e===1/t;if(null==e||null==t)return e===t;e instanceof E&&(e=e._wrapped),t instanceof E&&(t=t._wrapped);var i=h.call(e);if(i!==h.call(t))return!1;switch(i){case"[object RegExp]":case"[object String]":return""+e==""+t;case"[object Number]":return+e!==+e?+t!==+t:0===+e?1/+e===1/t:+e===+t;case"[object Date]":case"[object Boolean]":return+e===+t}var a="[object Array]"===i;if(!a){if("object"!=typeof e||"object"!=typeof t)return!1;var o=e.constructor,s=t.constructor;if(o!==s&&!(E.isFunction(o)&&o instanceof o&&E.isFunction(s)&&s instanceof s)&&"constructor"in e&&"constructor"in t)return!1}n=n||[],r=r||[];for(var u=n.length;u--;)if(n[u]===e)return r[u]===t;if(n.push(e),r.push(t),a){if(u=e.length,u!==t.length)return!1;for(;u--;)if(!U(e[u],t[u],n,r))return!1}else{var l,p=E.keys(e);if(u=p.length,E.keys(t).length!==u)return!1;for(;u--;)if(l=p[u],!E.has(t,l)||!U(e[l],t[l],n,r))return!1}return n.pop(),r.pop(),!0};E.isEqual=function(e,t){return U(e,t)},E.isEmpty=function(e){return null==e?!0:C(e)&&(E.isArray(e)||E.isString(e)||E.isArguments(e))?0===e.length:0===E.keys(e).length},E.isElement=function(e){return!(!e||1!==e.nodeType)},E.isArray=v||function(e){return"[object Array]"===h.call(e)},E.isObject=function(e){var t=typeof e;return"function"===t||"object"===t&&!!e},E.each(["Arguments","Function","String","Number","Date","RegExp","Error"],function(e){E["is"+e]=function(t){return h.call(t)==="[object "+e+"]"}}),E.isArguments(arguments)||(E.isArguments=function(e){return E.has(e,"callee")}),"function"!=typeof/./&&"object"!=typeof Int8Array&&(E.isFunction=function(e){return"function"==typeof e||!1}),E.isFinite=function(e){return isFinite(e)&&!isNaN(parseFloat(e))},E.isNaN=function(e){return E.isNumber(e)&&e!==+e},E.isBoolean=function(e){return e===!0||e===!1||"[object Boolean]"===h.call(e)},E.isNull=function(e){return null===e},E.isUndefined=function(e){return void 0===e},E.has=function(e,t){return null!=e&&y.call(e,t)},E.noConflict=function(){return u._=l,this},E.identity=function(e){return e},E.constant=function(e){return function(){return e}},E.noop=function(){},E.property=w,E.propertyOf=function(e){return null==e?function(){}:function(t){return e[t]}},E.matcher=E.matches=function(e){return e=E.extendOwn({},e),function(t){return E.isMatch(t,e)}},E.times=function(e,t,n){var r=Array(Math.max(0,e));t=b(t,n,1);for(var i=0;e>i;i++)r[i]=t(i);return r},E.random=function(e,t){return null==t&&(t=e,e=0),e+Math.floor(Math.random()*(t-e+1))},E.now=Date.now||function(){return(new Date).getTime()};var k={"&":"&amp;","<":"&lt;",">":"&gt;",'"':"&quot;","'":"&#x27;","`":"&#x60;"},F=E.invert(k),B=function(e){var t=function(t){return e[t]},n="(?:"+E.keys(e).join("|")+")",r=RegExp(n),i=RegExp(n,"g");return function(e){return e=null==e?"":""+e,r.test(e)?e.replace(i,t):e}};E.escape=B(k),E.unescape=B(F),E.result=function(e,t,n){var r=null==e?void 0:e[t];return void 0===r&&(r=n),E.isFunction(r)?r.call(e):r};var K=0;E.uniqueId=function(e){var t=++K+"";return e?e+t:t},E.templateSettings={evaluate:/<%([\s\S]+?)%>/g,interpolate:/<%=([\s\S]+?)%>/g,escape:/<%-([\s\S]+?)%>/g};var V=/(.)^/,j={"'":"'","\\":"\\","\r":"r","\n":"n","\u2028":"u2028","\u2029":"u2029"},W=/\\|'|\r|\n|\u2028|\u2029/g,q=function(e){return"\\"+j[e]};E.template=function(e,t,n){!t&&n&&(t=n),t=E.defaults({},t,E.templateSettings);var r=RegExp([(t.escape||V).source,(t.interpolate||V).source,(t.evaluate||V).source].join("|")+"|$","g"),i=0,a="__p+='";e.replace(r,function(t,n,r,o,s){return a+=e.slice(i,s).replace(W,q),i=s+t.length,n?a+="'+\n((__t=("+n+"))==null?'':_.escape(__t))+\n'":r?a+="'+\n((__t=("+r+"))==null?'':__t)+\n'":o&&(a+="';\n"+o+"\n__p+='"),t}),a+="';\n",t.variable||(a="with(obj||{}){\n"+a+"}\n"),a="var __t,__p='',__j=Array.prototype.join,print=function(){__p+=__j.call(arguments,'');};\n"+a+"return __p;\n";try{var o=new Function(t.variable||"obj","_",a)}catch(s){throw s.source=a,s}var u=function(e){return o.call(this,e,E)},l=t.variable||"obj";return u.source="function("+l+"){\n"+a+"}",u},E.chain=function(e){var t=E(e);return t._chain=!0,t};var Y=function(e,t){return e._chain?E(t).chain():t};E.mixin=function(e){E.each(E.functions(e),function(t){var n=E[t]=e[t];E.prototype[t]=function(){var e=[this._wrapped];return m.apply(e,arguments),Y(this,n.apply(E,e))}})},E.mixin(E),E.each(["pop","push","reverse","shift","sort","splice","unshift"],function(e){var t=p[e];E.prototype[e]=function(){var n=this._wrapped;return t.apply(n,arguments),"shift"!==e&&"splice"!==e||0!==n.length||delete n[0],Y(this,n)}}),E.each(["concat","join","slice"],function(e){var t=p[e];E.prototype[e]=function(){return Y(this,t.apply(this._wrapped,arguments))}}),E.prototype.value=function(){return this._wrapped},E.prototype.valueOf=E.prototype.toJSON=E.prototype.value,E.prototype.toString=function(){return""+this._wrapped},r=[],i=function(){return E}.apply(t,r),!(void 0!==i&&(e.exports=i))}).call(this)},function(e,t,n){(function(){function t(e,t){Array.isArray(e)||(e=[e]);for(var n=!!t,r=[],i=0;i<e.length;i++){var a=e[i];"object"==typeof a?(r.push(a),n=!0):r.push({type:a})}return n&&r}function n(e){if(e.type)if("string"!=typeof e.type){var r=t(e.type);r&&(e.anyOf=r,delete e.type)}else"any"==e.type&&delete e.type;if(e["extends"]){var i=e["extends"];Array.isArray(i)||(i=[i]),e.allOf=i,delete e["extends"]}if(e.disallow&&("string"==typeof e.disallow?e.not={type:e.disallow}:e.not={anyOf:t(e.disallow,!0)},delete e.disallow),e.properties){var a=Array.isArray(e.required)?e.required:[];for(var o in e.properties){var s=e.properties[o];s&&"boolean"==typeof s.required&&(s.required&&a.push(o),delete s.required)}a.length&&(e.required=a)}if(e.dependencies)for(var o in e.dependencies)"string"==typeof e.dependencies[o]&&(e.dependencies[o]=[e.dependencies[o]]);"boolean"==typeof e.required&&delete e.required,"undefined"!=typeof e.divisibleBy&&(e.multipleOf=e.divisibleBy,delete e.divisibleBy);for(var o in e)if("properties"===o||"patternProperties"===o||"dependencies"===o)for(var u in e[o])e[o][u]=n(e[o][u]);else if("enum"!==o)if(Array.isArray(e[o]))for(var l=0;l<e[o].length;l++)e[o][l]=n(e[o][l]);else"object"==typeof e[o]&&(e[o]=n(e[o]));return e}var r={v4:n};return e.exports=r,r})()},function(e,t,n){var r=[].indexOf;e.exports=function(e,t){if(r)return e.indexOf(t);for(var n=0;n<e.length;++n)if(e[n]===t)return n;return-1}},function(e,t,n){"use strict";function r(){}function i(e){try{return e.then}catch(t){return v=t,g}}function a(e,t){try{return e(t)}catch(n){return v=n,g}}function o(e,t,n){try{e(t,n)}catch(r){return v=r,g}}function s(e){if("object"!=typeof this)throw new TypeError("Promises must be constructed via new");if("function"!=typeof e)throw new TypeError("not a function");this._45=0,this._81=0,this._65=null,this._54=null,e!==r&&h(e,this)}function u(e,t,n){return new e.constructor(function(i,a){var o=new s(r);o.then(i,a),l(e,new d(t,n,o))})}function l(e,t){for(;3===e._81;)e=e._65;return s._10&&s._10(e),0===e._81?0===e._45?(e._45=1,void(e._54=t)):1===e._45?(e._45=2,void(e._54=[e._54,t])):void e._54.push(t):void p(e,t)}function p(e,t){y(function(){var n=1===e._81?t.onFulfilled:t.onRejected;if(null===n)return void(1===e._81?c(t.promise,e._65):f(t.promise,e._65));var r=a(n,e._65);r===g?f(t.promise,v):c(t.promise,r)})}function c(e,t){if(t===e)return f(e,new TypeError("A promise cannot be resolved with itself."));if(t&&("object"==typeof t||"function"==typeof t)){var n=i(t);if(n===g)return f(e,v);if(n===e.then&&t instanceof s)return e._81=3,e._65=t,void m(e);if("function"==typeof n)return void h(n.bind(t),e)}e._81=1,e._65=t,m(e)}function f(e,t){e._81=2,e._65=t,s._97&&s._97(e,t),m(e)}function m(e){if(1===e._45&&(l(e,e._54),e._54=null),2===e._45){for(var t=0;t<e._54.length;t++)l(e,e._54[t]);e._54=null}}function d(e,t,n){this.onFulfilled="function"==typeof e?e:null,this.onRejected="function"==typeof t?t:null,this.promise=n}function h(e,t){var n=!1,r=o(e,function(e){n||(n=!0,c(t,e))},function(e){n||(n=!0,f(t,e))});n||r!==g||(n=!0,f(t,v))}var y=n(230),v=null,g={};e.exports=s,s._10=null,s._97=null,s._61=r,s.prototype.then=function(e,t){if(this.constructor!==s)return u(this,e,t);var n=new s(r);return l(this,new d(e,t,n)),n}},function(e,t,n){"use strict";var r=n(190);e.exports=r,r.prototype.done=function(e,t){var n=arguments.length?this.then.apply(this,arguments):this;n.then(null,function(e){setTimeout(function(){throw e},0)})}},function(e,t,n){"use strict";var r=n(190);e.exports=r,r.prototype["finally"]=function(e){return this.then(function(t){return r.resolve(e()).then(function(){return t})},function(t){return r.resolve(e()).then(function(){throw t})})}},function(e,t,n){"use strict";function r(e){var t=new i(i._61);return t._81=1,t._65=e,t}var i=n(190);e.exports=i;var a=r(!0),o=r(!1),s=r(null),u=r(void 0),l=r(0),p=r("");i.resolve=function(e){if(e instanceof i)return e;if(null===e)return s;if(void 0===e)return u;if(e===!0)return a;if(e===!1)return o;if(0===e)return l;if(""===e)return p;if("object"==typeof e||"function"==typeof e)try{var t=e.then;if("function"==typeof t)return new i(t.bind(e))}catch(n){return new i(function(e,t){t(n)})}return r(e)},i.all=function(e){var t=Array.prototype.slice.call(e);return new i(function(e,n){function r(o,s){if(s&&("object"==typeof s||"function"==typeof s)){if(s instanceof i&&s.then===i.prototype.then){for(;3===s._81;)s=s._65;return 1===s._81?r(o,s._65):(2===s._81&&n(s._65),void s.then(function(e){r(o,e)},n))}var u=s.then;if("function"==typeof u){var l=new i(u.bind(s));return void l.then(function(e){r(o,e)},n)}}t[o]=s,0===--a&&e(t)}if(0===t.length)return e([]);for(var a=t.length,o=0;o<t.length;o++)r(o,t[o])})},i.reject=function(e){return new i(function(t,n){n(e)})},i.race=function(e){return new i(function(t,n){e.forEach(function(e){i.resolve(e).then(t,n)})})},i.prototype["catch"]=function(e){return this.then(null,e)}},function(e,t,n){"use strict";function r(e,t){for(var n=[],r=0;t>r;r++)n.push("a"+r);var i=["return function ("+n.join(",")+") {","var self = this;","return new Promise(function (rs, rj) {","var res = fn.call(",["self"].concat(n).concat([s]).join(","),");","if (res &&",'(typeof res === "object" || typeof res === "function") &&','typeof res.then === "function"',") {rs(res);}","});","};"].join("");return Function(["Promise","fn"],i)(a,e)}function i(e){for(var t=Math.max(e.length-1,3),n=[],r=0;t>r;r++)n.push("a"+r);var i=["return function ("+n.join(",")+") {","var self = this;","var args;","var argLength = arguments.length;","if (arguments.length > "+t+") {","args = new Array(arguments.length + 1);","for (var i = 0; i < arguments.length; i++) {","args[i] = arguments[i];","}","}","return new Promise(function (rs, rj) {","var cb = "+s+";","var res;","switch (argLength) {",n.concat(["extra"]).map(function(e,t){return"case "+t+":res = fn.call("+["self"].concat(n.slice(0,t)).concat("cb").join(",")+");break;"}).join(""),"default:","args[argLength] = cb;","res = fn.apply(self, args);","}","if (res &&",'(typeof res === "object" || typeof res === "function") &&','typeof res.then === "function"',") {rs(res);}","});","};"].join("");return Function(["Promise","fn"],i)(a,e)}var a=n(190),o=n(244);e.exports=a,a.denodeify=function(e,t){return"number"==typeof t&&t!==1/0?r(e,t):i(e)};var s="function (err, res) {if (err) { rj(err); } else { rs(res); }}";a.nodeify=function(e){return function(){var t=Array.prototype.slice.call(arguments),n="function"==typeof t[t.length-1]?t.pop():null,r=this;try{return e.apply(this,arguments).nodeify(n,r)}catch(i){if(null===n||"undefined"==typeof n)return new a(function(e,t){t(i)});o(function(){n.call(r,i)})}}},a.prototype.nodeify=function(e,t){return"function"!=typeof e?this:void this.then(function(n){o(function(){e.call(t,null,n)})},function(n){o(function(){e.call(t,n)})})}},function(e,t,n){"use strict";var r=n(190);e.exports=r,r.enableSynchronous=function(){r.prototype.isPending=function(){return 0==this.getState()},r.prototype.isFulfilled=function(){return 1==this.getState()},r.prototype.isRejected=function(){return 2==this.getState()},r.prototype.getValue=function(){if(3===this._81)return this._65.getValue();if(!this.isFulfilled())throw new Error("Cannot get a value of an unfulfilled promise.");return this._65},r.prototype.getReason=function(){if(3===this._81)return this._65.getReason();if(!this.isRejected())throw new Error("Cannot get a rejection reason of a non-rejected promise.");return this._65},r.prototype.getState=function(){return 3===this._81?this._65.getState():-1===this._81||-2===this._81?0:this._81}},r.disableSynchronous=function(){r.prototype.isPending=void 0,r.prototype.isFulfilled=void 0,r.prototype.isRejected=void 0,r.prototype.getValue=void 0,r.prototype.getReason=void 0,r.prototype.getState=void 0}},function(e,t,n){function r(e){return null}function i(e,t){}function a(e){return!1}function o(e){}function s(e){}function u(e){return{isDirectory:function(){return!1},isSymbolicLink:function(){return!1},isFile:function(){return!1}}}function l(e){return this.statSync(e)}function p(e,t){return[]}function c(e){}t.readFileSync=r,t.writeFileSync=i,t.existsSync=a,t.mkdirSync=o,t.readdirSync=s,t.statSync=u,t.lstatSync=l,t.list=p,t.onChange=c},function(e,t,n){"use strict";var r=n(157);e.exports=new r({include:[n(211)],implicit:[n(212),n(213),n(214),n(215)]})},function(e,t,n){"use strict";function r(e){var t={};return null!==e&&Object.keys(e).forEach(function(n){e[n].forEach(function(e){t[String(e)]=n})}),t}function i(e,t){if(t=t||{},Object.keys(t).forEach(function(t){if(-1===o.indexOf(t))throw new a('Unknown option "'+t+'" is met in definition of "'+e+'" YAML type.')}),this.tag=e,this.kind=t.kind||null,this.resolve=t.resolve||function(){return!0},this.construct=t.construct||function(e){return e},this.instanceOf=t.instanceOf||null,this.predicate=t.predicate||null,this.represent=t.represent||null,this.defaultStyle=t.defaultStyle||null,this.styleAliases=r(t.styleAliases||null),-1===s.indexOf(this.kind))throw new a('Unknown kind "'+this.kind+'" is specified for "'+e+'" YAML type.')}var a=n(116),o=["kind","resolve","construct","instanceOf","predicate","represent","defaultStyle","styleAliases"],s=["scalar","sequence","mapping"];e.exports=i},function(e,t,n){"use strict";var r=n(217),i=n(201),a={brackets:function(e){return e+"[]"},indices:function(e,t){return e+"["+t+"]"},repeat:function(e){return e}},o=Date.prototype.toISOString,s={delimiter:"&",encode:!0,encoder:r.encode,serializeDate:function(e){return o.call(e)},skipNulls:!1,strictNullHandling:!1},u=function l(e,t,n,i,a,o,s,u,p,c,f){var m=e;if("function"==typeof s)m=s(t,m);else if(m instanceof Date)m=c(m);else if(null===m){if(i)return o?o(t):t;m=""}if("string"==typeof m||"number"==typeof m||"boolean"==typeof m||r.isBuffer(m))return o?[f(o(t))+"="+f(o(m))]:[f(t)+"="+f(String(m))];var d=[];if("undefined"==typeof m)return d;var h;if(Array.isArray(s))h=s;else{var y=Object.keys(m);h=u?y.sort(u):y}for(var v=0;v<h.length;++v){var g=h[v];a&&null===m[g]||(d=Array.isArray(m)?d.concat(l(m[g],n(t,g),n,i,a,o,s,u,p,c,f)):d.concat(l(m[g],t+(p?"."+g:"["+g+"]"),n,i,a,o,s,u,p,c,f)))}return d};e.exports=function(e,t){var n=e,r=t||{},o="undefined"==typeof r.delimiter?s.delimiter:r.delimiter,l="boolean"==typeof r.strictNullHandling?r.strictNullHandling:s.strictNullHandling,p="boolean"==typeof r.skipNulls?r.skipNulls:s.skipNulls,c="boolean"==typeof r.encode?r.encode:s.encode,f=c?"function"==typeof r.encoder?r.encoder:s.encoder:null,m="function"==typeof r.sort?r.sort:null,d="undefined"==typeof r.allowDots?!1:r.allowDots,h="function"==typeof r.serializeDate?r.serializeDate:s.serializeDate;if("undefined"==typeof r.format)r.format=i["default"];else if(!Object.prototype.hasOwnProperty.call(i.formatters,r.format))throw new TypeError("Unknown format option provided.");var y,v,g=i.formatters[r.format];if(null!==r.encoder&&void 0!==r.encoder&&"function"!=typeof r.encoder)throw new TypeError("Encoder has to be a function.");"function"==typeof r.filter?(v=r.filter,n=v("",n)):Array.isArray(r.filter)&&(v=r.filter,y=v);var A=[];if("object"!=typeof n||null===n)return"";var S;S=r.arrayFormat in a?r.arrayFormat:"indices"in r?r.indices?"indices":"repeat":"indices";var T=a[S];y||(y=Object.keys(n)),m&&y.sort(m);for(var E=0;E<y.length;++E){var b=y[E];p&&null===n[b]||(A=A.concat(u(n[b],b,T,l,p,f,v,m,d,h,g)))}return A.join(o)}},function(e,t,n){"use strict";var r=n(217),i=Object.prototype.hasOwnProperty,a={allowDots:!1,allowPrototypes:!1,arrayLimit:20,decoder:r.decode,delimiter:"&",depth:5,parameterLimit:1e3,plainObjects:!1,strictNullHandling:!1},o=function(e,t){for(var n={},r=e.split(t.delimiter,t.parameterLimit===1/0?void 0:t.parameterLimit),a=0;a<r.length;++a){var o,s,u=r[a],l=-1===u.indexOf("]=")?u.indexOf("="):u.indexOf("]=")+1;-1===l?(o=t.decoder(u),s=t.strictNullHandling?null:""):(o=t.decoder(u.slice(0,l)),s=t.decoder(u.slice(l+1))),i.call(n,o)?n[o]=[].concat(n[o]).concat(s):n[o]=s}return n},s=function l(e,t,n){if(!e.length)return t;var r,i=e.shift();if("[]"===i)r=[],r=r.concat(l(e,t,n));else{r=n.plainObjects?Object.create(null):{};var a="["===i[0]&&"]"===i[i.length-1]?i.slice(1,i.length-1):i,o=parseInt(a,10);!isNaN(o)&&i!==a&&String(o)===a&&o>=0&&n.parseArrays&&o<=n.arrayLimit?(r=[],r[o]=l(e,t,n)):r[a]=l(e,t,n)}return r},u=function(e,t,n){if(e){var r=n.allowDots?e.replace(/\.([^\.\[]+)/g,"[$1]"):e,a=/^([^\[\]]*)/,o=/(\[[^\[\]]*\])/g,u=a.exec(r),l=[];if(u[1]){if(!n.plainObjects&&i.call(Object.prototype,u[1])&&!n.allowPrototypes)return;l.push(u[1])}for(var p=0;null!==(u=o.exec(r))&&p<n.depth;)p+=1,(n.plainObjects||!i.call(Object.prototype,u[1].replace(/\[|\]/g,""))||n.allowPrototypes)&&l.push(u[1]);return u&&l.push("["+r.slice(u.index)+"]"),s(l,t,n)}};e.exports=function(e,t){var n=t||{};if(null!==n.decoder&&void 0!==n.decoder&&"function"!=typeof n.decoder)throw new TypeError("Decoder has to be a function.");if(n.delimiter="string"==typeof n.delimiter||r.isRegExp(n.delimiter)?n.delimiter:a.delimiter,n.depth="number"==typeof n.depth?n.depth:a.depth,n.arrayLimit="number"==typeof n.arrayLimit?n.arrayLimit:a.arrayLimit,n.parseArrays=n.parseArrays!==!1,n.decoder="function"==typeof n.decoder?n.decoder:a.decoder,n.allowDots="boolean"==typeof n.allowDots?n.allowDots:a.allowDots,n.plainObjects="boolean"==typeof n.plainObjects?n.plainObjects:a.plainObjects,n.allowPrototypes="boolean"==typeof n.allowPrototypes?n.allowPrototypes:a.allowPrototypes,n.parameterLimit="number"==typeof n.parameterLimit?n.parameterLimit:a.parameterLimit,n.strictNullHandling="boolean"==typeof n.strictNullHandling?n.strictNullHandling:a.strictNullHandling,""===e||null===e||"undefined"==typeof e)return n.plainObjects?Object.create(null):{};for(var i="string"==typeof e?o(e,n):e,s=n.plainObjects?Object.create(null):{},l=Object.keys(i),p=0;p<l.length;++p){var c=l[p],f=u(c,i[c],n);s=r.merge(s,f,n)}return r.compact(s)}},function(e,t,n){"use strict";var r=String.prototype.replace,i=/%20/g;e.exports={"default":"RFC3986",formatters:{RFC1738:function(e){return r.call(e,i,"+")},RFC3986:function(e){return e}},RFC1738:"RFC1738",RFC3986:"RFC3986"}},function(e,t,n){var r,i;/**
	 * @preserve date-and-time.js (c) KNOWLEDGECODE | MIT
	 */
!function(a){"use strict";var o={},s="en",u={en:{MMMM:["January","February","March","April","May","June","July","August","September","October","November","December"],MMM:["Jan","Feb","Mar","Apr","May","Jun","Jul","Aug","Sep","Oct","Nov","Dec"],dddd:["Sunday","Monday","Tuesday","Wednesday","Thursday","Friday","Saturday"],ddd:["Sun","Mon","Tue","Wed","Thu","Fri","Sat"],dd:["Su","Mo","Tu","We","Th","Fr","Sa"],A:["a.m.","p.m."],formats:{YYYY:function(e){return("000"+e.getFullYear()).slice(-4)},YY:function(e){return("0"+e.getFullYear()).slice(-2)},Y:function(e){return""+e.getFullYear()},MMMM:function(e){return this.MMMM[e.getMonth()]},MMM:function(e){return this.MMM[e.getMonth()]},MM:function(e){return("0"+(e.getMonth()+1)).slice(-2)},M:function(e){return""+(e.getMonth()+1)},DD:function(e){return("0"+e.getDate()).slice(-2)},D:function(e){return""+e.getDate()},HH:function(e){return("0"+e.getHours()).slice(-2)},H:function(e){return""+e.getHours()},A:function(e){return this.A[e.getHours()>11|0]},hh:function(e){return("0"+(e.getHours()%12||12)).slice(-2)},h:function(e){return""+(e.getHours()%12||12)},mm:function(e){return("0"+e.getMinutes()).slice(-2)},m:function(e){return""+e.getMinutes()},ss:function(e){return("0"+e.getSeconds()).slice(-2)},s:function(e){return""+e.getSeconds()},SSS:function(e){return("00"+e.getMilliseconds()).slice(-3)},SS:function(e){return("0"+(e.getMilliseconds()/10|0)).slice(-2)},S:function(e){return""+(e.getMilliseconds()/100|0)},dddd:function(e){return this.dddd[e.getDay()]},ddd:function(e){return this.ddd[e.getDay()]},dd:function(e){return this.dd[e.getDay()]},Z:function(e){var t=e.utc?0:e.getTimezoneOffset()/.6;return(t>0?"-":"+")+("000"+Math.abs(t-t%100*.4)).slice(-4)},post:function(e){return e}},parsers:{h:function(e,t){return(12===e?0:e)+12*t},pre:function(e){return e}}}},l=function(){return"object"==typeof e&&"object"==typeof e.exports},p=function(e,t){for(var n=0,r=e.length;r>n&&0!==t(e[n],n);n++);},c=function(e,t){var n,r,i,a=0,o=t.match(/YYYY|YY|MMM?M?|DD|HH|hh|mm|ss|SSS?|./g),l={Y:0,M:1,D:1,A:0,H:0,h:0,m:0,s:0,S:0};return e=u[s].parsers.pre(e),p(o,function(t){n=t.charAt(0),r=t.length,i=e.slice(a),/^(MM|DD|HH|hh|mm|ss|SS?S?)$/.test(t)?l[n]=0|i.slice(0,r):/^(YYYY|YY|M|D|H|h|m|s)$/.test(t)?(i=(i.match(4===r?/^\d{1,4}/:/^\d\d?/)||[""])[0],r=i.length,l[n]=0|i,"Y"===n&&l.Y<70&&(l.Y+=2e3)):/^(MMMM?|A)$/.test(t)&&p(u[s][t],function(e,t){return i.indexOf(e)?void 0:(l[n]="M"===n?t+1:t,r=e.length,0)}),a+=r}),l},f=function(e,t){return u[s].parsers.h(e,t)};o.format=function(e,t,n){var r=new Date(e.getTime()+(n?6e4*e.getTimezoneOffset():0)),i=u[s],a=i.formats;return r.utc=n,t.replace(/(\[[^\[\]]*]|\[.*\][^\[]*\]|YYYY|YY|MMM?M?|DD|HH|hh|mm|ss|SSS?|ddd?d?|.)/g,function(e){var t=a[e];return t?a.post(t.call(i,r)):e.replace(/\[(.*)]/,"$1")})},o.parse=function(e,t,n){var r=c(e,t),i=new Date(r.Y,r.M-1,r.D,r.H||f(r.h,r.A),r.m,r.s,r.S);return n?new Date(i.getTime()-6e4*i.getTimezoneOffset()):i},o.isValid=function(e,t){var n=c(e,t),r=n.H||f(n.h,n.A),i=new Date(n.Y,n.M-1,n.D,r,n.m,n.s,n.S);return n.Y===i.getFullYear()&&n.M-1===i.getMonth()&&n.D===i.getDate()&&r===i.getHours()&&n.m===i.getMinutes()&&n.s===i.getSeconds()&&n.S===i.getMilliseconds()},o.addYears=function(e,t){var n=new Date(e.getTime());return n.setFullYear(n.getFullYear()+t),n},o.addMonths=function(e,t){var n=new Date(e.getTime());return n.setMonth(n.getMonth()+t),n},o.addDays=function(e,t){return new Date(e.getTime()+864e5*t)},o.addHours=function(e,t){return new Date(e.getTime()+36e5*t)},o.addMinutes=function(e,t){return new Date(e.getTime()+6e4*t)},o.addSeconds=function(e,t){return new Date(e.getTime()+1e3*t)},o.addMilliseconds=function(e,t){return new Date(e.getTime()+t)},o.subtract=function(e,t){var n=e.getTime()-t.getTime();return{toMilliseconds:function(){return n},toSeconds:function(){return n/1e3|0},toMinutes:function(){return n/6e4|0},toHours:function(){return n/36e5|0},toDays:function(){return n/864e5|0}}},o.isLeapYear=function(e){var t=e.getFullYear();return!((t%4||!(t%100))&&t%400)},o.locale=function(e){return e&&("en"!==e&&l()&&n(223)("./"+e),s=e),s},o.getLocales=function(e){return u[e||s]},o.setLocales=function(e,t){var n=function(e,t){var n,r,i=function(){};i.prototype=t,n=new i;for(r in e)e.hasOwnProperty(r)&&(n[r]=e[r]);return n},r=u[e]||u.en,i=n(t,r);t.formats&&(i.formats=n(t.formats,r.formats)),t.parsers&&(i.parsers=n(t.parsers,r.parsers)),u[e]=i},l()?e.exports=o:(r=[],i=function(){return o}.apply(t,r),!(void 0!==i&&(e.exports=i)))}(this)},function(e,t,n){(function(t){"use strict";function n(e,n,r,i){if("function"!=typeof e)throw new TypeError('"callback" argument must be a function');var a,o,s=arguments.length;switch(s){case 0:case 1:return t.nextTick(e);case 2:return t.nextTick(function(){e.call(null,n)});case 3:return t.nextTick(function(){e.call(null,n,r)});case 4:return t.nextTick(function(){e.call(null,n,r,i)});default:for(a=new Array(s-1),o=0;o<a.length;)a[o++]=arguments[o];return t.nextTick(function(){e.apply(null,a)})}}!t.version||0===t.version.indexOf("v0.")||0===t.version.indexOf("v1.")&&0!==t.version.indexOf("v1.8.")?e.exports=n:e.exports=t.nextTick}).call(t,n(61))},function(e,t,n){function r(){this._events=this._events||{},this._maxListeners=this._maxListeners||void 0}function i(e){return"function"==typeof e}function a(e){return"number"==typeof e}function o(e){return"object"==typeof e&&null!==e}function s(e){return void 0===e}e.exports=r,r.EventEmitter=r,r.prototype._events=void 0,r.prototype._maxListeners=void 0,r.defaultMaxListeners=10,r.prototype.setMaxListeners=function(e){if(!a(e)||0>e||isNaN(e))throw TypeError("n must be a positive number");return this._maxListeners=e,this},r.prototype.emit=function(e){var t,n,r,a,u,l;if(this._events||(this._events={}),"error"===e&&(!this._events.error||o(this._events.error)&&!this._events.error.length)){if(t=arguments[1],t instanceof Error)throw t;var p=new Error('Uncaught, unspecified "error" event. ('+t+")");throw p.context=t,p}if(n=this._events[e],s(n))return!1;if(i(n))switch(arguments.length){case 1:n.call(this);break;case 2:n.call(this,arguments[1]);break;case 3:n.call(this,arguments[1],arguments[2]);break;default:a=Array.prototype.slice.call(arguments,1),n.apply(this,a)}else if(o(n))for(a=Array.prototype.slice.call(arguments,1),l=n.slice(),r=l.length,u=0;r>u;u++)l[u].apply(this,a);return!0},r.prototype.addListener=function(e,t){var n;if(!i(t))throw TypeError("listener must be a function");return this._events||(this._events={}),this._events.newListener&&this.emit("newListener",e,i(t.listener)?t.listener:t),this._events[e]?o(this._events[e])?this._events[e].push(t):this._events[e]=[this._events[e],t]:this._events[e]=t,o(this._events[e])&&!this._events[e].warned&&(n=s(this._maxListeners)?r.defaultMaxListeners:this._maxListeners,n&&n>0&&this._events[e].length>n&&(this._events[e].warned=!0,console.error("(node) warning: possible EventEmitter memory leak detected. %d listeners added. Use emitter.setMaxListeners() to increase limit.",this._events[e].length),"function"==typeof console.trace&&console.trace())),this},r.prototype.on=r.prototype.addListener,r.prototype.once=function(e,t){function n(){this.removeListener(e,n),r||(r=!0,t.apply(this,arguments))}if(!i(t))throw TypeError("listener must be a function");var r=!1;return n.listener=t,this.on(e,n),this},r.prototype.removeListener=function(e,t){var n,r,a,s;if(!i(t))throw TypeError("listener must be a function");if(!this._events||!this._events[e])return this;if(n=this._events[e],a=n.length,r=-1,n===t||i(n.listener)&&n.listener===t)delete this._events[e],this._events.removeListener&&this.emit("removeListener",e,t);else if(o(n)){for(s=a;s-->0;)if(n[s]===t||n[s].listener&&n[s].listener===t){r=s;break}if(0>r)return this;1===n.length?(n.length=0,delete this._events[e]):n.splice(r,1),this._events.removeListener&&this.emit("removeListener",e,t)}return this},r.prototype.removeAllListeners=function(e){var t,n;if(!this._events)return this;if(!this._events.removeListener)return 0===arguments.length?this._events={}:this._events[e]&&delete this._events[e],this;if(0===arguments.length){for(t in this._events)"removeListener"!==t&&this.removeAllListeners(t);return this.removeAllListeners("removeListener"),this._events={},this}if(n=this._events[e],i(n))this.removeListener(e,n);else if(n)for(;n.length;)this.removeListener(e,n[n.length-1]);return delete this._events[e],this},r.prototype.listeners=function(e){var t;return t=this._events&&this._events[e]?i(this._events[e])?[this._events[e]]:this._events[e].slice():[]},r.prototype.listenerCount=function(e){if(this._events){var t=this._events[e];if(i(t))return 1;if(t)return t.length}return 0},r.listenerCount=function(e,t){return e.listenerCount(t)}},function(e,t,n){var r={}.toString;e.exports=Array.isArray||function(e){return"[object Array]"==r.call(e)}},function(e,t,n){function r(e){if(e&&!u(e))throw new Error("Unknown encoding: "+e)}function i(e){return e.toString(this.encoding)}function a(e){this.charReceived=e.length%2,this.charLength=this.charReceived?2:0}function o(e){this.charReceived=e.length%3,this.charLength=this.charReceived?3:0}var s=n(94).Buffer,u=s.isEncoding||function(e){switch(e&&e.toLowerCase()){case"hex":case"utf8":case"utf-8":case"ascii":case"binary":case"base64":case"ucs2":case"ucs-2":case"utf16le":case"utf-16le":case"raw":return!0;default:return!1}},l=t.StringDecoder=function(e){switch(this.encoding=(e||"utf8").toLowerCase().replace(/[-_]/,""),r(e),this.encoding){case"utf8":this.surrogateSize=3;break;case"ucs2":case"utf16le":this.surrogateSize=2,this.detectIncompleteChar=a;break;case"base64":this.surrogateSize=3,this.detectIncompleteChar=o;break;default:return void(this.write=i)}this.charBuffer=new s(6),this.charReceived=0,this.charLength=0};l.prototype.write=function(e){for(var t="";this.charLength;){var n=e.length>=this.charLength-this.charReceived?this.charLength-this.charReceived:e.length;if(e.copy(this.charBuffer,this.charReceived,0,n),this.charReceived+=n,this.charReceived<this.charLength)return"";e=e.slice(n,e.length),t=this.charBuffer.slice(0,this.charLength).toString(this.encoding);var r=t.charCodeAt(t.length-1);if(!(r>=55296&&56319>=r)){if(this.charReceived=this.charLength=0,0===e.length)return t;break}this.charLength+=this.surrogateSize,t=""}this.detectIncompleteChar(e);var i=e.length;this.charLength&&(e.copy(this.charBuffer,0,e.length-this.charReceived,i),i-=this.charReceived),t+=e.toString(this.encoding,0,i);var i=t.length-1,r=t.charCodeAt(i);if(r>=55296&&56319>=r){var a=this.surrogateSize;return this.charLength+=a,this.charReceived+=a,this.charBuffer.copy(this.charBuffer,a,0,a),e.copy(this.charBuffer,0,0,a),t.substring(0,i)}return t},l.prototype.detectIncompleteChar=function(e){for(var t=e.length>=3?3:e.length;t>0;t--){var n=e[e.length-t];if(1==t&&n>>5==6){this.charLength=2;break}if(2>=t&&n>>4==14){this.charLength=3;break}if(3>=t&&n>>3==30){this.charLength=4;break}}this.charReceived=t},l.prototype.end=function(e){var t="";if(e&&e.length&&(t=this.write(e)),this.charReceived){var n=this.charReceived,r=this.charBuffer,i=this.encoding;t+=r.slice(0,n).toString(i)}return t}},function(e,t,n){function r(){}function i(e,t,n,r,i){function p(e){if(e>65535){e-=65536;var t=55296+(e>>10),n=56320+(1023&e);return String.fromCharCode(t,n)}return String.fromCharCode(e)}function d(e){var t=e.slice(1,-1);return t in n?n[t]:"#"===t.charAt(0)?p(parseInt(t.substr(1).replace("x","0x"))):(i.error("entity not found:"+e),e)}function h(t){if(t>b){var n=e.substring(b,t).replace(/&#?\w+;/g,d);S&&y(b),r.characters(n,0,t-b),b=t}}function y(t,n){for(;t>=g&&(n=A.exec(e));)v=n.index,g=v+n[0].length,S.lineNumber++;S.columnNumber=t-v+1}for(var v=0,g=0,A=/.+(?:\r\n?|\n)|.*$/g,S=r.locator,T=[{currentNSMap:t}],E={},b=0;;){try{var N=e.indexOf("<",b);if(0>N){if(!e.substr(b).match(/^\s*$/)){var _=r.document,M=_.createTextNode(e.substr(b));_.appendChild(M),r.currentElement=M}return}switch(N>b&&h(N),e.charAt(N+1)){case"/":var w=e.indexOf(">",N+3),R=e.substring(N+2,w),I=T.pop(),C=I.localNSMap;if(I.tagName!=R&&i.fatalError("end tag name: "+R+" is not match the current start tagName:"+I.tagName),r.endElement(I.uri,I.localName,R),C)for(var L in C)r.endPrefixMapping(L);w++;break;case"?":S&&y(N),w=f(e,N,r);break;case"!":S&&y(N),w=c(e,N,r,i);break;default:S&&y(N);var P=new m,w=o(e,N,P,d,i),O=P.length;if(S){if(O)for(var D=0;O>D;D++){var x=P[D];y(x.offset),x.offset=a(S,{})}y(w)}!P.closed&&l(e,w,P.tagName,E)&&(P.closed=!0,n.nbsp||i.warning("unclosed xml attribute")),s(P,r,T),"http://www.w3.org/1999/xhtml"!==P.uri||P.closed?w++:w=u(e,w,P.tagName,d,r)}}catch(U){i.error("element parse error: "+U),w=-1}w>b?b=w:h(Math.max(N,b)+1)}}function a(e,t){return t.lineNumber=e.lineNumber,t.columnNumber=e.columnNumber,t}function o(e,t,n,r,i){for(var a,o,s=++t,u=A;;){var l=e.charAt(s);switch(l){case"=":if(u===S)a=e.slice(t,s),u=E;else{if(u!==T)throw new Error("attribute equal must after attrName");u=E}break;case"'":case'"':if(u===E){if(t=s+1,s=e.indexOf(l,t),!(s>0))throw new Error("attribute value no end '"+l+"' match");o=e.slice(t,s).replace(/&#?\w+;/g,r),n.add(a,o,t-1),u=N}else{if(u!=b)throw new Error('attribute value must after "="');o=e.slice(t,s).replace(/&#?\w+;/g,r),n.add(a,o,t),i.warning('attribute "'+a+'" missed start quot('+l+")!!"),t=s+1,u=N}break;case"/":switch(u){case A:n.setTagName(e.slice(t,s));case N:case _:case M:u=M,n.closed=!0;case b:case S:case T:break;default:throw new Error("attribute invalid close char('/')")}break;case"":i.error("unexpected end of input");case">":switch(u){case A:n.setTagName(e.slice(t,s));case N:case _:case M:break;case b:case S:o=e.slice(t,s),"/"===o.slice(-1)&&(n.closed=!0,o=o.slice(0,-1));case T:u===T&&(o=a),u==b?(i.warning('attribute "'+o+'" missed quot(")!!'),n.add(a,o.replace(/&#?\w+;/g,r),t)):(i.warning('attribute "'+o+'" missed value!! "'+o+'" instead!!'),n.add(o,o,t));break;case E:throw new Error("attribute value missed!!")}return s;case"":l=" ";default:if(" ">=l)switch(u){case A:n.setTagName(e.slice(t,s)),u=_;break;case S:a=e.slice(t,s),u=T;break;case b:var o=e.slice(t,s).replace(/&#?\w+;/g,r);i.warning('attribute "'+o+'" missed quot(")!!'),n.add(a,o,t);case N:u=_}else switch(u){case T:i.warning('attribute "'+a+'" missed value!! "'+a+'" instead!!'),n.add(a,a,t),t=s,u=S;break;case N:i.warning('attribute space is required"'+a+'"!!');case _:u=S,t=s;break;case E:u=b,t=s;break;case M:throw new Error("elements closed character '/' and '>' must be connected to")}}s++}}function s(e,t,n){for(var r=e.tagName,i=null,a=n[n.length-1].currentNSMap,o=e.length;o--;){var s=e[o],u=s.qName,l=s.value,c=u.indexOf(":");if(c>0)var f=s.prefix=u.slice(0,c),m=u.slice(c+1),d="xmlns"===f&&m;else m=u,f=null,d="xmlns"===u&&"";s.localName=m,d!==!1&&(null==i&&(i={},p(a,a={})),a[d]=i[d]=l,s.uri="http://www.w3.org/2000/xmlns/",t.startPrefixMapping(d,l))}for(var o=e.length;o--;){s=e[o];var f=s.prefix;f&&("xml"===f&&(s.uri="http://www.w3.org/XML/1998/namespace"),"xmlns"!==f&&(s.uri=a[f]))}var c=r.indexOf(":");c>0?(f=e.prefix=r.slice(0,c),m=e.localName=r.slice(c+1)):(f=null,m=e.localName=r);var h=e.uri=a[f||""];if(t.startElement(h,m,r,e),e.closed){if(t.endElement(h,m,r),i)for(f in i)t.endPrefixMapping(f)}else e.currentNSMap=a,e.localNSMap=i,n.push(e)}function u(e,t,n,r,i){if(/^(?:script|textarea)$/i.test(n)){var a=e.indexOf("</"+n+">",t),o=e.substring(t+1,a);if(/[&<]/.test(o))return/^script$/i.test(n)?(i.characters(o,0,o.length),a):(o=o.replace(/&#?\w+;/g,r),i.characters(o,0,o.length),a)}return t+1}function l(e,t,n,r){var i=r[n];return null==i&&(i=r[n]=e.lastIndexOf("</"+n+">")),t>i}function p(e,t){for(var n in e)t[n]=e[n]}function c(e,t,n,r){var i=e.charAt(t+2);switch(i){case"-":if("-"===e.charAt(t+3)){var a=e.indexOf("-->",t+4);return a>t?(n.comment(e,t+4,a-t-4),a+3):(r.error("Unclosed comment"),-1)}return-1;default:if("CDATA["==e.substr(t+3,6)){var a=e.indexOf("]]>",t+9);return n.startCDATA(),n.characters(e,t+9,a-t-9),n.endCDATA(),a+3}var o=h(e,t),s=o.length;if(s>1&&/!doctype/i.test(o[0][0])){var u=o[1][0],l=s>3&&/^public$/i.test(o[2][0])&&o[3][0],p=s>4&&o[4][0],c=o[s-1];return n.startDTD(u,l&&l.replace(/^(['"])(.*?)\1$/,"$2"),p&&p.replace(/^(['"])(.*?)\1$/,"$2")),n.endDTD(),c.index+c[0].length}}return-1}function f(e,t,n){var r=e.indexOf("?>",t);if(r){var i=e.substring(t,r).match(/^<\?(\S*)\s*([\s\S]*?)\s*$/);if(i){i[0].length;return n.processingInstruction(i[1],i[2]),r+2}return-1}return-1}function m(e){}function d(e,t){return e.__proto__=t,e}function h(e,t){var n,r=[],i=/'[^']+'|"[^"]+"|[^\s<>\/=]+=?|(\/?\s*>|<)/g;for(i.lastIndex=t,i.exec(e);n=i.exec(e);)if(r.push(n),n[1])return r}var y=/[A-Z_a-z\xC0-\xD6\xD8-\xF6\u00F8-\u02FF\u0370-\u037D\u037F-\u1FFF\u200C-\u200D\u2070-\u218F\u2C00-\u2FEF\u3001-\uD7FF\uF900-\uFDCF\uFDF0-\uFFFD]/,v=new RegExp("[\\-\\.0-9"+y.source.slice(1,-1)+"·̀-ͯ\\u203F-⁀]"),g=new RegExp("^"+y.source+v.source+"*(?::"+y.source+v.source+"*)?$"),A=0,S=1,T=2,E=3,b=4,N=5,_=6,M=7;r.prototype={parse:function(e,t,n){var r=this.domBuilder;r.startDocument(),p(t,t={}),i(e,t,n,r,this.errorHandler),r.endDocument()}},m.prototype={setTagName:function(e){if(!g.test(e))throw new Error("invalid tagName:"+e);this.tagName=e},add:function(e,t,n){if(!g.test(e))throw new Error("invalid attribute:"+e);this[this.length++]={qName:e,value:t,offset:n}},length:0,getLocalName:function(e){return this[e].localName},getOffset:function(e){return this[e].offset},getQName:function(e){return this[e].qName},getURI:function(e){return this[e].uri},getValue:function(e){return this[e].value}},d({},d.prototype)instanceof d||(d=function(e,t){function n(){}n.prototype=t,n=new n;for(t in e)n[t]=e[t];return n}),t.XMLReader=r},function(e,t,n){function r(e,t){for(var n in e)t[n]=e[n]}function i(e,t){function n(){}var i=e.prototype;if(Object.create){var a=Object.create(t.prototype);i.__proto__=a}i instanceof t||(n.prototype=t.prototype,n=new n,r(i,n),e.prototype=i=n),i.constructor!=e&&("function"!=typeof e&&console.error("unknow Class:"+e),i.constructor=e)}function a(e,t){if(t instanceof Error)var n=t;else n=this,Error.call(this,re[e]),this.message=re[e],Error.captureStackTrace&&Error.captureStackTrace(this,a);return n.code=e,t&&(this.message=this.message+": "+t),n}function o(){}function s(e,t){this._node=e,this._refresh=t,u(this)}function u(e){var t=e._node._inc||e._node.ownerDocument._inc;if(e._inc!=t){var n=e._refresh(e._node);K(e,"length",n.length),r(n,e),e._inc=t}}function l(){}function p(e,t){for(var n=e.length;n--;)if(e[n]===t)return n}function c(e,t,n,r){if(r?t[p(t,r)]=n:t[t.length++]=n,e){n.ownerElement=e;var i=e.ownerDocument;i&&(r&&A(i,e,r),g(i,e,n))}}function f(e,t,n){var r=p(t,n);if(!(r>=0))throw a(ie,new Error);for(var i=t.length-1;i>r;)t[r]=t[++r];if(t.length=i,e){var o=e.ownerDocument;o&&(A(o,e,n),n.ownerElement=null)}}function m(e){if(this._features={},e)for(var t in e)this._features=e[t]}function d(){}function h(e){return"<"==e&&"&lt;"||">"==e&&"&gt;"||"&"==e&&"&amp;"||'"'==e&&"&quot;"||"&#"+e.charCodeAt()+";"}function y(e,t){if(t(e))return!0;if(e=e.firstChild)do if(y(e,t))return!0;while(e=e.nextSibling)}function v(){}function g(e,t,n){e&&e._inc++;var r=n.namespaceURI;"http://www.w3.org/2000/xmlns/"==r&&(t._nsMap[n.prefix?n.localName:""]=n.value)}function A(e,t,n,r){e&&e._inc++;var i=n.namespaceURI;"http://www.w3.org/2000/xmlns/"==i&&delete t._nsMap[n.prefix?n.localName:""]}function S(e,t,n){if(e&&e._inc){e._inc++;var r=t.childNodes;if(n)r[r.length++]=n;else{for(var i=t.firstChild,a=0;i;)r[a++]=i,i=i.nextSibling;r.length=a}}}function T(e,t){var n=t.previousSibling,r=t.nextSibling;return n?n.nextSibling=r:e.firstChild=r,r?r.previousSibling=n:e.lastChild=n,S(e.ownerDocument,e),t}function E(e,t,n){var r=t.parentNode;if(r&&r.removeChild(t),t.nodeType===ee){var i=t.firstChild;if(null==i)return t;var a=t.lastChild}else i=a=t;var o=n?n.previousSibling:e.lastChild;i.previousSibling=o,a.nextSibling=n,o?o.nextSibling=i:e.firstChild=i,null==n?e.lastChild=a:n.previousSibling=a;do i.parentNode=e;while(i!==a&&(i=i.nextSibling));return S(e.ownerDocument||e,e),t.nodeType==ee&&(t.firstChild=t.lastChild=null),t}function b(e,t){var n=t.parentNode;if(n){var r=e.lastChild;n.removeChild(t);var r=e.lastChild}var r=e.lastChild;return t.parentNode=e,t.previousSibling=r,t.nextSibling=null,r?r.nextSibling=t:e.firstChild=t,e.lastChild=t,S(e.ownerDocument,e,t),t}function N(){this._nsMap={}}function _(){}function M(){}function w(){}function R(){}function I(){}function C(){}function L(){}function P(){}function O(){}function D(){}function x(){}function U(){}function k(e,t,n,r){switch(e.nodeType){case q:var i=e.attributes,a=i.length,o=e.firstChild,s=e.tagName;r=j===e.namespaceURI||r,t.push("<",s),n&&t.sort.apply(i,n);for(var u=0;a>u;u++)k(i.item(u),t,n,r);if(o||r&&!/^(?:meta|link|img|br|hr|input|button)$/i.test(s)){if(t.push(">"),r&&/^script$/i.test(s))o&&t.push(o.data);else for(;o;)k(o,t,n,r),o=o.nextSibling;t.push("</",s,">")}else t.push("/>");return;case Q:case ee:for(var o=e.firstChild;o;)k(o,t,n,r),o=o.nextSibling;return;case Y:return t.push(" ",e.name,'="',e.value.replace(/[<&"]/g,h),'"');case H:return t.push(e.data.replace(/[<&]/g,h));case $:return t.push("<![CDATA[",e.data,"]]>");case J:return t.push("<!--",e.data,"-->");case Z:var l=e.publicId,p=e.systemId;if(t.push("<!DOCTYPE ",e.name),l)t.push(' PUBLIC "',l),p&&"."!=p&&t.push('" "',p),t.push('">');else if(p&&"."!=p)t.push(' SYSTEM "',p,'">');else{var c=e.internalSubset;c&&t.push(" [",c,"]"),t.push(">")}return;case z:return t.push("<?",e.target," ",e.data,"?>");case G:return t.push("&",e.nodeName,";");default:t.push("??",e.nodeName)}}function F(e,t,n){var r;switch(t.nodeType){case q:r=t.cloneNode(!1),r.ownerDocument=e;case ee:break;case Y:n=!0}if(r||(r=t.cloneNode(!1)),r.ownerDocument=e,r.parentNode=null,n)for(var i=t.firstChild;i;)r.appendChild(F(e,i,n)),i=i.nextSibling;return r}function B(e,t,n){var r=new t.constructor;for(var i in t){var a=t[i];"object"!=typeof a&&a!=r[i]&&(r[i]=a)}switch(t.childNodes&&(r.childNodes=new o),r.ownerDocument=e,r.nodeType){case q:var s=t.attributes,u=r.attributes=new l,p=s.length;u._ownerElement=r;for(var c=0;p>c;c++)r.setAttributeNode(B(e,s.item(c),!0));break;case Y:n=!0}if(n)for(var f=t.firstChild;f;)r.appendChild(B(e,f,n)),f=f.nextSibling;return r}function K(e,t,n){e[t]=n}function V(e){switch(e.nodeType){case 1:case 11:var t=[];for(e=e.firstChild;e;)7!==e.nodeType&&8!==e.nodeType&&t.push(V(e)),e=e.nextSibling;return t.join("");default:return e.nodeValue}}var j="http://www.w3.org/1999/xhtml",W={},q=W.ELEMENT_NODE=1,Y=W.ATTRIBUTE_NODE=2,H=W.TEXT_NODE=3,$=W.CDATA_SECTION_NODE=4,G=W.ENTITY_REFERENCE_NODE=5,X=W.ENTITY_NODE=6,z=W.PROCESSING_INSTRUCTION_NODE=7,J=W.COMMENT_NODE=8,Q=W.DOCUMENT_NODE=9,Z=W.DOCUMENT_TYPE_NODE=10,ee=W.DOCUMENT_FRAGMENT_NODE=11,te=W.NOTATION_NODE=12,ne={},re={},ie=(ne.INDEX_SIZE_ERR=(re[1]="Index size error",1),ne.DOMSTRING_SIZE_ERR=(re[2]="DOMString size error",2),ne.HIERARCHY_REQUEST_ERR=(re[3]="Hierarchy request error",3),ne.WRONG_DOCUMENT_ERR=(re[4]="Wrong document",4),ne.INVALID_CHARACTER_ERR=(re[5]="Invalid character",5),ne.NO_DATA_ALLOWED_ERR=(re[6]="No data allowed",6),ne.NO_MODIFICATION_ALLOWED_ERR=(re[7]="No modification allowed",7),ne.NOT_FOUND_ERR=(re[8]="Not found",8)),ae=(ne.NOT_SUPPORTED_ERR=(re[9]="Not supported",9),ne.INUSE_ATTRIBUTE_ERR=(re[10]="Attribute in use",10));ne.INVALID_STATE_ERR=(re[11]="Invalid state",11),ne.SYNTAX_ERR=(re[12]="Syntax error",12),ne.INVALID_MODIFICATION_ERR=(re[13]="Invalid modification",13),ne.NAMESPACE_ERR=(re[14]="Invalid namespace",14),ne.INVALID_ACCESS_ERR=(re[15]="Invalid access",15);a.prototype=Error.prototype,r(ne,a),o.prototype={length:0,item:function(e){return this[e]||null},toString:function(){for(var e=[],t=0;t<this.length;t++)k(this[t],e);return e.join("")}},s.prototype.item=function(e){return u(this),this[e]},i(s,o),l.prototype={length:0,item:o.prototype.item,getNamedItem:function(e){for(var t=this.length;t--;){var n=this[t];if(n.nodeName==e)return n}},setNamedItem:function(e){var t=e.ownerElement;if(t&&t!=this._ownerElement)throw new a(ae);var n=this.getNamedItem(e.nodeName);return c(this._ownerElement,this,e,n),n},setNamedItemNS:function(e){var t,n=e.ownerElement;if(n&&n!=this._ownerElement)throw new a(ae);return t=this.getNamedItemNS(e.namespaceURI,e.localName),c(this._ownerElement,this,e,t),t},removeNamedItem:function(e){var t=this.getNamedItem(e);return f(this._ownerElement,this,t),t},removeNamedItemNS:function(e,t){var n=this.getNamedItemNS(e,t);return f(this._ownerElement,this,n),n},getNamedItemNS:function(e,t){for(var n=this.length;n--;){var r=this[n];if(r.localName==t&&r.namespaceURI==e)return r}return null}},m.prototype={hasFeature:function(e,t){var n=this._features[e.toLowerCase()];return n&&(!t||t in n)?!0:!1},createDocument:function(e,t,n){var r=new v;if(r.implementation=this,r.childNodes=new o,r.doctype=n,n&&r.appendChild(n),t){var i=r.createElementNS(e,t);r.appendChild(i)}return r},createDocumentType:function(e,t,n){var r=new C;return r.name=e,r.nodeName=e,r.publicId=t,r.systemId=n,r}},d.prototype={firstChild:null,lastChild:null,previousSibling:null,nextSibling:null,attributes:null,parentNode:null,childNodes:null,ownerDocument:null,nodeValue:null,namespaceURI:null,prefix:null,localName:null,insertBefore:function(e,t){return E(this,e,t)},replaceChild:function(e,t){this.insertBefore(e,t),t&&this.removeChild(t)},removeChild:function(e){return T(this,e)},appendChild:function(e){return this.insertBefore(e,null)},hasChildNodes:function(){return null!=this.firstChild},cloneNode:function(e){return B(this.ownerDocument||this,this,e)},normalize:function(){for(var e=this.firstChild;e;){var t=e.nextSibling;t&&t.nodeType==H&&e.nodeType==H?(this.removeChild(t),e.appendData(t.data)):(e.normalize(),e=t)}},isSupported:function(e,t){return this.ownerDocument.implementation.hasFeature(e,t)},hasAttributes:function(){return this.attributes.length>0},lookupPrefix:function(e){for(var t=this;t;){var n=t._nsMap;if(n)for(var r in n)if(n[r]==e)return r;t=2==t.nodeType?t.ownerDocument:t.parentNode}return null},lookupNamespaceURI:function(e){for(var t=this;t;){var n=t._nsMap;if(n&&e in n)return n[e];t=2==t.nodeType?t.ownerDocument:t.parentNode}return null},isDefaultNamespace:function(e){var t=this.lookupPrefix(e);return null==t}},r(W,d),r(W,d.prototype),v.prototype={nodeName:"#document",nodeType:Q,doctype:null,documentElement:null,_inc:1,insertBefore:function(e,t){if(e.nodeType==ee){for(var n=e.firstChild;n;){var r=n.nextSibling;this.insertBefore(n,t),n=r}return e}return null==this.documentElement&&1==e.nodeType&&(this.documentElement=e),E(this,e,t),e.ownerDocument=this,e},removeChild:function(e){return this.documentElement==e&&(this.documentElement=null),T(this,e)},importNode:function(e,t){return F(this,e,t)},getElementById:function(e){var t=null;return y(this.documentElement,function(n){return 1==n.nodeType&&n.getAttribute("id")==e?(t=n,!0):void 0}),t},createElement:function(e){var t=new N;t.ownerDocument=this,t.nodeName=e,t.tagName=e,t.childNodes=new o;var n=t.attributes=new l;return n._ownerElement=t,t},createDocumentFragment:function(){var e=new D;return e.ownerDocument=this,e.childNodes=new o,e},createTextNode:function(e){var t=new w;return t.ownerDocument=this,t.appendData(e),t},createComment:function(e){var t=new R;return t.ownerDocument=this,t.appendData(e),t},createCDATASection:function(e){var t=new I;return t.ownerDocument=this,t.appendData(e),t},createProcessingInstruction:function(e,t){var n=new x;return n.ownerDocument=this,n.tagName=n.target=e,n.nodeValue=n.data=t,n},createAttribute:function(e){var t=new _;return t.ownerDocument=this,t.name=e,t.nodeName=e,t.localName=e,t.specified=!0,t},createEntityReference:function(e){var t=new O;return t.ownerDocument=this,t.nodeName=e,t},createElementNS:function(e,t){var n=new N,r=t.split(":"),i=n.attributes=new l;return n.childNodes=new o,n.ownerDocument=this,n.nodeName=t,n.tagName=t,n.namespaceURI=e,2==r.length?(n.prefix=r[0],n.localName=r[1]):n.localName=t,i._ownerElement=n,n},createAttributeNS:function(e,t){var n=new _,r=t.split(":");return n.ownerDocument=this,n.nodeName=t,n.name=t,n.namespaceURI=e,n.specified=!0,2==r.length?(n.prefix=r[0],n.localName=r[1]):n.localName=t,n}},i(v,d),N.prototype={nodeType:q,hasAttribute:function(e){return null!=this.getAttributeNode(e)},getAttribute:function(e){var t=this.getAttributeNode(e);return t&&t.value||""},getAttributeNode:function(e){return this.attributes.getNamedItem(e)},setAttribute:function(e,t){var n=this.ownerDocument.createAttribute(e);n.value=n.nodeValue=""+t,this.setAttributeNode(n)},removeAttribute:function(e){var t=this.getAttributeNode(e);t&&this.removeAttributeNode(t)},appendChild:function(e){return e.nodeType===ee?this.insertBefore(e,null):b(this,e)},setAttributeNode:function(e){return this.attributes.setNamedItem(e)},setAttributeNodeNS:function(e){return this.attributes.setNamedItemNS(e)},removeAttributeNode:function(e){return this.attributes.removeNamedItem(e.nodeName)},removeAttributeNS:function(e,t){var n=this.getAttributeNodeNS(e,t);n&&this.removeAttributeNode(n)},hasAttributeNS:function(e,t){return null!=this.getAttributeNodeNS(e,t)},getAttributeNS:function(e,t){var n=this.getAttributeNodeNS(e,t);return n&&n.value||""},setAttributeNS:function(e,t,n){var r=this.ownerDocument.createAttributeNS(e,t);r.value=r.nodeValue=""+n,this.setAttributeNode(r)},getAttributeNodeNS:function(e,t){return this.attributes.getNamedItemNS(e,t)},getElementsByTagName:function(e){return new s(this,function(t){var n=[];return y(t,function(r){r===t||r.nodeType!=q||"*"!==e&&r.tagName!=e||n.push(r)}),n})},getElementsByTagNameNS:function(e,t){return new s(this,function(n){var r=[];return y(n,function(i){i===n||i.nodeType!==q||"*"!==e&&i.namespaceURI!==e||"*"!==t&&i.localName!=t||r.push(i)}),r})}},v.prototype.getElementsByTagName=N.prototype.getElementsByTagName,v.prototype.getElementsByTagNameNS=N.prototype.getElementsByTagNameNS,i(N,d),_.prototype.nodeType=Y,i(_,d),M.prototype={data:"",substringData:function(e,t){return this.data.substring(e,e+t)},appendData:function(e){e=this.data+e,this.nodeValue=this.data=e,this.length=e.length},insertData:function(e,t){this.replaceData(e,0,t)},appendChild:function(e){throw new Error(re[3])},deleteData:function(e,t){this.replaceData(e,t,"")},replaceData:function(e,t,n){var r=this.data.substring(0,e),i=this.data.substring(e+t);n=r+n+i,this.nodeValue=this.data=n,this.length=n.length}},i(M,d),w.prototype={nodeName:"#text",nodeType:H,splitText:function(e){var t=this.data,n=t.substring(e);t=t.substring(0,e),this.data=this.nodeValue=t,this.length=t.length;var r=this.ownerDocument.createTextNode(n);return this.parentNode&&this.parentNode.insertBefore(r,this.nextSibling),r}},i(w,M),R.prototype={nodeName:"#comment",nodeType:J},i(R,M),I.prototype={nodeName:"#cdata-section",nodeType:$},i(I,M),C.prototype.nodeType=Z,i(C,d),L.prototype.nodeType=te,i(L,d),P.prototype.nodeType=X,i(P,d),O.prototype.nodeType=G,i(O,d),D.prototype.nodeName="#document-fragment",D.prototype.nodeType=ee,i(D,d),x.prototype.nodeType=z,i(x,d),U.prototype.serializeToString=function(e,t){return e.toString(t)},d.prototype.toString=function(e){var t=[];return k(this,t,e),t.join("")};try{Object.defineProperty&&(Object.defineProperty(s.prototype,"length",{get:function(){return u(this),this.$$length}}),Object.defineProperty(d.prototype,"textContent",{get:function(){return V(this)},set:function(e){switch(this.nodeType){case 1:case 11:for(;this.firstChild;)this.removeChild(this.firstChild);(e||String(e))&&this.appendChild(this.ownerDocument.createTextNode(e));break;default:this.data=e,this.value=value,this.nodeValue=e}}}),K=function(e,t,n){e["$$"+t]=n})}catch(oe){}t.DOMImplementation=m,t.XMLSerializer=U},function(e,t,n){(function(){"use strict";var e,r,i,a,o,s,u,l,p,c,f,m=function(e,t){function n(){this.constructor=e}for(var r in t)d.call(t,r)&&(e[r]=t[r]);return n.prototype=t.prototype,e.prototype=new n,e.__super__=t.prototype,e},d={}.hasOwnProperty,h=function(e,t){return function(){return e.apply(t,arguments);
}};p=n(251),a=n(204),r=n(252),e=n(225),u=n(226),c=n(245).setImmediate,o=function(e){return"object"==typeof e&&null!=e&&0===Object.keys(e).length},s=function(e,t){var n,r,i;for(n=0,r=e.length;r>n;n++)i=e[n],t=i(t);return t},l=function(e){return e.indexOf("&")>=0||e.indexOf(">")>=0||e.indexOf("<")>=0},f=function(e){return"<![CDATA["+i(e)+"]]>"},i=function(e){return e.replace("]]>","]]]]><![CDATA[>")},t.processors=u,t.defaults={.1:{explicitCharkey:!1,trim:!0,normalize:!0,normalizeTags:!1,attrkey:"@",charkey:"#",explicitArray:!1,ignoreAttrs:!1,mergeAttrs:!1,explicitRoot:!1,validator:null,xmlns:!1,explicitChildren:!1,childkey:"@@",charsAsChildren:!1,async:!1,strict:!0,attrNameProcessors:null,attrValueProcessors:null,tagNameProcessors:null,valueProcessors:null,emptyTag:""},.2:{explicitCharkey:!1,trim:!1,normalize:!1,normalizeTags:!1,attrkey:"$",charkey:"_",explicitArray:!0,ignoreAttrs:!1,mergeAttrs:!1,explicitRoot:!0,validator:null,xmlns:!1,explicitChildren:!1,preserveChildrenOrder:!1,childkey:"$$",charsAsChildren:!1,async:!1,strict:!0,attrNameProcessors:null,attrValueProcessors:null,tagNameProcessors:null,valueProcessors:null,rootName:"root",xmldec:{version:"1.0",encoding:"UTF-8",standalone:!0},doctype:null,renderOpts:{pretty:!0,indent:"  ",newline:"\n"},headless:!1,chunkSize:1e4,emptyTag:"",cdata:!1}},t.ValidationError=function(e){function t(e){this.message=e}return m(t,e),t}(Error),t.Builder=function(){function e(e){var n,r,i;this.options={},r=t.defaults[.2];for(n in r)d.call(r,n)&&(i=r[n],this.options[n]=i);for(n in e)d.call(e,n)&&(i=e[n],this.options[n]=i)}return e.prototype.buildObject=function(e){var n,i,a,o,s;return n=this.options.attrkey,i=this.options.charkey,1===Object.keys(e).length&&this.options.rootName===t.defaults[.2].rootName?(s=Object.keys(e)[0],e=e[s]):s=this.options.rootName,a=function(e){return function(t,r){var o,s,u,p,c,m;if("object"!=typeof r)e.options.cdata&&l(r)?t.raw(f(r)):t.txt(r);else for(c in r)if(d.call(r,c))if(s=r[c],c===n){if("object"==typeof s)for(o in s)m=s[o],t=t.att(o,m)}else if(c===i)t=e.options.cdata&&l(s)?t.raw(f(s)):t.txt(s);else if(Array.isArray(s))for(p in s)d.call(s,p)&&(u=s[p],t="string"==typeof u?e.options.cdata&&l(u)?t.ele(c).raw(f(u)).up():t.ele(c,u).up():a(t.ele(c),u).up());else"object"==typeof s?t=a(t.ele(c),s).up():"string"==typeof s&&e.options.cdata&&l(s)?t=t.ele(c).raw(f(s)).up():(null==s&&(s=""),t=t.ele(c,s.toString()).up());return t}}(this),o=r.create(s,this.options.xmldec,this.options.doctype,{headless:this.options.headless,allowSurrogateChars:this.options.allowSurrogateChars}),a(o,e).end(this.options.renderOpts)},e}(),t.Parser=function(n){function r(e){this.parseString=h(this.parseString,this),this.reset=h(this.reset,this),this.assignOrPush=h(this.assignOrPush,this),this.processAsync=h(this.processAsync,this);var n,r,i;if(!(this instanceof t.Parser))return new t.Parser(e);this.options={},r=t.defaults[.2];for(n in r)d.call(r,n)&&(i=r[n],this.options[n]=i);for(n in e)d.call(e,n)&&(i=e[n],this.options[n]=i);this.options.xmlns&&(this.options.xmlnskey=this.options.attrkey+"ns"),this.options.normalizeTags&&(this.options.tagNameProcessors||(this.options.tagNameProcessors=[]),this.options.tagNameProcessors.unshift(u.normalize)),this.reset()}return m(r,n),r.prototype.processAsync=function(){var e,t,n;try{return this.remaining.length<=this.options.chunkSize?(e=this.remaining,this.remaining="",this.saxParser=this.saxParser.write(e),this.saxParser.close()):(e=this.remaining.substr(0,this.options.chunkSize),this.remaining=this.remaining.substr(this.options.chunkSize,this.remaining.length),this.saxParser=this.saxParser.write(e),c(this.processAsync))}catch(n){if(t=n,!this.saxParser.errThrown)return this.saxParser.errThrown=!0,this.emit(t)}},r.prototype.assignOrPush=function(e,t,n){return t in e?(e[t]instanceof Array||(e[t]=[e[t]]),e[t].push(n)):this.options.explicitArray?e[t]=[n]:e[t]=n},r.prototype.reset=function(){var e,t,n,r;return this.removeAllListeners(),this.saxParser=p.parser(this.options.strict,{trim:!1,normalize:!1,xmlns:this.options.xmlns}),this.saxParser.errThrown=!1,this.saxParser.onerror=function(e){return function(t){return e.saxParser.resume(),e.saxParser.errThrown?void 0:(e.saxParser.errThrown=!0,e.emit("error",t))}}(this),this.saxParser.onend=function(e){return function(){return e.saxParser.ended?void 0:(e.saxParser.ended=!0,e.emit("end",e.resultObject))}}(this),this.saxParser.ended=!1,this.EXPLICIT_CHARKEY=this.options.explicitCharkey,this.resultObject=null,r=[],e=this.options.attrkey,t=this.options.charkey,this.saxParser.onopentag=function(n){return function(i){var a,o,u,l,p;if(u={},u[t]="",!n.options.ignoreAttrs){p=i.attributes;for(a in p)d.call(p,a)&&(e in u||n.options.mergeAttrs||(u[e]={}),o=n.options.attrValueProcessors?s(n.options.attrValueProcessors,i.attributes[a]):i.attributes[a],l=n.options.attrNameProcessors?s(n.options.attrNameProcessors,a):a,n.options.mergeAttrs?n.assignOrPush(u,l,o):u[e][l]=o)}return u["#name"]=n.options.tagNameProcessors?s(n.options.tagNameProcessors,i.name):i.name,n.options.xmlns&&(u[n.options.xmlnskey]={uri:i.uri,local:i.local}),r.push(u)}}(this),this.saxParser.onclosetag=function(e){return function(){var n,i,a,u,l,p,c,f,m,h,y,v;if(f=r.pop(),c=f["#name"],e.options.explicitChildren&&e.options.preserveChildrenOrder||delete f["#name"],f.cdata===!0&&(n=f.cdata,delete f.cdata),y=r[r.length-1],f[t].match(/^\s*$/)&&!n?(i=f[t],delete f[t]):(e.options.trim&&(f[t]=f[t].trim()),e.options.normalize&&(f[t]=f[t].replace(/\s{2,}/g," ").trim()),f[t]=e.options.valueProcessors?s(e.options.valueProcessors,f[t]):f[t],1===Object.keys(f).length&&t in f&&!e.EXPLICIT_CHARKEY&&(f=f[t])),o(f)&&(f=""!==e.options.emptyTag?e.options.emptyTag:i),null!=e.options.validator){v="/"+function(){var e,t,n;for(n=[],e=0,t=r.length;t>e;e++)p=r[e],n.push(p["#name"]);return n}().concat(c).join("/");try{f=e.options.validator(v,y&&y[c],f)}catch(u){a=u,e.emit("error",a)}}if(e.options.explicitChildren&&!e.options.mergeAttrs&&"object"==typeof f)if(e.options.preserveChildrenOrder){if(y){y[e.options.childkey]=y[e.options.childkey]||[],m={};for(l in f)d.call(f,l)&&(m[l]=f[l]);y[e.options.childkey].push(m),delete f["#name"],1===Object.keys(f).length&&t in f&&!e.EXPLICIT_CHARKEY&&(f=f[t])}}else p={},e.options.attrkey in f&&(p[e.options.attrkey]=f[e.options.attrkey],delete f[e.options.attrkey]),!e.options.charsAsChildren&&e.options.charkey in f&&(p[e.options.charkey]=f[e.options.charkey],delete f[e.options.charkey]),Object.getOwnPropertyNames(f).length>0&&(p[e.options.childkey]=f),f=p;return r.length>0?e.assignOrPush(y,c,f):(e.options.explicitRoot&&(h=f,f={},f[c]=h),e.resultObject=f,e.saxParser.ended=!0,e.emit("end",e.resultObject))}}(this),n=function(e){return function(n){var i,a;return a=r[r.length-1],a?(a[t]+=n,e.options.explicitChildren&&e.options.preserveChildrenOrder&&e.options.charsAsChildren&&""!==n.replace(/\\n/g,"").trim()&&(a[e.options.childkey]=a[e.options.childkey]||[],i={"#name":"__text__"},i[t]=n,a[e.options.childkey].push(i)),a):void 0}}(this),this.saxParser.ontext=n,this.saxParser.oncdata=function(e){return function(e){var t;return t=n(e),t?t.cdata=!0:void 0}}(this)},r.prototype.parseString=function(t,n){var r,i;null!=n&&"function"==typeof n&&(this.on("end",function(e){return this.reset(),n(null,e)}),this.on("error",function(e){return this.reset(),n(e)}));try{return t=t.toString(),""===t.trim()?(this.emit("end",null),!0):(t=e.stripBOM(t),this.options.async?(this.remaining=t,c(this.processAsync),this.saxParser):this.saxParser.write(t).close())}catch(i){if(r=i,!this.saxParser.errThrown&&!this.saxParser.ended)return this.emit("error",r),this.saxParser.errThrown=!0;if(this.saxParser.ended)throw r}},r}(a.EventEmitter),t.parseString=function(e,n,r){var i,a,o;return null!=r?("function"==typeof r&&(i=r),"object"==typeof n&&(a=n)):("function"==typeof n&&(i=n),a={}),o=new t.Parser(a),o.parseString(e,i)}}).call(this)},function(e,t,n){(function(t){function n(e,t){function n(){if(!i){if(r("throwDeprecation"))throw new Error(t);r("traceDeprecation")?console.trace(t):console.warn(t),i=!0}return e.apply(this,arguments)}if(r("noDeprecation"))return e;var i=!1;return n}function r(e){try{if(!t.localStorage)return!1}catch(n){return!1}var r=t.localStorage[e];return null==r?!1:"true"===String(r).toLowerCase()}e.exports=n}).call(t,function(){return this}())},function(e,t,n){"use strict";var r=n(157);e.exports=new r({explicit:[n(227),n(228),n(229)]})},function(e,t,n){"use strict";function r(e){if(null===e)return!0;var t=e.length;return 1===t&&"~"===e||4===t&&("null"===e||"Null"===e||"NULL"===e)}function i(){return null}function a(e){return null===e}var o=n(198);e.exports=new o("tag:yaml.org,2002:null",{kind:"scalar",resolve:r,construct:i,predicate:a,represent:{canonical:function(){return"~"},lowercase:function(){return"null"},uppercase:function(){return"NULL"},camelcase:function(){return"Null"}},defaultStyle:"lowercase"})},function(e,t,n){"use strict";function r(e){if(null===e)return!1;var t=e.length;return 4===t&&("true"===e||"True"===e||"TRUE"===e)||5===t&&("false"===e||"False"===e||"FALSE"===e)}function i(e){return"true"===e||"True"===e||"TRUE"===e}function a(e){return"[object Boolean]"===Object.prototype.toString.call(e)}var o=n(198);e.exports=new o("tag:yaml.org,2002:bool",{kind:"scalar",resolve:r,construct:i,predicate:a,represent:{lowercase:function(e){return e?"true":"false"},uppercase:function(e){return e?"TRUE":"FALSE"},camelcase:function(e){return e?"True":"False"}},defaultStyle:"lowercase"})},function(e,t,n){"use strict";function r(e){return e>=48&&57>=e||e>=65&&70>=e||e>=97&&102>=e}function i(e){return e>=48&&55>=e}function a(e){return e>=48&&57>=e}function o(e){if(null===e)return!1;var t,n=e.length,o=0,s=!1;if(!n)return!1;if(t=e[o],("-"===t||"+"===t)&&(t=e[++o]),"0"===t){if(o+1===n)return!0;if(t=e[++o],"b"===t){for(o++;n>o;o++)if(t=e[o],"_"!==t){if("0"!==t&&"1"!==t)return!1;s=!0}return s}if("x"===t){for(o++;n>o;o++)if(t=e[o],"_"!==t){if(!r(e.charCodeAt(o)))return!1;s=!0}return s}for(;n>o;o++)if(t=e[o],"_"!==t){if(!i(e.charCodeAt(o)))return!1;s=!0}return s}for(;n>o;o++)if(t=e[o],"_"!==t){if(":"===t)break;if(!a(e.charCodeAt(o)))return!1;s=!0}return s?":"!==t?!0:/^(:[0-5]?[0-9])+$/.test(e.slice(o)):!1}function s(e){var t,n,r=e,i=1,a=[];return-1!==r.indexOf("_")&&(r=r.replace(/_/g,"")),t=r[0],("-"===t||"+"===t)&&("-"===t&&(i=-1),r=r.slice(1),t=r[0]),"0"===r?0:"0"===t?"b"===r[1]?i*parseInt(r.slice(2),2):"x"===r[1]?i*parseInt(r,16):i*parseInt(r,8):-1!==r.indexOf(":")?(r.split(":").forEach(function(e){a.unshift(parseInt(e,10))}),r=0,n=1,a.forEach(function(e){r+=e*n,n*=60}),i*r):i*parseInt(r,10)}function u(e){return"[object Number]"===Object.prototype.toString.call(e)&&0===e%1&&!l.isNegativeZero(e)}var l=n(115),p=n(198);e.exports=new p("tag:yaml.org,2002:int",{kind:"scalar",resolve:o,construct:s,predicate:u,represent:{binary:function(e){return"0b"+e.toString(2)},octal:function(e){return"0"+e.toString(8)},decimal:function(e){return e.toString(10)},hexadecimal:function(e){return"0x"+e.toString(16).toUpperCase()}},defaultStyle:"decimal",styleAliases:{binary:[2,"bin"],octal:[8,"oct"],decimal:[10,"dec"],hexadecimal:[16,"hex"]}})},function(e,t,n){"use strict";function r(e){if(null===e)return!1;return l.test(e)?!0:!1}function i(e){var t,n,r,i;return t=e.replace(/_/g,"").toLowerCase(),n="-"===t[0]?-1:1,i=[],0<="+-".indexOf(t[0])&&(t=t.slice(1)),".inf"===t?1===n?Number.POSITIVE_INFINITY:Number.NEGATIVE_INFINITY:".nan"===t?NaN:0<=t.indexOf(":")?(t.split(":").forEach(function(e){i.unshift(parseFloat(e,10))}),t=0,r=1,i.forEach(function(e){t+=e*r,r*=60}),n*t):n*parseFloat(t,10)}function a(e,t){if(isNaN(e))switch(t){case"lowercase":return".nan";case"uppercase":return".NAN";case"camelcase":return".NaN"}else if(Number.POSITIVE_INFINITY===e)switch(t){case"lowercase":return".inf";case"uppercase":return".INF";case"camelcase":return".Inf"}else if(Number.NEGATIVE_INFINITY===e)switch(t){case"lowercase":return"-.inf";case"uppercase":return"-.INF";case"camelcase":return"-.Inf"}else if(s.isNegativeZero(e))return"-0.0";return e.toString(10)}function o(e){return"[object Number]"===Object.prototype.toString.call(e)&&(0!==e%1||s.isNegativeZero(e))}var s=n(115),u=n(198),l=new RegExp("^(?:[-+]?(?:[0-9][0-9_]*)\\.[0-9_]*(?:[eE][-+][0-9]+)?|\\.[0-9_]+(?:[eE][-+][0-9]+)?|[-+]?[0-9][0-9_]*(?::[0-5]?[0-9])+\\.[0-9_]*|[-+]?\\.(?:inf|Inf|INF)|\\.(?:nan|NaN|NAN))$");e.exports=new u("tag:yaml.org,2002:float",{kind:"scalar",resolve:r,construct:i,predicate:o,represent:a,defaultStyle:"lowercase"})},function(e,t,n){(function(e){function n(e){return Array.isArray?Array.isArray(e):"[object Array]"===y(e)}function r(e){return"boolean"==typeof e}function i(e){return null===e}function a(e){return null==e}function o(e){return"number"==typeof e}function s(e){return"string"==typeof e}function u(e){return"symbol"==typeof e}function l(e){return void 0===e}function p(e){return"[object RegExp]"===y(e)}function c(e){return"object"==typeof e&&null!==e}function f(e){return"[object Date]"===y(e)}function m(e){return"[object Error]"===y(e)||e instanceof Error}function d(e){return"function"==typeof e}function h(e){return null===e||"boolean"==typeof e||"number"==typeof e||"string"==typeof e||"symbol"==typeof e||"undefined"==typeof e}function y(e){return Object.prototype.toString.call(e)}t.isArray=n,t.isBoolean=r,t.isNull=i,t.isNullOrUndefined=a,t.isNumber=o,t.isString=s,t.isSymbol=u,t.isUndefined=l,t.isRegExp=p,t.isObject=c,t.isDate=f,t.isError=m,t.isFunction=d,t.isPrimitive=h,t.isBuffer=e.isBuffer}).call(t,n(94).Buffer)},function(e,t,n){"use strict";var r=Object.prototype.hasOwnProperty,i=function(){for(var e=[],t=0;256>t;++t)e.push("%"+((16>t?"0":"")+t.toString(16)).toUpperCase());return e}();t.arrayToObject=function(e,t){for(var n=t&&t.plainObjects?Object.create(null):{},r=0;r<e.length;++r)"undefined"!=typeof e[r]&&(n[r]=e[r]);return n},t.merge=function(e,n,i){if(!n)return e;if("object"!=typeof n){if(Array.isArray(e))e.push(n);else{if("object"!=typeof e)return[e,n];e[n]=!0}return e}if("object"!=typeof e)return[e].concat(n);var a=e;return Array.isArray(e)&&!Array.isArray(n)&&(a=t.arrayToObject(e,i)),Array.isArray(e)&&Array.isArray(n)?(n.forEach(function(n,a){r.call(e,a)?e[a]&&"object"==typeof e[a]?e[a]=t.merge(e[a],n,i):e.push(n):e[a]=n}),e):Object.keys(n).reduce(function(e,r){var a=n[r];return Object.prototype.hasOwnProperty.call(e,r)?e[r]=t.merge(e[r],a,i):e[r]=a,e},a)},t.decode=function(e){try{return decodeURIComponent(e.replace(/\+/g," "))}catch(t){return e}},t.encode=function(e){if(0===e.length)return e;for(var t="string"==typeof e?e:String(e),n="",r=0;r<t.length;++r){var a=t.charCodeAt(r);45===a||46===a||95===a||126===a||a>=48&&57>=a||a>=65&&90>=a||a>=97&&122>=a?n+=t.charAt(r):128>a?n+=i[a]:2048>a?n+=i[192|a>>6]+i[128|63&a]:55296>a||a>=57344?n+=i[224|a>>12]+i[128|a>>6&63]+i[128|63&a]:(r+=1,a=65536+((1023&a)<<10|1023&t.charCodeAt(r)),n+=i[240|a>>18]+i[128|a>>12&63]+i[128|a>>6&63]+i[128|63&a])}return n},t.compact=function(e,n){if("object"!=typeof e||null===e)return e;var r=n||[],i=r.indexOf(e);if(-1!==i)return r[i];if(r.push(e),Array.isArray(e)){for(var a=[],o=0;o<e.length;++o)e[o]&&"object"==typeof e[o]?a.push(t.compact(e[o],r)):"undefined"!=typeof e[o]&&a.push(e[o]);return a}var s=Object.keys(e);return s.forEach(function(n){e[n]=t.compact(e[n],r)}),e},t.isRegExp=function(e){return"[object RegExp]"===Object.prototype.toString.call(e)},t.isBuffer=function(e){return null===e||"undefined"==typeof e?!1:!!(e.constructor&&e.constructor.isBuffer&&e.constructor.isBuffer(e))}},function(e,t,n){(function(r){t=e.exports=n(247),t.Stream=n(177),t.Readable=t,t.Writable=n(246),t.Duplex=n(248),t.Transform=n(249),t.PassThrough=n(250),r.browser||"disable"!==r.env.READABLE_STREAM||(e.exports=n(177))}).call(t,n(61))},function(e,t,n){e.exports=n(246)},function(e,t,n){e.exports=n(248)},function(e,t,n){e.exports=n(249)},function(e,t,n){e.exports=n(250)},function(e,t,n){function r(e){return n(i(e))}function i(e){return a[e]||function(){throw new Error("Cannot find module '"+e+"'.")}()}var a={"./ar":231,"./ar.js":231,"./bn":232,"./bn.js":232,"./de":233,"./de.js":233,"./es":234,"./es.js":234,"./fr":235,"./fr.js":235,"./hi":236,"./hi.js":236,"./it":237,"./it.js":237,"./ja":238,"./ja.js":238,"./ko":239,"./ko.js":239,"./pt":240,"./pt.js":240,"./ru":241,"./ru.js":241,"./zh-cn":242,"./zh-cn.js":242,"./zh-tw":243,"./zh-tw.js":243};r.id=223,r.keys=function(){return Object.keys(a)},r.resolve=i,e.exports=r},function(e,t,n){"function"==typeof Object.create?e.exports=function(e,t){e.super_=t,e.prototype=Object.create(t.prototype,{constructor:{value:e,enumerable:!1,writable:!0,configurable:!0}})}:e.exports=function(e,t){e.super_=t;var n=function(){};n.prototype=t.prototype,e.prototype=new n,e.prototype.constructor=e}},function(e,t,n){(function(){"use strict";var e;e=n(209),t.stripBOM=function(e){return"\ufeff"===e[0]?e.substring(1):e}}).call(this)},function(e,t,n){(function(){"use strict";var e;e=new RegExp(/(?!xmlns)^.*:/),t.normalize=function(e){return e.toLowerCase()},t.firstCharLowerCase=function(e){return e.charAt(0).toLowerCase()+e.slice(1)},t.stripPrefix=function(t){return t.replace(e,"")},t.parseNumbers=function(e){return isNaN(e)||(e=e%1===0?parseInt(e,10):parseFloat(e)),e},t.parseBooleans=function(e){return/^(?:true|false)$/i.test(e)&&(e="true"===e.toLowerCase()),e}}).call(this)},function(e,t,n){"use strict";var r=n(198);e.exports=new r("tag:yaml.org,2002:str",{kind:"scalar",construct:function(e){return null!==e?e:""}})},function(e,t,n){"use strict";var r=n(198);e.exports=new r("tag:yaml.org,2002:seq",{kind:"sequence",construct:function(e){return null!==e?e:[]}})},function(e,t,n){"use strict";var r=n(198);e.exports=new r("tag:yaml.org,2002:map",{kind:"mapping",construct:function(e){return null!==e?e:{}}})},function(e,t,n){(function(t){"use strict";function n(e){s.length||(o(),u=!0),s[s.length]=e}function r(){for(;l<s.length;){var e=l;if(l+=1,s[e].call(),l>p){for(var t=0,n=s.length-l;n>t;t++)s[t]=s[t+l];s.length-=l,l=0}}s.length=0,l=0,u=!1}function i(e){var t=1,n=new f(e),r=document.createTextNode("");return n.observe(r,{characterData:!0}),function(){t=-t,r.data=t}}function a(e){return function(){function t(){clearTimeout(n),clearInterval(r),e()}var n=setTimeout(t,0),r=setInterval(t,50)}}e.exports=n;var o,s=[],u=!1,l=0,p=1024,c="undefined"!=typeof t?t:self,f=c.MutationObserver||c.WebKitMutationObserver;o="function"==typeof f?i(r):a(r),n.requestFlush=o,n.makeRequestCallFromTimer=a}).call(t,function(){return this}())},function(e,t,n){var r,i,a;/**
	 * @preserve date-and-time.js locale configuration
	 * @preserve Arabic (ar)
	 * @preserve It is using moment.js locale configuration as a reference.
	 */
!function(o){"use strict";var s=function(e){var t=["٠","١","٢","٣","٤","٥","٦","٧","٨","٩"],n={"٠":0,"١":1,"٢":2,"٣":3,"٤":4,"٥":5,"٦":6,"٧":7,"٨":8,"٩":9};e.setLocales("ar",{MMMM:["كانون الثاني يناير","شباط فبراير","آذار مارس","نيسان أبريل","أيار مايو","حزيران يونيو","تموز يوليو","آب أغسطس","أيلول سبتمبر","تشرين الأول أكتوبر","تشرين الثاني نوفمبر","كانون الأول ديسمبر"],MMM:["كانون الثاني يناير","شباط فبراير","آذار مارس","نيسان أبريل","أيار مايو","حزيران يونيو","تموز يوليو","آب أغسطس","أيلول سبتمبر","تشرين الأول أكتوبر","تشرين الثاني نوفمبر","كانون الأول ديسمبر"],dddd:["الأحد","الإثنين","الثلاثاء","الأربعاء","الخميس","الجمعة","السبت"],ddd:["أحد","إثنين","ثلاثاء","أربعاء","خميس","جمعة","سبت"],dd:["ح","ن","ث","ر","خ","ج","س"],A:["ص","م"],formats:{post:function(e){return e.replace(/\d/g,function(e){return t[0|e]})}},parsers:{pre:function(e){return e.replace(/[٠١٢٣٤٥٦٧٨٩]/g,function(e){return""+n[e]})}}})};"object"==typeof e&&"object"==typeof e.exports?s(n(202)):(i=[n(202)],r=s,a="function"==typeof r?r.apply(t,i):r,!(void 0!==a&&(e.exports=a)))}(this)},function(e,t,n){var r,i,a;/**
	 * @preserve date-and-time.js locale configuration
	 * @preserve Bengali (bn)
	 * @preserve It is using moment.js locale configuration as a reference.
	 */
!function(o){"use strict";var s=function(e){e.setLocales("bn",{MMMM:["জানুয়ারী","ফেবুয়ারী","মার্চ","এপ্রিল","মে","জুন","জুলাই","অগাস্ট","সেপ্টেম্বর","অক্টোবর","নভেম্বর","ডিসেম্বর"],MMM:["জানু","ফেব","মার্চ","এপর","মে","জুন","জুল","অগ","সেপ্ট","অক্টো","নভ","ডিসেম্"],dddd:["রবিবার","সোমবার","মঙ্গলবার","বুধবার","বৃহস্পত্তিবার","শুক্রবার","শনিবার"],ddd:["রবি","সোম","মঙ্গল","বুধ","বৃহস্পত্তি","শুক্র","শনি"],dd:["রব","সম","মঙ্গ","বু","ব্রিহ","শু","শনি"],A:["রাত","সকাল","দুপুর","বিকাল"],formats:{A:function(e){var t=e.getHours();return 4>t?this.A[0]:10>t?this.A[1]:17>t?this.A[2]:20>t?this.A[3]:this.A[0]}},parsers:{h:function(e,t){return 1>t?4>e||e>11?e:e+12:2>t?e:3>t&&e>9?e:e+12}}})};"object"==typeof e&&"object"==typeof e.exports?s(n(202)):(i=[n(202)],r=s,a="function"==typeof r?r.apply(t,i):r,!(void 0!==a&&(e.exports=a)))}(this)},function(e,t,n){var r,i,a;/**
	 * @preserve date-and-time.js locale configuration
	 * @preserve German (de)
	 * @preserve It is using moment.js locale configuration as a reference.
	 */
!function(o){"use strict";var s=function(e){e.setLocales("de",{MMMM:["Januar","Februar","März","April","Mai","Juni","Juli","August","September","Oktober","November","Dezember"],MMM:["Jan.","Febr.","Mrz.","Apr.","Mai","Jun.","Jul.","Aug.","Sept.","Okt.","Nov.","Dez."],dddd:["Sonntag","Montag","Dienstag","Mittwoch","Donnerstag","Freitag","Samstag"],ddd:["So.","Mo.","Di.","Mi.","Do.","Fr.","Sa."],dd:["So","Mo","Di","Mi","Do","Fr","Sa"],A:["Uhr nachmittags","Uhr morgens"]})};"object"==typeof e&&"object"==typeof e.exports?s(n(202)):(i=[n(202)],r=s,a="function"==typeof r?r.apply(t,i):r,!(void 0!==a&&(e.exports=a)))}(this)},function(e,t,n){var r,i,a;/**
	 * @preserve date-and-time.js locale configuration
	 * @preserve Spanish (es)
	 * @preserve It is using moment.js locale configuration as a reference.
	 */
!function(o){"use strict";var s=function(e){e.setLocales("es",{MMMM:["enero","febrero","marzo","abril","mayo","junio","julio","agosto","septiembre","octubre","noviembre","diciembre"],MMM:["ene.","feb.","mar.","abr.","may.","jun.","jul.","ago.","sep.","oct.","nov.","dic."],dddd:["domingo","lunes","martes","miércoles","jueves","viernes","sábado"],ddd:["dom.","lun.","mar.","mié.","jue.","vie.","sáb."],dd:["do","lu","ma","mi","ju","vi","sá"],A:["de la mañana","de la tarde","de la noche"],formats:{A:function(e){var t=e.getHours();return 12>t?this.A[0]:19>t?this.A[1]:this.A[2]}},parsers:{h:function(e,t){return 1>t?e:e>11?e:e+12}}})};"object"==typeof e&&"object"==typeof e.exports?s(n(202)):(i=[n(202)],r=s,a="function"==typeof r?r.apply(t,i):r,!(void 0!==a&&(e.exports=a)))}(this)},function(e,t,n){var r,i,a;/**
	 * @preserve date-and-time.js locale configuration
	 * @preserve French (fr)
	 * @preserve It is using moment.js locale configuration as a reference.
	 */
!function(o){"use strict";var s=function(e){e.setLocales("fr",{MMMM:["janvier","février","mars","avril","mai","juin","juillet","août","septembre","octobre","novembre","décembre"],MMM:["janv.","févr.","mars","avr.","mai","juin","juil.","août","sept.","oct.","nov.","déc."],dddd:["dimanche","lundi","mardi","mercredi","jeudi","vendredi","samedi"],ddd:["dim.","lun.","mar.","mer.","jeu.","ven.","sam."],dd:["Di","Lu","Ma","Me","Je","Ve","Sa"],A:["matin","l'après-midi"]})};"object"==typeof e&&"object"==typeof e.exports?s(n(202)):(i=[n(202)],r=s,a="function"==typeof r?r.apply(t,i):r,!(void 0!==a&&(e.exports=a)))}(this)},function(e,t,n){var r,i,a;/**
	 * @preserve date-and-time.js locale configuration
	 * @preserve Hindi (hi)
	 * @preserve It is using moment.js locale configuration as a reference.
	 */
!function(o){"use strict";var s=function(e){e.setLocales("hi",{MMMM:["जनवरी","फ़रवरी","मार्च","अप्रैल","मई","जून","जुलाई","अगस्त","सितम्बर","अक्टूबर","नवम्बर","दिसम्बर"],MMM:["जन.","फ़र.","मार्च","अप्रै.","मई","जून","जुल.","अग.","सित.","अक्टू.","नव.","दिस."],dddd:["रविवार","सोमवार","मंगलवार","बुधवार","गुरूवार","शुक्रवार","शनिवार"],ddd:["रवि","सोम","मंगल","बुध","गुरू","शुक्र","शनि"],dd:["र","सो","मं","बु","गु","शु","श"],A:["रात","सुबह","दोपहर","शाम"],formats:{A:function(e){var t=e.getHours();return 4>t?this.A[0]:10>t?this.A[1]:17>t?this.A[2]:20>t?this.A[3]:this.A[0]}},parsers:{h:function(e,t){return 1>t?4>e||e>11?e:e+12:2>t?e:3>t&&e>9?e:e+12}}})};"object"==typeof e&&"object"==typeof e.exports?s(n(202)):(i=[n(202)],r=s,a="function"==typeof r?r.apply(t,i):r,!(void 0!==a&&(e.exports=a)))}(this)},function(e,t,n){var r,i,a;/**
	 * @preserve date-and-time.js locale configuration
	 * @preserve Italian (it)
	 * @preserve It is using moment.js locale configuration as a reference.
	 */
!function(o){"use strict";var s=function(e){e.setLocales("it",{MMMM:["gennaio","febbraio","marzo","aprile","maggio","giugno","luglio","agosto","settembre","ottobre","novembre","dicembre"],MMM:["gen","feb","mar","apr","mag","giu","lug","ago","set","ott","nov","dic"],dddd:["Domenica","Lunedì","Martedì","Mercoledì","Giovedì","Venerdì","Sabato"],ddd:["Dom","Lun","Mar","Mer","Gio","Ven","Sab"],dd:["Do","Lu","Ma","Me","Gi","Ve","Sa"],A:["di mattina","di pomerrigio"]})};"object"==typeof e&&"object"==typeof e.exports?s(n(202)):(i=[n(202)],r=s,a="function"==typeof r?r.apply(t,i):r,!(void 0!==a&&(e.exports=a)))}(this)},function(e,t,n){var r,i,a;/**
	 * @preserve date-and-time.js locale configuration
	 * @preserve Japanese (ja)
	 * @preserve It is using moment.js locale configuration as a reference.
	 */
!function(o){"use strict";var s=function(e){e.setLocales("ja",{MMMM:["1月","2月","3月","4月","5月","6月","7月","8月","9月","10月","11月","12月"],MMM:["1月","2月","3月","4月","5月","6月","7月","8月","9月","10月","11月","12月"],dddd:["日曜日","月曜日","火曜日","水曜日","木曜日","金曜日","土曜日"],ddd:["日","月","火","水","木","金","土"],dd:["日","月","火","水","木","金","土"],A:["午前","午後"],formats:{hh:function(e){return("0"+e.getHours()%12).slice(-2)},h:function(e){return e.getHours()%12}}})};"object"==typeof e&&"object"==typeof e.exports?s(n(202)):(i=[n(202)],r=s,a="function"==typeof r?r.apply(t,i):r,!(void 0!==a&&(e.exports=a)))}(this)},function(e,t,n){var r,i,a;/**
	 * @preserve date-and-time.js locale configuration
	 * @preserve Korean (ko)
	 * @preserve It is using moment.js locale configuration as a reference.
	 */
!function(o){"use strict";var s=function(e){e.setLocales("ko",{MMMM:["1월","2월","3월","4월","5월","6월","7월","8월","9월","10월","11월","12월"],MMM:["1월","2월","3월","4월","5월","6월","7월","8월","9월","10월","11월","12월"],dddd:["일요일","월요일","화요일","수요일","목요일","금요일","토요일"],ddd:["일","월","화","수","목","금","토"],dd:["일","월","화","수","목","금","토"],A:["오전","오후"]})};"object"==typeof e&&"object"==typeof e.exports?s(n(202)):(i=[n(202)],r=s,a="function"==typeof r?r.apply(t,i):r,!(void 0!==a&&(e.exports=a)))}(this)},function(e,t,n){var r,i,a;/**
	 * @preserve date-and-time.js locale configuration
	 * @preserve Portuguese (pt)
	 * @preserve It is using moment.js locale configuration as a reference.
	 */
!function(o){"use strict";var s=function(e){e.setLocales("pt",{MMMM:["Janeiro","Fevereiro","Março","Abril","Maio","Junho","Julho","Agosto","Setembro","Outubro","Novembro","Dezembro"],MMM:["Jan","Fev","Mar","Abr","Mai","Jun","Jul","Ago","Set","Out","Nov","Dez"],dddd:["Domingo","Segunda-Feira","Terça-Feira","Quarta-Feira","Quinta-Feira","Sexta-Feira","Sábado"],ddd:["Dom","Seg","Ter","Qua","Qui","Sex","Sáb"],dd:["Dom","2ª","3ª","4ª","5ª","6ª","Sáb"],A:["da madrugada","da manhã","da tarde","da noite"],formats:{A:function(e){var t=e.getHours();return 5>t?this.A[0]:12>t?this.A[1]:19>t?this.A[2]:this.A[3]}},parsers:{h:function(e,t){return 2>t?e:e>11?e:e+12}}})};"object"==typeof e&&"object"==typeof e.exports?s(n(202)):(i=[n(202)],r=s,a="function"==typeof r?r.apply(t,i):r,!(void 0!==a&&(e.exports=a)))}(this)},function(e,t,n){var r,i,a;/**
	 * @preserve date-and-time.js locale configuration
	 * @preserve Russian (ru)
	 * @preserve It is using moment.js locale configuration as a reference.
	 */
!function(o){"use strict";var s=function(e){e.setLocales("ru",{MMMM:["Января","Февраля","Марта","Апреля","Мая","Июня","Июля","Августа","Сентября","Октября","Ноября","Декабря"],MMM:["янв","фев","мар","апр","мая","июня","июля","авг","сен","окт","ноя","дек"],dddd:["Воскресенье","Понедельник","Вторник","Среду","Четверг","Пятницу","Субботу"],ddd:["Вс","Пн","Вт","Ср","Чт","Пт","Сб"],dd:["Вс","Пн","Вт","Ср","Чт","Пт","Сб"],A:["ночи","утра","дня","вечера"],formats:{A:function(e){var t=e.getHours();return 4>t?this.A[0]:12>t?this.A[1]:17>t?this.A[2]:this.A[3]}},parsers:{h:function(e,t){return 2>t?e:e>11?e:e+12}}})};"object"==typeof e&&"object"==typeof e.exports?s(n(202)):(i=[n(202)],r=s,a="function"==typeof r?r.apply(t,i):r,!(void 0!==a&&(e.exports=a)))}(this)},function(e,t,n){var r,i,a;/**
	 * @preserve date-and-time.js locale configuration
	 * @preserve Chinese (zh-cn)
	 * @preserve It is using moment.js locale configuration as a reference.
	 */
!function(o){"use strict";var s=function(e){e.setLocales("zh-cn",{MMMM:["一月","二月","三月","四月","五月","六月","七月","八月","九月","十月","十一月","十二月"],MMM:["1月","2月","3月","4月","5月","6月","7月","8月","9月","10月","11月","12月"],dddd:["星期日","星期一","星期二","星期三","星期四","星期五","星期六"],ddd:["周日","周一","周二","周三","周四","周五","周六"],dd:["日","一","二","三","四","五","六"],A:["凌晨","早上","上午","中午","下午","晚上"],formats:{A:function(e){var t=100*e.getHours()+e.getMinutes();return 600>t?this.A[0]:900>t?this.A[1]:1130>t?this.A[2]:1230>t?this.A[3]:1800>t?this.A[4]:this.A[5]}},parsers:{h:function(e,t){return 4>t?e:e>11?e:e+12}}})};"object"==typeof e&&"object"==typeof e.exports?s(n(202)):(i=[n(202)],r=s,a="function"==typeof r?r.apply(t,i):r,!(void 0!==a&&(e.exports=a)))}(this)},function(e,t,n){var r,i,a;/**
	 * @preserve date-and-time.js locale configuration
	 * @preserve Chinese (zh-tw)
	 * @preserve It is using moment.js locale configuration as a reference.
	 */
!function(o){"use strict";var s=function(e){e.setLocales("zh-tw",{MMMM:["一月","二月","三月","四月","五月","六月","七月","八月","九月","十月","十一月","十二月"],MMM:["1月","2月","3月","4月","5月","6月","7月","8月","9月","10月","11月","12月"],dddd:["星期日","星期一","星期二","星期三","星期四","星期五","星期六"],ddd:["周日","周一","周二","周三","周四","周五","周六"],dd:["日","一","二","三","四","五","六"],A:["早上","上午","中午","下午","晚上"],formats:{A:function(e){var t=100*e.getHours()+e.getMinutes();return 900>t?this.A[0]:1130>t?this.A[1]:1230>t?this.A[2]:1800>t?this.A[3]:this.A[4]}},parsers:{h:function(e,t){return 3>t?e:e>11?e:e+12}}})};"object"==typeof e&&"object"==typeof e.exports?s(n(202)):(i=[n(202)],r=s,a="function"==typeof r?r.apply(t,i):r,!(void 0!==a&&(e.exports=a)))}(this)},function(e,t,n){"use strict";function r(){if(u.length)throw u.shift()}function i(e){var t;t=s.length?s.pop():new a,t.task=e,o(t)}function a(){this.task=null}var o=n(230),s=[],u=[],l=o.makeRequestCallFromTimer(r);e.exports=i,a.prototype.call=function(){try{this.task.call()}catch(e){i.onerror?i.onerror(e):(u.push(e),l())}finally{this.task=null,s[s.length]=this}}},function(e,t,n){function r(e,t){this._id=e,this._clearFn=t}var i=n(258).nextTick,a=Function.prototype.apply,o=Array.prototype.slice,s={},u=0;t.setTimeout=function(){return new r(a.call(setTimeout,window,arguments),clearTimeout)},t.setInterval=function(){return new r(a.call(setInterval,window,arguments),clearInterval)},t.clearTimeout=t.clearInterval=function(e){e.close()},r.prototype.unref=r.prototype.ref=function(){},r.prototype.close=function(){this._clearFn.call(window,this._id)},t.enroll=function(e,t){clearTimeout(e._idleTimeoutId),e._idleTimeout=t},t.unenroll=function(e){clearTimeout(e._idleTimeoutId),e._idleTimeout=-1},t._unrefActive=t.active=function(e){clearTimeout(e._idleTimeoutId);var t=e._idleTimeout;t>=0&&(e._idleTimeoutId=setTimeout(function(){e._onTimeout&&e._onTimeout()},t))},t.setImmediate="function"==typeof setImmediate?setImmediate:function(e){var n=u++,r=arguments.length<2?!1:o.call(arguments,1);return s[n]=!0,i(function(){s[n]&&(r?e.apply(null,r):e.call(null),t.clearImmediate(n))}),n},t.clearImmediate="function"==typeof clearImmediate?clearImmediate:function(e){delete s[e]}},function(e,t,n){(function(t){function r(e,t,n){this.chunk=e,this.encoding=t,this.callback=n}function i(e,t){var r=n(248);e=e||{};var i=e.highWaterMark,a=e.objectMode?16:16384;this.highWaterMark=i||0===i?i:a,this.objectMode=!!e.objectMode,t instanceof r&&(this.objectMode=this.objectMode||!!e.writableObjectMode),this.highWaterMark=~~this.highWaterMark,this.needDrain=!1,this.ending=!1,this.ended=!1,this.finished=!1;var o=e.decodeStrings===!1;this.decodeStrings=!o,this.defaultEncoding=e.defaultEncoding||"utf8",this.length=0,this.writing=!1,this.corked=0,this.sync=!0,this.bufferProcessing=!1,this.onwrite=function(e){m(t,e)},this.writecb=null,this.writelen=0,this.buffer=[],this.pendingcb=0,this.prefinished=!1,this.errorEmitted=!1}function a(e){var t=n(248);return this instanceof a||this instanceof t?(this._writableState=new i(e,this),this.writable=!0,void b.call(this)):new a(e)}function o(e,n,r){var i=new Error("write after end");e.emit("error",i),t.nextTick(function(){r(i)})}function s(e,n,r,i){var a=!0;if(!(E.isBuffer(r)||E.isString(r)||E.isNullOrUndefined(r)||n.objectMode)){var o=new TypeError("Invalid non-string/buffer chunk");e.emit("error",o),t.nextTick(function(){i(o)}),a=!1}return a}function u(e,t,n){return!e.objectMode&&e.decodeStrings!==!1&&E.isString(t)&&(t=new T(t,n)),t}function l(e,t,n,i,a){n=u(t,n,i),E.isBuffer(n)&&(i="buffer");var o=t.objectMode?1:n.length;t.length+=o;var s=t.length<t.highWaterMark;return s||(t.needDrain=!0),t.writing||t.corked?t.buffer.push(new r(n,i,a)):p(e,t,!1,o,n,i,a),s}function p(e,t,n,r,i,a,o){t.writelen=r,t.writecb=o,t.writing=!0,t.sync=!0,n?e._writev(i,t.onwrite):e._write(i,a,t.onwrite),t.sync=!1}function c(e,n,r,i,a){r?t.nextTick(function(){n.pendingcb--,a(i)}):(n.pendingcb--,a(i)),e._writableState.errorEmitted=!0,e.emit("error",i)}function f(e){e.writing=!1,e.writecb=null,e.length-=e.writelen,e.writelen=0}function m(e,n){var r=e._writableState,i=r.sync,a=r.writecb;if(f(r),n)c(e,r,i,n,a);else{var o=v(e,r);o||r.corked||r.bufferProcessing||!r.buffer.length||y(e,r),i?t.nextTick(function(){d(e,r,o,a)}):d(e,r,o,a)}}function d(e,t,n,r){n||h(e,t),t.pendingcb--,r(),A(e,t)}function h(e,t){0===t.length&&t.needDrain&&(t.needDrain=!1,e.emit("drain"))}function y(e,t){if(t.bufferProcessing=!0,e._writev&&t.buffer.length>1){for(var n=[],r=0;r<t.buffer.length;r++)n.push(t.buffer[r].callback);t.pendingcb++,p(e,t,!0,t.length,t.buffer,"",function(e){for(var r=0;r<n.length;r++)t.pendingcb--,n[r](e)}),t.buffer=[]}else{for(var r=0;r<t.buffer.length;r++){var i=t.buffer[r],a=i.chunk,o=i.encoding,s=i.callback,u=t.objectMode?1:a.length;if(p(e,t,!1,u,a,o,s),t.writing){r++;break}}r<t.buffer.length?t.buffer=t.buffer.slice(r):t.buffer.length=0}t.bufferProcessing=!1}function v(e,t){return t.ending&&0===t.length&&!t.finished&&!t.writing}function g(e,t){t.prefinished||(t.prefinished=!0,e.emit("prefinish"))}function A(e,t){var n=v(e,t);return n&&(0===t.pendingcb?(g(e,t),t.finished=!0,e.emit("finish")):g(e,t)),n}function S(e,n,r){n.ending=!0,A(e,n),r&&(n.finished?t.nextTick(r):e.once("finish",r)),n.ended=!0}e.exports=a;var T=n(94).Buffer;a.WritableState=i;var E=n(259);E.inherits=n(257);var b=n(177);E.inherits(a,b),a.prototype.pipe=function(){this.emit("error",new Error("Cannot pipe. Not readable."))},a.prototype.write=function(e,t,n){var r=this._writableState,i=!1;return E.isFunction(t)&&(n=t,t=null),E.isBuffer(e)?t="buffer":t||(t=r.defaultEncoding),E.isFunction(n)||(n=function(){}),r.ended?o(this,r,n):s(this,r,e,n)&&(r.pendingcb++,i=l(this,r,e,t,n)),i},a.prototype.cork=function(){var e=this._writableState;e.corked++},a.prototype.uncork=function(){var e=this._writableState;e.corked&&(e.corked--,e.writing||e.corked||e.finished||e.bufferProcessing||!e.buffer.length||y(this,e))},a.prototype._write=function(e,t,n){n(new Error("not implemented"))},a.prototype._writev=null,a.prototype.end=function(e,t,n){var r=this._writableState;E.isFunction(e)?(n=e,e=null,t=null):E.isFunction(t)&&(n=t,t=null),E.isNullOrUndefined(e)||this.write(e,t),r.corked&&(r.corked=1,this.uncork()),r.ending||r.finished||S(this,r,n)}}).call(t,n(61))},function(e,t,n){(function(t){function r(e,t){var r=n(248);e=e||{};var i=e.highWaterMark,a=e.objectMode?16:16384;this.highWaterMark=i||0===i?i:a,this.highWaterMark=~~this.highWaterMark,this.buffer=[],this.length=0,this.pipes=null,this.pipesCount=0,this.flowing=null,this.ended=!1,this.endEmitted=!1,this.reading=!1,this.sync=!0,this.needReadable=!1,this.emittedReadable=!1,this.readableListening=!1,this.objectMode=!!e.objectMode,t instanceof r&&(this.objectMode=this.objectMode||!!e.readableObjectMode),this.defaultEncoding=e.defaultEncoding||"utf8",this.ranOut=!1,this.awaitDrain=0,this.readingMore=!1,this.decoder=null,this.encoding=null,e.encoding&&(R||(R=n(254).StringDecoder),this.decoder=new R(e.encoding),this.encoding=e.encoding)}function i(e){n(248);return this instanceof i?(this._readableState=new r(e,this),this.readable=!0,void M.call(this)):new i(e)}function a(e,t,n,r,i){var a=l(t,n);if(a)e.emit("error",a);else if(w.isNullOrUndefined(n))t.reading=!1,t.ended||p(e,t);else if(t.objectMode||n&&n.length>0)if(t.ended&&!i){var s=new Error("stream.push() after EOF");e.emit("error",s)}else if(t.endEmitted&&i){var s=new Error("stream.unshift() after end event");e.emit("error",s)}else!t.decoder||i||r||(n=t.decoder.write(n)),i||(t.reading=!1),t.flowing&&0===t.length&&!t.sync?(e.emit("data",n),e.read(0)):(t.length+=t.objectMode?1:n.length,i?t.buffer.unshift(n):t.buffer.push(n),t.needReadable&&c(e)),m(e,t);else i||(t.reading=!1);return o(t)}function o(e){return!e.ended&&(e.needReadable||e.length<e.highWaterMark||0===e.length)}function s(e){if(e>=C)e=C;else{e--;for(var t=1;32>t;t<<=1)e|=e>>t;e++}return e}function u(e,t){return 0===t.length&&t.ended?0:t.objectMode?0===e?0:1:isNaN(e)||w.isNull(e)?t.flowing&&t.buffer.length?t.buffer[0].length:t.length:0>=e?0:(e>t.highWaterMark&&(t.highWaterMark=s(e)),e>t.length?t.ended?t.length:(t.needReadable=!0,0):e)}function l(e,t){var n=null;return w.isBuffer(t)||w.isString(t)||w.isNullOrUndefined(t)||e.objectMode||(n=new TypeError("Invalid non-string/buffer chunk")),n}function p(e,t){if(t.decoder&&!t.ended){var n=t.decoder.end();n&&n.length&&(t.buffer.push(n),t.length+=t.objectMode?1:n.length)}t.ended=!0,c(e)}function c(e){var n=e._readableState;n.needReadable=!1,n.emittedReadable||(I("emitReadable",n.flowing),n.emittedReadable=!0,n.sync?t.nextTick(function(){f(e)}):f(e))}function f(e){I("emit readable"),e.emit("readable"),g(e)}function m(e,n){n.readingMore||(n.readingMore=!0,t.nextTick(function(){d(e,n)}))}function d(e,t){for(var n=t.length;!t.reading&&!t.flowing&&!t.ended&&t.length<t.highWaterMark&&(I("maybeReadMore read 0"),e.read(0),n!==t.length);)n=t.length;t.readingMore=!1}function h(e){return function(){var t=e._readableState;I("pipeOnDrain",t.awaitDrain),t.awaitDrain&&t.awaitDrain--,0===t.awaitDrain&&_.listenerCount(e,"data")&&(t.flowing=!0,g(e))}}function y(e,n){n.resumeScheduled||(n.resumeScheduled=!0,t.nextTick(function(){v(e,n)}))}function v(e,t){t.resumeScheduled=!1,e.emit("resume"),g(e),t.flowing&&!t.reading&&e.read(0)}function g(e){var t=e._readableState;if(I("flow",t.flowing),t.flowing)do var n=e.read();while(null!==n&&t.flowing)}function A(e,t){var n,r=t.buffer,i=t.length,a=!!t.decoder,o=!!t.objectMode;if(0===r.length)return null;if(0===i)n=null;else if(o)n=r.shift();else if(!e||e>=i)n=a?r.join(""):N.concat(r,i),r.length=0;else if(e<r[0].length){var s=r[0];n=s.slice(0,e),r[0]=s.slice(e)}else if(e===r[0].length)n=r.shift();else{n=a?"":new N(e);for(var u=0,l=0,p=r.length;p>l&&e>u;l++){var s=r[0],c=Math.min(e-u,s.length);a?n+=s.slice(0,c):s.copy(n,u,0,c),c<s.length?r[0]=s.slice(c):r.shift(),u+=c}}return n}function S(e){var n=e._readableState;if(n.length>0)throw new Error("endReadable called on non-empty stream");n.endEmitted||(n.ended=!0,t.nextTick(function(){n.endEmitted||0!==n.length||(n.endEmitted=!0,e.readable=!1,e.emit("end"))}))}function T(e,t){for(var n=0,r=e.length;r>n;n++)t(e[n],n)}function E(e,t){for(var n=0,r=e.length;r>n;n++)if(e[n]===t)return n;return-1}e.exports=i;var b=n(256),N=n(94).Buffer;i.ReadableState=r;var _=n(204).EventEmitter;_.listenerCount||(_.listenerCount=function(e,t){return e.listeners(t).length});var M=n(177),w=n(259);w.inherits=n(257);var R,I=n(253);I=I&&I.debuglog?I.debuglog("stream"):function(){},w.inherits(i,M),i.prototype.push=function(e,t){var n=this._readableState;return w.isString(e)&&!n.objectMode&&(t=t||n.defaultEncoding,t!==n.encoding&&(e=new N(e,t),t="")),a(this,n,e,t,!1)},i.prototype.unshift=function(e){var t=this._readableState;return a(this,t,e,"",!0)},i.prototype.setEncoding=function(e){return R||(R=n(254).StringDecoder),this._readableState.decoder=new R(e),this._readableState.encoding=e,this};var C=8388608;i.prototype.read=function(e){I("read",e);var t=this._readableState,n=e;if((!w.isNumber(e)||e>0)&&(t.emittedReadable=!1),0===e&&t.needReadable&&(t.length>=t.highWaterMark||t.ended))return I("read: emitReadable",t.length,t.ended),0===t.length&&t.ended?S(this):c(this),null;if(e=u(e,t),0===e&&t.ended)return 0===t.length&&S(this),null;var r=t.needReadable;I("need readable",r),(0===t.length||t.length-e<t.highWaterMark)&&(r=!0,I("length less than watermark",r)),(t.ended||t.reading)&&(r=!1,I("reading or ended",r)),r&&(I("do read"),t.reading=!0,t.sync=!0,0===t.length&&(t.needReadable=!0),this._read(t.highWaterMark),t.sync=!1),r&&!t.reading&&(e=u(n,t));var i;return i=e>0?A(e,t):null,w.isNull(i)&&(t.needReadable=!0,e=0),t.length-=e,0!==t.length||t.ended||(t.needReadable=!0),n!==e&&t.ended&&0===t.length&&S(this),w.isNull(i)||this.emit("data",i),i},i.prototype._read=function(e){this.emit("error",new Error("not implemented"))},i.prototype.pipe=function(e,n){function r(e){I("onunpipe"),e===c&&a()}function i(){I("onend"),e.end()}function a(){I("cleanup"),e.removeListener("close",u),e.removeListener("finish",l),e.removeListener("drain",y),e.removeListener("error",s),e.removeListener("unpipe",r),c.removeListener("end",i),c.removeListener("end",a),c.removeListener("data",o),!f.awaitDrain||e._writableState&&!e._writableState.needDrain||y()}function o(t){I("ondata");var n=e.write(t);!1===n&&(I("false write response, pause",c._readableState.awaitDrain),c._readableState.awaitDrain++,c.pause())}function s(t){I("onerror",t),p(),e.removeListener("error",s),0===_.listenerCount(e,"error")&&e.emit("error",t)}function u(){e.removeListener("finish",l),p()}function l(){I("onfinish"),e.removeListener("close",u),p()}function p(){I("unpipe"),c.unpipe(e)}var c=this,f=this._readableState;switch(f.pipesCount){case 0:f.pipes=e;break;case 1:f.pipes=[f.pipes,e];break;default:f.pipes.push(e)}f.pipesCount+=1,I("pipe count=%d opts=%j",f.pipesCount,n);var m=(!n||n.end!==!1)&&e!==t.stdout&&e!==t.stderr,d=m?i:a;f.endEmitted?t.nextTick(d):c.once("end",d),e.on("unpipe",r);var y=h(c);return e.on("drain",y),c.on("data",o),e._events&&e._events.error?b(e._events.error)?e._events.error.unshift(s):e._events.error=[s,e._events.error]:e.on("error",s),e.once("close",u),e.once("finish",l),e.emit("pipe",c),f.flowing||(I("pipe resume"),c.resume()),e},i.prototype.unpipe=function(e){var t=this._readableState;if(0===t.pipesCount)return this;if(1===t.pipesCount)return e&&e!==t.pipes?this:(e||(e=t.pipes),t.pipes=null,t.pipesCount=0,t.flowing=!1,e&&e.emit("unpipe",this),this);if(!e){var n=t.pipes,r=t.pipesCount;t.pipes=null,t.pipesCount=0,t.flowing=!1;for(var i=0;r>i;i++)n[i].emit("unpipe",this);return this}var i=E(t.pipes,e);return-1===i?this:(t.pipes.splice(i,1),t.pipesCount-=1,1===t.pipesCount&&(t.pipes=t.pipes[0]),e.emit("unpipe",this),this)},i.prototype.on=function(e,n){var r=M.prototype.on.call(this,e,n);if("data"===e&&!1!==this._readableState.flowing&&this.resume(),"readable"===e&&this.readable){var i=this._readableState;if(!i.readableListening)if(i.readableListening=!0,i.emittedReadable=!1,i.needReadable=!0,i.reading)i.length&&c(this,i);else{var a=this;t.nextTick(function(){I("readable nexttick read 0"),a.read(0)})}}return r},i.prototype.addListener=i.prototype.on,i.prototype.resume=function(){var e=this._readableState;return e.flowing||(I("resume"),e.flowing=!0,e.reading||(I("resume read 0"),this.read(0)),y(this,e)),this},i.prototype.pause=function(){return I("call pause flowing=%j",this._readableState.flowing),!1!==this._readableState.flowing&&(I("pause"),this._readableState.flowing=!1,this.emit("pause")),this},i.prototype.wrap=function(e){var t=this._readableState,n=!1,r=this;e.on("end",function(){if(I("wrapped end"),t.decoder&&!t.ended){var e=t.decoder.end();e&&e.length&&r.push(e)}r.push(null)}),e.on("data",function(i){if(I("wrapped data"),t.decoder&&(i=t.decoder.write(i)),i&&(t.objectMode||i.length)){var a=r.push(i);a||(n=!0,e.pause())}});for(var i in e)w.isFunction(e[i])&&w.isUndefined(this[i])&&(this[i]=function(t){return function(){return e[t].apply(e,arguments)}}(i));var a=["error","close","destroy","pause","resume"];return T(a,function(t){e.on(t,r.emit.bind(r,t))}),r._read=function(t){I("wrapped _read",t),n&&(n=!1,e.resume())},r},i._fromList=A}).call(t,n(61))},function(e,t,n){(function(t){function r(e){return this instanceof r?(u.call(this,e),l.call(this,e),e&&e.readable===!1&&(this.readable=!1),e&&e.writable===!1&&(this.writable=!1),this.allowHalfOpen=!0,e&&e.allowHalfOpen===!1&&(this.allowHalfOpen=!1),void this.once("end",i)):new r(e)}function i(){this.allowHalfOpen||this._writableState.ended||t.nextTick(this.end.bind(this))}function a(e,t){for(var n=0,r=e.length;r>n;n++)t(e[n],n)}e.exports=r;var o=Object.keys||function(e){var t=[];for(var n in e)t.push(n);return t},s=n(259);s.inherits=n(257);var u=n(247),l=n(246);s.inherits(r,u),a(o(l.prototype),function(e){r.prototype[e]||(r.prototype[e]=l.prototype[e])})}).call(t,n(61))},function(e,t,n){function r(e,t){this.afterTransform=function(e,n){return i(t,e,n)},this.needTransform=!1,this.transforming=!1,this.writecb=null,this.writechunk=null}function i(e,t,n){var r=e._transformState;r.transforming=!1;var i=r.writecb;if(!i)return e.emit("error",new Error("no writecb in Transform class"));r.writechunk=null,r.writecb=null,u.isNullOrUndefined(n)||e.push(n),i&&i(t);var a=e._readableState;a.reading=!1,(a.needReadable||a.length<a.highWaterMark)&&e._read(a.highWaterMark)}function a(e){if(!(this instanceof a))return new a(e);s.call(this,e),this._transformState=new r(e,this);var t=this;this._readableState.needReadable=!0,this._readableState.sync=!1,this.once("prefinish",function(){u.isFunction(this._flush)?this._flush(function(e){o(t,e)}):o(t)})}function o(e,t){if(t)return e.emit("error",t);var n=e._writableState,r=e._transformState;if(n.length)throw new Error("calling transform done when ws.length != 0");if(r.transforming)throw new Error("calling transform done when still transforming");return e.push(null)}e.exports=a;var s=n(248),u=n(259);u.inherits=n(257),u.inherits(a,s),a.prototype.push=function(e,t){return this._transformState.needTransform=!1,s.prototype.push.call(this,e,t)},a.prototype._transform=function(e,t,n){throw new Error("not implemented")},a.prototype._write=function(e,t,n){var r=this._transformState;if(r.writecb=n,r.writechunk=e,r.writeencoding=t,!r.transforming){var i=this._readableState;(r.needTransform||i.needReadable||i.length<i.highWaterMark)&&this._read(i.highWaterMark)}},a.prototype._read=function(e){var t=this._transformState;u.isNull(t.writechunk)||!t.writecb||t.transforming?t.needTransform=!0:(t.transforming=!0,this._transform(t.writechunk,t.writeencoding,t.afterTransform))}},function(e,t,n){function r(e){return this instanceof r?void i.call(this,e):new r(e)}e.exports=r;var i=n(249),a=n(259);a.inherits=n(257),a.inherits(r,i),r.prototype._transform=function(e,t,n){n(null,e)}},function(e,t,n){(function(e){!function(t){function r(e,n){if(!(this instanceof r))return new r(e,n);var i=this;a(i),i.q=i.c="",i.bufferCheckPosition=t.MAX_BUFFER_LENGTH,i.opt=n||{},i.opt.lowercase=i.opt.lowercase||i.opt.lowercasetags,i.looseCase=i.opt.lowercase?"toLowerCase":"toUpperCase",i.tags=[],i.closed=i.closedRoot=i.sawRoot=!1,i.tag=i.error=null,i.strict=!!e,i.noscript=!(!e&&!i.opt.noscript),i.state=$.BEGIN,i.strictEntities=i.opt.strictEntities,i.ENTITIES=i.strictEntities?Object.create(t.XML_ENTITIES):Object.create(t.ENTITIES),i.attribList=[],i.opt.xmlns&&(i.ns=Object.create(j)),i.trackPosition=i.opt.position!==!1,i.trackPosition&&(i.position=i.line=i.column=0),m(i,"onready")}function i(e){for(var n=Math.max(t.MAX_BUFFER_LENGTH,10),r=0,i=0,a=I.length;a>i;i++){var o=e[I[i]].length;if(o>n)switch(I[i]){case"textNode":h(e);break;case"cdata":d(e,"oncdata",e.cdata),e.cdata="";break;case"script":d(e,"onscript",e.script),e.script="";break;default:v(e,"Max buffer length exceeded: "+I[i])}r=Math.max(r,o)}var s=t.MAX_BUFFER_LENGTH-r;e.bufferCheckPosition=s+e.position}function a(e){for(var t=0,n=I.length;n>t;t++)e[I[t]]=""}function o(e){h(e),""!==e.cdata&&(d(e,"oncdata",e.cdata),e.cdata=""),""!==e.script&&(d(e,"onscript",e.script),e.script="")}function s(e,t){return new u(e,t)}function u(e,t){if(!(this instanceof u))return new u(e,t);C.apply(this),this._parser=new r(e,t),this.writable=!0,this.readable=!0;var n=this;this._parser.onend=function(){n.emit("end")},this._parser.onerror=function(e){n.emit("error",e),n._parser.error=null},this._decoder=null,P.forEach(function(e){Object.defineProperty(n,"on"+e,{get:function(){return n._parser["on"+e]},set:function(t){return t?void n.on(e,t):(n.removeAllListeners(e),n._parser["on"+e]=t,t)},enumerable:!0,configurable:!1})})}function l(e){return e.split("").reduce(function(e,t){return e[t]=!0,e},{})}function p(e){return"[object RegExp]"===Object.prototype.toString.call(e)}function c(e,t){return p(e)?!!t.match(e):e[t]}function f(e,t){return!c(e,t)}function m(e,t,n){e[t]&&e[t](n)}function d(e,t,n){e.textNode&&h(e),m(e,t,n)}function h(e){e.textNode=y(e.opt,e.textNode),e.textNode&&m(e,"ontext",e.textNode),e.textNode=""}function y(e,t){return e.trim&&(t=t.trim()),e.normalize&&(t=t.replace(/\s+/g," ")),t}function v(e,t){return h(e),e.trackPosition&&(t+="\nLine: "+e.line+"\nColumn: "+e.column+"\nChar: "+e.c),t=new Error(t),e.error=t,m(e,"onerror",t),e}function g(e){return e.sawRoot&&!e.closedRoot&&A(e,"Unclosed root tag"),e.state!==$.BEGIN&&e.state!==$.BEGIN_WHITESPACE&&e.state!==$.TEXT&&v(e,"Unexpected end"),h(e),e.c="",e.closed=!0,m(e,"onend"),r.call(e,e.strict,e.opt),e}function A(e,t){if("object"!=typeof e||!(e instanceof r))throw new Error("bad call to strictFail");e.strict&&v(e,t)}function S(e){e.strict||(e.tagName=e.tagName[e.looseCase]());var t=e.tags[e.tags.length-1]||e,n=e.tag={name:e.tagName,attributes:{}};e.opt.xmlns&&(n.ns=t.ns),e.attribList.length=0,d(e,"onopentagstart",n)}function T(e,t){var n=e.indexOf(":"),r=0>n?["",e]:e.split(":"),i=r[0],a=r[1];return t&&"xmlns"===e&&(i="xmlns",a=""),{prefix:i,local:a}}function E(e){if(e.strict||(e.attribName=e.attribName[e.looseCase]()),-1!==e.attribList.indexOf(e.attribName)||e.tag.attributes.hasOwnProperty(e.attribName))return void(e.attribName=e.attribValue="");if(e.opt.xmlns){var t=T(e.attribName,!0),n=t.prefix,r=t.local;if("xmlns"===n)if("xml"===r&&e.attribValue!==K)A(e,"xml: prefix must be bound to "+K+"\nActual: "+e.attribValue);else if("xmlns"===r&&e.attribValue!==V)A(e,"xmlns: prefix must be bound to "+V+"\nActual: "+e.attribValue);else{var i=e.tag,a=e.tags[e.tags.length-1]||e;i.ns===a.ns&&(i.ns=Object.create(a.ns)),i.ns[r]=e.attribValue}e.attribList.push([e.attribName,e.attribValue])}else e.tag.attributes[e.attribName]=e.attribValue,d(e,"onattribute",{name:e.attribName,value:e.attribValue});e.attribName=e.attribValue=""}function b(e,t){if(e.opt.xmlns){var n=e.tag,r=T(e.tagName);n.prefix=r.prefix,n.local=r.local,n.uri=n.ns[r.prefix]||"",n.prefix&&!n.uri&&(A(e,"Unbound namespace prefix: "+JSON.stringify(e.tagName)),n.uri=r.prefix);var i=e.tags[e.tags.length-1]||e;n.ns&&i.ns!==n.ns&&Object.keys(n.ns).forEach(function(t){d(e,"onopennamespace",{prefix:t,uri:n.ns[t]})});for(var a=0,o=e.attribList.length;o>a;a++){var s=e.attribList[a],u=s[0],l=s[1],p=T(u,!0),c=p.prefix,f=p.local,m=""===c?"":n.ns[c]||"",h={name:u,value:l,prefix:c,local:f,uri:m};c&&"xmlns"!==c&&!m&&(A(e,"Unbound namespace prefix: "+JSON.stringify(c)),h.uri=c),e.tag.attributes[u]=h,d(e,"onattribute",h)}e.attribList.length=0}e.tag.isSelfClosing=!!t,e.sawRoot=!0,e.tags.push(e.tag),d(e,"onopentag",e.tag),t||(e.noscript||"script"!==e.tagName.toLowerCase()?e.state=$.TEXT:e.state=$.SCRIPT,e.tag=null,e.tagName=""),e.attribName=e.attribValue="",e.attribList.length=0}function N(e){if(!e.tagName)return A(e,"Weird empty close tag."),e.textNode+="</>",void(e.state=$.TEXT);if(e.script){if("script"!==e.tagName)return e.script+="</"+e.tagName+">",e.tagName="",void(e.state=$.SCRIPT);d(e,"onscript",e.script),e.script=""}var t=e.tags.length,n=e.tagName;e.strict||(n=n[e.looseCase]());for(var r=n;t--;){var i=e.tags[t];if(i.name===r)break;A(e,"Unexpected close tag")}if(0>t)return A(e,"Unmatched closing tag: "+e.tagName),e.textNode+="</"+e.tagName+">",void(e.state=$.TEXT);e.tagName=n;for(var a=e.tags.length;a-->t;){var o=e.tag=e.tags.pop();e.tagName=e.tag.name,d(e,"onclosetag",e.tagName);var s={};for(var u in o.ns)s[u]=o.ns[u];var l=e.tags[e.tags.length-1]||e;e.opt.xmlns&&o.ns!==l.ns&&Object.keys(o.ns).forEach(function(t){var n=o.ns[t];d(e,"onclosenamespace",{prefix:t,uri:n})})}0===t&&(e.closedRoot=!0),e.tagName=e.attribValue=e.attribName="",e.attribList.length=0,e.state=$.TEXT}function _(e){var t,n=e.entity,r=n.toLowerCase(),i="";return e.ENTITIES[n]?e.ENTITIES[n]:e.ENTITIES[r]?e.ENTITIES[r]:(n=r,"#"===n.charAt(0)&&("x"===n.charAt(1)?(n=n.slice(2),t=parseInt(n,16),i=t.toString(16)):(n=n.slice(1),t=parseInt(n,10),i=t.toString(10))),n=n.replace(/^0+/,""),i.toLowerCase()!==n?(A(e,"Invalid character entity"),"&"+e.entity+";"):String.fromCodePoint(t))}function M(e,t){"<"===t?(e.state=$.OPEN_WAKA,e.startTagPosition=e.position):f(O,t)&&(A(e,"Non-whitespace before first tag."),e.textNode=t,e.state=$.TEXT)}function w(e,t){var n="";return t<e.length&&(n=e.charAt(t)),n}function R(e){var t=this;if(this.error)throw this.error;if(t.closed)return v(t,"Cannot write after close. Assign an onready handler.");if(null===e)return g(t);"object"==typeof e&&(e=e.toString());for(var n=0,r="";;){if(r=w(e,n++),t.c=r,!r)break;switch(t.trackPosition&&(t.position++,"\n"===r?(t.line++,t.column=0):t.column++),t.state){case $.BEGIN:if(t.state=$.BEGIN_WHITESPACE,"\ufeff"===r)continue;M(t,r);continue;case $.BEGIN_WHITESPACE:M(t,r);continue;case $.TEXT:if(t.sawRoot&&!t.closedRoot){for(var a=n-1;r&&"<"!==r&&"&"!==r;)r=w(e,n++),r&&t.trackPosition&&(t.position++,"\n"===r?(t.line++,t.column=0):t.column++);t.textNode+=e.substring(a,n-1)}"<"!==r||t.sawRoot&&t.closedRoot&&!t.strict?(!f(O,r)||t.sawRoot&&!t.closedRoot||A(t,"Text data outside of root node."),"&"===r?t.state=$.TEXT_ENTITY:t.textNode+=r):(t.state=$.OPEN_WAKA,t.startTagPosition=t.position);continue;case $.SCRIPT:"<"===r?t.state=$.SCRIPT_ENDING:t.script+=r;continue;case $.SCRIPT_ENDING:"/"===r?t.state=$.CLOSE_TAG:(t.script+="<"+r,t.state=$.SCRIPT);continue;case $.OPEN_WAKA:if("!"===r)t.state=$.SGML_DECL,t.sgmlDecl="";else if(c(O,r));else if(c(W,r))t.state=$.OPEN_TAG,t.tagName=r;else if("/"===r)t.state=$.CLOSE_TAG,t.tagName="";else if("?"===r)t.state=$.PROC_INST,t.procInstName=t.procInstBody="";else{if(A(t,"Unencoded <"),t.startTagPosition+1<t.position){var o=t.position-t.startTagPosition;r=new Array(o).join(" ")+r}t.textNode+="<"+r,t.state=$.TEXT}continue;case $.SGML_DECL:(t.sgmlDecl+r).toUpperCase()===F?(d(t,"onopencdata"),t.state=$.CDATA,t.sgmlDecl="",t.cdata=""):t.sgmlDecl+r==="--"?(t.state=$.COMMENT,t.comment="",t.sgmlDecl=""):(t.sgmlDecl+r).toUpperCase()===B?(t.state=$.DOCTYPE,(t.doctype||t.sawRoot)&&A(t,"Inappropriately located doctype declaration"),t.doctype="",t.sgmlDecl=""):">"===r?(d(t,"onsgmldeclaration",t.sgmlDecl),t.sgmlDecl="",t.state=$.TEXT):c(U,r)?(t.state=$.SGML_DECL_QUOTED,t.sgmlDecl+=r):t.sgmlDecl+=r;continue;case $.SGML_DECL_QUOTED:r===t.q&&(t.state=$.SGML_DECL,t.q=""),t.sgmlDecl+=r;continue;case $.DOCTYPE:">"===r?(t.state=$.TEXT,d(t,"ondoctype",t.doctype),t.doctype=!0):(t.doctype+=r,"["===r?t.state=$.DOCTYPE_DTD:c(U,r)&&(t.state=$.DOCTYPE_QUOTED,t.q=r));continue;case $.DOCTYPE_QUOTED:t.doctype+=r,r===t.q&&(t.q="",t.state=$.DOCTYPE);continue;case $.DOCTYPE_DTD:t.doctype+=r,"]"===r?t.state=$.DOCTYPE:c(U,r)&&(t.state=$.DOCTYPE_DTD_QUOTED,t.q=r);continue;case $.DOCTYPE_DTD_QUOTED:t.doctype+=r,r===t.q&&(t.state=$.DOCTYPE_DTD,t.q="");continue;case $.COMMENT:"-"===r?t.state=$.COMMENT_ENDING:t.comment+=r;continue;case $.COMMENT_ENDING:"-"===r?(t.state=$.COMMENT_ENDED,t.comment=y(t.opt,t.comment),t.comment&&d(t,"oncomment",t.comment),t.comment=""):(t.comment+="-"+r,t.state=$.COMMENT);continue;case $.COMMENT_ENDED:">"!==r?(A(t,"Malformed comment"),t.comment+="--"+r,t.state=$.COMMENT):t.state=$.TEXT;continue;case $.CDATA:"]"===r?t.state=$.CDATA_ENDING:t.cdata+=r;continue;case $.CDATA_ENDING:"]"===r?t.state=$.CDATA_ENDING_2:(t.cdata+="]"+r,t.state=$.CDATA);continue;case $.CDATA_ENDING_2:">"===r?(t.cdata&&d(t,"oncdata",t.cdata),d(t,"onclosecdata"),t.cdata="",t.state=$.TEXT):"]"===r?t.cdata+="]":(t.cdata+="]]"+r,t.state=$.CDATA);continue;case $.PROC_INST:"?"===r?t.state=$.PROC_INST_ENDING:c(O,r)?t.state=$.PROC_INST_BODY:t.procInstName+=r;continue;case $.PROC_INST_BODY:if(!t.procInstBody&&c(O,r))continue;"?"===r?t.state=$.PROC_INST_ENDING:t.procInstBody+=r;continue;case $.PROC_INST_ENDING:">"===r?(d(t,"onprocessinginstruction",{name:t.procInstName,body:t.procInstBody}),t.procInstName=t.procInstBody="",t.state=$.TEXT):(t.procInstBody+="?"+r,t.state=$.PROC_INST_BODY);continue;case $.OPEN_TAG:c(q,r)?t.tagName+=r:(S(t),">"===r?b(t):"/"===r?t.state=$.OPEN_TAG_SLASH:(f(O,r)&&A(t,"Invalid character in tag name"),t.state=$.ATTRIB));continue;case $.OPEN_TAG_SLASH:">"===r?(b(t,!0),N(t)):(A(t,"Forward-slash in opening tag not followed by >"),t.state=$.ATTRIB);continue;case $.ATTRIB:if(c(O,r))continue;">"===r?b(t):"/"===r?t.state=$.OPEN_TAG_SLASH:c(W,r)?(t.attribName=r,t.attribValue="",t.state=$.ATTRIB_NAME):A(t,"Invalid attribute name");continue;case $.ATTRIB_NAME:"="===r?t.state=$.ATTRIB_VALUE:">"===r?(A(t,"Attribute without value"),t.attribValue=t.attribName,E(t),b(t)):c(O,r)?t.state=$.ATTRIB_NAME_SAW_WHITE:c(q,r)?t.attribName+=r:A(t,"Invalid attribute name");continue;case $.ATTRIB_NAME_SAW_WHITE:if("="===r)t.state=$.ATTRIB_VALUE;else{if(c(O,r))continue;A(t,"Attribute without value"),t.tag.attributes[t.attribName]="",t.attribValue="",d(t,"onattribute",{name:t.attribName,value:""}),t.attribName="",">"===r?b(t):c(W,r)?(t.attribName=r,t.state=$.ATTRIB_NAME):(A(t,"Invalid attribute name"),t.state=$.ATTRIB)}continue;case $.ATTRIB_VALUE:if(c(O,r))continue;c(U,r)?(t.q=r,t.state=$.ATTRIB_VALUE_QUOTED):(A(t,"Unquoted attribute value"),t.state=$.ATTRIB_VALUE_UNQUOTED,t.attribValue=r);continue;case $.ATTRIB_VALUE_QUOTED:if(r!==t.q){"&"===r?t.state=$.ATTRIB_VALUE_ENTITY_Q:t.attribValue+=r;continue}E(t),t.q="",t.state=$.ATTRIB_VALUE_CLOSED;continue;case $.ATTRIB_VALUE_CLOSED:c(O,r)?t.state=$.ATTRIB:">"===r?b(t):"/"===r?t.state=$.OPEN_TAG_SLASH:c(W,r)?(A(t,"No whitespace between attributes"),t.attribName=r,t.attribValue="",t.state=$.ATTRIB_NAME):A(t,"Invalid attribute name");continue;case $.ATTRIB_VALUE_UNQUOTED:if(f(k,r)){"&"===r?t.state=$.ATTRIB_VALUE_ENTITY_U:t.attribValue+=r;continue}E(t),">"===r?b(t):t.state=$.ATTRIB;continue;case $.CLOSE_TAG:if(t.tagName)">"===r?N(t):c(q,r)?t.tagName+=r:t.script?(t.script+="</"+t.tagName,t.tagName="",t.state=$.SCRIPT):(f(O,r)&&A(t,"Invalid tagname in closing tag"),t.state=$.CLOSE_TAG_SAW_WHITE);else{if(c(O,r))continue;f(W,r)?t.script?(t.script+="</"+r,t.state=$.SCRIPT):A(t,"Invalid tagname in closing tag."):t.tagName=r}continue;case $.CLOSE_TAG_SAW_WHITE:if(c(O,r))continue;">"===r?N(t):A(t,"Invalid characters in closing tag");continue;case $.TEXT_ENTITY:case $.ATTRIB_VALUE_ENTITY_Q:case $.ATTRIB_VALUE_ENTITY_U:var s,u;switch(t.state){case $.TEXT_ENTITY:s=$.TEXT,u="textNode";break;case $.ATTRIB_VALUE_ENTITY_Q:s=$.ATTRIB_VALUE_QUOTED,u="attribValue";break;case $.ATTRIB_VALUE_ENTITY_U:s=$.ATTRIB_VALUE_UNQUOTED,u="attribValue"}";"===r?(t[u]+=_(t),t.entity="",t.state=s):c(t.entity.length?H:Y,r)?t.entity+=r:(A(t,"Invalid character in entity name"),t[u]+="&"+t.entity+r,t.entity="",t.state=s);continue;default:throw new Error(t,"Unknown state: "+t.state)}}return t.position>=t.bufferCheckPosition&&i(t),t}t.parser=function(e,t){return new r(e,t)},t.SAXParser=r,t.SAXStream=u,t.createStream=s,t.MAX_BUFFER_LENGTH=65536;var I=["comment","sgmlDecl","textNode","tagName","doctype","procInstName","procInstBody","entity","attribName","attribValue","cdata","script"];t.EVENTS=["text","processinginstruction","sgmldeclaration","doctype","comment","opentagstart","attribute","opentag","closetag","opencdata","cdata","closecdata","error","end","ready","script","opennamespace","closenamespace"],Object.create||(Object.create=function(e){function t(){}t.prototype=e;var n=new t;return n}),Object.keys||(Object.keys=function(e){var t=[];for(var n in e)e.hasOwnProperty(n)&&t.push(n);return t}),r.prototype={end:function(){g(this)},write:R,resume:function(){return this.error=null,this},close:function(){return this.write(null)},flush:function(){o(this)}};var C;try{C=n(177).Stream}catch(L){C=function(){}}var P=t.EVENTS.filter(function(e){return"error"!==e&&"end"!==e});u.prototype=Object.create(C.prototype,{constructor:{value:u}}),u.prototype.write=function(t){if("function"==typeof e&&"function"==typeof e.isBuffer&&e.isBuffer(t)){if(!this._decoder){var r=n(254).StringDecoder;this._decoder=new r("utf8")}t=this._decoder.write(t)}return this._parser.write(t.toString()),this.emit("data",t),!0},u.prototype.end=function(e){return e&&e.length&&this.write(e),this._parser.end(),!0},u.prototype.on=function(e,t){var n=this;return n._parser["on"+e]||-1===P.indexOf(e)||(n._parser["on"+e]=function(){
var t=1===arguments.length?[arguments[0]]:Array.apply(null,arguments);t.splice(0,0,e),n.emit.apply(n,t)}),C.prototype.on.call(n,e,t)};var O="\r\n	 ",D="0124356789",x="abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ",U="'\"",k=O+">",F="[CDATA[",B="DOCTYPE",K="http://www.w3.org/XML/1998/namespace",V="http://www.w3.org/2000/xmlns/",j={xml:K,xmlns:V};O=l(O),D=l(D),x=l(x);var W=/[:_A-Za-z\u00C0-\u00D6\u00D8-\u00F6\u00F8-\u02FF\u0370-\u037D\u037F-\u1FFF\u200C-\u200D\u2070-\u218F\u2C00-\u2FEF\u3001-\uD7FF\uF900-\uFDCF\uFDF0-\uFFFD]/,q=/[:_A-Za-z\u00C0-\u00D6\u00D8-\u00F6\u00F8-\u02FF\u0370-\u037D\u037F-\u1FFF\u200C-\u200D\u2070-\u218F\u2C00-\u2FEF\u3001-\uD7FF\uF900-\uFDCF\uFDF0-\uFFFD\u00B7\u0300-\u036F\u203F-\u2040\.\d-]/,Y=/[#:_A-Za-z\u00C0-\u00D6\u00D8-\u00F6\u00F8-\u02FF\u0370-\u037D\u037F-\u1FFF\u200C-\u200D\u2070-\u218F\u2C00-\u2FEF\u3001-\uD7FF\uF900-\uFDCF\uFDF0-\uFFFD]/,H=/[#:_A-Za-z\u00C0-\u00D6\u00D8-\u00F6\u00F8-\u02FF\u0370-\u037D\u037F-\u1FFF\u200C-\u200D\u2070-\u218F\u2C00-\u2FEF\u3001-\uD7FF\uF900-\uFDCF\uFDF0-\uFFFD\u00B7\u0300-\u036F\u203F-\u2040\.\d-]/;U=l(U),k=l(k);var $=0;t.STATE={BEGIN:$++,BEGIN_WHITESPACE:$++,TEXT:$++,TEXT_ENTITY:$++,OPEN_WAKA:$++,SGML_DECL:$++,SGML_DECL_QUOTED:$++,DOCTYPE:$++,DOCTYPE_QUOTED:$++,DOCTYPE_DTD:$++,DOCTYPE_DTD_QUOTED:$++,COMMENT_STARTING:$++,COMMENT:$++,COMMENT_ENDING:$++,COMMENT_ENDED:$++,CDATA:$++,CDATA_ENDING:$++,CDATA_ENDING_2:$++,PROC_INST:$++,PROC_INST_BODY:$++,PROC_INST_ENDING:$++,OPEN_TAG:$++,OPEN_TAG_SLASH:$++,ATTRIB:$++,ATTRIB_NAME:$++,ATTRIB_NAME_SAW_WHITE:$++,ATTRIB_VALUE:$++,ATTRIB_VALUE_QUOTED:$++,ATTRIB_VALUE_CLOSED:$++,ATTRIB_VALUE_UNQUOTED:$++,ATTRIB_VALUE_ENTITY_Q:$++,ATTRIB_VALUE_ENTITY_U:$++,CLOSE_TAG:$++,CLOSE_TAG_SAW_WHITE:$++,SCRIPT:$++,SCRIPT_ENDING:$++},t.XML_ENTITIES={amp:"&",gt:">",lt:"<",quot:'"',apos:"'"},t.ENTITIES={amp:"&",gt:">",lt:"<",quot:'"',apos:"'",AElig:198,Aacute:193,Acirc:194,Agrave:192,Aring:197,Atilde:195,Auml:196,Ccedil:199,ETH:208,Eacute:201,Ecirc:202,Egrave:200,Euml:203,Iacute:205,Icirc:206,Igrave:204,Iuml:207,Ntilde:209,Oacute:211,Ocirc:212,Ograve:210,Oslash:216,Otilde:213,Ouml:214,THORN:222,Uacute:218,Ucirc:219,Ugrave:217,Uuml:220,Yacute:221,aacute:225,acirc:226,aelig:230,agrave:224,aring:229,atilde:227,auml:228,ccedil:231,eacute:233,ecirc:234,egrave:232,eth:240,euml:235,iacute:237,icirc:238,igrave:236,iuml:239,ntilde:241,oacute:243,ocirc:244,ograve:242,oslash:248,otilde:245,ouml:246,szlig:223,thorn:254,uacute:250,ucirc:251,ugrave:249,uuml:252,yacute:253,yuml:255,copy:169,reg:174,nbsp:160,iexcl:161,cent:162,pound:163,curren:164,yen:165,brvbar:166,sect:167,uml:168,ordf:170,laquo:171,not:172,shy:173,macr:175,deg:176,plusmn:177,sup1:185,sup2:178,sup3:179,acute:180,micro:181,para:182,middot:183,cedil:184,ordm:186,raquo:187,frac14:188,frac12:189,frac34:190,iquest:191,times:215,divide:247,OElig:338,oelig:339,Scaron:352,scaron:353,Yuml:376,fnof:402,circ:710,tilde:732,Alpha:913,Beta:914,Gamma:915,Delta:916,Epsilon:917,Zeta:918,Eta:919,Theta:920,Iota:921,Kappa:922,Lambda:923,Mu:924,Nu:925,Xi:926,Omicron:927,Pi:928,Rho:929,Sigma:931,Tau:932,Upsilon:933,Phi:934,Chi:935,Psi:936,Omega:937,alpha:945,beta:946,gamma:947,delta:948,epsilon:949,zeta:950,eta:951,theta:952,iota:953,kappa:954,lambda:955,mu:956,nu:957,xi:958,omicron:959,pi:960,rho:961,sigmaf:962,sigma:963,tau:964,upsilon:965,phi:966,chi:967,psi:968,omega:969,thetasym:977,upsih:978,piv:982,ensp:8194,emsp:8195,thinsp:8201,zwnj:8204,zwj:8205,lrm:8206,rlm:8207,ndash:8211,mdash:8212,lsquo:8216,rsquo:8217,sbquo:8218,ldquo:8220,rdquo:8221,bdquo:8222,dagger:8224,Dagger:8225,bull:8226,hellip:8230,permil:8240,prime:8242,Prime:8243,lsaquo:8249,rsaquo:8250,oline:8254,frasl:8260,euro:8364,image:8465,weierp:8472,real:8476,trade:8482,alefsym:8501,larr:8592,uarr:8593,rarr:8594,darr:8595,harr:8596,crarr:8629,lArr:8656,uArr:8657,rArr:8658,dArr:8659,hArr:8660,forall:8704,part:8706,exist:8707,empty:8709,nabla:8711,isin:8712,notin:8713,ni:8715,prod:8719,sum:8721,minus:8722,lowast:8727,radic:8730,prop:8733,infin:8734,ang:8736,and:8743,or:8744,cap:8745,cup:8746,"int":8747,there4:8756,sim:8764,cong:8773,asymp:8776,ne:8800,equiv:8801,le:8804,ge:8805,sub:8834,sup:8835,nsub:8836,sube:8838,supe:8839,oplus:8853,otimes:8855,perp:8869,sdot:8901,lceil:8968,rceil:8969,lfloor:8970,rfloor:8971,lang:9001,rang:9002,loz:9674,spades:9824,clubs:9827,hearts:9829,diams:9830},Object.keys(t.ENTITIES).forEach(function(e){var n=t.ENTITIES[e],r="number"==typeof n?String.fromCharCode(n):n;t.ENTITIES[e]=r});for(var G in t.STATE)t.STATE[t.STATE[G]]=G;$=t.STATE,/*! http://mths.be/fromcodepoint v0.1.0 by @mathias */
String.fromCodePoint||!function(){var e=String.fromCharCode,t=Math.floor,n=function(){var n,r,i=16384,a=[],o=-1,s=arguments.length;if(!s)return"";for(var u="";++o<s;){var l=Number(arguments[o]);if(!isFinite(l)||0>l||l>1114111||t(l)!==l)throw RangeError("Invalid code point: "+l);65535>=l?a.push(l):(l-=65536,n=(l>>10)+55296,r=l%1024+56320,a.push(n,r)),(o+1===s||a.length>i)&&(u+=e.apply(null,a),a.length=0)}return u};Object.defineProperty?Object.defineProperty(String,"fromCodePoint",{value:n,configurable:!0,writable:!0}):String.fromCodePoint=n}()}("undefined"==typeof t?this.sax={}:t)}).call(t,n(94).Buffer)},function(e,t,n){(function(){var t,r;r=n(264),t=n(255),e.exports.create=function(e,n,i,a){return a=r({},n,i,a),new t(e,a).root()}}).call(this)},function(e,t,n){},function(e,t,n){function r(e){if(e&&!u(e))throw new Error("Unknown encoding: "+e)}function i(e){return e.toString(this.encoding)}function a(e){this.charReceived=e.length%2,this.charLength=this.charReceived?2:0}function o(e){this.charReceived=e.length%3,this.charLength=this.charReceived?3:0}var s=n(94).Buffer,u=s.isEncoding||function(e){switch(e&&e.toLowerCase()){case"hex":case"utf8":case"utf-8":case"ascii":case"binary":case"base64":case"ucs2":case"ucs-2":case"utf16le":case"utf-16le":case"raw":return!0;default:return!1}},l=t.StringDecoder=function(e){switch(this.encoding=(e||"utf8").toLowerCase().replace(/[-_]/,""),r(e),this.encoding){case"utf8":this.surrogateSize=3;break;case"ucs2":case"utf16le":this.surrogateSize=2,this.detectIncompleteChar=a;break;case"base64":this.surrogateSize=3,this.detectIncompleteChar=o;break;default:return void(this.write=i)}this.charBuffer=new s(6),this.charReceived=0,this.charLength=0};l.prototype.write=function(e){for(var t="";this.charLength;){var n=e.length>=this.charLength-this.charReceived?this.charLength-this.charReceived:e.length;if(e.copy(this.charBuffer,this.charReceived,0,n),this.charReceived+=n,this.charReceived<this.charLength)return"";e=e.slice(n,e.length),t=this.charBuffer.slice(0,this.charLength).toString(this.encoding);var r=t.charCodeAt(t.length-1);if(!(r>=55296&&56319>=r)){if(this.charReceived=this.charLength=0,0===e.length)return t;break}this.charLength+=this.surrogateSize,t=""}this.detectIncompleteChar(e);var i=e.length;this.charLength&&(e.copy(this.charBuffer,0,e.length-this.charReceived,i),i-=this.charReceived),t+=e.toString(this.encoding,0,i);var i=t.length-1,r=t.charCodeAt(i);if(r>=55296&&56319>=r){var a=this.surrogateSize;return this.charLength+=a,this.charReceived+=a,this.charBuffer.copy(this.charBuffer,a,0,a),e.copy(this.charBuffer,0,0,a),t.substring(0,i)}return t},l.prototype.detectIncompleteChar=function(e){for(var t=e.length>=3?3:e.length;t>0;t--){var n=e[e.length-t];if(1==t&&n>>5==6){this.charLength=2;break}if(2>=t&&n>>4==14){this.charLength=3;break}if(3>=t&&n>>3==30){this.charLength=4;break}}this.charReceived=t},l.prototype.end=function(e){var t="";if(e&&e.length&&(t=this.write(e)),this.charReceived){var n=this.charReceived,r=this.charBuffer,i=this.encoding;t+=r.slice(0,n).toString(i)}return t}},function(e,t,n){(function(){var t,r,i,a,o;o=n(260),r=n(261),i=n(262),a=n(263),e.exports=t=function(){function e(e,t){var n,r;if(null==e)throw new Error("Root element needs a name");null==t&&(t={}),this.options=t,this.stringify=new o(t),r=new a(this,"doc"),n=r.element(e),n.isRoot=!0,n.documentObject=this,this.rootObject=n,t.headless||(n.declaration(t),(null!=t.pubID||null!=t.sysID)&&n.doctype(t))}return e.prototype.root=function(){return this.rootObject},e.prototype.end=function(e){return this.toString(e)},e.prototype.toString=function(e){var t,n,r,i,a,o,s,u;return i=(null!=e?e.pretty:void 0)||!1,t=null!=(o=null!=e?e.indent:void 0)?o:"  ",r=null!=(s=null!=e?e.offset:void 0)?s:0,n=null!=(u=null!=e?e.newline:void 0)?u:"\n",a="",null!=this.xmldec&&(a+=this.xmldec.toString(e)),null!=this.doctype&&(a+=this.doctype.toString(e)),a+=this.rootObject.toString(e),i&&a.slice(-n.length)===n&&(a=a.slice(0,-n.length)),a},e}()}).call(this)},function(e,t,n){e.exports=Array.isArray||function(e){return"[object Array]"==Object.prototype.toString.call(e)}},function(e,t,n){"function"==typeof Object.create?e.exports=function(e,t){e.super_=t,e.prototype=Object.create(t.prototype,{constructor:{value:e,enumerable:!1,writable:!0,configurable:!0}})}:e.exports=function(e,t){e.super_=t;var n=function(){};n.prototype=t.prototype,e.prototype=new n,e.prototype.constructor=e}},function(e,t,n){function r(){throw new Error("setTimeout has not been defined")}function i(){throw new Error("clearTimeout has not been defined")}function a(e){if(c===setTimeout)return setTimeout(e,0);if((c===r||!c)&&setTimeout)return c=setTimeout,setTimeout(e,0);try{return c(e,0)}catch(t){try{return c.call(null,e,0)}catch(t){return c.call(this,e,0)}}}function o(e){if(f===clearTimeout)return clearTimeout(e);if((f===i||!f)&&clearTimeout)return f=clearTimeout,clearTimeout(e);try{return f(e)}catch(t){try{return f.call(null,e)}catch(t){return f.call(this,e)}}}function s(){y&&d&&(y=!1,d.length?h=d.concat(h):v=-1,h.length&&u())}function u(){if(!y){var e=a(s);y=!0;for(var t=h.length;t;){for(d=h,h=[];++v<t;)d&&d[v].run();v=-1,t=h.length}d=null,y=!1,o(e)}}function l(e,t){this.fun=e,this.array=t}function p(){}var c,f,m=e.exports={};!function(){try{c="function"==typeof setTimeout?setTimeout:r}catch(e){c=r}try{f="function"==typeof clearTimeout?clearTimeout:i}catch(e){f=i}}();var d,h=[],y=!1,v=-1;m.nextTick=function(e){var t=new Array(arguments.length-1);if(arguments.length>1)for(var n=1;n<arguments.length;n++)t[n-1]=arguments[n];h.push(new l(e,t)),1!==h.length||y||a(u)},l.prototype.run=function(){this.fun.apply(null,this.array)},m.title="browser",m.browser=!0,m.env={},m.argv=[],m.version="",m.versions={},m.on=p,m.addListener=p,m.once=p,m.off=p,m.removeListener=p,m.removeAllListeners=p,m.emit=p,m.binding=function(e){throw new Error("process.binding is not supported")},m.cwd=function(){return"/"},m.chdir=function(e){throw new Error("process.chdir is not supported")},m.umask=function(){return 0}},function(e,t,n){(function(e){function n(e){return Array.isArray?Array.isArray(e):"[object Array]"===y(e)}function r(e){return"boolean"==typeof e}function i(e){return null===e}function a(e){return null==e}function o(e){return"number"==typeof e}function s(e){return"string"==typeof e}function u(e){return"symbol"==typeof e}function l(e){return void 0===e}function p(e){return"[object RegExp]"===y(e)}function c(e){return"object"==typeof e&&null!==e}function f(e){return"[object Date]"===y(e)}function m(e){return"[object Error]"===y(e)||e instanceof Error}function d(e){return"function"==typeof e}function h(e){return null===e||"boolean"==typeof e||"number"==typeof e||"string"==typeof e||"symbol"==typeof e||"undefined"==typeof e}function y(e){return Object.prototype.toString.call(e)}t.isArray=n,t.isBoolean=r,t.isNull=i,t.isNullOrUndefined=a,t.isNumber=o,t.isString=s,t.isSymbol=u,t.isUndefined=l,t.isRegExp=p,t.isObject=c,t.isDate=f,t.isError=m,t.isFunction=d,t.isPrimitive=h,t.isBuffer=e.isBuffer}).call(t,n(94).Buffer)},function(e,t,n){(function(){var t,n=function(e,t){return function(){return e.apply(t,arguments)}},r={}.hasOwnProperty;e.exports=t=function(){function e(e){this.assertLegalChar=n(this.assertLegalChar,this);var t,i,a;this.allowSurrogateChars=null!=e?e.allowSurrogateChars:void 0,this.noDoubleEncoding=null!=e?e.noDoubleEncoding:void 0,i=(null!=e?e.stringify:void 0)||{};for(t in i)r.call(i,t)&&(a=i[t],this[t]=a)}return e.prototype.eleName=function(e){return e=""+e||"",this.assertLegalChar(e)},e.prototype.eleText=function(e){return e=""+e||"",this.assertLegalChar(this.elEscape(e))},e.prototype.cdata=function(e){if(e=""+e||"",e.match(/]]>/))throw new Error("Invalid CDATA text: "+e);return this.assertLegalChar(e)},e.prototype.comment=function(e){if(e=""+e||"",e.match(/--/))throw new Error("Comment text cannot contain double-hypen: "+e);return this.assertLegalChar(e)},e.prototype.raw=function(e){return""+e||""},e.prototype.attName=function(e){return""+e||""},e.prototype.attValue=function(e){return e=""+e||"",this.attEscape(e)},e.prototype.insTarget=function(e){return""+e||""},e.prototype.insValue=function(e){if(e=""+e||"",e.match(/\?>/))throw new Error("Invalid processing instruction value: "+e);return e},e.prototype.xmlVersion=function(e){if(e=""+e||"",!e.match(/1\.[0-9]+/))throw new Error("Invalid version number: "+e);return e},e.prototype.xmlEncoding=function(e){if(e=""+e||"",!e.match(/^[A-Za-z](?:[A-Za-z0-9._-]|-)*$/))throw new Error("Invalid encoding: "+e);return e},e.prototype.xmlStandalone=function(e){return e?"yes":"no"},e.prototype.dtdPubID=function(e){return""+e||""},e.prototype.dtdSysID=function(e){return""+e||""},e.prototype.dtdElementValue=function(e){return""+e||""},e.prototype.dtdAttType=function(e){return""+e||""},e.prototype.dtdAttDefault=function(e){return null!=e?""+e||"":e},e.prototype.dtdEntityValue=function(e){return""+e||""},e.prototype.dtdNData=function(e){return""+e||""},e.prototype.convertAttKey="@",e.prototype.convertPIKey="?",e.prototype.convertTextKey="#text",e.prototype.convertCDataKey="#cdata",e.prototype.convertCommentKey="#comment",e.prototype.convertRawKey="#raw",e.prototype.assertLegalChar=function(e){var t,n;if(t=this.allowSurrogateChars?/[\u0000-\u0008\u000B-\u000C\u000E-\u001F\uFFFE-\uFFFF]/:/[\u0000-\u0008\u000B-\u000C\u000E-\u001F\uD800-\uDFFF\uFFFE-\uFFFF]/,n=e.match(t))throw new Error("Invalid character ("+n+") in string: "+e+" at index "+n.index);return e},e.prototype.elEscape=function(e){var t;return t=this.noDoubleEncoding?/(?!&\S+;)&/g:/&/g,e.replace(t,"&amp;").replace(/</g,"&lt;").replace(/>/g,"&gt;").replace(/\r/g,"&#xD;")},e.prototype.attEscape=function(e){var t;return t=this.noDoubleEncoding?/(?!&\S+;)&/g:/&/g,e.replace(t,"&amp;").replace(/</g,"&lt;").replace(/"/g,"&quot;")},e}()}).call(this)},function(e,t,n){(function(){var t,r,i,a,o=function(e,t){function n(){this.constructor=e}for(var r in t)s.call(t,r)&&(e[r]=t[r]);return n.prototype=t.prototype,e.prototype=new n,e.__super__=t.prototype,e},s={}.hasOwnProperty;i=n(265),a=n(266),r=n(267),e.exports=t=function(e){function t(e,n,r,i){var o;t.__super__.constructor.call(this,e),a(n)&&(o=n,n=o.version,r=o.encoding,i=o.standalone),n||(n="1.0"),this.version=this.stringify.xmlVersion(n),null!=r&&(this.encoding=this.stringify.xmlEncoding(r)),null!=i&&(this.standalone=this.stringify.xmlStandalone(i))}return o(t,e),t.prototype.toString=function(e,t){var n,r,i,a,o,s,u,l,p;return a=(null!=e?e.pretty:void 0)||!1,n=null!=(s=null!=e?e.indent:void 0)?s:"  ",i=null!=(u=null!=e?e.offset:void 0)?u:0,r=null!=(l=null!=e?e.newline:void 0)?l:"\n",t||(t=0),p=new Array(t+i+1).join(n),o="",a&&(o+=p),o+="<?xml",o+=' version="'+this.version+'"',null!=this.encoding&&(o+=' encoding="'+this.encoding+'"'),null!=this.standalone&&(o+=' standalone="'+this.standalone+'"'),o+="?>",a&&(o+=r),o},t}(r)}).call(this)},function(e,t,n){(function(){var t,r,i,a,o,s,u,l,p,c;p=n(265),c=n(266),t=n(272),r=n(273),i=n(274),o=n(275),a=n(276),s=n(277),l=n(271),e.exports=u=function(){function e(e,t,n){var r,i;this.documentObject=e,this.stringify=this.documentObject.stringify,this.children=[],c(t)&&(r=t,t=r.pubID,n=r.sysID),null==n&&(i=[t,n],n=i[0],t=i[1]),null!=t&&(this.pubID=this.stringify.dtdPubID(t)),null!=n&&(this.sysID=this.stringify.dtdSysID(n))}return e.prototype.element=function(e,t){var n;return n=new a(this,e,t),this.children.push(n),this},e.prototype.attList=function(e,t,n,r,a){var o;return o=new i(this,e,t,n,r,a),this.children.push(o),this},e.prototype.entity=function(e,t){var n;return n=new o(this,!1,e,t),this.children.push(n),this},e.prototype.pEntity=function(e,t){var n;return n=new o(this,!0,e,t),this.children.push(n),this},e.prototype.notation=function(e,t){var n;return n=new s(this,e,t),this.children.push(n),this},e.prototype.cdata=function(e){var n;return n=new t(this,e),this.children.push(n),this},e.prototype.comment=function(e){var t;return t=new r(this,e),this.children.push(t),this},e.prototype.instruction=function(e,t){var n;return n=new l(this,e,t),this.children.push(n),this},e.prototype.root=function(){return this.documentObject.root()},e.prototype.document=function(){return this.documentObject},e.prototype.toString=function(e,t){var n,r,i,a,o,s,u,l,p,c,f,m,d;if(u=(null!=e?e.pretty:void 0)||!1,i=null!=(p=null!=e?e.indent:void 0)?p:"  ",s=null!=(c=null!=e?e.offset:void 0)?c:0,o=null!=(f=null!=e?e.newline:void 0)?f:"\n",t||(t=0),d=new Array(t+s+1).join(i),l="",u&&(l+=d),l+="<!DOCTYPE "+this.root().name,this.pubID&&this.sysID?l+=' PUBLIC "'+this.pubID+'" "'+this.sysID+'"':this.sysID&&(l+=' SYSTEM "'+this.sysID+'"'),this.children.length>0){for(l+=" [",u&&(l+=o),m=this.children,r=0,a=m.length;a>r;r++)n=m[r],l+=n.toString(e,t+1);l+="]"}return l+=">",u&&(l+=o),l},e.prototype.ele=function(e,t){return this.element(e,t)},e.prototype.att=function(e,t,n,r,i){return this.attList(e,t,n,r,i)},e.prototype.ent=function(e,t){return this.entity(e,t)},e.prototype.pent=function(e,t){return this.pEntity(e,t)},e.prototype.not=function(e,t){return this.notation(e,t)},e.prototype.dat=function(e){return this.cdata(e)},e.prototype.com=function(e){return this.comment(e)},e.prototype.ins=function(e,t){return this.instruction(e,t)},e.prototype.up=function(){return this.root()},e.prototype.doc=function(){return this.document()},e}()}).call(this)},function(e,t,n){(function(){var t,r,i,a,o,s,u,l,p=function(e,t){function n(){this.constructor=e}for(var r in t)c.call(t,r)&&(e[r]=t[r]);return n.prototype=t.prototype,e.prototype=new n,e.__super__=t.prototype,e},c={}.hasOwnProperty;o=n(265),l=n(266),u=n(268),s=n(269),i=n(267),t=n(270),a=n(271),e.exports=r=function(e){function n(e,t,r){if(n.__super__.constructor.call(this,e),null==t)throw new Error("Missing element name");this.name=this.stringify.eleName(t),this.children=[],this.instructions=[],this.attributes={},null!=r&&this.attribute(r)}return p(n,e),n.prototype.clone=function(){var e,t,r,i,a,s,u,l;r=o(n.prototype,this),r.isRoot&&(r.documentObject=null),r.attributes={},u=this.attributes;for(t in u)c.call(u,t)&&(e=u[t],r.attributes[t]=e.clone());for(r.instructions=[],l=this.instructions,i=0,a=l.length;a>i;i++)s=l[i],r.instructions.push(s.clone());return r.children=[],this.children.forEach(function(e){var t;return t=e.clone(),t.parent=r,r.children.push(t)}),r},n.prototype.attribute=function(e,n){var r,i;if(null!=e&&(e=e.valueOf()),l(e))for(r in e)c.call(e,r)&&(i=e[r],this.attribute(r,i));else u(n)&&(n=n.apply()),this.options.skipNullAttributes&&null==n||(this.attributes[e]=new t(this,e,n));return this},n.prototype.removeAttribute=function(e){var t,n,r;if(null==e)throw new Error("Missing attribute name");if(e=e.valueOf(),Array.isArray(e))for(n=0,r=e.length;r>n;n++)t=e[n],delete this.attributes[t];else delete this.attributes[e];return this},n.prototype.instruction=function(e,t){var n,r,i,o,s;if(null!=e&&(e=e.valueOf()),null!=t&&(t=t.valueOf()),Array.isArray(e))for(n=0,s=e.length;s>n;n++)r=e[n],this.instruction(r);else if(l(e))for(r in e)c.call(e,r)&&(i=e[r],this.instruction(r,i));else u(t)&&(t=t.apply()),o=new a(this,e,t),this.instructions.push(o);return this},n.prototype.toString=function(e,t){var n,r,i,a,o,u,l,p,f,m,d,h,y,v,g,A,S,T,E,b;for(h=(null!=e?e.pretty:void 0)||!1,a=null!=(v=null!=e?e.indent:void 0)?v:"  ",d=null!=(g=null!=e?e.offset:void 0)?g:0,m=null!=(A=null!=e?e.newline:void 0)?A:"\n",t||(t=0),b=new Array(t+d+1).join(a),y="",S=this.instructions,i=0,l=S.length;l>i;i++)o=S[i],y+=o.toString(e,t);h&&(y+=b),y+="<"+this.name,T=this.attributes;for(f in T)c.call(T,f)&&(n=T[f],y+=n.toString(e));if(0===this.children.length||s(this.children,function(e){return""===e.value}))y+="/>",h&&(y+=m);else if(h&&1===this.children.length&&null!=this.children[0].value)y+=">",y+=this.children[0].value,y+="</"+this.name+">",y+=m;else{for(y+=">",h&&(y+=m),E=this.children,u=0,p=E.length;p>u;u++)r=E[u],y+=r.toString(e,t+1);h&&(y+=b),y+="</"+this.name+">",h&&(y+=m)}return y},n.prototype.att=function(e,t){return this.attribute(e,t)},n.prototype.ins=function(e,t){return this.instruction(e,t)},n.prototype.a=function(e,t){return this.attribute(e,t)},n.prototype.i=function(e,t){return this.instruction(e,t)},n}(i)}).call(this)},function(e,t,n){var r=n(278),i=n(279),a=n(280),o=n(281),s=n(282),u=n(283),l=Object.prototype,p=l.hasOwnProperty,c=l.propertyIsEnumerable,f=!c.call({valueOf:1},"valueOf"),m=a(function(e,t){if(f||s(t)||o(t))return void i(t,u(t),e);for(var n in t)p.call(t,n)&&r(e,n,t[n])});e.exports=m},function(e,t,n){function r(e,t){var n=a(e);return t?i(n,t):n}var i=n(287),a=n(288);e.exports=r},function(e,t,n){function r(e){var t=typeof e;return!!e&&("object"==t||"function"==t)}e.exports=r},function(e,t,n){(function(){var t,r,i,a,o,s,u,l,p,c,f,m={}.hasOwnProperty;f=n(266),c=n(268),p=n(284),o=null,t=null,r=null,i=null,a=null,u=null,l=null,e.exports=s=function(){function e(e){this.parent=e,this.options=this.parent.options,this.stringify=this.parent.stringify,null===o&&(o=n(263),t=n(272),r=n(273),i=n(261),a=n(262),u=n(285),l=n(286))}return e.prototype.element=function(e,t,n){var r,i,a,o,s,u,l,d,h,y;if(u=null,null==t&&(t={}),t=t.valueOf(),f(t)||(h=[t,n],n=h[0],t=h[1]),null!=e&&(e=e.valueOf()),Array.isArray(e))for(a=0,l=e.length;l>a;a++)i=e[a],u=this.element(i);else if(c(e))u=this.element(e.apply());else if(f(e)){for(s in e)if(m.call(e,s))if(y=e[s],c(y)&&(y=y.apply()),f(y)&&p(y)&&(y=null),!this.options.ignoreDecorators&&this.stringify.convertAttKey&&0===s.indexOf(this.stringify.convertAttKey))u=this.attribute(s.substr(this.stringify.convertAttKey.length),y);else if(!this.options.ignoreDecorators&&this.stringify.convertPIKey&&0===s.indexOf(this.stringify.convertPIKey))u=this.instruction(s.substr(this.stringify.convertPIKey.length),y);else if(!this.options.separateArrayItems&&Array.isArray(y))for(o=0,d=y.length;d>o;o++)i=y[o],r={},r[s]=i,u=this.element(r);else f(y)?(u=this.element(s),u.element(y)):u=this.element(s,y)}else u=!this.options.ignoreDecorators&&this.stringify.convertTextKey&&0===e.indexOf(this.stringify.convertTextKey)?this.text(n):!this.options.ignoreDecorators&&this.stringify.convertCDataKey&&0===e.indexOf(this.stringify.convertCDataKey)?this.cdata(n):!this.options.ignoreDecorators&&this.stringify.convertCommentKey&&0===e.indexOf(this.stringify.convertCommentKey)?this.comment(n):!this.options.ignoreDecorators&&this.stringify.convertRawKey&&0===e.indexOf(this.stringify.convertRawKey)?this.raw(n):this.node(e,t,n);if(null==u)throw new Error("Could not create any elements with: "+e);return u},e.prototype.insertBefore=function(e,t,n){var r,i,a;if(this.isRoot)throw new Error("Cannot insert elements at root level");return i=this.parent.children.indexOf(this),a=this.parent.children.splice(i),r=this.parent.element(e,t,n),Array.prototype.push.apply(this.parent.children,a),r},e.prototype.insertAfter=function(e,t,n){var r,i,a;if(this.isRoot)throw new Error("Cannot insert elements at root level");return i=this.parent.children.indexOf(this),a=this.parent.children.splice(i+1),r=this.parent.element(e,t,n),Array.prototype.push.apply(this.parent.children,a),r},e.prototype.remove=function(){var e,t;if(this.isRoot)throw new Error("Cannot remove the root element");return e=this.parent.children.indexOf(this),[].splice.apply(this.parent.children,[e,e-e+1].concat(t=[])),t,this.parent},e.prototype.node=function(e,t,n){var r,i;return null!=e&&(e=e.valueOf()),null==t&&(t={}),t=t.valueOf(),f(t)||(i=[t,n],n=i[0],t=i[1]),r=new o(this,e,t),null!=n&&r.text(n),this.children.push(r),r},e.prototype.text=function(e){var t;return t=new l(this,e),this.children.push(t),this},e.prototype.cdata=function(e){var n;return n=new t(this,e),this.children.push(n),this},e.prototype.comment=function(e){var t;return t=new r(this,e),this.children.push(t),this},e.prototype.raw=function(e){var t;return t=new u(this,e),this.children.push(t),this},e.prototype.declaration=function(e,t,n){var r,a;return r=this.document(),a=new i(r,e,t,n),r.xmldec=a,r.root()},e.prototype.doctype=function(e,t){var n,r;return n=this.document(),r=new a(n,e,t),n.doctype=r,r},e.prototype.up=function(){if(this.isRoot)throw new Error("The root node has no parent. Use doc() if you need to get the document object.");return this.parent},e.prototype.root=function(){var e;if(this.isRoot)return this;for(e=this.parent;!e.isRoot;)e=e.parent;return e},e.prototype.document=function(){return this.root().documentObject},e.prototype.end=function(e){return this.document().toString(e)},e.prototype.prev=function(){var e;if(this.isRoot)throw new Error("Root node has no siblings");if(e=this.parent.children.indexOf(this),1>e)throw new Error("Already at the first node");return this.parent.children[e-1]},e.prototype.next=function(){var e;if(this.isRoot)throw new Error("Root node has no siblings");if(e=this.parent.children.indexOf(this),-1===e||e===this.parent.children.length-1)throw new Error("Already at the last node");return this.parent.children[e+1]},e.prototype.importXMLBuilder=function(e){var t;return t=e.root().clone(),t.parent=this,t.isRoot=!1,this.children.push(t),this},e.prototype.ele=function(e,t,n){return this.element(e,t,n)},e.prototype.nod=function(e,t,n){return this.node(e,t,n)},e.prototype.txt=function(e){return this.text(e)},e.prototype.dat=function(e){return this.cdata(e)},e.prototype.com=function(e){return this.comment(e)},e.prototype.doc=function(){return this.document()},e.prototype.dec=function(e,t,n){return this.declaration(e,t,n)},e.prototype.dtd=function(e,t){return this.doctype(e,t)},e.prototype.e=function(e,t,n){return this.element(e,t,n)},e.prototype.n=function(e,t,n){return this.node(e,t,n)},e.prototype.t=function(e){return this.text(e)},e.prototype.d=function(e){return this.cdata(e)},e.prototype.c=function(e){return this.comment(e)},e.prototype.r=function(e){return this.raw(e)},e.prototype.u=function(){return this.up()},e}()}).call(this)},function(e,t,n){function r(e){var t=i(e)?u.call(e):"";return t==a||t==o}var i=n(266),a="[object Function]",o="[object GeneratorFunction]",s=Object.prototype,u=s.toString;e.exports=r},function(e,t,n){function r(e,t,n){var r=s(e)?i:a;return n&&u(e,t,n)&&(t=void 0),r(e,o(t,3))}var i=n(289),a=n(290),o=n(291),s=n(292),u=n(293);e.exports=r},function(e,t,n){(function(){var t,r;r=n(265),e.exports=t=function(){function e(e,t,n){if(this.stringify=e.stringify,null==t)throw new Error("Missing attribute name of element "+e.name);if(null==n)throw new Error("Missing attribute value for attribute "+t+" of element "+e.name);this.name=this.stringify.attName(t),this.value=this.stringify.attValue(n)}return e.prototype.clone=function(){return r(e.prototype,this)},e.prototype.toString=function(e,t){return" "+this.name+'="'+this.value+'"'},e}()}).call(this)},function(e,t,n){(function(){var t,r;r=n(265),e.exports=t=function(){function e(e,t,n){if(this.stringify=e.stringify,null==t)throw new Error("Missing instruction target");this.target=this.stringify.insTarget(t),n&&(this.value=this.stringify.insValue(n))}return e.prototype.clone=function(){return r(e.prototype,this)},e.prototype.toString=function(e,t){var n,r,i,a,o,s,u,l,p;return a=(null!=e?e.pretty:void 0)||!1,n=null!=(s=null!=e?e.indent:void 0)?s:"  ",i=null!=(u=null!=e?e.offset:void 0)?u:0,r=null!=(l=null!=e?e.newline:void 0)?l:"\n",t||(t=0),p=new Array(t+i+1).join(n),o="",a&&(o+=p),o+="<?",o+=this.target,this.value&&(o+=" "+this.value),o+="?>",a&&(o+=r),o},e}()}).call(this)},function(e,t,n){(function(){var t,r,i,a=function(e,t){function n(){this.constructor=e}for(var r in t)o.call(t,r)&&(e[r]=t[r]);return n.prototype=t.prototype,e.prototype=new n,e.__super__=t.prototype,e},o={}.hasOwnProperty;i=n(265),r=n(267),e.exports=t=function(e){function t(e,n){if(t.__super__.constructor.call(this,e),null==n)throw new Error("Missing CDATA text");this.text=this.stringify.cdata(n)}return a(t,e),t.prototype.clone=function(){return i(t.prototype,this)},t.prototype.toString=function(e,t){var n,r,i,a,o,s,u,l,p;return a=(null!=e?e.pretty:void 0)||!1,n=null!=(s=null!=e?e.indent:void 0)?s:"  ",i=null!=(u=null!=e?e.offset:void 0)?u:0,r=null!=(l=null!=e?e.newline:void 0)?l:"\n",t||(t=0),p=new Array(t+i+1).join(n),o="",a&&(o+=p),o+="<![CDATA["+this.text+"]]>",a&&(o+=r),o},t}(r)}).call(this)},function(e,t,n){(function(){var t,r,i,a=function(e,t){function n(){this.constructor=e}for(var r in t)o.call(t,r)&&(e[r]=t[r]);return n.prototype=t.prototype,e.prototype=new n,e.__super__=t.prototype,e},o={}.hasOwnProperty;i=n(265),r=n(267),e.exports=t=function(e){function t(e,n){if(t.__super__.constructor.call(this,e),null==n)throw new Error("Missing comment text");this.text=this.stringify.comment(n)}return a(t,e),t.prototype.clone=function(){return i(t.prototype,this)},t.prototype.toString=function(e,t){var n,r,i,a,o,s,u,l,p;return a=(null!=e?e.pretty:void 0)||!1,n=null!=(s=null!=e?e.indent:void 0)?s:"  ",i=null!=(u=null!=e?e.offset:void 0)?u:0,r=null!=(l=null!=e?e.newline:void 0)?l:"\n",t||(t=0),p=new Array(t+i+1).join(n),o="",a&&(o+=p),o+="<!-- "+this.text+" -->",a&&(o+=r),o},t}(r)}).call(this)},function(e,t,n){(function(){var t,r;r=n(265),e.exports=t=function(){function e(e,t,n,r,i,a){if(this.stringify=e.stringify,null==t)throw new Error("Missing DTD element name");if(null==n)throw new Error("Missing DTD attribute name");if(!r)throw new Error("Missing DTD attribute type");if(!i)throw new Error("Missing DTD attribute default");if(0!==i.indexOf("#")&&(i="#"+i),!i.match(/^(#REQUIRED|#IMPLIED|#FIXED|#DEFAULT)$/))throw new Error("Invalid default value type; expected: #REQUIRED, #IMPLIED, #FIXED or #DEFAULT");if(a&&!i.match(/^(#FIXED|#DEFAULT)$/))throw new Error("Default value only applies to #FIXED or #DEFAULT");this.elementName=this.stringify.eleName(t),this.attributeName=this.stringify.attName(n),this.attributeType=this.stringify.dtdAttType(r),this.defaultValue=this.stringify.dtdAttDefault(a),this.defaultValueType=i}return e.prototype.toString=function(e,t){var n,r,i,a,o,s,u,l,p;return a=(null!=e?e.pretty:void 0)||!1,n=null!=(s=null!=e?e.indent:void 0)?s:"  ",i=null!=(u=null!=e?e.offset:void 0)?u:0,r=null!=(l=null!=e?e.newline:void 0)?l:"\n",t||(t=0),p=new Array(t+i+1).join(n),o="",a&&(o+=p),o+="<!ATTLIST "+this.elementName+" "+this.attributeName+" "+this.attributeType,"#DEFAULT"!==this.defaultValueType&&(o+=" "+this.defaultValueType),this.defaultValue&&(o+=' "'+this.defaultValue+'"'),o+=">",a&&(o+=r),o},e}()}).call(this)},function(e,t,n){(function(){var t,r,i;r=n(265),i=n(266),e.exports=t=function(){function e(e,t,n,r){if(this.stringify=e.stringify,null==n)throw new Error("Missing entity name");if(null==r)throw new Error("Missing entity value");if(this.pe=!!t,this.name=this.stringify.eleName(n),i(r)){if(!r.pubID&&!r.sysID)throw new Error("Public and/or system identifiers are required for an external entity");if(r.pubID&&!r.sysID)throw new Error("System identifier is required for a public external entity");if(null!=r.pubID&&(this.pubID=this.stringify.dtdPubID(r.pubID)),null!=r.sysID&&(this.sysID=this.stringify.dtdSysID(r.sysID)),null!=r.nData&&(this.nData=this.stringify.dtdNData(r.nData)),this.pe&&this.nData)throw new Error("Notation declaration is not allowed in a parameter entity")}else this.value=this.stringify.dtdEntityValue(r)}return e.prototype.toString=function(e,t){var n,r,i,a,o,s,u,l,p;return a=(null!=e?e.pretty:void 0)||!1,n=null!=(s=null!=e?e.indent:void 0)?s:"  ",i=null!=(u=null!=e?e.offset:void 0)?u:0,r=null!=(l=null!=e?e.newline:void 0)?l:"\n",t||(t=0),p=new Array(t+i+1).join(n),o="",a&&(o+=p),o+="<!ENTITY",this.pe&&(o+=" %"),o+=" "+this.name,this.value?o+=' "'+this.value+'"':(this.pubID&&this.sysID?o+=' PUBLIC "'+this.pubID+'" "'+this.sysID+'"':this.sysID&&(o+=' SYSTEM "'+this.sysID+'"'),this.nData&&(o+=" NDATA "+this.nData)),o+=">",a&&(o+=r),o},e}()}).call(this)},function(e,t,n){(function(){var t,r;r=n(265),e.exports=t=function(){function e(e,t,n){if(this.stringify=e.stringify,null==t)throw new Error("Missing DTD element name");n||(n="(#PCDATA)"),Array.isArray(n)&&(n="("+n.join(",")+")"),this.name=this.stringify.eleName(t),this.value=this.stringify.dtdElementValue(n)}return e.prototype.toString=function(e,t){var n,r,i,a,o,s,u,l,p;return a=(null!=e?e.pretty:void 0)||!1,n=null!=(s=null!=e?e.indent:void 0)?s:"  ",i=null!=(u=null!=e?e.offset:void 0)?u:0,r=null!=(l=null!=e?e.newline:void 0)?l:"\n",t||(t=0),p=new Array(t+i+1).join(n),o="",a&&(o+=p),o+="<!ELEMENT "+this.name+" "+this.value+">",a&&(o+=r),o},e}()}).call(this)},function(e,t,n){(function(){var t,r;r=n(265),e.exports=t=function(){function e(e,t,n){if(this.stringify=e.stringify,null==t)throw new Error("Missing notation name");if(!n.pubID&&!n.sysID)throw new Error("Public or system identifiers are required for an external entity");this.name=this.stringify.eleName(t),null!=n.pubID&&(this.pubID=this.stringify.dtdPubID(n.pubID)),null!=n.sysID&&(this.sysID=this.stringify.dtdSysID(n.sysID))}return e.prototype.toString=function(e,t){var n,r,i,a,o,s,u,l,p;return a=(null!=e?e.pretty:void 0)||!1,n=null!=(s=null!=e?e.indent:void 0)?s:"  ",i=null!=(u=null!=e?e.offset:void 0)?u:0,r=null!=(l=null!=e?e.newline:void 0)?l:"\n",t||(t=0),p=new Array(t+i+1).join(n),o="",a&&(o+=p),o+="<!NOTATION "+this.name,this.pubID&&this.sysID?o+=' PUBLIC "'+this.pubID+'" "'+this.sysID+'"':this.pubID?o+=' PUBLIC "'+this.pubID+'"':this.sysID&&(o+=' SYSTEM "'+this.sysID+'"'),o+=">",a&&(o+=r),o},e}()}).call(this)},function(e,t,n){function r(e,t,n){var r=e[t];o.call(e,t)&&i(r,n)&&(void 0!==n||t in e)||(e[t]=n)}var i=n(295),a=Object.prototype,o=a.hasOwnProperty;e.exports=r},function(e,t,n){function r(e,t,n,r){n||(n={});for(var a=-1,o=t.length;++a<o;){var s=t[a],u=r?r(n[s],e[s],s,n,e):e[s];i(n,s,u)}return n}var i=n(278);e.exports=r},function(e,t,n){function r(e){return a(function(t,n){var r=-1,a=n.length,o=a>1?n[a-1]:void 0,s=a>2?n[2]:void 0;for(o="function"==typeof o?(a--,o):void 0,s&&i(n[0],n[1],s)&&(o=3>a?void 0:o,a=1),t=Object(t);++r<a;){var u=n[r];u&&e(t,u,r,o)}return t})}var i=n(293),a=n(294);e.exports=r},function(e,t,n){function r(e){return null!=e&&o(i(e))&&!a(e)}var i=n(296),a=n(268),o=n(297);e.exports=r},function(e,t,n){function r(e){var t=e&&e.constructor,n="function"==typeof t&&t.prototype||i;return e===n}var i=Object.prototype;e.exports=r},function(e,t,n){function r(e){var t=l(e);if(!t&&!s(e))return a(e);var n=o(e),r=!!n,p=n||[],c=p.length;for(var f in e)!i(e,f)||r&&("length"==f||u(f,c))||t&&"constructor"==f||p.push(f);return p}var i=n(298),a=n(299),o=n(300),s=n(281),u=n(301),l=n(282);e.exports=r},function(e,t,n){function r(e){if(s(e)&&(o(e)||c(e)||l(e.splice)||a(e)||u(e)))return!e.length;if(p(e)){var t=i(e);if(t==m||t==d)return!e.size}for(var n in e)if(y.call(e,n))return!1;return!(g&&f(e).length)}var i=n(302),a=n(303),o=n(292),s=n(281),u=n(304),l=n(268),p=n(305),c=n(306),f=n(283),m="[object Map]",d="[object Set]",h=Object.prototype,y=h.hasOwnProperty,v=h.propertyIsEnumerable,g=!v.call({valueOf:1},"valueOf");e.exports=r},function(e,t,n){(function(){var t,r,i,a=function(e,t){function n(){this.constructor=e}for(var r in t)o.call(t,r)&&(e[r]=t[r]);return n.prototype=t.prototype,e.prototype=new n,e.__super__=t.prototype,e},o={}.hasOwnProperty;i=n(265),t=n(267),e.exports=r=function(e){function t(e,n){if(t.__super__.constructor.call(this,e),null==n)throw new Error("Missing raw text");this.value=this.stringify.raw(n)}return a(t,e),t.prototype.clone=function(){return i(t.prototype,this)},t.prototype.toString=function(e,t){var n,r,i,a,o,s,u,l,p;return a=(null!=e?e.pretty:void 0)||!1,n=null!=(s=null!=e?e.indent:void 0)?s:"  ",i=null!=(u=null!=e?e.offset:void 0)?u:0,r=null!=(l=null!=e?e.newline:void 0)?l:"\n",t||(t=0),p=new Array(t+i+1).join(n),o="",a&&(o+=p),o+=this.value,a&&(o+=r),o},t}(t)}).call(this)},function(e,t,n){(function(){var t,r,i,a=function(e,t){function n(){this.constructor=e}for(var r in t)o.call(t,r)&&(e[r]=t[r]);return n.prototype=t.prototype,e.prototype=new n,e.__super__=t.prototype,e},o={}.hasOwnProperty;i=n(265),t=n(267),e.exports=r=function(e){function t(e,n){if(t.__super__.constructor.call(this,e),
null==n)throw new Error("Missing element text");this.value=this.stringify.eleText(n)}return a(t,e),t.prototype.clone=function(){return i(t.prototype,this)},t.prototype.toString=function(e,t){var n,r,i,a,o,s,u,l,p;return a=(null!=e?e.pretty:void 0)||!1,n=null!=(s=null!=e?e.indent:void 0)?s:"  ",i=null!=(u=null!=e?e.offset:void 0)?u:0,r=null!=(l=null!=e?e.newline:void 0)?l:"\n",t||(t=0),p=new Array(t+i+1).join(n),o="",a&&(o+=p),o+=this.value,a&&(o+=r),o},t}(t)}).call(this)},function(e,t,n){function r(e,t){return e&&i(t,a(t),e)}var i=n(279),a=n(283);e.exports=r},function(e,t,n){function r(e){return i(e)?a(e):{}}var i=n(266),a=Object.create;e.exports=r},function(e,t,n){function r(e,t){for(var n=-1,r=e.length;++n<r;)if(!t(e[n],n,e))return!1;return!0}e.exports=r},function(e,t,n){function r(e,t){var n=!0;return i(e,function(e,r,i){return n=!!t(e,r,i)}),n}var i=n(311);e.exports=r},function(e,t,n){function r(e){return"function"==typeof e?e:null==e?o:"object"==typeof e?s(e)?a(e[0],e[1]):i(e):u(e)}var i=n(307),a=n(308),o=n(309),s=n(292),u=n(310);e.exports=r},function(e,t,n){var r=Array.isArray;e.exports=r},function(e,t,n){function r(e,t,n){if(!s(n))return!1;var r=typeof t;return("number"==r?a(n)&&o(t,n.length):"string"==r&&t in n)?i(n[t],e):!1}var i=n(295),a=n(281),o=n(301),s=n(266);e.exports=r},function(e,t,n){function r(e,t){if("function"!=typeof e)throw new TypeError(o);return t=s(void 0===t?e.length-1:a(t),0),function(){for(var n=arguments,r=-1,a=s(n.length-t,0),o=Array(a);++r<a;)o[r]=n[t+r];switch(t){case 0:return e.call(this,o);case 1:return e.call(this,n[0],o);case 2:return e.call(this,n[0],n[1],o)}var u=Array(t+1);for(r=-1;++r<t;)u[r]=n[r];return u[t]=o,i(e,this,u)}}var i=n(312),a=n(313),o="Expected a function",s=Math.max;e.exports=r},function(e,t,n){function r(e,t){return e===t||e!==e&&t!==t}e.exports=r},function(e,t,n){var r=n(314),i=r("length");e.exports=i},function(e,t,n){function r(e){return"number"==typeof e&&e>-1&&e%1==0&&i>=e}var i=9007199254740991;e.exports=r},function(e,t,n){function r(e,t){return o.call(e,t)||"object"==typeof e&&t in e&&null===i(e)}var i=n(315),a=Object.prototype,o=a.hasOwnProperty;e.exports=r},function(e,t,n){function r(e){return i(Object(e))}var i=Object.keys;e.exports=r},function(e,t,n){function r(e){var t=e?e.length:void 0;return s(t)&&(o(e)||u(e)||a(e))?i(t,String):null}var i=n(316),a=n(303),o=n(292),s=n(297),u=n(306);e.exports=r},function(e,t,n){function r(e,t){return e="number"==typeof e||a.test(e)?+e:-1,t=null==t?i:t,e>-1&&e%1==0&&t>e}var i=9007199254740991,a=/^(?:0|[1-9]\d*)$/;e.exports=r},function(e,t,n){function r(e){return v.call(e)}var i=n(318),a=n(319),o=n(320),s=n(321),u=n(322),l=n(323),p="[object Map]",c="[object Object]",f="[object Promise]",m="[object Set]",d="[object WeakMap]",h="[object DataView]",y=Object.prototype,v=y.toString,g=l(i),A=l(a),S=l(o),T=l(s),E=l(u);(i&&r(new i(new ArrayBuffer(1)))!=h||a&&r(new a)!=p||o&&r(o.resolve())!=f||s&&r(new s)!=m||u&&r(new u)!=d)&&(r=function(e){var t=v.call(e),n=t==c?e.constructor:void 0,r=n?l(n):void 0;if(r)switch(r){case g:return h;case A:return p;case S:return f;case T:return m;case E:return d}return t}),e.exports=r},function(e,t,n){function r(e){return i(e)&&s.call(e,"callee")&&(!l.call(e,"callee")||u.call(e)==a)}var i=n(317),a="[object Arguments]",o=Object.prototype,s=o.hasOwnProperty,u=o.toString,l=o.propertyIsEnumerable;e.exports=r},function(e,t,n){(function(e){var r=n(324),i=n(325),a={"function":!0,object:!0},o=a[typeof t]&&t&&!t.nodeType?t:void 0,s=a[typeof e]&&e&&!e.nodeType?e:void 0,u=s&&s.exports===o?o:void 0,l=u?i.Buffer:void 0,p=l?function(e){return e instanceof l}:r(!1);e.exports=p}).call(t,n(147)(e))},function(e,t,n){function r(e){return!!e&&"object"==typeof e}e.exports=r},function(e,t,n){function r(e){return"string"==typeof e||!i(e)&&a(e)&&u.call(e)==o}var i=n(292),a=n(305),o="[object String]",s=Object.prototype,u=s.toString;e.exports=r},function(e,t,n){function r(e){var t=a(e);return 1==t.length&&t[0][2]?o(t[0][0],t[0][1]):function(n){return n===e||i(n,e,t)}}var i=n(326),a=n(327),o=n(328);e.exports=r},function(e,t,n){function r(e,t){return s(e)&&u(t)?l(e,t):function(n){var r=a(n,e);return void 0===r&&r===t?o(n,e):i(t,r,void 0,p|c)}}var i=n(329),a=n(330),o=n(331),s=n(332),u=n(333),l=n(328),p=1,c=2;e.exports=r},function(e,t,n){function r(e){return e}e.exports=r},function(e,t,n){function r(e){return o(e)?i(e):a(e)}var i=n(314),a=n(336),o=n(332);e.exports=r},function(e,t,n){var r=n(334),i=n(335),a=i(r);e.exports=a},function(e,t,n){function r(e,t,n){var r=n.length;switch(r){case 0:return e.call(t);case 1:return e.call(t,n[0]);case 2:return e.call(t,n[0],n[1]);case 3:return e.call(t,n[0],n[1],n[2])}return e.apply(t,n)}e.exports=r},function(e,t,n){function r(e){if(!e)return 0===e?e:0;if(e=i(e),e===a||e===-a){var t=0>e?-1:1;return t*o}var n=e%1;return e===e?n?e-n:e:0}var i=n(337),a=1/0,o=1.7976931348623157e308;e.exports=r},function(e,t,n){function r(e){return function(t){return null==t?void 0:t[e]}}e.exports=r},function(e,t,n){function r(e){return i(Object(e))}var i=Object.getPrototypeOf;e.exports=r},function(e,t,n){function r(e,t){for(var n=-1,r=Array(e);++n<e;)r[n]=t(n);return r}e.exports=r},function(e,t,n){function r(e){return a(e)&&i(e)}var i=n(281),a=n(305);e.exports=r},function(e,t,n){var r=n(338),i=n(325),a=r(i,"DataView");e.exports=a},function(e,t,n){var r=n(338),i=n(325),a=r(i,"Map");e.exports=a},function(e,t,n){var r=n(338),i=n(325),a=r(i,"Promise");e.exports=a},function(e,t,n){var r=n(338),i=n(325),a=r(i,"Set");e.exports=a},function(e,t,n){var r=n(338),i=n(325),a=r(i,"WeakMap");e.exports=a},function(e,t,n){function r(e){if(null!=e){try{return i.call(e)}catch(t){}try{return e+""}catch(t){}}return""}var i=Function.prototype.toString;e.exports=r},function(e,t,n){function r(e){return function(){return e}}e.exports=r},function(e,t,n){(function(e,r){var i=n(340),a={"function":!0,object:!0},o=a[typeof t]&&t&&!t.nodeType?t:void 0,s=a[typeof e]&&e&&!e.nodeType?e:void 0,u=i(o&&s&&"object"==typeof r&&r),l=i(a[typeof self]&&self),p=i(a[typeof window]&&window),c=i(a[typeof this]&&this),f=u||p!==(c&&c.window)&&p||l||c||Function("return this")();e.exports=f}).call(t,n(147)(e),function(){return this}())},function(e,t,n){function r(e,t,n,r){var u=n.length,l=u,p=!r;if(null==e)return!l;for(e=Object(e);u--;){var c=n[u];if(p&&c[2]?c[1]!==e[c[0]]:!(c[0]in e))return!1}for(;++u<l;){c=n[u];var f=c[0],m=e[f],d=c[1];if(p&&c[2]){if(void 0===m&&!(f in e))return!1}else{var h=new i;if(r)var y=r(m,d,f,e,t,h);if(!(void 0===y?a(d,m,r,o|s,h):y))return!1}}return!0}var i=n(339),a=n(329),o=1,s=2;e.exports=r},function(e,t,n){function r(e){for(var t=a(e),n=t.length;n--;)t[n][2]=i(t[n][1]);return t}var i=n(333),a=n(341);e.exports=r},function(e,t,n){function r(e,t){return function(n){return null==n?!1:n[e]===t&&(void 0!==t||e in Object(n))}}e.exports=r},function(e,t,n){function r(e,t,n,s,u){return e===t?!0:null==e||null==t||!a(e)&&!o(t)?e!==e&&t!==t:i(e,t,r,n,s,u)}var i=n(342),a=n(266),o=n(305);e.exports=r},function(e,t,n){function r(e,t,n){var r=null==e?void 0:i(e,t);return void 0===r?n:r}var i=n(345);e.exports=r},function(e,t,n){function r(e,t){return null!=e&&a(e,t,i)}var i=n(343),a=n(344);e.exports=r},function(e,t,n){function r(e,t){var n=typeof e;return"number"==n||"symbol"==n?!0:!i(e)&&(a(e)||s.test(e)||!o.test(e)||null!=t&&e in Object(t))}var i=n(292),a=n(346),o=/\.|\[(?:[^[\]]*|(["'])(?:(?!\1)[^\\]|\\.)*?\1)\]/,s=/^\w*$/;e.exports=r},function(e,t,n){function r(e){return e===e&&!i(e)}var i=n(266);e.exports=r},function(e,t,n){function r(e,t){return e&&i(e,t,a)}var i=n(347),a=n(283);e.exports=r},function(e,t,n){function r(e,t){return function(n,r){if(null==n)return n;if(!i(n))return e(n,r);for(var a=n.length,o=t?a:-1,s=Object(n);(t?o--:++o<a)&&r(s[o],o,s)!==!1;);return n}}var i=n(281);e.exports=r},function(e,t,n){function r(e){return function(t){return i(t,e)}}var i=n(345);e.exports=r},function(e,t,n){function r(e){if("number"==typeof e)return e;if(o(e))return s;if(a(e)){var t=i(e.valueOf)?e.valueOf():e;e=a(t)?t+"":t}if("string"!=typeof e)return 0===e?e:+e;e=e.replace(u,"");var n=p.test(e);return n||c.test(e)?f(e.slice(2),n?2:8):l.test(e)?s:+e}var i=n(268),a=n(266),o=n(346),s=NaN,u=/^\s+|\s+$/g,l=/^[-+]0x[0-9a-f]+$/i,p=/^0b[01]+$/i,c=/^0o[0-7]+$/i,f=parseInt;e.exports=r},function(e,t,n){function r(e,t){var n=e[t];return i(n)?n:void 0}var i=n(348);e.exports=r},function(e,t,n){function r(e){var t=-1,n=e?e.length:0;for(this.clear();++t<n;){var r=e[t];this.set(r[0],r[1])}}var i=n(349),a=n(350),o=n(351),s=n(352),u=n(353);r.prototype.clear=i,r.prototype["delete"]=a,r.prototype.get=o,r.prototype.has=s,r.prototype.set=u,e.exports=r},function(e,t,n){function r(e){return e&&e.Object===Object?e:null}e.exports=r},function(e,t,n){function r(e){return i(e,a(e))}var i=n(354),a=n(283);e.exports=r},function(e,t,n){function r(e,t,n,r,y,g){var A=l(e),S=l(t),T=d,E=d;A||(T=u(e),T=T==m?h:T),S||(E=u(t),E=E==m?h:E);var b=T==h&&!p(e),N=E==h&&!p(t),_=T==E;if(_&&!b)return g||(g=new i),A||c(e)?a(e,t,n,r,y,g):o(e,t,T,n,r,y,g);if(!(y&f)){var M=b&&v.call(e,"__wrapped__"),w=N&&v.call(t,"__wrapped__");if(M||w){var R=M?e.value():e,I=w?t.value():t;return g||(g=new i),n(R,I,r,y,g)}}return _?(g||(g=new i),s(e,t,n,r,y,g)):!1}var i=n(339),a=n(356),o=n(357),s=n(358),u=n(302),l=n(292),p=n(359),c=n(360),f=2,m="[object Arguments]",d="[object Array]",h="[object Object]",y=Object.prototype,v=y.hasOwnProperty;e.exports=r},function(e,t,n){function r(e,t){return t in Object(e)}e.exports=r},function(e,t,n){function r(e,t,n){t=u(t,e)?[t]:i(t);for(var r,c=-1,f=t.length;++c<f;){var m=t[c];if(!(r=null!=e&&n(e,m)))break;e=e[m]}if(r)return r;var f=e?e.length:0;return!!f&&l(f)&&s(m,f)&&(o(e)||p(e)||a(e))}var i=n(355),a=n(303),o=n(292),s=n(301),u=n(332),l=n(297),p=n(306);e.exports=r},function(e,t,n){function r(e,t){t=a(t,e)?[t]:i(t);for(var n=0,r=t.length;null!=e&&r>n;)e=e[t[n++]];return n&&n==r?e:void 0}var i=n(355),a=n(332);e.exports=r},function(e,t,n){function r(e){return"symbol"==typeof e||i(e)&&s.call(e)==a}var i=n(305),a="[object Symbol]",o=Object.prototype,s=o.toString;e.exports=r},function(e,t,n){var r=n(361),i=r();e.exports=i},function(e,t,n){function r(e){if(!o(e))return!1;var t=i(e)||a(e)?m:l;return t.test(s(e))}var i=n(268),a=n(359),o=n(266),s=n(323),u=/[\\^$.*+?()[\]{}|]/g,l=/^\[object .+?Constructor\]$/,p=Object.prototype,c=Function.prototype.toString,f=p.hasOwnProperty,m=RegExp("^"+c.call(f).replace(u,"\\$&").replace(/hasOwnProperty|(function).*?(?=\\\()| for .+?(?=\\\])/g,"$1.*?")+"$");e.exports=r},function(e,t,n){function r(){this.__data__={array:[],map:null}}e.exports=r},function(e,t,n){function r(e){var t=this.__data__,n=t.array;return n?i(n,e):t.map["delete"](e)}var i=n(363);e.exports=r},function(e,t,n){function r(e){var t=this.__data__,n=t.array;return n?i(n,e):t.map.get(e)}var i=n(362);e.exports=r},function(e,t,n){function r(e){var t=this.__data__,n=t.array;return n?i(n,e):t.map.has(e)}var i=n(367);e.exports=r},function(e,t,n){function r(e,t){var n=this.__data__,r=n.array;r&&(r.length<o-1?a(r,e,t):(n.array=null,n.map=new i(r)));var s=n.map;return s&&s.set(e,t),this}var i=n(365),a=n(366),o=200;e.exports=r},function(e,t,n){function r(e,t){return i(t,function(t){return[t,e[t]]})}var i=n(368);e.exports=r},function(e,t,n){function r(e){return i(e)?e:a(e)}var i=n(292),a=n(364);e.exports=r},function(e,t,n){function r(e,t,n,r,s,u){var l=-1,p=s&o,c=s&a,f=e.length,m=t.length;if(f!=m&&!(p&&m>f))return!1;var d=u.get(e);if(d)return d==t;var h=!0;for(u.set(e,t);++l<f;){var y=e[l],v=t[l];if(r)var g=p?r(v,y,l,t,e,u):r(y,v,l,e,t,u);if(void 0!==g){if(g)continue;h=!1;break}if(c){if(!i(t,function(e){return y===e||n(y,e,r,s,u)})){h=!1;break}}else if(y!==v&&!n(y,v,r,s,u)){h=!1;break}}return u["delete"](e),h}var i=n(369),a=1,o=2;e.exports=r},function(e,t,n){function r(e,t,n,r,i,E,N){switch(n){case T:if(e.byteLength!=t.byteLength||e.byteOffset!=t.byteOffset)return!1;e=e.buffer,t=t.buffer;case S:return e.byteLength==t.byteLength&&r(new a(e),new a(t))?!0:!1;case c:case f:return+e==+t;case m:return e.name==t.name&&e.message==t.message;case h:return e!=+e?t!=+t:e==+t;case y:case g:return e==t+"";case d:var _=s;case v:var M=E&p;if(_||(_=u),e.size!=t.size&&!M)return!1;var w=N.get(e);return w?w==t:(E|=l,N.set(e,t),o(_(e),_(t),r,i,E,N));case A:if(b)return b.call(e)==b.call(t)}return!1}var i=n(370),a=n(371),o=n(356),s=n(372),u=n(373),l=1,p=2,c="[object Boolean]",f="[object Date]",m="[object Error]",d="[object Map]",h="[object Number]",y="[object RegExp]",v="[object Set]",g="[object String]",A="[object Symbol]",S="[object ArrayBuffer]",T="[object DataView]",E=i?i.prototype:void 0,b=E?E.valueOf:void 0;e.exports=r},function(e,t,n){function r(e,t,n,r,s,u){var l=s&o,p=a(e),c=p.length,f=a(t),m=f.length;if(c!=m&&!l)return!1;for(var d=c;d--;){var h=p[d];if(!(l?h in t:i(t,h)))return!1}var y=u.get(e);if(y)return y==t;var v=!0;u.set(e,t);for(var g=l;++d<c;){h=p[d];var A=e[h],S=t[h];if(r)var T=l?r(S,A,h,t,e,u):r(A,S,h,e,t,u);if(!(void 0===T?A===S||n(A,S,r,s,u):T)){v=!1;break}g||(g="constructor"==h)}if(v&&!g){var E=e.constructor,b=t.constructor;E!=b&&"constructor"in e&&"constructor"in t&&!("function"==typeof E&&E instanceof E&&"function"==typeof b&&b instanceof b)&&(v=!1)}return u["delete"](e),v}var i=n(298),a=n(283),o=2;e.exports=r},function(e,t,n){function r(e){var t=!1;if(null!=e&&"function"!=typeof e.toString)try{t=!!(e+"")}catch(n){}return t}e.exports=r},function(e,t,n){function r(e){return a(e)&&i(e.length)&&!!C[P.call(e)]}var i=n(297),a=n(305),o="[object Arguments]",s="[object Array]",u="[object Boolean]",l="[object Date]",p="[object Error]",c="[object Function]",f="[object Map]",m="[object Number]",d="[object Object]",h="[object RegExp]",y="[object Set]",v="[object String]",g="[object WeakMap]",A="[object ArrayBuffer]",S="[object DataView]",T="[object Float32Array]",E="[object Float64Array]",b="[object Int8Array]",N="[object Int16Array]",_="[object Int32Array]",M="[object Uint8Array]",w="[object Uint8ClampedArray]",R="[object Uint16Array]",I="[object Uint32Array]",C={};C[T]=C[E]=C[b]=C[N]=C[_]=C[M]=C[w]=C[R]=C[I]=!0,C[o]=C[s]=C[A]=C[u]=C[S]=C[l]=C[p]=C[c]=C[f]=C[m]=C[d]=C[h]=C[y]=C[v]=C[g]=!1;var L=Object.prototype,P=L.toString;e.exports=r},function(e,t,n){function r(e){return function(t,n,r){for(var i=-1,a=Object(t),o=r(t),s=o.length;s--;){var u=o[e?s:++i];if(n(a[u],u,a)===!1)break}return t}}e.exports=r},function(e,t,n){function r(e,t){var n=i(e,t);return 0>n?void 0:e[n][1]}var i=n(381);e.exports=r},function(e,t,n){function r(e,t){var n=i(e,t);if(0>n)return!1;var r=e.length-1;return n==r?e.pop():o.call(e,n,1),!0}var i=n(381),a=Array.prototype,o=a.splice;e.exports=r},function(e,t,n){var r=n(374),i=n(375),a=/[^.[\]]+|\[(?:(-?\d+(?:\.\d+)?)|(["'])((?:(?!\2)[^\\]|\\.)*?)\2)\]/g,o=/\\(\\)?/g,s=r(function(e){var t=[];return i(e).replace(a,function(e,n,r,i){t.push(r?i.replace(o,"$1"):n||e)}),t});e.exports=s},function(e,t,n){function r(e){var t=-1,n=e?e.length:0;for(this.clear();++t<n;){var r=e[t];this.set(r[0],r[1])}}var i=n(376),a=n(377),o=n(378),s=n(379),u=n(380);r.prototype.clear=i,r.prototype["delete"]=a,r.prototype.get=o,r.prototype.has=s,r.prototype.set=u,e.exports=r},function(e,t,n){function r(e,t,n){var r=i(e,t);0>r?e.push([t,n]):e[r][1]=n}var i=n(381);e.exports=r},function(e,t,n){function r(e,t){return i(e,t)>-1}var i=n(381);e.exports=r},function(e,t,n){function r(e,t){for(var n=-1,r=e.length,i=Array(r);++n<r;)i[n]=t(e[n],n,e);return i}e.exports=r},function(e,t,n){function r(e,t){for(var n=-1,r=e.length;++n<r;)if(t(e[n],n,e))return!0;return!1}e.exports=r},function(e,t,n){var r=n(325),i=r.Symbol;e.exports=i},function(e,t,n){var r=n(325),i=r.Uint8Array;e.exports=i},function(e,t,n){function r(e){var t=-1,n=Array(e.size);return e.forEach(function(e,r){n[++t]=[r,e]}),n}e.exports=r},function(e,t,n){function r(e){var t=-1,n=Array(e.size);return e.forEach(function(e){n[++t]=e}),n}e.exports=r},function(e,t,n){function r(e,t){if("function"!=typeof e||t&&"function"!=typeof t)throw new TypeError(a);var n=function(){var r=arguments,i=t?t.apply(this,r):r[0],a=n.cache;if(a.has(i))return a.get(i);var o=e.apply(this,r);return n.cache=a.set(i,o),o};return n.cache=new(r.Cache||i),n}var i=n(365),a="Expected a function";r.Cache=i,e.exports=r},function(e,t,n){function r(e){if("string"==typeof e)return e;if(null==e)return"";if(a(e))return u?u.call(e):"";var t=e+"";return"0"==t&&1/e==-o?"-0":t}var i=n(370),a=n(346),o=1/0,s=i?i.prototype:void 0,u=s?s.toString:void 0;e.exports=r},function(e,t,n){function r(){this.__data__={hash:new i,map:a?new a:[],string:new i}}var i=n(382),a=n(319);e.exports=r},function(e,t,n){function r(e){var t=this.__data__;return s(e)?o("string"==typeof e?t.string:t.hash,e):i?t.map["delete"](e):a(t.map,e)}var i=n(319),a=n(363),o=n(383),s=n(384);e.exports=r},function(e,t,n){function r(e){var t=this.__data__;return s(e)?o("string"==typeof e?t.string:t.hash,e):i?t.map.get(e):a(t.map,e)}var i=n(319),a=n(362),o=n(387),s=n(384);e.exports=r},function(e,t,n){function r(e){var t=this.__data__;return s(e)?o("string"==typeof e?t.string:t.hash,e):i?t.map.has(e):a(t.map,e)}var i=n(319),a=n(367),o=n(386),s=n(384);e.exports=r},function(e,t,n){function r(e,t){var n=this.__data__;return s(e)?o("string"==typeof e?n.string:n.hash,e,t):i?n.map.set(e,t):a(n.map,e,t),this}var i=n(319),a=n(366),o=n(385),s=n(384);e.exports=r},function(e,t,n){function r(e,t){for(var n=e.length;n--;)if(i(e[n][0],t))return n;return-1}var i=n(295);e.exports=r},function(e,t,n){function r(){}var i=n(388),a=Object.prototype;r.prototype=i?i(null):a,e.exports=r},function(e,t,n){function r(e,t){return i(e,t)&&delete e[t]}var i=n(386);e.exports=r},function(e,t,n){function r(e){var t=typeof e;return"number"==t||"boolean"==t||"string"==t&&"__proto__"!=e||null==e}e.exports=r},function(e,t,n){function r(e,t,n){e[t]=i&&void 0===n?a:n}var i=n(388),a="__lodash_hash_undefined__";e.exports=r},function(e,t,n){function r(e,t){return i?void 0!==e[t]:o.call(e,t)}var i=n(388),a=Object.prototype,o=a.hasOwnProperty;e.exports=r},function(e,t,n){function r(e,t){if(i){var n=e[t];return n===a?void 0:n}return s.call(e,t)?e[t]:void 0}var i=n(388),a="__lodash_hash_undefined__",o=Object.prototype,s=o.hasOwnProperty;e.exports=r},function(e,t,n){var r=n(338),i=r(Object,"create");e.exports=i}])});
// Copyright 2014 Simon Lydell
// X11 (“MIT”) Licensed. (See LICENSE.)

void (function(root, factory) {
  if (typeof define === "function" && define.amd) {
    define(factory)
  } else if (typeof exports === "object") {
    module.exports = factory()
  } else {
    root.resolveUrl = factory()
  }
}(this, function() {

  function resolveUrl(/* ...urls */) {
    var numUrls = arguments.length

    if (numUrls === 0) {
      throw new Error("resolveUrl requires at least one argument; got none.")
    }

    var base = document.createElement("base")
    base.href = arguments[0]

    if (numUrls === 1) {
      return base.href
    }

    var head = document.getElementsByTagName("head")[0]
    head.insertBefore(base, head.firstChild)

    var a = document.createElement("a")
    var resolved

    for (var index = 1; index < numUrls; index++) {
      a.href = arguments[index]
      resolved = a.href
      base.href = resolved
    }

    head.removeChild(base)

    return resolved
  }

  return resolveUrl

}));

/**

JSZip - A Javascript class for generating and reading zip files
<http://stuartk.com/jszip>

(c) 2009-2012 Stuart Knightley <stuart [at] stuartk.com>
Dual licenced under the MIT license or GPLv3. See LICENSE.markdown.

Usage:
   zip = new JSZip();
   zip.file("hello.txt", "Hello, World!").file("tempfile", "nothing");
   zip.folder("images").file("smile.gif", base64Data, {base64: true});
   zip.file("Xmas.txt", "Ho ho ho !", {date : new Date("December 25, 2007 00:00:01")});
   zip.remove("tempfile");

   base64zip = zip.generate();

**/
// We use strict, but it should not be placed outside of a function because
// the environment is shared inside the browser.
// "use strict";

/**
 * Representation a of zip file in js
 * @constructor
 * @param {String=|ArrayBuffer=|Uint8Array=|Buffer=} data the data to load, if any (optional).
 * @param {Object=} options the options for creating this objects (optional).
 */
var JSZip = function(data, options) {
   // object containing the files :
   // {
   //   "folder/" : {...},
   //   "folder/data.txt" : {...}
   // }
   this.files = {};

   // Where we are in the hierarchy
   this.root = "";

   if (data) {
      this.load(data, options);
   }
};

JSZip.signature = {
   LOCAL_FILE_HEADER : "\x50\x4b\x03\x04",
   CENTRAL_FILE_HEADER : "\x50\x4b\x01\x02",
   CENTRAL_DIRECTORY_END : "\x50\x4b\x05\x06",
   ZIP64_CENTRAL_DIRECTORY_LOCATOR : "\x50\x4b\x06\x07",
   ZIP64_CENTRAL_DIRECTORY_END : "\x50\x4b\x06\x06",
   DATA_DESCRIPTOR : "\x50\x4b\x07\x08"
};

// Default properties for a new file
JSZip.defaults = {
   base64: false,
   binary: false,
   dir: false,
   date: null,
   compression: null
};

/*
 * List features that require a modern browser, and if the current browser support them.
 */
JSZip.support = {
   // contains true if JSZip can read/generate ArrayBuffer, false otherwise.
   arraybuffer : (function(){
      return typeof ArrayBuffer !== "undefined" && typeof Uint8Array !== "undefined";
   })(),
   // contains true if JSZip can read/generate nodejs Buffer, false otherwise.
   nodebuffer : (function(){
      return typeof Buffer !== "undefined";
   })(),
   // contains true if JSZip can read/generate Uint8Array, false otherwise.
   uint8array : (function(){
      return typeof Uint8Array !== "undefined";
   })(),
   // contains true if JSZip can read/generate Blob, false otherwise.
   blob : (function(){
      // the spec started with BlobBuilder then replaced it with a construtor for Blob.
      // Result : we have browsers that :
      // * know the BlobBuilder (but with prefix)
      // * know the Blob constructor
      // * know about Blob but not about how to build them
      // About the "=== 0" test : if given the wrong type, it may be converted to a string.
      // Instead of an empty content, we will get "[object Uint8Array]" for example.
      if (typeof ArrayBuffer === "undefined") {
         return false;
      }
      var buffer = new ArrayBuffer(0);
      try {
         return new Blob([buffer], { type: "application/zip" }).size === 0;
      }
      catch(e) {}

      try {
         var BlobBuilder = window.BlobBuilder || window.WebKitBlobBuilder || window.MozBlobBuilder || window.MSBlobBuilder;
         var builder = new BlobBuilder();
         builder.append(buffer);
         return builder.getBlob('application/zip').size === 0;
      }
      catch(e) {}

      return false;
   })()
};

JSZip.prototype = (function () {
   var textEncoder, textDecoder;
   if (
      JSZip.support.uint8array &&
      typeof TextEncoder === "function" &&
      typeof TextDecoder === "function"
   ) {
      textEncoder = new TextEncoder("utf-8");
      textDecoder = new TextDecoder("utf-8");
   }

   /**
    * Returns the raw data of a ZipObject, decompress the content if necessary.
    * @param {ZipObject} file the file to use.
    * @return {String|ArrayBuffer|Uint8Array|Buffer} the data.
    */
   var getRawData = function (file) {
      if (file._data instanceof JSZip.CompressedObject) {
         file._data = file._data.getContent();
         file.options.binary = true;
         file.options.base64 = false;

         if (JSZip.utils.getTypeOf(file._data) === "uint8array") {
            var copy = file._data;
            // when reading an arraybuffer, the CompressedObject mechanism will keep it and subarray() a Uint8Array.
            // if we request a file in the same format, we might get the same Uint8Array or its ArrayBuffer (the original zip file).
            file._data = new Uint8Array(copy.length);
            // with an empty Uint8Array, Opera fails with a "Offset larger than array size"
            if (copy.length !== 0) {
               file._data.set(copy, 0);
            }
         }
      }
      return file._data;
   };

   /**
    * Returns the data of a ZipObject in a binary form. If the content is an unicode string, encode it.
    * @param {ZipObject} file the file to use.
    * @return {String|ArrayBuffer|Uint8Array|Buffer} the data.
    */
   var getBinaryData = function (file) {
      var result = getRawData(file), type = JSZip.utils.getTypeOf(result);
      if (type === "string") {
         if (!file.options.binary) {
            // unicode text !
            // unicode string => binary string is a painful process, check if we can avoid it.
            if (textEncoder) {
               return textEncoder.encode(result);
            }
            if (JSZip.support.nodebuffer) {
               return new Buffer(result, "utf-8");
            }
         }
         return file.asBinary();
      }
      return result;
   };

   /**
    * Transform this._data into a string.
    * @param {function} filter a function String -> String, applied if not null on the result.
    * @return {String} the string representing this._data.
    */
   var dataToString = function (asUTF8) {
      var result = getRawData(this);
      if (result === null || typeof result === "undefined") {
         return "";
      }
      // if the data is a base64 string, we decode it before checking the encoding !
      if (this.options.base64) {
         result = JSZip.base64.decode(result);
      }
      if (asUTF8 && this.options.binary) {
         // JSZip.prototype.utf8decode supports arrays as input
         // skip to array => string step, utf8decode will do it.
         result = JSZip.prototype.utf8decode(result);
      } else {
         // no utf8 transformation, do the array => string step.
         result = JSZip.utils.transformTo("string", result);
      }

      if (!asUTF8 && !this.options.binary) {
         result = JSZip.prototype.utf8encode(result);
      }
      return result;
   };
   /**
    * A simple object representing a file in the zip file.
    * @constructor
    * @param {string} name the name of the file
    * @param {String|ArrayBuffer|Uint8Array|Buffer} data the data
    * @param {Object} options the options of the file
    */
   var ZipObject = function (name, data, options) {
      this.name = name;
      this._data = data;
      this.options = options;
   };

   ZipObject.prototype = {
      /**
       * Return the content as UTF8 string.
       * @return {string} the UTF8 string.
       */
      asText : function () {
         return dataToString.call(this, true);
      },
      /**
       * Returns the binary content.
       * @return {string} the content as binary.
       */
      asBinary : function () {
         return dataToString.call(this, false);
      },
      /**
       * Returns the content as a nodejs Buffer.
       * @return {Buffer} the content as a Buffer.
       */
      asNodeBuffer : function () {
         var result = getBinaryData(this);
         return JSZip.utils.transformTo("nodebuffer", result);
      },
      /**
       * Returns the content as an Uint8Array.
       * @return {Uint8Array} the content as an Uint8Array.
       */
      asUint8Array : function () {
         var result = getBinaryData(this);
         return JSZip.utils.transformTo("uint8array", result);
      },
      /**
       * Returns the content as an ArrayBuffer.
       * @return {ArrayBuffer} the content as an ArrayBufer.
       */
      asArrayBuffer : function () {
         return this.asUint8Array().buffer;
      }
   };

   /**
    * Transform an integer into a string in hexadecimal.
    * @private
    * @param {number} dec the number to convert.
    * @param {number} bytes the number of bytes to generate.
    * @returns {string} the result.
    */
   var decToHex = function(dec, bytes) {
      var hex = "", i;
      for(i = 0; i < bytes; i++) {
         hex += String.fromCharCode(dec&0xff);
         dec=dec>>>8;
      }
      return hex;
   };

   /**
    * Merge the objects passed as parameters into a new one.
    * @private
    * @param {...Object} var_args All objects to merge.
    * @return {Object} a new object with the data of the others.
    */
   var extend = function () {
      var result = {}, i, attr;
      for (i = 0; i < arguments.length; i++) { // arguments is not enumerable in some browsers
         for (attr in arguments[i]) {
            if (arguments[i].hasOwnProperty(attr) && typeof result[attr] === "undefined") {
               result[attr] = arguments[i][attr];
            }
         }
      }
      return result;
   };

   /**
    * Transforms the (incomplete) options from the user into the complete
    * set of options to create a file.
    * @private
    * @param {Object} o the options from the user.
    * @return {Object} the complete set of options.
    */
   var prepareFileAttrs = function (o) {
      o = o || {};
      /*jshint -W041 */
      if (o.base64 === true && o.binary == null) {
         o.binary = true;
      }
      /*jshint +W041 */
      o = extend(o, JSZip.defaults);
      o.date = o.date || new Date();
      if (o.compression !== null) o.compression = o.compression.toUpperCase();

      return o;
   };

   /**
    * Add a file in the current folder.
    * @private
    * @param {string} name the name of the file
    * @param {String|ArrayBuffer|Uint8Array|Buffer} data the data of the file
    * @param {Object} o the options of the file
    * @return {Object} the new file.
    */
   var fileAdd = function (name, data, o) {
      // be sure sub folders exist
      var parent = parentFolder(name), dataType = JSZip.utils.getTypeOf(data);
      if (parent) {
         folderAdd.call(this, parent);
      }

      o = prepareFileAttrs(o);

      if (o.dir || data === null || typeof data === "undefined") {
         o.base64 = false;
         o.binary = false;
         data = null;
      } else if (dataType === "string") {
         if (o.binary && !o.base64) {
            // optimizedBinaryString == true means that the file has already been filtered with a 0xFF mask
            if (o.optimizedBinaryString !== true) {
               // this is a string, not in a base64 format.
               // Be sure that this is a correct "binary string"
               data = JSZip.utils.string2binary(data);
            }
         }
      } else { // arraybuffer, uint8array, ...
         o.base64 = false;
         o.binary = true;

         if (!dataType && !(data instanceof JSZip.CompressedObject)) {
            throw new Error("The data of '" + name + "' is in an unsupported format !");
         }

         // special case : it's way easier to work with Uint8Array than with ArrayBuffer
         if (dataType === "arraybuffer") {
            data = JSZip.utils.transformTo("uint8array", data);
         }
      }

      var object = new ZipObject(name, data, o);
      this.files[name] = object;
      return object;
   };


   /**
    * Find the parent folder of the path.
    * @private
    * @param {string} path the path to use
    * @return {string} the parent folder, or ""
    */
   var parentFolder = function (path) {
      if (path.slice(-1) == '/') {
         path = path.substring(0, path.length - 1);
      }
      var lastSlash = path.lastIndexOf('/');
      return (lastSlash > 0) ? path.substring(0, lastSlash) : "";
   };

   /**
    * Add a (sub) folder in the current folder.
    * @private
    * @param {string} name the folder's name
    * @return {Object} the new folder.
    */
   var folderAdd = function (name) {
      // Check the name ends with a /
      if (name.slice(-1) != "/") {
         name += "/"; // IE doesn't like substr(-1)
      }

      // Does this folder already exist?
      if (!this.files[name]) {
         fileAdd.call(this, name, null, {dir:true});
      }
      return this.files[name];
   };

   /**
    * Generate a JSZip.CompressedObject for a given zipOject.
    * @param {ZipObject} file the object to read.
    * @param {JSZip.compression} compression the compression to use.
    * @return {JSZip.CompressedObject} the compressed result.
    */
   var generateCompressedObjectFrom = function (file, compression) {
      var result = new JSZip.CompressedObject(), content;

      // the data has not been decompressed, we might reuse things !
      if (file._data instanceof JSZip.CompressedObject) {
         result.uncompressedSize = file._data.uncompressedSize;
         result.crc32 = file._data.crc32;

         if (result.uncompressedSize === 0 || file.options.dir) {
            compression = JSZip.compressions['STORE'];
            result.compressedContent = "";
            result.crc32 = 0;
         } else if (file._data.compressionMethod === compression.magic) {
            result.compressedContent = file._data.getCompressedContent();
         } else {
            content = file._data.getContent();
            // need to decompress / recompress
            result.compressedContent = compression.compress(JSZip.utils.transformTo(compression.compressInputType, content));
         }
      } else {
         // have uncompressed data
         content = getBinaryData(file);
         if (!content || content.length === 0 || file.options.dir) {
            compression = JSZip.compressions['STORE'];
            content = "";
         }
         result.uncompressedSize = content.length;
         result.crc32 = this.crc32(content);
         result.compressedContent = compression.compress(JSZip.utils.transformTo(compression.compressInputType, content));
      }

      result.compressedSize = result.compressedContent.length;
      result.compressionMethod = compression.magic;

      return result;
   };

   /**
    * Generate the various parts used in the construction of the final zip file.
    * @param {string} name the file name.
    * @param {ZipObject} file the file content.
    * @param {JSZip.CompressedObject} compressedObject the compressed object.
    * @param {number} offset the current offset from the start of the zip file.
    * @return {object} the zip parts.
    */
   var generateZipParts = function(name, file, compressedObject, offset) {
      var data = compressedObject.compressedContent,
          utfEncodedFileName = this.utf8encode(file.name),
          useUTF8 = utfEncodedFileName !== file.name,
          o       = file.options,
          dosTime,
          dosDate;

      // date
      // @see http://www.delorie.com/djgpp/doc/rbinter/it/52/13.html
      // @see http://www.delorie.com/djgpp/doc/rbinter/it/65/16.html
      // @see http://www.delorie.com/djgpp/doc/rbinter/it/66/16.html

      dosTime = o.date.getHours();
      dosTime = dosTime << 6;
      dosTime = dosTime | o.date.getMinutes();
      dosTime = dosTime << 5;
      dosTime = dosTime | o.date.getSeconds() / 2;

      dosDate = o.date.getFullYear() - 1980;
      dosDate = dosDate << 4;
      dosDate = dosDate | (o.date.getMonth() + 1);
      dosDate = dosDate << 5;
      dosDate = dosDate | o.date.getDate();


      var header = "";

      // version needed to extract
      header += "\x0A\x00";
      // general purpose bit flag
      // set bit 11 if utf8
      header += useUTF8 ? "\x00\x08" : "\x00\x00";
      // compression method
      header += compressedObject.compressionMethod;
      // last mod file time
      header += decToHex(dosTime, 2);
      // last mod file date
      header += decToHex(dosDate, 2);
      // crc-32
      header += decToHex(compressedObject.crc32, 4);
      // compressed size
      header += decToHex(compressedObject.compressedSize, 4);
      // uncompressed size
      header += decToHex(compressedObject.uncompressedSize, 4);
      // file name length
      header += decToHex(utfEncodedFileName.length, 2);
      // extra field length
      header += "\x00\x00";


      var fileRecord = JSZip.signature.LOCAL_FILE_HEADER + header + utfEncodedFileName;

      var dirRecord = JSZip.signature.CENTRAL_FILE_HEADER +
      // version made by (00: DOS)
      "\x14\x00" +
      // file header (common to file and central directory)
      header +
      // file comment length
      "\x00\x00" +
      // disk number start
      "\x00\x00" +
      // internal file attributes TODO
      "\x00\x00" +
      // external file attributes
      (file.options.dir===true?"\x10\x00\x00\x00":"\x00\x00\x00\x00")+
      // relative offset of local header
      decToHex(offset, 4) +
      // file name
      utfEncodedFileName;


      return {
         fileRecord : fileRecord,
         dirRecord : dirRecord,
         compressedObject : compressedObject
      };
   };

   /**
    * An object to write any content to a string.
    * @constructor
    */
   var StringWriter = function () {
      this.data = [];
   };
   StringWriter.prototype = {
      /**
       * Append any content to the current string.
       * @param {Object} input the content to add.
       */
      append : function (input) {
         input = JSZip.utils.transformTo("string", input);
         this.data.push(input);
      },
      /**
       * Finalize the construction an return the result.
       * @return {string} the generated string.
       */
      finalize : function () {
         return this.data.join("");
      }
   };
   /**
    * An object to write any content to an Uint8Array.
    * @constructor
    * @param {number} length The length of the array.
    */
   var Uint8ArrayWriter = function (length) {
      this.data = new Uint8Array(length);
      this.index = 0;
   };
   Uint8ArrayWriter.prototype = {
      /**
       * Append any content to the current array.
       * @param {Object} input the content to add.
       */
      append : function (input) {
         if (input.length !== 0) {
            // with an empty Uint8Array, Opera fails with a "Offset larger than array size"
            input = JSZip.utils.transformTo("uint8array", input);
            this.data.set(input, this.index);
            this.index += input.length;
         }
      },
      /**
       * Finalize the construction an return the result.
       * @return {Uint8Array} the generated array.
       */
      finalize : function () {
         return this.data;
      }
   };

   // return the actual prototype of JSZip
   return {
      /**
       * Read an existing zip and merge the data in the current JSZip object.
       * The implementation is in jszip-load.js, don't forget to include it.
       * @param {String|ArrayBuffer|Uint8Array|Buffer} stream  The stream to load
       * @param {Object} options Options for loading the stream.
       *  options.base64 : is the stream in base64 ? default : false
       * @return {JSZip} the current JSZip object
       */
      load : function (stream, options) {
         throw new Error("Load method is not defined. Is the file jszip-load.js included ?");
      },

      /**
       * Filter nested files/folders with the specified function.
       * @param {Function} search the predicate to use :
       * function (relativePath, file) {...}
       * It takes 2 arguments : the relative path and the file.
       * @return {Array} An array of matching elements.
       */
      filter : function (search) {
         var result = [], filename, relativePath, file, fileClone;
         for (filename in this.files) {
            if ( !this.files.hasOwnProperty(filename) ) { continue; }
            file = this.files[filename];
            // return a new object, don't let the user mess with our internal objects :)
            fileClone = new ZipObject(file.name, file._data, extend(file.options));
            relativePath = filename.slice(this.root.length, filename.length);
            if (filename.slice(0, this.root.length) === this.root && // the file is in the current root
                search(relativePath, fileClone)) { // and the file matches the function
               result.push(fileClone);
            }
         }
         return result;
      },

      /**
       * Add a file to the zip file, or search a file.
       * @param   {string|RegExp} name The name of the file to add (if data is defined),
       * the name of the file to find (if no data) or a regex to match files.
       * @param   {String|ArrayBuffer|Uint8Array|Buffer} data  The file data, either raw or base64 encoded
       * @param   {Object} o     File options
       * @return  {JSZip|Object|Array} this JSZip object (when adding a file),
       * a file (when searching by string) or an array of files (when searching by regex).
       */
      file : function(name, data, o) {
         if (arguments.length === 1) {
            if (JSZip.utils.isRegExp(name)) {
               var regexp = name;
               return this.filter(function(relativePath, file) {
                  return !file.options.dir && regexp.test(relativePath);
               });
            } else { // text
               return this.filter(function (relativePath, file) {
                  return !file.options.dir && relativePath === name;
               })[0]||null;
            }
         } else { // more than one argument : we have data !
            name = this.root+name;
            fileAdd.call(this, name, data, o);
         }
         return this;
      },

      /**
       * Add a directory to the zip file, or search.
       * @param   {String|RegExp} arg The name of the directory to add, or a regex to search folders.
       * @return  {JSZip} an object with the new directory as the root, or an array containing matching folders.
       */
      folder : function(arg) {
         if (!arg) {
            return this;
         }

         if (JSZip.utils.isRegExp(arg)) {
            return this.filter(function(relativePath, file) {
               return file.options.dir && arg.test(relativePath);
            });
         }

         // else, name is a new folder
         var name = this.root + arg;
         var newFolder = folderAdd.call(this, name);

         // Allow chaining by returning a new object with this folder as the root
         var ret = this.clone();
         ret.root = newFolder.name;
         return ret;
      },

      /**
       * Delete a file, or a directory and all sub-files, from the zip
       * @param {string} name the name of the file to delete
       * @return {JSZip} this JSZip object
       */
      remove : function(name) {
         name = this.root + name;
         var file = this.files[name];
         if (!file) {
            // Look for any folders
            if (name.slice(-1) != "/") {
               name += "/";
            }
            file = this.files[name];
         }

         if (file) {
            if (!file.options.dir) {
               // file
               delete this.files[name];
            } else {
               // folder
               var kids = this.filter(function (relativePath, file) {
                  return file.name.slice(0, name.length) === name;
               });
               for (var i = 0; i < kids.length; i++) {
                  delete this.files[kids[i].name];
               }
            }
         }

         return this;
      },

      /**
       * Generate the complete zip file
       * @param {Object} options the options to generate the zip file :
       * - base64, (deprecated, use type instead) true to generate base64.
       * - compression, "STORE" by default.
       * - type, "base64" by default. Values are : string, base64, uint8array, arraybuffer, blob.
       * @return {String|Uint8Array|ArrayBuffer|Buffer|Blob} the zip file
       */
      generate : function(options) {
         options = extend(options || {}, {
            base64 : true,
            compression : "STORE",
            type : "base64"
         });

         JSZip.utils.checkSupport(options.type);

         var zipData = [], localDirLength = 0, centralDirLength = 0, writer, i;


         // first, generate all the zip parts.
         for (var name in this.files) {
            if ( !this.files.hasOwnProperty(name) ) { continue; }
            var file = this.files[name];

            var compressionName = file.options.compression || options.compression.toUpperCase();
            var compression = JSZip.compressions[compressionName];
            if (!compression) {
               throw new Error(compressionName + " is not a valid compression method !");
            }

            var compressedObject = generateCompressedObjectFrom.call(this, file, compression);

            var zipPart = generateZipParts.call(this, name, file, compressedObject, localDirLength);
            localDirLength += zipPart.fileRecord.length + compressedObject.compressedSize;
            centralDirLength += zipPart.dirRecord.length;
            zipData.push(zipPart);
         }

         var dirEnd = "";

         // end of central dir signature
         dirEnd = JSZip.signature.CENTRAL_DIRECTORY_END +
         // number of this disk
         "\x00\x00" +
         // number of the disk with the start of the central directory
         "\x00\x00" +
         // total number of entries in the central directory on this disk
         decToHex(zipData.length, 2) +
         // total number of entries in the central directory
         decToHex(zipData.length, 2) +
         // size of the central directory   4 bytes
         decToHex(centralDirLength, 4) +
         // offset of start of central directory with respect to the starting disk number
         decToHex(localDirLength, 4) +
         // .ZIP file comment length
         "\x00\x00";


         // we have all the parts (and the total length)
         // time to create a writer !
         switch(options.type.toLowerCase()) {
            case "uint8array" :
            case "arraybuffer" :
            case "blob" :
            case "nodebuffer" :
               writer = new Uint8ArrayWriter(localDirLength + centralDirLength + dirEnd.length);
               break;
            // case "base64" :
            // case "string" :
            default :
               writer = new StringWriter(localDirLength + centralDirLength + dirEnd.length);
               break;
         }

         for (i = 0; i < zipData.length; i++) {
            writer.append(zipData[i].fileRecord);
            writer.append(zipData[i].compressedObject.compressedContent);
         }
         for (i = 0; i < zipData.length; i++) {
            writer.append(zipData[i].dirRecord);
         }

         writer.append(dirEnd);

         var zip = writer.finalize();



         switch(options.type.toLowerCase()) {
            // case "zip is an Uint8Array"
            case "uint8array" :
            case "arraybuffer" :
            case "nodebuffer" :
               return JSZip.utils.transformTo(options.type.toLowerCase(), zip);
            case "blob" :
               return JSZip.utils.arrayBuffer2Blob(JSZip.utils.transformTo("arraybuffer", zip));

            // case "zip is a string"
            case "base64" :
               return (options.base64) ? JSZip.base64.encode(zip) : zip;
            default : // case "string" :
               return zip;
         }
      },

      /**
       *
       *  Javascript crc32
       *  http://www.webtoolkit.info/
       *
       */
      crc32 : function crc32(input, crc) {
         if (typeof input === "undefined" || !input.length) {
            return 0;
         }

         var isArray = JSZip.utils.getTypeOf(input) !== "string";

         var table = [
            0x00000000, 0x77073096, 0xEE0E612C, 0x990951BA,
            0x076DC419, 0x706AF48F, 0xE963A535, 0x9E6495A3,
            0x0EDB8832, 0x79DCB8A4, 0xE0D5E91E, 0x97D2D988,
            0x09B64C2B, 0x7EB17CBD, 0xE7B82D07, 0x90BF1D91,
            0x1DB71064, 0x6AB020F2, 0xF3B97148, 0x84BE41DE,
            0x1ADAD47D, 0x6DDDE4EB, 0xF4D4B551, 0x83D385C7,
            0x136C9856, 0x646BA8C0, 0xFD62F97A, 0x8A65C9EC,
            0x14015C4F, 0x63066CD9, 0xFA0F3D63, 0x8D080DF5,
            0x3B6E20C8, 0x4C69105E, 0xD56041E4, 0xA2677172,
            0x3C03E4D1, 0x4B04D447, 0xD20D85FD, 0xA50AB56B,
            0x35B5A8FA, 0x42B2986C, 0xDBBBC9D6, 0xACBCF940,
            0x32D86CE3, 0x45DF5C75, 0xDCD60DCF, 0xABD13D59,
            0x26D930AC, 0x51DE003A, 0xC8D75180, 0xBFD06116,
            0x21B4F4B5, 0x56B3C423, 0xCFBA9599, 0xB8BDA50F,
            0x2802B89E, 0x5F058808, 0xC60CD9B2, 0xB10BE924,
            0x2F6F7C87, 0x58684C11, 0xC1611DAB, 0xB6662D3D,
            0x76DC4190, 0x01DB7106, 0x98D220BC, 0xEFD5102A,
            0x71B18589, 0x06B6B51F, 0x9FBFE4A5, 0xE8B8D433,
            0x7807C9A2, 0x0F00F934, 0x9609A88E, 0xE10E9818,
            0x7F6A0DBB, 0x086D3D2D, 0x91646C97, 0xE6635C01,
            0x6B6B51F4, 0x1C6C6162, 0x856530D8, 0xF262004E,
            0x6C0695ED, 0x1B01A57B, 0x8208F4C1, 0xF50FC457,
            0x65B0D9C6, 0x12B7E950, 0x8BBEB8EA, 0xFCB9887C,
            0x62DD1DDF, 0x15DA2D49, 0x8CD37CF3, 0xFBD44C65,
            0x4DB26158, 0x3AB551CE, 0xA3BC0074, 0xD4BB30E2,
            0x4ADFA541, 0x3DD895D7, 0xA4D1C46D, 0xD3D6F4FB,
            0x4369E96A, 0x346ED9FC, 0xAD678846, 0xDA60B8D0,
            0x44042D73, 0x33031DE5, 0xAA0A4C5F, 0xDD0D7CC9,
            0x5005713C, 0x270241AA, 0xBE0B1010, 0xC90C2086,
            0x5768B525, 0x206F85B3, 0xB966D409, 0xCE61E49F,
            0x5EDEF90E, 0x29D9C998, 0xB0D09822, 0xC7D7A8B4,
            0x59B33D17, 0x2EB40D81, 0xB7BD5C3B, 0xC0BA6CAD,
            0xEDB88320, 0x9ABFB3B6, 0x03B6E20C, 0x74B1D29A,
            0xEAD54739, 0x9DD277AF, 0x04DB2615, 0x73DC1683,
            0xE3630B12, 0x94643B84, 0x0D6D6A3E, 0x7A6A5AA8,
            0xE40ECF0B, 0x9309FF9D, 0x0A00AE27, 0x7D079EB1,
            0xF00F9344, 0x8708A3D2, 0x1E01F268, 0x6906C2FE,
            0xF762575D, 0x806567CB, 0x196C3671, 0x6E6B06E7,
            0xFED41B76, 0x89D32BE0, 0x10DA7A5A, 0x67DD4ACC,
            0xF9B9DF6F, 0x8EBEEFF9, 0x17B7BE43, 0x60B08ED5,
            0xD6D6A3E8, 0xA1D1937E, 0x38D8C2C4, 0x4FDFF252,
            0xD1BB67F1, 0xA6BC5767, 0x3FB506DD, 0x48B2364B,
            0xD80D2BDA, 0xAF0A1B4C, 0x36034AF6, 0x41047A60,
            0xDF60EFC3, 0xA867DF55, 0x316E8EEF, 0x4669BE79,
            0xCB61B38C, 0xBC66831A, 0x256FD2A0, 0x5268E236,
            0xCC0C7795, 0xBB0B4703, 0x220216B9, 0x5505262F,
            0xC5BA3BBE, 0xB2BD0B28, 0x2BB45A92, 0x5CB36A04,
            0xC2D7FFA7, 0xB5D0CF31, 0x2CD99E8B, 0x5BDEAE1D,
            0x9B64C2B0, 0xEC63F226, 0x756AA39C, 0x026D930A,
            0x9C0906A9, 0xEB0E363F, 0x72076785, 0x05005713,
            0x95BF4A82, 0xE2B87A14, 0x7BB12BAE, 0x0CB61B38,
            0x92D28E9B, 0xE5D5BE0D, 0x7CDCEFB7, 0x0BDBDF21,
            0x86D3D2D4, 0xF1D4E242, 0x68DDB3F8, 0x1FDA836E,
            0x81BE16CD, 0xF6B9265B, 0x6FB077E1, 0x18B74777,
            0x88085AE6, 0xFF0F6A70, 0x66063BCA, 0x11010B5C,
            0x8F659EFF, 0xF862AE69, 0x616BFFD3, 0x166CCF45,
            0xA00AE278, 0xD70DD2EE, 0x4E048354, 0x3903B3C2,
            0xA7672661, 0xD06016F7, 0x4969474D, 0x3E6E77DB,
            0xAED16A4A, 0xD9D65ADC, 0x40DF0B66, 0x37D83BF0,
            0xA9BCAE53, 0xDEBB9EC5, 0x47B2CF7F, 0x30B5FFE9,
            0xBDBDF21C, 0xCABAC28A, 0x53B39330, 0x24B4A3A6,
            0xBAD03605, 0xCDD70693, 0x54DE5729, 0x23D967BF,
            0xB3667A2E, 0xC4614AB8, 0x5D681B02, 0x2A6F2B94,
            0xB40BBE37, 0xC30C8EA1, 0x5A05DF1B, 0x2D02EF8D
         ];

         if (typeof(crc) == "undefined") { crc = 0; }
         var x = 0;
         var y = 0;
         var byte = 0;

         crc = crc ^ (-1);
         for( var i = 0, iTop = input.length; i < iTop; i++ ) {
            byte = isArray ? input[i] : input.charCodeAt(i);
            y = ( crc ^ byte ) & 0xFF;
            x = table[y];
            crc = ( crc >>> 8 ) ^ x;
         }

         return crc ^ (-1);
      },

      // Inspired by http://my.opera.com/GreyWyvern/blog/show.dml/1725165
      clone : function() {
         var newObj = new JSZip();
         for (var i in this) {
            if (typeof this[i] !== "function") {
               newObj[i] = this[i];
            }
         }
         return newObj;
      },


      /**
       * http://www.webtoolkit.info/javascript-utf8.html
       */
      utf8encode : function (string) {
         // TextEncoder + Uint8Array to binary string is faster than checking every bytes on long strings.
         // http://jsperf.com/utf8encode-vs-textencoder
         // On short strings (file names for example), the TextEncoder API is (currently) slower.
         if (textEncoder) {
            var u8 = textEncoder.encode(string);
            return JSZip.utils.transformTo("string", u8);
         }
         if (JSZip.support.nodebuffer) {
            return JSZip.utils.transformTo("string", new Buffer(string, "utf-8"));
         }

         // array.join may be slower than string concatenation but generates less objects (less time spent garbage collecting).
         // See also http://jsperf.com/array-direct-assignment-vs-push/31
         var result = [], resIndex = 0;

         for (var n = 0; n < string.length; n++) {

            var c = string.charCodeAt(n);

            if (c < 128) {
               result[resIndex++] = String.fromCharCode(c);
            } else if ((c > 127) && (c < 2048)) {
               result[resIndex++] = String.fromCharCode((c >> 6) | 192);
               result[resIndex++] = String.fromCharCode((c & 63) | 128);
            } else {
               result[resIndex++] = String.fromCharCode((c >> 12) | 224);
               result[resIndex++] = String.fromCharCode(((c >> 6) & 63) | 128);
               result[resIndex++] = String.fromCharCode((c & 63) | 128);
            }

         }

         return result.join("");
      },

      /**
       * http://www.webtoolkit.info/javascript-utf8.html
       */
      utf8decode : function (input) {
         var result = [], resIndex = 0;
         var type = JSZip.utils.getTypeOf(input);
         var isArray = type !== "string";
         var i = 0;
         var c = 0, c1 = 0, c2 = 0, c3 = 0;

         // check if we can use the TextDecoder API
         // see http://encoding.spec.whatwg.org/#api
         if (textDecoder) {
            return textDecoder.decode(
               JSZip.utils.transformTo("uint8array", input)
            );
         }
         if (JSZip.support.nodebuffer) {
            return JSZip.utils.transformTo("nodebuffer", input).toString("utf-8");
         }

         while ( i < input.length ) {

            c = isArray ? input[i] : input.charCodeAt(i);

            if (c < 128) {
               result[resIndex++] = String.fromCharCode(c);
               i++;
            } else if ((c > 191) && (c < 224)) {
               c2 = isArray ? input[i+1] : input.charCodeAt(i+1);
               result[resIndex++] = String.fromCharCode(((c & 31) << 6) | (c2 & 63));
               i += 2;
            } else {
               c2 = isArray ? input[i+1] : input.charCodeAt(i+1);
               c3 = isArray ? input[i+2] : input.charCodeAt(i+2);
               result[resIndex++] = String.fromCharCode(((c & 15) << 12) | ((c2 & 63) << 6) | (c3 & 63));
               i += 3;
            }

         }

         return result.join("");
      }
   };
}());

/*
 * Compression methods
 * This object is filled in as follow :
 * name : {
 *    magic // the 2 bytes indentifying the compression method
 *    compress // function, take the uncompressed content and return it compressed.
 *    uncompress // function, take the compressed content and return it uncompressed.
 *    compressInputType // string, the type accepted by the compress method. null to accept everything.
 *    uncompressInputType // string, the type accepted by the uncompress method. null to accept everything.
 * }
 *
 * STORE is the default compression method, so it's included in this file.
 * Other methods should go to separated files : the user wants modularity.
 */
JSZip.compressions = {
   "STORE" : {
      magic : "\x00\x00",
      compress : function (content) {
         return content; // no compression
      },
      uncompress : function (content) {
         return content; // no compression
      },
      compressInputType : null,
      uncompressInputType : null
   }
};

(function () {
   JSZip.utils = {
      /**
       * Convert a string to a "binary string" : a string containing only char codes between 0 and 255.
       * @param {string} str the string to transform.
       * @return {String} the binary string.
       */
      string2binary : function (str) {
         var result = "";
         for (var i = 0; i < str.length; i++) {
            result += String.fromCharCode(str.charCodeAt(i) & 0xff);
         }
         return result;
      },
      /**
       * Create a Uint8Array from the string.
       * @param {string} str the string to transform.
       * @return {Uint8Array} the typed array.
       * @throws {Error} an Error if the browser doesn't support the requested feature.
       * @deprecated : use JSZip.utils.transformTo instead.
       */
      string2Uint8Array : function (str) {
         return JSZip.utils.transformTo("uint8array", str);
      },

      /**
       * Create a string from the Uint8Array.
       * @param {Uint8Array} array the array to transform.
       * @return {string} the string.
       * @throws {Error} an Error if the browser doesn't support the requested feature.
       * @deprecated : use JSZip.utils.transformTo instead.
       */
      uint8Array2String : function (array) {
         return JSZip.utils.transformTo("string", array);
      },
      /**
       * Create a blob from the given ArrayBuffer.
       * @param {ArrayBuffer} buffer the buffer to transform.
       * @return {Blob} the result.
       * @throws {Error} an Error if the browser doesn't support the requested feature.
       */
      arrayBuffer2Blob : function (buffer) {
         JSZip.utils.checkSupport("blob");

         try {
            // Blob constructor
            return new Blob([buffer], { type: "application/zip" });
         }
         catch(e) {}

         try {
            // deprecated, browser only, old way
            var BlobBuilder = window.BlobBuilder || window.WebKitBlobBuilder || window.MozBlobBuilder || window.MSBlobBuilder;
            var builder = new BlobBuilder();
            builder.append(buffer);
            return builder.getBlob('application/zip');
         }
         catch(e) {}

         // well, fuck ?!
         throw new Error("Bug : can't construct the Blob.");
      },
      /**
       * Create a blob from the given string.
       * @param {string} str the string to transform.
       * @return {Blob} the result.
       * @throws {Error} an Error if the browser doesn't support the requested feature.
       */
      string2Blob : function (str) {
         var buffer = JSZip.utils.transformTo("arraybuffer", str);
         return JSZip.utils.arrayBuffer2Blob(buffer);
      }
   };

   /**
    * The identity function.
    * @param {Object} input the input.
    * @return {Object} the same input.
    */
   function identity(input) {
      return input;
   }

   /**
    * Fill in an array with a string.
    * @param {String} str the string to use.
    * @param {Array|ArrayBuffer|Uint8Array|Buffer} array the array to fill in (will be mutated).
    * @return {Array|ArrayBuffer|Uint8Array|Buffer} the updated array.
    */
   function stringToArrayLike(str, array) {
      for (var i = 0; i < str.length; ++i) {
         array[i] = str.charCodeAt(i) & 0xFF;
      }
      return array;
   }

   /**
    * Transform an array-like object to a string.
    * @param {Array|ArrayBuffer|Uint8Array|Buffer} array the array to transform.
    * @return {String} the result.
    */
   function arrayLikeToString(array) {
      // Performances notes :
      // --------------------
      // String.fromCharCode.apply(null, array) is the fastest, see
      // see http://jsperf.com/converting-a-uint8array-to-a-string/2
      // but the stack is limited (and we can get huge arrays !).
      //
      // result += String.fromCharCode(array[i]); generate too many strings !
      //
      // This code is inspired by http://jsperf.com/arraybuffer-to-string-apply-performance/2
      var chunk = 65536;
      var result = [], len = array.length, type = JSZip.utils.getTypeOf(array), k = 0;

      var canUseApply = true;
      try {
         switch(type) {
            case "uint8array":
               String.fromCharCode.apply(null, new Uint8Array(0));
               break;
            case "nodebuffer":
               String.fromCharCode.apply(null, new Buffer(0));
               break;
         }
      } catch(e) {
         canUseApply = false;
      }

      // no apply : slow and painful algorithm
      // default browser on android 4.*
      if (!canUseApply) {
         var resultStr = "";
         for(var i = 0; i < array.length;i++) {
            resultStr += String.fromCharCode(array[i]);
         }
         return resultStr;
      }

      while (k < len && chunk > 1) {
         try {
            if (type === "array" || type === "nodebuffer") {
               result.push(String.fromCharCode.apply(null, array.slice(k, Math.min(k + chunk, len))));
            } else {
               result.push(String.fromCharCode.apply(null, array.subarray(k, Math.min(k + chunk, len))));
            }
            k += chunk;
         } catch (e) {
            chunk = Math.floor(chunk / 2);
         }
      }
      return result.join("");
   }

   /**
    * Copy the data from an array-like to an other array-like.
    * @param {Array|ArrayBuffer|Uint8Array|Buffer} arrayFrom the origin array.
    * @param {Array|ArrayBuffer|Uint8Array|Buffer} arrayTo the destination array which will be mutated.
    * @return {Array|ArrayBuffer|Uint8Array|Buffer} the updated destination array.
    */
   function arrayLikeToArrayLike(arrayFrom, arrayTo) {
      for(var i = 0; i < arrayFrom.length; i++) {
         arrayTo[i] = arrayFrom[i];
      }
      return arrayTo;
   }

   // a matrix containing functions to transform everything into everything.
   var transform = {};

   // string to ?
   transform["string"] = {
      "string" : identity,
      "array" : function (input) {
         return stringToArrayLike(input, new Array(input.length));
      },
      "arraybuffer" : function (input) {
         return transform["string"]["uint8array"](input).buffer;
      },
      "uint8array" : function (input) {
         return stringToArrayLike(input, new Uint8Array(input.length));
      },
      "nodebuffer" : function (input) {
         return stringToArrayLike(input, new Buffer(input.length));
      }
   };

   // array to ?
   transform["array"] = {
      "string" : arrayLikeToString,
      "array" : identity,
      "arraybuffer" : function (input) {
         return (new Uint8Array(input)).buffer;
      },
      "uint8array" : function (input) {
         return new Uint8Array(input);
      },
      "nodebuffer" : function (input) {
         return new Buffer(input);
      }
   };

   // arraybuffer to ?
   transform["arraybuffer"] = {
      "string" : function (input) {
         return arrayLikeToString(new Uint8Array(input));
      },
      "array" : function (input) {
         return arrayLikeToArrayLike(new Uint8Array(input), new Array(input.byteLength));
      },
      "arraybuffer" : identity,
      "uint8array" : function (input) {
         return new Uint8Array(input);
      },
      "nodebuffer" : function (input) {
         return new Buffer(new Uint8Array(input));
      }
   };

   // uint8array to ?
   transform["uint8array"] = {
      "string" : arrayLikeToString,
      "array" : function (input) {
         return arrayLikeToArrayLike(input, new Array(input.length));
      },
      "arraybuffer" : function (input) {
         return input.buffer;
      },
      "uint8array" : identity,
      "nodebuffer" : function(input) {
         return new Buffer(input);
      }
   };

   // nodebuffer to ?
   transform["nodebuffer"] = {
      "string" : arrayLikeToString,
      "array" : function (input) {
         return arrayLikeToArrayLike(input, new Array(input.length));
      },
      "arraybuffer" : function (input) {
         return transform["nodebuffer"]["uint8array"](input).buffer;
      },
      "uint8array" : function (input) {
         return arrayLikeToArrayLike(input, new Uint8Array(input.length));
      },
      "nodebuffer" : identity
   };

   /**
    * Transform an input into any type.
    * The supported output type are : string, array, uint8array, arraybuffer, nodebuffer.
    * If no output type is specified, the unmodified input will be returned.
    * @param {String} outputType the output type.
    * @param {String|Array|ArrayBuffer|Uint8Array|Buffer} input the input to convert.
    * @throws {Error} an Error if the browser doesn't support the requested output type.
    */
   JSZip.utils.transformTo = function (outputType, input) {
      if (!input) {
         // undefined, null, etc
         // an empty string won't harm.
         input = "";
      }
      if (!outputType) {
         return input;
      }
      JSZip.utils.checkSupport(outputType);
      var inputType = JSZip.utils.getTypeOf(input);
      var result = transform[inputType][outputType](input);
      return result;
   };

   /**
    * Return the type of the input.
    * The type will be in a format valid for JSZip.utils.transformTo : string, array, uint8array, arraybuffer.
    * @param {Object} input the input to identify.
    * @return {String} the (lowercase) type of the input.
    */
   JSZip.utils.getTypeOf = function (input) {
      if (typeof input === "string") {
         return "string";
      }
      if (Object.prototype.toString.call(input) === "[object Array]") {
         return "array";
      }
      if (JSZip.support.nodebuffer && Buffer.isBuffer(input)) {
         return "nodebuffer";
      }
      if (JSZip.support.uint8array && input instanceof Uint8Array) {
         return "uint8array";
      }
      if (JSZip.support.arraybuffer && input instanceof ArrayBuffer) {
         return "arraybuffer";
      }
   };

   /**
    * Cross-window, cross-Node-context regular expression detection
    * @param  {Object}  object Anything
    * @return {Boolean}        true if the object is a regular expression,
    * false otherwise
    */
   JSZip.utils.isRegExp = function (object) {
      return Object.prototype.toString.call(object) === "[object RegExp]";
   };

   /**
    * Throw an exception if the type is not supported.
    * @param {String} type the type to check.
    * @throws {Error} an Error if the browser doesn't support the requested type.
    */
   JSZip.utils.checkSupport = function (type) {
      var supported = true;
      switch (type.toLowerCase()) {
         case "uint8array":
            supported = JSZip.support.uint8array;
         break;
         case "arraybuffer":
            supported = JSZip.support.arraybuffer;
         break;
         case "nodebuffer":
            supported = JSZip.support.nodebuffer;
         break;
         case "blob":
            supported = JSZip.support.blob;
         break;
      }
      if (!supported) {
         throw new Error(type + " is not supported by this browser");
      }
   };


})();

(function (){
   /**
    * Represents an entry in the zip.
    * The content may or may not be compressed.
    * @constructor
    */
   JSZip.CompressedObject = function () {
         this.compressedSize = 0;
         this.uncompressedSize = 0;
         this.crc32 = 0;
         this.compressionMethod = null;
         this.compressedContent = null;
   };

   JSZip.CompressedObject.prototype = {
      /**
       * Return the decompressed content in an unspecified format.
       * The format will depend on the decompressor.
       * @return {Object} the decompressed content.
       */
      getContent : function () {
         return null; // see implementation
      },
      /**
       * Return the compressed content in an unspecified format.
       * The format will depend on the compressed conten source.
       * @return {Object} the compressed content.
       */
      getCompressedContent : function () {
         return null; // see implementation
      }
   };
})();

/**
 *
 *  Base64 encode / decode
 *  http://www.webtoolkit.info/
 *
 *  Hacked so that it doesn't utf8 en/decode everything
 **/
JSZip.base64 = (function() {
   // private property
   var _keyStr = "ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/=";

   return {
      // public method for encoding
      encode : function(input, utf8) {
         var output = "";
         var chr1, chr2, chr3, enc1, enc2, enc3, enc4;
         var i = 0;

         while (i < input.length) {

            chr1 = input.charCodeAt(i++);
            chr2 = input.charCodeAt(i++);
            chr3 = input.charCodeAt(i++);

            enc1 = chr1 >> 2;
            enc2 = ((chr1 & 3) << 4) | (chr2 >> 4);
            enc3 = ((chr2 & 15) << 2) | (chr3 >> 6);
            enc4 = chr3 & 63;

            if (isNaN(chr2)) {
               enc3 = enc4 = 64;
            } else if (isNaN(chr3)) {
               enc4 = 64;
            }

            output = output +
               _keyStr.charAt(enc1) + _keyStr.charAt(enc2) +
               _keyStr.charAt(enc3) + _keyStr.charAt(enc4);

         }

         return output;
      },

      // public method for decoding
      decode : function(input, utf8) {
         var output = "";
         var chr1, chr2, chr3;
         var enc1, enc2, enc3, enc4;
         var i = 0;

         input = input.replace(/[^A-Za-z0-9\+\/\=]/g, "");

         while (i < input.length) {

            enc1 = _keyStr.indexOf(input.charAt(i++));
            enc2 = _keyStr.indexOf(input.charAt(i++));
            enc3 = _keyStr.indexOf(input.charAt(i++));
            enc4 = _keyStr.indexOf(input.charAt(i++));

            chr1 = (enc1 << 2) | (enc2 >> 4);
            chr2 = ((enc2 & 15) << 4) | (enc3 >> 2);
            chr3 = ((enc3 & 3) << 6) | enc4;

            output = output + String.fromCharCode(chr1);

            if (enc3 != 64) {
               output = output + String.fromCharCode(chr2);
            }
            if (enc4 != 64) {
               output = output + String.fromCharCode(chr3);
            }

         }

         return output;

      }
   };
}());

// enforcing Stuk's coding style
// vim: set shiftwidth=3 softtabstop=3:

/**

JSZip - A Javascript class for generating and reading zip files
<http://stuartk.com/jszip>

(c) 2011 David Duponchel <d.duponchel@gmail.com>
Dual licenced under the MIT license or GPLv3. See LICENSE.markdown.

**/
/*global JSZip */
(function (root) {
  "use strict";

   var JSZip = root.JSZip;

   var MAX_VALUE_16BITS = 65535;
   var MAX_VALUE_32BITS = -1; // well, "\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF" is parsed as -1

   /**
    * Prettify a string read as binary.
    * @param {string} str the string to prettify.
    * @return {string} a pretty string.
    */
   var pretty = function (str) {
      var res = '', code, i;
      for (i = 0; i < (str||"").length; i++) {
         code = str.charCodeAt(i);
         res += '\\x' + (code < 16 ? "0" : "") + code.toString(16).toUpperCase();
      }
      return res;
   };

   /**
    * Find a compression registered in JSZip.
    * @param {string} compressionMethod the method magic to find.
    * @return {Object|null} the JSZip compression object, null if none found.
    */
   var findCompression = function (compressionMethod) {
      for (var method in JSZip.compressions) {
         if( !JSZip.compressions.hasOwnProperty(method) ) { continue; }
         if (JSZip.compressions[method].magic === compressionMethod) {
            return JSZip.compressions[method];
         }
      }
      return null;
   };

   // class DataReader {{{
   /**
    * Read bytes from a source.
    * Developer tip : when debugging, a watch on pretty(this.reader.data.slice(this.reader.index))
    * is very useful :)
    * @constructor
    * @param {String|ArrayBuffer|Uint8Array|Buffer} data the data to read.
    */
   function DataReader(data) {
      this.data = null; // type : see implementation
      this.length = 0;
      this.index = 0;
   }
   DataReader.prototype = {
      /**
       * Check that the offset will not go too far.
       * @param {string} offset the additional offset to check.
       * @throws {Error} an Error if the offset is out of bounds.
       */
      checkOffset : function (offset) {
         this.checkIndex(this.index + offset);
      },
      /**
       * Check that the specifed index will not be too far.
       * @param {string} newIndex the index to check.
       * @throws {Error} an Error if the index is out of bounds.
       */
      checkIndex : function (newIndex) {
         if (this.length < newIndex || newIndex < 0) {
            throw new Error("End of data reached (data length = " +
                            this.length + ", asked index = " +
                            (newIndex) + "). Corrupted zip ?");
         }
      },
      /**
       * Change the index.
       * @param {number} newIndex The new index.
       * @throws {Error} if the new index is out of the data.
       */
      setIndex : function (newIndex) {
         this.checkIndex(newIndex);
         this.index = newIndex;
      },
      /**
       * Skip the next n bytes.
       * @param {number} n the number of bytes to skip.
       * @throws {Error} if the new index is out of the data.
       */
      skip : function (n) {
         this.setIndex(this.index + n);
      },
      /**
       * Get the byte at the specified index.
       * @param {number} i the index to use.
       * @return {number} a byte.
       */
      byteAt : function(i) {
         // see implementations
      },
      /**
       * Get the next number with a given byte size.
       * @param {number} size the number of bytes to read.
       * @return {number} the corresponding number.
       */
      readInt : function (size) {
         var result = 0, i;
         this.checkOffset(size);
         for(i = this.index + size - 1; i >= this.index; i--) {
            result = (result << 8) + this.byteAt(i);
         }
         this.index += size;
         return result;
      },
      /**
       * Get the next string with a given byte size.
       * @param {number} size the number of bytes to read.
       * @return {string} the corresponding string.
       */
      readString : function (size) {
         return JSZip.utils.transformTo("string", this.readData(size));
      },
      /**
       * Get raw data without conversion, <size> bytes.
       * @param {number} size the number of bytes to read.
       * @return {Object} the raw data, implementation specific.
       */
      readData : function (size) {
         // see implementations
      },
      /**
       * Find the last occurence of a zip signature (4 bytes).
       * @param {string} sig the signature to find.
       * @return {number} the index of the last occurence, -1 if not found.
       */
      lastIndexOfSignature : function (sig) {
         // see implementations
      },
      /**
       * Get the next date.
       * @return {Date} the date.
       */
      readDate : function () {
         var dostime = this.readInt(4);
         return new Date(
            ((dostime >> 25) & 0x7f) + 1980, // year
            ((dostime >> 21) & 0x0f) - 1, // month
            (dostime >> 16) & 0x1f, // day
            (dostime >> 11) & 0x1f, // hour
            (dostime >> 5) & 0x3f, // minute
            (dostime & 0x1f) << 1); // second
      }
   };


   /**
    * Read bytes from a string.
    * @constructor
    * @param {String} data the data to read.
    */
   function StringReader(data, optimizedBinaryString) {
      this.data = data;
      if (!optimizedBinaryString) {
         this.data = JSZip.utils.string2binary(this.data);
      }
      this.length = this.data.length;
      this.index = 0;
   }
   StringReader.prototype = new DataReader();
   /**
    * @see DataReader.byteAt
    */
   StringReader.prototype.byteAt = function(i) {
      return this.data.charCodeAt(i);
   };
   /**
    * @see DataReader.lastIndexOfSignature
    */
   StringReader.prototype.lastIndexOfSignature = function (sig) {
      return this.data.lastIndexOf(sig);
   };
   /**
    * @see DataReader.readData
    */
   StringReader.prototype.readData = function (size) {
      this.checkOffset(size);
      // this will work because the constructor applied the "& 0xff" mask.
      var result = this.data.slice(this.index, this.index + size);
      this.index += size;
      return result;
   };


   /**
    * Read bytes from an Uin8Array.
    * @constructor
    * @param {Uint8Array} data the data to read.
    */
   function Uint8ArrayReader(data) {
      if (data) {
         this.data = data;
         this.length = this.data.length;
         this.index = 0;
      }
   }
   Uint8ArrayReader.prototype = new DataReader();
   /**
    * @see DataReader.byteAt
    */
   Uint8ArrayReader.prototype.byteAt = function(i) {
      return this.data[i];
   };
   /**
    * @see DataReader.lastIndexOfSignature
    */
   Uint8ArrayReader.prototype.lastIndexOfSignature = function (sig) {
      var sig0 = sig.charCodeAt(0),
      sig1 = sig.charCodeAt(1),
      sig2 = sig.charCodeAt(2),
      sig3 = sig.charCodeAt(3);
      for(var i = this.length - 4;i >= 0;--i) {
         if (this.data[i] === sig0 && this.data[i+1] === sig1 && this.data[i+2] === sig2 && this.data[i+3] === sig3) {
            return i;
         }
      }

      return -1;
   };
   /**
    * @see DataReader.readData
    */
   Uint8ArrayReader.prototype.readData = function (size) {
      this.checkOffset(size);
      var result = this.data.subarray(this.index, this.index + size);
      this.index += size;
      return result;
   };

   /**
    * Read bytes from a Buffer.
    * @constructor
    * @param {Buffer} data the data to read.
    */
   function NodeBufferReader(data) {
      this.data = data;
      this.length = this.data.length;
      this.index = 0;
   }
   NodeBufferReader.prototype = new Uint8ArrayReader();

   /**
    * @see DataReader.readData
    */
   NodeBufferReader.prototype.readData = function (size) {
      this.checkOffset(size);
      var result = this.data.slice(this.index, this.index + size);
      this.index += size;
      return result;
   };
   // }}} end of DataReader

   // class ZipEntry {{{
   /**
    * An entry in the zip file.
    * @constructor
    * @param {Object} options Options of the current file.
    * @param {Object} loadOptions Options for loading the data.
    */
   function ZipEntry(options, loadOptions) {
      this.options = options;
      this.loadOptions = loadOptions;
   }
   ZipEntry.prototype = {
      /**
       * say if the file is encrypted.
       * @return {boolean} true if the file is encrypted, false otherwise.
       */
      isEncrypted : function () {
         // bit 1 is set
         return (this.bitFlag & 0x0001) === 0x0001;
      },
      /**
       * say if the file has utf-8 filename/comment.
       * @return {boolean} true if the filename/comment is in utf-8, false otherwise.
       */
      useUTF8 : function () {
         // bit 11 is set
         return (this.bitFlag & 0x0800) === 0x0800;
      },
      /**
       * Prepare the function used to generate the compressed content from this ZipFile.
       * @param {DataReader} reader the reader to use.
       * @param {number} from the offset from where we should read the data.
       * @param {number} length the length of the data to read.
       * @return {Function} the callback to get the compressed content (the type depends of the DataReader class).
       */
      prepareCompressedContent : function (reader, from, length) {
         return function () {
            var previousIndex = reader.index;
            reader.setIndex(from);
            var compressedFileData = reader.readData(length);
            reader.setIndex(previousIndex);

            return compressedFileData;
         };
      },
      /**
       * Prepare the function used to generate the uncompressed content from this ZipFile.
       * @param {DataReader} reader the reader to use.
       * @param {number} from the offset from where we should read the data.
       * @param {number} length the length of the data to read.
       * @param {JSZip.compression} compression the compression used on this file.
       * @param {number} uncompressedSize the uncompressed size to expect.
       * @return {Function} the callback to get the uncompressed content (the type depends of the DataReader class).
       */
      prepareContent : function (reader, from, length, compression, uncompressedSize) {
         return function () {

            var compressedFileData = JSZip.utils.transformTo(compression.uncompressInputType, this.getCompressedContent());
            var uncompressedFileData = compression.uncompress(compressedFileData);

            if (uncompressedFileData.length !== uncompressedSize) {
               throw new Error("Bug : uncompressed data size mismatch");
            }

            return uncompressedFileData;
         };
      },
      /**
       * Read the local part of a zip file and add the info in this object.
       * @param {DataReader} reader the reader to use.
       */
      readLocalPart : function(reader) {
         var compression, localExtraFieldsLength;

         // we already know everything from the central dir !
         // If the central dir data are false, we are doomed.
         // On the bright side, the local part is scary  : zip64, data descriptors, both, etc.
         // The less data we get here, the more reliable this should be.
         // Let's skip the whole header and dash to the data !
         reader.skip(22);
         // in some zip created on windows, the filename stored in the central dir contains \ instead of /.
         // Strangely, the filename here is OK.
         // I would love to treat these zip files as corrupted (see http://www.info-zip.org/FAQ.html#backslashes
         // or APPNOTE#4.4.17.1, "All slashes MUST be forward slashes '/'") but there are a lot of bad zip generators...
         // Search "unzip mismatching "local" filename continuing with "central" filename version" on
         // the internet.
         //
         // I think I see the logic here : the central directory is used to display
         // content and the local directory is used to extract the files. Mixing / and \
         // may be used to display \ to windows users and use / when extracting the files.
         // Unfortunately, this lead also to some issues : http://seclists.org/fulldisclosure/2009/Sep/394
         this.fileNameLength = reader.readInt(2);
         localExtraFieldsLength = reader.readInt(2); // can't be sure this will be the same as the central dir
         this.fileName = reader.readString(this.fileNameLength);
         reader.skip(localExtraFieldsLength);

         if (this.compressedSize == -1 || this.uncompressedSize == -1) {
            throw new Error("Bug or corrupted zip : didn't get enough informations from the central directory " +
                            "(compressedSize == -1 || uncompressedSize == -1)");
         }

         compression = findCompression(this.compressionMethod);
         if (compression === null) { // no compression found
            throw new Error("Corrupted zip : compression " + pretty(this.compressionMethod) +
                            " unknown (inner file : " + this.fileName + ")");
         }
         this.decompressed = new JSZip.CompressedObject();
         this.decompressed.compressedSize = this.compressedSize;
         this.decompressed.uncompressedSize = this.uncompressedSize;
         this.decompressed.crc32 = this.crc32;
         this.decompressed.compressionMethod = this.compressionMethod;
         this.decompressed.getCompressedContent = this.prepareCompressedContent(reader, reader.index, this.compressedSize, compression);
         this.decompressed.getContent = this.prepareContent(reader, reader.index, this.compressedSize, compression, this.uncompressedSize);

         // we need to compute the crc32...
         if (this.loadOptions.checkCRC32) {
            this.decompressed = JSZip.utils.transformTo("string", this.decompressed.getContent());
            if (JSZip.prototype.crc32(this.decompressed) !== this.crc32) {
               throw new Error("Corrupted zip : CRC32 mismatch");
            }
         }
      },

      /**
       * Read the central part of a zip file and add the info in this object.
       * @param {DataReader} reader the reader to use.
       */
      readCentralPart : function(reader) {
         this.versionMadeBy          = reader.readString(2);
         this.versionNeeded          = reader.readInt(2);
         this.bitFlag                = reader.readInt(2);
         this.compressionMethod      = reader.readString(2);
         this.date                   = reader.readDate();
         this.crc32                  = reader.readInt(4);
         this.compressedSize         = reader.readInt(4);
         this.uncompressedSize       = reader.readInt(4);
         this.fileNameLength         = reader.readInt(2);
         this.extraFieldsLength      = reader.readInt(2);
         this.fileCommentLength      = reader.readInt(2);
         this.diskNumberStart        = reader.readInt(2);
         this.internalFileAttributes = reader.readInt(2);
         this.externalFileAttributes = reader.readInt(4);
         this.localHeaderOffset      = reader.readInt(4);

         if (this.isEncrypted()) {
            throw new Error("Encrypted zip are not supported");
         }

         this.fileName = reader.readString(this.fileNameLength);
         this.readExtraFields(reader);
         this.parseZIP64ExtraField(reader);
         this.fileComment = reader.readString(this.fileCommentLength);

         // warning, this is true only for zip with madeBy == DOS (plateform dependent feature)
         this.dir = this.externalFileAttributes & 0x00000010 ? true : false;
      },
      /**
       * Parse the ZIP64 extra field and merge the info in the current ZipEntry.
       * @param {DataReader} reader the reader to use.
       */
      parseZIP64ExtraField : function(reader) {

         if(!this.extraFields[0x0001]) {
            return;
         }

         // should be something, preparing the extra reader
         var extraReader = new StringReader(this.extraFields[0x0001].value);

         // I really hope that these 64bits integer can fit in 32 bits integer, because js
         // won't let us have more.
         if(this.uncompressedSize === MAX_VALUE_32BITS) {
            this.uncompressedSize = extraReader.readInt(8);
         }
         if(this.compressedSize === MAX_VALUE_32BITS) {
            this.compressedSize = extraReader.readInt(8);
         }
         if(this.localHeaderOffset === MAX_VALUE_32BITS) {
            this.localHeaderOffset = extraReader.readInt(8);
         }
         if(this.diskNumberStart === MAX_VALUE_32BITS) {
            this.diskNumberStart = extraReader.readInt(4);
         }
      },
      /**
       * Read the central part of a zip file and add the info in this object.
       * @param {DataReader} reader the reader to use.
       */
      readExtraFields : function(reader) {
         var start = reader.index,
             extraFieldId,
             extraFieldLength,
             extraFieldValue;

         this.extraFields = this.extraFields || {};

         while (reader.index < start + this.extraFieldsLength) {
            extraFieldId     = reader.readInt(2);
            extraFieldLength = reader.readInt(2);
            extraFieldValue  = reader.readString(extraFieldLength);

            this.extraFields[extraFieldId] = {
               id:     extraFieldId,
               length: extraFieldLength,
               value:  extraFieldValue
            };
         }
      },
      /**
       * Apply an UTF8 transformation if needed.
       */
      handleUTF8 : function() {
         if (this.useUTF8()) {
            this.fileName    = JSZip.prototype.utf8decode(this.fileName);
            this.fileComment = JSZip.prototype.utf8decode(this.fileComment);
         }
      }
   };
   // }}} end of ZipEntry

   //  class ZipEntries {{{
   /**
    * All the entries in the zip file.
    * @constructor
    * @param {String|ArrayBuffer|Uint8Array|Buffer} data the binary data to load.
    * @param {Object} loadOptions Options for loading the data.
    */
   function ZipEntries(data, loadOptions) {
      this.files = [];
      this.loadOptions = loadOptions;
      if (data) {
         this.load(data);
      }
   }
   ZipEntries.prototype = {
      /**
       * Check that the reader is on the speficied signature.
       * @param {string} expectedSignature the expected signature.
       * @throws {Error} if it is an other signature.
       */
      checkSignature : function(expectedSignature) {
         var signature = this.reader.readString(4);
         if (signature !== expectedSignature) {
            throw new Error("Corrupted zip or bug : unexpected signature " +
                            "(" + pretty(signature) + ", expected " + pretty(expectedSignature) + ")");
         }
      },
      /**
       * Read the end of the central directory.
       */
      readBlockEndOfCentral : function () {
         this.diskNumber                  = this.reader.readInt(2);
         this.diskWithCentralDirStart     = this.reader.readInt(2);
         this.centralDirRecordsOnThisDisk = this.reader.readInt(2);
         this.centralDirRecords           = this.reader.readInt(2);
         this.centralDirSize              = this.reader.readInt(4);
         this.centralDirOffset            = this.reader.readInt(4);

         this.zipCommentLength            = this.reader.readInt(2);
         this.zipComment                  = this.reader.readString(this.zipCommentLength);
      },
      /**
       * Read the end of the Zip 64 central directory.
       * Not merged with the method readEndOfCentral :
       * The end of central can coexist with its Zip64 brother,
       * I don't want to read the wrong number of bytes !
       */
      readBlockZip64EndOfCentral : function () {
         this.zip64EndOfCentralSize       = this.reader.readInt(8);
         this.versionMadeBy               = this.reader.readString(2);
         this.versionNeeded               = this.reader.readInt(2);
         this.diskNumber                  = this.reader.readInt(4);
         this.diskWithCentralDirStart     = this.reader.readInt(4);
         this.centralDirRecordsOnThisDisk = this.reader.readInt(8);
         this.centralDirRecords           = this.reader.readInt(8);
         this.centralDirSize              = this.reader.readInt(8);
         this.centralDirOffset            = this.reader.readInt(8);

         this.zip64ExtensibleData = {};
         var extraDataSize = this.zip64EndOfCentralSize - 44,
         index = 0,
         extraFieldId,
         extraFieldLength,
         extraFieldValue;
         while(index < extraDataSize) {
            extraFieldId     = this.reader.readInt(2);
            extraFieldLength = this.reader.readInt(4);
            extraFieldValue  = this.reader.readString(extraFieldLength);
            this.zip64ExtensibleData[extraFieldId] = {
               id:     extraFieldId,
               length: extraFieldLength,
               value:  extraFieldValue
            };
         }
      },
      /**
       * Read the end of the Zip 64 central directory locator.
       */
      readBlockZip64EndOfCentralLocator : function () {
         this.diskWithZip64CentralDirStart       = this.reader.readInt(4);
         this.relativeOffsetEndOfZip64CentralDir = this.reader.readInt(8);
         this.disksCount                         = this.reader.readInt(4);
         if (this.disksCount > 1) {
            throw new Error("Multi-volumes zip are not supported");
         }
      },
      /**
       * Read the local files, based on the offset read in the central part.
       */
      readLocalFiles : function() {
         var i, file;
         for(i = 0; i < this.files.length; i++) {
            file = this.files[i];
            this.reader.setIndex(file.localHeaderOffset);
            this.checkSignature(JSZip.signature.LOCAL_FILE_HEADER);
            file.readLocalPart(this.reader);
            file.handleUTF8();
         }
      },
      /**
       * Read the central directory.
       */
      readCentralDir : function() {
         var file;

         this.reader.setIndex(this.centralDirOffset);
         while(this.reader.readString(4) === JSZip.signature.CENTRAL_FILE_HEADER) {
            file = new ZipEntry({
               zip64: this.zip64
            }, this.loadOptions);
            file.readCentralPart(this.reader);
            this.files.push(file);
         }
      },
      /**
       * Read the end of central directory.
       */
      readEndOfCentral : function() {
         var offset = this.reader.lastIndexOfSignature(JSZip.signature.CENTRAL_DIRECTORY_END);
         if (offset === -1) {
            throw new Error("Corrupted zip : can't find end of central directory");
         }
         this.reader.setIndex(offset);
         this.checkSignature(JSZip.signature.CENTRAL_DIRECTORY_END);
         this.readBlockEndOfCentral();


         /* extract from the zip spec :
            4)  If one of the fields in the end of central directory
                record is too small to hold required data, the field
                should be set to -1 (0xFFFF or 0xFFFFFFFF) and the
                ZIP64 format record should be created.
            5)  The end of central directory record and the
                Zip64 end of central directory locator record must
                reside on the same disk when splitting or spanning
                an archive.
         */
         if (this.diskNumber                 === MAX_VALUE_16BITS ||
            this.diskWithCentralDirStart     === MAX_VALUE_16BITS ||
            this.centralDirRecordsOnThisDisk === MAX_VALUE_16BITS ||
            this.centralDirRecords           === MAX_VALUE_16BITS ||
            this.centralDirSize              === MAX_VALUE_32BITS ||
            this.centralDirOffset            === MAX_VALUE_32BITS
         ) {
            this.zip64 = true;

            /*
            Warning : the zip64 extension is supported, but ONLY if the 64bits integer read from
            the zip file can fit into a 32bits integer. This cannot be solved : Javascript represents
            all numbers as 64-bit double precision IEEE 754 floating point numbers.
            So, we have 53bits for integers and bitwise operations treat everything as 32bits.
            see https://developer.mozilla.org/en-US/docs/JavaScript/Reference/Operators/Bitwise_Operators
            and http://www.ecma-international.org/publications/files/ECMA-ST/ECMA-262.pdf section 8.5
            */

            // should look for a zip64 EOCD locator
            offset = this.reader.lastIndexOfSignature(JSZip.signature.ZIP64_CENTRAL_DIRECTORY_LOCATOR);
            if (offset === -1) {
               throw new Error("Corrupted zip : can't find the ZIP64 end of central directory locator");
            }
            this.reader.setIndex(offset);
            this.checkSignature(JSZip.signature.ZIP64_CENTRAL_DIRECTORY_LOCATOR);
            this.readBlockZip64EndOfCentralLocator();

            // now the zip64 EOCD record
            this.reader.setIndex(this.relativeOffsetEndOfZip64CentralDir);
            this.checkSignature(JSZip.signature.ZIP64_CENTRAL_DIRECTORY_END);
            this.readBlockZip64EndOfCentral();
         }
      },
      prepareReader : function (data) {
         var type = JSZip.utils.getTypeOf(data);
         if (type === "string" && !JSZip.support.uint8array) {
            this.reader = new StringReader(data, this.loadOptions.optimizedBinaryString);
         } else if (type === "nodebuffer") {
            this.reader = new NodeBufferReader(data);
         } else {
            this.reader = new Uint8ArrayReader(JSZip.utils.transformTo("uint8array", data));
         }
      },
      /**
       * Read a zip file and create ZipEntries.
       * @param {String|ArrayBuffer|Uint8Array|Buffer} data the binary string representing a zip file.
       */
      load : function(data) {
         this.prepareReader(data);
         this.readEndOfCentral();
         this.readCentralDir();
         this.readLocalFiles();
      }
   };
   // }}} end of ZipEntries

   /**
    * Implementation of the load method of JSZip.
    * It uses the above classes to decode a zip file, and load every files.
    * @param {String|ArrayBuffer|Uint8Array|Buffer} data the data to load.
    * @param {Object} options Options for loading the data.
    *  options.base64 : is the data in base64 ? default : false
    */
   JSZip.prototype.load = function(data, options) {
      var files, zipEntries, i, input;
      options = options || {};
      if(options.base64) {
         data = JSZip.base64.decode(data);
      }

      zipEntries = new ZipEntries(data, options);
      files = zipEntries.files;
      for (i = 0; i < files.length; i++) {
         input = files[i];
         this.file(input.fileName, input.decompressed, {
            binary:true,
            optimizedBinaryString:true,
            date:input.date,
            dir:input.dir
         });
      }

      return this;
   };

}(this));
// enforcing Stuk's coding style
// vim: set shiftwidth=3 softtabstop=3 foldmethod=marker:

(function () {
   "use strict";

   if(!JSZip) {
      throw "JSZip not defined";
   }

   /*jshint -W004, -W018, -W030, -W032, -W033, -W034, -W037,-W040, -W055, -W056, -W061, -W064, -W093, -W117 */
   var context = {};
   (function () {

      // https://github.com/imaya/zlib.js
      // tag 0.1.6
      // file bin/deflate.min.js

/** @license zlib.js 2012 - imaya [ https://github.com/imaya/zlib.js ] The MIT License */(function() {'use strict';var n=void 0,u=!0,aa=this;function ba(e,d){var c=e.split("."),f=aa;!(c[0]in f)&&f.execScript&&f.execScript("var "+c[0]);for(var a;c.length&&(a=c.shift());)!c.length&&d!==n?f[a]=d:f=f[a]?f[a]:f[a]={}};var C="undefined"!==typeof Uint8Array&&"undefined"!==typeof Uint16Array&&"undefined"!==typeof Uint32Array;function K(e,d){this.index="number"===typeof d?d:0;this.d=0;this.buffer=e instanceof(C?Uint8Array:Array)?e:new (C?Uint8Array:Array)(32768);if(2*this.buffer.length<=this.index)throw Error("invalid index");this.buffer.length<=this.index&&ca(this)}function ca(e){var d=e.buffer,c,f=d.length,a=new (C?Uint8Array:Array)(f<<1);if(C)a.set(d);else for(c=0;c<f;++c)a[c]=d[c];return e.buffer=a}
K.prototype.a=function(e,d,c){var f=this.buffer,a=this.index,b=this.d,k=f[a],m;c&&1<d&&(e=8<d?(L[e&255]<<24|L[e>>>8&255]<<16|L[e>>>16&255]<<8|L[e>>>24&255])>>32-d:L[e]>>8-d);if(8>d+b)k=k<<d|e,b+=d;else for(m=0;m<d;++m)k=k<<1|e>>d-m-1&1,8===++b&&(b=0,f[a++]=L[k],k=0,a===f.length&&(f=ca(this)));f[a]=k;this.buffer=f;this.d=b;this.index=a};K.prototype.finish=function(){var e=this.buffer,d=this.index,c;0<this.d&&(e[d]<<=8-this.d,e[d]=L[e[d]],d++);C?c=e.subarray(0,d):(e.length=d,c=e);return c};
var ga=new (C?Uint8Array:Array)(256),M;for(M=0;256>M;++M){for(var R=M,S=R,ha=7,R=R>>>1;R;R>>>=1)S<<=1,S|=R&1,--ha;ga[M]=(S<<ha&255)>>>0}var L=ga;function ja(e){this.buffer=new (C?Uint16Array:Array)(2*e);this.length=0}ja.prototype.getParent=function(e){return 2*((e-2)/4|0)};ja.prototype.push=function(e,d){var c,f,a=this.buffer,b;c=this.length;a[this.length++]=d;for(a[this.length++]=e;0<c;)if(f=this.getParent(c),a[c]>a[f])b=a[c],a[c]=a[f],a[f]=b,b=a[c+1],a[c+1]=a[f+1],a[f+1]=b,c=f;else break;return this.length};
ja.prototype.pop=function(){var e,d,c=this.buffer,f,a,b;d=c[0];e=c[1];this.length-=2;c[0]=c[this.length];c[1]=c[this.length+1];for(b=0;;){a=2*b+2;if(a>=this.length)break;a+2<this.length&&c[a+2]>c[a]&&(a+=2);if(c[a]>c[b])f=c[b],c[b]=c[a],c[a]=f,f=c[b+1],c[b+1]=c[a+1],c[a+1]=f;else break;b=a}return{index:e,value:d,length:this.length}};function ka(e,d){this.e=ma;this.f=0;this.input=C&&e instanceof Array?new Uint8Array(e):e;this.c=0;d&&(d.lazy&&(this.f=d.lazy),"number"===typeof d.compressionType&&(this.e=d.compressionType),d.outputBuffer&&(this.b=C&&d.outputBuffer instanceof Array?new Uint8Array(d.outputBuffer):d.outputBuffer),"number"===typeof d.outputIndex&&(this.c=d.outputIndex));this.b||(this.b=new (C?Uint8Array:Array)(32768))}var ma=2,T=[],U;
for(U=0;288>U;U++)switch(u){case 143>=U:T.push([U+48,8]);break;case 255>=U:T.push([U-144+400,9]);break;case 279>=U:T.push([U-256+0,7]);break;case 287>=U:T.push([U-280+192,8]);break;default:throw"invalid literal: "+U;}
ka.prototype.h=function(){var e,d,c,f,a=this.input;switch(this.e){case 0:c=0;for(f=a.length;c<f;){d=C?a.subarray(c,c+65535):a.slice(c,c+65535);c+=d.length;var b=d,k=c===f,m=n,g=n,p=n,v=n,x=n,l=this.b,h=this.c;if(C){for(l=new Uint8Array(this.b.buffer);l.length<=h+b.length+5;)l=new Uint8Array(l.length<<1);l.set(this.b)}m=k?1:0;l[h++]=m|0;g=b.length;p=~g+65536&65535;l[h++]=g&255;l[h++]=g>>>8&255;l[h++]=p&255;l[h++]=p>>>8&255;if(C)l.set(b,h),h+=b.length,l=l.subarray(0,h);else{v=0;for(x=b.length;v<x;++v)l[h++]=
b[v];l.length=h}this.c=h;this.b=l}break;case 1:var q=new K(C?new Uint8Array(this.b.buffer):this.b,this.c);q.a(1,1,u);q.a(1,2,u);var t=na(this,a),w,da,z;w=0;for(da=t.length;w<da;w++)if(z=t[w],K.prototype.a.apply(q,T[z]),256<z)q.a(t[++w],t[++w],u),q.a(t[++w],5),q.a(t[++w],t[++w],u);else if(256===z)break;this.b=q.finish();this.c=this.b.length;break;case ma:var B=new K(C?new Uint8Array(this.b.buffer):this.b,this.c),ra,J,N,O,P,Ia=[16,17,18,0,8,7,9,6,10,5,11,4,12,3,13,2,14,1,15],W,sa,X,ta,ea,ia=Array(19),
ua,Q,fa,y,va;ra=ma;B.a(1,1,u);B.a(ra,2,u);J=na(this,a);W=oa(this.j,15);sa=pa(W);X=oa(this.i,7);ta=pa(X);for(N=286;257<N&&0===W[N-1];N--);for(O=30;1<O&&0===X[O-1];O--);var wa=N,xa=O,F=new (C?Uint32Array:Array)(wa+xa),r,G,s,Y,E=new (C?Uint32Array:Array)(316),D,A,H=new (C?Uint8Array:Array)(19);for(r=G=0;r<wa;r++)F[G++]=W[r];for(r=0;r<xa;r++)F[G++]=X[r];if(!C){r=0;for(Y=H.length;r<Y;++r)H[r]=0}r=D=0;for(Y=F.length;r<Y;r+=G){for(G=1;r+G<Y&&F[r+G]===F[r];++G);s=G;if(0===F[r])if(3>s)for(;0<s--;)E[D++]=0,
H[0]++;else for(;0<s;)A=138>s?s:138,A>s-3&&A<s&&(A=s-3),10>=A?(E[D++]=17,E[D++]=A-3,H[17]++):(E[D++]=18,E[D++]=A-11,H[18]++),s-=A;else if(E[D++]=F[r],H[F[r]]++,s--,3>s)for(;0<s--;)E[D++]=F[r],H[F[r]]++;else for(;0<s;)A=6>s?s:6,A>s-3&&A<s&&(A=s-3),E[D++]=16,E[D++]=A-3,H[16]++,s-=A}e=C?E.subarray(0,D):E.slice(0,D);ea=oa(H,7);for(y=0;19>y;y++)ia[y]=ea[Ia[y]];for(P=19;4<P&&0===ia[P-1];P--);ua=pa(ea);B.a(N-257,5,u);B.a(O-1,5,u);B.a(P-4,4,u);for(y=0;y<P;y++)B.a(ia[y],3,u);y=0;for(va=e.length;y<va;y++)if(Q=
e[y],B.a(ua[Q],ea[Q],u),16<=Q){y++;switch(Q){case 16:fa=2;break;case 17:fa=3;break;case 18:fa=7;break;default:throw"invalid code: "+Q;}B.a(e[y],fa,u)}var ya=[sa,W],za=[ta,X],I,Aa,Z,la,Ba,Ca,Da,Ea;Ba=ya[0];Ca=ya[1];Da=za[0];Ea=za[1];I=0;for(Aa=J.length;I<Aa;++I)if(Z=J[I],B.a(Ba[Z],Ca[Z],u),256<Z)B.a(J[++I],J[++I],u),la=J[++I],B.a(Da[la],Ea[la],u),B.a(J[++I],J[++I],u);else if(256===Z)break;this.b=B.finish();this.c=this.b.length;break;default:throw"invalid compression type";}return this.b};
function qa(e,d){this.length=e;this.g=d}
var Fa=function(){function e(a){switch(u){case 3===a:return[257,a-3,0];case 4===a:return[258,a-4,0];case 5===a:return[259,a-5,0];case 6===a:return[260,a-6,0];case 7===a:return[261,a-7,0];case 8===a:return[262,a-8,0];case 9===a:return[263,a-9,0];case 10===a:return[264,a-10,0];case 12>=a:return[265,a-11,1];case 14>=a:return[266,a-13,1];case 16>=a:return[267,a-15,1];case 18>=a:return[268,a-17,1];case 22>=a:return[269,a-19,2];case 26>=a:return[270,a-23,2];case 30>=a:return[271,a-27,2];case 34>=a:return[272,
a-31,2];case 42>=a:return[273,a-35,3];case 50>=a:return[274,a-43,3];case 58>=a:return[275,a-51,3];case 66>=a:return[276,a-59,3];case 82>=a:return[277,a-67,4];case 98>=a:return[278,a-83,4];case 114>=a:return[279,a-99,4];case 130>=a:return[280,a-115,4];case 162>=a:return[281,a-131,5];case 194>=a:return[282,a-163,5];case 226>=a:return[283,a-195,5];case 257>=a:return[284,a-227,5];case 258===a:return[285,a-258,0];default:throw"invalid length: "+a;}}var d=[],c,f;for(c=3;258>=c;c++)f=e(c),d[c]=f[2]<<24|
f[1]<<16|f[0];return d}(),Ga=C?new Uint32Array(Fa):Fa;
function na(e,d){function c(a,c){var b=a.g,d=[],f=0,e;e=Ga[a.length];d[f++]=e&65535;d[f++]=e>>16&255;d[f++]=e>>24;var g;switch(u){case 1===b:g=[0,b-1,0];break;case 2===b:g=[1,b-2,0];break;case 3===b:g=[2,b-3,0];break;case 4===b:g=[3,b-4,0];break;case 6>=b:g=[4,b-5,1];break;case 8>=b:g=[5,b-7,1];break;case 12>=b:g=[6,b-9,2];break;case 16>=b:g=[7,b-13,2];break;case 24>=b:g=[8,b-17,3];break;case 32>=b:g=[9,b-25,3];break;case 48>=b:g=[10,b-33,4];break;case 64>=b:g=[11,b-49,4];break;case 96>=b:g=[12,b-
65,5];break;case 128>=b:g=[13,b-97,5];break;case 192>=b:g=[14,b-129,6];break;case 256>=b:g=[15,b-193,6];break;case 384>=b:g=[16,b-257,7];break;case 512>=b:g=[17,b-385,7];break;case 768>=b:g=[18,b-513,8];break;case 1024>=b:g=[19,b-769,8];break;case 1536>=b:g=[20,b-1025,9];break;case 2048>=b:g=[21,b-1537,9];break;case 3072>=b:g=[22,b-2049,10];break;case 4096>=b:g=[23,b-3073,10];break;case 6144>=b:g=[24,b-4097,11];break;case 8192>=b:g=[25,b-6145,11];break;case 12288>=b:g=[26,b-8193,12];break;case 16384>=
b:g=[27,b-12289,12];break;case 24576>=b:g=[28,b-16385,13];break;case 32768>=b:g=[29,b-24577,13];break;default:throw"invalid distance";}e=g;d[f++]=e[0];d[f++]=e[1];d[f++]=e[2];var k,m;k=0;for(m=d.length;k<m;++k)l[h++]=d[k];t[d[0]]++;w[d[3]]++;q=a.length+c-1;x=null}var f,a,b,k,m,g={},p,v,x,l=C?new Uint16Array(2*d.length):[],h=0,q=0,t=new (C?Uint32Array:Array)(286),w=new (C?Uint32Array:Array)(30),da=e.f,z;if(!C){for(b=0;285>=b;)t[b++]=0;for(b=0;29>=b;)w[b++]=0}t[256]=1;f=0;for(a=d.length;f<a;++f){b=
m=0;for(k=3;b<k&&f+b!==a;++b)m=m<<8|d[f+b];g[m]===n&&(g[m]=[]);p=g[m];if(!(0<q--)){for(;0<p.length&&32768<f-p[0];)p.shift();if(f+3>=a){x&&c(x,-1);b=0;for(k=a-f;b<k;++b)z=d[f+b],l[h++]=z,++t[z];break}0<p.length?(v=Ha(d,f,p),x?x.length<v.length?(z=d[f-1],l[h++]=z,++t[z],c(v,0)):c(x,-1):v.length<da?x=v:c(v,0)):x?c(x,-1):(z=d[f],l[h++]=z,++t[z])}p.push(f)}l[h++]=256;t[256]++;e.j=t;e.i=w;return C?l.subarray(0,h):l}
function Ha(e,d,c){var f,a,b=0,k,m,g,p,v=e.length;m=0;p=c.length;a:for(;m<p;m++){f=c[p-m-1];k=3;if(3<b){for(g=b;3<g;g--)if(e[f+g-1]!==e[d+g-1])continue a;k=b}for(;258>k&&d+k<v&&e[f+k]===e[d+k];)++k;k>b&&(a=f,b=k);if(258===k)break}return new qa(b,d-a)}
function oa(e,d){var c=e.length,f=new ja(572),a=new (C?Uint8Array:Array)(c),b,k,m,g,p;if(!C)for(g=0;g<c;g++)a[g]=0;for(g=0;g<c;++g)0<e[g]&&f.push(g,e[g]);b=Array(f.length/2);k=new (C?Uint32Array:Array)(f.length/2);if(1===b.length)return a[f.pop().index]=1,a;g=0;for(p=f.length/2;g<p;++g)b[g]=f.pop(),k[g]=b[g].value;m=Ja(k,k.length,d);g=0;for(p=b.length;g<p;++g)a[b[g].index]=m[g];return a}
function Ja(e,d,c){function f(a){var b=g[a][p[a]];b===d?(f(a+1),f(a+1)):--k[b];++p[a]}var a=new (C?Uint16Array:Array)(c),b=new (C?Uint8Array:Array)(c),k=new (C?Uint8Array:Array)(d),m=Array(c),g=Array(c),p=Array(c),v=(1<<c)-d,x=1<<c-1,l,h,q,t,w;a[c-1]=d;for(h=0;h<c;++h)v<x?b[h]=0:(b[h]=1,v-=x),v<<=1,a[c-2-h]=(a[c-1-h]/2|0)+d;a[0]=b[0];m[0]=Array(a[0]);g[0]=Array(a[0]);for(h=1;h<c;++h)a[h]>2*a[h-1]+b[h]&&(a[h]=2*a[h-1]+b[h]),m[h]=Array(a[h]),g[h]=Array(a[h]);for(l=0;l<d;++l)k[l]=c;for(q=0;q<a[c-1];++q)m[c-
1][q]=e[q],g[c-1][q]=q;for(l=0;l<c;++l)p[l]=0;1===b[c-1]&&(--k[0],++p[c-1]);for(h=c-2;0<=h;--h){t=l=0;w=p[h+1];for(q=0;q<a[h];q++)t=m[h+1][w]+m[h+1][w+1],t>e[l]?(m[h][q]=t,g[h][q]=d,w+=2):(m[h][q]=e[l],g[h][q]=l,++l);p[h]=0;1===b[h]&&f(h)}return k}
function pa(e){var d=new (C?Uint16Array:Array)(e.length),c=[],f=[],a=0,b,k,m,g;b=0;for(k=e.length;b<k;b++)c[e[b]]=(c[e[b]]|0)+1;b=1;for(k=16;b<=k;b++)f[b]=a,a+=c[b]|0,a<<=1;b=0;for(k=e.length;b<k;b++){a=f[e[b]];f[e[b]]+=1;m=d[b]=0;for(g=e[b];m<g;m++)d[b]=d[b]<<1|a&1,a>>>=1}return d};ba("Zlib.RawDeflate",ka);ba("Zlib.RawDeflate.prototype.compress",ka.prototype.h);var Ka={NONE:0,FIXED:1,DYNAMIC:ma},V,La,$,Ma;if(Object.keys)V=Object.keys(Ka);else for(La in V=[],$=0,Ka)V[$++]=La;$=0;for(Ma=V.length;$<Ma;++$)La=V[$],ba("Zlib.RawDeflate.CompressionType."+La,Ka[La]);}).call(this); //@ sourceMappingURL=rawdeflate.min.js.map


   }).call(context);
   /*jshint +W004, +W018, +W030, +W032, +W033, +W034, +W037,+W040, +W055, +W056, +W061, +W064, +W093, +W117 */

   var compress = function (input) {
      var deflate = new context.Zlib.RawDeflate(input);
      return deflate.compress();
   };

   var USE_TYPEDARRAY =
      (typeof Uint8Array !== 'undefined') &&
      (typeof Uint16Array !== 'undefined') &&
      (typeof Uint32Array !== 'undefined');


   // we add the compression method for JSZip
   if(!JSZip.compressions["DEFLATE"]) {
      JSZip.compressions["DEFLATE"] = {
         magic : "\x08\x00",
         compress : compress,
         compressInputType : USE_TYPEDARRAY ? "uint8array" : "array"
      };
   } else {
      JSZip.compressions["DEFLATE"].compress = compress;
      JSZip.compressions["DEFLATE"].compressInputType = USE_TYPEDARRAY ? "uint8array" : "array";
   }
})();

// enforcing Stuk's coding style
// vim: set shiftwidth=3 softtabstop=3:

(function () {
   "use strict";

   if(!JSZip) {
      throw "JSZip not defined";
   }

   /*jshint -W004, -W030, -W032, -W033, -W034, -W040, -W056, -W061, -W064, -W093 */
   var context = {};
   (function () {

      // https://github.com/imaya/zlib.js
      // tag 0.1.6
      // file bin/deflate.min.js

/** @license zlib.js 2012 - imaya [ https://github.com/imaya/zlib.js ] The MIT License */(function() {'use strict';var l=void 0,p=this;function q(c,d){var a=c.split("."),b=p;!(a[0]in b)&&b.execScript&&b.execScript("var "+a[0]);for(var e;a.length&&(e=a.shift());)!a.length&&d!==l?b[e]=d:b=b[e]?b[e]:b[e]={}};var r="undefined"!==typeof Uint8Array&&"undefined"!==typeof Uint16Array&&"undefined"!==typeof Uint32Array;function u(c){var d=c.length,a=0,b=Number.POSITIVE_INFINITY,e,f,g,h,k,m,s,n,t;for(n=0;n<d;++n)c[n]>a&&(a=c[n]),c[n]<b&&(b=c[n]);e=1<<a;f=new (r?Uint32Array:Array)(e);g=1;h=0;for(k=2;g<=a;){for(n=0;n<d;++n)if(c[n]===g){m=0;s=h;for(t=0;t<g;++t)m=m<<1|s&1,s>>=1;for(t=m;t<e;t+=k)f[t]=g<<16|n;++h}++g;h<<=1;k<<=1}return[f,a,b]};function v(c,d){this.g=[];this.h=32768;this.c=this.f=this.d=this.k=0;this.input=r?new Uint8Array(c):c;this.l=!1;this.i=w;this.p=!1;if(d||!(d={}))d.index&&(this.d=d.index),d.bufferSize&&(this.h=d.bufferSize),d.bufferType&&(this.i=d.bufferType),d.resize&&(this.p=d.resize);switch(this.i){case x:this.a=32768;this.b=new (r?Uint8Array:Array)(32768+this.h+258);break;case w:this.a=0;this.b=new (r?Uint8Array:Array)(this.h);this.e=this.u;this.m=this.r;this.j=this.s;break;default:throw Error("invalid inflate mode");
}}var x=0,w=1;
v.prototype.t=function(){for(;!this.l;){var c=y(this,3);c&1&&(this.l=!0);c>>>=1;switch(c){case 0:var d=this.input,a=this.d,b=this.b,e=this.a,f=l,g=l,h=l,k=b.length,m=l;this.c=this.f=0;f=d[a++];if(f===l)throw Error("invalid uncompressed block header: LEN (first byte)");g=f;f=d[a++];if(f===l)throw Error("invalid uncompressed block header: LEN (second byte)");g|=f<<8;f=d[a++];if(f===l)throw Error("invalid uncompressed block header: NLEN (first byte)");h=f;f=d[a++];if(f===l)throw Error("invalid uncompressed block header: NLEN (second byte)");h|=
f<<8;if(g===~h)throw Error("invalid uncompressed block header: length verify");if(a+g>d.length)throw Error("input buffer is broken");switch(this.i){case x:for(;e+g>b.length;){m=k-e;g-=m;if(r)b.set(d.subarray(a,a+m),e),e+=m,a+=m;else for(;m--;)b[e++]=d[a++];this.a=e;b=this.e();e=this.a}break;case w:for(;e+g>b.length;)b=this.e({o:2});break;default:throw Error("invalid inflate mode");}if(r)b.set(d.subarray(a,a+g),e),e+=g,a+=g;else for(;g--;)b[e++]=d[a++];this.d=a;this.a=e;this.b=b;break;case 1:this.j(z,
A);break;case 2:B(this);break;default:throw Error("unknown BTYPE: "+c);}}return this.m()};
var C=[16,17,18,0,8,7,9,6,10,5,11,4,12,3,13,2,14,1,15],D=r?new Uint16Array(C):C,E=[3,4,5,6,7,8,9,10,11,13,15,17,19,23,27,31,35,43,51,59,67,83,99,115,131,163,195,227,258,258,258],F=r?new Uint16Array(E):E,G=[0,0,0,0,0,0,0,0,1,1,1,1,2,2,2,2,3,3,3,3,4,4,4,4,5,5,5,5,0,0,0],H=r?new Uint8Array(G):G,I=[1,2,3,4,5,7,9,13,17,25,33,49,65,97,129,193,257,385,513,769,1025,1537,2049,3073,4097,6145,8193,12289,16385,24577],J=r?new Uint16Array(I):I,K=[0,0,0,0,1,1,2,2,3,3,4,4,5,5,6,6,7,7,8,8,9,9,10,10,11,11,12,12,13,
13],L=r?new Uint8Array(K):K,M=new (r?Uint8Array:Array)(288),N,O;N=0;for(O=M.length;N<O;++N)M[N]=143>=N?8:255>=N?9:279>=N?7:8;var z=u(M),P=new (r?Uint8Array:Array)(30),Q,R;Q=0;for(R=P.length;Q<R;++Q)P[Q]=5;var A=u(P);function y(c,d){for(var a=c.f,b=c.c,e=c.input,f=c.d,g;b<d;){g=e[f++];if(g===l)throw Error("input buffer is broken");a|=g<<b;b+=8}g=a&(1<<d)-1;c.f=a>>>d;c.c=b-d;c.d=f;return g}
function S(c,d){for(var a=c.f,b=c.c,e=c.input,f=c.d,g=d[0],h=d[1],k,m,s;b<h;){k=e[f++];if(k===l)break;a|=k<<b;b+=8}m=g[a&(1<<h)-1];s=m>>>16;c.f=a>>s;c.c=b-s;c.d=f;return m&65535}
function B(c){function d(a,c,b){var d,f,e,g;for(g=0;g<a;)switch(d=S(this,c),d){case 16:for(e=3+y(this,2);e--;)b[g++]=f;break;case 17:for(e=3+y(this,3);e--;)b[g++]=0;f=0;break;case 18:for(e=11+y(this,7);e--;)b[g++]=0;f=0;break;default:f=b[g++]=d}return b}var a=y(c,5)+257,b=y(c,5)+1,e=y(c,4)+4,f=new (r?Uint8Array:Array)(D.length),g,h,k,m;for(m=0;m<e;++m)f[D[m]]=y(c,3);g=u(f);h=new (r?Uint8Array:Array)(a);k=new (r?Uint8Array:Array)(b);c.j(u(d.call(c,a,g,h)),u(d.call(c,b,g,k)))}
v.prototype.j=function(c,d){var a=this.b,b=this.a;this.n=c;for(var e=a.length-258,f,g,h,k;256!==(f=S(this,c));)if(256>f)b>=e&&(this.a=b,a=this.e(),b=this.a),a[b++]=f;else{g=f-257;k=F[g];0<H[g]&&(k+=y(this,H[g]));f=S(this,d);h=J[f];0<L[f]&&(h+=y(this,L[f]));b>=e&&(this.a=b,a=this.e(),b=this.a);for(;k--;)a[b]=a[b++-h]}for(;8<=this.c;)this.c-=8,this.d--;this.a=b};
v.prototype.s=function(c,d){var a=this.b,b=this.a;this.n=c;for(var e=a.length,f,g,h,k;256!==(f=S(this,c));)if(256>f)b>=e&&(a=this.e(),e=a.length),a[b++]=f;else{g=f-257;k=F[g];0<H[g]&&(k+=y(this,H[g]));f=S(this,d);h=J[f];0<L[f]&&(h+=y(this,L[f]));b+k>e&&(a=this.e(),e=a.length);for(;k--;)a[b]=a[b++-h]}for(;8<=this.c;)this.c-=8,this.d--;this.a=b};
v.prototype.e=function(){var c=new (r?Uint8Array:Array)(this.a-32768),d=this.a-32768,a,b,e=this.b;if(r)c.set(e.subarray(32768,c.length));else{a=0;for(b=c.length;a<b;++a)c[a]=e[a+32768]}this.g.push(c);this.k+=c.length;if(r)e.set(e.subarray(d,d+32768));else for(a=0;32768>a;++a)e[a]=e[d+a];this.a=32768;return e};
v.prototype.u=function(c){var d,a=this.input.length/this.d+1|0,b,e,f,g=this.input,h=this.b;c&&("number"===typeof c.o&&(a=c.o),"number"===typeof c.q&&(a+=c.q));2>a?(b=(g.length-this.d)/this.n[2],f=258*(b/2)|0,e=f<h.length?h.length+f:h.length<<1):e=h.length*a;r?(d=new Uint8Array(e),d.set(h)):d=h;return this.b=d};
v.prototype.m=function(){var c=0,d=this.b,a=this.g,b,e=new (r?Uint8Array:Array)(this.k+(this.a-32768)),f,g,h,k;if(0===a.length)return r?this.b.subarray(32768,this.a):this.b.slice(32768,this.a);f=0;for(g=a.length;f<g;++f){b=a[f];h=0;for(k=b.length;h<k;++h)e[c++]=b[h]}f=32768;for(g=this.a;f<g;++f)e[c++]=d[f];this.g=[];return this.buffer=e};
v.prototype.r=function(){var c,d=this.a;r?this.p?(c=new Uint8Array(d),c.set(this.b.subarray(0,d))):c=this.b.subarray(0,d):(this.b.length>d&&(this.b.length=d),c=this.b);return this.buffer=c};q("Zlib.RawInflate",v);q("Zlib.RawInflate.prototype.decompress",v.prototype.t);var T={ADAPTIVE:w,BLOCK:x},U,V,W,X;if(Object.keys)U=Object.keys(T);else for(V in U=[],W=0,T)U[W++]=V;W=0;for(X=U.length;W<X;++W)V=U[W],q("Zlib.RawInflate.BufferType."+V,T[V]);}).call(this); //@ sourceMappingURL=rawinflate.min.js.map


   }).call(context);
   /*jshint +W004, +W030, +W032, +W033, +W034, +W040, +W056, +W061, +W064, +W093 */

   var uncompress = function (input) {
      var inflate = new context.Zlib.RawInflate(input);
      return inflate.decompress();
   };

   var USE_TYPEDARRAY =
      (typeof Uint8Array !== 'undefined') &&
      (typeof Uint16Array !== 'undefined') &&
      (typeof Uint32Array !== 'undefined');


   // we add the compression method for JSZip
   if(!JSZip.compressions["DEFLATE"]) {
      JSZip.compressions["DEFLATE"] = {
         magic : "\x08\x00",
         uncompress : uncompress,
         uncompressInputType : USE_TYPEDARRAY ? "uint8array" : "array"
      };
   } else {
      JSZip.compressions["DEFLATE"].uncompress = uncompress;
      JSZip.compressions["DEFLATE"].uncompressInputType = USE_TYPEDARRAY ? "uint8array" : "array";
   }
})();

// enforcing Stuk's coding style
// vim: set shiftwidth=3 softtabstop=3:

/**
 * marked - a markdown parser
 * Copyright (c) 2011-2014, Christopher Jeffrey. (MIT Licensed)
 * https://github.com/chjj/marked
 */

;(function() {

/**
 * Block-Level Grammar
 */

var block = {
  newline: /^\n+/,
  code: /^( {4}[^\n]+\n*)+/,
  fences: noop,
  hr: /^( *[-*_]){3,} *(?:\n+|$)/,
  heading: /^ *(#{1,6}) *([^\n]+?) *#* *(?:\n+|$)/,
  nptable: noop,
  lheading: /^([^\n]+)\n *(=|-){2,} *(?:\n+|$)/,
  blockquote: /^( *>[^\n]+(\n(?!def)[^\n]+)*\n*)+/,
  list: /^( *)(bull) [\s\S]+?(?:hr|def|\n{2,}(?! )(?!\1bull )\n*|\s*$)/,
  html: /^ *(?:comment *(?:\n|\s*$)|closed *(?:\n{2,}|\s*$)|closing *(?:\n{2,}|\s*$))/,
  def: /^ *\[([^\]]+)\]: *<?([^\s>]+)>?(?: +["(]([^\n]+)[")])? *(?:\n+|$)/,
  table: noop,
  paragraph: /^((?:[^\n]+\n?(?!hr|heading|lheading|blockquote|tag|def))+)\n*/,
  text: /^[^\n]+/
};

block.bullet = /(?:[*+-]|\d+\.)/;
block.item = /^( *)(bull) [^\n]*(?:\n(?!\1bull )[^\n]*)*/;
block.item = replace(block.item, 'gm')
  (/bull/g, block.bullet)
  ();

block.list = replace(block.list)
  (/bull/g, block.bullet)
  ('hr', '\\n+(?=\\1?(?:[-*_] *){3,}(?:\\n+|$))')
  ('def', '\\n+(?=' + block.def.source + ')')
  ();

block.blockquote = replace(block.blockquote)
  ('def', block.def)
  ();

block._tag = '(?!(?:'
  + 'a|em|strong|small|s|cite|q|dfn|abbr|data|time|code'
  + '|var|samp|kbd|sub|sup|i|b|u|mark|ruby|rt|rp|bdi|bdo'
  + '|span|br|wbr|ins|del|img)\\b)\\w+(?!:/|[^\\w\\s@]*@)\\b';

block.html = replace(block.html)
  ('comment', /<!--[\s\S]*?-->/)
  ('closed', /<(tag)[\s\S]+?<\/\1>/)
  ('closing', /<tag(?:"[^"]*"|'[^']*'|[^'">])*?>/)
  (/tag/g, block._tag)
  ();

block.paragraph = replace(block.paragraph)
  ('hr', block.hr)
  ('heading', block.heading)
  ('lheading', block.lheading)
  ('blockquote', block.blockquote)
  ('tag', '<' + block._tag)
  ('def', block.def)
  ();

/**
 * Normal Block Grammar
 */

block.normal = merge({}, block);

/**
 * GFM Block Grammar
 */

block.gfm = merge({}, block.normal, {
  fences: /^ *(`{3,}|~{3,})[ \.]*(\S+)? *\n([\s\S]*?)\s*\1 *(?:\n+|$)/,
  paragraph: /^/,
  heading: /^ *(#{1,6}) +([^\n]+?) *#* *(?:\n+|$)/
});

block.gfm.paragraph = replace(block.paragraph)
  ('(?!', '(?!'
    + block.gfm.fences.source.replace('\\1', '\\2') + '|'
    + block.list.source.replace('\\1', '\\3') + '|')
  ();

/**
 * GFM + Tables Block Grammar
 */

block.tables = merge({}, block.gfm, {
  nptable: /^ *(\S.*\|.*)\n *([-:]+ *\|[-| :]*)\n((?:.*\|.*(?:\n|$))*)\n*/,
  table: /^ *\|(.+)\n *\|( *[-:]+[-| :]*)\n((?: *\|.*(?:\n|$))*)\n*/
});

/**
 * Block Lexer
 */

function Lexer(options) {
  this.tokens = [];
  this.tokens.links = {};
  this.options = options || marked.defaults;
  this.rules = block.normal;

  if (this.options.gfm) {
    if (this.options.tables) {
      this.rules = block.tables;
    } else {
      this.rules = block.gfm;
    }
  }
}

/**
 * Expose Block Rules
 */

Lexer.rules = block;

/**
 * Static Lex Method
 */

Lexer.lex = function(src, options) {
  var lexer = new Lexer(options);
  return lexer.lex(src);
};

/**
 * Preprocessing
 */

Lexer.prototype.lex = function(src) {
  src = src
    .replace(/\r\n|\r/g, '\n')
    .replace(/\t/g, '    ')
    .replace(/\u00a0/g, ' ')
    .replace(/\u2424/g, '\n');

  return this.token(src, true);
};

/**
 * Lexing
 */

Lexer.prototype.token = function(src, top, bq) {
  var src = src.replace(/^ +$/gm, '')
    , next
    , loose
    , cap
    , bull
    , b
    , item
    , space
    , i
    , l;

  while (src) {
    // newline
    if (cap = this.rules.newline.exec(src)) {
      src = src.substring(cap[0].length);
      if (cap[0].length > 1) {
        this.tokens.push({
          type: 'space'
        });
      }
    }

    // code
    if (cap = this.rules.code.exec(src)) {
      src = src.substring(cap[0].length);
      cap = cap[0].replace(/^ {4}/gm, '');
      this.tokens.push({
        type: 'code',
        text: !this.options.pedantic
          ? cap.replace(/\n+$/, '')
          : cap
      });
      continue;
    }

    // fences (gfm)
    if (cap = this.rules.fences.exec(src)) {
      src = src.substring(cap[0].length);
      this.tokens.push({
        type: 'code',
        lang: cap[2],
        text: cap[3] || ''
      });
      continue;
    }

    // heading
    if (cap = this.rules.heading.exec(src)) {
      src = src.substring(cap[0].length);
      this.tokens.push({
        type: 'heading',
        depth: cap[1].length,
        text: cap[2]
      });
      continue;
    }

    // table no leading pipe (gfm)
    if (top && (cap = this.rules.nptable.exec(src))) {
      src = src.substring(cap[0].length);

      item = {
        type: 'table',
        header: cap[1].replace(/^ *| *\| *$/g, '').split(/ *\| */),
        align: cap[2].replace(/^ *|\| *$/g, '').split(/ *\| */),
        cells: cap[3].replace(/\n$/, '').split('\n')
      };

      for (i = 0; i < item.align.length; i++) {
        if (/^ *-+: *$/.test(item.align[i])) {
          item.align[i] = 'right';
        } else if (/^ *:-+: *$/.test(item.align[i])) {
          item.align[i] = 'center';
        } else if (/^ *:-+ *$/.test(item.align[i])) {
          item.align[i] = 'left';
        } else {
          item.align[i] = null;
        }
      }

      for (i = 0; i < item.cells.length; i++) {
        item.cells[i] = item.cells[i].split(/ *\| */);
      }

      this.tokens.push(item);

      continue;
    }

    // lheading
    if (cap = this.rules.lheading.exec(src)) {
      src = src.substring(cap[0].length);
      this.tokens.push({
        type: 'heading',
        depth: cap[2] === '=' ? 1 : 2,
        text: cap[1]
      });
      continue;
    }

    // hr
    if (cap = this.rules.hr.exec(src)) {
      src = src.substring(cap[0].length);
      this.tokens.push({
        type: 'hr'
      });
      continue;
    }

    // blockquote
    if (cap = this.rules.blockquote.exec(src)) {
      src = src.substring(cap[0].length);

      this.tokens.push({
        type: 'blockquote_start'
      });

      cap = cap[0].replace(/^ *> ?/gm, '');

      // Pass `top` to keep the current
      // "toplevel" state. This is exactly
      // how markdown.pl works.
      this.token(cap, top, true);

      this.tokens.push({
        type: 'blockquote_end'
      });

      continue;
    }

    // list
    if (cap = this.rules.list.exec(src)) {
      src = src.substring(cap[0].length);
      bull = cap[2];

      this.tokens.push({
        type: 'list_start',
        ordered: bull.length > 1
      });

      // Get each top-level item.
      cap = cap[0].match(this.rules.item);

      next = false;
      l = cap.length;
      i = 0;

      for (; i < l; i++) {
        item = cap[i];

        // Remove the list item's bullet
        // so it is seen as the next token.
        space = item.length;
        item = item.replace(/^ *([*+-]|\d+\.) +/, '');

        // Outdent whatever the
        // list item contains. Hacky.
        if (~item.indexOf('\n ')) {
          space -= item.length;
          item = !this.options.pedantic
            ? item.replace(new RegExp('^ {1,' + space + '}', 'gm'), '')
            : item.replace(/^ {1,4}/gm, '');
        }

        // Determine whether the next list item belongs here.
        // Backpedal if it does not belong in this list.
        if (this.options.smartLists && i !== l - 1) {
          b = block.bullet.exec(cap[i + 1])[0];
          if (bull !== b && !(bull.length > 1 && b.length > 1)) {
            src = cap.slice(i + 1).join('\n') + src;
            i = l - 1;
          }
        }

        // Determine whether item is loose or not.
        // Use: /(^|\n)(?! )[^\n]+\n\n(?!\s*$)/
        // for discount behavior.
        loose = next || /\n\n(?!\s*$)/.test(item);
        if (i !== l - 1) {
          next = item.charAt(item.length - 1) === '\n';
          if (!loose) loose = next;
        }

        this.tokens.push({
          type: loose
            ? 'loose_item_start'
            : 'list_item_start'
        });

        // Recurse.
        this.token(item, false, bq);

        this.tokens.push({
          type: 'list_item_end'
        });
      }

      this.tokens.push({
        type: 'list_end'
      });

      continue;
    }

    // html
    if (cap = this.rules.html.exec(src)) {
      src = src.substring(cap[0].length);
      this.tokens.push({
        type: this.options.sanitize
          ? 'paragraph'
          : 'html',
        pre: !this.options.sanitizer
          && (cap[1] === 'pre' || cap[1] === 'script' || cap[1] === 'style'),
        text: cap[0]
      });
      continue;
    }

    // def
    if ((!bq && top) && (cap = this.rules.def.exec(src))) {
      src = src.substring(cap[0].length);
      this.tokens.links[cap[1].toLowerCase()] = {
        href: cap[2],
        title: cap[3]
      };
      continue;
    }

    // table (gfm)
    if (top && (cap = this.rules.table.exec(src))) {
      src = src.substring(cap[0].length);

      item = {
        type: 'table',
        header: cap[1].replace(/^ *| *\| *$/g, '').split(/ *\| */),
        align: cap[2].replace(/^ *|\| *$/g, '').split(/ *\| */),
        cells: cap[3].replace(/(?: *\| *)?\n$/, '').split('\n')
      };

      for (i = 0; i < item.align.length; i++) {
        if (/^ *-+: *$/.test(item.align[i])) {
          item.align[i] = 'right';
        } else if (/^ *:-+: *$/.test(item.align[i])) {
          item.align[i] = 'center';
        } else if (/^ *:-+ *$/.test(item.align[i])) {
          item.align[i] = 'left';
        } else {
          item.align[i] = null;
        }
      }

      for (i = 0; i < item.cells.length; i++) {
        item.cells[i] = item.cells[i]
          .replace(/^ *\| *| *\| *$/g, '')
          .split(/ *\| */);
      }

      this.tokens.push(item);

      continue;
    }

    // top-level paragraph
    if (top && (cap = this.rules.paragraph.exec(src))) {
      src = src.substring(cap[0].length);
      this.tokens.push({
        type: 'paragraph',
        text: cap[1].charAt(cap[1].length - 1) === '\n'
          ? cap[1].slice(0, -1)
          : cap[1]
      });
      continue;
    }

    // text
    if (cap = this.rules.text.exec(src)) {
      // Top-level should never reach here.
      src = src.substring(cap[0].length);
      this.tokens.push({
        type: 'text',
        text: cap[0]
      });
      continue;
    }

    if (src) {
      throw new
        Error('Infinite loop on byte: ' + src.charCodeAt(0));
    }
  }

  return this.tokens;
};

/**
 * Inline-Level Grammar
 */

var inline = {
  escape: /^\\([\\`*{}\[\]()#+\-.!_>])/,
  autolink: /^<([^ >]+(@|:\/)[^ >]+)>/,
  url: noop,
  tag: /^<!--[\s\S]*?-->|^<\/?\w+(?:"[^"]*"|'[^']*'|[^'">])*?>/,
  link: /^!?\[(inside)\]\(href\)/,
  reflink: /^!?\[(inside)\]\s*\[([^\]]*)\]/,
  nolink: /^!?\[((?:\[[^\]]*\]|[^\[\]])*)\]/,
  strong: /^__([\s\S]+?)__(?!_)|^\*\*([\s\S]+?)\*\*(?!\*)/,
  em: /^\b_((?:[^_]|__)+?)_\b|^\*((?:\*\*|[\s\S])+?)\*(?!\*)/,
  code: /^(`+)\s*([\s\S]*?[^`])\s*\1(?!`)/,
  br: /^ {2,}\n(?!\s*$)/,
  del: noop,
  text: /^[\s\S]+?(?=[\\<!\[_*`]| {2,}\n|$)/
};

inline._inside = /(?:\[[^\]]*\]|[^\[\]]|\](?=[^\[]*\]))*/;
inline._href = /\s*<?([\s\S]*?)>?(?:\s+['"]([\s\S]*?)['"])?\s*/;

inline.link = replace(inline.link)
  ('inside', inline._inside)
  ('href', inline._href)
  ();

inline.reflink = replace(inline.reflink)
  ('inside', inline._inside)
  ();

/**
 * Normal Inline Grammar
 */

inline.normal = merge({}, inline);

/**
 * Pedantic Inline Grammar
 */

inline.pedantic = merge({}, inline.normal, {
  strong: /^__(?=\S)([\s\S]*?\S)__(?!_)|^\*\*(?=\S)([\s\S]*?\S)\*\*(?!\*)/,
  em: /^_(?=\S)([\s\S]*?\S)_(?!_)|^\*(?=\S)([\s\S]*?\S)\*(?!\*)/
});

/**
 * GFM Inline Grammar
 */

inline.gfm = merge({}, inline.normal, {
  escape: replace(inline.escape)('])', '~|])')(),
  url: /^(https?:\/\/[^\s<]+[^<.,:;"')\]\s])/,
  del: /^~~(?=\S)([\s\S]*?\S)~~/,
  text: replace(inline.text)
    (']|', '~]|')
    ('|', '|https?://|')
    ()
});

/**
 * GFM + Line Breaks Inline Grammar
 */

inline.breaks = merge({}, inline.gfm, {
  br: replace(inline.br)('{2,}', '*')(),
  text: replace(inline.gfm.text)('{2,}', '*')()
});

/**
 * Inline Lexer & Compiler
 */

function InlineLexer(links, options) {
  this.options = options || marked.defaults;
  this.links = links;
  this.rules = inline.normal;
  this.renderer = this.options.renderer || new Renderer;
  this.renderer.options = this.options;

  if (!this.links) {
    throw new
      Error('Tokens array requires a `links` property.');
  }

  if (this.options.gfm) {
    if (this.options.breaks) {
      this.rules = inline.breaks;
    } else {
      this.rules = inline.gfm;
    }
  } else if (this.options.pedantic) {
    this.rules = inline.pedantic;
  }
}

/**
 * Expose Inline Rules
 */

InlineLexer.rules = inline;

/**
 * Static Lexing/Compiling Method
 */

InlineLexer.output = function(src, links, options) {
  var inline = new InlineLexer(links, options);
  return inline.output(src);
};

/**
 * Lexing/Compiling
 */

InlineLexer.prototype.output = function(src) {
  var out = ''
    , link
    , text
    , href
    , cap;

  while (src) {
    // escape
    if (cap = this.rules.escape.exec(src)) {
      src = src.substring(cap[0].length);
      out += cap[1];
      continue;
    }

    // autolink
    if (cap = this.rules.autolink.exec(src)) {
      src = src.substring(cap[0].length);
      if (cap[2] === '@') {
        text = cap[1].charAt(6) === ':'
          ? this.mangle(cap[1].substring(7))
          : this.mangle(cap[1]);
        href = this.mangle('mailto:') + text;
      } else {
        text = escape(cap[1]);
        href = text;
      }
      out += this.renderer.link(href, null, text);
      continue;
    }

    // url (gfm)
    if (!this.inLink && (cap = this.rules.url.exec(src))) {
      src = src.substring(cap[0].length);
      text = escape(cap[1]);
      href = text;
      out += this.renderer.link(href, null, text);
      continue;
    }

    // tag
    if (cap = this.rules.tag.exec(src)) {
      if (!this.inLink && /^<a /i.test(cap[0])) {
        this.inLink = true;
      } else if (this.inLink && /^<\/a>/i.test(cap[0])) {
        this.inLink = false;
      }
      src = src.substring(cap[0].length);
      out += this.options.sanitize
        ? this.options.sanitizer
          ? this.options.sanitizer(cap[0])
          : escape(cap[0])
        : cap[0]
      continue;
    }

    // link
    if (cap = this.rules.link.exec(src)) {
      src = src.substring(cap[0].length);
      this.inLink = true;
      out += this.outputLink(cap, {
        href: cap[2],
        title: cap[3]
      });
      this.inLink = false;
      continue;
    }

    // reflink, nolink
    if ((cap = this.rules.reflink.exec(src))
        || (cap = this.rules.nolink.exec(src))) {
      src = src.substring(cap[0].length);
      link = (cap[2] || cap[1]).replace(/\s+/g, ' ');
      link = this.links[link.toLowerCase()];
      if (!link || !link.href) {
        out += cap[0].charAt(0);
        src = cap[0].substring(1) + src;
        continue;
      }
      this.inLink = true;
      out += this.outputLink(cap, link);
      this.inLink = false;
      continue;
    }

    // strong
    if (cap = this.rules.strong.exec(src)) {
      src = src.substring(cap[0].length);
      out += this.renderer.strong(this.output(cap[2] || cap[1]));
      continue;
    }

    // em
    if (cap = this.rules.em.exec(src)) {
      src = src.substring(cap[0].length);
      out += this.renderer.em(this.output(cap[2] || cap[1]));
      continue;
    }

    // code
    if (cap = this.rules.code.exec(src)) {
      src = src.substring(cap[0].length);
      out += this.renderer.codespan(escape(cap[2], true));
      continue;
    }

    // br
    if (cap = this.rules.br.exec(src)) {
      src = src.substring(cap[0].length);
      out += this.renderer.br();
      continue;
    }

    // del (gfm)
    if (cap = this.rules.del.exec(src)) {
      src = src.substring(cap[0].length);
      out += this.renderer.del(this.output(cap[1]));
      continue;
    }

    // text
    if (cap = this.rules.text.exec(src)) {
      src = src.substring(cap[0].length);
      out += this.renderer.text(escape(this.smartypants(cap[0])));
      continue;
    }

    if (src) {
      throw new
        Error('Infinite loop on byte: ' + src.charCodeAt(0));
    }
  }

  return out;
};

/**
 * Compile Link
 */

InlineLexer.prototype.outputLink = function(cap, link) {
  var href = escape(link.href)
    , title = link.title ? escape(link.title) : null;

  return cap[0].charAt(0) !== '!'
    ? this.renderer.link(href, title, this.output(cap[1]))
    : this.renderer.image(href, title, escape(cap[1]));
};

/**
 * Smartypants Transformations
 */

InlineLexer.prototype.smartypants = function(text) {
  if (!this.options.smartypants) return text;
  return text
    // em-dashes
    .replace(/---/g, '\u2014')
    // en-dashes
    .replace(/--/g, '\u2013')
    // opening singles
    .replace(/(^|[-\u2014/(\[{"\s])'/g, '$1\u2018')
    // closing singles & apostrophes
    .replace(/'/g, '\u2019')
    // opening doubles
    .replace(/(^|[-\u2014/(\[{\u2018\s])"/g, '$1\u201c')
    // closing doubles
    .replace(/"/g, '\u201d')
    // ellipses
    .replace(/\.{3}/g, '\u2026');
};

/**
 * Mangle Links
 */

InlineLexer.prototype.mangle = function(text) {
  if (!this.options.mangle) return text;
  var out = ''
    , l = text.length
    , i = 0
    , ch;

  for (; i < l; i++) {
    ch = text.charCodeAt(i);
    if (Math.random() > 0.5) {
      ch = 'x' + ch.toString(16);
    }
    out += '&#' + ch + ';';
  }

  return out;
};

/**
 * Renderer
 */

function Renderer(options) {
  this.options = options || {};
}

Renderer.prototype.code = function(code, lang, escaped) {
  if (this.options.highlight) {
    var out = this.options.highlight(code, lang);
    if (out != null && out !== code) {
      escaped = true;
      code = out;
    }
  }

  if (!lang) {
    return '<pre><code>'
      + (escaped ? code : escape(code, true))
      + '\n</code></pre>';
  }

  return '<pre><code class="'
    + this.options.langPrefix
    + escape(lang, true)
    + '">'
    + (escaped ? code : escape(code, true))
    + '\n</code></pre>\n';
};

Renderer.prototype.blockquote = function(quote) {
  return '<blockquote>\n' + quote + '</blockquote>\n';
};

Renderer.prototype.html = function(html) {
  return html;
};

Renderer.prototype.heading = function(text, level, raw) {
  return '<h'
    + level
    + ' id="'
    + this.options.headerPrefix
    + raw.toLowerCase().replace(/[^\w]+/g, '-')
    + '">'
    + text
    + '</h'
    + level
    + '>\n';
};

Renderer.prototype.hr = function() {
  return this.options.xhtml ? '<hr/>\n' : '<hr>\n';
};

Renderer.prototype.list = function(body, ordered) {
  var type = ordered ? 'ol' : 'ul';
  return '<' + type + '>\n' + body + '</' + type + '>\n';
};

Renderer.prototype.listitem = function(text) {
  return '<li>' + text + '</li>\n';
};

Renderer.prototype.paragraph = function(text) {
  return '<p>' + text + '</p>\n';
};

Renderer.prototype.table = function(header, body) {
  return '<table>\n'
    + '<thead>\n'
    + header
    + '</thead>\n'
    + '<tbody>\n'
    + body
    + '</tbody>\n'
    + '</table>\n';
};

Renderer.prototype.tablerow = function(content) {
  return '<tr>\n' + content + '</tr>\n';
};

Renderer.prototype.tablecell = function(content, flags) {
  var type = flags.header ? 'th' : 'td';
  var tag = flags.align
    ? '<' + type + ' style="text-align:' + flags.align + '">'
    : '<' + type + '>';
  return tag + content + '</' + type + '>\n';
};

// span level renderer
Renderer.prototype.strong = function(text) {
  return '<strong>' + text + '</strong>';
};

Renderer.prototype.em = function(text) {
  return '<em>' + text + '</em>';
};

Renderer.prototype.codespan = function(text) {
  return '<code>' + text + '</code>';
};

Renderer.prototype.br = function() {
  return this.options.xhtml ? '<br/>' : '<br>';
};

Renderer.prototype.del = function(text) {
  return '<del>' + text + '</del>';
};

Renderer.prototype.link = function(href, title, text) {
  if (this.options.sanitize) {
    try {
      var prot = decodeURIComponent(unescape(href))
        .replace(/[^\w:]/g, '')
        .toLowerCase();
    } catch (e) {
      return '';
    }
    if (prot.indexOf('javascript:') === 0 || prot.indexOf('vbscript:') === 0) {
      return '';
    }
  }
  var out = '<a href="' + href + '"';
  if (title) {
    out += ' title="' + title + '"';
  }
  out += '>' + text + '</a>';
  return out;
};

Renderer.prototype.image = function(href, title, text) {
  var out = '<img src="' + href + '" alt="' + text + '"';
  if (title) {
    out += ' title="' + title + '"';
  }
  out += this.options.xhtml ? '/>' : '>';
  return out;
};

Renderer.prototype.text = function(text) {
  return text;
};

/**
 * Parsing & Compiling
 */

function Parser(options) {
  this.tokens = [];
  this.token = null;
  this.options = options || marked.defaults;
  this.options.renderer = this.options.renderer || new Renderer;
  this.renderer = this.options.renderer;
  this.renderer.options = this.options;
}

/**
 * Static Parse Method
 */

Parser.parse = function(src, options, renderer) {
  var parser = new Parser(options, renderer);
  return parser.parse(src);
};

/**
 * Parse Loop
 */

Parser.prototype.parse = function(src) {
  this.inline = new InlineLexer(src.links, this.options, this.renderer);
  this.tokens = src.reverse();

  var out = '';
  while (this.next()) {
    out += this.tok();
  }

  return out;
};

/**
 * Next Token
 */

Parser.prototype.next = function() {
  return this.token = this.tokens.pop();
};

/**
 * Preview Next Token
 */

Parser.prototype.peek = function() {
  return this.tokens[this.tokens.length - 1] || 0;
};

/**
 * Parse Text Tokens
 */

Parser.prototype.parseText = function() {
  var body = this.token.text;

  while (this.peek().type === 'text') {
    body += '\n' + this.next().text;
  }

  return this.inline.output(body);
};

/**
 * Parse Current Token
 */

Parser.prototype.tok = function() {
  switch (this.token.type) {
    case 'space': {
      return '';
    }
    case 'hr': {
      return this.renderer.hr();
    }
    case 'heading': {
      return this.renderer.heading(
        this.inline.output(this.token.text),
        this.token.depth,
        this.token.text);
    }
    case 'code': {
      return this.renderer.code(this.token.text,
        this.token.lang,
        this.token.escaped);
    }
    case 'table': {
      var header = ''
        , body = ''
        , i
        , row
        , cell
        , flags
        , j;

      // header
      cell = '';
      for (i = 0; i < this.token.header.length; i++) {
        flags = { header: true, align: this.token.align[i] };
        cell += this.renderer.tablecell(
          this.inline.output(this.token.header[i]),
          { header: true, align: this.token.align[i] }
        );
      }
      header += this.renderer.tablerow(cell);

      for (i = 0; i < this.token.cells.length; i++) {
        row = this.token.cells[i];

        cell = '';
        for (j = 0; j < row.length; j++) {
          cell += this.renderer.tablecell(
            this.inline.output(row[j]),
            { header: false, align: this.token.align[j] }
          );
        }

        body += this.renderer.tablerow(cell);
      }
      return this.renderer.table(header, body);
    }
    case 'blockquote_start': {
      var body = '';

      while (this.next().type !== 'blockquote_end') {
        body += this.tok();
      }

      return this.renderer.blockquote(body);
    }
    case 'list_start': {
      var body = ''
        , ordered = this.token.ordered;

      while (this.next().type !== 'list_end') {
        body += this.tok();
      }

      return this.renderer.list(body, ordered);
    }
    case 'list_item_start': {
      var body = '';

      while (this.next().type !== 'list_item_end') {
        body += this.token.type === 'text'
          ? this.parseText()
          : this.tok();
      }

      return this.renderer.listitem(body);
    }
    case 'loose_item_start': {
      var body = '';

      while (this.next().type !== 'list_item_end') {
        body += this.tok();
      }

      return this.renderer.listitem(body);
    }
    case 'html': {
      var html = !this.token.pre && !this.options.pedantic
        ? this.inline.output(this.token.text)
        : this.token.text;
      return this.renderer.html(html);
    }
    case 'paragraph': {
      return this.renderer.paragraph(this.inline.output(this.token.text));
    }
    case 'text': {
      return this.renderer.paragraph(this.parseText());
    }
  }
};

/**
 * Helpers
 */

function escape(html, encode) {
  return html
    .replace(!encode ? /&(?!#?\w+;)/g : /&/g, '&amp;')
    .replace(/</g, '&lt;')
    .replace(/>/g, '&gt;')
    .replace(/"/g, '&quot;')
    .replace(/'/g, '&#39;');
}

function unescape(html) {
	// explicitly match decimal, hex, and named HTML entities 
  return html.replace(/&(#(?:\d+)|(?:#x[0-9A-Fa-f]+)|(?:\w+));?/g, function(_, n) {
    n = n.toLowerCase();
    if (n === 'colon') return ':';
    if (n.charAt(0) === '#') {
      return n.charAt(1) === 'x'
        ? String.fromCharCode(parseInt(n.substring(2), 16))
        : String.fromCharCode(+n.substring(1));
    }
    return '';
  });
}

function replace(regex, opt) {
  regex = regex.source;
  opt = opt || '';
  return function self(name, val) {
    if (!name) return new RegExp(regex, opt);
    val = val.source || val;
    val = val.replace(/(^|[^\[])\^/g, '$1');
    regex = regex.replace(name, val);
    return self;
  };
}

function noop() {}
noop.exec = noop;

function merge(obj) {
  var i = 1
    , target
    , key;

  for (; i < arguments.length; i++) {
    target = arguments[i];
    for (key in target) {
      if (Object.prototype.hasOwnProperty.call(target, key)) {
        obj[key] = target[key];
      }
    }
  }

  return obj;
}


/**
 * Marked
 */

function marked(src, opt, callback) {
  if (callback || typeof opt === 'function') {
    if (!callback) {
      callback = opt;
      opt = null;
    }

    opt = merge({}, marked.defaults, opt || {});

    var highlight = opt.highlight
      , tokens
      , pending
      , i = 0;

    try {
      tokens = Lexer.lex(src, opt)
    } catch (e) {
      return callback(e);
    }

    pending = tokens.length;

    var done = function(err) {
      if (err) {
        opt.highlight = highlight;
        return callback(err);
      }

      var out;

      try {
        out = Parser.parse(tokens, opt);
      } catch (e) {
        err = e;
      }

      opt.highlight = highlight;

      return err
        ? callback(err)
        : callback(null, out);
    };

    if (!highlight || highlight.length < 3) {
      return done();
    }

    delete opt.highlight;

    if (!pending) return done();

    for (; i < tokens.length; i++) {
      (function(token) {
        if (token.type !== 'code') {
          return --pending || done();
        }
        return highlight(token.text, token.lang, function(err, code) {
          if (err) return done(err);
          if (code == null || code === token.text) {
            return --pending || done();
          }
          token.text = code;
          token.escaped = true;
          --pending || done();
        });
      })(tokens[i]);
    }

    return;
  }
  try {
    if (opt) opt = merge({}, marked.defaults, opt);
    return Parser.parse(Lexer.lex(src, opt), opt);
  } catch (e) {
    e.message += '\nPlease report this to https://github.com/chjj/marked.';
    if ((opt || marked.defaults).silent) {
      return '<p>An error occured:</p><pre>'
        + escape(e.message + '', true)
        + '</pre>';
    }
    throw e;
  }
}

/**
 * Options
 */

marked.options =
marked.setOptions = function(opt) {
  merge(marked.defaults, opt);
  return marked;
};

marked.defaults = {
  gfm: true,
  tables: true,
  breaks: false,
  pedantic: false,
  sanitize: false,
  sanitizer: null,
  mangle: true,
  smartLists: false,
  silent: false,
  highlight: null,
  langPrefix: 'lang-',
  smartypants: false,
  headerPrefix: '',
  renderer: new Renderer,
  xhtml: false
};

/**
 * Expose
 */

marked.Parser = Parser;
marked.parser = Parser.parse;

marked.Renderer = Renderer;

marked.Lexer = Lexer;
marked.lexer = Lexer.lex;

marked.InlineLexer = InlineLexer;
marked.inlineLexer = InlineLexer.output;

marked.parse = marked;

if (typeof module !== 'undefined' && typeof exports === 'object') {
  module.exports = marked;
} else if (typeof define === 'function' && define.amd) {
  define(function() { return marked; });
} else {
  this.marked = marked;
}

}).call(function() {
  return this || (typeof window !== 'undefined' ? window : global);
}());

(function(factory) {

  // Setup highlight.js for different environments. First is Node.js or
  // CommonJS.
  if(typeof exports !== 'undefined') {
    factory(exports);
  } else {
    // Export hljs globally even when using AMD for cases when this script
    // is loaded with others that may still expect a global hljs.
    window.hljs = factory({});

    // Finally register the global hljs with AMD.
    if(typeof define === 'function' && define.amd) {
      define('hljs', [], function() {
        return window.hljs;
      });
    }
  }

}(function(hljs) {

  /* Utility functions */

  function escape(value) {
    return value.replace(/&/gm, '&amp;').replace(/</gm, '&lt;').replace(/>/gm, '&gt;');
  }

  function tag(node) {
    return node.nodeName.toLowerCase();
  }

  function testRe(re, lexeme) {
    var match = re && re.exec(lexeme);
    return match && match.index == 0;
  }

  function isNotHighlighted(language) {
    return (/^(no-?highlight|plain|text)$/i).test(language);
  }

  function blockLanguage(block) {
    var i, match, length,
        classes = block.className + ' ';

    classes += block.parentNode ? block.parentNode.className : '';

    // language-* takes precedence over non-prefixed class names
    match = (/\blang(?:uage)?-([\w-]+)\b/i).exec(classes);
    if (match) {
      return getLanguage(match[1]) ? match[1] : 'no-highlight';
    }

    classes = classes.split(/\s+/);
    for (i = 0, length = classes.length; i < length; i++) {
      if (getLanguage(classes[i]) || isNotHighlighted(classes[i])) {
        return classes[i];
      }
    }
  }

  function inherit(parent, obj) {
    var result = {}, key;
    for (key in parent)
      result[key] = parent[key];
    if (obj)
      for (key in obj)
        result[key] = obj[key];
    return result;
  }

  /* Stream merging */

  function nodeStream(node) {
    var result = [];
    (function _nodeStream(node, offset) {
      for (var child = node.firstChild; child; child = child.nextSibling) {
        if (child.nodeType == 3)
          offset += child.nodeValue.length;
        else if (child.nodeType == 1) {
          result.push({
            event: 'start',
            offset: offset,
            node: child
          });
          offset = _nodeStream(child, offset);
          // Prevent void elements from having an end tag that would actually
          // double them in the output. There are more void elements in HTML
          // but we list only those realistically expected in code display.
          if (!tag(child).match(/br|hr|img|input/)) {
            result.push({
              event: 'stop',
              offset: offset,
              node: child
            });
          }
        }
      }
      return offset;
    })(node, 0);
    return result;
  }

  function mergeStreams(original, highlighted, value) {
    var processed = 0;
    var result = '';
    var nodeStack = [];

    function selectStream() {
      if (!original.length || !highlighted.length) {
        return original.length ? original : highlighted;
      }
      if (original[0].offset != highlighted[0].offset) {
        return (original[0].offset < highlighted[0].offset) ? original : highlighted;
      }

      /*
      To avoid starting the stream just before it should stop the order is
      ensured that original always starts first and closes last:

      if (event1 == 'start' && event2 == 'start')
        return original;
      if (event1 == 'start' && event2 == 'stop')
        return highlighted;
      if (event1 == 'stop' && event2 == 'start')
        return original;
      if (event1 == 'stop' && event2 == 'stop')
        return highlighted;

      ... which is collapsed to:
      */
      return highlighted[0].event == 'start' ? original : highlighted;
    }

    function open(node) {
      function attr_str(a) {return ' ' + a.nodeName + '="' + escape(a.value) + '"';}
      result += '<' + tag(node) + Array.prototype.map.call(node.attributes, attr_str).join('') + '>';
    }

    function close(node) {
      result += '</' + tag(node) + '>';
    }

    function render(event) {
      (event.event == 'start' ? open : close)(event.node);
    }

    while (original.length || highlighted.length) {
      var stream = selectStream();
      result += escape(value.substr(processed, stream[0].offset - processed));
      processed = stream[0].offset;
      if (stream == original) {
        /*
        On any opening or closing tag of the original markup we first close
        the entire highlighted node stack, then render the original tag along
        with all the following original tags at the same offset and then
        reopen all the tags on the highlighted stack.
        */
        nodeStack.reverse().forEach(close);
        do {
          render(stream.splice(0, 1)[0]);
          stream = selectStream();
        } while (stream == original && stream.length && stream[0].offset == processed);
        nodeStack.reverse().forEach(open);
      } else {
        if (stream[0].event == 'start') {
          nodeStack.push(stream[0].node);
        } else {
          nodeStack.pop();
        }
        render(stream.splice(0, 1)[0]);
      }
    }
    return result + escape(value.substr(processed));
  }

  /* Initialization */

  function compileLanguage(language) {

    function reStr(re) {
        return (re && re.source) || re;
    }

    function langRe(value, global) {
      return new RegExp(
        reStr(value),
        'm' + (language.case_insensitive ? 'i' : '') + (global ? 'g' : '')
      );
    }

    function compileMode(mode, parent) {
      if (mode.compiled)
        return;
      mode.compiled = true;

      mode.keywords = mode.keywords || mode.beginKeywords;
      if (mode.keywords) {
        var compiled_keywords = {};

        var flatten = function(className, str) {
          if (language.case_insensitive) {
            str = str.toLowerCase();
          }
          str.split(' ').forEach(function(kw) {
            var pair = kw.split('|');
            compiled_keywords[pair[0]] = [className, pair[1] ? Number(pair[1]) : 1];
          });
        };

        if (typeof mode.keywords == 'string') { // string
          flatten('keyword', mode.keywords);
        } else {
          Object.keys(mode.keywords).forEach(function (className) {
            flatten(className, mode.keywords[className]);
          });
        }
        mode.keywords = compiled_keywords;
      }
      mode.lexemesRe = langRe(mode.lexemes || /\b\w+\b/, true);

      if (parent) {
        if (mode.beginKeywords) {
          mode.begin = '\\b(' + mode.beginKeywords.split(' ').join('|') + ')\\b';
        }
        if (!mode.begin)
          mode.begin = /\B|\b/;
        mode.beginRe = langRe(mode.begin);
        if (!mode.end && !mode.endsWithParent)
          mode.end = /\B|\b/;
        if (mode.end)
          mode.endRe = langRe(mode.end);
        mode.terminator_end = reStr(mode.end) || '';
        if (mode.endsWithParent && parent.terminator_end)
          mode.terminator_end += (mode.end ? '|' : '') + parent.terminator_end;
      }
      if (mode.illegal)
        mode.illegalRe = langRe(mode.illegal);
      if (mode.relevance === undefined)
        mode.relevance = 1;
      if (!mode.contains) {
        mode.contains = [];
      }
      var expanded_contains = [];
      mode.contains.forEach(function(c) {
        if (c.variants) {
          c.variants.forEach(function(v) {expanded_contains.push(inherit(c, v));});
        } else {
          expanded_contains.push(c == 'self' ? mode : c);
        }
      });
      mode.contains = expanded_contains;
      mode.contains.forEach(function(c) {compileMode(c, mode);});

      if (mode.starts) {
        compileMode(mode.starts, parent);
      }

      var terminators =
        mode.contains.map(function(c) {
          return c.beginKeywords ? '\\.?(' + c.begin + ')\\.?' : c.begin;
        })
        .concat([mode.terminator_end, mode.illegal])
        .map(reStr)
        .filter(Boolean);
      mode.terminators = terminators.length ? langRe(terminators.join('|'), true) : {exec: function(/*s*/) {return null;}};
    }

    compileMode(language);
  }

  /*
  Core highlighting function. Accepts a language name, or an alias, and a
  string with the code to highlight. Returns an object with the following
  properties:

  - relevance (int)
  - value (an HTML string with highlighting markup)

  */
  function highlight(name, value, ignore_illegals, continuation) {

    function subMode(lexeme, mode) {
      for (var i = 0; i < mode.contains.length; i++) {
        if (testRe(mode.contains[i].beginRe, lexeme)) {
          return mode.contains[i];
        }
      }
    }

    function endOfMode(mode, lexeme) {
      if (testRe(mode.endRe, lexeme)) {
        while (mode.endsParent && mode.parent) {
          mode = mode.parent;
        }
        return mode;
      }
      if (mode.endsWithParent) {
        return endOfMode(mode.parent, lexeme);
      }
    }

    function isIllegal(lexeme, mode) {
      return !ignore_illegals && testRe(mode.illegalRe, lexeme);
    }

    function keywordMatch(mode, match) {
      var match_str = language.case_insensitive ? match[0].toLowerCase() : match[0];
      return mode.keywords.hasOwnProperty(match_str) && mode.keywords[match_str];
    }

    function buildSpan(classname, insideSpan, leaveOpen, noPrefix) {
      var classPrefix = noPrefix ? '' : options.classPrefix,
          openSpan    = '<span class="' + classPrefix,
          closeSpan   = leaveOpen ? '' : '</span>';

      openSpan += classname + '">';

      return openSpan + insideSpan + closeSpan;
    }

    function processKeywords() {
      if (!top.keywords)
        return escape(mode_buffer);
      var result = '';
      var last_index = 0;
      top.lexemesRe.lastIndex = 0;
      var match = top.lexemesRe.exec(mode_buffer);
      while (match) {
        result += escape(mode_buffer.substr(last_index, match.index - last_index));
        var keyword_match = keywordMatch(top, match);
        if (keyword_match) {
          relevance += keyword_match[1];
          result += buildSpan(keyword_match[0], escape(match[0]));
        } else {
          result += escape(match[0]);
        }
        last_index = top.lexemesRe.lastIndex;
        match = top.lexemesRe.exec(mode_buffer);
      }
      return result + escape(mode_buffer.substr(last_index));
    }

    function processSubLanguage() {
      var explicit = typeof top.subLanguage == 'string';
      if (explicit && !languages[top.subLanguage]) {
        return escape(mode_buffer);
      }

      var result = explicit ?
                   highlight(top.subLanguage, mode_buffer, true, continuations[top.subLanguage]) :
                   highlightAuto(mode_buffer, top.subLanguage.length ? top.subLanguage : undefined);

      // Counting embedded language score towards the host language may be disabled
      // with zeroing the containing mode relevance. Usecase in point is Markdown that
      // allows XML everywhere and makes every XML snippet to have a much larger Markdown
      // score.
      if (top.relevance > 0) {
        relevance += result.relevance;
      }
      if (explicit) {
        continuations[top.subLanguage] = result.top;
      }
      return buildSpan(result.language, result.value, false, true);
    }

    function processBuffer() {
      return top.subLanguage !== undefined ? processSubLanguage() : processKeywords();
    }

    function startNewMode(mode, lexeme) {
      var markup = mode.className? buildSpan(mode.className, '', true): '';
      if (mode.returnBegin) {
        result += markup;
        mode_buffer = '';
      } else if (mode.excludeBegin) {
        result += escape(lexeme) + markup;
        mode_buffer = '';
      } else {
        result += markup;
        mode_buffer = lexeme;
      }
      top = Object.create(mode, {parent: {value: top}});
    }

    function processLexeme(buffer, lexeme) {

      mode_buffer += buffer;
      if (lexeme === undefined) {
        result += processBuffer();
        return 0;
      }

      var new_mode = subMode(lexeme, top);
      if (new_mode) {
        result += processBuffer();
        startNewMode(new_mode, lexeme);
        return new_mode.returnBegin ? 0 : lexeme.length;
      }

      var end_mode = endOfMode(top, lexeme);
      if (end_mode) {
        var origin = top;
        if (!(origin.returnEnd || origin.excludeEnd)) {
          mode_buffer += lexeme;
        }
        result += processBuffer();
        do {
          if (top.className) {
            result += '</span>';
          }
          relevance += top.relevance;
          top = top.parent;
        } while (top != end_mode.parent);
        if (origin.excludeEnd) {
          result += escape(lexeme);
        }
        mode_buffer = '';
        if (end_mode.starts) {
          startNewMode(end_mode.starts, '');
        }
        return origin.returnEnd ? 0 : lexeme.length;
      }

      if (isIllegal(lexeme, top))
        throw new Error('Illegal lexeme "' + lexeme + '" for mode "' + (top.className || '<unnamed>') + '"');

      /*
      Parser should not reach this point as all types of lexemes should be caught
      earlier, but if it does due to some bug make sure it advances at least one
      character forward to prevent infinite looping.
      */
      mode_buffer += lexeme;
      return lexeme.length || 1;
    }

    var language = getLanguage(name);
    if (!language) {
      throw new Error('Unknown language: "' + name + '"');
    }

    compileLanguage(language);
    var top = continuation || language;
    var continuations = {}; // keep continuations for sub-languages
    var result = '', current;
    for(current = top; current != language; current = current.parent) {
      if (current.className) {
        result = buildSpan(current.className, '', true) + result;
      }
    }
    var mode_buffer = '';
    var relevance = 0;
    try {
      var match, count, index = 0;
      while (true) {
        top.terminators.lastIndex = index;
        match = top.terminators.exec(value);
        if (!match)
          break;
        count = processLexeme(value.substr(index, match.index - index), match[0]);
        index = match.index + count;
      }
      processLexeme(value.substr(index));
      for(current = top; current.parent; current = current.parent) { // close dangling modes
        if (current.className) {
          result += '</span>';
        }
      }
      return {
        relevance: relevance,
        value: result,
        language: name,
        top: top
      };
    } catch (e) {
      if (e.message.indexOf('Illegal') != -1) {
        return {
          relevance: 0,
          value: escape(value)
        };
      } else {
        throw e;
      }
    }
  }

  /*
  Highlighting with language detection. Accepts a string with the code to
  highlight. Returns an object with the following properties:

  - language (detected language)
  - relevance (int)
  - value (an HTML string with highlighting markup)
  - second_best (object with the same structure for second-best heuristically
    detected language, may be absent)

  */
  function highlightAuto(text, languageSubset) {
    languageSubset = languageSubset || options.languages || Object.keys(languages);
    var result = {
      relevance: 0,
      value: escape(text)
    };
    var second_best = result;
    languageSubset.forEach(function(name) {
      if (!getLanguage(name)) {
        return;
      }
      var current = highlight(name, text, false);
      current.language = name;
      if (current.relevance > second_best.relevance) {
        second_best = current;
      }
      if (current.relevance > result.relevance) {
        second_best = result;
        result = current;
      }
    });
    if (second_best.language) {
      result.second_best = second_best;
    }
    return result;
  }

  /*
  Post-processing of the highlighted markup:

  - replace TABs with something more useful
  - replace real line-breaks with '<br>' for non-pre containers

  */
  function fixMarkup(value) {
    if (options.tabReplace) {
      value = value.replace(/^((<[^>]+>|\t)+)/gm, function(match, p1 /*..., offset, s*/) {
        return p1.replace(/\t/g, options.tabReplace);
      });
    }
    if (options.useBR) {
      value = value.replace(/\n/g, '<br>');
    }
    return value;
  }

  function buildClassName(prevClassName, currentLang, resultLang) {
    var language = currentLang ? aliases[currentLang] : resultLang,
        result   = [prevClassName.trim()];

    if (!prevClassName.match(/\bhljs\b/)) {
      result.push('hljs');
    }

    if (prevClassName.indexOf(language) === -1) {
      result.push(language);
    }

    return result.join(' ').trim();
  }

  /*
  Applies highlighting to a DOM node containing code. Accepts a DOM node and
  two optional parameters for fixMarkup.
  */
  function highlightBlock(block) {
    var language = blockLanguage(block);
    if (isNotHighlighted(language))
        return;

    var node;
    if (options.useBR) {
      node = document.createElementNS('http://www.w3.org/1999/xhtml', 'div');
      node.innerHTML = block.innerHTML.replace(/\n/g, '').replace(/<br[ \/]*>/g, '\n');
    } else {
      node = block;
    }
    var text = node.textContent;
    var result = language ? highlight(language, text, true) : highlightAuto(text);

    var originalStream = nodeStream(node);
    if (originalStream.length) {
      var resultNode = document.createElementNS('http://www.w3.org/1999/xhtml', 'div');
      resultNode.innerHTML = result.value;
      result.value = mergeStreams(originalStream, nodeStream(resultNode), text);
    }
    result.value = fixMarkup(result.value);

    block.innerHTML = result.value;
    block.className = buildClassName(block.className, language, result.language);
    block.result = {
      language: result.language,
      re: result.relevance
    };
    if (result.second_best) {
      block.second_best = {
        language: result.second_best.language,
        re: result.second_best.relevance
      };
    }
  }

  var options = {
    classPrefix: 'hljs-',
    tabReplace: null,
    useBR: false,
    languages: undefined
  };

  /*
  Updates highlight.js global options with values passed in the form of an object
  */
  function configure(user_options) {
    options = inherit(options, user_options);
  }

  /*
  Applies highlighting to all <pre><code>..</code></pre> blocks on a page.
  */
  function initHighlighting() {
    if (initHighlighting.called)
      return;
    initHighlighting.called = true;

    var blocks = document.querySelectorAll('pre code');
    Array.prototype.forEach.call(blocks, highlightBlock);
  }

  /*
  Attaches highlighting to the page load event.
  */
  function initHighlightingOnLoad() {
    addEventListener('DOMContentLoaded', initHighlighting, false);
    addEventListener('load', initHighlighting, false);
  }

  var languages = {};
  var aliases = {};

  function registerLanguage(name, language) {
    var lang = languages[name] = language(hljs);
    if (lang.aliases) {
      lang.aliases.forEach(function(alias) {aliases[alias] = name;});
    }
  }

  function listLanguages() {
    return Object.keys(languages);
  }

  function getLanguage(name) {
    name = (name || '').toLowerCase();
    return languages[name] || languages[aliases[name]];
  }

  /* Interface definition */

  hljs.highlight = highlight;
  hljs.highlightAuto = highlightAuto;
  hljs.fixMarkup = fixMarkup;
  hljs.highlightBlock = highlightBlock;
  hljs.configure = configure;
  hljs.initHighlighting = initHighlighting;
  hljs.initHighlightingOnLoad = initHighlightingOnLoad;
  hljs.registerLanguage = registerLanguage;
  hljs.listLanguages = listLanguages;
  hljs.getLanguage = getLanguage;
  hljs.inherit = inherit;

  // Common regexps
  hljs.IDENT_RE = '[a-zA-Z]\\w*';
  hljs.UNDERSCORE_IDENT_RE = '[a-zA-Z_]\\w*';
  hljs.NUMBER_RE = '\\b\\d+(\\.\\d+)?';
  hljs.C_NUMBER_RE = '(\\b0[xX][a-fA-F0-9]+|(\\b\\d+(\\.\\d*)?|\\.\\d+)([eE][-+]?\\d+)?)'; // 0x..., 0..., decimal, float
  hljs.BINARY_NUMBER_RE = '\\b(0b[01]+)'; // 0b...
  hljs.RE_STARTERS_RE = '!|!=|!==|%|%=|&|&&|&=|\\*|\\*=|\\+|\\+=|,|-|-=|/=|/|:|;|<<|<<=|<=|<|===|==|=|>>>=|>>=|>=|>>>|>>|>|\\?|\\[|\\{|\\(|\\^|\\^=|\\||\\|=|\\|\\||~';

  // Common modes
  hljs.BACKSLASH_ESCAPE = {
    begin: '\\\\[\\s\\S]', relevance: 0
  };
  hljs.APOS_STRING_MODE = {
    className: 'string',
    begin: '\'', end: '\'',
    illegal: '\\n',
    contains: [hljs.BACKSLASH_ESCAPE]
  };
  hljs.QUOTE_STRING_MODE = {
    className: 'string',
    begin: '"', end: '"',
    illegal: '\\n',
    contains: [hljs.BACKSLASH_ESCAPE]
  };
  hljs.PHRASAL_WORDS_MODE = {
    begin: /\b(a|an|the|are|I|I'm|isn't|don't|doesn't|won't|but|just|should|pretty|simply|enough|gonna|going|wtf|so|such|will|you|your|like)\b/
  };
  hljs.COMMENT = function (begin, end, inherits) {
    var mode = hljs.inherit(
      {
        className: 'comment',
        begin: begin, end: end,
        contains: []
      },
      inherits || {}
    );
    mode.contains.push(hljs.PHRASAL_WORDS_MODE);
    mode.contains.push({
      className: 'doctag',
      begin: "(?:TODO|FIXME|NOTE|BUG|XXX):",
      relevance: 0
    });
    return mode;
  };
  hljs.C_LINE_COMMENT_MODE = hljs.COMMENT('//', '$');
  hljs.C_BLOCK_COMMENT_MODE = hljs.COMMENT('/\\*', '\\*/');
  hljs.HASH_COMMENT_MODE = hljs.COMMENT('#', '$');
  hljs.NUMBER_MODE = {
    className: 'number',
    begin: hljs.NUMBER_RE,
    relevance: 0
  };
  hljs.C_NUMBER_MODE = {
    className: 'number',
    begin: hljs.C_NUMBER_RE,
    relevance: 0
  };
  hljs.BINARY_NUMBER_MODE = {
    className: 'number',
    begin: hljs.BINARY_NUMBER_RE,
    relevance: 0
  };
  hljs.CSS_NUMBER_MODE = {
    className: 'number',
    begin: hljs.NUMBER_RE + '(' +
      '%|em|ex|ch|rem'  +
      '|vw|vh|vmin|vmax' +
      '|cm|mm|in|pt|pc|px' +
      '|deg|grad|rad|turn' +
      '|s|ms' +
      '|Hz|kHz' +
      '|dpi|dpcm|dppx' +
      ')?',
    relevance: 0
  };
  hljs.REGEXP_MODE = {
    className: 'regexp',
    begin: /\//, end: /\/[gimuy]*/,
    illegal: /\n/,
    contains: [
      hljs.BACKSLASH_ESCAPE,
      {
        begin: /\[/, end: /\]/,
        relevance: 0,
        contains: [hljs.BACKSLASH_ESCAPE]
      }
    ]
  };
  hljs.TITLE_MODE = {
    className: 'title',
    begin: hljs.IDENT_RE,
    relevance: 0
  };
  hljs.UNDERSCORE_TITLE_MODE = {
    className: 'title',
    begin: hljs.UNDERSCORE_IDENT_RE,
    relevance: 0
  };

hljs.registerLanguage('1c', function(hljs){
  var IDENT_RE_RU = '[a-zA-Zа-яА-Я][a-zA-Z0-9_а-яА-Я]*';
  var OneS_KEYWORDS = 'возврат дата для если и или иначе иначеесли исключение конецесли ' +
    'конецпопытки конецпроцедуры конецфункции конеццикла константа не перейти перем ' +
    'перечисление по пока попытка прервать продолжить процедура строка тогда фс функция цикл ' +
    'число экспорт';
  var OneS_BUILT_IN = 'ansitooem oemtoansi ввестивидсубконто ввестидату ввестизначение ' +
    'ввестиперечисление ввестипериод ввестиплансчетов ввестистроку ввестичисло вопрос ' +
    'восстановитьзначение врег выбранныйплансчетов вызватьисключение датагод датамесяц ' +
    'датачисло добавитьмесяц завершитьработусистемы заголовоксистемы записьжурналарегистрации ' +
    'запуститьприложение зафиксироватьтранзакцию значениевстроку значениевстрокувнутр ' +
    'значениевфайл значениеизстроки значениеизстрокивнутр значениеизфайла имякомпьютера ' +
    'имяпользователя каталогвременныхфайлов каталогиб каталогпользователя каталогпрограммы ' +
    'кодсимв командасистемы конгода конецпериодаби конецрассчитанногопериодаби ' +
    'конецстандартногоинтервала конквартала конмесяца коннедели лев лог лог10 макс ' +
    'максимальноеколичествосубконто мин монопольныйрежим названиеинтерфейса названиенабораправ ' +
    'назначитьвид назначитьсчет найти найтипомеченныенаудаление найтиссылки началопериодаби ' +
    'началостандартногоинтервала начатьтранзакцию начгода начквартала начмесяца начнедели ' +
    'номерднягода номерднянедели номернеделигода нрег обработкаожидания окр описаниеошибки ' +
    'основнойжурналрасчетов основнойплансчетов основнойязык открытьформу открытьформумодально ' +
    'отменитьтранзакцию очиститьокносообщений периодстр полноеимяпользователя получитьвремята ' +
    'получитьдатута получитьдокументта получитьзначенияотбора получитьпозициюта ' +
    'получитьпустоезначение получитьта прав праводоступа предупреждение префиксавтонумерации ' +
    'пустаястрока пустоезначение рабочаядаттьпустоезначение рабочаядата разделительстраниц ' +
    'разделительстрок разм разобратьпозициюдокумента рассчитатьрегистрына ' +
    'рассчитатьрегистрыпо сигнал симв символтабуляции создатьобъект сокрл сокрлп сокрп ' +
    'сообщить состояние сохранитьзначение сред статусвозврата стрдлина стрзаменить ' +
    'стрколичествострок стрполучитьстроку  стрчисловхождений сформироватьпозициюдокумента ' +
    'счетпокоду текущаядата текущеевремя типзначения типзначениястр удалитьобъекты ' +
    'установитьтана установитьтапо фиксшаблон формат цел шаблон';
  var DQUOTE =  {className: 'dquote',  begin: '""'};
  var STR_START = {
      className: 'string',
      begin: '"', end: '"|$',
      contains: [DQUOTE]
    };
  var STR_CONT = {
    className: 'string',
    begin: '\\|', end: '"|$',
    contains: [DQUOTE]
  };

  return {
    case_insensitive: true,
    lexemes: IDENT_RE_RU,
    keywords: {keyword: OneS_KEYWORDS, built_in: OneS_BUILT_IN},
    contains: [
      hljs.C_LINE_COMMENT_MODE,
      hljs.NUMBER_MODE,
      STR_START, STR_CONT,
      {
        className: 'function',
        begin: '(процедура|функция)', end: '$',
        lexemes: IDENT_RE_RU,
        keywords: 'процедура функция',
        contains: [
          hljs.inherit(hljs.TITLE_MODE, {begin: IDENT_RE_RU}),
          {
            className: 'tail',
            endsWithParent: true,
            contains: [
              {
                className: 'params',
                begin: '\\(', end: '\\)',
                lexemes: IDENT_RE_RU,
                keywords: 'знач',
                contains: [STR_START, STR_CONT]
              },
              {
                className: 'export',
                begin: 'экспорт', endsWithParent: true,
                lexemes: IDENT_RE_RU,
                keywords: 'экспорт',
                contains: [hljs.C_LINE_COMMENT_MODE]
              }
            ]
          },
          hljs.C_LINE_COMMENT_MODE
        ]
      },
      {className: 'preprocessor', begin: '#', end: '$'},
      {className: 'date', begin: '\'\\d{2}\\.\\d{2}\\.(\\d{2}|\\d{4})\''}
    ]
  };
});

hljs.registerLanguage('accesslog', function(hljs) {
  return {
    contains: [
      // IP
      {
        className: 'number',
        begin: '\\b\\d{1,3}\\.\\d{1,3}\\.\\d{1,3}\\.\\d{1,3}(:\\d{1,5})?\\b'
      },
      // Other numbers
      {
        className: 'number',
        begin: '\\b\\d+\\b',
        relevance: 0
      },
      // Requests
      {
        className: 'string',
        begin: '"(GET|POST|HEAD|PUT|DELETE|CONNECT|OPTIONS|PATCH|TRACE)', end: '"',
        keywords: 'GET POST HEAD PUT DELETE CONNECT OPTIONS PATCH TRACE',
        illegal: '\\n',
        relevance: 10
      },
      // Dates
      {
        className: 'string',
        begin: /\[/, end: /\]/,
        illegal: '\\n'
      },
      // Strings
      {
        className: 'string',
        begin: '"', end: '"',
        illegal: '\\n'
      }
    ]
  };
});

hljs.registerLanguage('actionscript', function(hljs) {
  var IDENT_RE = '[a-zA-Z_$][a-zA-Z0-9_$]*';
  var IDENT_FUNC_RETURN_TYPE_RE = '([*]|[a-zA-Z_$][a-zA-Z0-9_$]*)';

  var AS3_REST_ARG_MODE = {
    className: 'rest_arg',
    begin: '[.]{3}', end: IDENT_RE,
    relevance: 10
  };

  return {
    aliases: ['as'],
    keywords: {
      keyword: 'as break case catch class const continue default delete do dynamic each ' +
        'else extends final finally for function get if implements import in include ' +
        'instanceof interface internal is namespace native new override package private ' +
        'protected public return set static super switch this throw try typeof use var void ' +
        'while with',
      literal: 'true false null undefined'
    },
    contains: [
      hljs.APOS_STRING_MODE,
      hljs.QUOTE_STRING_MODE,
      hljs.C_LINE_COMMENT_MODE,
      hljs.C_BLOCK_COMMENT_MODE,
      hljs.C_NUMBER_MODE,
      {
        className: 'package',
        beginKeywords: 'package', end: '{',
        contains: [hljs.TITLE_MODE]
      },
      {
        className: 'class',
        beginKeywords: 'class interface', end: '{', excludeEnd: true,
        contains: [
          {
            beginKeywords: 'extends implements'
          },
          hljs.TITLE_MODE
        ]
      },
      {
        className: 'preprocessor',
        beginKeywords: 'import include', end: ';'
      },
      {
        className: 'function',
        beginKeywords: 'function', end: '[{;]', excludeEnd: true,
        illegal: '\\S',
        contains: [
          hljs.TITLE_MODE,
          {
            className: 'params',
            begin: '\\(', end: '\\)',
            contains: [
              hljs.APOS_STRING_MODE,
              hljs.QUOTE_STRING_MODE,
              hljs.C_LINE_COMMENT_MODE,
              hljs.C_BLOCK_COMMENT_MODE,
              AS3_REST_ARG_MODE
            ]
          },
          {
            className: 'type',
            begin: ':',
            end: IDENT_FUNC_RETURN_TYPE_RE,
            relevance: 10
          }
        ]
      }
    ],
    illegal: /#/
  };
});

hljs.registerLanguage('apache', function(hljs) {
  var NUMBER = {className: 'number', begin: '[\\$%]\\d+'};
  return {
    aliases: ['apacheconf'],
    case_insensitive: true,
    contains: [
      hljs.HASH_COMMENT_MODE,
      {className: 'tag', begin: '</?', end: '>'},
      {
        className: 'keyword',
        begin: /\w+/,
        relevance: 0,
        // keywords aren’t needed for highlighting per se, they only boost relevance
        // for a very generally defined mode (starts with a word, ends with line-end
        keywords: {
          common:
            'order deny allow setenv rewriterule rewriteengine rewritecond documentroot ' +
            'sethandler errordocument loadmodule options header listen serverroot ' +
            'servername'
        },
        starts: {
          end: /$/,
          relevance: 0,
          keywords: {
            literal: 'on off all'
          },
          contains: [
            {
              className: 'sqbracket',
              begin: '\\s\\[', end: '\\]$'
            },
            {
              className: 'cbracket',
              begin: '[\\$%]\\{', end: '\\}',
              contains: ['self', NUMBER]
            },
            NUMBER,
            hljs.QUOTE_STRING_MODE
          ]
        }
      }
    ],
    illegal: /\S/
  };
});

hljs.registerLanguage('applescript', function(hljs) {
  var STRING = hljs.inherit(hljs.QUOTE_STRING_MODE, {illegal: ''});
  var PARAMS = {
    className: 'params',
    begin: '\\(', end: '\\)',
    contains: ['self', hljs.C_NUMBER_MODE, STRING]
  };
  var COMMENT_MODE_1 = hljs.COMMENT('--', '$');
  var COMMENT_MODE_2 = hljs.COMMENT(
    '\\(\\*',
    '\\*\\)',
    {
      contains: ['self', COMMENT_MODE_1] //allow nesting
    }
  );
  var COMMENTS = [
    COMMENT_MODE_1,
    COMMENT_MODE_2,
    hljs.HASH_COMMENT_MODE
  ];

  return {
    aliases: ['osascript'],
    keywords: {
      keyword:
        'about above after against and around as at back before beginning ' +
        'behind below beneath beside between but by considering ' +
        'contain contains continue copy div does eighth else end equal ' +
        'equals error every exit fifth first for fourth from front ' +
        'get given global if ignoring in into is it its last local me ' +
        'middle mod my ninth not of on onto or over prop property put ref ' +
        'reference repeat returning script second set seventh since ' +
        'sixth some tell tenth that the|0 then third through thru ' +
        'timeout times to transaction try until where while whose with ' +
        'without',
      constant:
        'AppleScript false linefeed return pi quote result space tab true',
      type:
        'alias application boolean class constant date file integer list ' +
        'number real record string text',
      command:
        'activate beep count delay launch log offset read round ' +
        'run say summarize write',
      property:
        'character characters contents day frontmost id item length ' +
        'month name paragraph paragraphs rest reverse running time version ' +
        'weekday word words year'
    },
    contains: [
      STRING,
      hljs.C_NUMBER_MODE,
      {
        className: 'type',
        begin: '\\bPOSIX file\\b'
      },
      {
        className: 'command',
        begin:
          '\\b(clipboard info|the clipboard|info for|list (disks|folder)|' +
          'mount volume|path to|(close|open for) access|(get|set) eof|' +
          'current date|do shell script|get volume settings|random number|' +
          'set volume|system attribute|system info|time to GMT|' +
          '(load|run|store) script|scripting components|' +
          'ASCII (character|number)|localized string|' +
          'choose (application|color|file|file name|' +
          'folder|from list|remote application|URL)|' +
          'display (alert|dialog))\\b|^\\s*return\\b'
      },
      {
        className: 'constant',
        begin:
          '\\b(text item delimiters|current application|missing value)\\b'
      },
      {
        className: 'keyword',
        begin:
          '\\b(apart from|aside from|instead of|out of|greater than|' +
          "isn't|(doesn't|does not) (equal|come before|come after|contain)|" +
          '(greater|less) than( or equal)?|(starts?|ends|begins?) with|' +
          'contained by|comes (before|after)|a (ref|reference))\\b'
      },
      {
        className: 'property',
        begin:
          '\\b(POSIX path|(date|time) string|quoted form)\\b'
      },
      {
        className: 'function_start',
        beginKeywords: 'on',
        illegal: '[${=;\\n]',
        contains: [hljs.UNDERSCORE_TITLE_MODE, PARAMS]
      }
    ].concat(COMMENTS),
    illegal: '//|->|=>|\\[\\['
  };
});

hljs.registerLanguage('armasm', function(hljs) {
    //local labels: %?[FB]?[AT]?\d{1,2}\w+
  return {
    case_insensitive: true,
    aliases: ['arm'],
    lexemes: '\\.?' + hljs.IDENT_RE,
    keywords: {
      literal:
        'r0 r1 r2 r3 r4 r5 r6 r7 r8 r9 r10 r11 r12 r13 r14 r15 '+ //standard registers
        'pc lr sp ip sl sb fp '+ //typical regs plus backward compatibility
        'a1 a2 a3 a4 v1 v2 v3 v4 v5 v6 v7 v8 f0 f1 f2 f3 f4 f5 f6 f7 '+ //more regs and fp
        'p0 p1 p2 p3 p4 p5 p6 p7 p8 p9 p10 p11 p12 p13 p14 p15 '+ //coprocessor regs
        'c0 c1 c2 c3 c4 c5 c6 c7 c8 c9 c10 c11 c12 c13 c14 c15 '+ //more coproc
        'q0 q1 q2 q3 q4 q5 q6 q7 q8 q9 q10 q11 q12 q13 q14 q15 '+ //advanced SIMD NEON regs

        //program status registers
        'cpsr_c cpsr_x cpsr_s cpsr_f cpsr_cx cpsr_cxs cpsr_xs cpsr_xsf cpsr_sf cpsr_cxsf '+
        'spsr_c spsr_x spsr_s spsr_f spsr_cx spsr_cxs spsr_xs spsr_xsf spsr_sf spsr_cxsf '+

        //NEON and VFP registers
        's0 s1 s2 s3 s4 s5 s6 s7 s8 s9 s10 s11 s12 s13 s14 s15 '+
        's16 s17 s18 s19 s20 s21 s22 s23 s24 s25 s26 s27 s28 s29 s30 s31 '+
        'd0 d1 d2 d3 d4 d5 d6 d7 d8 d9 d10 d11 d12 d13 d14 d15 '+
        'd16 d17 d18 d19 d20 d21 d22 d23 d24 d25 d26 d27 d28 d29 d30 d31 ',
    preprocessor:
        //GNU preprocs
        '.2byte .4byte .align .ascii .asciz .balign .byte .code .data .else .end .endif .endm .endr .equ .err .exitm .extern .global .hword .if .ifdef .ifndef .include .irp .long .macro .rept .req .section .set .skip .space .text .word .arm .thumb .code16 .code32 .force_thumb .thumb_func .ltorg '+
        //ARM directives
        'ALIAS ALIGN ARM AREA ASSERT ATTR CN CODE CODE16 CODE32 COMMON CP DATA DCB DCD DCDU DCDO DCFD DCFDU DCI DCQ DCQU DCW DCWU DN ELIF ELSE END ENDFUNC ENDIF ENDP ENTRY EQU EXPORT EXPORTAS EXTERN FIELD FILL FUNCTION GBLA GBLL GBLS GET GLOBAL IF IMPORT INCBIN INCLUDE INFO KEEP LCLA LCLL LCLS LTORG MACRO MAP MEND MEXIT NOFP OPT PRESERVE8 PROC QN READONLY RELOC REQUIRE REQUIRE8 RLIST FN ROUT SETA SETL SETS SN SPACE SUBT THUMB THUMBX TTL WHILE WEND ',
    built_in:
        '{PC} {VAR} {TRUE} {FALSE} {OPT} {CONFIG} {ENDIAN} {CODESIZE} {CPU} {FPU} {ARCHITECTURE} {PCSTOREOFFSET} {ARMASM_VERSION} {INTER} {ROPI} {RWPI} {SWST} {NOSWST} . @ '
    },
    contains: [
      {
        className: 'keyword',
        begin: '\\b('+     //mnemonics
            'adc|'+
            '(qd?|sh?|u[qh]?)?add(8|16)?|usada?8|(q|sh?|u[qh]?)?(as|sa)x|'+
            'and|adrl?|sbc|rs[bc]|asr|b[lx]?|blx|bxj|cbn?z|tb[bh]|bic|'+
            'bfc|bfi|[su]bfx|bkpt|cdp2?|clz|clrex|cmp|cmn|cpsi[ed]|cps|'+
            'setend|dbg|dmb|dsb|eor|isb|it[te]{0,3}|lsl|lsr|ror|rrx|'+
            'ldm(([id][ab])|f[ds])?|ldr((s|ex)?[bhd])?|movt?|mvn|mra|mar|'+
            'mul|[us]mull|smul[bwt][bt]|smu[as]d|smmul|smmla|'+
            'mla|umlaal|smlal?([wbt][bt]|d)|mls|smlsl?[ds]|smc|svc|sev|'+
            'mia([bt]{2}|ph)?|mrr?c2?|mcrr2?|mrs|msr|orr|orn|pkh(tb|bt)|rbit|'+
            'rev(16|sh)?|sel|[su]sat(16)?|nop|pop|push|rfe([id][ab])?|'+
            'stm([id][ab])?|str(ex)?[bhd]?|(qd?)?sub|(sh?|q|u[qh]?)?sub(8|16)|'+
            '[su]xt(a?h|a?b(16)?)|srs([id][ab])?|swpb?|swi|smi|tst|teq|'+
            'wfe|wfi|yield'+
        ')'+
        '(eq|ne|cs|cc|mi|pl|vs|vc|hi|ls|ge|lt|gt|le|al|hs|lo)?'+ //condition codes
        '[sptrx]?' ,                                             //legal postfixes
        end: '\\s'
      },
      hljs.COMMENT('[;@]', '$', {relevance: 0}),
      hljs.C_BLOCK_COMMENT_MODE,
      hljs.QUOTE_STRING_MODE,
      {
        className: 'string',
        begin: '\'',
        end: '[^\\\\]\'',
        relevance: 0
      },
      {
        className: 'title',
        begin: '\\|', end: '\\|',
        illegal: '\\n',
        relevance: 0
      },
      {
        className: 'number',
        variants: [
            {begin: '[#$=]?0x[0-9a-f]+'}, //hex
            {begin: '[#$=]?0b[01]+'},     //bin
            {begin: '[#$=]\\d+'},        //literal
            {begin: '\\b\\d+'}           //bare number
        ],
        relevance: 0
      },
      {
        className: 'label',
        variants: [
            {begin: '^[a-z_\\.\\$][a-z0-9_\\.\\$]+'}, //ARM syntax
            {begin: '^\\s*[a-z_\\.\\$][a-z0-9_\\.\\$]+:'}, //GNU ARM syntax
            {begin: '[=#]\\w+' }  //label reference
        ],
        relevance: 0
      }
    ]
  };
});

hljs.registerLanguage('xml', function(hljs) {
  var XML_IDENT_RE = '[A-Za-z0-9\\._:-]+';
  var PHP = {
    begin: /<\?(php)?(?!\w)/, end: /\?>/,
    subLanguage: 'php'
  };
  var TAG_INTERNALS = {
    endsWithParent: true,
    illegal: /</,
    relevance: 0,
    contains: [
      PHP,
      {
        className: 'attribute',
        begin: XML_IDENT_RE,
        relevance: 0
      },
      {
        begin: '=',
        relevance: 0,
        contains: [
          {
            className: 'value',
            contains: [PHP],
            variants: [
              {begin: /"/, end: /"/},
              {begin: /'/, end: /'/},
              {begin: /[^\s\/>]+/}
            ]
          }
        ]
      }
    ]
  };
  return {
    aliases: ['html', 'xhtml', 'rss', 'atom', 'xsl', 'plist'],
    case_insensitive: true,
    contains: [
      {
        className: 'doctype',
        begin: '<!DOCTYPE', end: '>',
        relevance: 10,
        contains: [{begin: '\\[', end: '\\]'}]
      },
      hljs.COMMENT(
        '<!--',
        '-->',
        {
          relevance: 10
        }
      ),
      {
        className: 'cdata',
        begin: '<\\!\\[CDATA\\[', end: '\\]\\]>',
        relevance: 10
      },
      {
        className: 'tag',
        /*
        The lookahead pattern (?=...) ensures that 'begin' only matches
        '<style' as a single word, followed by a whitespace or an
        ending braket. The '$' is needed for the lexeme to be recognized
        by hljs.subMode() that tests lexemes outside the stream.
        */
        begin: '<style(?=\\s|>|$)', end: '>',
        keywords: {title: 'style'},
        contains: [TAG_INTERNALS],
        starts: {
          end: '</style>', returnEnd: true,
          subLanguage: 'css'
        }
      },
      {
        className: 'tag',
        // See the comment in the <style tag about the lookahead pattern
        begin: '<script(?=\\s|>|$)', end: '>',
        keywords: {title: 'script'},
        contains: [TAG_INTERNALS],
        starts: {
          end: '\<\/script\>', returnEnd: true,
          subLanguage: ['actionscript', 'javascript', 'handlebars']
        }
      },
      PHP,
      {
        className: 'pi',
        begin: /<\?\w+/, end: /\?>/,
        relevance: 10
      },
      {
        className: 'tag',
        begin: '</?', end: '/?>',
        contains: [
          {
            className: 'title', begin: /[^ \/><\n\t]+/, relevance: 0
          },
          TAG_INTERNALS
        ]
      }
    ]
  };
});

hljs.registerLanguage('asciidoc', function(hljs) {
  return {
    aliases: ['adoc'],
    contains: [
      // block comment
      hljs.COMMENT(
        '^/{4,}\\n',
        '\\n/{4,}$',
        // can also be done as...
        //'^/{4,}$',
        //'^/{4,}$',
        {
          relevance: 10
        }
      ),
      // line comment
      hljs.COMMENT(
        '^//',
        '$',
        {
          relevance: 0
        }
      ),
      // title
      {
        className: 'title',
        begin: '^\\.\\w.*$'
      },
      // example, admonition & sidebar blocks
      {
        begin: '^[=\\*]{4,}\\n',
        end: '\\n^[=\\*]{4,}$',
        relevance: 10
      },
      // headings
      {
        className: 'header',
        begin: '^(={1,5}) .+?( \\1)?$',
        relevance: 10
      },
      {
        className: 'header',
        begin: '^[^\\[\\]\\n]+?\\n[=\\-~\\^\\+]{2,}$',
        relevance: 10
      },
      // document attributes
      {
        className: 'attribute',
        begin: '^:.+?:',
        end: '\\s',
        excludeEnd: true,
        relevance: 10
      },
      // block attributes
      {
        className: 'attribute',
        begin: '^\\[.+?\\]$',
        relevance: 0
      },
      // quoteblocks
      {
        className: 'blockquote',
        begin: '^_{4,}\\n',
        end: '\\n_{4,}$',
        relevance: 10
      },
      // listing and literal blocks
      {
        className: 'code',
        begin: '^[\\-\\.]{4,}\\n',
        end: '\\n[\\-\\.]{4,}$',
        relevance: 10
      },
      // passthrough blocks
      {
        begin: '^\\+{4,}\\n',
        end: '\\n\\+{4,}$',
        contains: [
          {
            begin: '<', end: '>',
            subLanguage: 'xml',
            relevance: 0
          }
        ],
        relevance: 10
      },
      // lists (can only capture indicators)
      {
        className: 'bullet',
        begin: '^(\\*+|\\-+|\\.+|[^\\n]+?::)\\s+'
      },
      // admonition
      {
        className: 'label',
        begin: '^(NOTE|TIP|IMPORTANT|WARNING|CAUTION):\\s+',
        relevance: 10
      },
      // inline strong
      {
        className: 'strong',
        // must not follow a word character or be followed by an asterisk or space
        begin: '\\B\\*(?![\\*\\s])',
        end: '(\\n{2}|\\*)',
        // allow escaped asterisk followed by word char
        contains: [
          {
            begin: '\\\\*\\w',
            relevance: 0
          }
        ]
      },
      // inline emphasis
      {
        className: 'emphasis',
        // must not follow a word character or be followed by a single quote or space
        begin: '\\B\'(?![\'\\s])',
        end: '(\\n{2}|\')',
        // allow escaped single quote followed by word char
        contains: [
          {
            begin: '\\\\\'\\w',
            relevance: 0
          }
        ],
        relevance: 0
      },
      // inline emphasis (alt)
      {
        className: 'emphasis',
        // must not follow a word character or be followed by an underline or space
        begin: '_(?![_\\s])',
        end: '(\\n{2}|_)',
        relevance: 0
      },
      // inline smart quotes
      {
        className: 'smartquote',
        variants: [
          {begin: "``.+?''"},
          {begin: "`.+?'"}
        ]
      },
      // inline code snippets (TODO should get same treatment as strong and emphasis)
      {
        className: 'code',
        begin: '(`.+?`|\\+.+?\\+)',
        relevance: 0
      },
      // indented literal block
      {
        className: 'code',
        begin: '^[ \\t]',
        end: '$',
        relevance: 0
      },
      // horizontal rules
      {
        className: 'horizontal_rule',
        begin: '^\'{3,}[ \\t]*$',
        relevance: 10
      },
      // images and links
      {
        begin: '(link:)?(http|https|ftp|file|irc|image:?):\\S+\\[.*?\\]',
        returnBegin: true,
        contains: [
          {
            //className: 'macro',
            begin: '(link|image:?):',
            relevance: 0
          },
          {
            className: 'link_url',
            begin: '\\w',
            end: '[^\\[]+',
            relevance: 0
          },
          {
            className: 'link_label',
            begin: '\\[',
            end: '\\]',
            excludeBegin: true,
            excludeEnd: true,
            relevance: 0
          }
        ],
        relevance: 10
      }
    ]
  };
});

hljs.registerLanguage('aspectj', function (hljs) {
  var KEYWORDS =
    'false synchronized int abstract float private char boolean static null if const ' +
    'for true while long throw strictfp finally protected import native final return void ' +
    'enum else extends implements break transient new catch instanceof byte super volatile case ' +
    'assert short package default double public try this switch continue throws privileged ' +
    'aspectOf adviceexecution proceed cflowbelow cflow initialization preinitialization ' +
    'staticinitialization withincode target within execution getWithinTypeName handler ' +
    'thisJoinPoint thisJoinPointStaticPart thisEnclosingJoinPointStaticPart declare parents '+
    'warning error soft precedence thisAspectInstance';
  var SHORTKEYS = 'get set args call';
  return {
    keywords : KEYWORDS,
    illegal : /<\/|#/,
    contains : [
      hljs.COMMENT(
        '/\\*\\*',
        '\\*/',
        {
          relevance : 0,
          contains : [{
            className : 'doctag',
            begin : '@[A-Za-z]+'
          }]
        }
      ),
      hljs.C_LINE_COMMENT_MODE,
      hljs.C_BLOCK_COMMENT_MODE,
      hljs.APOS_STRING_MODE,
      hljs.QUOTE_STRING_MODE,
      {
        className : 'aspect',
        beginKeywords : 'aspect',
        end : /[{;=]/,
        excludeEnd : true,
        illegal : /[:;"\[\]]/,
        contains : [
          {
            beginKeywords : 'extends implements pertypewithin perthis pertarget percflowbelow percflow issingleton'
          },
          hljs.UNDERSCORE_TITLE_MODE,
          {
            begin : /\([^\)]*/,
            end : /[)]+/,
            keywords : KEYWORDS + ' ' + SHORTKEYS,
            excludeEnd : false
          }
        ]
      },
      {
        className : 'class',
        beginKeywords : 'class interface',
        end : /[{;=]/,
        excludeEnd : true,
        relevance: 0,
        keywords : 'class interface',
        illegal : /[:"\[\]]/,
        contains : [
          {beginKeywords : 'extends implements'},
          hljs.UNDERSCORE_TITLE_MODE
        ]
      },
      {
        // AspectJ Constructs
        beginKeywords : 'pointcut after before around throwing returning',
        end : /[)]/,
        excludeEnd : false,
        illegal : /["\[\]]/,
        contains : [
          {
            begin : hljs.UNDERSCORE_IDENT_RE + '\\s*\\(',
            returnBegin : true,
            contains : [hljs.UNDERSCORE_TITLE_MODE]
          }
        ]
      },
      {
        begin : /[:]/,
        returnBegin : true,
        end : /[{;]/,
        relevance: 0,
        excludeEnd : false,
        keywords : KEYWORDS,
        illegal : /["\[\]]/,
        contains : [
          {
            begin : hljs.UNDERSCORE_IDENT_RE + '\\s*\\(',
            keywords : KEYWORDS + ' ' + SHORTKEYS
          },
          hljs.QUOTE_STRING_MODE
        ]
      },
      {
        // this prevents 'new Name(...), or throw ...' from being recognized as a function definition
        beginKeywords : 'new throw',
        relevance : 0
      },
      {
        // the function class is a bit different for AspectJ compared to the Java language
        className : 'function',
        begin : /\w+ +\w+(\.)?\w+\s*\([^\)]*\)\s*((throws)[\w\s,]+)?[\{;]/,
        returnBegin : true,
        end : /[{;=]/,
        keywords : KEYWORDS,
        excludeEnd : true,
        contains : [
          {
            begin : hljs.UNDERSCORE_IDENT_RE + '\\s*\\(',
            returnBegin : true,
            relevance: 0,
            contains : [hljs.UNDERSCORE_TITLE_MODE]
          },
          {
            className : 'params',
            begin : /\(/, end : /\)/,
            relevance: 0,
            keywords : KEYWORDS,
            contains : [
              hljs.APOS_STRING_MODE,
              hljs.QUOTE_STRING_MODE,
              hljs.C_NUMBER_MODE,
              hljs.C_BLOCK_COMMENT_MODE
            ]
          },
          hljs.C_LINE_COMMENT_MODE,
          hljs.C_BLOCK_COMMENT_MODE
        ]
      },
      hljs.C_NUMBER_MODE,
      {
        // annotation is also used in this language
        className : 'annotation',
        begin : '@[A-Za-z]+'
      }
    ]
  };
});

hljs.registerLanguage('autohotkey', function(hljs) {
  var BACKTICK_ESCAPE = {
    className: 'escape',
    begin: '`[\\s\\S]'
  };
  var COMMENTS = hljs.COMMENT(
    ';',
    '$',
    {
      relevance: 0
    }
  );
  var BUILT_IN = [
    {
      className: 'built_in',
      begin: 'A_[a-zA-Z0-9]+'
    },
    {
      className: 'built_in',
      beginKeywords: 'ComSpec Clipboard ClipboardAll ErrorLevel'
    }
  ];

  return {
    case_insensitive: true,
    keywords: {
      keyword: 'Break Continue Else Gosub If Loop Return While',
      literal: 'A true false NOT AND OR'
    },
    contains: BUILT_IN.concat([
      BACKTICK_ESCAPE,
      hljs.inherit(hljs.QUOTE_STRING_MODE, {contains: [BACKTICK_ESCAPE]}),
      COMMENTS,
      {
        className: 'number',
        begin: hljs.NUMBER_RE,
        relevance: 0
      },
      {
        className: 'var_expand', // FIXME
        begin: '%', end: '%',
        illegal: '\\n',
        contains: [BACKTICK_ESCAPE]
      },
      {
        className: 'label',
        contains: [BACKTICK_ESCAPE],
        variants: [
          {begin: '^[^\\n";]+::(?!=)'},
          {begin: '^[^\\n";]+:(?!=)', relevance: 0} // zero relevance as it catches a lot of things
                                                    // followed by a single ':' in many languages
        ]
      },
      {
        // consecutive commas, not for highlighting but just for relevance
        begin: ',\\s*,',
        relevance: 10
      }
    ])
  }
});

hljs.registerLanguage('autoit', function(hljs) {
    var KEYWORDS = 'ByRef Case Const ContinueCase ContinueLoop ' +
        'Default Dim Do Else ElseIf EndFunc EndIf EndSelect ' +
        'EndSwitch EndWith Enum Exit ExitLoop For Func ' +
        'Global If In Local Next ReDim Return Select Static ' +
        'Step Switch Then To Until Volatile WEnd While With',

        LITERAL = 'True False And Null Not Or',

        BUILT_IN = 'Abs ACos AdlibRegister AdlibUnRegister Asc AscW ASin ' +
        'Assign ATan AutoItSetOption AutoItWinGetTitle ' +
        'AutoItWinSetTitle Beep Binary BinaryLen BinaryMid ' +
        'BinaryToString BitAND BitNOT BitOR BitRotate BitShift ' +
        'BitXOR BlockInput Break Call CDTray Ceiling Chr ' +
        'ChrW ClipGet ClipPut ConsoleRead ConsoleWrite ' +
        'ConsoleWriteError ControlClick ControlCommand ' +
        'ControlDisable ControlEnable ControlFocus ControlGetFocus ' +
        'ControlGetHandle ControlGetPos ControlGetText ControlHide ' +
        'ControlListView ControlMove ControlSend ControlSetText ' +
        'ControlShow ControlTreeView Cos Dec DirCopy DirCreate ' +
        'DirGetSize DirMove DirRemove DllCall DllCallAddress ' +
        'DllCallbackFree DllCallbackGetPtr DllCallbackRegister ' +
        'DllClose DllOpen DllStructCreate DllStructGetData ' +
        'DllStructGetPtr DllStructGetSize DllStructSetData ' +
        'DriveGetDrive DriveGetFileSystem DriveGetLabel ' +
        'DriveGetSerial DriveGetType DriveMapAdd DriveMapDel ' +
        'DriveMapGet DriveSetLabel DriveSpaceFree DriveSpaceTotal ' +
        'DriveStatus EnvGet EnvSet EnvUpdate Eval Execute Exp ' +
        'FileChangeDir FileClose FileCopy FileCreateNTFSLink ' +
        'FileCreateShortcut FileDelete FileExists FileFindFirstFile ' +
        'FileFindNextFile FileFlush FileGetAttrib FileGetEncoding ' +
        'FileGetLongName FileGetPos FileGetShortcut FileGetShortName ' +
        'FileGetSize FileGetTime FileGetVersion FileInstall ' +
        'FileMove FileOpen FileOpenDialog FileRead FileReadLine ' +
        'FileReadToArray FileRecycle FileRecycleEmpty FileSaveDialog ' +
        'FileSelectFolder FileSetAttrib FileSetEnd FileSetPos ' +
        'FileSetTime FileWrite FileWriteLine Floor FtpSetProxy ' +
        'FuncName GUICreate GUICtrlCreateAvi GUICtrlCreateButton ' +
        'GUICtrlCreateCheckbox GUICtrlCreateCombo ' +
        'GUICtrlCreateContextMenu GUICtrlCreateDate GUICtrlCreateDummy ' +
        'GUICtrlCreateEdit GUICtrlCreateGraphic GUICtrlCreateGroup ' +
        'GUICtrlCreateIcon GUICtrlCreateInput GUICtrlCreateLabel ' +
        'GUICtrlCreateList GUICtrlCreateListView ' +
        'GUICtrlCreateListViewItem GUICtrlCreateMenu ' +
        'GUICtrlCreateMenuItem GUICtrlCreateMonthCal GUICtrlCreateObj ' +
        'GUICtrlCreatePic GUICtrlCreateProgress GUICtrlCreateRadio ' +
        'GUICtrlCreateSlider GUICtrlCreateTab GUICtrlCreateTabItem ' +
        'GUICtrlCreateTreeView GUICtrlCreateTreeViewItem ' +
        'GUICtrlCreateUpdown GUICtrlDelete GUICtrlGetHandle ' +
        'GUICtrlGetState GUICtrlRead GUICtrlRecvMsg ' +
        'GUICtrlRegisterListViewSort GUICtrlSendMsg GUICtrlSendToDummy ' +
        'GUICtrlSetBkColor GUICtrlSetColor GUICtrlSetCursor ' +
        'GUICtrlSetData GUICtrlSetDefBkColor GUICtrlSetDefColor ' +
        'GUICtrlSetFont GUICtrlSetGraphic GUICtrlSetImage ' +
        'GUICtrlSetLimit GUICtrlSetOnEvent GUICtrlSetPos ' +
        'GUICtrlSetResizing GUICtrlSetState GUICtrlSetStyle ' +
        'GUICtrlSetTip GUIDelete GUIGetCursorInfo GUIGetMsg ' +
        'GUIGetStyle GUIRegisterMsg GUISetAccelerators GUISetBkColor ' +
        'GUISetCoord GUISetCursor GUISetFont GUISetHelp GUISetIcon ' +
        'GUISetOnEvent GUISetState GUISetStyle GUIStartGroup ' +
        'GUISwitch Hex HotKeySet HttpSetProxy HttpSetUserAgent ' +
        'HWnd InetClose InetGet InetGetInfo InetGetSize InetRead ' +
        'IniDelete IniRead IniReadSection IniReadSectionNames ' +
        'IniRenameSection IniWrite IniWriteSection InputBox Int ' +
        'IsAdmin IsArray IsBinary IsBool IsDeclared IsDllStruct ' +
        'IsFloat IsFunc IsHWnd IsInt IsKeyword IsNumber IsObj ' +
        'IsPtr IsString Log MemGetStats Mod MouseClick ' +
        'MouseClickDrag MouseDown MouseGetCursor MouseGetPos ' +
        'MouseMove MouseUp MouseWheel MsgBox Number ObjCreate ' +
        'ObjCreateInterface ObjEvent ObjGet ObjName ' +
        'OnAutoItExitRegister OnAutoItExitUnRegister Opt Ping ' +
        'PixelChecksum PixelGetColor PixelSearch ProcessClose ' +
        'ProcessExists ProcessGetStats ProcessList ' +
        'ProcessSetPriority ProcessWait ProcessWaitClose ProgressOff ' +
        'ProgressOn ProgressSet Ptr Random RegDelete RegEnumKey ' +
        'RegEnumVal RegRead RegWrite Round Run RunAs RunAsWait ' +
        'RunWait Send SendKeepActive SetError SetExtended ' +
        'ShellExecute ShellExecuteWait Shutdown Sin Sleep ' +
        'SoundPlay SoundSetWaveVolume SplashImageOn SplashOff ' +
        'SplashTextOn Sqrt SRandom StatusbarGetText StderrRead ' +
        'StdinWrite StdioClose StdoutRead String StringAddCR ' +
        'StringCompare StringFormat StringFromASCIIArray StringInStr ' +
        'StringIsAlNum StringIsAlpha StringIsASCII StringIsDigit ' +
        'StringIsFloat StringIsInt StringIsLower StringIsSpace ' +
        'StringIsUpper StringIsXDigit StringLeft StringLen ' +
        'StringLower StringMid StringRegExp StringRegExpReplace ' +
        'StringReplace StringReverse StringRight StringSplit ' +
        'StringStripCR StringStripWS StringToASCIIArray ' +
        'StringToBinary StringTrimLeft StringTrimRight StringUpper ' +
        'Tan TCPAccept TCPCloseSocket TCPConnect TCPListen ' +
        'TCPNameToIP TCPRecv TCPSend TCPShutdown TCPStartup ' +
        'TimerDiff TimerInit ToolTip TrayCreateItem TrayCreateMenu ' +
        'TrayGetMsg TrayItemDelete TrayItemGetHandle ' +
        'TrayItemGetState TrayItemGetText TrayItemSetOnEvent ' +
        'TrayItemSetState TrayItemSetText TraySetClick TraySetIcon ' +
        'TraySetOnEvent TraySetPauseIcon TraySetState TraySetToolTip ' +
        'TrayTip UBound UDPBind UDPCloseSocket UDPOpen UDPRecv ' +
        'UDPSend UDPShutdown UDPStartup VarGetType WinActivate ' +
        'WinActive WinClose WinExists WinFlash WinGetCaretPos ' +
        'WinGetClassList WinGetClientSize WinGetHandle WinGetPos ' +
        'WinGetProcess WinGetState WinGetText WinGetTitle WinKill ' +
        'WinList WinMenuSelectItem WinMinimizeAll WinMinimizeAllUndo ' +
        'WinMove WinSetOnTop WinSetState WinSetTitle WinSetTrans ' +
        'WinWait WinWaitActive WinWaitClose WinWaitNotActive ' +
        'Array1DToHistogram ArrayAdd ArrayBinarySearch ' +
        'ArrayColDelete ArrayColInsert ArrayCombinations ' +
        'ArrayConcatenate ArrayDelete ArrayDisplay ArrayExtract ' +
        'ArrayFindAll ArrayInsert ArrayMax ArrayMaxIndex ArrayMin ' +
        'ArrayMinIndex ArrayPermute ArrayPop ArrayPush ' +
        'ArrayReverse ArraySearch ArrayShuffle ArraySort ArraySwap ' +
        'ArrayToClip ArrayToString ArrayTranspose ArrayTrim ' +
        'ArrayUnique Assert ChooseColor ChooseFont ' +
        'ClipBoard_ChangeChain ClipBoard_Close ClipBoard_CountFormats ' +
        'ClipBoard_Empty ClipBoard_EnumFormats ClipBoard_FormatStr ' +
        'ClipBoard_GetData ClipBoard_GetDataEx ClipBoard_GetFormatName ' +
        'ClipBoard_GetOpenWindow ClipBoard_GetOwner ' +
        'ClipBoard_GetPriorityFormat ClipBoard_GetSequenceNumber ' +
        'ClipBoard_GetViewer ClipBoard_IsFormatAvailable ' +
        'ClipBoard_Open ClipBoard_RegisterFormat ClipBoard_SetData ' +
        'ClipBoard_SetDataEx ClipBoard_SetViewer ClipPutFile ' +
        'ColorConvertHSLtoRGB ColorConvertRGBtoHSL ColorGetBlue ' +
        'ColorGetCOLORREF ColorGetGreen ColorGetRed ColorGetRGB ' +
        'ColorSetCOLORREF ColorSetRGB Crypt_DecryptData ' +
        'Crypt_DecryptFile Crypt_DeriveKey Crypt_DestroyKey ' +
        'Crypt_EncryptData Crypt_EncryptFile Crypt_GenRandom ' +
        'Crypt_HashData Crypt_HashFile Crypt_Shutdown Crypt_Startup ' +
        'DateAdd DateDayOfWeek DateDaysInMonth DateDiff ' +
        'DateIsLeapYear DateIsValid DateTimeFormat DateTimeSplit ' +
        'DateToDayOfWeek DateToDayOfWeekISO DateToDayValue ' +
        'DateToMonth Date_Time_CompareFileTime ' +
        'Date_Time_DOSDateTimeToArray Date_Time_DOSDateTimeToFileTime ' +
        'Date_Time_DOSDateTimeToStr Date_Time_DOSDateToArray ' +
        'Date_Time_DOSDateToStr Date_Time_DOSTimeToArray ' +
        'Date_Time_DOSTimeToStr Date_Time_EncodeFileTime ' +
        'Date_Time_EncodeSystemTime Date_Time_FileTimeToArray ' +
        'Date_Time_FileTimeToDOSDateTime ' +
        'Date_Time_FileTimeToLocalFileTime Date_Time_FileTimeToStr ' +
        'Date_Time_FileTimeToSystemTime Date_Time_GetFileTime ' +
        'Date_Time_GetLocalTime Date_Time_GetSystemTime ' +
        'Date_Time_GetSystemTimeAdjustment ' +
        'Date_Time_GetSystemTimeAsFileTime Date_Time_GetSystemTimes ' +
        'Date_Time_GetTickCount Date_Time_GetTimeZoneInformation ' +
        'Date_Time_LocalFileTimeToFileTime Date_Time_SetFileTime ' +
        'Date_Time_SetLocalTime Date_Time_SetSystemTime ' +
        'Date_Time_SetSystemTimeAdjustment ' +
        'Date_Time_SetTimeZoneInformation Date_Time_SystemTimeToArray ' +
        'Date_Time_SystemTimeToDateStr Date_Time_SystemTimeToDateTimeStr ' +
        'Date_Time_SystemTimeToFileTime Date_Time_SystemTimeToTimeStr ' +
        'Date_Time_SystemTimeToTzSpecificLocalTime ' +
        'Date_Time_TzSpecificLocalTimeToSystemTime DayValueToDate ' +
        'DebugBugReportEnv DebugCOMError DebugOut DebugReport ' +
        'DebugReportEx DebugReportVar DebugSetup Degree ' +
        'EventLog__Backup EventLog__Clear EventLog__Close ' +
        'EventLog__Count EventLog__DeregisterSource EventLog__Full ' +
        'EventLog__Notify EventLog__Oldest EventLog__Open ' +
        'EventLog__OpenBackup EventLog__Read EventLog__RegisterSource ' +
        'EventLog__Report Excel_BookAttach Excel_BookClose ' +
        'Excel_BookList Excel_BookNew Excel_BookOpen ' +
        'Excel_BookOpenText Excel_BookSave Excel_BookSaveAs ' +
        'Excel_Close Excel_ColumnToLetter Excel_ColumnToNumber ' +
        'Excel_ConvertFormula Excel_Export Excel_FilterGet ' +
        'Excel_FilterSet Excel_Open Excel_PictureAdd Excel_Print ' +
        'Excel_RangeCopyPaste Excel_RangeDelete Excel_RangeFind ' +
        'Excel_RangeInsert Excel_RangeLinkAddRemove Excel_RangeRead ' +
        'Excel_RangeReplace Excel_RangeSort Excel_RangeValidate ' +
        'Excel_RangeWrite Excel_SheetAdd Excel_SheetCopyMove ' +
        'Excel_SheetDelete Excel_SheetList FileCountLines FileCreate ' +
        'FileListToArray FileListToArrayRec FilePrint ' +
        'FileReadToArray FileWriteFromArray FileWriteLog ' +
        'FileWriteToLine FTP_Close FTP_Command FTP_Connect ' +
        'FTP_DecodeInternetStatus FTP_DirCreate FTP_DirDelete ' +
        'FTP_DirGetCurrent FTP_DirPutContents FTP_DirSetCurrent ' +
        'FTP_FileClose FTP_FileDelete FTP_FileGet FTP_FileGetSize ' +
        'FTP_FileOpen FTP_FilePut FTP_FileRead FTP_FileRename ' +
        'FTP_FileTimeLoHiToStr FTP_FindFileClose FTP_FindFileFirst ' +
        'FTP_FindFileNext FTP_GetLastResponseInfo FTP_ListToArray ' +
        'FTP_ListToArray2D FTP_ListToArrayEx FTP_Open ' +
        'FTP_ProgressDownload FTP_ProgressUpload FTP_SetStatusCallback ' +
        'GDIPlus_ArrowCapCreate GDIPlus_ArrowCapDispose ' +
        'GDIPlus_ArrowCapGetFillState GDIPlus_ArrowCapGetHeight ' +
        'GDIPlus_ArrowCapGetMiddleInset GDIPlus_ArrowCapGetWidth ' +
        'GDIPlus_ArrowCapSetFillState GDIPlus_ArrowCapSetHeight ' +
        'GDIPlus_ArrowCapSetMiddleInset GDIPlus_ArrowCapSetWidth ' +
        'GDIPlus_BitmapApplyEffect GDIPlus_BitmapApplyEffectEx ' +
        'GDIPlus_BitmapCloneArea GDIPlus_BitmapConvertFormat ' +
        'GDIPlus_BitmapCreateApplyEffect ' +
        'GDIPlus_BitmapCreateApplyEffectEx ' +
        'GDIPlus_BitmapCreateDIBFromBitmap GDIPlus_BitmapCreateFromFile ' +
        'GDIPlus_BitmapCreateFromGraphics ' +
        'GDIPlus_BitmapCreateFromHBITMAP GDIPlus_BitmapCreateFromHICON ' +
        'GDIPlus_BitmapCreateFromHICON32 GDIPlus_BitmapCreateFromMemory ' +
        'GDIPlus_BitmapCreateFromResource GDIPlus_BitmapCreateFromScan0 ' +
        'GDIPlus_BitmapCreateFromStream ' +
        'GDIPlus_BitmapCreateHBITMAPFromBitmap GDIPlus_BitmapDispose ' +
        'GDIPlus_BitmapGetHistogram GDIPlus_BitmapGetHistogramEx ' +
        'GDIPlus_BitmapGetHistogramSize GDIPlus_BitmapGetPixel ' +
        'GDIPlus_BitmapLockBits GDIPlus_BitmapSetPixel ' +
        'GDIPlus_BitmapUnlockBits GDIPlus_BrushClone ' +
        'GDIPlus_BrushCreateSolid GDIPlus_BrushDispose ' +
        'GDIPlus_BrushGetSolidColor GDIPlus_BrushGetType ' +
        'GDIPlus_BrushSetSolidColor GDIPlus_ColorMatrixCreate ' +
        'GDIPlus_ColorMatrixCreateGrayScale ' +
        'GDIPlus_ColorMatrixCreateNegative ' +
        'GDIPlus_ColorMatrixCreateSaturation ' +
        'GDIPlus_ColorMatrixCreateScale ' +
        'GDIPlus_ColorMatrixCreateTranslate GDIPlus_CustomLineCapClone ' +
        'GDIPlus_CustomLineCapCreate GDIPlus_CustomLineCapDispose ' +
        'GDIPlus_CustomLineCapGetStrokeCaps ' +
        'GDIPlus_CustomLineCapSetStrokeCaps GDIPlus_Decoders ' +
        'GDIPlus_DecodersGetCount GDIPlus_DecodersGetSize ' +
        'GDIPlus_DrawImageFX GDIPlus_DrawImageFXEx ' +
        'GDIPlus_DrawImagePoints GDIPlus_EffectCreate ' +
        'GDIPlus_EffectCreateBlur GDIPlus_EffectCreateBrightnessContrast ' +
        'GDIPlus_EffectCreateColorBalance GDIPlus_EffectCreateColorCurve ' +
        'GDIPlus_EffectCreateColorLUT GDIPlus_EffectCreateColorMatrix ' +
        'GDIPlus_EffectCreateHueSaturationLightness ' +
        'GDIPlus_EffectCreateLevels GDIPlus_EffectCreateRedEyeCorrection ' +
        'GDIPlus_EffectCreateSharpen GDIPlus_EffectCreateTint ' +
        'GDIPlus_EffectDispose GDIPlus_EffectGetParameters ' +
        'GDIPlus_EffectSetParameters GDIPlus_Encoders ' +
        'GDIPlus_EncodersGetCLSID GDIPlus_EncodersGetCount ' +
        'GDIPlus_EncodersGetParamList GDIPlus_EncodersGetParamListSize ' +
        'GDIPlus_EncodersGetSize GDIPlus_FontCreate ' +
        'GDIPlus_FontDispose GDIPlus_FontFamilyCreate ' +
        'GDIPlus_FontFamilyCreateFromCollection ' +
        'GDIPlus_FontFamilyDispose GDIPlus_FontFamilyGetCellAscent ' +
        'GDIPlus_FontFamilyGetCellDescent GDIPlus_FontFamilyGetEmHeight ' +
        'GDIPlus_FontFamilyGetLineSpacing GDIPlus_FontGetHeight ' +
        'GDIPlus_FontPrivateAddFont GDIPlus_FontPrivateAddMemoryFont ' +
        'GDIPlus_FontPrivateCollectionDispose ' +
        'GDIPlus_FontPrivateCreateCollection GDIPlus_GraphicsClear ' +
        'GDIPlus_GraphicsCreateFromHDC GDIPlus_GraphicsCreateFromHWND ' +
        'GDIPlus_GraphicsDispose GDIPlus_GraphicsDrawArc ' +
        'GDIPlus_GraphicsDrawBezier GDIPlus_GraphicsDrawClosedCurve ' +
        'GDIPlus_GraphicsDrawClosedCurve2 GDIPlus_GraphicsDrawCurve ' +
        'GDIPlus_GraphicsDrawCurve2 GDIPlus_GraphicsDrawEllipse ' +
        'GDIPlus_GraphicsDrawImage GDIPlus_GraphicsDrawImagePointsRect ' +
        'GDIPlus_GraphicsDrawImageRect GDIPlus_GraphicsDrawImageRectRect ' +
        'GDIPlus_GraphicsDrawLine GDIPlus_GraphicsDrawPath ' +
        'GDIPlus_GraphicsDrawPie GDIPlus_GraphicsDrawPolygon ' +
        'GDIPlus_GraphicsDrawRect GDIPlus_GraphicsDrawString ' +
        'GDIPlus_GraphicsDrawStringEx GDIPlus_GraphicsFillClosedCurve ' +
        'GDIPlus_GraphicsFillClosedCurve2 GDIPlus_GraphicsFillEllipse ' +
        'GDIPlus_GraphicsFillPath GDIPlus_GraphicsFillPie ' +
        'GDIPlus_GraphicsFillPolygon GDIPlus_GraphicsFillRect ' +
        'GDIPlus_GraphicsFillRegion GDIPlus_GraphicsGetCompositingMode ' +
        'GDIPlus_GraphicsGetCompositingQuality GDIPlus_GraphicsGetDC ' +
        'GDIPlus_GraphicsGetInterpolationMode ' +
        'GDIPlus_GraphicsGetSmoothingMode GDIPlus_GraphicsGetTransform ' +
        'GDIPlus_GraphicsMeasureCharacterRanges ' +
        'GDIPlus_GraphicsMeasureString GDIPlus_GraphicsReleaseDC ' +
        'GDIPlus_GraphicsResetClip GDIPlus_GraphicsResetTransform ' +
        'GDIPlus_GraphicsRestore GDIPlus_GraphicsRotateTransform ' +
        'GDIPlus_GraphicsSave GDIPlus_GraphicsScaleTransform ' +
        'GDIPlus_GraphicsSetClipPath GDIPlus_GraphicsSetClipRect ' +
        'GDIPlus_GraphicsSetClipRegion ' +
        'GDIPlus_GraphicsSetCompositingMode ' +
        'GDIPlus_GraphicsSetCompositingQuality ' +
        'GDIPlus_GraphicsSetInterpolationMode ' +
        'GDIPlus_GraphicsSetPixelOffsetMode ' +
        'GDIPlus_GraphicsSetSmoothingMode ' +
        'GDIPlus_GraphicsSetTextRenderingHint ' +
        'GDIPlus_GraphicsSetTransform GDIPlus_GraphicsTransformPoints ' +
        'GDIPlus_GraphicsTranslateTransform GDIPlus_HatchBrushCreate ' +
        'GDIPlus_HICONCreateFromBitmap GDIPlus_ImageAttributesCreate ' +
        'GDIPlus_ImageAttributesDispose ' +
        'GDIPlus_ImageAttributesSetColorKeys ' +
        'GDIPlus_ImageAttributesSetColorMatrix GDIPlus_ImageDispose ' +
        'GDIPlus_ImageGetDimension GDIPlus_ImageGetFlags ' +
        'GDIPlus_ImageGetGraphicsContext GDIPlus_ImageGetHeight ' +
        'GDIPlus_ImageGetHorizontalResolution ' +
        'GDIPlus_ImageGetPixelFormat GDIPlus_ImageGetRawFormat ' +
        'GDIPlus_ImageGetThumbnail GDIPlus_ImageGetType ' +
        'GDIPlus_ImageGetVerticalResolution GDIPlus_ImageGetWidth ' +
        'GDIPlus_ImageLoadFromFile GDIPlus_ImageLoadFromStream ' +
        'GDIPlus_ImageResize GDIPlus_ImageRotateFlip ' +
        'GDIPlus_ImageSaveToFile GDIPlus_ImageSaveToFileEx ' +
        'GDIPlus_ImageSaveToStream GDIPlus_ImageScale ' +
        'GDIPlus_LineBrushCreate GDIPlus_LineBrushCreateFromRect ' +
        'GDIPlus_LineBrushCreateFromRectWithAngle ' +
        'GDIPlus_LineBrushGetColors GDIPlus_LineBrushGetRect ' +
        'GDIPlus_LineBrushMultiplyTransform ' +
        'GDIPlus_LineBrushResetTransform GDIPlus_LineBrushSetBlend ' +
        'GDIPlus_LineBrushSetColors GDIPlus_LineBrushSetGammaCorrection ' +
        'GDIPlus_LineBrushSetLinearBlend GDIPlus_LineBrushSetPresetBlend ' +
        'GDIPlus_LineBrushSetSigmaBlend GDIPlus_LineBrushSetTransform ' +
        'GDIPlus_MatrixClone GDIPlus_MatrixCreate ' +
        'GDIPlus_MatrixDispose GDIPlus_MatrixGetElements ' +
        'GDIPlus_MatrixInvert GDIPlus_MatrixMultiply ' +
        'GDIPlus_MatrixRotate GDIPlus_MatrixScale ' +
        'GDIPlus_MatrixSetElements GDIPlus_MatrixShear ' +
        'GDIPlus_MatrixTransformPoints GDIPlus_MatrixTranslate ' +
        'GDIPlus_PaletteInitialize GDIPlus_ParamAdd GDIPlus_ParamInit ' +
        'GDIPlus_ParamSize GDIPlus_PathAddArc GDIPlus_PathAddBezier ' +
        'GDIPlus_PathAddClosedCurve GDIPlus_PathAddClosedCurve2 ' +
        'GDIPlus_PathAddCurve GDIPlus_PathAddCurve2 ' +
        'GDIPlus_PathAddCurve3 GDIPlus_PathAddEllipse ' +
        'GDIPlus_PathAddLine GDIPlus_PathAddLine2 GDIPlus_PathAddPath ' +
        'GDIPlus_PathAddPie GDIPlus_PathAddPolygon ' +
        'GDIPlus_PathAddRectangle GDIPlus_PathAddString ' +
        'GDIPlus_PathBrushCreate GDIPlus_PathBrushCreateFromPath ' +
        'GDIPlus_PathBrushGetCenterPoint GDIPlus_PathBrushGetFocusScales ' +
        'GDIPlus_PathBrushGetPointCount GDIPlus_PathBrushGetRect ' +
        'GDIPlus_PathBrushGetWrapMode GDIPlus_PathBrushMultiplyTransform ' +
        'GDIPlus_PathBrushResetTransform GDIPlus_PathBrushSetBlend ' +
        'GDIPlus_PathBrushSetCenterColor GDIPlus_PathBrushSetCenterPoint ' +
        'GDIPlus_PathBrushSetFocusScales ' +
        'GDIPlus_PathBrushSetGammaCorrection ' +
        'GDIPlus_PathBrushSetLinearBlend GDIPlus_PathBrushSetPresetBlend ' +
        'GDIPlus_PathBrushSetSigmaBlend ' +
        'GDIPlus_PathBrushSetSurroundColor ' +
        'GDIPlus_PathBrushSetSurroundColorsWithCount ' +
        'GDIPlus_PathBrushSetTransform GDIPlus_PathBrushSetWrapMode ' +
        'GDIPlus_PathClone GDIPlus_PathCloseFigure GDIPlus_PathCreate ' +
        'GDIPlus_PathCreate2 GDIPlus_PathDispose GDIPlus_PathFlatten ' +
        'GDIPlus_PathGetData GDIPlus_PathGetFillMode ' +
        'GDIPlus_PathGetLastPoint GDIPlus_PathGetPointCount ' +
        'GDIPlus_PathGetPoints GDIPlus_PathGetWorldBounds ' +
        'GDIPlus_PathIsOutlineVisiblePoint GDIPlus_PathIsVisiblePoint ' +
        'GDIPlus_PathIterCreate GDIPlus_PathIterDispose ' +
        'GDIPlus_PathIterGetSubpathCount GDIPlus_PathIterNextMarkerPath ' +
        'GDIPlus_PathIterNextSubpathPath GDIPlus_PathIterRewind ' +
        'GDIPlus_PathReset GDIPlus_PathReverse GDIPlus_PathSetFillMode ' +
        'GDIPlus_PathSetMarker GDIPlus_PathStartFigure ' +
        'GDIPlus_PathTransform GDIPlus_PathWarp GDIPlus_PathWiden ' +
        'GDIPlus_PathWindingModeOutline GDIPlus_PenCreate ' +
        'GDIPlus_PenCreate2 GDIPlus_PenDispose GDIPlus_PenGetAlignment ' +
        'GDIPlus_PenGetColor GDIPlus_PenGetCustomEndCap ' +
        'GDIPlus_PenGetDashCap GDIPlus_PenGetDashStyle ' +
        'GDIPlus_PenGetEndCap GDIPlus_PenGetMiterLimit ' +
        'GDIPlus_PenGetWidth GDIPlus_PenSetAlignment ' +
        'GDIPlus_PenSetColor GDIPlus_PenSetCustomEndCap ' +
        'GDIPlus_PenSetDashCap GDIPlus_PenSetDashStyle ' +
        'GDIPlus_PenSetEndCap GDIPlus_PenSetLineCap ' +
        'GDIPlus_PenSetLineJoin GDIPlus_PenSetMiterLimit ' +
        'GDIPlus_PenSetStartCap GDIPlus_PenSetWidth ' +
        'GDIPlus_RectFCreate GDIPlus_RegionClone ' +
        'GDIPlus_RegionCombinePath GDIPlus_RegionCombineRect ' +
        'GDIPlus_RegionCombineRegion GDIPlus_RegionCreate ' +
        'GDIPlus_RegionCreateFromPath GDIPlus_RegionCreateFromRect ' +
        'GDIPlus_RegionDispose GDIPlus_RegionGetBounds ' +
        'GDIPlus_RegionGetHRgn GDIPlus_RegionTransform ' +
        'GDIPlus_RegionTranslate GDIPlus_Shutdown GDIPlus_Startup ' +
        'GDIPlus_StringFormatCreate GDIPlus_StringFormatDispose ' +
        'GDIPlus_StringFormatGetMeasurableCharacterRangeCount ' +
        'GDIPlus_StringFormatSetAlign GDIPlus_StringFormatSetLineAlign ' +
        'GDIPlus_StringFormatSetMeasurableCharacterRanges ' +
        'GDIPlus_TextureCreate GDIPlus_TextureCreate2 ' +
        'GDIPlus_TextureCreateIA GetIP GUICtrlAVI_Close ' +
        'GUICtrlAVI_Create GUICtrlAVI_Destroy GUICtrlAVI_IsPlaying ' +
        'GUICtrlAVI_Open GUICtrlAVI_OpenEx GUICtrlAVI_Play ' +
        'GUICtrlAVI_Seek GUICtrlAVI_Show GUICtrlAVI_Stop ' +
        'GUICtrlButton_Click GUICtrlButton_Create ' +
        'GUICtrlButton_Destroy GUICtrlButton_Enable ' +
        'GUICtrlButton_GetCheck GUICtrlButton_GetFocus ' +
        'GUICtrlButton_GetIdealSize GUICtrlButton_GetImage ' +
        'GUICtrlButton_GetImageList GUICtrlButton_GetNote ' +
        'GUICtrlButton_GetNoteLength GUICtrlButton_GetSplitInfo ' +
        'GUICtrlButton_GetState GUICtrlButton_GetText ' +
        'GUICtrlButton_GetTextMargin GUICtrlButton_SetCheck ' +
        'GUICtrlButton_SetDontClick GUICtrlButton_SetFocus ' +
        'GUICtrlButton_SetImage GUICtrlButton_SetImageList ' +
        'GUICtrlButton_SetNote GUICtrlButton_SetShield ' +
        'GUICtrlButton_SetSize GUICtrlButton_SetSplitInfo ' +
        'GUICtrlButton_SetState GUICtrlButton_SetStyle ' +
        'GUICtrlButton_SetText GUICtrlButton_SetTextMargin ' +
        'GUICtrlButton_Show GUICtrlComboBoxEx_AddDir ' +
        'GUICtrlComboBoxEx_AddString GUICtrlComboBoxEx_BeginUpdate ' +
        'GUICtrlComboBoxEx_Create GUICtrlComboBoxEx_CreateSolidBitMap ' +
        'GUICtrlComboBoxEx_DeleteString GUICtrlComboBoxEx_Destroy ' +
        'GUICtrlComboBoxEx_EndUpdate GUICtrlComboBoxEx_FindStringExact ' +
        'GUICtrlComboBoxEx_GetComboBoxInfo ' +
        'GUICtrlComboBoxEx_GetComboControl GUICtrlComboBoxEx_GetCount ' +
        'GUICtrlComboBoxEx_GetCurSel ' +
        'GUICtrlComboBoxEx_GetDroppedControlRect ' +
        'GUICtrlComboBoxEx_GetDroppedControlRectEx ' +
        'GUICtrlComboBoxEx_GetDroppedState ' +
        'GUICtrlComboBoxEx_GetDroppedWidth ' +
        'GUICtrlComboBoxEx_GetEditControl GUICtrlComboBoxEx_GetEditSel ' +
        'GUICtrlComboBoxEx_GetEditText ' +
        'GUICtrlComboBoxEx_GetExtendedStyle ' +
        'GUICtrlComboBoxEx_GetExtendedUI GUICtrlComboBoxEx_GetImageList ' +
        'GUICtrlComboBoxEx_GetItem GUICtrlComboBoxEx_GetItemEx ' +
        'GUICtrlComboBoxEx_GetItemHeight GUICtrlComboBoxEx_GetItemImage ' +
        'GUICtrlComboBoxEx_GetItemIndent ' +
        'GUICtrlComboBoxEx_GetItemOverlayImage ' +
        'GUICtrlComboBoxEx_GetItemParam ' +
        'GUICtrlComboBoxEx_GetItemSelectedImage ' +
        'GUICtrlComboBoxEx_GetItemText GUICtrlComboBoxEx_GetItemTextLen ' +
        'GUICtrlComboBoxEx_GetList GUICtrlComboBoxEx_GetListArray ' +
        'GUICtrlComboBoxEx_GetLocale GUICtrlComboBoxEx_GetLocaleCountry ' +
        'GUICtrlComboBoxEx_GetLocaleLang ' +
        'GUICtrlComboBoxEx_GetLocalePrimLang ' +
        'GUICtrlComboBoxEx_GetLocaleSubLang ' +
        'GUICtrlComboBoxEx_GetMinVisible GUICtrlComboBoxEx_GetTopIndex ' +
        'GUICtrlComboBoxEx_GetUnicode GUICtrlComboBoxEx_InitStorage ' +
        'GUICtrlComboBoxEx_InsertString GUICtrlComboBoxEx_LimitText ' +
        'GUICtrlComboBoxEx_ReplaceEditSel GUICtrlComboBoxEx_ResetContent ' +
        'GUICtrlComboBoxEx_SetCurSel GUICtrlComboBoxEx_SetDroppedWidth ' +
        'GUICtrlComboBoxEx_SetEditSel GUICtrlComboBoxEx_SetEditText ' +
        'GUICtrlComboBoxEx_SetExtendedStyle ' +
        'GUICtrlComboBoxEx_SetExtendedUI GUICtrlComboBoxEx_SetImageList ' +
        'GUICtrlComboBoxEx_SetItem GUICtrlComboBoxEx_SetItemEx ' +
        'GUICtrlComboBoxEx_SetItemHeight GUICtrlComboBoxEx_SetItemImage ' +
        'GUICtrlComboBoxEx_SetItemIndent ' +
        'GUICtrlComboBoxEx_SetItemOverlayImage ' +
        'GUICtrlComboBoxEx_SetItemParam ' +
        'GUICtrlComboBoxEx_SetItemSelectedImage ' +
        'GUICtrlComboBoxEx_SetMinVisible GUICtrlComboBoxEx_SetTopIndex ' +
        'GUICtrlComboBoxEx_SetUnicode GUICtrlComboBoxEx_ShowDropDown ' +
        'GUICtrlComboBox_AddDir GUICtrlComboBox_AddString ' +
        'GUICtrlComboBox_AutoComplete GUICtrlComboBox_BeginUpdate ' +
        'GUICtrlComboBox_Create GUICtrlComboBox_DeleteString ' +
        'GUICtrlComboBox_Destroy GUICtrlComboBox_EndUpdate ' +
        'GUICtrlComboBox_FindString GUICtrlComboBox_FindStringExact ' +
        'GUICtrlComboBox_GetComboBoxInfo GUICtrlComboBox_GetCount ' +
        'GUICtrlComboBox_GetCueBanner GUICtrlComboBox_GetCurSel ' +
        'GUICtrlComboBox_GetDroppedControlRect ' +
        'GUICtrlComboBox_GetDroppedControlRectEx ' +
        'GUICtrlComboBox_GetDroppedState GUICtrlComboBox_GetDroppedWidth ' +
        'GUICtrlComboBox_GetEditSel GUICtrlComboBox_GetEditText ' +
        'GUICtrlComboBox_GetExtendedUI ' +
        'GUICtrlComboBox_GetHorizontalExtent ' +
        'GUICtrlComboBox_GetItemHeight GUICtrlComboBox_GetLBText ' +
        'GUICtrlComboBox_GetLBTextLen GUICtrlComboBox_GetList ' +
        'GUICtrlComboBox_GetListArray GUICtrlComboBox_GetLocale ' +
        'GUICtrlComboBox_GetLocaleCountry GUICtrlComboBox_GetLocaleLang ' +
        'GUICtrlComboBox_GetLocalePrimLang ' +
        'GUICtrlComboBox_GetLocaleSubLang GUICtrlComboBox_GetMinVisible ' +
        'GUICtrlComboBox_GetTopIndex GUICtrlComboBox_InitStorage ' +
        'GUICtrlComboBox_InsertString GUICtrlComboBox_LimitText ' +
        'GUICtrlComboBox_ReplaceEditSel GUICtrlComboBox_ResetContent ' +
        'GUICtrlComboBox_SelectString GUICtrlComboBox_SetCueBanner ' +
        'GUICtrlComboBox_SetCurSel GUICtrlComboBox_SetDroppedWidth ' +
        'GUICtrlComboBox_SetEditSel GUICtrlComboBox_SetEditText ' +
        'GUICtrlComboBox_SetExtendedUI ' +
        'GUICtrlComboBox_SetHorizontalExtent ' +
        'GUICtrlComboBox_SetItemHeight GUICtrlComboBox_SetMinVisible ' +
        'GUICtrlComboBox_SetTopIndex GUICtrlComboBox_ShowDropDown ' +
        'GUICtrlDTP_Create GUICtrlDTP_Destroy GUICtrlDTP_GetMCColor ' +
        'GUICtrlDTP_GetMCFont GUICtrlDTP_GetMonthCal ' +
        'GUICtrlDTP_GetRange GUICtrlDTP_GetRangeEx ' +
        'GUICtrlDTP_GetSystemTime GUICtrlDTP_GetSystemTimeEx ' +
        'GUICtrlDTP_SetFormat GUICtrlDTP_SetMCColor ' +
        'GUICtrlDTP_SetMCFont GUICtrlDTP_SetRange ' +
        'GUICtrlDTP_SetRangeEx GUICtrlDTP_SetSystemTime ' +
        'GUICtrlDTP_SetSystemTimeEx GUICtrlEdit_AppendText ' +
        'GUICtrlEdit_BeginUpdate GUICtrlEdit_CanUndo ' +
        'GUICtrlEdit_CharFromPos GUICtrlEdit_Create ' +
        'GUICtrlEdit_Destroy GUICtrlEdit_EmptyUndoBuffer ' +
        'GUICtrlEdit_EndUpdate GUICtrlEdit_Find GUICtrlEdit_FmtLines ' +
        'GUICtrlEdit_GetCueBanner GUICtrlEdit_GetFirstVisibleLine ' +
        'GUICtrlEdit_GetLimitText GUICtrlEdit_GetLine ' +
        'GUICtrlEdit_GetLineCount GUICtrlEdit_GetMargins ' +
        'GUICtrlEdit_GetModify GUICtrlEdit_GetPasswordChar ' +
        'GUICtrlEdit_GetRECT GUICtrlEdit_GetRECTEx GUICtrlEdit_GetSel ' +
        'GUICtrlEdit_GetText GUICtrlEdit_GetTextLen ' +
        'GUICtrlEdit_HideBalloonTip GUICtrlEdit_InsertText ' +
        'GUICtrlEdit_LineFromChar GUICtrlEdit_LineIndex ' +
        'GUICtrlEdit_LineLength GUICtrlEdit_LineScroll ' +
        'GUICtrlEdit_PosFromChar GUICtrlEdit_ReplaceSel ' +
        'GUICtrlEdit_Scroll GUICtrlEdit_SetCueBanner ' +
        'GUICtrlEdit_SetLimitText GUICtrlEdit_SetMargins ' +
        'GUICtrlEdit_SetModify GUICtrlEdit_SetPasswordChar ' +
        'GUICtrlEdit_SetReadOnly GUICtrlEdit_SetRECT ' +
        'GUICtrlEdit_SetRECTEx GUICtrlEdit_SetRECTNP ' +
        'GUICtrlEdit_SetRectNPEx GUICtrlEdit_SetSel ' +
        'GUICtrlEdit_SetTabStops GUICtrlEdit_SetText ' +
        'GUICtrlEdit_ShowBalloonTip GUICtrlEdit_Undo ' +
        'GUICtrlHeader_AddItem GUICtrlHeader_ClearFilter ' +
        'GUICtrlHeader_ClearFilterAll GUICtrlHeader_Create ' +
        'GUICtrlHeader_CreateDragImage GUICtrlHeader_DeleteItem ' +
        'GUICtrlHeader_Destroy GUICtrlHeader_EditFilter ' +
        'GUICtrlHeader_GetBitmapMargin GUICtrlHeader_GetImageList ' +
        'GUICtrlHeader_GetItem GUICtrlHeader_GetItemAlign ' +
        'GUICtrlHeader_GetItemBitmap GUICtrlHeader_GetItemCount ' +
        'GUICtrlHeader_GetItemDisplay GUICtrlHeader_GetItemFlags ' +
        'GUICtrlHeader_GetItemFormat GUICtrlHeader_GetItemImage ' +
        'GUICtrlHeader_GetItemOrder GUICtrlHeader_GetItemParam ' +
        'GUICtrlHeader_GetItemRect GUICtrlHeader_GetItemRectEx ' +
        'GUICtrlHeader_GetItemText GUICtrlHeader_GetItemWidth ' +
        'GUICtrlHeader_GetOrderArray GUICtrlHeader_GetUnicodeFormat ' +
        'GUICtrlHeader_HitTest GUICtrlHeader_InsertItem ' +
        'GUICtrlHeader_Layout GUICtrlHeader_OrderToIndex ' +
        'GUICtrlHeader_SetBitmapMargin ' +
        'GUICtrlHeader_SetFilterChangeTimeout ' +
        'GUICtrlHeader_SetHotDivider GUICtrlHeader_SetImageList ' +
        'GUICtrlHeader_SetItem GUICtrlHeader_SetItemAlign ' +
        'GUICtrlHeader_SetItemBitmap GUICtrlHeader_SetItemDisplay ' +
        'GUICtrlHeader_SetItemFlags GUICtrlHeader_SetItemFormat ' +
        'GUICtrlHeader_SetItemImage GUICtrlHeader_SetItemOrder ' +
        'GUICtrlHeader_SetItemParam GUICtrlHeader_SetItemText ' +
        'GUICtrlHeader_SetItemWidth GUICtrlHeader_SetOrderArray ' +
        'GUICtrlHeader_SetUnicodeFormat GUICtrlIpAddress_ClearAddress ' +
        'GUICtrlIpAddress_Create GUICtrlIpAddress_Destroy ' +
        'GUICtrlIpAddress_Get GUICtrlIpAddress_GetArray ' +
        'GUICtrlIpAddress_GetEx GUICtrlIpAddress_IsBlank ' +
        'GUICtrlIpAddress_Set GUICtrlIpAddress_SetArray ' +
        'GUICtrlIpAddress_SetEx GUICtrlIpAddress_SetFocus ' +
        'GUICtrlIpAddress_SetFont GUICtrlIpAddress_SetRange ' +
        'GUICtrlIpAddress_ShowHide GUICtrlListBox_AddFile ' +
        'GUICtrlListBox_AddString GUICtrlListBox_BeginUpdate ' +
        'GUICtrlListBox_ClickItem GUICtrlListBox_Create ' +
        'GUICtrlListBox_DeleteString GUICtrlListBox_Destroy ' +
        'GUICtrlListBox_Dir GUICtrlListBox_EndUpdate ' +
        'GUICtrlListBox_FindInText GUICtrlListBox_FindString ' +
        'GUICtrlListBox_GetAnchorIndex GUICtrlListBox_GetCaretIndex ' +
        'GUICtrlListBox_GetCount GUICtrlListBox_GetCurSel ' +
        'GUICtrlListBox_GetHorizontalExtent GUICtrlListBox_GetItemData ' +
        'GUICtrlListBox_GetItemHeight GUICtrlListBox_GetItemRect ' +
        'GUICtrlListBox_GetItemRectEx GUICtrlListBox_GetListBoxInfo ' +
        'GUICtrlListBox_GetLocale GUICtrlListBox_GetLocaleCountry ' +
        'GUICtrlListBox_GetLocaleLang GUICtrlListBox_GetLocalePrimLang ' +
        'GUICtrlListBox_GetLocaleSubLang GUICtrlListBox_GetSel ' +
        'GUICtrlListBox_GetSelCount GUICtrlListBox_GetSelItems ' +
        'GUICtrlListBox_GetSelItemsText GUICtrlListBox_GetText ' +
        'GUICtrlListBox_GetTextLen GUICtrlListBox_GetTopIndex ' +
        'GUICtrlListBox_InitStorage GUICtrlListBox_InsertString ' +
        'GUICtrlListBox_ItemFromPoint GUICtrlListBox_ReplaceString ' +
        'GUICtrlListBox_ResetContent GUICtrlListBox_SelectString ' +
        'GUICtrlListBox_SelItemRange GUICtrlListBox_SelItemRangeEx ' +
        'GUICtrlListBox_SetAnchorIndex GUICtrlListBox_SetCaretIndex ' +
        'GUICtrlListBox_SetColumnWidth GUICtrlListBox_SetCurSel ' +
        'GUICtrlListBox_SetHorizontalExtent GUICtrlListBox_SetItemData ' +
        'GUICtrlListBox_SetItemHeight GUICtrlListBox_SetLocale ' +
        'GUICtrlListBox_SetSel GUICtrlListBox_SetTabStops ' +
        'GUICtrlListBox_SetTopIndex GUICtrlListBox_Sort ' +
        'GUICtrlListBox_SwapString GUICtrlListBox_UpdateHScroll ' +
        'GUICtrlListView_AddArray GUICtrlListView_AddColumn ' +
        'GUICtrlListView_AddItem GUICtrlListView_AddSubItem ' +
        'GUICtrlListView_ApproximateViewHeight ' +
        'GUICtrlListView_ApproximateViewRect ' +
        'GUICtrlListView_ApproximateViewWidth GUICtrlListView_Arrange ' +
        'GUICtrlListView_BeginUpdate GUICtrlListView_CancelEditLabel ' +
        'GUICtrlListView_ClickItem GUICtrlListView_CopyItems ' +
        'GUICtrlListView_Create GUICtrlListView_CreateDragImage ' +
        'GUICtrlListView_CreateSolidBitMap ' +
        'GUICtrlListView_DeleteAllItems GUICtrlListView_DeleteColumn ' +
        'GUICtrlListView_DeleteItem GUICtrlListView_DeleteItemsSelected ' +
        'GUICtrlListView_Destroy GUICtrlListView_DrawDragImage ' +
        'GUICtrlListView_EditLabel GUICtrlListView_EnableGroupView ' +
        'GUICtrlListView_EndUpdate GUICtrlListView_EnsureVisible ' +
        'GUICtrlListView_FindInText GUICtrlListView_FindItem ' +
        'GUICtrlListView_FindNearest GUICtrlListView_FindParam ' +
        'GUICtrlListView_FindText GUICtrlListView_GetBkColor ' +
        'GUICtrlListView_GetBkImage GUICtrlListView_GetCallbackMask ' +
        'GUICtrlListView_GetColumn GUICtrlListView_GetColumnCount ' +
        'GUICtrlListView_GetColumnOrder ' +
        'GUICtrlListView_GetColumnOrderArray ' +
        'GUICtrlListView_GetColumnWidth GUICtrlListView_GetCounterPage ' +
        'GUICtrlListView_GetEditControl ' +
        'GUICtrlListView_GetExtendedListViewStyle ' +
        'GUICtrlListView_GetFocusedGroup GUICtrlListView_GetGroupCount ' +
        'GUICtrlListView_GetGroupInfo ' +
        'GUICtrlListView_GetGroupInfoByIndex ' +
        'GUICtrlListView_GetGroupRect ' +
        'GUICtrlListView_GetGroupViewEnabled GUICtrlListView_GetHeader ' +
        'GUICtrlListView_GetHotCursor GUICtrlListView_GetHotItem ' +
        'GUICtrlListView_GetHoverTime GUICtrlListView_GetImageList ' +
        'GUICtrlListView_GetISearchString GUICtrlListView_GetItem ' +
        'GUICtrlListView_GetItemChecked GUICtrlListView_GetItemCount ' +
        'GUICtrlListView_GetItemCut GUICtrlListView_GetItemDropHilited ' +
        'GUICtrlListView_GetItemEx GUICtrlListView_GetItemFocused ' +
        'GUICtrlListView_GetItemGroupID GUICtrlListView_GetItemImage ' +
        'GUICtrlListView_GetItemIndent GUICtrlListView_GetItemParam ' +
        'GUICtrlListView_GetItemPosition ' +
        'GUICtrlListView_GetItemPositionX ' +
        'GUICtrlListView_GetItemPositionY GUICtrlListView_GetItemRect ' +
        'GUICtrlListView_GetItemRectEx GUICtrlListView_GetItemSelected ' +
        'GUICtrlListView_GetItemSpacing GUICtrlListView_GetItemSpacingX ' +
        'GUICtrlListView_GetItemSpacingY GUICtrlListView_GetItemState ' +
        'GUICtrlListView_GetItemStateImage GUICtrlListView_GetItemText ' +
        'GUICtrlListView_GetItemTextArray ' +
        'GUICtrlListView_GetItemTextString GUICtrlListView_GetNextItem ' +
        'GUICtrlListView_GetNumberOfWorkAreas GUICtrlListView_GetOrigin ' +
        'GUICtrlListView_GetOriginX GUICtrlListView_GetOriginY ' +
        'GUICtrlListView_GetOutlineColor ' +
        'GUICtrlListView_GetSelectedColumn ' +
        'GUICtrlListView_GetSelectedCount ' +
        'GUICtrlListView_GetSelectedIndices ' +
        'GUICtrlListView_GetSelectionMark GUICtrlListView_GetStringWidth ' +
        'GUICtrlListView_GetSubItemRect GUICtrlListView_GetTextBkColor ' +
        'GUICtrlListView_GetTextColor GUICtrlListView_GetToolTips ' +
        'GUICtrlListView_GetTopIndex GUICtrlListView_GetUnicodeFormat ' +
        'GUICtrlListView_GetView GUICtrlListView_GetViewDetails ' +
        'GUICtrlListView_GetViewLarge GUICtrlListView_GetViewList ' +
        'GUICtrlListView_GetViewRect GUICtrlListView_GetViewSmall ' +
        'GUICtrlListView_GetViewTile GUICtrlListView_HideColumn ' +
        'GUICtrlListView_HitTest GUICtrlListView_InsertColumn ' +
        'GUICtrlListView_InsertGroup GUICtrlListView_InsertItem ' +
        'GUICtrlListView_JustifyColumn GUICtrlListView_MapIDToIndex ' +
        'GUICtrlListView_MapIndexToID GUICtrlListView_RedrawItems ' +
        'GUICtrlListView_RegisterSortCallBack ' +
        'GUICtrlListView_RemoveAllGroups GUICtrlListView_RemoveGroup ' +
        'GUICtrlListView_Scroll GUICtrlListView_SetBkColor ' +
        'GUICtrlListView_SetBkImage GUICtrlListView_SetCallBackMask ' +
        'GUICtrlListView_SetColumn GUICtrlListView_SetColumnOrder ' +
        'GUICtrlListView_SetColumnOrderArray ' +
        'GUICtrlListView_SetColumnWidth ' +
        'GUICtrlListView_SetExtendedListViewStyle ' +
        'GUICtrlListView_SetGroupInfo GUICtrlListView_SetHotItem ' +
        'GUICtrlListView_SetHoverTime GUICtrlListView_SetIconSpacing ' +
        'GUICtrlListView_SetImageList GUICtrlListView_SetItem ' +
        'GUICtrlListView_SetItemChecked GUICtrlListView_SetItemCount ' +
        'GUICtrlListView_SetItemCut GUICtrlListView_SetItemDropHilited ' +
        'GUICtrlListView_SetItemEx GUICtrlListView_SetItemFocused ' +
        'GUICtrlListView_SetItemGroupID GUICtrlListView_SetItemImage ' +
        'GUICtrlListView_SetItemIndent GUICtrlListView_SetItemParam ' +
        'GUICtrlListView_SetItemPosition ' +
        'GUICtrlListView_SetItemPosition32 ' +
        'GUICtrlListView_SetItemSelected GUICtrlListView_SetItemState ' +
        'GUICtrlListView_SetItemStateImage GUICtrlListView_SetItemText ' +
        'GUICtrlListView_SetOutlineColor ' +
        'GUICtrlListView_SetSelectedColumn ' +
        'GUICtrlListView_SetSelectionMark GUICtrlListView_SetTextBkColor ' +
        'GUICtrlListView_SetTextColor GUICtrlListView_SetToolTips ' +
        'GUICtrlListView_SetUnicodeFormat GUICtrlListView_SetView ' +
        'GUICtrlListView_SetWorkAreas GUICtrlListView_SimpleSort ' +
        'GUICtrlListView_SortItems GUICtrlListView_SubItemHitTest ' +
        'GUICtrlListView_UnRegisterSortCallBack GUICtrlMenu_AddMenuItem ' +
        'GUICtrlMenu_AppendMenu GUICtrlMenu_CalculatePopupWindowPosition ' +
        'GUICtrlMenu_CheckMenuItem GUICtrlMenu_CheckRadioItem ' +
        'GUICtrlMenu_CreateMenu GUICtrlMenu_CreatePopup ' +
        'GUICtrlMenu_DeleteMenu GUICtrlMenu_DestroyMenu ' +
        'GUICtrlMenu_DrawMenuBar GUICtrlMenu_EnableMenuItem ' +
        'GUICtrlMenu_FindItem GUICtrlMenu_FindParent ' +
        'GUICtrlMenu_GetItemBmp GUICtrlMenu_GetItemBmpChecked ' +
        'GUICtrlMenu_GetItemBmpUnchecked GUICtrlMenu_GetItemChecked ' +
        'GUICtrlMenu_GetItemCount GUICtrlMenu_GetItemData ' +
        'GUICtrlMenu_GetItemDefault GUICtrlMenu_GetItemDisabled ' +
        'GUICtrlMenu_GetItemEnabled GUICtrlMenu_GetItemGrayed ' +
        'GUICtrlMenu_GetItemHighlighted GUICtrlMenu_GetItemID ' +
        'GUICtrlMenu_GetItemInfo GUICtrlMenu_GetItemRect ' +
        'GUICtrlMenu_GetItemRectEx GUICtrlMenu_GetItemState ' +
        'GUICtrlMenu_GetItemStateEx GUICtrlMenu_GetItemSubMenu ' +
        'GUICtrlMenu_GetItemText GUICtrlMenu_GetItemType ' +
        'GUICtrlMenu_GetMenu GUICtrlMenu_GetMenuBackground ' +
        'GUICtrlMenu_GetMenuBarInfo GUICtrlMenu_GetMenuContextHelpID ' +
        'GUICtrlMenu_GetMenuData GUICtrlMenu_GetMenuDefaultItem ' +
        'GUICtrlMenu_GetMenuHeight GUICtrlMenu_GetMenuInfo ' +
        'GUICtrlMenu_GetMenuStyle GUICtrlMenu_GetSystemMenu ' +
        'GUICtrlMenu_InsertMenuItem GUICtrlMenu_InsertMenuItemEx ' +
        'GUICtrlMenu_IsMenu GUICtrlMenu_LoadMenu ' +
        'GUICtrlMenu_MapAccelerator GUICtrlMenu_MenuItemFromPoint ' +
        'GUICtrlMenu_RemoveMenu GUICtrlMenu_SetItemBitmaps ' +
        'GUICtrlMenu_SetItemBmp GUICtrlMenu_SetItemBmpChecked ' +
        'GUICtrlMenu_SetItemBmpUnchecked GUICtrlMenu_SetItemChecked ' +
        'GUICtrlMenu_SetItemData GUICtrlMenu_SetItemDefault ' +
        'GUICtrlMenu_SetItemDisabled GUICtrlMenu_SetItemEnabled ' +
        'GUICtrlMenu_SetItemGrayed GUICtrlMenu_SetItemHighlighted ' +
        'GUICtrlMenu_SetItemID GUICtrlMenu_SetItemInfo ' +
        'GUICtrlMenu_SetItemState GUICtrlMenu_SetItemSubMenu ' +
        'GUICtrlMenu_SetItemText GUICtrlMenu_SetItemType ' +
        'GUICtrlMenu_SetMenu GUICtrlMenu_SetMenuBackground ' +
        'GUICtrlMenu_SetMenuContextHelpID GUICtrlMenu_SetMenuData ' +
        'GUICtrlMenu_SetMenuDefaultItem GUICtrlMenu_SetMenuHeight ' +
        'GUICtrlMenu_SetMenuInfo GUICtrlMenu_SetMenuStyle ' +
        'GUICtrlMenu_TrackPopupMenu GUICtrlMonthCal_Create ' +
        'GUICtrlMonthCal_Destroy GUICtrlMonthCal_GetCalendarBorder ' +
        'GUICtrlMonthCal_GetCalendarCount GUICtrlMonthCal_GetColor ' +
        'GUICtrlMonthCal_GetColorArray GUICtrlMonthCal_GetCurSel ' +
        'GUICtrlMonthCal_GetCurSelStr GUICtrlMonthCal_GetFirstDOW ' +
        'GUICtrlMonthCal_GetFirstDOWStr GUICtrlMonthCal_GetMaxSelCount ' +
        'GUICtrlMonthCal_GetMaxTodayWidth ' +
        'GUICtrlMonthCal_GetMinReqHeight GUICtrlMonthCal_GetMinReqRect ' +
        'GUICtrlMonthCal_GetMinReqRectArray ' +
        'GUICtrlMonthCal_GetMinReqWidth GUICtrlMonthCal_GetMonthDelta ' +
        'GUICtrlMonthCal_GetMonthRange GUICtrlMonthCal_GetMonthRangeMax ' +
        'GUICtrlMonthCal_GetMonthRangeMaxStr ' +
        'GUICtrlMonthCal_GetMonthRangeMin ' +
        'GUICtrlMonthCal_GetMonthRangeMinStr ' +
        'GUICtrlMonthCal_GetMonthRangeSpan GUICtrlMonthCal_GetRange ' +
        'GUICtrlMonthCal_GetRangeMax GUICtrlMonthCal_GetRangeMaxStr ' +
        'GUICtrlMonthCal_GetRangeMin GUICtrlMonthCal_GetRangeMinStr ' +
        'GUICtrlMonthCal_GetSelRange GUICtrlMonthCal_GetSelRangeMax ' +
        'GUICtrlMonthCal_GetSelRangeMaxStr ' +
        'GUICtrlMonthCal_GetSelRangeMin ' +
        'GUICtrlMonthCal_GetSelRangeMinStr GUICtrlMonthCal_GetToday ' +
        'GUICtrlMonthCal_GetTodayStr GUICtrlMonthCal_GetUnicodeFormat ' +
        'GUICtrlMonthCal_HitTest GUICtrlMonthCal_SetCalendarBorder ' +
        'GUICtrlMonthCal_SetColor GUICtrlMonthCal_SetCurSel ' +
        'GUICtrlMonthCal_SetDayState GUICtrlMonthCal_SetFirstDOW ' +
        'GUICtrlMonthCal_SetMaxSelCount GUICtrlMonthCal_SetMonthDelta ' +
        'GUICtrlMonthCal_SetRange GUICtrlMonthCal_SetSelRange ' +
        'GUICtrlMonthCal_SetToday GUICtrlMonthCal_SetUnicodeFormat ' +
        'GUICtrlRebar_AddBand GUICtrlRebar_AddToolBarBand ' +
        'GUICtrlRebar_BeginDrag GUICtrlRebar_Create ' +
        'GUICtrlRebar_DeleteBand GUICtrlRebar_Destroy ' +
        'GUICtrlRebar_DragMove GUICtrlRebar_EndDrag ' +
        'GUICtrlRebar_GetBandBackColor GUICtrlRebar_GetBandBorders ' +
        'GUICtrlRebar_GetBandBordersEx GUICtrlRebar_GetBandChildHandle ' +
        'GUICtrlRebar_GetBandChildSize GUICtrlRebar_GetBandCount ' +
        'GUICtrlRebar_GetBandForeColor GUICtrlRebar_GetBandHeaderSize ' +
        'GUICtrlRebar_GetBandID GUICtrlRebar_GetBandIdealSize ' +
        'GUICtrlRebar_GetBandLength GUICtrlRebar_GetBandLParam ' +
        'GUICtrlRebar_GetBandMargins GUICtrlRebar_GetBandMarginsEx ' +
        'GUICtrlRebar_GetBandRect GUICtrlRebar_GetBandRectEx ' +
        'GUICtrlRebar_GetBandStyle GUICtrlRebar_GetBandStyleBreak ' +
        'GUICtrlRebar_GetBandStyleChildEdge ' +
        'GUICtrlRebar_GetBandStyleFixedBMP ' +
        'GUICtrlRebar_GetBandStyleFixedSize ' +
        'GUICtrlRebar_GetBandStyleGripperAlways ' +
        'GUICtrlRebar_GetBandStyleHidden ' +
        'GUICtrlRebar_GetBandStyleHideTitle ' +
        'GUICtrlRebar_GetBandStyleNoGripper ' +
        'GUICtrlRebar_GetBandStyleTopAlign ' +
        'GUICtrlRebar_GetBandStyleUseChevron ' +
        'GUICtrlRebar_GetBandStyleVariableHeight ' +
        'GUICtrlRebar_GetBandText GUICtrlRebar_GetBarHeight ' +
        'GUICtrlRebar_GetBarInfo GUICtrlRebar_GetBKColor ' +
        'GUICtrlRebar_GetColorScheme GUICtrlRebar_GetRowCount ' +
        'GUICtrlRebar_GetRowHeight GUICtrlRebar_GetTextColor ' +
        'GUICtrlRebar_GetToolTips GUICtrlRebar_GetUnicodeFormat ' +
        'GUICtrlRebar_HitTest GUICtrlRebar_IDToIndex ' +
        'GUICtrlRebar_MaximizeBand GUICtrlRebar_MinimizeBand ' +
        'GUICtrlRebar_MoveBand GUICtrlRebar_SetBandBackColor ' +
        'GUICtrlRebar_SetBandForeColor GUICtrlRebar_SetBandHeaderSize ' +
        'GUICtrlRebar_SetBandID GUICtrlRebar_SetBandIdealSize ' +
        'GUICtrlRebar_SetBandLength GUICtrlRebar_SetBandLParam ' +
        'GUICtrlRebar_SetBandStyle GUICtrlRebar_SetBandStyleBreak ' +
        'GUICtrlRebar_SetBandStyleChildEdge ' +
        'GUICtrlRebar_SetBandStyleFixedBMP ' +
        'GUICtrlRebar_SetBandStyleFixedSize ' +
        'GUICtrlRebar_SetBandStyleGripperAlways ' +
        'GUICtrlRebar_SetBandStyleHidden ' +
        'GUICtrlRebar_SetBandStyleHideTitle ' +
        'GUICtrlRebar_SetBandStyleNoGripper ' +
        'GUICtrlRebar_SetBandStyleTopAlign ' +
        'GUICtrlRebar_SetBandStyleUseChevron ' +
        'GUICtrlRebar_SetBandStyleVariableHeight ' +
        'GUICtrlRebar_SetBandText GUICtrlRebar_SetBarInfo ' +
        'GUICtrlRebar_SetBKColor GUICtrlRebar_SetColorScheme ' +
        'GUICtrlRebar_SetTextColor GUICtrlRebar_SetToolTips ' +
        'GUICtrlRebar_SetUnicodeFormat GUICtrlRebar_ShowBand ' +
        'GUICtrlRichEdit_AppendText GUICtrlRichEdit_AutoDetectURL ' +
        'GUICtrlRichEdit_CanPaste GUICtrlRichEdit_CanPasteSpecial ' +
        'GUICtrlRichEdit_CanRedo GUICtrlRichEdit_CanUndo ' +
        'GUICtrlRichEdit_ChangeFontSize GUICtrlRichEdit_Copy ' +
        'GUICtrlRichEdit_Create GUICtrlRichEdit_Cut ' +
        'GUICtrlRichEdit_Deselect GUICtrlRichEdit_Destroy ' +
        'GUICtrlRichEdit_EmptyUndoBuffer GUICtrlRichEdit_FindText ' +
        'GUICtrlRichEdit_FindTextInRange GUICtrlRichEdit_GetBkColor ' +
        'GUICtrlRichEdit_GetCharAttributes ' +
        'GUICtrlRichEdit_GetCharBkColor GUICtrlRichEdit_GetCharColor ' +
        'GUICtrlRichEdit_GetCharPosFromXY ' +
        'GUICtrlRichEdit_GetCharPosOfNextWord ' +
        'GUICtrlRichEdit_GetCharPosOfPreviousWord ' +
        'GUICtrlRichEdit_GetCharWordBreakInfo ' +
        'GUICtrlRichEdit_GetFirstCharPosOnLine GUICtrlRichEdit_GetFont ' +
        'GUICtrlRichEdit_GetLineCount GUICtrlRichEdit_GetLineLength ' +
        'GUICtrlRichEdit_GetLineNumberFromCharPos ' +
        'GUICtrlRichEdit_GetNextRedo GUICtrlRichEdit_GetNextUndo ' +
        'GUICtrlRichEdit_GetNumberOfFirstVisibleLine ' +
        'GUICtrlRichEdit_GetParaAlignment ' +
        'GUICtrlRichEdit_GetParaAttributes GUICtrlRichEdit_GetParaBorder ' +
        'GUICtrlRichEdit_GetParaIndents GUICtrlRichEdit_GetParaNumbering ' +
        'GUICtrlRichEdit_GetParaShading GUICtrlRichEdit_GetParaSpacing ' +
        'GUICtrlRichEdit_GetParaTabStops GUICtrlRichEdit_GetPasswordChar ' +
        'GUICtrlRichEdit_GetRECT GUICtrlRichEdit_GetScrollPos ' +
        'GUICtrlRichEdit_GetSel GUICtrlRichEdit_GetSelAA ' +
        'GUICtrlRichEdit_GetSelText GUICtrlRichEdit_GetSpaceUnit ' +
        'GUICtrlRichEdit_GetText GUICtrlRichEdit_GetTextInLine ' +
        'GUICtrlRichEdit_GetTextInRange GUICtrlRichEdit_GetTextLength ' +
        'GUICtrlRichEdit_GetVersion GUICtrlRichEdit_GetXYFromCharPos ' +
        'GUICtrlRichEdit_GetZoom GUICtrlRichEdit_GotoCharPos ' +
        'GUICtrlRichEdit_HideSelection GUICtrlRichEdit_InsertText ' +
        'GUICtrlRichEdit_IsModified GUICtrlRichEdit_IsTextSelected ' +
        'GUICtrlRichEdit_Paste GUICtrlRichEdit_PasteSpecial ' +
        'GUICtrlRichEdit_PauseRedraw GUICtrlRichEdit_Redo ' +
        'GUICtrlRichEdit_ReplaceText GUICtrlRichEdit_ResumeRedraw ' +
        'GUICtrlRichEdit_ScrollLineOrPage GUICtrlRichEdit_ScrollLines ' +
        'GUICtrlRichEdit_ScrollToCaret GUICtrlRichEdit_SetBkColor ' +
        'GUICtrlRichEdit_SetCharAttributes ' +
        'GUICtrlRichEdit_SetCharBkColor GUICtrlRichEdit_SetCharColor ' +
        'GUICtrlRichEdit_SetEventMask GUICtrlRichEdit_SetFont ' +
        'GUICtrlRichEdit_SetLimitOnText GUICtrlRichEdit_SetModified ' +
        'GUICtrlRichEdit_SetParaAlignment ' +
        'GUICtrlRichEdit_SetParaAttributes GUICtrlRichEdit_SetParaBorder ' +
        'GUICtrlRichEdit_SetParaIndents GUICtrlRichEdit_SetParaNumbering ' +
        'GUICtrlRichEdit_SetParaShading GUICtrlRichEdit_SetParaSpacing ' +
        'GUICtrlRichEdit_SetParaTabStops GUICtrlRichEdit_SetPasswordChar ' +
        'GUICtrlRichEdit_SetReadOnly GUICtrlRichEdit_SetRECT ' +
        'GUICtrlRichEdit_SetScrollPos GUICtrlRichEdit_SetSel ' +
        'GUICtrlRichEdit_SetSpaceUnit GUICtrlRichEdit_SetTabStops ' +
        'GUICtrlRichEdit_SetText GUICtrlRichEdit_SetUndoLimit ' +
        'GUICtrlRichEdit_SetZoom GUICtrlRichEdit_StreamFromFile ' +
        'GUICtrlRichEdit_StreamFromVar GUICtrlRichEdit_StreamToFile ' +
        'GUICtrlRichEdit_StreamToVar GUICtrlRichEdit_Undo ' +
        'GUICtrlSlider_ClearSel GUICtrlSlider_ClearTics ' +
        'GUICtrlSlider_Create GUICtrlSlider_Destroy ' +
        'GUICtrlSlider_GetBuddy GUICtrlSlider_GetChannelRect ' +
        'GUICtrlSlider_GetChannelRectEx GUICtrlSlider_GetLineSize ' +
        'GUICtrlSlider_GetLogicalTics GUICtrlSlider_GetNumTics ' +
        'GUICtrlSlider_GetPageSize GUICtrlSlider_GetPos ' +
        'GUICtrlSlider_GetRange GUICtrlSlider_GetRangeMax ' +
        'GUICtrlSlider_GetRangeMin GUICtrlSlider_GetSel ' +
        'GUICtrlSlider_GetSelEnd GUICtrlSlider_GetSelStart ' +
        'GUICtrlSlider_GetThumbLength GUICtrlSlider_GetThumbRect ' +
        'GUICtrlSlider_GetThumbRectEx GUICtrlSlider_GetTic ' +
        'GUICtrlSlider_GetTicPos GUICtrlSlider_GetToolTips ' +
        'GUICtrlSlider_GetUnicodeFormat GUICtrlSlider_SetBuddy ' +
        'GUICtrlSlider_SetLineSize GUICtrlSlider_SetPageSize ' +
        'GUICtrlSlider_SetPos GUICtrlSlider_SetRange ' +
        'GUICtrlSlider_SetRangeMax GUICtrlSlider_SetRangeMin ' +
        'GUICtrlSlider_SetSel GUICtrlSlider_SetSelEnd ' +
        'GUICtrlSlider_SetSelStart GUICtrlSlider_SetThumbLength ' +
        'GUICtrlSlider_SetTic GUICtrlSlider_SetTicFreq ' +
        'GUICtrlSlider_SetTipSide GUICtrlSlider_SetToolTips ' +
        'GUICtrlSlider_SetUnicodeFormat GUICtrlStatusBar_Create ' +
        'GUICtrlStatusBar_Destroy GUICtrlStatusBar_EmbedControl ' +
        'GUICtrlStatusBar_GetBorders GUICtrlStatusBar_GetBordersHorz ' +
        'GUICtrlStatusBar_GetBordersRect GUICtrlStatusBar_GetBordersVert ' +
        'GUICtrlStatusBar_GetCount GUICtrlStatusBar_GetHeight ' +
        'GUICtrlStatusBar_GetIcon GUICtrlStatusBar_GetParts ' +
        'GUICtrlStatusBar_GetRect GUICtrlStatusBar_GetRectEx ' +
        'GUICtrlStatusBar_GetText GUICtrlStatusBar_GetTextFlags ' +
        'GUICtrlStatusBar_GetTextLength GUICtrlStatusBar_GetTextLengthEx ' +
        'GUICtrlStatusBar_GetTipText GUICtrlStatusBar_GetUnicodeFormat ' +
        'GUICtrlStatusBar_GetWidth GUICtrlStatusBar_IsSimple ' +
        'GUICtrlStatusBar_Resize GUICtrlStatusBar_SetBkColor ' +
        'GUICtrlStatusBar_SetIcon GUICtrlStatusBar_SetMinHeight ' +
        'GUICtrlStatusBar_SetParts GUICtrlStatusBar_SetSimple ' +
        'GUICtrlStatusBar_SetText GUICtrlStatusBar_SetTipText ' +
        'GUICtrlStatusBar_SetUnicodeFormat GUICtrlStatusBar_ShowHide ' +
        'GUICtrlTab_ActivateTab GUICtrlTab_ClickTab GUICtrlTab_Create ' +
        'GUICtrlTab_DeleteAllItems GUICtrlTab_DeleteItem ' +
        'GUICtrlTab_DeselectAll GUICtrlTab_Destroy GUICtrlTab_FindTab ' +
        'GUICtrlTab_GetCurFocus GUICtrlTab_GetCurSel ' +
        'GUICtrlTab_GetDisplayRect GUICtrlTab_GetDisplayRectEx ' +
        'GUICtrlTab_GetExtendedStyle GUICtrlTab_GetImageList ' +
        'GUICtrlTab_GetItem GUICtrlTab_GetItemCount ' +
        'GUICtrlTab_GetItemImage GUICtrlTab_GetItemParam ' +
        'GUICtrlTab_GetItemRect GUICtrlTab_GetItemRectEx ' +
        'GUICtrlTab_GetItemState GUICtrlTab_GetItemText ' +
        'GUICtrlTab_GetRowCount GUICtrlTab_GetToolTips ' +
        'GUICtrlTab_GetUnicodeFormat GUICtrlTab_HighlightItem ' +
        'GUICtrlTab_HitTest GUICtrlTab_InsertItem ' +
        'GUICtrlTab_RemoveImage GUICtrlTab_SetCurFocus ' +
        'GUICtrlTab_SetCurSel GUICtrlTab_SetExtendedStyle ' +
        'GUICtrlTab_SetImageList GUICtrlTab_SetItem ' +
        'GUICtrlTab_SetItemImage GUICtrlTab_SetItemParam ' +
        'GUICtrlTab_SetItemSize GUICtrlTab_SetItemState ' +
        'GUICtrlTab_SetItemText GUICtrlTab_SetMinTabWidth ' +
        'GUICtrlTab_SetPadding GUICtrlTab_SetToolTips ' +
        'GUICtrlTab_SetUnicodeFormat GUICtrlToolbar_AddBitmap ' +
        'GUICtrlToolbar_AddButton GUICtrlToolbar_AddButtonSep ' +
        'GUICtrlToolbar_AddString GUICtrlToolbar_ButtonCount ' +
        'GUICtrlToolbar_CheckButton GUICtrlToolbar_ClickAccel ' +
        'GUICtrlToolbar_ClickButton GUICtrlToolbar_ClickIndex ' +
        'GUICtrlToolbar_CommandToIndex GUICtrlToolbar_Create ' +
        'GUICtrlToolbar_Customize GUICtrlToolbar_DeleteButton ' +
        'GUICtrlToolbar_Destroy GUICtrlToolbar_EnableButton ' +
        'GUICtrlToolbar_FindToolbar GUICtrlToolbar_GetAnchorHighlight ' +
        'GUICtrlToolbar_GetBitmapFlags GUICtrlToolbar_GetButtonBitmap ' +
        'GUICtrlToolbar_GetButtonInfo GUICtrlToolbar_GetButtonInfoEx ' +
        'GUICtrlToolbar_GetButtonParam GUICtrlToolbar_GetButtonRect ' +
        'GUICtrlToolbar_GetButtonRectEx GUICtrlToolbar_GetButtonSize ' +
        'GUICtrlToolbar_GetButtonState GUICtrlToolbar_GetButtonStyle ' +
        'GUICtrlToolbar_GetButtonText GUICtrlToolbar_GetColorScheme ' +
        'GUICtrlToolbar_GetDisabledImageList ' +
        'GUICtrlToolbar_GetExtendedStyle GUICtrlToolbar_GetHotImageList ' +
        'GUICtrlToolbar_GetHotItem GUICtrlToolbar_GetImageList ' +
        'GUICtrlToolbar_GetInsertMark GUICtrlToolbar_GetInsertMarkColor ' +
        'GUICtrlToolbar_GetMaxSize GUICtrlToolbar_GetMetrics ' +
        'GUICtrlToolbar_GetPadding GUICtrlToolbar_GetRows ' +
        'GUICtrlToolbar_GetString GUICtrlToolbar_GetStyle ' +
        'GUICtrlToolbar_GetStyleAltDrag ' +
        'GUICtrlToolbar_GetStyleCustomErase GUICtrlToolbar_GetStyleFlat ' +
        'GUICtrlToolbar_GetStyleList GUICtrlToolbar_GetStyleRegisterDrop ' +
        'GUICtrlToolbar_GetStyleToolTips ' +
        'GUICtrlToolbar_GetStyleTransparent ' +
        'GUICtrlToolbar_GetStyleWrapable GUICtrlToolbar_GetTextRows ' +
        'GUICtrlToolbar_GetToolTips GUICtrlToolbar_GetUnicodeFormat ' +
        'GUICtrlToolbar_HideButton GUICtrlToolbar_HighlightButton ' +
        'GUICtrlToolbar_HitTest GUICtrlToolbar_IndexToCommand ' +
        'GUICtrlToolbar_InsertButton GUICtrlToolbar_InsertMarkHitTest ' +
        'GUICtrlToolbar_IsButtonChecked GUICtrlToolbar_IsButtonEnabled ' +
        'GUICtrlToolbar_IsButtonHidden ' +
        'GUICtrlToolbar_IsButtonHighlighted ' +
        'GUICtrlToolbar_IsButtonIndeterminate ' +
        'GUICtrlToolbar_IsButtonPressed GUICtrlToolbar_LoadBitmap ' +
        'GUICtrlToolbar_LoadImages GUICtrlToolbar_MapAccelerator ' +
        'GUICtrlToolbar_MoveButton GUICtrlToolbar_PressButton ' +
        'GUICtrlToolbar_SetAnchorHighlight GUICtrlToolbar_SetBitmapSize ' +
        'GUICtrlToolbar_SetButtonBitMap GUICtrlToolbar_SetButtonInfo ' +
        'GUICtrlToolbar_SetButtonInfoEx GUICtrlToolbar_SetButtonParam ' +
        'GUICtrlToolbar_SetButtonSize GUICtrlToolbar_SetButtonState ' +
        'GUICtrlToolbar_SetButtonStyle GUICtrlToolbar_SetButtonText ' +
        'GUICtrlToolbar_SetButtonWidth GUICtrlToolbar_SetCmdID ' +
        'GUICtrlToolbar_SetColorScheme ' +
        'GUICtrlToolbar_SetDisabledImageList ' +
        'GUICtrlToolbar_SetDrawTextFlags GUICtrlToolbar_SetExtendedStyle ' +
        'GUICtrlToolbar_SetHotImageList GUICtrlToolbar_SetHotItem ' +
        'GUICtrlToolbar_SetImageList GUICtrlToolbar_SetIndent ' +
        'GUICtrlToolbar_SetIndeterminate GUICtrlToolbar_SetInsertMark ' +
        'GUICtrlToolbar_SetInsertMarkColor GUICtrlToolbar_SetMaxTextRows ' +
        'GUICtrlToolbar_SetMetrics GUICtrlToolbar_SetPadding ' +
        'GUICtrlToolbar_SetParent GUICtrlToolbar_SetRows ' +
        'GUICtrlToolbar_SetStyle GUICtrlToolbar_SetStyleAltDrag ' +
        'GUICtrlToolbar_SetStyleCustomErase GUICtrlToolbar_SetStyleFlat ' +
        'GUICtrlToolbar_SetStyleList GUICtrlToolbar_SetStyleRegisterDrop ' +
        'GUICtrlToolbar_SetStyleToolTips ' +
        'GUICtrlToolbar_SetStyleTransparent ' +
        'GUICtrlToolbar_SetStyleWrapable GUICtrlToolbar_SetToolTips ' +
        'GUICtrlToolbar_SetUnicodeFormat GUICtrlToolbar_SetWindowTheme ' +
        'GUICtrlTreeView_Add GUICtrlTreeView_AddChild ' +
        'GUICtrlTreeView_AddChildFirst GUICtrlTreeView_AddFirst ' +
        'GUICtrlTreeView_BeginUpdate GUICtrlTreeView_ClickItem ' +
        'GUICtrlTreeView_Create GUICtrlTreeView_CreateDragImage ' +
        'GUICtrlTreeView_CreateSolidBitMap GUICtrlTreeView_Delete ' +
        'GUICtrlTreeView_DeleteAll GUICtrlTreeView_DeleteChildren ' +
        'GUICtrlTreeView_Destroy GUICtrlTreeView_DisplayRect ' +
        'GUICtrlTreeView_DisplayRectEx GUICtrlTreeView_EditText ' +
        'GUICtrlTreeView_EndEdit GUICtrlTreeView_EndUpdate ' +
        'GUICtrlTreeView_EnsureVisible GUICtrlTreeView_Expand ' +
        'GUICtrlTreeView_ExpandedOnce GUICtrlTreeView_FindItem ' +
        'GUICtrlTreeView_FindItemEx GUICtrlTreeView_GetBkColor ' +
        'GUICtrlTreeView_GetBold GUICtrlTreeView_GetChecked ' +
        'GUICtrlTreeView_GetChildCount GUICtrlTreeView_GetChildren ' +
        'GUICtrlTreeView_GetCount GUICtrlTreeView_GetCut ' +
        'GUICtrlTreeView_GetDropTarget GUICtrlTreeView_GetEditControl ' +
        'GUICtrlTreeView_GetExpanded GUICtrlTreeView_GetFirstChild ' +
        'GUICtrlTreeView_GetFirstItem GUICtrlTreeView_GetFirstVisible ' +
        'GUICtrlTreeView_GetFocused GUICtrlTreeView_GetHeight ' +
        'GUICtrlTreeView_GetImageIndex ' +
        'GUICtrlTreeView_GetImageListIconHandle ' +
        'GUICtrlTreeView_GetIndent GUICtrlTreeView_GetInsertMarkColor ' +
        'GUICtrlTreeView_GetISearchString GUICtrlTreeView_GetItemByIndex ' +
        'GUICtrlTreeView_GetItemHandle GUICtrlTreeView_GetItemParam ' +
        'GUICtrlTreeView_GetLastChild GUICtrlTreeView_GetLineColor ' +
        'GUICtrlTreeView_GetNext GUICtrlTreeView_GetNextChild ' +
        'GUICtrlTreeView_GetNextSibling GUICtrlTreeView_GetNextVisible ' +
        'GUICtrlTreeView_GetNormalImageList ' +
        'GUICtrlTreeView_GetParentHandle GUICtrlTreeView_GetParentParam ' +
        'GUICtrlTreeView_GetPrev GUICtrlTreeView_GetPrevChild ' +
        'GUICtrlTreeView_GetPrevSibling GUICtrlTreeView_GetPrevVisible ' +
        'GUICtrlTreeView_GetScrollTime GUICtrlTreeView_GetSelected ' +
        'GUICtrlTreeView_GetSelectedImageIndex ' +
        'GUICtrlTreeView_GetSelection GUICtrlTreeView_GetSiblingCount ' +
        'GUICtrlTreeView_GetState GUICtrlTreeView_GetStateImageIndex ' +
        'GUICtrlTreeView_GetStateImageList GUICtrlTreeView_GetText ' +
        'GUICtrlTreeView_GetTextColor GUICtrlTreeView_GetToolTips ' +
        'GUICtrlTreeView_GetTree GUICtrlTreeView_GetUnicodeFormat ' +
        'GUICtrlTreeView_GetVisible GUICtrlTreeView_GetVisibleCount ' +
        'GUICtrlTreeView_HitTest GUICtrlTreeView_HitTestEx ' +
        'GUICtrlTreeView_HitTestItem GUICtrlTreeView_Index ' +
        'GUICtrlTreeView_InsertItem GUICtrlTreeView_IsFirstItem ' +
        'GUICtrlTreeView_IsParent GUICtrlTreeView_Level ' +
        'GUICtrlTreeView_SelectItem GUICtrlTreeView_SelectItemByIndex ' +
        'GUICtrlTreeView_SetBkColor GUICtrlTreeView_SetBold ' +
        'GUICtrlTreeView_SetChecked GUICtrlTreeView_SetCheckedByIndex ' +
        'GUICtrlTreeView_SetChildren GUICtrlTreeView_SetCut ' +
        'GUICtrlTreeView_SetDropTarget GUICtrlTreeView_SetFocused ' +
        'GUICtrlTreeView_SetHeight GUICtrlTreeView_SetIcon ' +
        'GUICtrlTreeView_SetImageIndex GUICtrlTreeView_SetIndent ' +
        'GUICtrlTreeView_SetInsertMark ' +
        'GUICtrlTreeView_SetInsertMarkColor ' +
        'GUICtrlTreeView_SetItemHeight GUICtrlTreeView_SetItemParam ' +
        'GUICtrlTreeView_SetLineColor GUICtrlTreeView_SetNormalImageList ' +
        'GUICtrlTreeView_SetScrollTime GUICtrlTreeView_SetSelected ' +
        'GUICtrlTreeView_SetSelectedImageIndex GUICtrlTreeView_SetState ' +
        'GUICtrlTreeView_SetStateImageIndex ' +
        'GUICtrlTreeView_SetStateImageList GUICtrlTreeView_SetText ' +
        'GUICtrlTreeView_SetTextColor GUICtrlTreeView_SetToolTips ' +
        'GUICtrlTreeView_SetUnicodeFormat GUICtrlTreeView_Sort ' +
        'GUIImageList_Add GUIImageList_AddBitmap GUIImageList_AddIcon ' +
        'GUIImageList_AddMasked GUIImageList_BeginDrag ' +
        'GUIImageList_Copy GUIImageList_Create GUIImageList_Destroy ' +
        'GUIImageList_DestroyIcon GUIImageList_DragEnter ' +
        'GUIImageList_DragLeave GUIImageList_DragMove ' +
        'GUIImageList_Draw GUIImageList_DrawEx GUIImageList_Duplicate ' +
        'GUIImageList_EndDrag GUIImageList_GetBkColor ' +
        'GUIImageList_GetIcon GUIImageList_GetIconHeight ' +
        'GUIImageList_GetIconSize GUIImageList_GetIconSizeEx ' +
        'GUIImageList_GetIconWidth GUIImageList_GetImageCount ' +
        'GUIImageList_GetImageInfoEx GUIImageList_Remove ' +
        'GUIImageList_ReplaceIcon GUIImageList_SetBkColor ' +
        'GUIImageList_SetIconSize GUIImageList_SetImageCount ' +
        'GUIImageList_Swap GUIScrollBars_EnableScrollBar ' +
        'GUIScrollBars_GetScrollBarInfoEx GUIScrollBars_GetScrollBarRect ' +
        'GUIScrollBars_GetScrollBarRGState ' +
        'GUIScrollBars_GetScrollBarXYLineButton ' +
        'GUIScrollBars_GetScrollBarXYThumbBottom ' +
        'GUIScrollBars_GetScrollBarXYThumbTop ' +
        'GUIScrollBars_GetScrollInfo GUIScrollBars_GetScrollInfoEx ' +
        'GUIScrollBars_GetScrollInfoMax GUIScrollBars_GetScrollInfoMin ' +
        'GUIScrollBars_GetScrollInfoPage GUIScrollBars_GetScrollInfoPos ' +
        'GUIScrollBars_GetScrollInfoTrackPos GUIScrollBars_GetScrollPos ' +
        'GUIScrollBars_GetScrollRange GUIScrollBars_Init ' +
        'GUIScrollBars_ScrollWindow GUIScrollBars_SetScrollInfo ' +
        'GUIScrollBars_SetScrollInfoMax GUIScrollBars_SetScrollInfoMin ' +
        'GUIScrollBars_SetScrollInfoPage GUIScrollBars_SetScrollInfoPos ' +
        'GUIScrollBars_SetScrollRange GUIScrollBars_ShowScrollBar ' +
        'GUIToolTip_Activate GUIToolTip_AddTool GUIToolTip_AdjustRect ' +
        'GUIToolTip_BitsToTTF GUIToolTip_Create GUIToolTip_Deactivate ' +
        'GUIToolTip_DelTool GUIToolTip_Destroy GUIToolTip_EnumTools ' +
        'GUIToolTip_GetBubbleHeight GUIToolTip_GetBubbleSize ' +
        'GUIToolTip_GetBubbleWidth GUIToolTip_GetCurrentTool ' +
        'GUIToolTip_GetDelayTime GUIToolTip_GetMargin ' +
        'GUIToolTip_GetMarginEx GUIToolTip_GetMaxTipWidth ' +
        'GUIToolTip_GetText GUIToolTip_GetTipBkColor ' +
        'GUIToolTip_GetTipTextColor GUIToolTip_GetTitleBitMap ' +
        'GUIToolTip_GetTitleText GUIToolTip_GetToolCount ' +
        'GUIToolTip_GetToolInfo GUIToolTip_HitTest ' +
        'GUIToolTip_NewToolRect GUIToolTip_Pop GUIToolTip_PopUp ' +
        'GUIToolTip_SetDelayTime GUIToolTip_SetMargin ' +
        'GUIToolTip_SetMaxTipWidth GUIToolTip_SetTipBkColor ' +
        'GUIToolTip_SetTipTextColor GUIToolTip_SetTitle ' +
        'GUIToolTip_SetToolInfo GUIToolTip_SetWindowTheme ' +
        'GUIToolTip_ToolExists GUIToolTip_ToolToArray ' +
        'GUIToolTip_TrackActivate GUIToolTip_TrackPosition ' +
        'GUIToolTip_Update GUIToolTip_UpdateTipText HexToString ' +
        'IEAction IEAttach IEBodyReadHTML IEBodyReadText ' +
        'IEBodyWriteHTML IECreate IECreateEmbedded IEDocGetObj ' +
        'IEDocInsertHTML IEDocInsertText IEDocReadHTML ' +
        'IEDocWriteHTML IEErrorNotify IEFormElementCheckBoxSelect ' +
        'IEFormElementGetCollection IEFormElementGetObjByName ' +
        'IEFormElementGetValue IEFormElementOptionSelect ' +
        'IEFormElementRadioSelect IEFormElementSetValue ' +
        'IEFormGetCollection IEFormGetObjByName IEFormImageClick ' +
        'IEFormReset IEFormSubmit IEFrameGetCollection ' +
        'IEFrameGetObjByName IEGetObjById IEGetObjByName ' +
        'IEHeadInsertEventScript IEImgClick IEImgGetCollection ' +
        'IEIsFrameSet IELinkClickByIndex IELinkClickByText ' +
        'IELinkGetCollection IELoadWait IELoadWaitTimeout IENavigate ' +
        'IEPropertyGet IEPropertySet IEQuit IETableGetCollection ' +
        'IETableWriteToArray IETagNameAllGetCollection ' +
        'IETagNameGetCollection IE_Example IE_Introduction ' +
        'IE_VersionInfo INetExplorerCapable INetGetSource INetMail ' +
        'INetSmtpMail IsPressed MathCheckDiv Max MemGlobalAlloc ' +
        'MemGlobalFree MemGlobalLock MemGlobalSize MemGlobalUnlock ' +
        'MemMoveMemory MemVirtualAlloc MemVirtualAllocEx ' +
        'MemVirtualFree MemVirtualFreeEx Min MouseTrap ' +
        'NamedPipes_CallNamedPipe NamedPipes_ConnectNamedPipe ' +
        'NamedPipes_CreateNamedPipe NamedPipes_CreatePipe ' +
        'NamedPipes_DisconnectNamedPipe ' +
        'NamedPipes_GetNamedPipeHandleState NamedPipes_GetNamedPipeInfo ' +
        'NamedPipes_PeekNamedPipe NamedPipes_SetNamedPipeHandleState ' +
        'NamedPipes_TransactNamedPipe NamedPipes_WaitNamedPipe ' +
        'Net_Share_ConnectionEnum Net_Share_FileClose ' +
        'Net_Share_FileEnum Net_Share_FileGetInfo Net_Share_PermStr ' +
        'Net_Share_ResourceStr Net_Share_SessionDel ' +
        'Net_Share_SessionEnum Net_Share_SessionGetInfo ' +
        'Net_Share_ShareAdd Net_Share_ShareCheck Net_Share_ShareDel ' +
        'Net_Share_ShareEnum Net_Share_ShareGetInfo ' +
        'Net_Share_ShareSetInfo Net_Share_StatisticsGetSvr ' +
        'Net_Share_StatisticsGetWrk Now NowCalc NowCalcDate ' +
        'NowDate NowTime PathFull PathGetRelative PathMake ' +
        'PathSplit ProcessGetName ProcessGetPriority Radian ' +
        'ReplaceStringInFile RunDos ScreenCapture_Capture ' +
        'ScreenCapture_CaptureWnd ScreenCapture_SaveImage ' +
        'ScreenCapture_SetBMPFormat ScreenCapture_SetJPGQuality ' +
        'ScreenCapture_SetTIFColorDepth ScreenCapture_SetTIFCompression ' +
        'Security__AdjustTokenPrivileges ' +
        'Security__CreateProcessWithToken Security__DuplicateTokenEx ' +
        'Security__GetAccountSid Security__GetLengthSid ' +
        'Security__GetTokenInformation Security__ImpersonateSelf ' +
        'Security__IsValidSid Security__LookupAccountName ' +
        'Security__LookupAccountSid Security__LookupPrivilegeValue ' +
        'Security__OpenProcessToken Security__OpenThreadToken ' +
        'Security__OpenThreadTokenEx Security__SetPrivilege ' +
        'Security__SetTokenInformation Security__SidToStringSid ' +
        'Security__SidTypeStr Security__StringSidToSid SendMessage ' +
        'SendMessageA SetDate SetTime Singleton SoundClose ' +
        'SoundLength SoundOpen SoundPause SoundPlay SoundPos ' +
        'SoundResume SoundSeek SoundStatus SoundStop ' +
        'SQLite_Changes SQLite_Close SQLite_Display2DResult ' +
        'SQLite_Encode SQLite_ErrCode SQLite_ErrMsg SQLite_Escape ' +
        'SQLite_Exec SQLite_FastEncode SQLite_FastEscape ' +
        'SQLite_FetchData SQLite_FetchNames SQLite_GetTable ' +
        'SQLite_GetTable2d SQLite_LastInsertRowID SQLite_LibVersion ' +
        'SQLite_Open SQLite_Query SQLite_QueryFinalize ' +
        'SQLite_QueryReset SQLite_QuerySingleRow SQLite_SafeMode ' +
        'SQLite_SetTimeout SQLite_Shutdown SQLite_SQLiteExe ' +
        'SQLite_Startup SQLite_TotalChanges StringBetween ' +
        'StringExplode StringInsert StringProper StringRepeat ' +
        'StringTitleCase StringToHex TCPIpToName TempFile ' +
        'TicksToTime Timer_Diff Timer_GetIdleTime Timer_GetTimerID ' +
        'Timer_Init Timer_KillAllTimers Timer_KillTimer ' +
        'Timer_SetTimer TimeToTicks VersionCompare viClose ' +
        'viExecCommand viFindGpib viGpibBusReset viGTL ' +
        'viInteractiveControl viOpen viSetAttribute viSetTimeout ' +
        'WeekNumberISO WinAPI_AbortPath WinAPI_ActivateKeyboardLayout ' +
        'WinAPI_AddClipboardFormatListener WinAPI_AddFontMemResourceEx ' +
        'WinAPI_AddFontResourceEx WinAPI_AddIconOverlay ' +
        'WinAPI_AddIconTransparency WinAPI_AddMRUString ' +
        'WinAPI_AdjustBitmap WinAPI_AdjustTokenPrivileges ' +
        'WinAPI_AdjustWindowRectEx WinAPI_AlphaBlend WinAPI_AngleArc ' +
        'WinAPI_AnimateWindow WinAPI_Arc WinAPI_ArcTo ' +
        'WinAPI_ArrayToStruct WinAPI_AssignProcessToJobObject ' +
        'WinAPI_AssocGetPerceivedType WinAPI_AssocQueryString ' +
        'WinAPI_AttachConsole WinAPI_AttachThreadInput ' +
        'WinAPI_BackupRead WinAPI_BackupReadAbort WinAPI_BackupSeek ' +
        'WinAPI_BackupWrite WinAPI_BackupWriteAbort WinAPI_Beep ' +
        'WinAPI_BeginBufferedPaint WinAPI_BeginDeferWindowPos ' +
        'WinAPI_BeginPaint WinAPI_BeginPath WinAPI_BeginUpdateResource ' +
        'WinAPI_BitBlt WinAPI_BringWindowToTop ' +
        'WinAPI_BroadcastSystemMessage WinAPI_BrowseForFolderDlg ' +
        'WinAPI_BufferedPaintClear WinAPI_BufferedPaintInit ' +
        'WinAPI_BufferedPaintSetAlpha WinAPI_BufferedPaintUnInit ' +
        'WinAPI_CallNextHookEx WinAPI_CallWindowProc ' +
        'WinAPI_CallWindowProcW WinAPI_CascadeWindows ' +
        'WinAPI_ChangeWindowMessageFilterEx WinAPI_CharToOem ' +
        'WinAPI_ChildWindowFromPointEx WinAPI_ClientToScreen ' +
        'WinAPI_ClipCursor WinAPI_CloseDesktop WinAPI_CloseEnhMetaFile ' +
        'WinAPI_CloseFigure WinAPI_CloseHandle WinAPI_CloseThemeData ' +
        'WinAPI_CloseWindow WinAPI_CloseWindowStation ' +
        'WinAPI_CLSIDFromProgID WinAPI_CoInitialize ' +
        'WinAPI_ColorAdjustLuma WinAPI_ColorHLSToRGB ' +
        'WinAPI_ColorRGBToHLS WinAPI_CombineRgn ' +
        'WinAPI_CombineTransform WinAPI_CommandLineToArgv ' +
        'WinAPI_CommDlgExtendedError WinAPI_CommDlgExtendedErrorEx ' +
        'WinAPI_CompareString WinAPI_CompressBitmapBits ' +
        'WinAPI_CompressBuffer WinAPI_ComputeCrc32 ' +
        'WinAPI_ConfirmCredentials WinAPI_CopyBitmap WinAPI_CopyCursor ' +
        'WinAPI_CopyEnhMetaFile WinAPI_CopyFileEx WinAPI_CopyIcon ' +
        'WinAPI_CopyImage WinAPI_CopyRect WinAPI_CopyStruct ' +
        'WinAPI_CoTaskMemAlloc WinAPI_CoTaskMemFree ' +
        'WinAPI_CoTaskMemRealloc WinAPI_CoUninitialize ' +
        'WinAPI_Create32BitHBITMAP WinAPI_Create32BitHICON ' +
        'WinAPI_CreateANDBitmap WinAPI_CreateBitmap ' +
        'WinAPI_CreateBitmapIndirect WinAPI_CreateBrushIndirect ' +
        'WinAPI_CreateBuffer WinAPI_CreateBufferFromStruct ' +
        'WinAPI_CreateCaret WinAPI_CreateColorAdjustment ' +
        'WinAPI_CreateCompatibleBitmap WinAPI_CreateCompatibleBitmapEx ' +
        'WinAPI_CreateCompatibleDC WinAPI_CreateDesktop ' +
        'WinAPI_CreateDIB WinAPI_CreateDIBColorTable ' +
        'WinAPI_CreateDIBitmap WinAPI_CreateDIBSection ' +
        'WinAPI_CreateDirectory WinAPI_CreateDirectoryEx ' +
        'WinAPI_CreateEllipticRgn WinAPI_CreateEmptyIcon ' +
        'WinAPI_CreateEnhMetaFile WinAPI_CreateEvent WinAPI_CreateFile ' +
        'WinAPI_CreateFileEx WinAPI_CreateFileMapping ' +
        'WinAPI_CreateFont WinAPI_CreateFontEx ' +
        'WinAPI_CreateFontIndirect WinAPI_CreateGUID ' +
        'WinAPI_CreateHardLink WinAPI_CreateIcon ' +
        'WinAPI_CreateIconFromResourceEx WinAPI_CreateIconIndirect ' +
        'WinAPI_CreateJobObject WinAPI_CreateMargins ' +
        'WinAPI_CreateMRUList WinAPI_CreateMutex WinAPI_CreateNullRgn ' +
        'WinAPI_CreateNumberFormatInfo WinAPI_CreateObjectID ' +
        'WinAPI_CreatePen WinAPI_CreatePoint WinAPI_CreatePolygonRgn ' +
        'WinAPI_CreateProcess WinAPI_CreateProcessWithToken ' +
        'WinAPI_CreateRect WinAPI_CreateRectEx WinAPI_CreateRectRgn ' +
        'WinAPI_CreateRectRgnIndirect WinAPI_CreateRoundRectRgn ' +
        'WinAPI_CreateSemaphore WinAPI_CreateSize ' +
        'WinAPI_CreateSolidBitmap WinAPI_CreateSolidBrush ' +
        'WinAPI_CreateStreamOnHGlobal WinAPI_CreateString ' +
        'WinAPI_CreateSymbolicLink WinAPI_CreateTransform ' +
        'WinAPI_CreateWindowEx WinAPI_CreateWindowStation ' +
        'WinAPI_DecompressBuffer WinAPI_DecryptFile ' +
        'WinAPI_DeferWindowPos WinAPI_DefineDosDevice ' +
        'WinAPI_DefRawInputProc WinAPI_DefSubclassProc ' +
        'WinAPI_DefWindowProc WinAPI_DefWindowProcW WinAPI_DeleteDC ' +
        'WinAPI_DeleteEnhMetaFile WinAPI_DeleteFile ' +
        'WinAPI_DeleteObject WinAPI_DeleteObjectID ' +
        'WinAPI_DeleteVolumeMountPoint WinAPI_DeregisterShellHookWindow ' +
        'WinAPI_DestroyCaret WinAPI_DestroyCursor WinAPI_DestroyIcon ' +
        'WinAPI_DestroyWindow WinAPI_DeviceIoControl ' +
        'WinAPI_DisplayStruct WinAPI_DllGetVersion WinAPI_DllInstall ' +
        'WinAPI_DllUninstall WinAPI_DPtoLP WinAPI_DragAcceptFiles ' +
        'WinAPI_DragFinish WinAPI_DragQueryFileEx ' +
        'WinAPI_DragQueryPoint WinAPI_DrawAnimatedRects ' +
        'WinAPI_DrawBitmap WinAPI_DrawEdge WinAPI_DrawFocusRect ' +
        'WinAPI_DrawFrameControl WinAPI_DrawIcon WinAPI_DrawIconEx ' +
        'WinAPI_DrawLine WinAPI_DrawShadowText WinAPI_DrawText ' +
        'WinAPI_DrawThemeBackground WinAPI_DrawThemeEdge ' +
        'WinAPI_DrawThemeIcon WinAPI_DrawThemeParentBackground ' +
        'WinAPI_DrawThemeText WinAPI_DrawThemeTextEx ' +
        'WinAPI_DuplicateEncryptionInfoFile WinAPI_DuplicateHandle ' +
        'WinAPI_DuplicateTokenEx WinAPI_DwmDefWindowProc ' +
        'WinAPI_DwmEnableBlurBehindWindow WinAPI_DwmEnableComposition ' +
        'WinAPI_DwmExtendFrameIntoClientArea ' +
        'WinAPI_DwmGetColorizationColor ' +
        'WinAPI_DwmGetColorizationParameters ' +
        'WinAPI_DwmGetWindowAttribute WinAPI_DwmInvalidateIconicBitmaps ' +
        'WinAPI_DwmIsCompositionEnabled ' +
        'WinAPI_DwmQueryThumbnailSourceSize WinAPI_DwmRegisterThumbnail ' +
        'WinAPI_DwmSetColorizationParameters ' +
        'WinAPI_DwmSetIconicLivePreviewBitmap ' +
        'WinAPI_DwmSetIconicThumbnail WinAPI_DwmSetWindowAttribute ' +
        'WinAPI_DwmUnregisterThumbnail ' +
        'WinAPI_DwmUpdateThumbnailProperties WinAPI_DWordToFloat ' +
        'WinAPI_DWordToInt WinAPI_EjectMedia WinAPI_Ellipse ' +
        'WinAPI_EmptyWorkingSet WinAPI_EnableWindow WinAPI_EncryptFile ' +
        'WinAPI_EncryptionDisable WinAPI_EndBufferedPaint ' +
        'WinAPI_EndDeferWindowPos WinAPI_EndPaint WinAPI_EndPath ' +
        'WinAPI_EndUpdateResource WinAPI_EnumChildProcess ' +
        'WinAPI_EnumChildWindows WinAPI_EnumDesktops ' +
        'WinAPI_EnumDesktopWindows WinAPI_EnumDeviceDrivers ' +
        'WinAPI_EnumDisplayDevices WinAPI_EnumDisplayMonitors ' +
        'WinAPI_EnumDisplaySettings WinAPI_EnumDllProc ' +
        'WinAPI_EnumFiles WinAPI_EnumFileStreams ' +
        'WinAPI_EnumFontFamilies WinAPI_EnumHardLinks ' +
        'WinAPI_EnumMRUList WinAPI_EnumPageFiles ' +
        'WinAPI_EnumProcessHandles WinAPI_EnumProcessModules ' +
        'WinAPI_EnumProcessThreads WinAPI_EnumProcessWindows ' +
        'WinAPI_EnumRawInputDevices WinAPI_EnumResourceLanguages ' +
        'WinAPI_EnumResourceNames WinAPI_EnumResourceTypes ' +
        'WinAPI_EnumSystemGeoID WinAPI_EnumSystemLocales ' +
        'WinAPI_EnumUILanguages WinAPI_EnumWindows ' +
        'WinAPI_EnumWindowsPopup WinAPI_EnumWindowStations ' +
        'WinAPI_EnumWindowsTop WinAPI_EqualMemory WinAPI_EqualRect ' +
        'WinAPI_EqualRgn WinAPI_ExcludeClipRect ' +
        'WinAPI_ExpandEnvironmentStrings WinAPI_ExtCreatePen ' +
        'WinAPI_ExtCreateRegion WinAPI_ExtFloodFill WinAPI_ExtractIcon ' +
        'WinAPI_ExtractIconEx WinAPI_ExtSelectClipRgn ' +
        'WinAPI_FatalAppExit WinAPI_FatalExit ' +
        'WinAPI_FileEncryptionStatus WinAPI_FileExists ' +
        'WinAPI_FileIconInit WinAPI_FileInUse WinAPI_FillMemory ' +
        'WinAPI_FillPath WinAPI_FillRect WinAPI_FillRgn ' +
        'WinAPI_FindClose WinAPI_FindCloseChangeNotification ' +
        'WinAPI_FindExecutable WinAPI_FindFirstChangeNotification ' +
        'WinAPI_FindFirstFile WinAPI_FindFirstFileName ' +
        'WinAPI_FindFirstStream WinAPI_FindNextChangeNotification ' +
        'WinAPI_FindNextFile WinAPI_FindNextFileName ' +
        'WinAPI_FindNextStream WinAPI_FindResource ' +
        'WinAPI_FindResourceEx WinAPI_FindTextDlg WinAPI_FindWindow ' +
        'WinAPI_FlashWindow WinAPI_FlashWindowEx WinAPI_FlattenPath ' +
        'WinAPI_FloatToDWord WinAPI_FloatToInt WinAPI_FlushFileBuffers ' +
        'WinAPI_FlushFRBuffer WinAPI_FlushViewOfFile ' +
        'WinAPI_FormatDriveDlg WinAPI_FormatMessage WinAPI_FrameRect ' +
        'WinAPI_FrameRgn WinAPI_FreeLibrary WinAPI_FreeMemory ' +
        'WinAPI_FreeMRUList WinAPI_FreeResource WinAPI_GdiComment ' +
        'WinAPI_GetActiveWindow WinAPI_GetAllUsersProfileDirectory ' +
        'WinAPI_GetAncestor WinAPI_GetApplicationRestartSettings ' +
        'WinAPI_GetArcDirection WinAPI_GetAsyncKeyState ' +
        'WinAPI_GetBinaryType WinAPI_GetBitmapBits ' +
        'WinAPI_GetBitmapDimension WinAPI_GetBitmapDimensionEx ' +
        'WinAPI_GetBkColor WinAPI_GetBkMode WinAPI_GetBoundsRect ' +
        'WinAPI_GetBrushOrg WinAPI_GetBufferedPaintBits ' +
        'WinAPI_GetBufferedPaintDC WinAPI_GetBufferedPaintTargetDC ' +
        'WinAPI_GetBufferedPaintTargetRect WinAPI_GetBValue ' +
        'WinAPI_GetCaretBlinkTime WinAPI_GetCaretPos WinAPI_GetCDType ' +
        'WinAPI_GetClassInfoEx WinAPI_GetClassLongEx ' +
        'WinAPI_GetClassName WinAPI_GetClientHeight ' +
        'WinAPI_GetClientRect WinAPI_GetClientWidth ' +
        'WinAPI_GetClipboardSequenceNumber WinAPI_GetClipBox ' +
        'WinAPI_GetClipCursor WinAPI_GetClipRgn ' +
        'WinAPI_GetColorAdjustment WinAPI_GetCompressedFileSize ' +
        'WinAPI_GetCompression WinAPI_GetConnectedDlg ' +
        'WinAPI_GetCurrentDirectory WinAPI_GetCurrentHwProfile ' +
        'WinAPI_GetCurrentObject WinAPI_GetCurrentPosition ' +
        'WinAPI_GetCurrentProcess ' +
        'WinAPI_GetCurrentProcessExplicitAppUserModelID ' +
        'WinAPI_GetCurrentProcessID WinAPI_GetCurrentThemeName ' +
        'WinAPI_GetCurrentThread WinAPI_GetCurrentThreadId ' +
        'WinAPI_GetCursor WinAPI_GetCursorInfo WinAPI_GetDateFormat ' +
        'WinAPI_GetDC WinAPI_GetDCEx WinAPI_GetDefaultPrinter ' +
        'WinAPI_GetDefaultUserProfileDirectory WinAPI_GetDesktopWindow ' +
        'WinAPI_GetDeviceCaps WinAPI_GetDeviceDriverBaseName ' +
        'WinAPI_GetDeviceDriverFileName WinAPI_GetDeviceGammaRamp ' +
        'WinAPI_GetDIBColorTable WinAPI_GetDIBits ' +
        'WinAPI_GetDiskFreeSpaceEx WinAPI_GetDlgCtrlID ' +
        'WinAPI_GetDlgItem WinAPI_GetDllDirectory ' +
        'WinAPI_GetDriveBusType WinAPI_GetDriveGeometryEx ' +
        'WinAPI_GetDriveNumber WinAPI_GetDriveType ' +
        'WinAPI_GetDurationFormat WinAPI_GetEffectiveClientRect ' +
        'WinAPI_GetEnhMetaFile WinAPI_GetEnhMetaFileBits ' +
        'WinAPI_GetEnhMetaFileDescription WinAPI_GetEnhMetaFileDimension ' +
        'WinAPI_GetEnhMetaFileHeader WinAPI_GetErrorMessage ' +
        'WinAPI_GetErrorMode WinAPI_GetExitCodeProcess ' +
        'WinAPI_GetExtended WinAPI_GetFileAttributes WinAPI_GetFileID ' +
        'WinAPI_GetFileInformationByHandle ' +
        'WinAPI_GetFileInformationByHandleEx WinAPI_GetFilePointerEx ' +
        'WinAPI_GetFileSizeEx WinAPI_GetFileSizeOnDisk ' +
        'WinAPI_GetFileTitle WinAPI_GetFileType ' +
        'WinAPI_GetFileVersionInfo WinAPI_GetFinalPathNameByHandle ' +
        'WinAPI_GetFinalPathNameByHandleEx WinAPI_GetFocus ' +
        'WinAPI_GetFontMemoryResourceInfo WinAPI_GetFontName ' +
        'WinAPI_GetFontResourceInfo WinAPI_GetForegroundWindow ' +
        'WinAPI_GetFRBuffer WinAPI_GetFullPathName WinAPI_GetGeoInfo ' +
        'WinAPI_GetGlyphOutline WinAPI_GetGraphicsMode ' +
        'WinAPI_GetGuiResources WinAPI_GetGUIThreadInfo ' +
        'WinAPI_GetGValue WinAPI_GetHandleInformation ' +
        'WinAPI_GetHGlobalFromStream WinAPI_GetIconDimension ' +
        'WinAPI_GetIconInfo WinAPI_GetIconInfoEx WinAPI_GetIdleTime ' +
        'WinAPI_GetKeyboardLayout WinAPI_GetKeyboardLayoutList ' +
        'WinAPI_GetKeyboardState WinAPI_GetKeyboardType ' +
        'WinAPI_GetKeyNameText WinAPI_GetKeyState ' +
        'WinAPI_GetLastActivePopup WinAPI_GetLastError ' +
        'WinAPI_GetLastErrorMessage WinAPI_GetLayeredWindowAttributes ' +
        'WinAPI_GetLocaleInfo WinAPI_GetLogicalDrives ' +
        'WinAPI_GetMapMode WinAPI_GetMemorySize ' +
        'WinAPI_GetMessageExtraInfo WinAPI_GetModuleFileNameEx ' +
        'WinAPI_GetModuleHandle WinAPI_GetModuleHandleEx ' +
        'WinAPI_GetModuleInformation WinAPI_GetMonitorInfo ' +
        'WinAPI_GetMousePos WinAPI_GetMousePosX WinAPI_GetMousePosY ' +
        'WinAPI_GetMUILanguage WinAPI_GetNumberFormat WinAPI_GetObject ' +
        'WinAPI_GetObjectID WinAPI_GetObjectInfoByHandle ' +
        'WinAPI_GetObjectNameByHandle WinAPI_GetObjectType ' +
        'WinAPI_GetOpenFileName WinAPI_GetOutlineTextMetrics ' +
        'WinAPI_GetOverlappedResult WinAPI_GetParent ' +
        'WinAPI_GetParentProcess WinAPI_GetPerformanceInfo ' +
        'WinAPI_GetPEType WinAPI_GetPhysicallyInstalledSystemMemory ' +
        'WinAPI_GetPixel WinAPI_GetPolyFillMode WinAPI_GetPosFromRect ' +
        'WinAPI_GetPriorityClass WinAPI_GetProcAddress ' +
        'WinAPI_GetProcessAffinityMask WinAPI_GetProcessCommandLine ' +
        'WinAPI_GetProcessFileName WinAPI_GetProcessHandleCount ' +
        'WinAPI_GetProcessID WinAPI_GetProcessIoCounters ' +
        'WinAPI_GetProcessMemoryInfo WinAPI_GetProcessName ' +
        'WinAPI_GetProcessShutdownParameters WinAPI_GetProcessTimes ' +
        'WinAPI_GetProcessUser WinAPI_GetProcessWindowStation ' +
        'WinAPI_GetProcessWorkingDirectory WinAPI_GetProfilesDirectory ' +
        'WinAPI_GetPwrCapabilities WinAPI_GetRawInputBuffer ' +
        'WinAPI_GetRawInputBufferLength WinAPI_GetRawInputData ' +
        'WinAPI_GetRawInputDeviceInfo WinAPI_GetRegionData ' +
        'WinAPI_GetRegisteredRawInputDevices ' +
        'WinAPI_GetRegKeyNameByHandle WinAPI_GetRgnBox WinAPI_GetROP2 ' +
        'WinAPI_GetRValue WinAPI_GetSaveFileName WinAPI_GetShellWindow ' +
        'WinAPI_GetStartupInfo WinAPI_GetStdHandle ' +
        'WinAPI_GetStockObject WinAPI_GetStretchBltMode ' +
        'WinAPI_GetString WinAPI_GetSysColor WinAPI_GetSysColorBrush ' +
        'WinAPI_GetSystemDefaultLangID WinAPI_GetSystemDefaultLCID ' +
        'WinAPI_GetSystemDefaultUILanguage WinAPI_GetSystemDEPPolicy ' +
        'WinAPI_GetSystemInfo WinAPI_GetSystemMetrics ' +
        'WinAPI_GetSystemPowerStatus WinAPI_GetSystemTimes ' +
        'WinAPI_GetSystemWow64Directory WinAPI_GetTabbedTextExtent ' +
        'WinAPI_GetTempFileName WinAPI_GetTextAlign ' +
        'WinAPI_GetTextCharacterExtra WinAPI_GetTextColor ' +
        'WinAPI_GetTextExtentPoint32 WinAPI_GetTextFace ' +
        'WinAPI_GetTextMetrics WinAPI_GetThemeAppProperties ' +
        'WinAPI_GetThemeBackgroundContentRect ' +
        'WinAPI_GetThemeBackgroundExtent WinAPI_GetThemeBackgroundRegion ' +
        'WinAPI_GetThemeBitmap WinAPI_GetThemeBool ' +
        'WinAPI_GetThemeColor WinAPI_GetThemeDocumentationProperty ' +
        'WinAPI_GetThemeEnumValue WinAPI_GetThemeFilename ' +
        'WinAPI_GetThemeFont WinAPI_GetThemeInt WinAPI_GetThemeMargins ' +
        'WinAPI_GetThemeMetric WinAPI_GetThemePartSize ' +
        'WinAPI_GetThemePosition WinAPI_GetThemePropertyOrigin ' +
        'WinAPI_GetThemeRect WinAPI_GetThemeString ' +
        'WinAPI_GetThemeSysBool WinAPI_GetThemeSysColor ' +
        'WinAPI_GetThemeSysColorBrush WinAPI_GetThemeSysFont ' +
        'WinAPI_GetThemeSysInt WinAPI_GetThemeSysSize ' +
        'WinAPI_GetThemeSysString WinAPI_GetThemeTextExtent ' +
        'WinAPI_GetThemeTextMetrics WinAPI_GetThemeTransitionDuration ' +
        'WinAPI_GetThreadDesktop WinAPI_GetThreadErrorMode ' +
        'WinAPI_GetThreadLocale WinAPI_GetThreadUILanguage ' +
        'WinAPI_GetTickCount WinAPI_GetTickCount64 ' +
        'WinAPI_GetTimeFormat WinAPI_GetTopWindow ' +
        'WinAPI_GetUDFColorMode WinAPI_GetUpdateRect ' +
        'WinAPI_GetUpdateRgn WinAPI_GetUserDefaultLangID ' +
        'WinAPI_GetUserDefaultLCID WinAPI_GetUserDefaultUILanguage ' +
        'WinAPI_GetUserGeoID WinAPI_GetUserObjectInformation ' +
        'WinAPI_GetVersion WinAPI_GetVersionEx ' +
        'WinAPI_GetVolumeInformation WinAPI_GetVolumeInformationByHandle ' +
        'WinAPI_GetVolumeNameForVolumeMountPoint WinAPI_GetWindow ' +
        'WinAPI_GetWindowDC WinAPI_GetWindowDisplayAffinity ' +
        'WinAPI_GetWindowExt WinAPI_GetWindowFileName ' +
        'WinAPI_GetWindowHeight WinAPI_GetWindowInfo ' +
        'WinAPI_GetWindowLong WinAPI_GetWindowOrg ' +
        'WinAPI_GetWindowPlacement WinAPI_GetWindowRect ' +
        'WinAPI_GetWindowRgn WinAPI_GetWindowRgnBox ' +
        'WinAPI_GetWindowSubclass WinAPI_GetWindowText ' +
        'WinAPI_GetWindowTheme WinAPI_GetWindowThreadProcessId ' +
        'WinAPI_GetWindowWidth WinAPI_GetWorkArea ' +
        'WinAPI_GetWorldTransform WinAPI_GetXYFromPoint ' +
        'WinAPI_GlobalMemoryStatus WinAPI_GradientFill ' +
        'WinAPI_GUIDFromString WinAPI_GUIDFromStringEx WinAPI_HashData ' +
        'WinAPI_HashString WinAPI_HiByte WinAPI_HideCaret ' +
        'WinAPI_HiDWord WinAPI_HiWord WinAPI_InflateRect ' +
        'WinAPI_InitMUILanguage WinAPI_InProcess ' +
        'WinAPI_IntersectClipRect WinAPI_IntersectRect ' +
        'WinAPI_IntToDWord WinAPI_IntToFloat WinAPI_InvalidateRect ' +
        'WinAPI_InvalidateRgn WinAPI_InvertANDBitmap ' +
        'WinAPI_InvertColor WinAPI_InvertRect WinAPI_InvertRgn ' +
        'WinAPI_IOCTL WinAPI_IsAlphaBitmap WinAPI_IsBadCodePtr ' +
        'WinAPI_IsBadReadPtr WinAPI_IsBadStringPtr ' +
        'WinAPI_IsBadWritePtr WinAPI_IsChild WinAPI_IsClassName ' +
        'WinAPI_IsDoorOpen WinAPI_IsElevated WinAPI_IsHungAppWindow ' +
        'WinAPI_IsIconic WinAPI_IsInternetConnected ' +
        'WinAPI_IsLoadKBLayout WinAPI_IsMemory ' +
        'WinAPI_IsNameInExpression WinAPI_IsNetworkAlive ' +
        'WinAPI_IsPathShared WinAPI_IsProcessInJob ' +
        'WinAPI_IsProcessorFeaturePresent WinAPI_IsRectEmpty ' +
        'WinAPI_IsThemeActive ' +
        'WinAPI_IsThemeBackgroundPartiallyTransparent ' +
        'WinAPI_IsThemePartDefined WinAPI_IsValidLocale ' +
        'WinAPI_IsWindow WinAPI_IsWindowEnabled WinAPI_IsWindowUnicode ' +
        'WinAPI_IsWindowVisible WinAPI_IsWow64Process ' +
        'WinAPI_IsWritable WinAPI_IsZoomed WinAPI_Keybd_Event ' +
        'WinAPI_KillTimer WinAPI_LineDDA WinAPI_LineTo ' +
        'WinAPI_LoadBitmap WinAPI_LoadCursor WinAPI_LoadCursorFromFile ' +
        'WinAPI_LoadIcon WinAPI_LoadIconMetric ' +
        'WinAPI_LoadIconWithScaleDown WinAPI_LoadImage ' +
        'WinAPI_LoadIndirectString WinAPI_LoadKeyboardLayout ' +
        'WinAPI_LoadLibrary WinAPI_LoadLibraryEx WinAPI_LoadMedia ' +
        'WinAPI_LoadResource WinAPI_LoadShell32Icon WinAPI_LoadString ' +
        'WinAPI_LoadStringEx WinAPI_LoByte WinAPI_LocalFree ' +
        'WinAPI_LockDevice WinAPI_LockFile WinAPI_LockResource ' +
        'WinAPI_LockWindowUpdate WinAPI_LockWorkStation WinAPI_LoDWord ' +
        'WinAPI_LongMid WinAPI_LookupIconIdFromDirectoryEx ' +
        'WinAPI_LoWord WinAPI_LPtoDP WinAPI_MAKELANGID ' +
        'WinAPI_MAKELCID WinAPI_MakeLong WinAPI_MakeQWord ' +
        'WinAPI_MakeWord WinAPI_MapViewOfFile WinAPI_MapVirtualKey ' +
        'WinAPI_MaskBlt WinAPI_MessageBeep WinAPI_MessageBoxCheck ' +
        'WinAPI_MessageBoxIndirect WinAPI_MirrorIcon ' +
        'WinAPI_ModifyWorldTransform WinAPI_MonitorFromPoint ' +
        'WinAPI_MonitorFromRect WinAPI_MonitorFromWindow ' +
        'WinAPI_Mouse_Event WinAPI_MoveFileEx WinAPI_MoveMemory ' +
        'WinAPI_MoveTo WinAPI_MoveToEx WinAPI_MoveWindow ' +
        'WinAPI_MsgBox WinAPI_MulDiv WinAPI_MultiByteToWideChar ' +
        'WinAPI_MultiByteToWideCharEx WinAPI_NtStatusToDosError ' +
        'WinAPI_OemToChar WinAPI_OffsetClipRgn WinAPI_OffsetPoints ' +
        'WinAPI_OffsetRect WinAPI_OffsetRgn WinAPI_OffsetWindowOrg ' +
        'WinAPI_OpenDesktop WinAPI_OpenFileById WinAPI_OpenFileDlg ' +
        'WinAPI_OpenFileMapping WinAPI_OpenIcon ' +
        'WinAPI_OpenInputDesktop WinAPI_OpenJobObject WinAPI_OpenMutex ' +
        'WinAPI_OpenProcess WinAPI_OpenProcessToken ' +
        'WinAPI_OpenSemaphore WinAPI_OpenThemeData ' +
        'WinAPI_OpenWindowStation WinAPI_PageSetupDlg ' +
        'WinAPI_PaintDesktop WinAPI_PaintRgn WinAPI_ParseURL ' +
        'WinAPI_ParseUserName WinAPI_PatBlt WinAPI_PathAddBackslash ' +
        'WinAPI_PathAddExtension WinAPI_PathAppend ' +
        'WinAPI_PathBuildRoot WinAPI_PathCanonicalize ' +
        'WinAPI_PathCommonPrefix WinAPI_PathCompactPath ' +
        'WinAPI_PathCompactPathEx WinAPI_PathCreateFromUrl ' +
        'WinAPI_PathFindExtension WinAPI_PathFindFileName ' +
        'WinAPI_PathFindNextComponent WinAPI_PathFindOnPath ' +
        'WinAPI_PathGetArgs WinAPI_PathGetCharType ' +
        'WinAPI_PathGetDriveNumber WinAPI_PathIsContentType ' +
        'WinAPI_PathIsDirectory WinAPI_PathIsDirectoryEmpty ' +
        'WinAPI_PathIsExe WinAPI_PathIsFileSpec ' +
        'WinAPI_PathIsLFNFileSpec WinAPI_PathIsRelative ' +
        'WinAPI_PathIsRoot WinAPI_PathIsSameRoot ' +
        'WinAPI_PathIsSystemFolder WinAPI_PathIsUNC ' +
        'WinAPI_PathIsUNCServer WinAPI_PathIsUNCServerShare ' +
        'WinAPI_PathMakeSystemFolder WinAPI_PathMatchSpec ' +
        'WinAPI_PathParseIconLocation WinAPI_PathRelativePathTo ' +
        'WinAPI_PathRemoveArgs WinAPI_PathRemoveBackslash ' +
        'WinAPI_PathRemoveExtension WinAPI_PathRemoveFileSpec ' +
        'WinAPI_PathRenameExtension WinAPI_PathSearchAndQualify ' +
        'WinAPI_PathSkipRoot WinAPI_PathStripPath ' +
        'WinAPI_PathStripToRoot WinAPI_PathToRegion ' +
        'WinAPI_PathUndecorate WinAPI_PathUnExpandEnvStrings ' +
        'WinAPI_PathUnmakeSystemFolder WinAPI_PathUnquoteSpaces ' +
        'WinAPI_PathYetAnotherMakeUniqueName WinAPI_PickIconDlg ' +
        'WinAPI_PlayEnhMetaFile WinAPI_PlaySound WinAPI_PlgBlt ' +
        'WinAPI_PointFromRect WinAPI_PolyBezier WinAPI_PolyBezierTo ' +
        'WinAPI_PolyDraw WinAPI_Polygon WinAPI_PostMessage ' +
        'WinAPI_PrimaryLangId WinAPI_PrintDlg WinAPI_PrintDlgEx ' +
        'WinAPI_PrintWindow WinAPI_ProgIDFromCLSID WinAPI_PtInRect ' +
        'WinAPI_PtInRectEx WinAPI_PtInRegion WinAPI_PtVisible ' +
        'WinAPI_QueryDosDevice WinAPI_QueryInformationJobObject ' +
        'WinAPI_QueryPerformanceCounter WinAPI_QueryPerformanceFrequency ' +
        'WinAPI_RadialGradientFill WinAPI_ReadDirectoryChanges ' +
        'WinAPI_ReadFile WinAPI_ReadProcessMemory WinAPI_Rectangle ' +
        'WinAPI_RectInRegion WinAPI_RectIsEmpty WinAPI_RectVisible ' +
        'WinAPI_RedrawWindow WinAPI_RegCloseKey ' +
        'WinAPI_RegConnectRegistry WinAPI_RegCopyTree ' +
        'WinAPI_RegCopyTreeEx WinAPI_RegCreateKey ' +
        'WinAPI_RegDeleteEmptyKey WinAPI_RegDeleteKey ' +
        'WinAPI_RegDeleteKeyValue WinAPI_RegDeleteTree ' +
        'WinAPI_RegDeleteTreeEx WinAPI_RegDeleteValue ' +
        'WinAPI_RegDisableReflectionKey WinAPI_RegDuplicateHKey ' +
        'WinAPI_RegEnableReflectionKey WinAPI_RegEnumKey ' +
        'WinAPI_RegEnumValue WinAPI_RegFlushKey ' +
        'WinAPI_RegisterApplicationRestart WinAPI_RegisterClass ' +
        'WinAPI_RegisterClassEx WinAPI_RegisterHotKey ' +
        'WinAPI_RegisterPowerSettingNotification ' +
        'WinAPI_RegisterRawInputDevices WinAPI_RegisterShellHookWindow ' +
        'WinAPI_RegisterWindowMessage WinAPI_RegLoadMUIString ' +
        'WinAPI_RegNotifyChangeKeyValue WinAPI_RegOpenKey ' +
        'WinAPI_RegQueryInfoKey WinAPI_RegQueryLastWriteTime ' +
        'WinAPI_RegQueryMultipleValues WinAPI_RegQueryReflectionKey ' +
        'WinAPI_RegQueryValue WinAPI_RegRestoreKey WinAPI_RegSaveKey ' +
        'WinAPI_RegSetValue WinAPI_ReleaseCapture WinAPI_ReleaseDC ' +
        'WinAPI_ReleaseMutex WinAPI_ReleaseSemaphore ' +
        'WinAPI_ReleaseStream WinAPI_RemoveClipboardFormatListener ' +
        'WinAPI_RemoveDirectory WinAPI_RemoveFontMemResourceEx ' +
        'WinAPI_RemoveFontResourceEx WinAPI_RemoveWindowSubclass ' +
        'WinAPI_ReOpenFile WinAPI_ReplaceFile WinAPI_ReplaceTextDlg ' +
        'WinAPI_ResetEvent WinAPI_RestartDlg WinAPI_RestoreDC ' +
        'WinAPI_RGB WinAPI_RotatePoints WinAPI_RoundRect ' +
        'WinAPI_SaveDC WinAPI_SaveFileDlg WinAPI_SaveHBITMAPToFile ' +
        'WinAPI_SaveHICONToFile WinAPI_ScaleWindowExt ' +
        'WinAPI_ScreenToClient WinAPI_SearchPath WinAPI_SelectClipPath ' +
        'WinAPI_SelectClipRgn WinAPI_SelectObject ' +
        'WinAPI_SendMessageTimeout WinAPI_SetActiveWindow ' +
        'WinAPI_SetArcDirection WinAPI_SetBitmapBits ' +
        'WinAPI_SetBitmapDimensionEx WinAPI_SetBkColor ' +
        'WinAPI_SetBkMode WinAPI_SetBoundsRect WinAPI_SetBrushOrg ' +
        'WinAPI_SetCapture WinAPI_SetCaretBlinkTime WinAPI_SetCaretPos ' +
        'WinAPI_SetClassLongEx WinAPI_SetColorAdjustment ' +
        'WinAPI_SetCompression WinAPI_SetCurrentDirectory ' +
        'WinAPI_SetCurrentProcessExplicitAppUserModelID WinAPI_SetCursor ' +
        'WinAPI_SetDCBrushColor WinAPI_SetDCPenColor ' +
        'WinAPI_SetDefaultPrinter WinAPI_SetDeviceGammaRamp ' +
        'WinAPI_SetDIBColorTable WinAPI_SetDIBits ' +
        'WinAPI_SetDIBitsToDevice WinAPI_SetDllDirectory ' +
        'WinAPI_SetEndOfFile WinAPI_SetEnhMetaFileBits ' +
        'WinAPI_SetErrorMode WinAPI_SetEvent WinAPI_SetFileAttributes ' +
        'WinAPI_SetFileInformationByHandleEx WinAPI_SetFilePointer ' +
        'WinAPI_SetFilePointerEx WinAPI_SetFileShortName ' +
        'WinAPI_SetFileValidData WinAPI_SetFocus WinAPI_SetFont ' +
        'WinAPI_SetForegroundWindow WinAPI_SetFRBuffer ' +
        'WinAPI_SetGraphicsMode WinAPI_SetHandleInformation ' +
        'WinAPI_SetInformationJobObject WinAPI_SetKeyboardLayout ' +
        'WinAPI_SetKeyboardState WinAPI_SetLastError ' +
        'WinAPI_SetLayeredWindowAttributes WinAPI_SetLocaleInfo ' +
        'WinAPI_SetMapMode WinAPI_SetMessageExtraInfo WinAPI_SetParent ' +
        'WinAPI_SetPixel WinAPI_SetPolyFillMode ' +
        'WinAPI_SetPriorityClass WinAPI_SetProcessAffinityMask ' +
        'WinAPI_SetProcessShutdownParameters ' +
        'WinAPI_SetProcessWindowStation WinAPI_SetRectRgn ' +
        'WinAPI_SetROP2 WinAPI_SetSearchPathMode ' +
        'WinAPI_SetStretchBltMode WinAPI_SetSysColors ' +
        'WinAPI_SetSystemCursor WinAPI_SetTextAlign ' +
        'WinAPI_SetTextCharacterExtra WinAPI_SetTextColor ' +
        'WinAPI_SetTextJustification WinAPI_SetThemeAppProperties ' +
        'WinAPI_SetThreadDesktop WinAPI_SetThreadErrorMode ' +
        'WinAPI_SetThreadExecutionState WinAPI_SetThreadLocale ' +
        'WinAPI_SetThreadUILanguage WinAPI_SetTimer ' +
        'WinAPI_SetUDFColorMode WinAPI_SetUserGeoID ' +
        'WinAPI_SetUserObjectInformation WinAPI_SetVolumeMountPoint ' +
        'WinAPI_SetWindowDisplayAffinity WinAPI_SetWindowExt ' +
        'WinAPI_SetWindowLong WinAPI_SetWindowOrg ' +
        'WinAPI_SetWindowPlacement WinAPI_SetWindowPos ' +
        'WinAPI_SetWindowRgn WinAPI_SetWindowsHookEx ' +
        'WinAPI_SetWindowSubclass WinAPI_SetWindowText ' +
        'WinAPI_SetWindowTheme WinAPI_SetWinEventHook ' +
        'WinAPI_SetWorldTransform WinAPI_SfcIsFileProtected ' +
        'WinAPI_SfcIsKeyProtected WinAPI_ShellAboutDlg ' +
        'WinAPI_ShellAddToRecentDocs WinAPI_ShellChangeNotify ' +
        'WinAPI_ShellChangeNotifyDeregister ' +
        'WinAPI_ShellChangeNotifyRegister WinAPI_ShellCreateDirectory ' +
        'WinAPI_ShellEmptyRecycleBin WinAPI_ShellExecute ' +
        'WinAPI_ShellExecuteEx WinAPI_ShellExtractAssociatedIcon ' +
        'WinAPI_ShellExtractIcon WinAPI_ShellFileOperation ' +
        'WinAPI_ShellFlushSFCache WinAPI_ShellGetFileInfo ' +
        'WinAPI_ShellGetIconOverlayIndex WinAPI_ShellGetImageList ' +
        'WinAPI_ShellGetKnownFolderIDList WinAPI_ShellGetKnownFolderPath ' +
        'WinAPI_ShellGetLocalizedName WinAPI_ShellGetPathFromIDList ' +
        'WinAPI_ShellGetSetFolderCustomSettings WinAPI_ShellGetSettings ' +
        'WinAPI_ShellGetSpecialFolderLocation ' +
        'WinAPI_ShellGetSpecialFolderPath WinAPI_ShellGetStockIconInfo ' +
        'WinAPI_ShellILCreateFromPath WinAPI_ShellNotifyIcon ' +
        'WinAPI_ShellNotifyIconGetRect WinAPI_ShellObjectProperties ' +
        'WinAPI_ShellOpenFolderAndSelectItems WinAPI_ShellOpenWithDlg ' +
        'WinAPI_ShellQueryRecycleBin ' +
        'WinAPI_ShellQueryUserNotificationState ' +
        'WinAPI_ShellRemoveLocalizedName WinAPI_ShellRestricted ' +
        'WinAPI_ShellSetKnownFolderPath WinAPI_ShellSetLocalizedName ' +
        'WinAPI_ShellSetSettings WinAPI_ShellStartNetConnectionDlg ' +
        'WinAPI_ShellUpdateImage WinAPI_ShellUserAuthenticationDlg ' +
        'WinAPI_ShellUserAuthenticationDlgEx WinAPI_ShortToWord ' +
        'WinAPI_ShowCaret WinAPI_ShowCursor WinAPI_ShowError ' +
        'WinAPI_ShowLastError WinAPI_ShowMsg WinAPI_ShowOwnedPopups ' +
        'WinAPI_ShowWindow WinAPI_ShutdownBlockReasonCreate ' +
        'WinAPI_ShutdownBlockReasonDestroy ' +
        'WinAPI_ShutdownBlockReasonQuery WinAPI_SizeOfResource ' +
        'WinAPI_StretchBlt WinAPI_StretchDIBits ' +
        'WinAPI_StrFormatByteSize WinAPI_StrFormatByteSizeEx ' +
        'WinAPI_StrFormatKBSize WinAPI_StrFromTimeInterval ' +
        'WinAPI_StringFromGUID WinAPI_StringLenA WinAPI_StringLenW ' +
        'WinAPI_StrLen WinAPI_StrokeAndFillPath WinAPI_StrokePath ' +
        'WinAPI_StructToArray WinAPI_SubLangId WinAPI_SubtractRect ' +
        'WinAPI_SwapDWord WinAPI_SwapQWord WinAPI_SwapWord ' +
        'WinAPI_SwitchColor WinAPI_SwitchDesktop ' +
        'WinAPI_SwitchToThisWindow WinAPI_SystemParametersInfo ' +
        'WinAPI_TabbedTextOut WinAPI_TerminateJobObject ' +
        'WinAPI_TerminateProcess WinAPI_TextOut WinAPI_TileWindows ' +
        'WinAPI_TrackMouseEvent WinAPI_TransparentBlt ' +
        'WinAPI_TwipsPerPixelX WinAPI_TwipsPerPixelY ' +
        'WinAPI_UnhookWindowsHookEx WinAPI_UnhookWinEvent ' +
        'WinAPI_UnionRect WinAPI_UnionStruct WinAPI_UniqueHardwareID ' +
        'WinAPI_UnloadKeyboardLayout WinAPI_UnlockFile ' +
        'WinAPI_UnmapViewOfFile WinAPI_UnregisterApplicationRestart ' +
        'WinAPI_UnregisterClass WinAPI_UnregisterHotKey ' +
        'WinAPI_UnregisterPowerSettingNotification ' +
        'WinAPI_UpdateLayeredWindow WinAPI_UpdateLayeredWindowEx ' +
        'WinAPI_UpdateLayeredWindowIndirect WinAPI_UpdateResource ' +
        'WinAPI_UpdateWindow WinAPI_UrlApplyScheme ' +
        'WinAPI_UrlCanonicalize WinAPI_UrlCombine WinAPI_UrlCompare ' +
        'WinAPI_UrlCreateFromPath WinAPI_UrlFixup WinAPI_UrlGetPart ' +
        'WinAPI_UrlHash WinAPI_UrlIs WinAPI_UserHandleGrantAccess ' +
        'WinAPI_ValidateRect WinAPI_ValidateRgn WinAPI_VerQueryRoot ' +
        'WinAPI_VerQueryValue WinAPI_VerQueryValueEx ' +
        'WinAPI_WaitForInputIdle WinAPI_WaitForMultipleObjects ' +
        'WinAPI_WaitForSingleObject WinAPI_WideCharToMultiByte ' +
        'WinAPI_WidenPath WinAPI_WindowFromDC WinAPI_WindowFromPoint ' +
        'WinAPI_WordToShort WinAPI_Wow64EnableWow64FsRedirection ' +
        'WinAPI_WriteConsole WinAPI_WriteFile ' +
        'WinAPI_WriteProcessMemory WinAPI_ZeroMemory ' +
        'WinNet_AddConnection WinNet_AddConnection2 ' +
        'WinNet_AddConnection3 WinNet_CancelConnection ' +
        'WinNet_CancelConnection2 WinNet_CloseEnum ' +
        'WinNet_ConnectionDialog WinNet_ConnectionDialog1 ' +
        'WinNet_DisconnectDialog WinNet_DisconnectDialog1 ' +
        'WinNet_EnumResource WinNet_GetConnection ' +
        'WinNet_GetConnectionPerformance WinNet_GetLastError ' +
        'WinNet_GetNetworkInformation WinNet_GetProviderName ' +
        'WinNet_GetResourceInformation WinNet_GetResourceParent ' +
        'WinNet_GetUniversalName WinNet_GetUser WinNet_OpenEnum ' +
        'WinNet_RestoreConnection WinNet_UseConnection Word_Create ' +
        'Word_DocAdd Word_DocAttach Word_DocClose Word_DocExport ' +
        'Word_DocFind Word_DocFindReplace Word_DocGet ' +
        'Word_DocLinkAdd Word_DocLinkGet Word_DocOpen ' +
        'Word_DocPictureAdd Word_DocPrint Word_DocRangeSet ' +
        'Word_DocSave Word_DocSaveAs Word_DocTableRead ' +
        'Word_DocTableWrite Word_Quit',

        COMMENT = {
            variants: [
              hljs.COMMENT(';', '$', {relevance: 0}),
              hljs.COMMENT('#cs', '#ce'),
              hljs.COMMENT('#comments-start', '#comments-end')
            ]
        },

        VARIABLE = {
            className: 'variable',
            begin: '\\$[A-z0-9_]+'
        },

        STRING = {
            className: 'string',
            variants: [{
                begin: /"/,
                end: /"/,
                contains: [{
                    begin: /""/,
                    relevance: 0
                }]
            }, {
                begin: /'/,
                end: /'/,
                contains: [{
                    begin: /''/,
                    relevance: 0
                }]
            }]
        },

        NUMBER = {
            variants: [hljs.BINARY_NUMBER_MODE, hljs.C_NUMBER_MODE]
        },

        PREPROCESSOR = {
            className: 'preprocessor',
            begin: '#',
            end: '$',
            keywords: 'include include-once NoTrayIcon OnAutoItStartRegister RequireAdmin pragma ' +
                'Au3Stripper_Ignore_Funcs Au3Stripper_Ignore_Variables ' +
                'Au3Stripper_Off Au3Stripper_On Au3Stripper_Parameters ' +
                'AutoIt3Wrapper_Add_Constants AutoIt3Wrapper_Au3Check_Parameters ' +
                'AutoIt3Wrapper_Au3Check_Stop_OnWarning AutoIt3Wrapper_Aut2Exe ' +
                'AutoIt3Wrapper_AutoIt3 AutoIt3Wrapper_AutoIt3Dir ' +
                'AutoIt3Wrapper_Change2CUI AutoIt3Wrapper_Compile_Both ' +
                'AutoIt3Wrapper_Compression AutoIt3Wrapper_EndIf ' +
                'AutoIt3Wrapper_Icon AutoIt3Wrapper_If_Compile ' +
                'AutoIt3Wrapper_If_Run AutoIt3Wrapper_Jump_To_First_Error ' +
                'AutoIt3Wrapper_OutFile AutoIt3Wrapper_OutFile_Type ' +
                'AutoIt3Wrapper_OutFile_X64 AutoIt3Wrapper_PlugIn_Funcs ' +
                'AutoIt3Wrapper_Res_Comment Autoit3Wrapper_Res_Compatibility ' +
                'AutoIt3Wrapper_Res_Description AutoIt3Wrapper_Res_Field ' +
                'AutoIt3Wrapper_Res_File_Add AutoIt3Wrapper_Res_FileVersion ' +
                'AutoIt3Wrapper_Res_FileVersion_AutoIncrement ' +
                'AutoIt3Wrapper_Res_Icon_Add AutoIt3Wrapper_Res_Language ' +
                'AutoIt3Wrapper_Res_LegalCopyright ' +
                'AutoIt3Wrapper_Res_ProductVersion ' +
                'AutoIt3Wrapper_Res_requestedExecutionLevel ' +
                'AutoIt3Wrapper_Res_SaveSource AutoIt3Wrapper_Run_After ' +
                'AutoIt3Wrapper_Run_Au3Check AutoIt3Wrapper_Run_Au3Stripper ' +
                'AutoIt3Wrapper_Run_Before AutoIt3Wrapper_Run_Debug_Mode ' +
                'AutoIt3Wrapper_Run_SciTE_Minimized ' +
                'AutoIt3Wrapper_Run_SciTE_OutputPane_Minimized ' +
                'AutoIt3Wrapper_Run_Tidy AutoIt3Wrapper_ShowProgress ' +
                'AutoIt3Wrapper_Testing AutoIt3Wrapper_Tidy_Stop_OnError ' +
                'AutoIt3Wrapper_UPX_Parameters AutoIt3Wrapper_UseUPX ' +
                'AutoIt3Wrapper_UseX64 AutoIt3Wrapper_Version ' +
                'AutoIt3Wrapper_Versioning AutoIt3Wrapper_Versioning_Parameters ' +
                'Tidy_Off Tidy_On Tidy_Parameters EndRegion Region',
            contains: [{
                    begin: /\\\n/,
                    relevance: 0
                }, {
                    beginKeywords: 'include',
                    end: '$',
                    contains: [
                        STRING, {
                            className: 'string',
                            variants: [{
                                begin: '<',
                                end: '>'
                            }, {
                                begin: /"/,
                                end: /"/,
                                contains: [{
                                    begin: /""/,
                                    relevance: 0
                                }]
                            }, {
                                begin: /'/,
                                end: /'/,
                                contains: [{
                                    begin: /''/,
                                    relevance: 0
                                }]
                            }]
                        }
                    ]
                },
                STRING,
                COMMENT
            ]
        },

        CONSTANT = {
            className: 'constant',
            // begin: '@',
            // end: '$',
            // keywords: 'AppDataCommonDir AppDataDir AutoItExe AutoItPID AutoItVersion AutoItX64 COM_EventObj CommonFilesDir Compiled ComputerName ComSpec CPUArch CR CRLF DesktopCommonDir DesktopDepth DesktopDir DesktopHeight DesktopRefresh DesktopWidth DocumentsCommonDir error exitCode exitMethod extended FavoritesCommonDir FavoritesDir GUI_CtrlHandle GUI_CtrlId GUI_DragFile GUI_DragId GUI_DropId GUI_WinHandle HomeDrive HomePath HomeShare HotKeyPressed HOUR IPAddress1 IPAddress2 IPAddress3 IPAddress4 KBLayout LF LocalAppDataDir LogonDNSDomain LogonDomain LogonServer MDAY MIN MON MSEC MUILang MyDocumentsDir NumParams OSArch OSBuild OSLang OSServicePack OSType OSVersion ProgramFilesDir ProgramsCommonDir ProgramsDir ScriptDir ScriptFullPath ScriptLineNumber ScriptName SEC StartMenuCommonDir StartMenuDir StartupCommonDir StartupDir SW_DISABLE SW_ENABLE SW_HIDE SW_LOCK SW_MAXIMIZE SW_MINIMIZE SW_RESTORE SW_SHOW SW_SHOWDEFAULT SW_SHOWMAXIMIZED SW_SHOWMINIMIZED SW_SHOWMINNOACTIVE SW_SHOWNA SW_SHOWNOACTIVATE SW_SHOWNORMAL SW_UNLOCK SystemDir TAB TempDir TRAY_ID TrayIconFlashing TrayIconVisible UserName UserProfileDir WDAY WindowsDir WorkingDir YDAY YEAR',
            // relevance: 5
            begin: '@[A-z0-9_]+'
        },

        FUNCTION = {
            className: 'function',
            beginKeywords: 'Func',
            end: '$',
            excludeEnd: true,
            illegal: '\\$|\\[|%',
            contains: [
                hljs.UNDERSCORE_TITLE_MODE, {
                    className: 'params',
                    begin: '\\(',
                    end: '\\)',
                    contains: [
                        VARIABLE,
                        STRING,
                        NUMBER
                    ]
                }
            ]
        };

    return {
        case_insensitive: true,
        illegal: /\/\*/,
        keywords: {
            keyword: KEYWORDS,
            built_in: BUILT_IN,
            literal: LITERAL
        },
        contains: [
            COMMENT,
            VARIABLE,
            STRING,
            NUMBER,
            PREPROCESSOR,
            CONSTANT,
            FUNCTION
        ]
    }
});

hljs.registerLanguage('avrasm', function(hljs) {
  return {
    case_insensitive: true,
    lexemes: '\\.?' + hljs.IDENT_RE,
    keywords: {
      keyword:
        /* mnemonic */
        'adc add adiw and andi asr bclr bld brbc brbs brcc brcs break breq brge brhc brhs ' +
        'brid brie brlo brlt brmi brne brpl brsh brtc brts brvc brvs bset bst call cbi cbr ' +
        'clc clh cli cln clr cls clt clv clz com cp cpc cpi cpse dec eicall eijmp elpm eor ' +
        'fmul fmuls fmulsu icall ijmp in inc jmp ld ldd ldi lds lpm lsl lsr mov movw mul ' +
        'muls mulsu neg nop or ori out pop push rcall ret reti rjmp rol ror sbc sbr sbrc sbrs ' +
        'sec seh sbi sbci sbic sbis sbiw sei sen ser ses set sev sez sleep spm st std sts sub ' +
        'subi swap tst wdr',
      built_in:
        /* general purpose registers */
        'r0 r1 r2 r3 r4 r5 r6 r7 r8 r9 r10 r11 r12 r13 r14 r15 r16 r17 r18 r19 r20 r21 r22 ' +
        'r23 r24 r25 r26 r27 r28 r29 r30 r31 x|0 xh xl y|0 yh yl z|0 zh zl ' +
        /* IO Registers (ATMega128) */
        'ucsr1c udr1 ucsr1a ucsr1b ubrr1l ubrr1h ucsr0c ubrr0h tccr3c tccr3a tccr3b tcnt3h ' +
        'tcnt3l ocr3ah ocr3al ocr3bh ocr3bl ocr3ch ocr3cl icr3h icr3l etimsk etifr tccr1c ' +
        'ocr1ch ocr1cl twcr twdr twar twsr twbr osccal xmcra xmcrb eicra spmcsr spmcr portg ' +
        'ddrg ping portf ddrf sreg sph spl xdiv rampz eicrb eimsk gimsk gicr eifr gifr timsk ' +
        'tifr mcucr mcucsr tccr0 tcnt0 ocr0 assr tccr1a tccr1b tcnt1h tcnt1l ocr1ah ocr1al ' +
        'ocr1bh ocr1bl icr1h icr1l tccr2 tcnt2 ocr2 ocdr wdtcr sfior eearh eearl eedr eecr ' +
        'porta ddra pina portb ddrb pinb portc ddrc pinc portd ddrd pind spdr spsr spcr udr0 ' +
        'ucsr0a ucsr0b ubrr0l acsr admux adcsr adch adcl porte ddre pine pinf',
      preprocessor:
        '.byte .cseg .db .def .device .dseg .dw .endmacro .equ .eseg .exit .include .list ' +
        '.listmac .macro .nolist .org .set'
    },
    contains: [
      hljs.C_BLOCK_COMMENT_MODE,
      hljs.COMMENT(
        ';',
        '$',
        {
          relevance: 0
        }
      ),
      hljs.C_NUMBER_MODE, // 0x..., decimal, float
      hljs.BINARY_NUMBER_MODE, // 0b...
      {
        className: 'number',
        begin: '\\b(\\$[a-zA-Z0-9]+|0o[0-7]+)' // $..., 0o...
      },
      hljs.QUOTE_STRING_MODE,
      {
        className: 'string',
        begin: '\'', end: '[^\\\\]\'',
        illegal: '[^\\\\][^\']'
      },
      {className: 'label',  begin: '^[A-Za-z0-9_.$]+:'},
      {className: 'preprocessor', begin: '#', end: '$'},
      {  // подстановка в «.macro»
        className: 'localvars',
        begin: '@[0-9]+'
      }
    ]
  };
});

hljs.registerLanguage('axapta', function(hljs) {
  return {
    keywords: 'false int abstract private char boolean static null if for true ' +
      'while long throw finally protected final return void enum else ' +
      'break new catch byte super case short default double public try this switch ' +
      'continue reverse firstfast firstonly forupdate nofetch sum avg minof maxof count ' +
      'order group by asc desc index hint like dispaly edit client server ttsbegin ' +
      'ttscommit str real date container anytype common div mod',
    contains: [
      hljs.C_LINE_COMMENT_MODE,
      hljs.C_BLOCK_COMMENT_MODE,
      hljs.APOS_STRING_MODE,
      hljs.QUOTE_STRING_MODE,
      hljs.C_NUMBER_MODE,
      {
        className: 'preprocessor',
        begin: '#', end: '$'
      },
      {
        className: 'class',
        beginKeywords: 'class interface', end: '{', excludeEnd: true,
        illegal: ':',
        contains: [
          {beginKeywords: 'extends implements'},
          hljs.UNDERSCORE_TITLE_MODE
        ]
      }
    ]
  };
});

hljs.registerLanguage('bash', function(hljs) {
  var VAR = {
    className: 'variable',
    variants: [
      {begin: /\$[\w\d#@][\w\d_]*/},
      {begin: /\$\{(.*?)}/}
    ]
  };
  var QUOTE_STRING = {
    className: 'string',
    begin: /"/, end: /"/,
    contains: [
      hljs.BACKSLASH_ESCAPE,
      VAR,
      {
        className: 'variable',
        begin: /\$\(/, end: /\)/,
        contains: [hljs.BACKSLASH_ESCAPE]
      }
    ]
  };
  var APOS_STRING = {
    className: 'string',
    begin: /'/, end: /'/
  };

  return {
    aliases: ['sh', 'zsh'],
    lexemes: /-?[a-z\.]+/,
    keywords: {
      keyword:
        'if then else elif fi for while in do done case esac function',
      literal:
        'true false',
      built_in:
        // Shell built-ins
        // http://www.gnu.org/software/bash/manual/html_node/Shell-Builtin-Commands.html
        'break cd continue eval exec exit export getopts hash pwd readonly return shift test times ' +
        'trap umask unset ' +
        // Bash built-ins
        'alias bind builtin caller command declare echo enable help let local logout mapfile printf ' +
        'read readarray source type typeset ulimit unalias ' +
        // Shell modifiers
        'set shopt ' +
        // Zsh built-ins
        'autoload bg bindkey bye cap chdir clone comparguments compcall compctl compdescribe compfiles ' +
        'compgroups compquote comptags comptry compvalues dirs disable disown echotc echoti emulate ' +
        'fc fg float functions getcap getln history integer jobs kill limit log noglob popd print ' +
        'pushd pushln rehash sched setcap setopt stat suspend ttyctl unfunction unhash unlimit ' +
        'unsetopt vared wait whence where which zcompile zformat zftp zle zmodload zparseopts zprof ' +
        'zpty zregexparse zsocket zstyle ztcp',
      operator:
        '-ne -eq -lt -gt -f -d -e -s -l -a' // relevance booster
    },
    contains: [
      {
        className: 'shebang',
        begin: /^#![^\n]+sh\s*$/,
        relevance: 10
      },
      {
        className: 'function',
        begin: /\w[\w\d_]*\s*\(\s*\)\s*\{/,
        returnBegin: true,
        contains: [hljs.inherit(hljs.TITLE_MODE, {begin: /\w[\w\d_]*/})],
        relevance: 0
      },
      hljs.HASH_COMMENT_MODE,
      hljs.NUMBER_MODE,
      QUOTE_STRING,
      APOS_STRING,
      VAR
    ]
  };
});

hljs.registerLanguage('brainfuck', function(hljs){
  var LITERAL = {
    className: 'literal',
    begin: '[\\+\\-]',
    relevance: 0
  };
  return {
    aliases: ['bf'],
    contains: [
      hljs.COMMENT(
        '[^\\[\\]\\.,\\+\\-<> \r\n]',
        '[\\[\\]\\.,\\+\\-<> \r\n]',
        {
          returnEnd: true,
          relevance: 0
        }
      ),
      {
        className: 'title',
        begin: '[\\[\\]]',
        relevance: 0
      },
      {
        className: 'string',
        begin: '[\\.,]',
        relevance: 0
      },
      {
        // this mode works as the only relevance counter
        begin: /\+\+|\-\-/, returnBegin: true,
        contains: [LITERAL]
      },
      LITERAL
    ]
  };
});

hljs.registerLanguage('cal', function(hljs) {
  var KEYWORDS =
    'div mod in and or not xor asserterror begin case do downto else end exit for if of repeat then to ' +
    'until while with var';
  var LITERALS = 'false true';
  var COMMENT_MODES = [
    hljs.C_LINE_COMMENT_MODE,
    hljs.COMMENT(
      /\{/,
      /\}/,
      {
        relevance: 0
      }
    ),
    hljs.COMMENT(
      /\(\*/,
      /\*\)/,
      {
        relevance: 10
      }
    )
  ];
  var STRING = {
    className: 'string',
    begin: /'/, end: /'/,
    contains: [{begin: /''/}]
  };
  var CHAR_STRING = {
    className: 'string', begin: /(#\d+)+/
  };
  var DATE = {
      className: 'date',
      begin: '\\b\\d+(\\.\\d+)?(DT|D|T)',
      relevance: 0
  };
  var DBL_QUOTED_VARIABLE = {
      className: 'variable',
      begin: '"',
      end: '"'
  };

  var PROCEDURE = {
    className: 'function',
    beginKeywords: 'procedure', end: /[:;]/,
    keywords: 'procedure|10',
    contains: [
      hljs.TITLE_MODE,
      {
        className: 'params',
        begin: /\(/, end: /\)/,
        keywords: KEYWORDS,
        contains: [STRING, CHAR_STRING]
      }
    ].concat(COMMENT_MODES)
  };

  var OBJECT = {
    className: 'class',
    begin: 'OBJECT (Table|Form|Report|Dataport|Codeunit|XMLport|MenuSuite|Page|Query) (\\d+) ([^\\r\\n]+)',
    returnBegin: true,
    contains: [
      hljs.TITLE_MODE,
        PROCEDURE
    ]
  };

  return {
    case_insensitive: true,
    keywords: { keyword: KEYWORDS, literal: LITERALS },
    illegal: /\/\*/,
    contains: [
      STRING, CHAR_STRING,
      DATE, DBL_QUOTED_VARIABLE,
      hljs.NUMBER_MODE,
      OBJECT,
      PROCEDURE
    ]
  };
});

hljs.registerLanguage('capnproto', function(hljs) {
  return {
    aliases: ['capnp'],
    keywords: {
      keyword:
        'struct enum interface union group import using const annotation extends in of on as with from fixed',
      built_in:
        'Void Bool Int8 Int16 Int32 Int64 UInt8 UInt16 UInt32 UInt64 Float32 Float64 ' +
        'Text Data AnyPointer AnyStruct Capability List',
      literal:
        'true false'
    },
    contains: [
      hljs.QUOTE_STRING_MODE,
      hljs.NUMBER_MODE,
      hljs.HASH_COMMENT_MODE,
      {
        className: 'shebang',
        begin: /@0x[\w\d]{16};/,
        illegal: /\n/
      },
      {
        className: 'number',
        begin: /@\d+\b/
      },
      {
        className: 'class',
        beginKeywords: 'struct enum', end: /\{/,
        illegal: /\n/,
        contains: [
          hljs.inherit(hljs.TITLE_MODE, {
            starts: {endsWithParent: true, excludeEnd: true} // hack: eating everything after the first title
          })
        ]
      },
      {
        className: 'class',
        beginKeywords: 'interface', end: /\{/,
        illegal: /\n/,
        contains: [
          hljs.inherit(hljs.TITLE_MODE, {
            starts: {endsWithParent: true, excludeEnd: true} // hack: eating everything after the first title
          })
        ]
      }
    ]
  };
});

hljs.registerLanguage('ceylon', function(hljs) {
  // 2.3. Identifiers and keywords
  var KEYWORDS =
    'assembly module package import alias class interface object given value ' +
    'assign void function new of extends satisfies abstracts in out return ' +
    'break continue throw assert dynamic if else switch case for while try ' +
    'catch finally then let this outer super is exists nonempty';
  // 7.4.1 Declaration Modifiers
  var DECLARATION_MODIFIERS =
    'shared abstract formal default actual variable late native deprecated' +
    'final sealed annotation suppressWarnings small';
  // 7.4.2 Documentation
  var DOCUMENTATION =
    'doc by license see throws tagged';
  var LANGUAGE_ANNOTATIONS = DECLARATION_MODIFIERS + ' ' + DOCUMENTATION;
  var SUBST = {
    className: 'subst', excludeBegin: true, excludeEnd: true,
    begin: /``/, end: /``/,
    keywords: KEYWORDS,
    relevance: 10
  };
  var EXPRESSIONS = [
    {
      // verbatim string
      className: 'string',
      begin: '"""',
      end: '"""',
      relevance: 10
    },
    {
      // string literal or template
      className: 'string',
      begin: '"', end: '"',
      contains: [SUBST]
    },
    {
      // character literal
      className: 'string',
      begin: "'",
      end: "'"
    },
    {
      // numeric literal
      className: 'number',
      begin: '#[0-9a-fA-F_]+|\\$[01_]+|[0-9_]+(?:\\.[0-9_](?:[eE][+-]?\\d+)?)?[kMGTPmunpf]?',
      relevance: 0
    }
  ];
  SUBST.contains = EXPRESSIONS;

  return {
    keywords: {
      keyword: KEYWORDS,
      annotation: LANGUAGE_ANNOTATIONS
    },
    illegal: '\\$[^01]|#[^0-9a-fA-F]',
    contains: [
      hljs.C_LINE_COMMENT_MODE,
      hljs.COMMENT('/\\*', '\\*/', {contains: ['self']}),
      {
        // compiler annotation
        className: 'annotation',
        begin: '@[a-z]\\w*(?:\\:\"[^\"]*\")?'
      }
    ].concat(EXPRESSIONS)
  };
});

hljs.registerLanguage('clojure', function(hljs) {
  var keywords = {
    built_in:
      // Clojure keywords
      'def defonce cond apply if-not if-let if not not= = < > <= >= == + / * - rem '+
      'quot neg? pos? delay? symbol? keyword? true? false? integer? empty? coll? list? '+
      'set? ifn? fn? associative? sequential? sorted? counted? reversible? number? decimal? '+
      'class? distinct? isa? float? rational? reduced? ratio? odd? even? char? seq? vector? '+
      'string? map? nil? contains? zero? instance? not-every? not-any? libspec? -> ->> .. . '+
      'inc compare do dotimes mapcat take remove take-while drop letfn drop-last take-last '+
      'drop-while while intern condp case reduced cycle split-at split-with repeat replicate '+
      'iterate range merge zipmap declare line-seq sort comparator sort-by dorun doall nthnext '+
      'nthrest partition eval doseq await await-for let agent atom send send-off release-pending-sends '+
      'add-watch mapv filterv remove-watch agent-error restart-agent set-error-handler error-handler '+
      'set-error-mode! error-mode shutdown-agents quote var fn loop recur throw try monitor-enter '+
      'monitor-exit defmacro defn defn- macroexpand macroexpand-1 for dosync and or '+
      'when when-not when-let comp juxt partial sequence memoize constantly complement identity assert '+
      'peek pop doto proxy defstruct first rest cons defprotocol cast coll deftype defrecord last butlast '+
      'sigs reify second ffirst fnext nfirst nnext defmulti defmethod meta with-meta ns in-ns create-ns import '+
      'refer keys select-keys vals key val rseq name namespace promise into transient persistent! conj! '+
      'assoc! dissoc! pop! disj! use class type num float double short byte boolean bigint biginteger '+
      'bigdec print-method print-dup throw-if printf format load compile get-in update-in pr pr-on newline '+
      'flush read slurp read-line subvec with-open memfn time re-find re-groups rand-int rand mod locking '+
      'assert-valid-fdecl alias resolve ref deref refset swap! reset! set-validator! compare-and-set! alter-meta! '+
      'reset-meta! commute get-validator alter ref-set ref-history-count ref-min-history ref-max-history ensure sync io! '+
      'new next conj set! to-array future future-call into-array aset gen-class reduce map filter find empty '+
      'hash-map hash-set sorted-map sorted-map-by sorted-set sorted-set-by vec vector seq flatten reverse assoc dissoc list '+
      'disj get union difference intersection extend extend-type extend-protocol int nth delay count concat chunk chunk-buffer '+
      'chunk-append chunk-first chunk-rest max min dec unchecked-inc-int unchecked-inc unchecked-dec-inc unchecked-dec unchecked-negate '+
      'unchecked-add-int unchecked-add unchecked-subtract-int unchecked-subtract chunk-next chunk-cons chunked-seq? prn vary-meta '+
      'lazy-seq spread list* str find-keyword keyword symbol gensym force rationalize'
   };

  var SYMBOLSTART = 'a-zA-Z_\\-!.?+*=<>&#\'';
  var SYMBOL_RE = '[' + SYMBOLSTART + '][' + SYMBOLSTART + '0-9/;:]*';
  var SIMPLE_NUMBER_RE = '[-+]?\\d+(\\.\\d+)?';

  var SYMBOL = {
    begin: SYMBOL_RE,
    relevance: 0
  };
  var NUMBER = {
    className: 'number', begin: SIMPLE_NUMBER_RE,
    relevance: 0
  };
  var STRING = hljs.inherit(hljs.QUOTE_STRING_MODE, {illegal: null});
  var COMMENT = hljs.COMMENT(
    ';',
    '$',
    {
      relevance: 0
    }
  );
  var LITERAL = {
    className: 'literal',
    begin: /\b(true|false|nil)\b/
  };
  var COLLECTION = {
    className: 'collection',
    begin: '[\\[\\{]', end: '[\\]\\}]'
  };
  var HINT = {
    className: 'comment',
    begin: '\\^' + SYMBOL_RE
  };
  var HINT_COL = hljs.COMMENT('\\^\\{', '\\}');
  var KEY = {
    className: 'attribute',
    begin: '[:]' + SYMBOL_RE
  };
  var LIST = {
    className: 'list',
    begin: '\\(', end: '\\)'
  };
  var BODY = {
    endsWithParent: true,
    relevance: 0
  };
  var NAME = {
    keywords: keywords,
    lexemes: SYMBOL_RE,
    className: 'keyword', begin: SYMBOL_RE,
    starts: BODY
  };
  var DEFAULT_CONTAINS = [LIST, STRING, HINT, HINT_COL, COMMENT, KEY, COLLECTION, NUMBER, LITERAL, SYMBOL];

  LIST.contains = [hljs.COMMENT('comment', ''), NAME, BODY];
  BODY.contains = DEFAULT_CONTAINS;
  COLLECTION.contains = DEFAULT_CONTAINS;

  return {
    aliases: ['clj'],
    illegal: /\S/,
    contains: [LIST, STRING, HINT, HINT_COL, COMMENT, KEY, COLLECTION, NUMBER, LITERAL]
  }
});

hljs.registerLanguage('clojure-repl', function(hljs) {
  return {
    contains: [
      {
        className: 'prompt',
        begin: /^([\w.-]+|\s*#_)=>/,
        starts: {
          end: /$/,
          subLanguage: 'clojure'
        }
      }
    ]
  }
});

hljs.registerLanguage('cmake', function(hljs) {
  return {
    aliases: ['cmake.in'],
    case_insensitive: true,
    keywords: {
      keyword:
        'add_custom_command add_custom_target add_definitions add_dependencies ' +
        'add_executable add_library add_subdirectory add_test aux_source_directory ' +
        'break build_command cmake_minimum_required cmake_policy configure_file ' +
        'create_test_sourcelist define_property else elseif enable_language enable_testing ' +
        'endforeach endfunction endif endmacro endwhile execute_process export find_file ' +
        'find_library find_package find_path find_program fltk_wrap_ui foreach function ' +
        'get_cmake_property get_directory_property get_filename_component get_property ' +
        'get_source_file_property get_target_property get_test_property if include ' +
        'include_directories include_external_msproject include_regular_expression install ' +
        'link_directories load_cache load_command macro mark_as_advanced message option ' +
        'output_required_files project qt_wrap_cpp qt_wrap_ui remove_definitions return ' +
        'separate_arguments set set_directory_properties set_property ' +
        'set_source_files_properties set_target_properties set_tests_properties site_name ' +
        'source_group string target_link_libraries try_compile try_run unset variable_watch ' +
        'while build_name exec_program export_library_dependencies install_files ' +
        'install_programs install_targets link_libraries make_directory remove subdir_depends ' +
        'subdirs use_mangled_mesa utility_source variable_requires write_file ' +
        'qt5_use_modules qt5_use_package qt5_wrap_cpp on off true false and or',
      operator:
        'equal less greater strless strgreater strequal matches'
    },
    contains: [
      {
        className: 'envvar',
        begin: '\\${', end: '}'
      },
      hljs.HASH_COMMENT_MODE,
      hljs.QUOTE_STRING_MODE,
      hljs.NUMBER_MODE
    ]
  };
});

hljs.registerLanguage('coffeescript', function(hljs) {
  var KEYWORDS = {
    keyword:
      // JS keywords
      'in if for while finally new do return else break catch instanceof throw try this ' +
      'switch continue typeof delete debugger super ' +
      // Coffee keywords
      'then unless until loop of by when and or is isnt not',
    literal:
      // JS literals
      'true false null undefined ' +
      // Coffee literals
      'yes no on off',
    built_in:
      'npm require console print module global window document'
  };
  var JS_IDENT_RE = '[A-Za-z$_][0-9A-Za-z$_]*';
  var SUBST = {
    className: 'subst',
    begin: /#\{/, end: /}/,
    keywords: KEYWORDS
  };
  var EXPRESSIONS = [
    hljs.BINARY_NUMBER_MODE,
    hljs.inherit(hljs.C_NUMBER_MODE, {starts: {end: '(\\s*/)?', relevance: 0}}), // a number tries to eat the following slash to prevent treating it as a regexp
    {
      className: 'string',
      variants: [
        {
          begin: /'''/, end: /'''/,
          contains: [hljs.BACKSLASH_ESCAPE]
        },
        {
          begin: /'/, end: /'/,
          contains: [hljs.BACKSLASH_ESCAPE]
        },
        {
          begin: /"""/, end: /"""/,
          contains: [hljs.BACKSLASH_ESCAPE, SUBST]
        },
        {
          begin: /"/, end: /"/,
          contains: [hljs.BACKSLASH_ESCAPE, SUBST]
        }
      ]
    },
    {
      className: 'regexp',
      variants: [
        {
          begin: '///', end: '///',
          contains: [SUBST, hljs.HASH_COMMENT_MODE]
        },
        {
          begin: '//[gim]*',
          relevance: 0
        },
        {
          // regex can't start with space to parse x / 2 / 3 as two divisions
          // regex can't start with *, and it supports an "illegal" in the main mode
          begin: /\/(?![ *])(\\\/|.)*?\/[gim]*(?=\W|$)/
        }
      ]
    },
    {
      className: 'property',
      begin: '@' + JS_IDENT_RE
    },
    {
      begin: '`', end: '`',
      excludeBegin: true, excludeEnd: true,
      subLanguage: 'javascript'
    }
  ];
  SUBST.contains = EXPRESSIONS;

  var TITLE = hljs.inherit(hljs.TITLE_MODE, {begin: JS_IDENT_RE});
  var PARAMS_RE = '(\\(.*\\))?\\s*\\B[-=]>';
  var PARAMS = {
    className: 'params',
    begin: '\\([^\\(]', returnBegin: true,
    /* We need another contained nameless mode to not have every nested
    pair of parens to be called "params" */
    contains: [{
      begin: /\(/, end: /\)/,
      keywords: KEYWORDS,
      contains: ['self'].concat(EXPRESSIONS)
    }]
  };

  return {
    aliases: ['coffee', 'cson', 'iced'],
    keywords: KEYWORDS,
    illegal: /\/\*/,
    contains: EXPRESSIONS.concat([
      hljs.COMMENT('###', '###'),
      hljs.HASH_COMMENT_MODE,
      {
        className: 'function',
        begin: '^\\s*' + JS_IDENT_RE + '\\s*=\\s*' + PARAMS_RE, end: '[-=]>',
        returnBegin: true,
        contains: [TITLE, PARAMS]
      },
      {
        // anonymous function start
        begin: /[:\(,=]\s*/,
        relevance: 0,
        contains: [
          {
            className: 'function',
            begin: PARAMS_RE, end: '[-=]>',
            returnBegin: true,
            contains: [PARAMS]
          }
        ]
      },
      {
        className: 'class',
        beginKeywords: 'class',
        end: '$',
        illegal: /[:="\[\]]/,
        contains: [
          {
            beginKeywords: 'extends',
            endsWithParent: true,
            illegal: /[:="\[\]]/,
            contains: [TITLE]
          },
          TITLE
        ]
      },
      {
        className: 'attribute',
        begin: JS_IDENT_RE + ':', end: ':',
        returnBegin: true, returnEnd: true,
        relevance: 0
      }
    ])
  };
});

hljs.registerLanguage('cpp', function(hljs) {
  var CPP_PRIMATIVE_TYPES = {
    className: 'keyword',
    begin: '\\b[a-z\\d_]*_t\\b'
  };

  var STRINGS = {
    className: 'string',
    variants: [
      hljs.inherit(hljs.QUOTE_STRING_MODE, { begin: '((u8?|U)|L)?"' }),
      {
        begin: '(u8?|U)?R"', end: '"',
        contains: [hljs.BACKSLASH_ESCAPE]
      },
      {
        begin: '\'\\\\?.', end: '\'',
        illegal: '.'
      }
    ]
  };

  var NUMBERS = {
    className: 'number',
    variants: [
      { begin: '\\b(\\d+(\\.\\d*)?|\\.\\d+)(u|U|l|L|ul|UL|f|F)' },
      { begin: hljs.C_NUMBER_RE }
    ]
  };

  var PREPROCESSOR =       {
    className: 'preprocessor',
    begin: '#', end: '$',
    keywords: 'if else elif endif define undef warning error line ' +
              'pragma ifdef ifndef',
    contains: [
      {
        begin: /\\\n/, relevance: 0
      },
      {
        beginKeywords: 'include', end: '$',
        contains: [
          STRINGS,
          {
            className: 'string',
            begin: '<', end: '>',
            illegal: '\\n',
          }
        ]
      },
      STRINGS,
      NUMBERS,
      hljs.C_LINE_COMMENT_MODE,
      hljs.C_BLOCK_COMMENT_MODE
    ]
  };

  var FUNCTION_TITLE = hljs.IDENT_RE + '\\s*\\(';

  var CPP_KEYWORDS = {
    keyword: 'int float while private char catch export virtual operator sizeof ' +
      'dynamic_cast|10 typedef const_cast|10 const struct for static_cast|10 union namespace ' +
      'unsigned long volatile static protected bool template mutable if public friend ' +
      'do goto auto void enum else break extern using class asm case typeid ' +
      'short reinterpret_cast|10 default double register explicit signed typename try this ' +
      'switch continue inline delete alignof constexpr decltype ' +
      'noexcept static_assert thread_local restrict _Bool complex _Complex _Imaginary ' +
      'atomic_bool atomic_char atomic_schar ' +
      'atomic_uchar atomic_short atomic_ushort atomic_int atomic_uint atomic_long atomic_ulong atomic_llong ' +
      'atomic_ullong',
    built_in: 'std string cin cout cerr clog stdin stdout stderr stringstream istringstream ostringstream ' +
      'auto_ptr deque list queue stack vector map set bitset multiset multimap unordered_set ' +
      'unordered_map unordered_multiset unordered_multimap array shared_ptr abort abs acos ' +
      'asin atan2 atan calloc ceil cosh cos exit exp fabs floor fmod fprintf fputs free frexp ' +
      'fscanf isalnum isalpha iscntrl isdigit isgraph islower isprint ispunct isspace isupper ' +
      'isxdigit tolower toupper labs ldexp log10 log malloc realloc memchr memcmp memcpy memset modf pow ' +
      'printf putchar puts scanf sinh sin snprintf sprintf sqrt sscanf strcat strchr strcmp ' +
      'strcpy strcspn strlen strncat strncmp strncpy strpbrk strrchr strspn strstr tanh tan ' +
      'vfprintf vprintf vsprintf',
    literal: 'true false nullptr NULL'
  };

  return {
    aliases: ['c', 'cc', 'h', 'c++', 'h++', 'hpp'],
    keywords: CPP_KEYWORDS,
    illegal: '</',
    contains: [
      CPP_PRIMATIVE_TYPES,
      hljs.C_LINE_COMMENT_MODE,
      hljs.C_BLOCK_COMMENT_MODE,
      NUMBERS,
      STRINGS,
      PREPROCESSOR,
      {
        begin: '\\b(deque|list|queue|stack|vector|map|set|bitset|multiset|multimap|unordered_map|unordered_set|unordered_multiset|unordered_multimap|array)\\s*<', end: '>',
        keywords: CPP_KEYWORDS,
        contains: ['self', CPP_PRIMATIVE_TYPES]
      },
      {
        begin: hljs.IDENT_RE + '::',
        keywords: CPP_KEYWORDS
      },
      {
        // Expression keywords prevent 'keyword Name(...) or else if(...)' from
        // being recognized as a function definition
        beginKeywords: 'new throw return else',
        relevance: 0
      },
      {
        className: 'function',
        begin: '(' + hljs.IDENT_RE + '[\\*&\\s]+)+' + FUNCTION_TITLE,
        returnBegin: true, end: /[{;=]/,
        excludeEnd: true,
        keywords: CPP_KEYWORDS,
        illegal: /[^\w\s\*&]/,
        contains: [
          {
            begin: FUNCTION_TITLE, returnBegin: true,
            contains: [hljs.TITLE_MODE],
            relevance: 0
          },
          {
            className: 'params',
            begin: /\(/, end: /\)/,
            keywords: CPP_KEYWORDS,
            relevance: 0,
            contains: [
              hljs.C_LINE_COMMENT_MODE,
              hljs.C_BLOCK_COMMENT_MODE,
              STRINGS,
              NUMBERS
            ]
          },
          hljs.C_LINE_COMMENT_MODE,
          hljs.C_BLOCK_COMMENT_MODE,
          PREPROCESSOR
        ]
      }
    ]
  };
});

hljs.registerLanguage('crmsh', function(hljs) {
  var RESOURCES = 'primitive rsc_template';

  var COMMANDS = 'group clone ms master location colocation order fencing_topology ' +
      'rsc_ticket acl_target acl_group user role ' +
      'tag xml';

  var PROPERTY_SETS = 'property rsc_defaults op_defaults';

  var KEYWORDS = 'params meta operations op rule attributes utilization';

  var OPERATORS = 'read write deny defined not_defined in_range date spec in ' +
      'ref reference attribute type xpath version and or lt gt tag ' +
      'lte gte eq ne \\';

  var TYPES = 'number string';

  var LITERALS = 'Master Started Slave Stopped start promote demote stop monitor true false';

  return {
    aliases: ['crm', 'pcmk'],
    case_insensitive: true,
    keywords: {
      keyword: KEYWORDS,
      operator: OPERATORS,
      type: TYPES,
      literal: LITERALS
    },
    contains: [
      hljs.HASH_COMMENT_MODE,
      {
        beginKeywords: 'node',
        starts: {
          className: 'identifier',
          end: '\\s*([\\w_-]+:)?',
          starts: {
            className: 'title',
            end: '\\s*[\\$\\w_][\\w_-]*'
          }
        }
      },
      {
        beginKeywords: RESOURCES,
        starts: {
          className: 'title',
          end: '\\s*[\\$\\w_][\\w_-]*',
          starts: {
            className: 'pragma',
            end: '\\s*@?[\\w_][\\w_\\.:-]*',
          }
        }
      },
      {
        begin: '\\b(' + COMMANDS.split(' ').join('|') + ')\\s+',
        keywords: COMMANDS,
        starts: {
          className: 'title',
          end: '[\\$\\w_][\\w_-]*',
        }
      },
      {
        beginKeywords: PROPERTY_SETS,
        starts: {
          className: 'title',
          end: '\\s*([\\w_-]+:)?'
        }
      },
      hljs.QUOTE_STRING_MODE,
      {
        className: 'pragma',
        begin: '(ocf|systemd|service|lsb):[\\w_:-]+',
        relevance: 0
      },
      {
        className: 'number',
        begin: '\\b\\d+(\\.\\d+)?(ms|s|h|m)?',
        relevance: 0
      },
      {
        className: 'number',
        begin: '[-]?(infinity|inf)',
        relevance: 0
      },
      {
        className: 'variable',
        begin: /([A-Za-z\$_\#][\w_-]+)=/,
        relevance: 0
      },
      {
        className: 'tag',
        begin: '</?',
        end: '/?>',
        relevance: 0
      }
    ]
  };
});

hljs.registerLanguage('crystal', function(hljs) {
  var NUM_SUFFIX = '(_[uif](8|16|32|64))?';
  var CRYSTAL_IDENT_RE = '[a-zA-Z_]\\w*[!?=]?';
  var RE_STARTER = '!=|!==|%|%=|&|&&|&=|\\*|\\*=|\\+|\\+=|,|-|-=|/=|/|:|;|<<|<<=|<=|<|===|==|=|>>>=|>>=|>=|>>>|' +
    '>>|>|\\[|\\{|\\(|\\^|\\^=|\\||\\|=|\\|\\||~';
  var CRYSTAL_METHOD_RE = '[a-zA-Z_]\\w*[!?=]?|[-+~]\\@|<<|>>|=~|===?|<=>|[<>]=?|\\*\\*|[-/+%^&*~`|]|\\[\\][=?]?';
  var CRYSTAL_KEYWORDS = {
    keyword:
      'abstract alias as asm begin break case class def do else elsif end ensure enum extend for fun if ifdef ' +
      'include instance_sizeof is_a? lib macro module next of out pointerof private protected rescue responds_to? ' +
      'return require self sizeof struct super then type typeof union unless until when while with yield ' +
      '__DIR__ __FILE__ __LINE__',
    literal: 'false nil true'
  };
  var SUBST = {
    className: 'subst',
    begin: '#{', end: '}',
    keywords: CRYSTAL_KEYWORDS
  };
  var EXPANSION = {
    className: 'expansion',
    variants: [
      {begin: '\\{\\{', end: '\\}\\}'},
      {begin: '\\{%', end: '%\\}'}
    ],
    keywords: CRYSTAL_KEYWORDS,
    relevance: 10
  };

  function recursiveParen(begin, end) {
    var
    contains = [{begin: begin, end: end}];
    contains[0].contains = contains;
    return contains;
  }
  var STRING = {
    className: 'string',
    contains: [hljs.BACKSLASH_ESCAPE, SUBST],
    variants: [
      {begin: /'/, end: /'/},
      {begin: /"/, end: /"/},
      {begin: /`/, end: /`/},
      {begin: '%w?\\(', end: '\\)', contains: recursiveParen('\\(', '\\)')},
      {begin: '%w?\\[', end: '\\]', contains: recursiveParen('\\[', '\\]')},
      {begin: '%w?{', end: '}', contains: recursiveParen('{', '}')},
      {begin: '%w?<', end: '>', contains: recursiveParen('<', '>')},
      {begin: '%w?/', end: '/'},
      {begin: '%w?%', end: '%'},
      {begin: '%w?-', end: '-'},
      {begin: '%w?\\|', end: '\\|'},
    ],
    relevance: 0,
  };
  var REGEXP = {
    begin: '(' + RE_STARTER + ')\\s*',
    contains: [
      {
        className: 'regexp',
        contains: [hljs.BACKSLASH_ESCAPE, SUBST],
        variants: [
          {begin: '/', end: '/[a-z]*'},
          {begin: '%r\\(', end: '\\)', contains: recursiveParen('\\(', '\\)')},
          {begin: '%r\\[', end: '\\]', contains: recursiveParen('\\[', '\\]')},
          {begin: '%r{', end: '}', contains: recursiveParen('{', '}')},
          {begin: '%r<', end: '>', contains: recursiveParen('<', '>')},
          {begin: '%r/', end: '/'},
          {begin: '%r%', end: '%'},
          {begin: '%r-', end: '-'},
          {begin: '%r\\|', end: '\\|'},
        ]
      }
    ],
    relevance: 0
  };
  var REGEXP2 = {
    className: 'regexp',
    contains: [hljs.BACKSLASH_ESCAPE, SUBST],
    variants: [
      {begin: '%r\\(', end: '\\)', contains: recursiveParen('\\(', '\\)')},
      {begin: '%r\\[', end: '\\]', contains: recursiveParen('\\[', '\\]')},
      {begin: '%r{', end: '}', contains: recursiveParen('{', '}')},
      {begin: '%r<', end: '>', contains: recursiveParen('<', '>')},
      {begin: '%r/', end: '/'},
      {begin: '%r%', end: '%'},
      {begin: '%r-', end: '-'},
      {begin: '%r\\|', end: '\\|'},
    ],
    relevance: 0
  };
  var ATTRIBUTE = {
    className: 'annotation',
    begin: '@\\[', end: '\\]',
    relevance: 5
  };
  var CRYSTAL_DEFAULT_CONTAINS = [
    EXPANSION,
    STRING,
    REGEXP,
    REGEXP2,
    ATTRIBUTE,
    hljs.HASH_COMMENT_MODE,
    {
      className: 'class',
      beginKeywords: 'class module struct', end: '$|;',
      illegal: /=/,
      contains: [
        hljs.HASH_COMMENT_MODE,
        hljs.inherit(hljs.TITLE_MODE, {begin: '[A-Za-z_]\\w*(::\\w+)*(\\?|\\!)?'}),
        {
          className: 'inheritance',
          begin: '<\\s*',
          contains: [{
            className: 'parent',
            begin: '(' + hljs.IDENT_RE + '::)?' + hljs.IDENT_RE
          }]
        }
      ]
    },
    {
      className: 'class',
      beginKeywords: 'lib enum union', end: '$|;',
      illegal: /=/,
      contains: [
        hljs.HASH_COMMENT_MODE,
        hljs.inherit(hljs.TITLE_MODE, {begin: '[A-Za-z_]\\w*(::\\w+)*(\\?|\\!)?'}),
      ],
      relevance: 10
    },
    {
      className: 'function',
      beginKeywords: 'def', end: /\B\b/,
      contains: [
        hljs.inherit(hljs.TITLE_MODE, {
          begin: CRYSTAL_METHOD_RE,
          endsParent: true
        })
      ]
    },
    {
      className: 'function',
      beginKeywords: 'fun macro', end: /\B\b/,
      contains: [
        hljs.inherit(hljs.TITLE_MODE, {
          begin: CRYSTAL_METHOD_RE,
          endsParent: true
        })
      ],
      relevance: 5
    },
    {
      className: 'constant',
      begin: '(::)?(\\b[A-Z]\\w*(::)?)+',
      relevance: 0
    },
    {
      className: 'symbol',
      begin: hljs.UNDERSCORE_IDENT_RE + '(\\!|\\?)?:',
      relevance: 0
    },
    {
      className: 'symbol',
      begin: ':',
      contains: [STRING, {begin: CRYSTAL_METHOD_RE}],
      relevance: 0
    },
    {
      className: 'number',
      variants: [
        { begin: '\\b0b([01_]*[01])' + NUM_SUFFIX },
        { begin: '\\b0o([0-7_]*[0-7])' + NUM_SUFFIX },
        { begin: '\\b0x([A-Fa-f0-9_]*[A-Fa-f0-9])' + NUM_SUFFIX },
        { begin: '\\b(([0-9][0-9_]*[0-9]|[0-9])(\\.[0-9_]*[0-9])?([eE][+-]?[0-9_]*[0-9])?)' + NUM_SUFFIX}
      ],
      relevance: 0
    },
    {
      className: 'variable',
      begin: '(\\$\\W)|((\\$|\\@\\@?|%)(\\w+))'
    }
  ];
  SUBST.contains = CRYSTAL_DEFAULT_CONTAINS;
  ATTRIBUTE.contains = CRYSTAL_DEFAULT_CONTAINS;
  EXPANSION.contains = CRYSTAL_DEFAULT_CONTAINS.slice(1); // without EXPANSION

  return {
    aliases: ['cr'],
    lexemes: CRYSTAL_IDENT_RE,
    keywords: CRYSTAL_KEYWORDS,
    contains: CRYSTAL_DEFAULT_CONTAINS
  };
});

hljs.registerLanguage('cs', function(hljs) {
  var KEYWORDS =
    // Normal keywords.
    'abstract as base bool break byte case catch char checked const continue decimal dynamic ' +
    'default delegate do double else enum event explicit extern false finally fixed float ' +
    'for foreach goto if implicit in int interface internal is lock long null when ' +
    'object operator out override params private protected public readonly ref sbyte ' +
    'sealed short sizeof stackalloc static string struct switch this true try typeof ' +
    'uint ulong unchecked unsafe ushort using virtual volatile void while async ' +
    'protected public private internal ' +
    // Contextual keywords.
    'ascending descending from get group into join let orderby partial select set value var ' +
    'where yield';
  var GENERIC_IDENT_RE = hljs.IDENT_RE + '(<' + hljs.IDENT_RE + '>)?';
  return {
    aliases: ['csharp'],
    keywords: KEYWORDS,
    illegal: /::/,
    contains: [
      hljs.COMMENT(
        '///',
        '$',
        {
          returnBegin: true,
          contains: [
            {
              className: 'xmlDocTag',
              variants: [
                {
                  begin: '///', relevance: 0
                },
                {
                  begin: '<!--|-->'
                },
                {
                  begin: '</?', end: '>'
                }
              ]
            }
          ]
        }
      ),
      hljs.C_LINE_COMMENT_MODE,
      hljs.C_BLOCK_COMMENT_MODE,
      {
        className: 'preprocessor',
        begin: '#', end: '$',
        keywords: 'if else elif endif define undef warning error line region endregion pragma checksum'
      },
      {
        className: 'string',
        begin: '@"', end: '"',
        contains: [{begin: '""'}]
      },
      hljs.APOS_STRING_MODE,
      hljs.QUOTE_STRING_MODE,
      hljs.C_NUMBER_MODE,
      {
        beginKeywords: 'class interface', end: /[{;=]/,
        illegal: /[^\s:]/,
        contains: [
          hljs.TITLE_MODE,
          hljs.C_LINE_COMMENT_MODE,
          hljs.C_BLOCK_COMMENT_MODE
        ]
      },
      {
        beginKeywords: 'namespace', end: /[{;=]/,
        illegal: /[^\s:]/,
        contains: [
          {
            // Customization of hljs.TITLE_MODE that allows '.'
            className: 'title',
            begin: '[a-zA-Z](\\.?\\w)*',
            relevance: 0
          },
          hljs.C_LINE_COMMENT_MODE,
          hljs.C_BLOCK_COMMENT_MODE
        ]
      },
      {
        // Expression keywords prevent 'keyword Name(...)' from being
        // recognized as a function definition
        beginKeywords: 'new return throw await',
        relevance: 0
      },
      {
        className: 'function',
        begin: '(' + GENERIC_IDENT_RE + '\\s+)+' + hljs.IDENT_RE + '\\s*\\(', returnBegin: true, end: /[{;=]/,
        excludeEnd: true,
        keywords: KEYWORDS,
        contains: [
          {
            begin: hljs.IDENT_RE + '\\s*\\(', returnBegin: true,
            contains: [hljs.TITLE_MODE],
            relevance: 0
          },
          {
            className: 'params',
            begin: /\(/, end: /\)/,
            excludeBegin: true,
            excludeEnd: true,
            keywords: KEYWORDS,
            relevance: 0,
            contains: [
              hljs.APOS_STRING_MODE,
              hljs.QUOTE_STRING_MODE,
              hljs.C_NUMBER_MODE,
              hljs.C_BLOCK_COMMENT_MODE
            ]
          },
          hljs.C_LINE_COMMENT_MODE,
          hljs.C_BLOCK_COMMENT_MODE
        ]
      }
    ]
  };
});

hljs.registerLanguage('css', function(hljs) {
  var IDENT_RE = '[a-zA-Z-][a-zA-Z0-9_-]*';
  var FUNCTION = {
    className: 'function',
    begin: IDENT_RE + '\\(',
    returnBegin: true,
    excludeEnd: true,
    end: '\\('
  };
  var RULE = {
    className: 'rule',
    begin: /[A-Z\_\.\-]+\s*:/, returnBegin: true, end: ';', endsWithParent: true,
    contains: [
      {
        className: 'attribute',
        begin: /\S/, end: ':', excludeEnd: true,
        starts: {
          className: 'value',
          endsWithParent: true, excludeEnd: true,
          contains: [
            FUNCTION,
            hljs.CSS_NUMBER_MODE,
            hljs.QUOTE_STRING_MODE,
            hljs.APOS_STRING_MODE,
            hljs.C_BLOCK_COMMENT_MODE,
            {
              className: 'hexcolor', begin: '#[0-9A-Fa-f]+'
            },
            {
              className: 'important', begin: '!important'
            }
          ]
        }
      }
    ]
  };

  return {
    case_insensitive: true,
    illegal: /[=\/|'\$]/,
    contains: [
      hljs.C_BLOCK_COMMENT_MODE,
      {
        className: 'id', begin: /\#[A-Za-z0-9_-]+/
      },
      {
        className: 'class', begin: /\.[A-Za-z0-9_-]+/
      },
      {
        className: 'attr_selector',
        begin: /\[/, end: /\]/,
        illegal: '$'
      },
      {
        className: 'pseudo',
        begin: /:(:)?[a-zA-Z0-9\_\-\+\(\)"']+/
      },
      {
        className: 'at_rule',
        begin: '@(font-face|page)',
        lexemes: '[a-z-]+',
        keywords: 'font-face page'
      },
      {
        className: 'at_rule',
        begin: '@', end: '[{;]', // at_rule eating first "{" is a good thing
                                 // because it doesn’t let it to be parsed as
                                 // a rule set but instead drops parser into
                                 // the default mode which is how it should be.
        contains: [
          {
            className: 'keyword',
            begin: /\S+/
          },
          {
            begin: /\s/, endsWithParent: true, excludeEnd: true,
            relevance: 0,
            contains: [
              FUNCTION,
              hljs.APOS_STRING_MODE, hljs.QUOTE_STRING_MODE,
              hljs.CSS_NUMBER_MODE
            ]
          }
        ]
      },
      {
        className: 'tag', begin: IDENT_RE,
        relevance: 0
      },
      {
        className: 'rules',
        begin: '{', end: '}',
        illegal: /\S/,
        contains: [
          hljs.C_BLOCK_COMMENT_MODE,
          RULE,
        ]
      }
    ]
  };
});

hljs.registerLanguage('d', /**
 * Known issues:
 *
 * - invalid hex string literals will be recognized as a double quoted strings
 *   but 'x' at the beginning of string will not be matched
 *
 * - delimited string literals are not checked for matching end delimiter
 *   (not possible to do with js regexp)
 *
 * - content of token string is colored as a string (i.e. no keyword coloring inside a token string)
 *   also, content of token string is not validated to contain only valid D tokens
 *
 * - special token sequence rule is not strictly following D grammar (anything following #line
 *   up to the end of line is matched as special token sequence)
 */

function(hljs) {
  /**
   * Language keywords
   *
   * @type {Object}
   */
  var D_KEYWORDS = {
    keyword:
      'abstract alias align asm assert auto body break byte case cast catch class ' +
      'const continue debug default delete deprecated do else enum export extern final ' +
      'finally for foreach foreach_reverse|10 goto if immutable import in inout int ' +
      'interface invariant is lazy macro mixin module new nothrow out override package ' +
      'pragma private protected public pure ref return scope shared static struct ' +
      'super switch synchronized template this throw try typedef typeid typeof union ' +
      'unittest version void volatile while with __FILE__ __LINE__ __gshared|10 ' +
      '__thread __traits __DATE__ __EOF__ __TIME__ __TIMESTAMP__ __VENDOR__ __VERSION__',
    built_in:
      'bool cdouble cent cfloat char creal dchar delegate double dstring float function ' +
      'idouble ifloat ireal long real short string ubyte ucent uint ulong ushort wchar ' +
      'wstring',
    literal:
      'false null true'
  };

  /**
   * Number literal regexps
   *
   * @type {String}
   */
  var decimal_integer_re = '(0|[1-9][\\d_]*)',
    decimal_integer_nosus_re = '(0|[1-9][\\d_]*|\\d[\\d_]*|[\\d_]+?\\d)',
    binary_integer_re = '0[bB][01_]+',
    hexadecimal_digits_re = '([\\da-fA-F][\\da-fA-F_]*|_[\\da-fA-F][\\da-fA-F_]*)',
    hexadecimal_integer_re = '0[xX]' + hexadecimal_digits_re,

    decimal_exponent_re = '([eE][+-]?' + decimal_integer_nosus_re + ')',
    decimal_float_re = '(' + decimal_integer_nosus_re + '(\\.\\d*|' + decimal_exponent_re + ')|' +
                '\\d+\\.' + decimal_integer_nosus_re + decimal_integer_nosus_re + '|' +
                '\\.' + decimal_integer_re + decimal_exponent_re + '?' +
              ')',
    hexadecimal_float_re = '(0[xX](' +
                  hexadecimal_digits_re + '\\.' + hexadecimal_digits_re + '|'+
                  '\\.?' + hexadecimal_digits_re +
                 ')[pP][+-]?' + decimal_integer_nosus_re + ')',

    integer_re = '(' +
      decimal_integer_re + '|' +
      binary_integer_re  + '|' +
       hexadecimal_integer_re   +
    ')',

    float_re = '(' +
      hexadecimal_float_re + '|' +
      decimal_float_re  +
    ')';

  /**
   * Escape sequence supported in D string and character literals
   *
   * @type {String}
   */
  var escape_sequence_re = '\\\\(' +
              '[\'"\\?\\\\abfnrtv]|' +  // common escapes
              'u[\\dA-Fa-f]{4}|' +     // four hex digit unicode codepoint
              '[0-7]{1,3}|' +       // one to three octal digit ascii char code
              'x[\\dA-Fa-f]{2}|' +    // two hex digit ascii char code
              'U[\\dA-Fa-f]{8}' +      // eight hex digit unicode codepoint
              ')|' +
              '&[a-zA-Z\\d]{2,};';      // named character entity

  /**
   * D integer number literals
   *
   * @type {Object}
   */
  var D_INTEGER_MODE = {
    className: 'number',
      begin: '\\b' + integer_re + '(L|u|U|Lu|LU|uL|UL)?',
      relevance: 0
  };

  /**
   * [D_FLOAT_MODE description]
   * @type {Object}
   */
  var D_FLOAT_MODE = {
    className: 'number',
    begin: '\\b(' +
        float_re + '([fF]|L|i|[fF]i|Li)?|' +
        integer_re + '(i|[fF]i|Li)' +
      ')',
    relevance: 0
  };

  /**
   * D character literal
   *
   * @type {Object}
   */
  var D_CHARACTER_MODE = {
    className: 'string',
    begin: '\'(' + escape_sequence_re + '|.)', end: '\'',
    illegal: '.'
  };

  /**
   * D string escape sequence
   *
   * @type {Object}
   */
  var D_ESCAPE_SEQUENCE = {
    begin: escape_sequence_re,
    relevance: 0
  };

  /**
   * D double quoted string literal
   *
   * @type {Object}
   */
  var D_STRING_MODE = {
    className: 'string',
    begin: '"',
    contains: [D_ESCAPE_SEQUENCE],
    end: '"[cwd]?'
  };

  /**
   * D wysiwyg and delimited string literals
   *
   * @type {Object}
   */
  var D_WYSIWYG_DELIMITED_STRING_MODE = {
    className: 'string',
    begin: '[rq]"',
    end: '"[cwd]?',
    relevance: 5
  };

  /**
   * D alternate wysiwyg string literal
   *
   * @type {Object}
   */
  var D_ALTERNATE_WYSIWYG_STRING_MODE = {
    className: 'string',
    begin: '`',
    end: '`[cwd]?'
  };

  /**
   * D hexadecimal string literal
   *
   * @type {Object}
   */
  var D_HEX_STRING_MODE = {
    className: 'string',
    begin: 'x"[\\da-fA-F\\s\\n\\r]*"[cwd]?',
    relevance: 10
  };

  /**
   * D delimited string literal
   *
   * @type {Object}
   */
  var D_TOKEN_STRING_MODE = {
    className: 'string',
    begin: 'q"\\{',
    end: '\\}"'
  };

  /**
   * Hashbang support
   *
   * @type {Object}
   */
  var D_HASHBANG_MODE = {
    className: 'shebang',
    begin: '^#!',
    end: '$',
    relevance: 5
  };

  /**
   * D special token sequence
   *
   * @type {Object}
   */
  var D_SPECIAL_TOKEN_SEQUENCE_MODE = {
    className: 'preprocessor',
    begin: '#(line)',
    end: '$',
    relevance: 5
  };

  /**
   * D attributes
   *
   * @type {Object}
   */
  var D_ATTRIBUTE_MODE = {
    className: 'keyword',
    begin: '@[a-zA-Z_][a-zA-Z_\\d]*'
  };

  /**
   * D nesting comment
   *
   * @type {Object}
   */
  var D_NESTING_COMMENT_MODE = hljs.COMMENT(
    '\\/\\+',
    '\\+\\/',
    {
      contains: ['self'],
      relevance: 10
    }
  );

  return {
    lexemes: hljs.UNDERSCORE_IDENT_RE,
    keywords: D_KEYWORDS,
    contains: [
      hljs.C_LINE_COMMENT_MODE,
        hljs.C_BLOCK_COMMENT_MODE,
        D_NESTING_COMMENT_MODE,
        D_HEX_STRING_MODE,
        D_STRING_MODE,
        D_WYSIWYG_DELIMITED_STRING_MODE,
        D_ALTERNATE_WYSIWYG_STRING_MODE,
        D_TOKEN_STRING_MODE,
        D_FLOAT_MODE,
        D_INTEGER_MODE,
        D_CHARACTER_MODE,
        D_HASHBANG_MODE,
        D_SPECIAL_TOKEN_SEQUENCE_MODE,
        D_ATTRIBUTE_MODE
    ]
  };
});

hljs.registerLanguage('markdown', function(hljs) {
  return {
    aliases: ['md', 'mkdown', 'mkd'],
    contains: [
      // highlight headers
      {
        className: 'header',
        variants: [
          { begin: '^#{1,6}', end: '$' },
          { begin: '^.+?\\n[=-]{2,}$' }
        ]
      },
      // inline html
      {
        begin: '<', end: '>',
        subLanguage: 'xml',
        relevance: 0
      },
      // lists (indicators only)
      {
        className: 'bullet',
        begin: '^([*+-]|(\\d+\\.))\\s+'
      },
      // strong segments
      {
        className: 'strong',
        begin: '[*_]{2}.+?[*_]{2}'
      },
      // emphasis segments
      {
        className: 'emphasis',
        variants: [
          { begin: '\\*.+?\\*' },
          { begin: '_.+?_'
          , relevance: 0
          }
        ]
      },
      // blockquotes
      {
        className: 'blockquote',
        begin: '^>\\s+', end: '$'
      },
      // code snippets
      {
        className: 'code',
        variants: [
          { begin: '`.+?`' },
          { begin: '^( {4}|\t)', end: '$'
          , relevance: 0
          }
        ]
      },
      // horizontal rules
      {
        className: 'horizontal_rule',
        begin: '^[-\\*]{3,}', end: '$'
      },
      // using links - title and link
      {
        begin: '\\[.+?\\][\\(\\[].*?[\\)\\]]',
        returnBegin: true,
        contains: [
          {
            className: 'link_label',
            begin: '\\[', end: '\\]',
            excludeBegin: true,
            returnEnd: true,
            relevance: 0
          },
          {
            className: 'link_url',
            begin: '\\]\\(', end: '\\)',
            excludeBegin: true, excludeEnd: true
          },
          {
            className: 'link_reference',
            begin: '\\]\\[', end: '\\]',
            excludeBegin: true, excludeEnd: true
          }
        ],
        relevance: 10
      },
      {
        begin: '^\\[\.+\\]:',
        returnBegin: true,
        contains: [
          {
            className: 'link_reference',
            begin: '\\[', end: '\\]:',
            excludeBegin: true, excludeEnd: true,
            starts: {
              className: 'link_url',
              end: '$'
            }
          }
        ]
      }
    ]
  };
});

hljs.registerLanguage('dart', function (hljs) {
  var SUBST = {
    className: 'subst',
    begin: '\\$\\{', end: '}',
    keywords: 'true false null this is new super'
  };

  var STRING = {
    className: 'string',
    variants: [
      {
        begin: 'r\'\'\'', end: '\'\'\''
      },
      {
        begin: 'r"""', end: '"""'
      },
      {
        begin: 'r\'', end: '\'',
        illegal: '\\n'
      },
      {
        begin: 'r"', end: '"',
        illegal: '\\n'
      },
      {
        begin: '\'\'\'', end: '\'\'\'',
        contains: [hljs.BACKSLASH_ESCAPE, SUBST]
      },
      {
        begin: '"""', end: '"""',
        contains: [hljs.BACKSLASH_ESCAPE, SUBST]
      },
      {
        begin: '\'', end: '\'',
        illegal: '\\n',
        contains: [hljs.BACKSLASH_ESCAPE, SUBST]
      },
      {
        begin: '"', end: '"',
        illegal: '\\n',
        contains: [hljs.BACKSLASH_ESCAPE, SUBST]
      }
    ]
  };
  SUBST.contains = [
    hljs.C_NUMBER_MODE, STRING
  ];

  var KEYWORDS = {
    keyword: 'assert break case catch class const continue default do else enum extends false final finally for if ' +
      'in is new null rethrow return super switch this throw true try var void while with',
    literal: 'abstract as dynamic export external factory get implements import library operator part set static typedef',
    built_in:
      // dart:core
      'print Comparable DateTime Duration Function Iterable Iterator List Map Match Null Object Pattern RegExp Set ' +
      'Stopwatch String StringBuffer StringSink Symbol Type Uri bool double int num ' +
      // dart:html
      'document window querySelector querySelectorAll Element ElementList'
  };

  return {
    keywords: KEYWORDS,
    contains: [
      STRING,
      hljs.COMMENT(
        '/\\*\\*',
        '\\*/',
        {
          subLanguage: 'markdown'
        }
      ),
      hljs.COMMENT(
        '///',
        '$',
        {
          subLanguage: 'markdown'
        }
      ),
      hljs.C_LINE_COMMENT_MODE,
      hljs.C_BLOCK_COMMENT_MODE,
      {
        className: 'class',
        beginKeywords: 'class interface', end: '{', excludeEnd: true,
        contains: [
          {
            beginKeywords: 'extends implements'
          },
          hljs.UNDERSCORE_TITLE_MODE
        ]
      },
      hljs.C_NUMBER_MODE,
      {
        className: 'annotation', begin: '@[A-Za-z]+'
      },
      {
        begin: '=>' // No markup, just a relevance booster
      }
    ]
  }
});

hljs.registerLanguage('delphi', function(hljs) {
  var KEYWORDS =
    'exports register file shl array record property for mod while set ally label uses raise not ' +
    'stored class safecall var interface or private static exit index inherited to else stdcall ' +
    'override shr asm far resourcestring finalization packed virtual out and protected library do ' +
    'xorwrite goto near function end div overload object unit begin string on inline repeat until ' +
    'destructor write message program with read initialization except default nil if case cdecl in ' +
    'downto threadvar of try pascal const external constructor type public then implementation ' +
    'finally published procedure';
  var COMMENT_MODES = [
    hljs.C_LINE_COMMENT_MODE,
    hljs.COMMENT(
      /\{/,
      /\}/,
      {
        relevance: 0
      }
    ),
    hljs.COMMENT(
      /\(\*/,
      /\*\)/,
      {
        relevance: 10
      }
    )
  ];
  var STRING = {
    className: 'string',
    begin: /'/, end: /'/,
    contains: [{begin: /''/}]
  };
  var CHAR_STRING = {
    className: 'string', begin: /(#\d+)+/
  };
  var CLASS = {
    begin: hljs.IDENT_RE + '\\s*=\\s*class\\s*\\(', returnBegin: true,
    contains: [
      hljs.TITLE_MODE
    ]
  };
  var FUNCTION = {
    className: 'function',
    beginKeywords: 'function constructor destructor procedure', end: /[:;]/,
    keywords: 'function constructor|10 destructor|10 procedure|10',
    contains: [
      hljs.TITLE_MODE,
      {
        className: 'params',
        begin: /\(/, end: /\)/,
        keywords: KEYWORDS,
        contains: [STRING, CHAR_STRING]
      }
    ].concat(COMMENT_MODES)
  };
  return {
    case_insensitive: true,
    keywords: KEYWORDS,
    illegal: /"|\$[G-Zg-z]|\/\*|<\/|\|/,
    contains: [
      STRING, CHAR_STRING,
      hljs.NUMBER_MODE,
      CLASS,
      FUNCTION
    ].concat(COMMENT_MODES)
  };
});

hljs.registerLanguage('diff', function(hljs) {
  return {
    aliases: ['patch'],
    contains: [
      {
        className: 'chunk',
        relevance: 10,
        variants: [
          {begin: /^@@ +\-\d+,\d+ +\+\d+,\d+ +@@$/},
          {begin: /^\*\*\* +\d+,\d+ +\*\*\*\*$/},
          {begin: /^\-\-\- +\d+,\d+ +\-\-\-\-$/}
        ]
      },
      {
        className: 'header',
        variants: [
          {begin: /Index: /, end: /$/},
          {begin: /=====/, end: /=====$/},
          {begin: /^\-\-\-/, end: /$/},
          {begin: /^\*{3} /, end: /$/},
          {begin: /^\+\+\+/, end: /$/},
          {begin: /\*{5}/, end: /\*{5}$/}
        ]
      },
      {
        className: 'addition',
        begin: '^\\+', end: '$'
      },
      {
        className: 'deletion',
        begin: '^\\-', end: '$'
      },
      {
        className: 'change',
        begin: '^\\!', end: '$'
      }
    ]
  };
});

hljs.registerLanguage('django', function(hljs) {
  var FILTER = {
    className: 'filter',
    begin: /\|[A-Za-z]+:?/,
    keywords:
      'truncatewords removetags linebreaksbr yesno get_digit timesince random striptags ' +
      'filesizeformat escape linebreaks length_is ljust rjust cut urlize fix_ampersands ' +
      'title floatformat capfirst pprint divisibleby add make_list unordered_list urlencode ' +
      'timeuntil urlizetrunc wordcount stringformat linenumbers slice date dictsort ' +
      'dictsortreversed default_if_none pluralize lower join center default ' +
      'truncatewords_html upper length phone2numeric wordwrap time addslashes slugify first ' +
      'escapejs force_escape iriencode last safe safeseq truncatechars localize unlocalize ' +
      'localtime utc timezone',
    contains: [
      {className: 'argument', begin: /"/, end: /"/},
      {className: 'argument', begin: /'/, end: /'/}
    ]
  };

  return {
    aliases: ['jinja'],
    case_insensitive: true,
    subLanguage: 'xml',
    contains: [
      hljs.COMMENT(/\{%\s*comment\s*%}/, /\{%\s*endcomment\s*%}/),
      hljs.COMMENT(/\{#/, /#}/),
      {
        className: 'template_tag',
        begin: /\{%/, end: /%}/,
        keywords:
          'comment endcomment load templatetag ifchanged endifchanged if endif firstof for ' +
          'endfor in ifnotequal endifnotequal widthratio extends include spaceless ' +
          'endspaceless regroup by as ifequal endifequal ssi now with cycle url filter ' +
          'endfilter debug block endblock else autoescape endautoescape csrf_token empty elif ' +
          'endwith static trans blocktrans endblocktrans get_static_prefix get_media_prefix ' +
          'plural get_current_language language get_available_languages ' +
          'get_current_language_bidi get_language_info get_language_info_list localize ' +
          'endlocalize localtime endlocaltime timezone endtimezone get_current_timezone ' +
          'verbatim',
        contains: [FILTER]
      },
      {
        className: 'variable',
        begin: /\{\{/, end: /}}/,
        contains: [FILTER]
      }
    ]
  };
});

hljs.registerLanguage('dns', function(hljs) {
  return {
    aliases: ['bind', 'zone'],
    keywords: {
      keyword:
        'IN A AAAA AFSDB APL CAA CDNSKEY CDS CERT CNAME DHCID DLV DNAME DNSKEY DS HIP IPSECKEY KEY KX ' +
        'LOC MX NAPTR NS NSEC NSEC3 NSEC3PARAM PTR RRSIG RP SIG SOA SRV SSHFP TA TKEY TLSA TSIG TXT'
    },
    contains: [
      hljs.COMMENT(';', '$'),
      {
        className: 'operator',
        beginKeywords: '$TTL $GENERATE $INCLUDE $ORIGIN'
      },
      // IPv6
      {
        className: 'number',
        begin: '((([0-9A-Fa-f]{1,4}:){7}([0-9A-Fa-f]{1,4}|:))|(([0-9A-Fa-f]{1,4}:){6}(:[0-9A-Fa-f]{1,4}|((25[0-5]|2[0-4]\\d|1\\d\\d|[1-9]?\\d)(\\.(25[0-5]|2[0-4]\\d|1\\d\\d|[1-9]?\\d)){3})|:))|(([0-9A-Fa-f]{1,4}:){5}(((:[0-9A-Fa-f]{1,4}){1,2})|:((25[0-5]|2[0-4]\\d|1\\d\\d|[1-9]?\\d)(\\.(25[0-5]|2[0-4]\\d|1\\d\\d|[1-9]?\\d)){3})|:))|(([0-9A-Fa-f]{1,4}:){4}(((:[0-9A-Fa-f]{1,4}){1,3})|((:[0-9A-Fa-f]{1,4})?:((25[0-5]|2[0-4]\\d|1\\d\\d|[1-9]?\\d)(\\.(25[0-5]|2[0-4]\\d|1\\d\\d|[1-9]?\\d)){3}))|:))|(([0-9A-Fa-f]{1,4}:){3}(((:[0-9A-Fa-f]{1,4}){1,4})|((:[0-9A-Fa-f]{1,4}){0,2}:((25[0-5]|2[0-4]\\d|1\\d\\d|[1-9]?\\d)(\\.(25[0-5]|2[0-4]\\d|1\\d\\d|[1-9]?\\d)){3}))|:))|(([0-9A-Fa-f]{1,4}:){2}(((:[0-9A-Fa-f]{1,4}){1,5})|((:[0-9A-Fa-f]{1,4}){0,3}:((25[0-5]|2[0-4]\\d|1\\d\\d|[1-9]?\\d)(\\.(25[0-5]|2[0-4]\\d|1\\d\\d|[1-9]?\\d)){3}))|:))|(([0-9A-Fa-f]{1,4}:){1}(((:[0-9A-Fa-f]{1,4}){1,6})|((:[0-9A-Fa-f]{1,4}){0,4}:((25[0-5]|2[0-4]\\d|1\\d\\d|[1-9]?\\d)(\\.(25[0-5]|2[0-4]\\d|1\\d\\d|[1-9]?\\d)){3}))|:))|(:(((:[0-9A-Fa-f]{1,4}){1,7})|((:[0-9A-Fa-f]{1,4}){0,5}:((25[0-5]|2[0-4]\\d|1\\d\\d|[1-9]?\\d)(\\.(25[0-5]|2[0-4]\\d|1\\d\\d|[1-9]?\\d)){3}))|:)))'
      },
      // IPv4
      {
        className: 'number',
        begin: '((25[0-5]|(2[0-4]|1{0,1}[0-9]){0,1}[0-9])\.){3,3}(25[0-5]|(2[0-4]|1{0,1}[0-9]){0,1}[0-9])'
      }
    ]
  };
});

hljs.registerLanguage('dockerfile', function(hljs) {
  return {
    aliases: ['docker'],
    case_insensitive: true,
    keywords: {
      built_ins: 'from maintainer cmd expose add copy entrypoint volume user workdir onbuild run env label'
    },
    contains: [
      hljs.HASH_COMMENT_MODE,
      {
        keywords : {
          built_in: 'run cmd entrypoint volume add copy workdir onbuild label'
        },
        begin: /^ *(onbuild +)?(run|cmd|entrypoint|volume|add|copy|workdir|label) +/,
        starts: {
          end: /[^\\]\n/,
          subLanguage: 'bash'
        }
      },
      {
        keywords: {
          built_in: 'from maintainer expose env user onbuild'
        },
        begin: /^ *(onbuild +)?(from|maintainer|expose|env|user|onbuild) +/, end: /[^\\]\n/,
        contains: [
          hljs.APOS_STRING_MODE,
          hljs.QUOTE_STRING_MODE,
          hljs.NUMBER_MODE,
          hljs.HASH_COMMENT_MODE
        ]
      }
    ]
  }
});

hljs.registerLanguage('dos', function(hljs) {
  var COMMENT = hljs.COMMENT(
    /@?rem\b/, /$/,
    {
      relevance: 10
    }
  );
  var LABEL = {
    className: 'label',
    begin: '^\\s*[A-Za-z._?][A-Za-z0-9_$#@~.?]*(:|\\s+label)',
    relevance: 0
  };
  return {
    aliases: ['bat', 'cmd'],
    case_insensitive: true,
    illegal: /\/\*/,
    keywords: {
      flow: 'if else goto for in do call exit not exist errorlevel defined',
      operator: 'equ neq lss leq gtr geq',
      keyword: 'shift cd dir echo setlocal endlocal set pause copy',
      stream: 'prn nul lpt3 lpt2 lpt1 con com4 com3 com2 com1 aux',
      winutils: 'ping net ipconfig taskkill xcopy ren del',
      built_in: 'append assoc at attrib break cacls cd chcp chdir chkdsk chkntfs cls cmd color ' +
        'comp compact convert date dir diskcomp diskcopy doskey erase fs ' +
        'find findstr format ftype graftabl help keyb label md mkdir mode more move path ' +
        'pause print popd pushd promt rd recover rem rename replace restore rmdir shift' +
        'sort start subst time title tree type ver verify vol'
    },
    contains: [
      {
        className: 'envvar', begin: /%%[^ ]|%[^ ]+?%|![^ ]+?!/
      },
      {
        className: 'function',
        begin: LABEL.begin, end: 'goto:eof',
        contains: [
          hljs.inherit(hljs.TITLE_MODE, {begin: '([_a-zA-Z]\\w*\\.)*([_a-zA-Z]\\w*:)?[_a-zA-Z]\\w*'}),
          COMMENT
        ]
      },
      {
        className: 'number', begin: '\\b\\d+',
        relevance: 0
      },
      COMMENT
    ]
  };
});

hljs.registerLanguage('dust', function(hljs) {
  var EXPRESSION_KEYWORDS = 'if eq ne lt lte gt gte select default math sep';
  return {
    aliases: ['dst'],
    case_insensitive: true,
    subLanguage: 'xml',
    contains: [
      {
        className: 'expression',
        begin: '{', end: '}',
        relevance: 0,
        contains: [
          {
            className: 'begin-block', begin: '\#[a-zA-Z\-\ \.]+',
            keywords: EXPRESSION_KEYWORDS
          },
          {
            className: 'string',
            begin: '"', end: '"'
          },
          {
            className: 'end-block', begin: '\\\/[a-zA-Z\-\ \.]+',
            keywords: EXPRESSION_KEYWORDS
          },
          {
            className: 'variable', begin: '[a-zA-Z\-\.]+',
            keywords: EXPRESSION_KEYWORDS,
            relevance: 0
          }
        ]
      }
    ]
  };
});

hljs.registerLanguage('elixir', function(hljs) {
  var ELIXIR_IDENT_RE = '[a-zA-Z_][a-zA-Z0-9_]*(\\!|\\?)?';
  var ELIXIR_METHOD_RE = '[a-zA-Z_]\\w*[!?=]?|[-+~]\\@|<<|>>|=~|===?|<=>|[<>]=?|\\*\\*|[-/+%^&*~`|]|\\[\\]=?';
  var ELIXIR_KEYWORDS =
    'and false then defined module in return redo retry end for true self when ' +
    'next until do begin unless nil break not case cond alias while ensure or ' +
    'include use alias fn quote';
  var SUBST = {
    className: 'subst',
    begin: '#\\{', end: '}',
    lexemes: ELIXIR_IDENT_RE,
    keywords: ELIXIR_KEYWORDS
  };
  var STRING = {
    className: 'string',
    contains: [hljs.BACKSLASH_ESCAPE, SUBST],
    variants: [
      {
        begin: /'/, end: /'/
      },
      {
        begin: /"/, end: /"/
      }
    ]
  };
  var FUNCTION = {
    className: 'function',
    beginKeywords: 'def defp defmacro', end: /\B\b/, // the mode is ended by the title
    contains: [
      hljs.inherit(hljs.TITLE_MODE, {
        begin: ELIXIR_IDENT_RE,
        endsParent: true
      })
    ]
  };
  var CLASS = hljs.inherit(FUNCTION, {
    className: 'class',
    beginKeywords: 'defmodule defrecord', end: /\bdo\b|$|;/
  });
  var ELIXIR_DEFAULT_CONTAINS = [
    STRING,
    hljs.HASH_COMMENT_MODE,
    CLASS,
    FUNCTION,
    {
      className: 'constant',
      begin: '(\\b[A-Z_]\\w*(.)?)+',
      relevance: 0
    },
    {
      className: 'symbol',
      begin: ':',
      contains: [STRING, {begin: ELIXIR_METHOD_RE}],
      relevance: 0
    },
    {
      className: 'symbol',
      begin: ELIXIR_IDENT_RE + ':',
      relevance: 0
    },
    {
      className: 'number',
      begin: '(\\b0[0-7_]+)|(\\b0x[0-9a-fA-F_]+)|(\\b[1-9][0-9_]*(\\.[0-9_]+)?)|[0_]\\b',
      relevance: 0
    },
    {
      className: 'variable',
      begin: '(\\$\\W)|((\\$|\\@\\@?)(\\w+))'
    },
    {
      begin: '->'
    },
    { // regexp container
      begin: '(' + hljs.RE_STARTERS_RE + ')\\s*',
      contains: [
        hljs.HASH_COMMENT_MODE,
        {
          className: 'regexp',
          illegal: '\\n',
          contains: [hljs.BACKSLASH_ESCAPE, SUBST],
          variants: [
            {
              begin: '/', end: '/[a-z]*'
            },
            {
              begin: '%r\\[', end: '\\][a-z]*'
            }
          ]
        }
      ],
      relevance: 0
    }
  ];
  SUBST.contains = ELIXIR_DEFAULT_CONTAINS;

  return {
    lexemes: ELIXIR_IDENT_RE,
    keywords: ELIXIR_KEYWORDS,
    contains: ELIXIR_DEFAULT_CONTAINS
  };
});

hljs.registerLanguage('elm', function(hljs) {
  var COMMENT_MODES = [
    hljs.COMMENT('--', '$'),
    hljs.COMMENT(
      '{-',
      '-}',
      {
        contains: ['self']
      }
    )
  ];

  var CONSTRUCTOR = {
    className: 'type',
    begin: '\\b[A-Z][\\w\']*', // TODO: other constructors (build-in, infix).
    relevance: 0
  };

  var LIST = {
    className: 'container',
    begin: '\\(', end: '\\)',
    illegal: '"',
    contains: [
      {className: 'type', begin: '\\b[A-Z][\\w]*(\\((\\.\\.|,|\\w+)\\))?'}
    ].concat(COMMENT_MODES)
  };

  var RECORD = {
    className: 'container',
    begin: '{', end: '}',
    contains: LIST.contains
  };

  return {
    keywords:
      'let in if then else case of where module import exposing ' +
      'type alias as infix infixl infixr port',
    contains: [

      // Top-level constructions.

      {
        className: 'module',
        begin: '\\bmodule\\b', end: 'where',
        keywords: 'module where',
        contains: [LIST].concat(COMMENT_MODES),
        illegal: '\\W\\.|;'
      },
      {
        className: 'import',
        begin: '\\bimport\\b', end: '$',
        keywords: 'import|0 as exposing',
        contains: [LIST].concat(COMMENT_MODES),
        illegal: '\\W\\.|;'
      },
      {
        className: 'typedef',
        begin: '\\btype\\b', end: '$',
        keywords: 'type alias',
        contains: [CONSTRUCTOR, LIST, RECORD].concat(COMMENT_MODES)
      },
      {
        className: 'infix',
        beginKeywords: 'infix infixl infixr', end: '$',
        contains: [hljs.C_NUMBER_MODE].concat(COMMENT_MODES)
      },
      {
        className: 'foreign',
        begin: '\\bport\\b', end: '$',
        keywords: 'port',
        contains: COMMENT_MODES
      },

      // Literals and names.

      // TODO: characters.
      hljs.QUOTE_STRING_MODE,
      hljs.C_NUMBER_MODE,
      CONSTRUCTOR,
      hljs.inherit(hljs.TITLE_MODE, {begin: '^[_a-z][\\w\']*'}),

      {begin: '->|<-'} // No markup, relevance booster
    ].concat(COMMENT_MODES)
  };
});

hljs.registerLanguage('ruby', function(hljs) {
  var RUBY_METHOD_RE = '[a-zA-Z_]\\w*[!?=]?|[-+~]\\@|<<|>>|=~|===?|<=>|[<>]=?|\\*\\*|[-/+%^&*~`|]|\\[\\]=?';
  var RUBY_KEYWORDS =
    'and false then defined module in return redo if BEGIN retry end for true self when ' +
    'next until do begin unless END rescue nil else break undef not super class case ' +
    'require yield alias while ensure elsif or include attr_reader attr_writer attr_accessor';
  var YARDOCTAG = {
    className: 'doctag',
    begin: '@[A-Za-z]+'
  };
  var IRB_OBJECT = {
    className: 'value',
    begin: '#<', end: '>'
  };
  var COMMENT_MODES = [
    hljs.COMMENT(
      '#',
      '$',
      {
        contains: [YARDOCTAG]
      }
    ),
    hljs.COMMENT(
      '^\\=begin',
      '^\\=end',
      {
        contains: [YARDOCTAG],
        relevance: 10
      }
    ),
    hljs.COMMENT('^__END__', '\\n$')
  ];
  var SUBST = {
    className: 'subst',
    begin: '#\\{', end: '}',
    keywords: RUBY_KEYWORDS
  };
  var STRING = {
    className: 'string',
    contains: [hljs.BACKSLASH_ESCAPE, SUBST],
    variants: [
      {begin: /'/, end: /'/},
      {begin: /"/, end: /"/},
      {begin: /`/, end: /`/},
      {begin: '%[qQwWx]?\\(', end: '\\)'},
      {begin: '%[qQwWx]?\\[', end: '\\]'},
      {begin: '%[qQwWx]?{', end: '}'},
      {begin: '%[qQwWx]?<', end: '>'},
      {begin: '%[qQwWx]?/', end: '/'},
      {begin: '%[qQwWx]?%', end: '%'},
      {begin: '%[qQwWx]?-', end: '-'},
      {begin: '%[qQwWx]?\\|', end: '\\|'},
      {
        // \B in the beginning suppresses recognition of ?-sequences where ?
        // is the last character of a preceding identifier, as in: `func?4`
        begin: /\B\?(\\\d{1,3}|\\x[A-Fa-f0-9]{1,2}|\\u[A-Fa-f0-9]{4}|\\?\S)\b/
      }
    ]
  };
  var PARAMS = {
    className: 'params',
    begin: '\\(', end: '\\)',
    keywords: RUBY_KEYWORDS
  };

  var RUBY_DEFAULT_CONTAINS = [
    STRING,
    IRB_OBJECT,
    {
      className: 'class',
      beginKeywords: 'class module', end: '$|;',
      illegal: /=/,
      contains: [
        hljs.inherit(hljs.TITLE_MODE, {begin: '[A-Za-z_]\\w*(::\\w+)*(\\?|\\!)?'}),
        {
          className: 'inheritance',
          begin: '<\\s*',
          contains: [{
            className: 'parent',
            begin: '(' + hljs.IDENT_RE + '::)?' + hljs.IDENT_RE
          }]
        }
      ].concat(COMMENT_MODES)
    },
    {
      className: 'function',
      beginKeywords: 'def', end: '$|;',
      contains: [
        hljs.inherit(hljs.TITLE_MODE, {begin: RUBY_METHOD_RE}),
        PARAMS
      ].concat(COMMENT_MODES)
    },
    {
      className: 'constant',
      begin: '(::)?(\\b[A-Z]\\w*(::)?)+',
      relevance: 0
    },
    {
      className: 'symbol',
      begin: hljs.UNDERSCORE_IDENT_RE + '(\\!|\\?)?:',
      relevance: 0
    },
    {
      className: 'symbol',
      begin: ':',
      contains: [STRING, {begin: RUBY_METHOD_RE}],
      relevance: 0
    },
    {
      className: 'number',
      begin: '(\\b0[0-7_]+)|(\\b0x[0-9a-fA-F_]+)|(\\b[1-9][0-9_]*(\\.[0-9_]+)?)|[0_]\\b',
      relevance: 0
    },
    {
      className: 'variable',
      begin: '(\\$\\W)|((\\$|\\@\\@?)(\\w+))'
    },
    { // regexp container
      begin: '(' + hljs.RE_STARTERS_RE + ')\\s*',
      contains: [
        IRB_OBJECT,
        {
          className: 'regexp',
          contains: [hljs.BACKSLASH_ESCAPE, SUBST],
          illegal: /\n/,
          variants: [
            {begin: '/', end: '/[a-z]*'},
            {begin: '%r{', end: '}[a-z]*'},
            {begin: '%r\\(', end: '\\)[a-z]*'},
            {begin: '%r!', end: '![a-z]*'},
            {begin: '%r\\[', end: '\\][a-z]*'}
          ]
        }
      ].concat(COMMENT_MODES),
      relevance: 0
    }
  ].concat(COMMENT_MODES);

  SUBST.contains = RUBY_DEFAULT_CONTAINS;
  PARAMS.contains = RUBY_DEFAULT_CONTAINS;

  var SIMPLE_PROMPT = "[>?]>";
  var DEFAULT_PROMPT = "[\\w#]+\\(\\w+\\):\\d+:\\d+>";
  var RVM_PROMPT = "(\\w+-)?\\d+\\.\\d+\\.\\d(p\\d+)?[^>]+>";

  var IRB_DEFAULT = [
    {
      begin: /^\s*=>/,
      className: 'status',
      starts: {
        end: '$', contains: RUBY_DEFAULT_CONTAINS
      }
    },
    {
      className: 'prompt',
      begin: '^('+SIMPLE_PROMPT+"|"+DEFAULT_PROMPT+'|'+RVM_PROMPT+')',
      starts: {
        end: '$', contains: RUBY_DEFAULT_CONTAINS
      }
    }
  ];

  return {
    aliases: ['rb', 'gemspec', 'podspec', 'thor', 'irb'],
    keywords: RUBY_KEYWORDS,
    illegal: /\/\*/,
    contains: COMMENT_MODES.concat(IRB_DEFAULT).concat(RUBY_DEFAULT_CONTAINS)
  };
});

hljs.registerLanguage('erb', function(hljs) {
  return {
    subLanguage: 'xml',
    contains: [
      hljs.COMMENT('<%#', '%>'),
      {
        begin: '<%[%=-]?', end: '[%-]?%>',
        subLanguage: 'ruby',
        excludeBegin: true,
        excludeEnd: true
      }
    ]
  };
});

hljs.registerLanguage('erlang-repl', function(hljs) {
  return {
    keywords: {
      special_functions:
        'spawn spawn_link self',
      reserved:
        'after and andalso|10 band begin bnot bor bsl bsr bxor case catch cond div end fun if ' +
        'let not of or orelse|10 query receive rem try when xor'
    },
    contains: [
      {
        className: 'prompt', begin: '^[0-9]+> ',
        relevance: 10
      },
      hljs.COMMENT('%', '$'),
      {
        className: 'number',
        begin: '\\b(\\d+#[a-fA-F0-9]+|\\d+(\\.\\d+)?([eE][-+]?\\d+)?)',
        relevance: 0
      },
      hljs.APOS_STRING_MODE,
      hljs.QUOTE_STRING_MODE,
      {
        className: 'constant', begin: '\\?(::)?([A-Z]\\w*(::)?)+'
      },
      {
        className: 'arrow', begin: '->'
      },
      {
        className: 'ok', begin: 'ok'
      },
      {
        className: 'exclamation_mark', begin: '!'
      },
      {
        className: 'function_or_atom',
        begin: '(\\b[a-z\'][a-zA-Z0-9_\']*:[a-z\'][a-zA-Z0-9_\']*)|(\\b[a-z\'][a-zA-Z0-9_\']*)',
        relevance: 0
      },
      {
        className: 'variable',
        begin: '[A-Z][a-zA-Z0-9_\']*',
        relevance: 0
      }
    ]
  };
});

hljs.registerLanguage('erlang', function(hljs) {
  var BASIC_ATOM_RE = '[a-z\'][a-zA-Z0-9_\']*';
  var FUNCTION_NAME_RE = '(' + BASIC_ATOM_RE + ':' + BASIC_ATOM_RE + '|' + BASIC_ATOM_RE + ')';
  var ERLANG_RESERVED = {
    keyword:
      'after and andalso|10 band begin bnot bor bsl bzr bxor case catch cond div end fun if ' +
      'let not of orelse|10 query receive rem try when xor',
    literal:
      'false true'
  };

  var COMMENT = hljs.COMMENT('%', '$');
  var NUMBER = {
    className: 'number',
    begin: '\\b(\\d+#[a-fA-F0-9]+|\\d+(\\.\\d+)?([eE][-+]?\\d+)?)',
    relevance: 0
  };
  var NAMED_FUN = {
    begin: 'fun\\s+' + BASIC_ATOM_RE + '/\\d+'
  };
  var FUNCTION_CALL = {
    begin: FUNCTION_NAME_RE + '\\(', end: '\\)',
    returnBegin: true,
    relevance: 0,
    contains: [
      {
        className: 'function_name', begin: FUNCTION_NAME_RE,
        relevance: 0
      },
      {
        begin: '\\(', end: '\\)', endsWithParent: true,
        returnEnd: true,
        relevance: 0
        // "contains" defined later
      }
    ]
  };
  var TUPLE = {
    className: 'tuple',
    begin: '{', end: '}',
    relevance: 0
    // "contains" defined later
  };
  var VAR1 = {
    className: 'variable',
    begin: '\\b_([A-Z][A-Za-z0-9_]*)?',
    relevance: 0
  };
  var VAR2 = {
    className: 'variable',
    begin: '[A-Z][a-zA-Z0-9_]*',
    relevance: 0
  };
  var RECORD_ACCESS = {
    begin: '#' + hljs.UNDERSCORE_IDENT_RE,
    relevance: 0,
    returnBegin: true,
    contains: [
      {
        className: 'record_name',
        begin: '#' + hljs.UNDERSCORE_IDENT_RE,
        relevance: 0
      },
      {
        begin: '{', end: '}',
        relevance: 0
        // "contains" defined later
      }
    ]
  };

  var BLOCK_STATEMENTS = {
    beginKeywords: 'fun receive if try case', end: 'end',
    keywords: ERLANG_RESERVED
  };
  BLOCK_STATEMENTS.contains = [
    COMMENT,
    NAMED_FUN,
    hljs.inherit(hljs.APOS_STRING_MODE, {className: ''}),
    BLOCK_STATEMENTS,
    FUNCTION_CALL,
    hljs.QUOTE_STRING_MODE,
    NUMBER,
    TUPLE,
    VAR1, VAR2,
    RECORD_ACCESS
  ];

  var BASIC_MODES = [
    COMMENT,
    NAMED_FUN,
    BLOCK_STATEMENTS,
    FUNCTION_CALL,
    hljs.QUOTE_STRING_MODE,
    NUMBER,
    TUPLE,
    VAR1, VAR2,
    RECORD_ACCESS
  ];
  FUNCTION_CALL.contains[1].contains = BASIC_MODES;
  TUPLE.contains = BASIC_MODES;
  RECORD_ACCESS.contains[1].contains = BASIC_MODES;

  var PARAMS = {
    className: 'params',
    begin: '\\(', end: '\\)',
    contains: BASIC_MODES
  };
  return {
    aliases: ['erl'],
    keywords: ERLANG_RESERVED,
    illegal: '(</|\\*=|\\+=|-=|/\\*|\\*/|\\(\\*|\\*\\))',
    contains: [
      {
        className: 'function',
        begin: '^' + BASIC_ATOM_RE + '\\s*\\(', end: '->',
        returnBegin: true,
        illegal: '\\(|#|//|/\\*|\\\\|:|;',
        contains: [
          PARAMS,
          hljs.inherit(hljs.TITLE_MODE, {begin: BASIC_ATOM_RE})
        ],
        starts: {
          end: ';|\\.',
          keywords: ERLANG_RESERVED,
          contains: BASIC_MODES
        }
      },
      COMMENT,
      {
        className: 'pp',
        begin: '^-', end: '\\.',
        relevance: 0,
        excludeEnd: true,
        returnBegin: true,
        lexemes: '-' + hljs.IDENT_RE,
        keywords:
          '-module -record -undef -export -ifdef -ifndef -author -copyright -doc -vsn ' +
          '-import -include -include_lib -compile -define -else -endif -file -behaviour ' +
          '-behavior -spec',
        contains: [PARAMS]
      },
      NUMBER,
      hljs.QUOTE_STRING_MODE,
      RECORD_ACCESS,
      VAR1, VAR2,
      TUPLE,
      {begin: /\.$/} // relevance booster
    ]
  };
});

hljs.registerLanguage('fix', function(hljs) {
  return {
    contains: [
    {
      begin: /[^\u2401\u0001]+/,
      end: /[\u2401\u0001]/,
      excludeEnd: true,
      returnBegin: true,
      returnEnd: false,
      contains: [
      {
        begin: /([^\u2401\u0001=]+)/,
        end: /=([^\u2401\u0001=]+)/,
        returnEnd: true,
        returnBegin: false,
        className: 'attribute'
      },
      {
        begin: /=/,
        end: /([\u2401\u0001])/,
        excludeEnd: true,
        excludeBegin: true,
        className: 'string'
      }]
    }],
    case_insensitive: true
  };
});

hljs.registerLanguage('fortran', function(hljs) {
  var PARAMS = {
    className: 'params',
    begin: '\\(', end: '\\)'
  };

  var F_KEYWORDS = {
    constant: '.False. .True.',
    type: 'integer real character complex logical dimension allocatable|10 parameter ' +
      'external implicit|10 none double precision assign intent optional pointer ' +
      'target in out common equivalence data',
    keyword: 'kind do while private call intrinsic where elsewhere ' +
      'type endtype endmodule endselect endinterface end enddo endif if forall endforall only contains default return stop then ' +
      'public subroutine|10 function program .and. .or. .not. .le. .eq. .ge. .gt. .lt. ' +
      'goto save else use module select case ' +
      'access blank direct exist file fmt form formatted iostat name named nextrec number opened rec recl sequential status unformatted unit ' +
      'continue format pause cycle exit ' +
      'c_null_char c_alert c_backspace c_form_feed flush wait decimal round iomsg ' +
      'synchronous nopass non_overridable pass protected volatile abstract extends import ' +
      'non_intrinsic value deferred generic final enumerator class associate bind enum ' +
      'c_int c_short c_long c_long_long c_signed_char c_size_t c_int8_t c_int16_t c_int32_t c_int64_t c_int_least8_t c_int_least16_t ' +
      'c_int_least32_t c_int_least64_t c_int_fast8_t c_int_fast16_t c_int_fast32_t c_int_fast64_t c_intmax_t C_intptr_t c_float c_double ' +
      'c_long_double c_float_complex c_double_complex c_long_double_complex c_bool c_char c_null_ptr c_null_funptr ' +
      'c_new_line c_carriage_return c_horizontal_tab c_vertical_tab iso_c_binding c_loc c_funloc c_associated  c_f_pointer ' +
      'c_ptr c_funptr iso_fortran_env character_storage_size error_unit file_storage_size input_unit iostat_end iostat_eor ' +
      'numeric_storage_size output_unit c_f_procpointer ieee_arithmetic ieee_support_underflow_control ' +
      'ieee_get_underflow_mode ieee_set_underflow_mode newunit contiguous recursive ' +
      'pad position action delim readwrite eor advance nml interface procedure namelist include sequence elemental pure',
    built_in: 'alog alog10 amax0 amax1 amin0 amin1 amod cabs ccos cexp clog csin csqrt dabs dacos dasin datan datan2 dcos dcosh ddim dexp dint ' +
      'dlog dlog10 dmax1 dmin1 dmod dnint dsign dsin dsinh dsqrt dtan dtanh float iabs idim idint idnint ifix isign max0 max1 min0 min1 sngl ' +
      'algama cdabs cdcos cdexp cdlog cdsin cdsqrt cqabs cqcos cqexp cqlog cqsin cqsqrt dcmplx dconjg derf derfc dfloat dgamma dimag dlgama ' +
      'iqint qabs qacos qasin qatan qatan2 qcmplx qconjg qcos qcosh qdim qerf qerfc qexp qgamma qimag qlgama qlog qlog10 qmax1 qmin1 qmod ' +
      'qnint qsign qsin qsinh qsqrt qtan qtanh abs acos aimag aint anint asin atan atan2 char cmplx conjg cos cosh exp ichar index int log ' +
      'log10 max min nint sign sin sinh sqrt tan tanh print write dim lge lgt lle llt mod nullify allocate deallocate ' +
      'adjustl adjustr all allocated any associated bit_size btest ceiling count cshift date_and_time digits dot_product ' +
      'eoshift epsilon exponent floor fraction huge iand ibclr ibits ibset ieor ior ishft ishftc lbound len_trim matmul ' +
      'maxexponent maxloc maxval merge minexponent minloc minval modulo mvbits nearest pack present product ' +
      'radix random_number random_seed range repeat reshape rrspacing scale scan selected_int_kind selected_real_kind ' +
      'set_exponent shape size spacing spread sum system_clock tiny transpose trim ubound unpack verify achar iachar transfer ' +
      'dble entry dprod cpu_time command_argument_count get_command get_command_argument get_environment_variable is_iostat_end ' +
      'ieee_arithmetic ieee_support_underflow_control ieee_get_underflow_mode ieee_set_underflow_mode ' +
      'is_iostat_eor move_alloc new_line selected_char_kind same_type_as extends_type_of'  +
      'acosh asinh atanh bessel_j0 bessel_j1 bessel_jn bessel_y0 bessel_y1 bessel_yn erf erfc erfc_scaled gamma log_gamma hypot norm2 ' +
      'atomic_define atomic_ref execute_command_line leadz trailz storage_size merge_bits ' +
      'bge bgt ble blt dshiftl dshiftr findloc iall iany iparity image_index lcobound ucobound maskl maskr ' +
      'num_images parity popcnt poppar shifta shiftl shiftr this_image'
  };
  return {
    case_insensitive: true,
    aliases: ['f90', 'f95'],
    keywords: F_KEYWORDS,
    illegal: /\/\*/,
    contains: [
      hljs.inherit(hljs.APOS_STRING_MODE, {className: 'string', relevance: 0}),
      hljs.inherit(hljs.QUOTE_STRING_MODE, {className: 'string', relevance: 0}),
      {
        className: 'function',
        beginKeywords: 'subroutine function program',
        illegal: '[${=\\n]',
        contains: [hljs.UNDERSCORE_TITLE_MODE, PARAMS]
      },
      hljs.COMMENT('!', '$', {relevance: 0}),
      {
        className: 'number',
        begin: '(?=\\b|\\+|\\-|\\.)(?=\\.\\d|\\d)(?:\\d+)?(?:\\.?\\d*)(?:[de][+-]?\\d+)?\\b\\.?',
        relevance: 0
      }
    ]
  };
});

hljs.registerLanguage('fsharp', function(hljs) {
  var TYPEPARAM = {
    begin: '<', end: '>',
    contains: [
      hljs.inherit(hljs.TITLE_MODE, {begin: /'[a-zA-Z0-9_]+/})
    ]
  };

  return {
    aliases: ['fs'],
    keywords:
      'abstract and as assert base begin class default delegate do done ' +
      'downcast downto elif else end exception extern false finally for ' +
      'fun function global if in inherit inline interface internal lazy let ' +
      'match member module mutable namespace new null of open or ' +
      'override private public rec return sig static struct then to ' +
      'true try type upcast use val void when while with yield',
    illegal: /\/\*/,
    contains: [
      {
        // monad builder keywords (matches before non-bang kws)
        className: 'keyword',
        begin: /\b(yield|return|let|do)!/
      },
      {
        className: 'string',
        begin: '@"', end: '"',
        contains: [{begin: '""'}]
      },
      {
        className: 'string',
        begin: '"""', end: '"""'
      },
      hljs.COMMENT('\\(\\*', '\\*\\)'),
      {
        className: 'class',
        beginKeywords: 'type', end: '\\(|=|$', excludeEnd: true,
        contains: [
          hljs.UNDERSCORE_TITLE_MODE,
          TYPEPARAM
        ]
      },
      {
        className: 'annotation',
        begin: '\\[<', end: '>\\]',
        relevance: 10
      },
      {
        className: 'attribute',
        begin: '\\B(\'[A-Za-z])\\b',
        contains: [hljs.BACKSLASH_ESCAPE]
      },
      hljs.C_LINE_COMMENT_MODE,
      hljs.inherit(hljs.QUOTE_STRING_MODE, {illegal: null}),
      hljs.C_NUMBER_MODE
    ]
  };
});

hljs.registerLanguage('gams', function (hljs) {
  var KEYWORDS =
    'abort acronym acronyms alias all and assign binary card diag display else1 eps eq equation equations file files ' +
    'for1 free ge gt if inf integer le loop lt maximizing minimizing model models na ne negative no not option ' +
    'options or ord parameter parameters positive prod putpage puttl repeat sameas scalar scalars semicont semiint ' +
    'set1 sets smax smin solve sos1 sos2 sum system table then until using variable variables while1 xor yes';

  return {
    aliases: ['gms'],
    case_insensitive: true,
    keywords: KEYWORDS,
    contains: [
      {
        className: 'section',
        beginKeywords: 'sets parameters variables equations',
        end: ';',
        contains: [
          {
            begin: '/',
            end: '/',
            contains: [hljs.NUMBER_MODE]
          }
        ]
      },
      {
        className: 'string',
        begin: '\\*{3}', end: '\\*{3}'
      },
      hljs.NUMBER_MODE,
      {
        className: 'number',
        begin: '\\$[a-zA-Z0-9]+'
      }
    ]
  };
});

hljs.registerLanguage('gcode', function(hljs) {
    var GCODE_IDENT_RE = '[A-Z_][A-Z0-9_.]*';
    var GCODE_CLOSE_RE = '\\%';
    var GCODE_KEYWORDS = {
        literal:
            '',
        built_in:
            '',
        keyword:
            'IF DO WHILE ENDWHILE CALL ENDIF SUB ENDSUB GOTO REPEAT ENDREPEAT ' +
            'EQ LT GT NE GE LE OR XOR'
    };
    var GCODE_START = {
        className: 'preprocessor',
        begin: '([O])([0-9]+)'
    };
    var GCODE_CODE = [
        hljs.C_LINE_COMMENT_MODE,
        hljs.C_BLOCK_COMMENT_MODE,
        hljs.COMMENT(/\(/, /\)/),
        hljs.inherit(hljs.C_NUMBER_MODE, {begin: '([-+]?([0-9]*\\.?[0-9]+\\.?))|' + hljs.C_NUMBER_RE}),
        hljs.inherit(hljs.APOS_STRING_MODE, {illegal: null}),
        hljs.inherit(hljs.QUOTE_STRING_MODE, {illegal: null}),
        {
            className: 'keyword',
            begin: '([G])([0-9]+\\.?[0-9]?)'
        },
        {
            className: 'title',
            begin: '([M])([0-9]+\\.?[0-9]?)'
        },
        {
            className: 'title',
            begin: '(VC|VS|#)',
            end: '(\\d+)'
        },
        {
            className: 'title',
            begin: '(VZOFX|VZOFY|VZOFZ)'
        },
        {
            className: 'built_in',
            begin: '(ATAN|ABS|ACOS|ASIN|SIN|COS|EXP|FIX|FUP|ROUND|LN|TAN)(\\[)',
            end: '([-+]?([0-9]*\\.?[0-9]+\\.?))(\\])'
        },
        {
            className: 'label',
            variants: [
                {
                    begin: 'N', end: '\\d+',
                    illegal: '\\W'
                }
            ]
        }
    ];

    return {
        aliases: ['nc'],
        // Some implementations (CNC controls) of G-code are interoperable with uppercase and lowercase letters seamlessly.
        // However, most prefer all uppercase and uppercase is customary.
        case_insensitive: true,
        lexemes: GCODE_IDENT_RE,
        keywords: GCODE_KEYWORDS,
        contains: [
            {
                className: 'preprocessor',
                begin: GCODE_CLOSE_RE
            },
            GCODE_START
        ].concat(GCODE_CODE)
    };
});

hljs.registerLanguage('gherkin', function (hljs) {
  return {
    aliases: ['feature'],
    keywords: 'Feature Background Ability Business\ Need Scenario Scenarios Scenario\ Outline Scenario\ Template Examples Given And Then But When',
    contains: [
      {
        className: 'keyword',
        begin: '\\*'
      },
      hljs.COMMENT('@[^@\r\n\t ]+', '$'),
      {
        begin: '\\|', end: '\\|\\w*$',
        contains: [
          {
            className: 'string',
            begin: '[^|]+'
          }
        ]
      },
      {
        className: 'variable',
        begin: '<', end: '>'
      },
      hljs.HASH_COMMENT_MODE,
      {
        className: 'string',
        begin: '"""', end: '"""'
      },
      hljs.QUOTE_STRING_MODE
    ]
  };
});

hljs.registerLanguage('glsl', function(hljs) {
  return {
    keywords: {
      keyword:
        'atomic_uint attribute bool break bvec2 bvec3 bvec4 case centroid coherent const continue default ' +
        'discard dmat2 dmat2x2 dmat2x3 dmat2x4 dmat3 dmat3x2 dmat3x3 dmat3x4 dmat4 dmat4x2 dmat4x3 ' +
        'dmat4x4 do double dvec2 dvec3 dvec4 else flat float for highp if iimage1D iimage1DArray ' +
        'iimage2D iimage2DArray iimage2DMS iimage2DMSArray iimage2DRect iimage3D iimageBuffer iimageCube ' +
        'iimageCubeArray image1D image1DArray image2D image2DArray image2DMS image2DMSArray image2DRect ' +
        'image3D imageBuffer imageCube imageCubeArray in inout int invariant isampler1D isampler1DArray ' +
        'isampler2D isampler2DArray isampler2DMS isampler2DMSArray isampler2DRect isampler3D isamplerBuffer ' +
        'isamplerCube isamplerCubeArray ivec2 ivec3 ivec4 layout lowp mat2 mat2x2 mat2x3 mat2x4 mat3 mat3x2 ' +
        'mat3x3 mat3x4 mat4 mat4x2 mat4x3 mat4x4 mediump noperspective out patch precision readonly restrict ' +
        'return sample sampler1D sampler1DArray sampler1DArrayShadow sampler1DShadow sampler2D sampler2DArray ' +
        'sampler2DArrayShadow sampler2DMS sampler2DMSArray sampler2DRect sampler2DRectShadow sampler2DShadow ' +
        'sampler3D samplerBuffer samplerCube samplerCubeArray samplerCubeArrayShadow samplerCubeShadow smooth ' +
        'struct subroutine switch uimage1D uimage1DArray uimage2D uimage2DArray uimage2DMS uimage2DMSArray ' +
        'uimage2DRect uimage3D uimageBuffer uimageCube uimageCubeArray uint uniform usampler1D usampler1DArray ' +
        'usampler2D usampler2DArray usampler2DMS usampler2DMSArray usampler2DRect usampler3D usamplerBuffer ' +
        'usamplerCube usamplerCubeArray uvec2 uvec3 uvec4 varying vec2 vec3 vec4 void volatile while writeonly',
      built_in:
        'gl_BackColor gl_BackLightModelProduct gl_BackLightProduct gl_BackMaterial ' +
        'gl_BackSecondaryColor gl_ClipDistance gl_ClipPlane gl_ClipVertex gl_Color ' +
        'gl_DepthRange gl_EyePlaneQ gl_EyePlaneR gl_EyePlaneS gl_EyePlaneT gl_Fog gl_FogCoord ' +
        'gl_FogFragCoord gl_FragColor gl_FragCoord gl_FragData gl_FragDepth gl_FrontColor ' +
        'gl_FrontFacing gl_FrontLightModelProduct gl_FrontLightProduct gl_FrontMaterial ' +
        'gl_FrontSecondaryColor gl_InstanceID gl_InvocationID gl_Layer gl_LightModel ' +
        'gl_LightSource gl_MaxAtomicCounterBindings gl_MaxAtomicCounterBufferSize ' +
        'gl_MaxClipDistances gl_MaxClipPlanes gl_MaxCombinedAtomicCounterBuffers ' +
        'gl_MaxCombinedAtomicCounters gl_MaxCombinedImageUniforms gl_MaxCombinedImageUnitsAndFragmentOutputs ' +
        'gl_MaxCombinedTextureImageUnits gl_MaxDrawBuffers gl_MaxFragmentAtomicCounterBuffers ' +
        'gl_MaxFragmentAtomicCounters gl_MaxFragmentImageUniforms gl_MaxFragmentInputComponents ' +
        'gl_MaxFragmentUniformComponents gl_MaxFragmentUniformVectors gl_MaxGeometryAtomicCounterBuffers ' +
        'gl_MaxGeometryAtomicCounters gl_MaxGeometryImageUniforms gl_MaxGeometryInputComponents ' +
        'gl_MaxGeometryOutputComponents gl_MaxGeometryOutputVertices gl_MaxGeometryTextureImageUnits ' +
        'gl_MaxGeometryTotalOutputComponents gl_MaxGeometryUniformComponents gl_MaxGeometryVaryingComponents ' +
        'gl_MaxImageSamples gl_MaxImageUnits gl_MaxLights gl_MaxPatchVertices gl_MaxProgramTexelOffset ' +
        'gl_MaxTessControlAtomicCounterBuffers gl_MaxTessControlAtomicCounters gl_MaxTessControlImageUniforms ' +
        'gl_MaxTessControlInputComponents gl_MaxTessControlOutputComponents gl_MaxTessControlTextureImageUnits ' +
        'gl_MaxTessControlTotalOutputComponents gl_MaxTessControlUniformComponents ' +
        'gl_MaxTessEvaluationAtomicCounterBuffers gl_MaxTessEvaluationAtomicCounters ' +
        'gl_MaxTessEvaluationImageUniforms gl_MaxTessEvaluationInputComponents gl_MaxTessEvaluationOutputComponents ' +
        'gl_MaxTessEvaluationTextureImageUnits gl_MaxTessEvaluationUniformComponents ' +
        'gl_MaxTessGenLevel gl_MaxTessPatchComponents gl_MaxTextureCoords gl_MaxTextureImageUnits ' +
        'gl_MaxTextureUnits gl_MaxVaryingComponents gl_MaxVaryingFloats gl_MaxVaryingVectors ' +
        'gl_MaxVertexAtomicCounterBuffers gl_MaxVertexAtomicCounters gl_MaxVertexAttribs ' +
        'gl_MaxVertexImageUniforms gl_MaxVertexOutputComponents gl_MaxVertexTextureImageUnits ' +
        'gl_MaxVertexUniformComponents gl_MaxVertexUniformVectors gl_MaxViewports gl_MinProgramTexelOffset'+
        'gl_ModelViewMatrix gl_ModelViewMatrixInverse gl_ModelViewMatrixInverseTranspose ' +
        'gl_ModelViewMatrixTranspose gl_ModelViewProjectionMatrix gl_ModelViewProjectionMatrixInverse ' +
        'gl_ModelViewProjectionMatrixInverseTranspose gl_ModelViewProjectionMatrixTranspose ' +
        'gl_MultiTexCoord0 gl_MultiTexCoord1 gl_MultiTexCoord2 gl_MultiTexCoord3 gl_MultiTexCoord4 ' +
        'gl_MultiTexCoord5 gl_MultiTexCoord6 gl_MultiTexCoord7 gl_Normal gl_NormalMatrix ' +
        'gl_NormalScale gl_ObjectPlaneQ gl_ObjectPlaneR gl_ObjectPlaneS gl_ObjectPlaneT gl_PatchVerticesIn ' +
        'gl_PerVertex gl_Point gl_PointCoord gl_PointSize gl_Position gl_PrimitiveID gl_PrimitiveIDIn ' +
        'gl_ProjectionMatrix gl_ProjectionMatrixInverse gl_ProjectionMatrixInverseTranspose ' +
        'gl_ProjectionMatrixTranspose gl_SampleID gl_SampleMask gl_SampleMaskIn gl_SamplePosition ' +
        'gl_SecondaryColor gl_TessCoord gl_TessLevelInner gl_TessLevelOuter gl_TexCoord gl_TextureEnvColor ' +
        'gl_TextureMatrixInverseTranspose gl_TextureMatrixTranspose gl_Vertex gl_VertexID ' +
        'gl_ViewportIndex gl_in gl_out EmitStreamVertex EmitVertex EndPrimitive EndStreamPrimitive ' +
        'abs acos acosh all any asin asinh atan atanh atomicCounter atomicCounterDecrement ' +
        'atomicCounterIncrement barrier bitCount bitfieldExtract bitfieldInsert bitfieldReverse ' +
        'ceil clamp cos cosh cross dFdx dFdy degrees determinant distance dot equal exp exp2 faceforward ' +
        'findLSB findMSB floatBitsToInt floatBitsToUint floor fma fract frexp ftransform fwidth greaterThan ' +
        'greaterThanEqual imageAtomicAdd imageAtomicAnd imageAtomicCompSwap imageAtomicExchange ' +
        'imageAtomicMax imageAtomicMin imageAtomicOr imageAtomicXor imageLoad imageStore imulExtended ' +
        'intBitsToFloat interpolateAtCentroid interpolateAtOffset interpolateAtSample inverse inversesqrt ' +
        'isinf isnan ldexp length lessThan lessThanEqual log log2 matrixCompMult max memoryBarrier ' +
        'min mix mod modf noise1 noise2 noise3 noise4 normalize not notEqual outerProduct packDouble2x32 ' +
        'packHalf2x16 packSnorm2x16 packSnorm4x8 packUnorm2x16 packUnorm4x8 pow radians reflect refract ' +
        'round roundEven shadow1D shadow1DLod shadow1DProj shadow1DProjLod shadow2D shadow2DLod shadow2DProj ' +
        'shadow2DProjLod sign sin sinh smoothstep sqrt step tan tanh texelFetch texelFetchOffset texture ' +
        'texture1D texture1DLod texture1DProj texture1DProjLod texture2D texture2DLod texture2DProj ' +
        'texture2DProjLod texture3D texture3DLod texture3DProj texture3DProjLod textureCube textureCubeLod ' +
        'textureGather textureGatherOffset textureGatherOffsets textureGrad textureGradOffset textureLod ' +
        'textureLodOffset textureOffset textureProj textureProjGrad textureProjGradOffset textureProjLod ' +
        'textureProjLodOffset textureProjOffset textureQueryLod textureSize transpose trunc uaddCarry ' +
        'uintBitsToFloat umulExtended unpackDouble2x32 unpackHalf2x16 unpackSnorm2x16 unpackSnorm4x8 ' +
        'unpackUnorm2x16 unpackUnorm4x8 usubBorrow gl_TextureMatrix gl_TextureMatrixInverse',
      literal: 'true false'
    },
    illegal: '"',
    contains: [
      hljs.C_LINE_COMMENT_MODE,
      hljs.C_BLOCK_COMMENT_MODE,
      hljs.C_NUMBER_MODE,
      {
        className: 'preprocessor',
        begin: '#', end: '$'
      }
    ]
  };
});

hljs.registerLanguage('go', function(hljs) {
  var GO_KEYWORDS = {
    keyword:
      'break default func interface select case map struct chan else goto package switch ' +
      'const fallthrough if range type continue for import return var go defer',
    constant:
       'true false iota nil',
    typename:
      'bool byte complex64 complex128 float32 float64 int8 int16 int32 int64 string uint8 ' +
      'uint16 uint32 uint64 int uint uintptr rune',
    built_in:
      'append cap close complex copy imag len make new panic print println real recover delete'
  };
  return {
    aliases: ["golang"],
    keywords: GO_KEYWORDS,
    illegal: '</',
    contains: [
      hljs.C_LINE_COMMENT_MODE,
      hljs.C_BLOCK_COMMENT_MODE,
      hljs.QUOTE_STRING_MODE,
      {
        className: 'string',
        begin: '\'', end: '[^\\\\]\''
      },
      {
        className: 'string',
        begin: '`', end: '`'
      },
      {
        className: 'number',
        begin: hljs.C_NUMBER_RE + '[dflsi]?',
        relevance: 0
      },
      hljs.C_NUMBER_MODE
    ]
  };
});

hljs.registerLanguage('golo', function(hljs) {
    return {
      keywords: {
        keyword:
          'println readln print import module function local return let var ' +
          'while for foreach times in case when match with break continue ' +
          'augment augmentation each find filter reduce ' +
          'if then else otherwise try catch finally raise throw orIfNull',
        typename:
          'DynamicObject|10 DynamicVariable struct Observable map set vector list array',
        literal:
          'true false null'
      },
      contains: [
        hljs.HASH_COMMENT_MODE,
        hljs.QUOTE_STRING_MODE,
        hljs.C_NUMBER_MODE,
        {
          className: 'annotation', begin: '@[A-Za-z]+'
        }
      ]
    }
});

hljs.registerLanguage('gradle', function(hljs) {
  return {
    case_insensitive: true,
    keywords: {
      keyword:
        'task project allprojects subprojects artifacts buildscript configurations ' +
        'dependencies repositories sourceSets description delete from into include ' +
        'exclude source classpath destinationDir includes options sourceCompatibility ' +
        'targetCompatibility group flatDir doLast doFirst flatten todir fromdir ant ' +
        'def abstract break case catch continue default do else extends final finally ' +
        'for if implements instanceof native new private protected public return static ' +
        'switch synchronized throw throws transient try volatile while strictfp package ' +
        'import false null super this true antlrtask checkstyle codenarc copy boolean ' +
        'byte char class double float int interface long short void compile runTime ' +
        'file fileTree abs any append asList asWritable call collect compareTo count ' +
        'div dump each eachByte eachFile eachLine every find findAll flatten getAt ' +
        'getErr getIn getOut getText grep immutable inject inspect intersect invokeMethods ' +
        'isCase join leftShift minus multiply newInputStream newOutputStream newPrintWriter ' +
        'newReader newWriter next plus pop power previous print println push putAt read ' +
        'readBytes readLines reverse reverseEach round size sort splitEachLine step subMap ' +
        'times toInteger toList tokenize upto waitForOrKill withPrintWriter withReader ' +
        'withStream withWriter withWriterAppend write writeLine'
    },
    contains: [
      hljs.C_LINE_COMMENT_MODE,
      hljs.C_BLOCK_COMMENT_MODE,
      hljs.APOS_STRING_MODE,
      hljs.QUOTE_STRING_MODE,
      hljs.NUMBER_MODE,
      hljs.REGEXP_MODE

    ]
  }
});

hljs.registerLanguage('groovy', function(hljs) {
    return {
        keywords: {
            typename: 'byte short char int long boolean float double void',
            literal : 'true false null',
            keyword:
            // groovy specific keywords
            'def as in assert trait ' +
            // common keywords with Java
            'super this abstract static volatile transient public private protected synchronized final ' +
            'class interface enum if else for while switch case break default continue ' +
            'throw throws try catch finally implements extends new import package return instanceof'
        },

        contains: [
            hljs.COMMENT(
                '/\\*\\*',
                '\\*/',
                {
                    relevance : 0,
                    contains : [{
                        className : 'doctag',
                        begin : '@[A-Za-z]+'
                    }]
                }
            ),
            hljs.C_LINE_COMMENT_MODE,
            hljs.C_BLOCK_COMMENT_MODE,
            {
                className: 'string',
                begin: '"""', end: '"""'
            },
            {
                className: 'string',
                begin: "'''", end: "'''"
            },
            {
                className: 'string',
                begin: "\\$/", end: "/\\$",
                relevance: 10
            },
            hljs.APOS_STRING_MODE,
            {
                className: 'regexp',
                begin: /~?\/[^\/\n]+\//,
                contains: [
                    hljs.BACKSLASH_ESCAPE
                ]
            },
            hljs.QUOTE_STRING_MODE,
            {
                className: 'shebang',
                begin: "^#!/usr/bin/env", end: '$',
                illegal: '\n'
            },
            hljs.BINARY_NUMBER_MODE,
            {
                className: 'class',
                beginKeywords: 'class interface trait enum', end: '{',
                illegal: ':',
                contains: [
                    {beginKeywords: 'extends implements'},
                    hljs.UNDERSCORE_TITLE_MODE,
                ]
            },
            hljs.C_NUMBER_MODE,
            {
                className: 'annotation', begin: '@[A-Za-z]+'
            },
            {
                // highlight map keys and named parameters as strings
                className: 'string', begin: /[^\?]{0}[A-Za-z0-9_$]+ *:/
            },
            {
                // catch middle element of the ternary operator
                // to avoid highlight it as a label, named parameter, or map key
                begin: /\?/, end: /\:/
            },
            {
                // highlight labeled statements
                className: 'label', begin: '^\\s*[A-Za-z0-9_$]+:',
                relevance: 0
            },
        ],
        illegal: /#/
    }
});

hljs.registerLanguage('haml', // TODO support filter tags like :javascript, support inline HTML
function(hljs) {
  return {
    case_insensitive: true,
    contains: [
      {
        className: 'doctype',
        begin: '^!!!( (5|1\\.1|Strict|Frameset|Basic|Mobile|RDFa|XML\\b.*))?$',
        relevance: 10
      },
      // FIXME these comments should be allowed to span indented lines
      hljs.COMMENT(
        '^\\s*(!=#|=#|-#|/).*$',
        false,
        {
          relevance: 0
        }
      ),
      {
        begin: '^\\s*(-|=|!=)(?!#)',
        starts: {
          end: '\\n',
          subLanguage: 'ruby'
        }
      },
      {
        className: 'tag',
        begin: '^\\s*%',
        contains: [
          {
            className: 'title',
            begin: '\\w+'
          },
          {
            className: 'value',
            begin: '[#\\.][\\w-]+'
          },
          {
            begin: '{\\s*',
            end: '\\s*}',
            excludeEnd: true,
            contains: [
              {
                //className: 'attribute',
                begin: ':\\w+\\s*=>',
                end: ',\\s+',
                returnBegin: true,
                endsWithParent: true,
                contains: [
                  {
                    className: 'symbol',
                    begin: ':\\w+'
                  },
                  hljs.APOS_STRING_MODE,
                  hljs.QUOTE_STRING_MODE,
                  {
                    begin: '\\w+',
                    relevance: 0
                  }
                ]
              }
            ]
          },
          {
            begin: '\\(\\s*',
            end: '\\s*\\)',
            excludeEnd: true,
            contains: [
              {
                //className: 'attribute',
                begin: '\\w+\\s*=',
                end: '\\s+',
                returnBegin: true,
                endsWithParent: true,
                contains: [
                  {
                    className: 'attribute',
                    begin: '\\w+',
                    relevance: 0
                  },
                  hljs.APOS_STRING_MODE,
                  hljs.QUOTE_STRING_MODE,
                  {
                    begin: '\\w+',
                    relevance: 0
                  }
                ]
              }
            ]
          }
        ]
      },
      {
        className: 'bullet',
        begin: '^\\s*[=~]\\s*',
        relevance: 0
      },
      {
        begin: '#{',
        starts: {
          end: '}',
          subLanguage: 'ruby'
        }
      }
    ]
  };
});

hljs.registerLanguage('handlebars', function(hljs) {
  var EXPRESSION_KEYWORDS = 'each in with if else unless bindattr action collection debugger log outlet template unbound view yield';
  return {
    aliases: ['hbs', 'html.hbs', 'html.handlebars'],
    case_insensitive: true,
    subLanguage: 'xml',
    contains: [
      {
        className: 'expression',
        begin: '{{', end: '}}',
        contains: [
          {
            className: 'begin-block', begin: '\#[a-zA-Z\-\ \.]+',
            keywords: EXPRESSION_KEYWORDS
          },
          {
            className: 'string',
            begin: '"', end: '"'
          },
          {
            className: 'end-block', begin: '\\\/[a-zA-Z\-\ \.]+',
            keywords: EXPRESSION_KEYWORDS
          },
          {
            className: 'variable', begin: '[a-zA-Z\-\.]+',
            keywords: EXPRESSION_KEYWORDS
          }
        ]
      }
    ]
  };
});

hljs.registerLanguage('haskell', function(hljs) {
  var COMMENT_MODES = [
    hljs.COMMENT('--', '$'),
    hljs.COMMENT(
      '{-',
      '-}',
      {
        contains: ['self']
      }
    )
  ];

  var PRAGMA = {
    className: 'pragma',
    begin: '{-#', end: '#-}'
  };

  var PREPROCESSOR = {
    className: 'preprocessor',
    begin: '^#', end: '$'
  };

  var CONSTRUCTOR = {
    className: 'type',
    begin: '\\b[A-Z][\\w\']*', // TODO: other constructors (build-in, infix).
    relevance: 0
  };

  var LIST = {
    className: 'container',
    begin: '\\(', end: '\\)',
    illegal: '"',
    contains: [
      PRAGMA,
      PREPROCESSOR,
      {className: 'type', begin: '\\b[A-Z][\\w]*(\\((\\.\\.|,|\\w+)\\))?'},
      hljs.inherit(hljs.TITLE_MODE, {begin: '[_a-z][\\w\']*'})
    ].concat(COMMENT_MODES)
  };

  var RECORD = {
    className: 'container',
    begin: '{', end: '}',
    contains: LIST.contains
  };

  return {
    aliases: ['hs'],
    keywords:
      'let in if then else case of where do module import hiding ' +
      'qualified type data newtype deriving class instance as default ' +
      'infix infixl infixr foreign export ccall stdcall cplusplus ' +
      'jvm dotnet safe unsafe family forall mdo proc rec',
    contains: [

      // Top-level constructions.

      {
        className: 'module',
        begin: '\\bmodule\\b', end: 'where',
        keywords: 'module where',
        contains: [LIST].concat(COMMENT_MODES),
        illegal: '\\W\\.|;'
      },
      {
        className: 'import',
        begin: '\\bimport\\b', end: '$',
        keywords: 'import|0 qualified as hiding',
        contains: [LIST].concat(COMMENT_MODES),
        illegal: '\\W\\.|;'
      },

      {
        className: 'class',
        begin: '^(\\s*)?(class|instance)\\b', end: 'where',
        keywords: 'class family instance where',
        contains: [CONSTRUCTOR, LIST].concat(COMMENT_MODES)
      },
      {
        className: 'typedef',
        begin: '\\b(data|(new)?type)\\b', end: '$',
        keywords: 'data family type newtype deriving',
        contains: [PRAGMA, CONSTRUCTOR, LIST, RECORD].concat(COMMENT_MODES)
      },
      {
        className: 'default',
        beginKeywords: 'default', end: '$',
        contains: [CONSTRUCTOR, LIST].concat(COMMENT_MODES)
      },
      {
        className: 'infix',
        beginKeywords: 'infix infixl infixr', end: '$',
        contains: [hljs.C_NUMBER_MODE].concat(COMMENT_MODES)
      },
      {
        className: 'foreign',
        begin: '\\bforeign\\b', end: '$',
        keywords: 'foreign import export ccall stdcall cplusplus jvm ' +
                  'dotnet safe unsafe',
        contains: [CONSTRUCTOR, hljs.QUOTE_STRING_MODE].concat(COMMENT_MODES)
      },
      {
        className: 'shebang',
        begin: '#!\\/usr\\/bin\\/env\ runhaskell', end: '$'
      },

      // "Whitespaces".

      PRAGMA,
      PREPROCESSOR,

      // Literals and names.

      // TODO: characters.
      hljs.QUOTE_STRING_MODE,
      hljs.C_NUMBER_MODE,
      CONSTRUCTOR,
      hljs.inherit(hljs.TITLE_MODE, {begin: '^[_a-z][\\w\']*'}),

      {begin: '->|<-'} // No markup, relevance booster
    ].concat(COMMENT_MODES)
  };
});

hljs.registerLanguage('haxe', function(hljs) {
  var IDENT_RE = '[a-zA-Z_$][a-zA-Z0-9_$]*';
  var IDENT_FUNC_RETURN_TYPE_RE = '([*]|[a-zA-Z_$][a-zA-Z0-9_$]*)';

  return {
    aliases: ['hx'],
    keywords: {
      keyword: 'break callback case cast catch class continue default do dynamic else enum extends extern ' +
    'for function here if implements import in inline interface never new override package private ' +
    'public return static super switch this throw trace try typedef untyped using var while',
      literal: 'true false null'
    },
    contains: [
      hljs.APOS_STRING_MODE,
      hljs.QUOTE_STRING_MODE,
      hljs.C_LINE_COMMENT_MODE,
      hljs.C_BLOCK_COMMENT_MODE,
      hljs.C_NUMBER_MODE,
      {
        className: 'class',
        beginKeywords: 'class interface', end: '{', excludeEnd: true,
        contains: [
          {
            beginKeywords: 'extends implements'
          },
          hljs.TITLE_MODE
        ]
      },
      {
        className: 'preprocessor',
        begin: '#', end: '$',
        keywords: 'if else elseif end error'
      },
      {
        className: 'function',
        beginKeywords: 'function', end: '[{;]', excludeEnd: true,
        illegal: '\\S',
        contains: [
          hljs.TITLE_MODE,
          {
            className: 'params',
            begin: '\\(', end: '\\)',
            contains: [
              hljs.APOS_STRING_MODE,
              hljs.QUOTE_STRING_MODE,
              hljs.C_LINE_COMMENT_MODE,
              hljs.C_BLOCK_COMMENT_MODE
            ]
          },
          {
            className: 'type',
            begin: ':',
            end: IDENT_FUNC_RETURN_TYPE_RE,
            relevance: 10
          }
        ]
      }
    ]
  };
});

hljs.registerLanguage('http', function(hljs) {
  return {
    aliases: ['https'],
    illegal: '\\S',
    contains: [
      {
        className: 'status',
        begin: '^HTTP/[0-9\\.]+', end: '$',
        contains: [{className: 'number', begin: '\\b\\d{3}\\b'}]
      },
      {
        className: 'request',
        begin: '^[A-Z]+ (.*?) HTTP/[0-9\\.]+$', returnBegin: true, end: '$',
        contains: [
          {
            className: 'string',
            begin: ' ', end: ' ',
            excludeBegin: true, excludeEnd: true
          }
        ]
      },
      {
        className: 'attribute',
        begin: '^\\w', end: ': ', excludeEnd: true,
        illegal: '\\n|\\s|=',
        starts: {className: 'string', end: '$'}
      },
      {
        begin: '\\n\\n',
        starts: {subLanguage: [], endsWithParent: true}
      }
    ]
  };
});

hljs.registerLanguage('inform7', function(hljs) {
  var START_BRACKET = '\\[';
  var END_BRACKET = '\\]';
  return {
    aliases: ['i7'],
    case_insensitive: true,
    keywords: {
      // Some keywords more or less unique to I7, for relevance.
      keyword:
        // kind:
        'thing room person man woman animal container ' +
        'supporter backdrop door ' +
        // characteristic:
        'scenery open closed locked inside gender ' +
        // verb:
        'is are say understand ' +
        // misc keyword:
        'kind of rule'
    },
    contains: [
      {
        className: 'string',
        begin: '"', end: '"',
        relevance: 0,
        contains: [
          {
            className: 'subst',
            begin: START_BRACKET, end: END_BRACKET
          }
        ]
      },
      {
        className: 'title',
        begin: /^(Volume|Book|Part|Chapter|Section|Table)\b/,
        end: '$'
      },
      {
        // Rule definition
        // This is here for relevance.
        begin: /^(Check|Carry out|Report|Instead of|To|Rule|When|Before|After)\b/,
        end: ':',
        contains: [
          {
            //Rule name
            begin: '\\b\\(This',
            end: '\\)'
          }
        ]
      },
      {
        className: 'comment',
        begin: START_BRACKET, end: END_BRACKET,
        contains: ['self']
      }
    ]
  };
});

hljs.registerLanguage('ini', function(hljs) {
  var STRING = {
    className: "string",
    contains: [hljs.BACKSLASH_ESCAPE],
    variants: [
      {
        begin: "'''", end: "'''",
        relevance: 10
      }, {
        begin: '"""', end: '"""',
        relevance: 10
      }, {
        begin: '"', end: '"'
      }, {
        begin: "'", end: "'"
      }
    ]
  };
  return {
    aliases: ['toml'],
    case_insensitive: true,
    illegal: /\S/,
    contains: [
      hljs.COMMENT(';', '$'),
      hljs.HASH_COMMENT_MODE,
      {
        className: 'title',
        begin: /^\s*\[+/, end: /\]+/
      },
      {
        className: 'setting',
        begin: /^[a-z0-9\[\]_-]+\s*=\s*/, end: '$',
        contains: [
          {
            className: 'value',
            endsWithParent: true,
            keywords: 'on off true false yes no',
            contains: [
              {
                className: 'variable',
                variants: [
                  {begin: /\$[\w\d"][\w\d_]*/},
                  {begin: /\$\{(.*?)}/}
                ]
              },
              STRING,
              {
                className: 'number',
                begin: /([\+\-]+)?[\d]+_[\d_]+/
              },
              hljs.NUMBER_MODE
            ],
            relevance: 0
          }
        ]
      }
    ]
  };
});

hljs.registerLanguage('irpf90', function(hljs) {
  var PARAMS = {
    className: 'params',
    begin: '\\(', end: '\\)'
  };

  var F_KEYWORDS = {
    constant: '.False. .True.',
    type: 'integer real character complex logical dimension allocatable|10 parameter ' +
      'external implicit|10 none double precision assign intent optional pointer ' +
      'target in out common equivalence data',
    keyword: 'kind do while private call intrinsic where elsewhere ' +
      'type endtype endmodule endselect endinterface end enddo endif if forall endforall only contains default return stop then ' +
      'public subroutine|10 function program .and. .or. .not. .le. .eq. .ge. .gt. .lt. ' +
      'goto save else use module select case ' +
      'access blank direct exist file fmt form formatted iostat name named nextrec number opened rec recl sequential status unformatted unit ' +
      'continue format pause cycle exit ' +
      'c_null_char c_alert c_backspace c_form_feed flush wait decimal round iomsg ' +
      'synchronous nopass non_overridable pass protected volatile abstract extends import ' +
      'non_intrinsic value deferred generic final enumerator class associate bind enum ' +
      'c_int c_short c_long c_long_long c_signed_char c_size_t c_int8_t c_int16_t c_int32_t c_int64_t c_int_least8_t c_int_least16_t ' +
      'c_int_least32_t c_int_least64_t c_int_fast8_t c_int_fast16_t c_int_fast32_t c_int_fast64_t c_intmax_t C_intptr_t c_float c_double ' +
      'c_long_double c_float_complex c_double_complex c_long_double_complex c_bool c_char c_null_ptr c_null_funptr ' +
      'c_new_line c_carriage_return c_horizontal_tab c_vertical_tab iso_c_binding c_loc c_funloc c_associated  c_f_pointer ' +
      'c_ptr c_funptr iso_fortran_env character_storage_size error_unit file_storage_size input_unit iostat_end iostat_eor ' +
      'numeric_storage_size output_unit c_f_procpointer ieee_arithmetic ieee_support_underflow_control ' +
      'ieee_get_underflow_mode ieee_set_underflow_mode newunit contiguous recursive ' +
      'pad position action delim readwrite eor advance nml interface procedure namelist include sequence elemental pure ' +
      // IRPF90 special keywords
      'begin_provider &begin_provider end_provider begin_shell end_shell begin_template end_template subst assert touch ' +
      'soft_touch provide no_dep free irp_if irp_else irp_endif irp_write irp_read',
    built_in: 'alog alog10 amax0 amax1 amin0 amin1 amod cabs ccos cexp clog csin csqrt dabs dacos dasin datan datan2 dcos dcosh ddim dexp dint ' +
      'dlog dlog10 dmax1 dmin1 dmod dnint dsign dsin dsinh dsqrt dtan dtanh float iabs idim idint idnint ifix isign max0 max1 min0 min1 sngl ' +
      'algama cdabs cdcos cdexp cdlog cdsin cdsqrt cqabs cqcos cqexp cqlog cqsin cqsqrt dcmplx dconjg derf derfc dfloat dgamma dimag dlgama ' +
      'iqint qabs qacos qasin qatan qatan2 qcmplx qconjg qcos qcosh qdim qerf qerfc qexp qgamma qimag qlgama qlog qlog10 qmax1 qmin1 qmod ' +
      'qnint qsign qsin qsinh qsqrt qtan qtanh abs acos aimag aint anint asin atan atan2 char cmplx conjg cos cosh exp ichar index int log ' +
      'log10 max min nint sign sin sinh sqrt tan tanh print write dim lge lgt lle llt mod nullify allocate deallocate ' +
      'adjustl adjustr all allocated any associated bit_size btest ceiling count cshift date_and_time digits dot_product ' +
      'eoshift epsilon exponent floor fraction huge iand ibclr ibits ibset ieor ior ishft ishftc lbound len_trim matmul ' +
      'maxexponent maxloc maxval merge minexponent minloc minval modulo mvbits nearest pack present product ' +
      'radix random_number random_seed range repeat reshape rrspacing scale scan selected_int_kind selected_real_kind ' +
      'set_exponent shape size spacing spread sum system_clock tiny transpose trim ubound unpack verify achar iachar transfer ' +
      'dble entry dprod cpu_time command_argument_count get_command get_command_argument get_environment_variable is_iostat_end ' +
      'ieee_arithmetic ieee_support_underflow_control ieee_get_underflow_mode ieee_set_underflow_mode ' +
      'is_iostat_eor move_alloc new_line selected_char_kind same_type_as extends_type_of'  +
      'acosh asinh atanh bessel_j0 bessel_j1 bessel_jn bessel_y0 bessel_y1 bessel_yn erf erfc erfc_scaled gamma log_gamma hypot norm2 ' +
      'atomic_define atomic_ref execute_command_line leadz trailz storage_size merge_bits ' +
      'bge bgt ble blt dshiftl dshiftr findloc iall iany iparity image_index lcobound ucobound maskl maskr ' +
      'num_images parity popcnt poppar shifta shiftl shiftr this_image ' +
      // IRPF90 special built_ins
      'IRP_ALIGN irp_here'
  };
  return {
    case_insensitive: true,
    keywords: F_KEYWORDS,
    illegal: /\/\*/,
    contains: [
      hljs.inherit(hljs.APOS_STRING_MODE, {className: 'string', relevance: 0}),
      hljs.inherit(hljs.QUOTE_STRING_MODE, {className: 'string', relevance: 0}),
      {
        className: 'function',
        beginKeywords: 'subroutine function program',
        illegal: '[${=\\n]',
        contains: [hljs.UNDERSCORE_TITLE_MODE, PARAMS]
      },
      hljs.COMMENT('!', '$', {relevance: 0}),
      hljs.COMMENT('begin_doc', 'end_doc', {relevance: 10}),
      {
        className: 'number',
        begin: '(?=\\b|\\+|\\-|\\.)(?=\\.\\d|\\d)(?:\\d+)?(?:\\.?\\d*)(?:[de][+-]?\\d+)?\\b\\.?',
        relevance: 0
      }
    ]
  };
});

hljs.registerLanguage('java', function(hljs) {
  var GENERIC_IDENT_RE = hljs.UNDERSCORE_IDENT_RE + '(<' + hljs.UNDERSCORE_IDENT_RE + '>)?';
  var KEYWORDS =
    'false synchronized int abstract float private char boolean static null if const ' +
    'for true while long strictfp finally protected import native final void ' +
    'enum else break transient catch instanceof byte super volatile case assert short ' +
    'package default double public try this switch continue throws protected public private';

  // https://docs.oracle.com/javase/7/docs/technotes/guides/language/underscores-literals.html
  var JAVA_NUMBER_RE = '\\b' +
    '(' +
      '0[bB]([01]+[01_]+[01]+|[01]+)' + // 0b...
      '|' +
      '0[xX]([a-fA-F0-9]+[a-fA-F0-9_]+[a-fA-F0-9]+|[a-fA-F0-9]+)' + // 0x...
      '|' +
      '(' +
        '([\\d]+[\\d_]+[\\d]+|[\\d]+)(\\.([\\d]+[\\d_]+[\\d]+|[\\d]+))?' +
        '|' +
        '\\.([\\d]+[\\d_]+[\\d]+|[\\d]+)' +
      ')' +
      '([eE][-+]?\\d+)?' + // octal, decimal, float
    ')' +
    '[lLfF]?';
  var JAVA_NUMBER_MODE = {
    className: 'number',
    begin: JAVA_NUMBER_RE,
    relevance: 0
  };

  return {
    aliases: ['jsp'],
    keywords: KEYWORDS,
    illegal: /<\/|#/,
    contains: [
      hljs.COMMENT(
        '/\\*\\*',
        '\\*/',
        {
          relevance : 0,
          contains : [{
            className : 'doctag',
            begin : '@[A-Za-z]+'
          }]
        }
      ),
      hljs.C_LINE_COMMENT_MODE,
      hljs.C_BLOCK_COMMENT_MODE,
      hljs.APOS_STRING_MODE,
      hljs.QUOTE_STRING_MODE,
      {
        className: 'class',
        beginKeywords: 'class interface', end: /[{;=]/, excludeEnd: true,
        keywords: 'class interface',
        illegal: /[:"\[\]]/,
        contains: [
          {beginKeywords: 'extends implements'},
          hljs.UNDERSCORE_TITLE_MODE
        ]
      },
      {
        // Expression keywords prevent 'keyword Name(...)' from being
        // recognized as a function definition
        beginKeywords: 'new throw return else',
        relevance: 0
      },
      {
        className: 'function',
        begin: '(' + GENERIC_IDENT_RE + '\\s+)+' + hljs.UNDERSCORE_IDENT_RE + '\\s*\\(', returnBegin: true, end: /[{;=]/,
        excludeEnd: true,
        keywords: KEYWORDS,
        contains: [
          {
            begin: hljs.UNDERSCORE_IDENT_RE + '\\s*\\(', returnBegin: true,
            relevance: 0,
            contains: [hljs.UNDERSCORE_TITLE_MODE]
          },
          {
            className: 'params',
            begin: /\(/, end: /\)/,
            keywords: KEYWORDS,
            relevance: 0,
            contains: [
              hljs.APOS_STRING_MODE,
              hljs.QUOTE_STRING_MODE,
              hljs.C_NUMBER_MODE,
              hljs.C_BLOCK_COMMENT_MODE
            ]
          },
          hljs.C_LINE_COMMENT_MODE,
          hljs.C_BLOCK_COMMENT_MODE
        ]
      },
      JAVA_NUMBER_MODE,
      {
        className: 'annotation', begin: '@[A-Za-z]+'
      }
    ]
  };
});

hljs.registerLanguage('javascript', function(hljs) {
  return {
    aliases: ['js'],
    keywords: {
      keyword:
        'in of if for while finally var new function do return void else break catch ' +
        'instanceof with throw case default try this switch continue typeof delete ' +
        'let yield const export super debugger as async await',
      literal:
        'true false null undefined NaN Infinity',
      built_in:
        'eval isFinite isNaN parseFloat parseInt decodeURI decodeURIComponent ' +
        'encodeURI encodeURIComponent escape unescape Object Function Boolean Error ' +
        'EvalError InternalError RangeError ReferenceError StopIteration SyntaxError ' +
        'TypeError URIError Number Math Date String RegExp Array Float32Array ' +
        'Float64Array Int16Array Int32Array Int8Array Uint16Array Uint32Array ' +
        'Uint8Array Uint8ClampedArray ArrayBuffer DataView JSON Intl arguments require ' +
        'module console window document Symbol Set Map WeakSet WeakMap Proxy Reflect ' +
        'Promise'
    },
    contains: [
      {
        className: 'pi',
        relevance: 10,
        begin: /^\s*['"]use (strict|asm)['"]/
      },
      hljs.APOS_STRING_MODE,
      hljs.QUOTE_STRING_MODE,
      { // template string
        className: 'string',
        begin: '`', end: '`',
        contains: [
          hljs.BACKSLASH_ESCAPE,
          {
            className: 'subst',
            begin: '\\$\\{', end: '\\}'
          }
        ]
      },
      hljs.C_LINE_COMMENT_MODE,
      hljs.C_BLOCK_COMMENT_MODE,
      {
        className: 'number',
        variants: [
          { begin: '\\b(0[bB][01]+)' },
          { begin: '\\b(0[oO][0-7]+)' },
          { begin: hljs.C_NUMBER_RE }
        ],
        relevance: 0
      },
      { // "value" container
        begin: '(' + hljs.RE_STARTERS_RE + '|\\b(case|return|throw)\\b)\\s*',
        keywords: 'return throw case',
        contains: [
          hljs.C_LINE_COMMENT_MODE,
          hljs.C_BLOCK_COMMENT_MODE,
          hljs.REGEXP_MODE,
          { // E4X / JSX
            begin: /</, end: />\s*[);\]]/,
            relevance: 0,
            subLanguage: 'xml'
          }
        ],
        relevance: 0
      },
      {
        className: 'function',
        beginKeywords: 'function', end: /\{/, excludeEnd: true,
        contains: [
          hljs.inherit(hljs.TITLE_MODE, {begin: /[A-Za-z$_][0-9A-Za-z$_]*/}),
          {
            className: 'params',
            begin: /\(/, end: /\)/,
            excludeBegin: true,
            excludeEnd: true,
            contains: [
              hljs.C_LINE_COMMENT_MODE,
              hljs.C_BLOCK_COMMENT_MODE
            ]
          }
        ],
        illegal: /\[|%/
      },
      {
        begin: /\$[(.]/ // relevance booster for a pattern common to JS libs: `$(something)` and `$.something`
      },
      {
        begin: '\\.' + hljs.IDENT_RE, relevance: 0 // hack: prevents detection of keywords after dots
      },
      // ECMAScript 6 modules import
      {
        beginKeywords: 'import', end: '[;$]',
        keywords: 'import from as',
        contains: [
          hljs.APOS_STRING_MODE,
          hljs.QUOTE_STRING_MODE
        ]
      },
      { // ES6 class
        className: 'class',
        beginKeywords: 'class', end: /[{;=]/, excludeEnd: true,
        illegal: /[:"\[\]]/,
        contains: [
          {beginKeywords: 'extends'},
          hljs.UNDERSCORE_TITLE_MODE
        ]
      }
    ],
    illegal: /#/
  };
});

hljs.registerLanguage('json', function(hljs) {
  var LITERALS = {literal: 'true false null'};
  var TYPES = [
    hljs.QUOTE_STRING_MODE,
    hljs.C_NUMBER_MODE
  ];
  var VALUE_CONTAINER = {
    className: 'value',
    end: ',', endsWithParent: true, excludeEnd: true,
    contains: TYPES,
    keywords: LITERALS
  };
  var OBJECT = {
    begin: '{', end: '}',
    contains: [
      {
        className: 'attribute',
        begin: '\\s*"', end: '"\\s*:\\s*', excludeBegin: true, excludeEnd: true,
        contains: [hljs.BACKSLASH_ESCAPE],
        illegal: '\\n',
        starts: VALUE_CONTAINER
      }
    ],
    illegal: '\\S'
  };
  var ARRAY = {
    begin: '\\[', end: '\\]',
    contains: [hljs.inherit(VALUE_CONTAINER, {className: null})], // inherit is also a workaround for a bug that makes shared modes with endsWithParent compile only the ending of one of the parents
    illegal: '\\S'
  };
  TYPES.splice(TYPES.length, 0, OBJECT, ARRAY);
  return {
    contains: TYPES,
    keywords: LITERALS,
    illegal: '\\S'
  };
});

hljs.registerLanguage('julia', function(hljs) {
  // Since there are numerous special names in Julia, it is too much trouble
  // to maintain them by hand. Hence these names (i.e. keywords, literals and
  // built-ins) are automatically generated from Julia (v0.3.0) itself through
  // following scripts for each.

  var KEYWORDS = {
    // # keyword generator
    // println("\"in\",")
    // for kw in Base.REPLCompletions.complete_keyword("")
    //     println("\"$kw\",")
    // end
    keyword:
      'in abstract baremodule begin bitstype break catch ccall const continue do else elseif end export ' +
      'finally for function global if immutable import importall let local macro module quote return try type ' +
      'typealias using while',

    // # literal generator
    // println("\"true\",\n\"false\"")
    // for name in Base.REPLCompletions.completions("", 0)[1]
    //     try
    //         s = symbol(name)
    //         v = eval(s)
    //         if !isa(v, Function) &&
    //            !isa(v, DataType) &&
    //            !issubtype(typeof(v), Tuple) &&
    //            !isa(v, UnionType) &&
    //            !isa(v, Module) &&
    //            !isa(v, TypeConstructor) &&
    //            !isa(v, Colon)
    //             println("\"$name\",")
    //         end
    //     end
    // end
    literal:
      'true false ANY ARGS CPU_CORES C_NULL DL_LOAD_PATH DevNull ENDIAN_BOM ENV I|0 Inf Inf16 Inf32 ' +
      'InsertionSort JULIA_HOME LOAD_PATH MS_ASYNC MS_INVALIDATE MS_SYNC MergeSort NaN NaN16 NaN32 OS_NAME QuickSort ' +
      'RTLD_DEEPBIND RTLD_FIRST RTLD_GLOBAL RTLD_LAZY RTLD_LOCAL RTLD_NODELETE RTLD_NOLOAD RTLD_NOW RoundDown ' +
      'RoundFromZero RoundNearest RoundToZero RoundUp STDERR STDIN STDOUT VERSION WORD_SIZE catalan cglobal e|0 eu|0 ' +
      'eulergamma golden im nothing pi γ π φ',

    // # built_in generator:
    // for name in Base.REPLCompletions.completions("", 0)[1]
    //     try
    //         v = eval(symbol(name))
    //         if isa(v, DataType)
    //             println("\"$name\",")
    //         end
    //     end
    // end
    built_in:
      'ASCIIString AbstractArray AbstractRNG AbstractSparseArray Any ArgumentError Array Associative Base64Pipe ' +
      'Bidiagonal BigFloat BigInt BitArray BitMatrix BitVector Bool BoundsError Box CFILE Cchar Cdouble Cfloat Char ' +
      'CharString Cint Clong Clonglong ClusterManager Cmd Coff_t Colon Complex Complex128 Complex32 Complex64 ' +
      'Condition Cptrdiff_t Cshort Csize_t Cssize_t Cuchar Cuint Culong Culonglong Cushort Cwchar_t DArray DataType ' +
      'DenseArray Diagonal Dict DimensionMismatch DirectIndexString Display DivideError DomainError EOFError ' +
      'EachLine Enumerate ErrorException Exception Expr Factorization FileMonitor FileOffset Filter Float16 Float32 ' +
      'Float64 FloatRange FloatingPoint Function GetfieldNode GotoNode Hermitian IO IOBuffer IOStream IPv4 IPv6 ' +
      'InexactError Int Int128 Int16 Int32 Int64 Int8 IntSet Integer InterruptException IntrinsicFunction KeyError ' +
      'LabelNode LambdaStaticData LineNumberNode LoadError LocalProcess MIME MathConst MemoryError MersenneTwister ' +
      'Method MethodError MethodTable Module NTuple NewvarNode Nothing Number ObjectIdDict OrdinalRange ' +
      'OverflowError ParseError PollingFileWatcher ProcessExitedException ProcessGroup Ptr QuoteNode Range Range1 ' +
      'Ranges Rational RawFD Real Regex RegexMatch RemoteRef RepString RevString RopeString RoundingMode Set ' +
      'SharedArray Signed SparseMatrixCSC StackOverflowError Stat StatStruct StepRange String SubArray SubString ' +
      'SymTridiagonal Symbol SymbolNode Symmetric SystemError Task TextDisplay Timer TmStruct TopNode Triangular ' +
      'Tridiagonal Type TypeConstructor TypeError TypeName TypeVar UTF16String UTF32String UTF8String UdpSocket ' +
      'Uint Uint128 Uint16 Uint32 Uint64 Uint8 UndefRefError UndefVarError UniformScaling UnionType UnitRange ' +
      'Unsigned Vararg VersionNumber WString WeakKeyDict WeakRef Woodbury Zip'
  };

  // ref: http://julia.readthedocs.org/en/latest/manual/variables/#allowed-variable-names
  var VARIABLE_NAME_RE = "[A-Za-z_\\u00A1-\\uFFFF][A-Za-z_0-9\\u00A1-\\uFFFF]*";

  // placeholder for recursive self-reference
  var DEFAULT = { lexemes: VARIABLE_NAME_RE, keywords: KEYWORDS };

  var TYPE_ANNOTATION = {
    className: "type-annotation",
    begin: /::/
  };

  var SUBTYPE = {
    className: "subtype",
    begin: /<:/
  };

  // ref: http://julia.readthedocs.org/en/latest/manual/integers-and-floating-point-numbers/
  var NUMBER = {
    className: "number",
    // supported numeric literals:
    //  * binary literal (e.g. 0x10)
    //  * octal literal (e.g. 0o76543210)
    //  * hexadecimal literal (e.g. 0xfedcba876543210)
    //  * hexadecimal floating point literal (e.g. 0x1p0, 0x1.2p2)
    //  * decimal literal (e.g. 9876543210, 100_000_000)
    //  * floating pointe literal (e.g. 1.2, 1.2f, .2, 1., 1.2e10, 1.2e-10)
    begin: /(\b0x[\d_]*(\.[\d_]*)?|0x\.\d[\d_]*)p[-+]?\d+|\b0[box][a-fA-F0-9][a-fA-F0-9_]*|(\b\d[\d_]*(\.[\d_]*)?|\.\d[\d_]*)([eEfF][-+]?\d+)?/,
    relevance: 0
  };

  var CHAR = {
    className: "char",
    begin: /'(.|\\[xXuU][a-zA-Z0-9]+)'/
  };

  var INTERPOLATION = {
    className: 'subst',
    begin: /\$\(/, end: /\)/,
    keywords: KEYWORDS
  };

  var INTERPOLATED_VARIABLE = {
    className: 'variable',
    begin: "\\$" + VARIABLE_NAME_RE
  };

  // TODO: neatly escape normal code in string literal
  var STRING = {
    className: "string",
    contains: [hljs.BACKSLASH_ESCAPE, INTERPOLATION, INTERPOLATED_VARIABLE],
    variants: [
      { begin: /\w*"/, end: /"\w*/ },
      { begin: /\w*"""/, end: /"""\w*/ }
    ]
  };

  var COMMAND = {
    className: "string",
    contains: [hljs.BACKSLASH_ESCAPE, INTERPOLATION, INTERPOLATED_VARIABLE],
    begin: '`', end: '`'
  };

  var MACROCALL = {
    className: "macrocall",
    begin: "@" + VARIABLE_NAME_RE
  };

  var COMMENT = {
    className: "comment",
    variants: [
      { begin: "#=", end: "=#", relevance: 10 },
      { begin: '#', end: '$' }
    ]
  };

  DEFAULT.contains = [
    NUMBER,
    CHAR,
    TYPE_ANNOTATION,
    SUBTYPE,
    STRING,
    COMMAND,
    MACROCALL,
    COMMENT,
    hljs.HASH_COMMENT_MODE
  ];
  INTERPOLATION.contains = DEFAULT.contains;

  return DEFAULT;
});

hljs.registerLanguage('kotlin', function (hljs) {
  var KEYWORDS = 'val var get set class trait object public open private protected ' +
    'final enum if else do while for when break continue throw try catch finally ' +
    'import package is as in return fun override default companion reified inline volatile transient native';

  return {
    keywords: {
      typename: 'Byte Short Char Int Long Boolean Float Double Void Unit Nothing',
      literal: 'true false null',
      keyword: KEYWORDS
    },
    contains : [
      hljs.COMMENT(
        '/\\*\\*',
        '\\*/',
        {
          relevance : 0,
          contains : [{
            className : 'doctag',
            begin : '@[A-Za-z]+'
          }]
        }
      ),
      hljs.C_LINE_COMMENT_MODE,
      hljs.C_BLOCK_COMMENT_MODE,
      {
        className: 'type',
        begin: /</, end: />/,
        returnBegin: true,
        excludeEnd: false,
        relevance: 0
      },
      {
        className: 'function',
        beginKeywords: 'fun', end: '[(]|$',
        returnBegin: true,
        excludeEnd: true,
        keywords: KEYWORDS,
        illegal: /fun\s+(<.*>)?[^\s\(]+(\s+[^\s\(]+)\s*=/,
        relevance: 5,
        contains: [
          {
            begin: hljs.UNDERSCORE_IDENT_RE + '\\s*\\(', returnBegin: true,
            relevance: 0,
            contains: [hljs.UNDERSCORE_TITLE_MODE]
          },
          {
            className: 'type',
            begin: /</, end: />/, keywords: 'reified',
            relevance: 0
          },
          {
            className: 'params',
            begin: /\(/, end: /\)/,
            keywords: KEYWORDS,
            relevance: 0,
            illegal: /\([^\(,\s:]+,/,
            contains: [
              {
                className: 'typename',
                begin: /:\s*/, end: /\s*[=\)]/, excludeBegin: true, returnEnd: true,
                relevance: 0
              }
            ]
          },
          hljs.C_LINE_COMMENT_MODE,
          hljs.C_BLOCK_COMMENT_MODE
        ]
      },
      {
        className: 'class',
        beginKeywords: 'class trait', end: /[:\{(]|$/,
        excludeEnd: true,
        illegal: 'extends implements',
        contains: [
          hljs.UNDERSCORE_TITLE_MODE,
          {
            className: 'type',
            begin: /</, end: />/, excludeBegin: true, excludeEnd: true,
            relevance: 0
          },
          {
            className: 'typename',
            begin: /[,:]\s*/, end: /[<\(,]|$/, excludeBegin: true, returnEnd: true
          }
        ]
      },
      {
        className: 'variable', beginKeywords: 'var val', end: /\s*[=:$]/, excludeEnd: true
      },
      hljs.QUOTE_STRING_MODE,
      {
        className: 'shebang',
        begin: "^#!/usr/bin/env", end: '$',
        illegal: '\n'
      },
      hljs.C_NUMBER_MODE
    ]
  };
});

hljs.registerLanguage('lasso', function(hljs) {
  var LASSO_IDENT_RE = '[a-zA-Z_][a-zA-Z0-9_.]*';
  var LASSO_ANGLE_RE = '<\\?(lasso(script)?|=)';
  var LASSO_CLOSE_RE = '\\]|\\?>';
  var LASSO_KEYWORDS = {
    literal:
      'true false none minimal full all void ' +
      'bw nbw ew new cn ncn lt lte gt gte eq neq rx nrx ft',
    built_in:
      'array date decimal duration integer map pair string tag xml null ' +
      'boolean bytes keyword list locale queue set stack staticarray ' +
      'local var variable global data self inherited currentcapture givenblock',
    keyword:
      'error_code error_msg error_pop error_push error_reset cache ' +
      'database_names database_schemanames database_tablenames define_tag ' +
      'define_type email_batch encode_set html_comment handle handle_error ' +
      'header if inline iterate ljax_target link link_currentaction ' +
      'link_currentgroup link_currentrecord link_detail link_firstgroup ' +
      'link_firstrecord link_lastgroup link_lastrecord link_nextgroup ' +
      'link_nextrecord link_prevgroup link_prevrecord log loop ' +
      'namespace_using output_none portal private protect records referer ' +
      'referrer repeating resultset rows search_args search_arguments ' +
      'select sort_args sort_arguments thread_atomic value_list while ' +
      'abort case else if_empty if_false if_null if_true loop_abort ' +
      'loop_continue loop_count params params_up return return_value ' +
      'run_children soap_definetag soap_lastrequest soap_lastresponse ' +
      'tag_name ascending average by define descending do equals ' +
      'frozen group handle_failure import in into join let match max ' +
      'min on order parent protected provide public require returnhome ' +
      'skip split_thread sum take thread to trait type where with ' +
      'yield yieldhome'
  };
  var HTML_COMMENT = hljs.COMMENT(
    '<!--',
    '-->',
    {
      relevance: 0
    }
  );
  var LASSO_NOPROCESS = {
    className: 'preprocessor',
    begin: '\\[noprocess\\]',
    starts: {
      className: 'markup',
      end: '\\[/noprocess\\]',
      returnEnd: true,
      contains: [HTML_COMMENT]
    }
  };
  var LASSO_START = {
    className: 'preprocessor',
    begin: '\\[/noprocess|' + LASSO_ANGLE_RE
  };
  var LASSO_DATAMEMBER = {
    className: 'variable',
    begin: '\'' + LASSO_IDENT_RE + '\''
  };
  var LASSO_CODE = [
    hljs.COMMENT(
      '/\\*\\*!',
      '\\*/'
    ),
    hljs.C_LINE_COMMENT_MODE,
    hljs.C_BLOCK_COMMENT_MODE,
    hljs.inherit(hljs.C_NUMBER_MODE, {begin: hljs.C_NUMBER_RE + '|(infinity|nan)\\b'}),
    hljs.inherit(hljs.APOS_STRING_MODE, {illegal: null}),
    hljs.inherit(hljs.QUOTE_STRING_MODE, {illegal: null}),
    {
      className: 'string',
      begin: '`', end: '`'
    },
    {
      className: 'variable',
      variants: [
        {
          begin: '[#$]' + LASSO_IDENT_RE
        },
        {
          begin: '#', end: '\\d+',
          illegal: '\\W'
        }
      ]
    },
    {
      className: 'tag',
      begin: '::\\s*', end: LASSO_IDENT_RE,
      illegal: '\\W'
    },
    {
      className: 'attribute',
      variants: [
        {
          begin: '-(?!infinity)' + hljs.UNDERSCORE_IDENT_RE,
          relevance: 0
        },
        {
          begin: '(\\.\\.\\.)'
        }
      ]
    },
    {
      className: 'subst',
      variants: [
        {
          begin: '->\\s*',
          contains: [LASSO_DATAMEMBER]
        },
        {
          begin: '->|\\\\|&&?|\\|\\||!(?!=|>)|(and|or|not)\\b',
          relevance: 0
        }
      ]
    },
    {
      className: 'built_in',
      begin: '\\.\\.?\\s*',
      relevance: 0,
      contains: [LASSO_DATAMEMBER]
    },
    {
      className: 'class',
      beginKeywords: 'define',
      returnEnd: true, end: '\\(|=>',
      contains: [
        hljs.inherit(hljs.TITLE_MODE, {begin: hljs.UNDERSCORE_IDENT_RE + '(=(?!>))?'})
      ]
    }
  ];
  return {
    aliases: ['ls', 'lassoscript'],
    case_insensitive: true,
    lexemes: LASSO_IDENT_RE + '|&[lg]t;',
    keywords: LASSO_KEYWORDS,
    contains: [
      {
        className: 'preprocessor',
        begin: LASSO_CLOSE_RE,
        relevance: 0,
        starts: {
          className: 'markup',
          end: '\\[|' + LASSO_ANGLE_RE,
          returnEnd: true,
          relevance: 0,
          contains: [HTML_COMMENT]
        }
      },
      LASSO_NOPROCESS,
      LASSO_START,
      {
        className: 'preprocessor',
        begin: '\\[no_square_brackets',
        starts: {
          end: '\\[/no_square_brackets\\]', // not implemented in the language
          lexemes: LASSO_IDENT_RE + '|&[lg]t;',
          keywords: LASSO_KEYWORDS,
          contains: [
            {
              className: 'preprocessor',
              begin: LASSO_CLOSE_RE,
              relevance: 0,
              starts: {
                className: 'markup',
                end: '\\[noprocess\\]|' + LASSO_ANGLE_RE,
                returnEnd: true,
                contains: [HTML_COMMENT]
              }
            },
            LASSO_NOPROCESS,
            LASSO_START
          ].concat(LASSO_CODE)
        }
      },
      {
        className: 'preprocessor',
        begin: '\\[',
        relevance: 0
      },
      {
        className: 'shebang',
        begin: '^#!.+lasso9\\b',
        relevance: 10
      }
    ].concat(LASSO_CODE)
  };
});

hljs.registerLanguage('less', function(hljs) {
  var IDENT_RE        = '[\\w-]+'; // yes, Less identifiers may begin with a digit
  var INTERP_IDENT_RE = '(' + IDENT_RE + '|@{' + IDENT_RE + '})';

  /* Generic Modes */

  var RULES = [], VALUE = []; // forward def. for recursive modes

  var STRING_MODE = function(c) { return {
    // Less strings are not multiline (also include '~' for more consistent coloring of "escaped" strings)
    className: 'string', begin: '~?' + c + '.*?' + c
  };};

  var IDENT_MODE = function(name, begin, relevance) { return {
    className: name, begin: begin, relevance: relevance
  };};

  var FUNCT_MODE = function(name, ident, obj) {
    return hljs.inherit({
        className: name, begin: ident + '\\(', end: '\\(',
        returnBegin: true, excludeEnd: true, relevance: 0
    }, obj);
  };

  var PARENS_MODE = {
    // used only to properly balance nested parens inside mixin call, def. arg list
    begin: '\\(', end: '\\)', contains: VALUE, relevance: 0
  };

  // generic Less highlighter (used almost everywhere except selectors):
  VALUE.push(
    hljs.C_LINE_COMMENT_MODE,
    hljs.C_BLOCK_COMMENT_MODE,
    STRING_MODE("'"),
    STRING_MODE('"'),
    hljs.CSS_NUMBER_MODE, // fixme: it does not include dot for numbers like .5em :(
    IDENT_MODE('hexcolor', '#[0-9A-Fa-f]+\\b'),
    FUNCT_MODE('function', '(url|data-uri)', {
      starts: {className: 'string', end: '[\\)\\n]', excludeEnd: true}
    }),
    FUNCT_MODE('function', IDENT_RE),
    PARENS_MODE,
    IDENT_MODE('variable', '@@?' + IDENT_RE, 10),
    IDENT_MODE('variable', '@{'  + IDENT_RE + '}'),
    IDENT_MODE('built_in', '~?`[^`]*?`'), // inline javascript (or whatever host language) *multiline* string
    { // @media features (it’s here to not duplicate things in AT_RULE_MODE with extra PARENS_MODE overriding):
      className: 'attribute', begin: IDENT_RE + '\\s*:', end: ':', returnBegin: true, excludeEnd: true
    }
  );

  var VALUE_WITH_RULESETS = VALUE.concat({
    begin: '{', end: '}', contains: RULES
  });

  var MIXIN_GUARD_MODE = {
    beginKeywords: 'when', endsWithParent: true,
    contains: [{beginKeywords: 'and not'}].concat(VALUE) // using this form to override VALUE’s 'function' match
  };

  /* Rule-Level Modes */

  var RULE_MODE = {
    className: 'attribute',
    begin: INTERP_IDENT_RE, end: ':', excludeEnd: true,
    contains: [hljs.C_LINE_COMMENT_MODE, hljs.C_BLOCK_COMMENT_MODE],
    illegal: /\S/,
    starts: {end: '[;}]', returnEnd: true, contains: VALUE, illegal: '[<=$]'}
  };

  var AT_RULE_MODE = {
    className: 'at_rule', // highlight only at-rule keyword
    begin: '@(import|media|charset|font-face|(-[a-z]+-)?keyframes|supports|document|namespace|page|viewport|host)\\b',
    starts: {end: '[;{}]', returnEnd: true, contains: VALUE, relevance: 0}
  };

  // variable definitions and calls
  var VAR_RULE_MODE = {
    className: 'variable',
    variants: [
      // using more strict pattern for higher relevance to increase chances of Less detection.
      // this is *the only* Less specific statement used in most of the sources, so...
      // (we’ll still often loose to the css-parser unless there's '//' comment,
      // simply because 1 variable just can't beat 99 properties :)
      {begin: '@' + IDENT_RE + '\\s*:', relevance: 15},
      {begin: '@' + IDENT_RE}
    ],
    starts: {end: '[;}]', returnEnd: true, contains: VALUE_WITH_RULESETS}
  };

  var SELECTOR_MODE = {
    // first parse unambiguous selectors (i.e. those not starting with tag)
    // then fall into the scary lookahead-discriminator variant.
    // this mode also handles mixin definitions and calls
    variants: [{
      begin: '[\\.#:&\\[]', end: '[;{}]'  // mixin calls end with ';'
      }, {
      begin: INTERP_IDENT_RE + '[^;]*{',
      end: '{'
    }],
    returnBegin: true,
    returnEnd:   true,
    illegal: '[<=\'$"]',
    contains: [
      hljs.C_LINE_COMMENT_MODE,
      hljs.C_BLOCK_COMMENT_MODE,
      MIXIN_GUARD_MODE,
      IDENT_MODE('keyword',  'all\\b'),
      IDENT_MODE('variable', '@{'  + IDENT_RE + '}'),     // otherwise it’s identified as tag
      IDENT_MODE('tag',       INTERP_IDENT_RE + '%?', 0), // '%' for more consistent coloring of @keyframes "tags"
      IDENT_MODE('id',       '#'   + INTERP_IDENT_RE),
      IDENT_MODE('class',    '\\.' + INTERP_IDENT_RE, 0),
      IDENT_MODE('keyword',  '&', 0),
      FUNCT_MODE('pseudo',   ':not'),
      FUNCT_MODE('keyword',  ':extend'),
      IDENT_MODE('pseudo',   '::?' + INTERP_IDENT_RE),
      {className: 'attr_selector', begin: '\\[', end: '\\]'},
      {begin: '\\(', end: '\\)', contains: VALUE_WITH_RULESETS}, // argument list of parametric mixins
      {begin: '!important'} // eat !important after mixin call or it will be colored as tag
    ]
  };

  RULES.push(
    hljs.C_LINE_COMMENT_MODE,
    hljs.C_BLOCK_COMMENT_MODE,
    AT_RULE_MODE,
    VAR_RULE_MODE,
    SELECTOR_MODE,
    RULE_MODE
  );

  return {
    case_insensitive: true,
    illegal: '[=>\'/<($"]',
    contains: RULES
  };
});

hljs.registerLanguage('lisp', function(hljs) {
  var LISP_IDENT_RE = '[a-zA-Z_\\-\\+\\*\\/\\<\\=\\>\\&\\#][a-zA-Z0-9_\\-\\+\\*\\/\\<\\=\\>\\&\\#!]*';
  var MEC_RE = '\\|[^]*?\\|';
  var LISP_SIMPLE_NUMBER_RE = '(\\-|\\+)?\\d+(\\.\\d+|\\/\\d+)?((d|e|f|l|s|D|E|F|L|S)(\\+|\\-)?\\d+)?';
  var SHEBANG = {
    className: 'shebang',
    begin: '^#!', end: '$'
  };
  var LITERAL = {
    className: 'literal',
    begin: '\\b(t{1}|nil)\\b'
  };
  var NUMBER = {
    className: 'number',
    variants: [
      {begin: LISP_SIMPLE_NUMBER_RE, relevance: 0},
      {begin: '#(b|B)[0-1]+(/[0-1]+)?'},
      {begin: '#(o|O)[0-7]+(/[0-7]+)?'},
      {begin: '#(x|X)[0-9a-fA-F]+(/[0-9a-fA-F]+)?'},
      {begin: '#(c|C)\\(' + LISP_SIMPLE_NUMBER_RE + ' +' + LISP_SIMPLE_NUMBER_RE, end: '\\)'}
    ]
  };
  var STRING = hljs.inherit(hljs.QUOTE_STRING_MODE, {illegal: null});
  var COMMENT = hljs.COMMENT(
    ';', '$',
    {
      relevance: 0
    }
  );
  var VARIABLE = {
    className: 'variable',
    begin: '\\*', end: '\\*'
  };
  var KEYWORD = {
    className: 'keyword',
    begin: '[:&]' + LISP_IDENT_RE
  };
  var IDENT = {
    begin: LISP_IDENT_RE,
    relevance: 0
  };
  var MEC = {
    begin: MEC_RE
  };
  var QUOTED_LIST = {
    begin: '\\(', end: '\\)',
    contains: ['self', LITERAL, STRING, NUMBER, IDENT]
  };
  var QUOTED = {
    className: 'quoted',
    contains: [NUMBER, STRING, VARIABLE, KEYWORD, QUOTED_LIST, IDENT],
    variants: [
      {
        begin: '[\'`]\\(', end: '\\)'
      },
      {
        begin: '\\(quote ', end: '\\)',
        keywords: 'quote'
      },
      {
        begin: '\'' + MEC_RE
      }
    ]
  };
  var QUOTED_ATOM = {
    className: 'quoted',
    variants: [
      {begin: '\'' + LISP_IDENT_RE},
      {begin: '#\'' + LISP_IDENT_RE + '(::' + LISP_IDENT_RE + ')*'}
    ]
  };
  var LIST = {
    className: 'list',
    begin: '\\(\\s*', end: '\\)'
  };
  var BODY = {
    endsWithParent: true,
    relevance: 0
  };
  LIST.contains = [
    {
      className: 'keyword',
      variants: [
        {begin: LISP_IDENT_RE},
        {begin: MEC_RE}
      ]
    },
    BODY
  ];
  BODY.contains = [QUOTED, QUOTED_ATOM, LIST, LITERAL, NUMBER, STRING, COMMENT, VARIABLE, KEYWORD, MEC, IDENT];

  return {
    illegal: /\S/,
    contains: [
      NUMBER,
      SHEBANG,
      LITERAL,
      STRING,
      COMMENT,
      QUOTED,
      QUOTED_ATOM,
      LIST,
      IDENT
    ]
  };
});

hljs.registerLanguage('livecodeserver', function(hljs) {
  var VARIABLE = {
    className: 'variable', begin: '\\b[gtps][A-Z]+[A-Za-z0-9_\\-]*\\b|\\$_[A-Z]+',
    relevance: 0
  };
  var COMMENT_MODES = [
    hljs.C_BLOCK_COMMENT_MODE,
    hljs.HASH_COMMENT_MODE,
    hljs.COMMENT('--', '$'),
    hljs.COMMENT('[^:]//', '$')
  ];
  var TITLE1 = hljs.inherit(hljs.TITLE_MODE, {
    variants: [
      {begin: '\\b_*rig[A-Z]+[A-Za-z0-9_\\-]*'},
      {begin: '\\b_[a-z0-9\\-]+'}
    ]
  });
  var TITLE2 = hljs.inherit(hljs.TITLE_MODE, {begin: '\\b([A-Za-z0-9_\\-]+)\\b'});
  return {
    case_insensitive: false,
    keywords: {
      keyword:
        '$_COOKIE $_FILES $_GET $_GET_BINARY $_GET_RAW $_POST $_POST_BINARY $_POST_RAW $_SESSION $_SERVER ' +
        'codepoint codepoints segment segments codeunit codeunits sentence sentences trueWord trueWords paragraph ' +
        'after byte bytes english the until http forever descending using line real8 with seventh ' +
        'for stdout finally element word words fourth before black ninth sixth characters chars stderr ' +
        'uInt1 uInt1s uInt2 uInt2s stdin string lines relative rel any fifth items from middle mid ' +
        'at else of catch then third it file milliseconds seconds second secs sec int1 int1s int4 ' +
        'int4s internet int2 int2s normal text item last long detailed effective uInt4 uInt4s repeat ' +
        'end repeat URL in try into switch to words https token binfile each tenth as ticks tick ' +
        'system real4 by dateItems without char character ascending eighth whole dateTime numeric short ' +
        'first ftp integer abbreviated abbr abbrev private case while if',
      constant:
        'SIX TEN FORMFEED NINE ZERO NONE SPACE FOUR FALSE COLON CRLF PI COMMA ENDOFFILE EOF EIGHT FIVE ' +
        'QUOTE EMPTY ONE TRUE RETURN CR LINEFEED RIGHT BACKSLASH NULL SEVEN TAB THREE TWO ' +
        'six ten formfeed nine zero none space four false colon crlf pi comma endoffile eof eight five ' +
        'quote empty one true return cr linefeed right backslash null seven tab three two ' +
        'RIVERSION RISTATE FILE_READ_MODE FILE_WRITE_MODE FILE_WRITE_MODE DIR_WRITE_MODE FILE_READ_UMASK ' +
        'FILE_WRITE_UMASK DIR_READ_UMASK DIR_WRITE_UMASK',
      operator:
        'div mod wrap and or bitAnd bitNot bitOr bitXor among not in a an within ' +
        'contains ends with begins the keys of keys',
      built_in:
        'put abs acos aliasReference annuity arrayDecode arrayEncode asin atan atan2 average avg avgDev base64Decode ' +
        'base64Encode baseConvert binaryDecode binaryEncode byteOffset byteToNum cachedURL cachedURLs charToNum ' +
        'cipherNames codepointOffset codepointProperty codepointToNum codeunitOffset commandNames compound compress ' +
        'constantNames cos date dateFormat decompress directories ' +
        'diskSpace DNSServers exp exp1 exp2 exp10 extents files flushEvents folders format functionNames geometricMean global ' +
        'globals hasMemory harmonicMean hostAddress hostAddressToName hostName hostNameToAddress isNumber ISOToMac itemOffset ' +
        'keys len length libURLErrorData libUrlFormData libURLftpCommand libURLLastHTTPHeaders libURLLastRHHeaders ' +
        'libUrlMultipartFormAddPart libUrlMultipartFormData libURLVersion lineOffset ln ln1 localNames log log2 log10 ' +
        'longFilePath lower macToISO matchChunk matchText matrixMultiply max md5Digest median merge millisec ' +
        'millisecs millisecond milliseconds min monthNames nativeCharToNum normalizeText num number numToByte numToChar ' +
        'numToCodepoint numToNativeChar offset open openfiles openProcesses openProcessIDs openSockets ' +
        'paragraphOffset paramCount param params peerAddress pendingMessages platform popStdDev populationStandardDeviation ' +
        'populationVariance popVariance processID random randomBytes replaceText result revCreateXMLTree revCreateXMLTreeFromFile ' +
        'revCurrentRecord revCurrentRecordIsFirst revCurrentRecordIsLast revDatabaseColumnCount revDatabaseColumnIsNull ' +
        'revDatabaseColumnLengths revDatabaseColumnNames revDatabaseColumnNamed revDatabaseColumnNumbered ' +
        'revDatabaseColumnTypes revDatabaseConnectResult revDatabaseCursors revDatabaseID revDatabaseTableNames ' +
        'revDatabaseType revDataFromQuery revdb_closeCursor revdb_columnbynumber revdb_columncount revdb_columnisnull ' +
        'revdb_columnlengths revdb_columnnames revdb_columntypes revdb_commit revdb_connect revdb_connections ' +
        'revdb_connectionerr revdb_currentrecord revdb_cursorconnection revdb_cursorerr revdb_cursors revdb_dbtype ' +
        'revdb_disconnect revdb_execute revdb_iseof revdb_isbof revdb_movefirst revdb_movelast revdb_movenext ' +
        'revdb_moveprev revdb_query revdb_querylist revdb_recordcount revdb_rollback revdb_tablenames ' +
        'revGetDatabaseDriverPath revNumberOfRecords revOpenDatabase revOpenDatabases revQueryDatabase ' +
        'revQueryDatabaseBlob revQueryResult revQueryIsAtStart revQueryIsAtEnd revUnixFromMacPath revXMLAttribute ' +
        'revXMLAttributes revXMLAttributeValues revXMLChildContents revXMLChildNames revXMLCreateTreeFromFileWithNamespaces ' +
        'revXMLCreateTreeWithNamespaces revXMLDataFromXPathQuery revXMLEvaluateXPath revXMLFirstChild revXMLMatchingNode ' +
        'revXMLNextSibling revXMLNodeContents revXMLNumberOfChildren revXMLParent revXMLPreviousSibling ' +
        'revXMLRootNode revXMLRPC_CreateRequest revXMLRPC_Documents revXMLRPC_Error ' +
        'revXMLRPC_GetHost revXMLRPC_GetMethod revXMLRPC_GetParam revXMLText revXMLRPC_Execute ' +
        'revXMLRPC_GetParamCount revXMLRPC_GetParamNode revXMLRPC_GetParamType revXMLRPC_GetPath revXMLRPC_GetPort ' +
        'revXMLRPC_GetProtocol revXMLRPC_GetRequest revXMLRPC_GetResponse revXMLRPC_GetSocket revXMLTree ' +
        'revXMLTrees revXMLValidateDTD revZipDescribeItem revZipEnumerateItems revZipOpenArchives round sampVariance ' +
        'sec secs seconds sentenceOffset sha1Digest shell shortFilePath sin specialFolderPath sqrt standardDeviation statRound ' +
        'stdDev sum sysError systemVersion tan tempName textDecode textEncode tick ticks time to tokenOffset toLower toUpper ' +
        'transpose truewordOffset trunc uniDecode uniEncode upper URLDecode URLEncode URLStatus uuid value variableNames ' +
        'variance version waitDepth weekdayNames wordOffset xsltApplyStylesheet xsltApplyStylesheetFromFile xsltLoadStylesheet ' +
        'xsltLoadStylesheetFromFile add breakpoint cancel clear local variable file word line folder directory URL close socket process ' +
        'combine constant convert create new alias folder directory decrypt delete variable word line folder ' +
        'directory URL dispatch divide do encrypt filter get include intersect kill libURLDownloadToFile ' +
        'libURLFollowHttpRedirects libURLftpUpload libURLftpUploadFile libURLresetAll libUrlSetAuthCallback ' +
        'libURLSetCustomHTTPHeaders libUrlSetExpect100 libURLSetFTPListCommand libURLSetFTPMode libURLSetFTPStopTime ' +
        'libURLSetStatusCallback load multiply socket prepare process post seek rel relative read from process rename ' +
        'replace require resetAll resolve revAddXMLNode revAppendXML revCloseCursor revCloseDatabase revCommitDatabase ' +
        'revCopyFile revCopyFolder revCopyXMLNode revDeleteFolder revDeleteXMLNode revDeleteAllXMLTrees ' +
        'revDeleteXMLTree revExecuteSQL revGoURL revInsertXMLNode revMoveFolder revMoveToFirstRecord revMoveToLastRecord ' +
        'revMoveToNextRecord revMoveToPreviousRecord revMoveToRecord revMoveXMLNode revPutIntoXMLNode revRollBackDatabase ' +
        'revSetDatabaseDriverPath revSetXMLAttribute revXMLRPC_AddParam revXMLRPC_DeleteAllDocuments revXMLAddDTD ' +
        'revXMLRPC_Free revXMLRPC_FreeAll revXMLRPC_DeleteDocument revXMLRPC_DeleteParam revXMLRPC_SetHost ' +
        'revXMLRPC_SetMethod revXMLRPC_SetPort revXMLRPC_SetProtocol revXMLRPC_SetSocket revZipAddItemWithData ' +
        'revZipAddItemWithFile revZipAddUncompressedItemWithData revZipAddUncompressedItemWithFile revZipCancel ' +
        'revZipCloseArchive revZipDeleteItem revZipExtractItemToFile revZipExtractItemToVariable revZipSetProgressCallback ' +
        'revZipRenameItem revZipReplaceItemWithData revZipReplaceItemWithFile revZipOpenArchive send set sort split start stop ' +
        'subtract union unload wait write'
    },
    contains: [
      VARIABLE,
      {
        className: 'keyword',
        begin: '\\bend\\sif\\b'
      },
      {
        className: 'function',
        beginKeywords: 'function', end: '$',
        contains: [
          VARIABLE,
          TITLE2,
          hljs.APOS_STRING_MODE,
          hljs.QUOTE_STRING_MODE,
          hljs.BINARY_NUMBER_MODE,
          hljs.C_NUMBER_MODE,
          TITLE1
        ]
      },
      {
        className: 'function',
        begin: '\\bend\\s+', end: '$',
        keywords: 'end',
        contains: [
          TITLE2,
          TITLE1
        ]
      },
      {
        className: 'command',
        beginKeywords: 'command on', end: '$',
        contains: [
          VARIABLE,
          TITLE2,
          hljs.APOS_STRING_MODE,
          hljs.QUOTE_STRING_MODE,
          hljs.BINARY_NUMBER_MODE,
          hljs.C_NUMBER_MODE,
          TITLE1
        ]
      },
      {
        className: 'preprocessor',
        variants: [
          {
            begin: '<\\?(rev|lc|livecode)',
            relevance: 10
          },
          { begin: '<\\?' },
          { begin: '\\?>' }
        ]
      },
      hljs.APOS_STRING_MODE,
      hljs.QUOTE_STRING_MODE,
      hljs.BINARY_NUMBER_MODE,
      hljs.C_NUMBER_MODE,
      TITLE1
    ].concat(COMMENT_MODES),
    illegal: ';$|^\\[|^='
  };
});

hljs.registerLanguage('livescript', function(hljs) {
  var KEYWORDS = {
    keyword:
      // JS keywords
      'in if for while finally new do return else break catch instanceof throw try this ' +
      'switch continue typeof delete debugger case default function var with ' +
      // LiveScript keywords
      'then unless until loop of by when and or is isnt not it that otherwise from to til fallthrough super ' +
      'case default function var void const let enum export import native ' +
      '__hasProp __extends __slice __bind __indexOf',
    literal:
      // JS literals
      'true false null undefined ' +
      // LiveScript literals
      'yes no on off it that void',
    built_in:
      'npm require console print module global window document'
  };
  var JS_IDENT_RE = '[A-Za-z$_](?:\-[0-9A-Za-z$_]|[0-9A-Za-z$_])*';
  var TITLE = hljs.inherit(hljs.TITLE_MODE, {begin: JS_IDENT_RE});
  var SUBST = {
    className: 'subst',
    begin: /#\{/, end: /}/,
    keywords: KEYWORDS
  };
  var SUBST_SIMPLE = {
    className: 'subst',
    begin: /#[A-Za-z$_]/, end: /(?:\-[0-9A-Za-z$_]|[0-9A-Za-z$_])*/,
    keywords: KEYWORDS
  };
  var EXPRESSIONS = [
    hljs.BINARY_NUMBER_MODE,
    {
      className: 'number',
      begin: '(\\b0[xX][a-fA-F0-9_]+)|(\\b\\d(\\d|_\\d)*(\\.(\\d(\\d|_\\d)*)?)?(_*[eE]([-+]\\d(_\\d|\\d)*)?)?[_a-z]*)',
      relevance: 0,
      starts: {end: '(\\s*/)?', relevance: 0} // a number tries to eat the following slash to prevent treating it as a regexp
    },
    {
      className: 'string',
      variants: [
        {
          begin: /'''/, end: /'''/,
          contains: [hljs.BACKSLASH_ESCAPE]
        },
        {
          begin: /'/, end: /'/,
          contains: [hljs.BACKSLASH_ESCAPE]
        },
        {
          begin: /"""/, end: /"""/,
          contains: [hljs.BACKSLASH_ESCAPE, SUBST, SUBST_SIMPLE]
        },
        {
          begin: /"/, end: /"/,
          contains: [hljs.BACKSLASH_ESCAPE, SUBST, SUBST_SIMPLE]
        },
        {
          begin: /\\/, end: /(\s|$)/,
          excludeEnd: true
        }
      ]
    },
    {
      className: 'pi',
      variants: [
        {
          begin: '//', end: '//[gim]*',
          contains: [SUBST, hljs.HASH_COMMENT_MODE]
        },
        {
          // regex can't start with space to parse x / 2 / 3 as two divisions
          // regex can't start with *, and it supports an "illegal" in the main mode
          begin: /\/(?![ *])(\\\/|.)*?\/[gim]*(?=\W|$)/
        }
      ]
    },
    {
      className: 'property',
      begin: '@' + JS_IDENT_RE
    },
    {
      begin: '``', end: '``',
      excludeBegin: true, excludeEnd: true,
      subLanguage: 'javascript'
    }
  ];
  SUBST.contains = EXPRESSIONS;

  var PARAMS = {
    className: 'params',
    begin: '\\(', returnBegin: true,
    /* We need another contained nameless mode to not have every nested
    pair of parens to be called "params" */
    contains: [
      {
        begin: /\(/, end: /\)/,
        keywords: KEYWORDS,
        contains: ['self'].concat(EXPRESSIONS)
      }
    ]
  };

  return {
    aliases: ['ls'],
    keywords: KEYWORDS,
    illegal: /\/\*/,
    contains: EXPRESSIONS.concat([
      hljs.COMMENT('\\/\\*', '\\*\\/'),
      hljs.HASH_COMMENT_MODE,
      {
        className: 'function',
        contains: [TITLE, PARAMS],
        returnBegin: true,
        variants: [
          {
            begin: '(' + JS_IDENT_RE + '\\s*(?:=|:=)\\s*)?(\\(.*\\))?\\s*\\B\\->\\*?', end: '\\->\\*?'
          },
          {
            begin: '(' + JS_IDENT_RE + '\\s*(?:=|:=)\\s*)?!?(\\(.*\\))?\\s*\\B[-~]{1,2}>\\*?', end: '[-~]{1,2}>\\*?'
          },
          {
            begin: '(' + JS_IDENT_RE + '\\s*(?:=|:=)\\s*)?(\\(.*\\))?\\s*\\B!?[-~]{1,2}>\\*?', end: '!?[-~]{1,2}>\\*?'
          }
        ]
      },
      {
        className: 'class',
        beginKeywords: 'class',
        end: '$',
        illegal: /[:="\[\]]/,
        contains: [
          {
            beginKeywords: 'extends',
            endsWithParent: true,
            illegal: /[:="\[\]]/,
            contains: [TITLE]
          },
          TITLE
        ]
      },
      {
        className: 'attribute',
        begin: JS_IDENT_RE + ':', end: ':',
        returnBegin: true, returnEnd: true,
        relevance: 0
      }
    ])
  };
});

hljs.registerLanguage('lua', function(hljs) {
  var OPENING_LONG_BRACKET = '\\[=*\\[';
  var CLOSING_LONG_BRACKET = '\\]=*\\]';
  var LONG_BRACKETS = {
    begin: OPENING_LONG_BRACKET, end: CLOSING_LONG_BRACKET,
    contains: ['self']
  };
  var COMMENTS = [
    hljs.COMMENT('--(?!' + OPENING_LONG_BRACKET + ')', '$'),
    hljs.COMMENT(
      '--' + OPENING_LONG_BRACKET,
      CLOSING_LONG_BRACKET,
      {
        contains: [LONG_BRACKETS],
        relevance: 10
      }
    )
  ];
  return {
    lexemes: hljs.UNDERSCORE_IDENT_RE,
    keywords: {
      keyword:
        'and break do else elseif end false for if in local nil not or repeat return then ' +
        'true until while',
      built_in:
        '_G _VERSION assert collectgarbage dofile error getfenv getmetatable ipairs load ' +
        'loadfile loadstring module next pairs pcall print rawequal rawget rawset require ' +
        'select setfenv setmetatable tonumber tostring type unpack xpcall coroutine debug ' +
        'io math os package string table'
    },
    contains: COMMENTS.concat([
      {
        className: 'function',
        beginKeywords: 'function', end: '\\)',
        contains: [
          hljs.inherit(hljs.TITLE_MODE, {begin: '([_a-zA-Z]\\w*\\.)*([_a-zA-Z]\\w*:)?[_a-zA-Z]\\w*'}),
          {
            className: 'params',
            begin: '\\(', endsWithParent: true,
            contains: COMMENTS
          }
        ].concat(COMMENTS)
      },
      hljs.C_NUMBER_MODE,
      hljs.APOS_STRING_MODE,
      hljs.QUOTE_STRING_MODE,
      {
        className: 'string',
        begin: OPENING_LONG_BRACKET, end: CLOSING_LONG_BRACKET,
        contains: [LONG_BRACKETS],
        relevance: 5
      }
    ])
  };
});

hljs.registerLanguage('makefile', function(hljs) {
  var VARIABLE = {
    className: 'variable',
    begin: /\$\(/, end: /\)/,
    contains: [hljs.BACKSLASH_ESCAPE]
  };
  return {
    aliases: ['mk', 'mak'],
    contains: [
      hljs.HASH_COMMENT_MODE,
      {
        begin: /^\w+\s*\W*=/, returnBegin: true,
        relevance: 0,
        starts: {
          className: 'constant',
          end: /\s*\W*=/, excludeEnd: true,
          starts: {
            end: /$/,
            relevance: 0,
            contains: [
              VARIABLE
            ]
          }
        }
      },
      {
        className: 'title',
        begin: /^[\w]+:\s*$/
      },
      {
        className: 'phony',
        begin: /^\.PHONY:/, end: /$/,
        keywords: '.PHONY', lexemes: /[\.\w]+/
      },
      {
        begin: /^\t+/, end: /$/,
        relevance: 0,
        contains: [
          hljs.QUOTE_STRING_MODE,
          VARIABLE
        ]
      }
    ]
  };
});

hljs.registerLanguage('mathematica', function(hljs) {
  return {
    aliases: ['mma'],
    lexemes: '(\\$|\\b)' + hljs.IDENT_RE + '\\b',
    keywords: 'AbelianGroup Abort AbortKernels AbortProtect Above Abs Absolute AbsoluteCorrelation AbsoluteCorrelationFunction AbsoluteCurrentValue AbsoluteDashing AbsoluteFileName AbsoluteOptions AbsolutePointSize AbsoluteThickness AbsoluteTime AbsoluteTiming AccountingForm Accumulate Accuracy AccuracyGoal ActionDelay ActionMenu ActionMenuBox ActionMenuBoxOptions Active ActiveItem ActiveStyle AcyclicGraphQ AddOnHelpPath AddTo AdjacencyGraph AdjacencyList AdjacencyMatrix AdjustmentBox AdjustmentBoxOptions AdjustTimeSeriesForecast AffineTransform After AiryAi AiryAiPrime AiryAiZero AiryBi AiryBiPrime AiryBiZero AlgebraicIntegerQ AlgebraicNumber AlgebraicNumberDenominator AlgebraicNumberNorm AlgebraicNumberPolynomial AlgebraicNumberTrace AlgebraicRules AlgebraicRulesData Algebraics AlgebraicUnitQ Alignment AlignmentMarker AlignmentPoint All AllowedDimensions AllowGroupClose AllowInlineCells AllowKernelInitialization AllowReverseGroupClose AllowScriptLevelChange AlphaChannel AlternatingGroup AlternativeHypothesis Alternatives AmbientLight Analytic AnchoredSearch And AndersonDarlingTest AngerJ AngleBracket AngularGauge Animate AnimationCycleOffset AnimationCycleRepetitions AnimationDirection AnimationDisplayTime AnimationRate AnimationRepetitions AnimationRunning Animator AnimatorBox AnimatorBoxOptions AnimatorElements Annotation Annuity AnnuityDue Antialiasing Antisymmetric Apart ApartSquareFree Appearance AppearanceElements AppellF1 Append AppendTo Apply ArcCos ArcCosh ArcCot ArcCoth ArcCsc ArcCsch ArcSec ArcSech ArcSin ArcSinDistribution ArcSinh ArcTan ArcTanh Arg ArgMax ArgMin ArgumentCountQ ARIMAProcess ArithmeticGeometricMean ARMAProcess ARProcess Array ArrayComponents ArrayDepth ArrayFlatten ArrayPad ArrayPlot ArrayQ ArrayReshape ArrayRules Arrays Arrow Arrow3DBox ArrowBox Arrowheads AspectRatio AspectRatioFixed Assert Assuming Assumptions AstronomicalData Asynchronous AsynchronousTaskObject AsynchronousTasks AtomQ Attributes AugmentedSymmetricPolynomial AutoAction AutoDelete AutoEvaluateEvents AutoGeneratedPackage AutoIndent AutoIndentSpacings AutoItalicWords AutoloadPath AutoMatch Automatic AutomaticImageSize AutoMultiplicationSymbol AutoNumberFormatting AutoOpenNotebooks AutoOpenPalettes AutorunSequencing AutoScaling AutoScroll AutoSpacing AutoStyleOptions AutoStyleWords Axes AxesEdge AxesLabel AxesOrigin AxesStyle Axis ' +
      'BabyMonsterGroupB Back Background BackgroundTasksSettings Backslash Backsubstitution Backward Band BandpassFilter BandstopFilter BarabasiAlbertGraphDistribution BarChart BarChart3D BarLegend BarlowProschanImportance BarnesG BarOrigin BarSpacing BartlettHannWindow BartlettWindow BaseForm Baseline BaselinePosition BaseStyle BatesDistribution BattleLemarieWavelet Because BeckmannDistribution Beep Before Begin BeginDialogPacket BeginFrontEndInteractionPacket BeginPackage BellB BellY Below BenfordDistribution BeniniDistribution BenktanderGibratDistribution BenktanderWeibullDistribution BernoulliB BernoulliDistribution BernoulliGraphDistribution BernoulliProcess BernsteinBasis BesselFilterModel BesselI BesselJ BesselJZero BesselK BesselY BesselYZero Beta BetaBinomialDistribution BetaDistribution BetaNegativeBinomialDistribution BetaPrimeDistribution BetaRegularized BetweennessCentrality BezierCurve BezierCurve3DBox BezierCurve3DBoxOptions BezierCurveBox BezierCurveBoxOptions BezierFunction BilateralFilter Binarize BinaryFormat BinaryImageQ BinaryRead BinaryReadList BinaryWrite BinCounts BinLists Binomial BinomialDistribution BinomialProcess BinormalDistribution BiorthogonalSplineWavelet BipartiteGraphQ BirnbaumImportance BirnbaumSaundersDistribution BitAnd BitClear BitGet BitLength BitNot BitOr BitSet BitShiftLeft BitShiftRight BitXor Black BlackmanHarrisWindow BlackmanNuttallWindow BlackmanWindow Blank BlankForm BlankNullSequence BlankSequence Blend Block BlockRandom BlomqvistBeta BlomqvistBetaTest Blue Blur BodePlot BohmanWindow Bold Bookmarks Boole BooleanConsecutiveFunction BooleanConvert BooleanCountingFunction BooleanFunction BooleanGraph BooleanMaxterms BooleanMinimize BooleanMinterms Booleans BooleanTable BooleanVariables BorderDimensions BorelTannerDistribution Bottom BottomHatTransform BoundaryStyle Bounds Box BoxBaselineShift BoxData BoxDimensions Boxed Boxes BoxForm BoxFormFormatTypes BoxFrame BoxID BoxMargins BoxMatrix BoxRatios BoxRotation BoxRotationPoint BoxStyle BoxWhiskerChart Bra BracketingBar BraKet BrayCurtisDistance BreadthFirstScan Break Brown BrownForsytheTest BrownianBridgeProcess BrowserCategory BSplineBasis BSplineCurve BSplineCurve3DBox BSplineCurveBox BSplineCurveBoxOptions BSplineFunction BSplineSurface BSplineSurface3DBox BubbleChart BubbleChart3D BubbleScale BubbleSizes BulletGauge BusinessDayQ ButterflyGraph ButterworthFilterModel Button ButtonBar ButtonBox ButtonBoxOptions ButtonCell ButtonContents ButtonData ButtonEvaluator ButtonExpandable ButtonFrame ButtonFunction ButtonMargins ButtonMinHeight ButtonNote ButtonNotebook ButtonSource ButtonStyle ButtonStyleMenuListing Byte ByteCount ByteOrdering ' +
      'C CachedValue CacheGraphics CalendarData CalendarType CallPacket CanberraDistance Cancel CancelButton CandlestickChart Cap CapForm CapitalDifferentialD CardinalBSplineBasis CarmichaelLambda Cases Cashflow Casoratian Catalan CatalanNumber Catch CauchyDistribution CauchyWindow CayleyGraph CDF CDFDeploy CDFInformation CDFWavelet Ceiling Cell CellAutoOverwrite CellBaseline CellBoundingBox CellBracketOptions CellChangeTimes CellContents CellContext CellDingbat CellDynamicExpression CellEditDuplicate CellElementsBoundingBox CellElementSpacings CellEpilog CellEvaluationDuplicate CellEvaluationFunction CellEventActions CellFrame CellFrameColor CellFrameLabelMargins CellFrameLabels CellFrameMargins CellGroup CellGroupData CellGrouping CellGroupingRules CellHorizontalScrolling CellID CellLabel CellLabelAutoDelete CellLabelMargins CellLabelPositioning CellMargins CellObject CellOpen CellPrint CellProlog Cells CellSize CellStyle CellTags CellularAutomaton CensoredDistribution Censoring Center CenterDot CentralMoment CentralMomentGeneratingFunction CForm ChampernowneNumber ChanVeseBinarize Character CharacterEncoding CharacterEncodingsPath CharacteristicFunction CharacteristicPolynomial CharacterRange Characters ChartBaseStyle ChartElementData ChartElementDataFunction ChartElementFunction ChartElements ChartLabels ChartLayout ChartLegends ChartStyle Chebyshev1FilterModel Chebyshev2FilterModel ChebyshevDistance ChebyshevT ChebyshevU Check CheckAbort CheckAll Checkbox CheckboxBar CheckboxBox CheckboxBoxOptions ChemicalData ChessboardDistance ChiDistribution ChineseRemainder ChiSquareDistribution ChoiceButtons ChoiceDialog CholeskyDecomposition Chop Circle CircleBox CircleDot CircleMinus CirclePlus CircleTimes CirculantGraph CityData Clear ClearAll ClearAttributes ClearSystemCache ClebschGordan ClickPane Clip ClipboardNotebook ClipFill ClippingStyle ClipPlanes ClipRange Clock ClockGauge ClockwiseContourIntegral Close Closed CloseKernels ClosenessCentrality Closing ClosingAutoSave ClosingEvent ClusteringComponents CMYKColor Coarse Coefficient CoefficientArrays CoefficientDomain CoefficientList CoefficientRules CoifletWavelet Collect Colon ColonForm ColorCombine ColorConvert ColorData ColorDataFunction ColorFunction ColorFunctionScaling Colorize ColorNegate ColorOutput ColorProfileData ColorQuantize ColorReplace ColorRules ColorSelectorSettings ColorSeparate ColorSetter ColorSetterBox ColorSetterBoxOptions ColorSlider ColorSpace Column ColumnAlignments ColumnBackgrounds ColumnForm ColumnLines ColumnsEqual ColumnSpacings ColumnWidths CommonDefaultFormatTypes Commonest CommonestFilter CommonUnits CommunityBoundaryStyle CommunityGraphPlot CommunityLabels CommunityRegionStyle CompatibleUnitQ CompilationOptions CompilationTarget Compile Compiled CompiledFunction Complement CompleteGraph CompleteGraphQ CompleteKaryTree CompletionsListPacket Complex Complexes ComplexExpand ComplexInfinity ComplexityFunction ComponentMeasurements ' +
      'ComponentwiseContextMenu Compose ComposeList ComposeSeries Composition CompoundExpression CompoundPoissonDistribution CompoundPoissonProcess CompoundRenewalProcess Compress CompressedData Condition ConditionalExpression Conditioned Cone ConeBox ConfidenceLevel ConfidenceRange ConfidenceTransform ConfigurationPath Congruent Conjugate ConjugateTranspose Conjunction Connect ConnectedComponents ConnectedGraphQ ConnesWindow ConoverTest ConsoleMessage ConsoleMessagePacket ConsolePrint Constant ConstantArray Constants ConstrainedMax ConstrainedMin ContentPadding ContentsBoundingBox ContentSelectable ContentSize Context ContextMenu Contexts ContextToFilename ContextToFileName Continuation Continue ContinuedFraction ContinuedFractionK ContinuousAction ContinuousMarkovProcess ContinuousTimeModelQ ContinuousWaveletData ContinuousWaveletTransform ContourDetect ContourGraphics ContourIntegral ContourLabels ContourLines ContourPlot ContourPlot3D Contours ContourShading ContourSmoothing ContourStyle ContraharmonicMean Control ControlActive ControlAlignment ControllabilityGramian ControllabilityMatrix ControllableDecomposition ControllableModelQ ControllerDuration ControllerInformation ControllerInformationData ControllerLinking ControllerManipulate ControllerMethod ControllerPath ControllerState ControlPlacement ControlsRendering ControlType Convergents ConversionOptions ConversionRules ConvertToBitmapPacket ConvertToPostScript ConvertToPostScriptPacket Convolve ConwayGroupCo1 ConwayGroupCo2 ConwayGroupCo3 CoordinateChartData CoordinatesToolOptions CoordinateTransform CoordinateTransformData CoprimeQ Coproduct CopulaDistribution Copyable CopyDirectory CopyFile CopyTag CopyToClipboard CornerFilter CornerNeighbors Correlation CorrelationDistance CorrelationFunction CorrelationTest Cos Cosh CoshIntegral CosineDistance CosineWindow CosIntegral Cot Coth Count CounterAssignments CounterBox CounterBoxOptions CounterClockwiseContourIntegral CounterEvaluator CounterFunction CounterIncrements CounterStyle CounterStyleMenuListing CountRoots CountryData Covariance CovarianceEstimatorFunction CovarianceFunction CoxianDistribution CoxIngersollRossProcess CoxModel CoxModelFit CramerVonMisesTest CreateArchive CreateDialog CreateDirectory CreateDocument CreateIntermediateDirectories CreatePalette CreatePalettePacket CreateScheduledTask CreateTemporary CreateWindow CriticalityFailureImportance CriticalitySuccessImportance CriticalSection Cross CrossingDetect CrossMatrix Csc Csch CubeRoot Cubics Cuboid CuboidBox Cumulant CumulantGeneratingFunction Cup CupCap Curl CurlyDoubleQuote CurlyQuote CurrentImage CurrentlySpeakingPacket CurrentValue CurvatureFlowFilter CurveClosed Cyan CycleGraph CycleIndexPolynomial Cycles CyclicGroup Cyclotomic Cylinder CylinderBox CylindricalDecomposition ' +
      'D DagumDistribution DamerauLevenshteinDistance DampingFactor Darker Dashed Dashing DataCompression DataDistribution DataRange DataReversed Date DateDelimiters DateDifference DateFunction DateList DateListLogPlot DateListPlot DatePattern DatePlus DateRange DateString DateTicksFormat DaubechiesWavelet DavisDistribution DawsonF DayCount DayCountConvention DayMatchQ DayName DayPlus DayRange DayRound DeBruijnGraph Debug DebugTag Decimal DeclareKnownSymbols DeclarePackage Decompose Decrement DedekindEta Default DefaultAxesStyle DefaultBaseStyle DefaultBoxStyle DefaultButton DefaultColor DefaultControlPlacement DefaultDuplicateCellStyle DefaultDuration DefaultElement DefaultFaceGridsStyle DefaultFieldHintStyle DefaultFont DefaultFontProperties DefaultFormatType DefaultFormatTypeForStyle DefaultFrameStyle DefaultFrameTicksStyle DefaultGridLinesStyle DefaultInlineFormatType DefaultInputFormatType DefaultLabelStyle DefaultMenuStyle DefaultNaturalLanguage DefaultNewCellStyle DefaultNewInlineCellStyle DefaultNotebook DefaultOptions DefaultOutputFormatType DefaultStyle DefaultStyleDefinitions DefaultTextFormatType DefaultTextInlineFormatType DefaultTicksStyle DefaultTooltipStyle DefaultValues Defer DefineExternal DefineInputStreamMethod DefineOutputStreamMethod Definition Degree DegreeCentrality DegreeGraphDistribution DegreeLexicographic DegreeReverseLexicographic Deinitialization Del Deletable Delete DeleteBorderComponents DeleteCases DeleteContents DeleteDirectory DeleteDuplicates DeleteFile DeleteSmallComponents DeleteWithContents DeletionWarning Delimiter DelimiterFlashTime DelimiterMatching Delimiters Denominator DensityGraphics DensityHistogram DensityPlot DependentVariables Deploy Deployed Depth DepthFirstScan Derivative DerivativeFilter DescriptorStateSpace DesignMatrix Det DGaussianWavelet DiacriticalPositioning Diagonal DiagonalMatrix Dialog DialogIndent DialogInput DialogLevel DialogNotebook DialogProlog DialogReturn DialogSymbols Diamond DiamondMatrix DiceDissimilarity DictionaryLookup DifferenceDelta DifferenceOrder DifferenceRoot DifferenceRootReduce Differences DifferentialD DifferentialRoot DifferentialRootReduce DifferentiatorFilter DigitBlock DigitBlockMinimum DigitCharacter DigitCount DigitQ DihedralGroup Dilation Dimensions DiracComb DiracDelta DirectedEdge DirectedEdges DirectedGraph DirectedGraphQ DirectedInfinity Direction Directive Directory DirectoryName DirectoryQ DirectoryStack DirichletCharacter DirichletConvolve DirichletDistribution DirichletL DirichletTransform DirichletWindow DisableConsolePrintPacket DiscreteChirpZTransform DiscreteConvolve DiscreteDelta DiscreteHadamardTransform DiscreteIndicator DiscreteLQEstimatorGains DiscreteLQRegulatorGains DiscreteLyapunovSolve DiscreteMarkovProcess DiscretePlot DiscretePlot3D DiscreteRatio DiscreteRiccatiSolve DiscreteShift DiscreteTimeModelQ DiscreteUniformDistribution DiscreteVariables DiscreteWaveletData DiscreteWaveletPacketTransform ' +
      'DiscreteWaveletTransform Discriminant Disjunction Disk DiskBox DiskMatrix Dispatch DispersionEstimatorFunction Display DisplayAllSteps DisplayEndPacket DisplayFlushImagePacket DisplayForm DisplayFunction DisplayPacket DisplayRules DisplaySetSizePacket DisplayString DisplayTemporary DisplayWith DisplayWithRef DisplayWithVariable DistanceFunction DistanceTransform Distribute Distributed DistributedContexts DistributeDefinitions DistributionChart DistributionDomain DistributionFitTest DistributionParameterAssumptions DistributionParameterQ Dithering Div Divergence Divide DivideBy Dividers Divisible Divisors DivisorSigma DivisorSum DMSList DMSString Do DockedCells DocumentNotebook DominantColors DOSTextFormat Dot DotDashed DotEqual Dotted DoubleBracketingBar DoubleContourIntegral DoubleDownArrow DoubleLeftArrow DoubleLeftRightArrow DoubleLeftTee DoubleLongLeftArrow DoubleLongLeftRightArrow DoubleLongRightArrow DoubleRightArrow DoubleRightTee DoubleUpArrow DoubleUpDownArrow DoubleVerticalBar DoublyInfinite Down DownArrow DownArrowBar DownArrowUpArrow DownLeftRightVector DownLeftTeeVector DownLeftVector DownLeftVectorBar DownRightTeeVector DownRightVector DownRightVectorBar Downsample DownTee DownTeeArrow DownValues DragAndDrop DrawEdges DrawFrontFaces DrawHighlighted Drop DSolve Dt DualLinearProgramming DualSystemsModel DumpGet DumpSave DuplicateFreeQ Dynamic DynamicBox DynamicBoxOptions DynamicEvaluationTimeout DynamicLocation DynamicModule DynamicModuleBox DynamicModuleBoxOptions DynamicModuleParent DynamicModuleValues DynamicName DynamicNamespace DynamicReference DynamicSetting DynamicUpdating DynamicWrapper DynamicWrapperBox DynamicWrapperBoxOptions ' +
      'E EccentricityCentrality EdgeAdd EdgeBetweennessCentrality EdgeCapacity EdgeCapForm EdgeColor EdgeConnectivity EdgeCost EdgeCount EdgeCoverQ EdgeDashing EdgeDelete EdgeDetect EdgeForm EdgeIndex EdgeJoinForm EdgeLabeling EdgeLabels EdgeLabelStyle EdgeList EdgeOpacity EdgeQ EdgeRenderingFunction EdgeRules EdgeShapeFunction EdgeStyle EdgeThickness EdgeWeight Editable EditButtonSettings EditCellTagsSettings EditDistance EffectiveInterest Eigensystem Eigenvalues EigenvectorCentrality Eigenvectors Element ElementData Eliminate EliminationOrder EllipticE EllipticExp EllipticExpPrime EllipticF EllipticFilterModel EllipticK EllipticLog EllipticNomeQ EllipticPi EllipticReducedHalfPeriods EllipticTheta EllipticThetaPrime EmitSound EmphasizeSyntaxErrors EmpiricalDistribution Empty EmptyGraphQ EnableConsolePrintPacket Enabled Encode End EndAdd EndDialogPacket EndFrontEndInteractionPacket EndOfFile EndOfLine EndOfString EndPackage EngineeringForm Enter EnterExpressionPacket EnterTextPacket Entropy EntropyFilter Environment Epilog Equal EqualColumns EqualRows EqualTilde EquatedTo Equilibrium EquirippleFilterKernel Equivalent Erf Erfc Erfi ErlangB ErlangC ErlangDistribution Erosion ErrorBox ErrorBoxOptions ErrorNorm ErrorPacket ErrorsDialogSettings EstimatedDistribution EstimatedProcess EstimatorGains EstimatorRegulator EuclideanDistance EulerE EulerGamma EulerianGraphQ EulerPhi Evaluatable Evaluate Evaluated EvaluatePacket EvaluationCell EvaluationCompletionAction EvaluationElements EvaluationMode EvaluationMonitor EvaluationNotebook EvaluationObject EvaluationOrder Evaluator EvaluatorNames EvenQ EventData EventEvaluator EventHandler EventHandlerTag EventLabels ExactBlackmanWindow ExactNumberQ ExactRootIsolation ExampleData Except ExcludedForms ExcludePods Exclusions ExclusionsStyle Exists Exit ExitDialog Exp Expand ExpandAll ExpandDenominator ExpandFileName ExpandNumerator Expectation ExpectationE ExpectedValue ExpGammaDistribution ExpIntegralE ExpIntegralEi Exponent ExponentFunction ExponentialDistribution ExponentialFamily ExponentialGeneratingFunction ExponentialMovingAverage ExponentialPowerDistribution ExponentPosition ExponentStep Export ExportAutoReplacements ExportPacket ExportString Expression ExpressionCell ExpressionPacket ExpToTrig ExtendedGCD Extension ExtentElementFunction ExtentMarkers ExtentSize ExternalCall ExternalDataCharacterEncoding Extract ExtractArchive ExtremeValueDistribution ' +
      'FaceForm FaceGrids FaceGridsStyle Factor FactorComplete Factorial Factorial2 FactorialMoment FactorialMomentGeneratingFunction FactorialPower FactorInteger FactorList FactorSquareFree FactorSquareFreeList FactorTerms FactorTermsList Fail FailureDistribution False FARIMAProcess FEDisableConsolePrintPacket FeedbackSector FeedbackSectorStyle FeedbackType FEEnableConsolePrintPacket Fibonacci FieldHint FieldHintStyle FieldMasked FieldSize File FileBaseName FileByteCount FileDate FileExistsQ FileExtension FileFormat FileHash FileInformation FileName FileNameDepth FileNameDialogSettings FileNameDrop FileNameJoin FileNames FileNameSetter FileNameSplit FileNameTake FilePrint FileType FilledCurve FilledCurveBox Filling FillingStyle FillingTransform FilterRules FinancialBond FinancialData FinancialDerivative FinancialIndicator Find FindArgMax FindArgMin FindClique FindClusters FindCurvePath FindDistributionParameters FindDivisions FindEdgeCover FindEdgeCut FindEulerianCycle FindFaces FindFile FindFit FindGeneratingFunction FindGeoLocation FindGeometricTransform FindGraphCommunities FindGraphIsomorphism FindGraphPartition FindHamiltonianCycle FindIndependentEdgeSet FindIndependentVertexSet FindInstance FindIntegerNullVector FindKClan FindKClique FindKClub FindKPlex FindLibrary FindLinearRecurrence FindList FindMaximum FindMaximumFlow FindMaxValue FindMinimum FindMinimumCostFlow FindMinimumCut FindMinValue FindPermutation FindPostmanTour FindProcessParameters FindRoot FindSequenceFunction FindSettings FindShortestPath FindShortestTour FindThreshold FindVertexCover FindVertexCut Fine FinishDynamic FiniteAbelianGroupCount FiniteGroupCount FiniteGroupData First FirstPassageTimeDistribution FischerGroupFi22 FischerGroupFi23 FischerGroupFi24Prime FisherHypergeometricDistribution FisherRatioTest FisherZDistribution Fit FitAll FittedModel FixedPoint FixedPointList FlashSelection Flat Flatten FlattenAt FlatTopWindow FlipView Floor FlushPrintOutputPacket Fold FoldList Font FontColor FontFamily FontForm FontName FontOpacity FontPostScriptName FontProperties FontReencoding FontSize FontSlant FontSubstitutions FontTracking FontVariations FontWeight For ForAll Format FormatRules FormatType FormatTypeAutoConvert FormatValues FormBox FormBoxOptions FortranForm Forward ForwardBackward Fourier FourierCoefficient FourierCosCoefficient FourierCosSeries FourierCosTransform FourierDCT FourierDCTFilter FourierDCTMatrix FourierDST FourierDSTMatrix FourierMatrix FourierParameters FourierSequenceTransform FourierSeries FourierSinCoefficient FourierSinSeries FourierSinTransform FourierTransform FourierTrigSeries FractionalBrownianMotionProcess FractionalPart FractionBox FractionBoxOptions FractionLine Frame FrameBox FrameBoxOptions Framed FrameInset FrameLabel Frameless FrameMargins FrameStyle FrameTicks FrameTicksStyle FRatioDistribution FrechetDistribution FreeQ FrequencySamplingFilterKernel FresnelC FresnelS Friday FrobeniusNumber FrobeniusSolve ' +
      'FromCharacterCode FromCoefficientRules FromContinuedFraction FromDate FromDigits FromDMS Front FrontEndDynamicExpression FrontEndEventActions FrontEndExecute FrontEndObject FrontEndResource FrontEndResourceString FrontEndStackSize FrontEndToken FrontEndTokenExecute FrontEndValueCache FrontEndVersion FrontFaceColor FrontFaceOpacity Full FullAxes FullDefinition FullForm FullGraphics FullOptions FullSimplify Function FunctionExpand FunctionInterpolation FunctionSpace FussellVeselyImportance ' +
      'GaborFilter GaborMatrix GaborWavelet GainMargins GainPhaseMargins Gamma GammaDistribution GammaRegularized GapPenalty Gather GatherBy GaugeFaceElementFunction GaugeFaceStyle GaugeFrameElementFunction GaugeFrameSize GaugeFrameStyle GaugeLabels GaugeMarkers GaugeStyle GaussianFilter GaussianIntegers GaussianMatrix GaussianWindow GCD GegenbauerC General GeneralizedLinearModelFit GenerateConditions GeneratedCell GeneratedParameters GeneratingFunction Generic GenericCylindricalDecomposition GenomeData GenomeLookup GeodesicClosing GeodesicDilation GeodesicErosion GeodesicOpening GeoDestination GeodesyData GeoDirection GeoDistance GeoGridPosition GeometricBrownianMotionProcess GeometricDistribution GeometricMean GeometricMeanFilter GeometricTransformation GeometricTransformation3DBox GeometricTransformation3DBoxOptions GeometricTransformationBox GeometricTransformationBoxOptions GeoPosition GeoPositionENU GeoPositionXYZ GeoProjectionData GestureHandler GestureHandlerTag Get GetBoundingBoxSizePacket GetContext GetEnvironment GetFileName GetFrontEndOptionsDataPacket GetLinebreakInformationPacket GetMenusPacket GetPageBreakInformationPacket Glaisher GlobalClusteringCoefficient GlobalPreferences GlobalSession Glow GoldenRatio GompertzMakehamDistribution GoodmanKruskalGamma GoodmanKruskalGammaTest Goto Grad Gradient GradientFilter GradientOrientationFilter Graph GraphAssortativity GraphCenter GraphComplement GraphData GraphDensity GraphDiameter GraphDifference GraphDisjointUnion ' +
      'GraphDistance GraphDistanceMatrix GraphElementData GraphEmbedding GraphHighlight GraphHighlightStyle GraphHub Graphics Graphics3D Graphics3DBox Graphics3DBoxOptions GraphicsArray GraphicsBaseline GraphicsBox GraphicsBoxOptions GraphicsColor GraphicsColumn GraphicsComplex GraphicsComplex3DBox GraphicsComplex3DBoxOptions GraphicsComplexBox GraphicsComplexBoxOptions GraphicsContents GraphicsData GraphicsGrid GraphicsGridBox GraphicsGroup GraphicsGroup3DBox GraphicsGroup3DBoxOptions GraphicsGroupBox GraphicsGroupBoxOptions GraphicsGrouping GraphicsHighlightColor GraphicsRow GraphicsSpacing GraphicsStyle GraphIntersection GraphLayout GraphLinkEfficiency GraphPeriphery GraphPlot GraphPlot3D GraphPower GraphPropertyDistribution GraphQ GraphRadius GraphReciprocity GraphRoot GraphStyle GraphUnion Gray GrayLevel GreatCircleDistance Greater GreaterEqual GreaterEqualLess GreaterFullEqual GreaterGreater GreaterLess GreaterSlantEqual GreaterTilde Green Grid GridBaseline GridBox GridBoxAlignment GridBoxBackground GridBoxDividers GridBoxFrame GridBoxItemSize GridBoxItemStyle GridBoxOptions GridBoxSpacings GridCreationSettings GridDefaultElement GridElementStyleOptions GridFrame GridFrameMargins GridGraph GridLines GridLinesStyle GroebnerBasis GroupActionBase GroupCentralizer GroupElementFromWord GroupElementPosition GroupElementQ GroupElements GroupElementToWord GroupGenerators GroupMultiplicationTable GroupOrbits GroupOrder GroupPageBreakWithin GroupSetwiseStabilizer GroupStabilizer GroupStabilizerChain Gudermannian GumbelDistribution ' +
      'HaarWavelet HadamardMatrix HalfNormalDistribution HamiltonianGraphQ HammingDistance HammingWindow HankelH1 HankelH2 HankelMatrix HannPoissonWindow HannWindow HaradaNortonGroupHN HararyGraph HarmonicMean HarmonicMeanFilter HarmonicNumber Hash HashTable Haversine HazardFunction Head HeadCompose Heads HeavisideLambda HeavisidePi HeavisideTheta HeldGroupHe HeldPart HelpBrowserLookup HelpBrowserNotebook HelpBrowserSettings HermiteDecomposition HermiteH HermitianMatrixQ HessenbergDecomposition Hessian HexadecimalCharacter Hexahedron HexahedronBox HexahedronBoxOptions HiddenSurface HighlightGraph HighlightImage HighpassFilter HigmanSimsGroupHS HilbertFilter HilbertMatrix Histogram Histogram3D HistogramDistribution HistogramList HistogramTransform HistogramTransformInterpolation HitMissTransform HITSCentrality HodgeDual HoeffdingD HoeffdingDTest Hold HoldAll HoldAllComplete HoldComplete HoldFirst HoldForm HoldPattern HoldRest HolidayCalendar HomeDirectory HomePage Horizontal HorizontalForm HorizontalGauge HorizontalScrollPosition HornerForm HotellingTSquareDistribution HoytDistribution HTMLSave Hue HumpDownHump HumpEqual HurwitzLerchPhi HurwitzZeta HyperbolicDistribution HypercubeGraph HyperexponentialDistribution Hyperfactorial Hypergeometric0F1 Hypergeometric0F1Regularized Hypergeometric1F1 Hypergeometric1F1Regularized Hypergeometric2F1 Hypergeometric2F1Regularized HypergeometricDistribution HypergeometricPFQ HypergeometricPFQRegularized HypergeometricU Hyperlink HyperlinkCreationSettings Hyphenation HyphenationOptions HypoexponentialDistribution HypothesisTestData ' +
      'I Identity IdentityMatrix If IgnoreCase Im Image Image3D Image3DSlices ImageAccumulate ImageAdd ImageAdjust ImageAlign ImageApply ImageAspectRatio ImageAssemble ImageCache ImageCacheValid ImageCapture ImageChannels ImageClip ImageColorSpace ImageCompose ImageConvolve ImageCooccurrence ImageCorners ImageCorrelate ImageCorrespondingPoints ImageCrop ImageData ImageDataPacket ImageDeconvolve ImageDemosaic ImageDifference ImageDimensions ImageDistance ImageEffect ImageFeatureTrack ImageFileApply ImageFileFilter ImageFileScan ImageFilter ImageForestingComponents ImageForwardTransformation ImageHistogram ImageKeypoints ImageLevels ImageLines ImageMargins ImageMarkers ImageMeasurements ImageMultiply ImageOffset ImagePad ImagePadding ImagePartition ImagePeriodogram ImagePerspectiveTransformation ImageQ ImageRangeCache ImageReflect ImageRegion ImageResize ImageResolution ImageRotate ImageRotated ImageScaled ImageScan ImageSize ImageSizeAction ImageSizeCache ImageSizeMultipliers ImageSizeRaw ImageSubtract ImageTake ImageTransformation ImageTrim ImageType ImageValue ImageValuePositions Implies Import ImportAutoReplacements ImportString ImprovementImportance In IncidenceGraph IncidenceList IncidenceMatrix IncludeConstantBasis IncludeFileExtension IncludePods IncludeSingularTerm Increment Indent IndentingNewlineSpacings IndentMaxFraction IndependenceTest IndependentEdgeSetQ IndependentUnit IndependentVertexSetQ Indeterminate IndexCreationOptions Indexed IndexGraph IndexTag Inequality InexactNumberQ InexactNumbers Infinity Infix Information Inherited InheritScope Initialization InitializationCell InitializationCellEvaluation InitializationCellWarning InlineCounterAssignments InlineCounterIncrements InlineRules Inner Inpaint Input InputAliases InputAssumptions InputAutoReplacements InputField InputFieldBox InputFieldBoxOptions InputForm InputGrouping InputNamePacket InputNotebook InputPacket InputSettings InputStream InputString InputStringPacket InputToBoxFormPacket Insert InsertionPointObject InsertResults Inset Inset3DBox Inset3DBoxOptions InsetBox InsetBoxOptions Install InstallService InString Integer IntegerDigits IntegerExponent IntegerLength IntegerPart IntegerPartitions IntegerQ Integers IntegerString Integral Integrate Interactive InteractiveTradingChart Interlaced Interleaving InternallyBalancedDecomposition InterpolatingFunction InterpolatingPolynomial Interpolation InterpolationOrder InterpolationPoints InterpolationPrecision Interpretation InterpretationBox InterpretationBoxOptions InterpretationFunction ' +
      'InterpretTemplate InterquartileRange Interrupt InterruptSettings Intersection Interval IntervalIntersection IntervalMemberQ IntervalUnion Inverse InverseBetaRegularized InverseCDF InverseChiSquareDistribution InverseContinuousWaveletTransform InverseDistanceTransform InverseEllipticNomeQ InverseErf InverseErfc InverseFourier InverseFourierCosTransform InverseFourierSequenceTransform InverseFourierSinTransform InverseFourierTransform InverseFunction InverseFunctions InverseGammaDistribution InverseGammaRegularized InverseGaussianDistribution InverseGudermannian InverseHaversine InverseJacobiCD InverseJacobiCN InverseJacobiCS InverseJacobiDC InverseJacobiDN InverseJacobiDS InverseJacobiNC InverseJacobiND InverseJacobiNS InverseJacobiSC InverseJacobiSD InverseJacobiSN InverseLaplaceTransform InversePermutation InverseRadon InverseSeries InverseSurvivalFunction InverseWaveletTransform InverseWeierstrassP InverseZTransform Invisible InvisibleApplication InvisibleTimes IrreduciblePolynomialQ IsolatingInterval IsomorphicGraphQ IsotopeData Italic Item ItemBox ItemBoxOptions ItemSize ItemStyle ItoProcess ' +
      'JaccardDissimilarity JacobiAmplitude Jacobian JacobiCD JacobiCN JacobiCS JacobiDC JacobiDN JacobiDS JacobiNC JacobiND JacobiNS JacobiP JacobiSC JacobiSD JacobiSN JacobiSymbol JacobiZeta JankoGroupJ1 JankoGroupJ2 JankoGroupJ3 JankoGroupJ4 JarqueBeraALMTest JohnsonDistribution Join Joined JoinedCurve JoinedCurveBox JoinForm JordanDecomposition JordanModelDecomposition ' +
      'K KagiChart KaiserBesselWindow KaiserWindow KalmanEstimator KalmanFilter KarhunenLoeveDecomposition KaryTree KatzCentrality KCoreComponents KDistribution KelvinBei KelvinBer KelvinKei KelvinKer KendallTau KendallTauTest KernelExecute KernelMixtureDistribution KernelObject Kernels Ket Khinchin KirchhoffGraph KirchhoffMatrix KleinInvariantJ KnightTourGraph KnotData KnownUnitQ KolmogorovSmirnovTest KroneckerDelta KroneckerModelDecomposition KroneckerProduct KroneckerSymbol KuiperTest KumaraswamyDistribution Kurtosis KuwaharaFilter ' +
      'Label Labeled LabeledSlider LabelingFunction LabelStyle LaguerreL LambdaComponents LambertW LanczosWindow LandauDistribution Language LanguageCategory LaplaceDistribution LaplaceTransform Laplacian LaplacianFilter LaplacianGaussianFilter Large Larger Last Latitude LatitudeLongitude LatticeData LatticeReduce Launch LaunchKernels LayeredGraphPlot LayerSizeFunction LayoutInformation LCM LeafCount LeapYearQ LeastSquares LeastSquaresFilterKernel Left LeftArrow LeftArrowBar LeftArrowRightArrow LeftDownTeeVector LeftDownVector LeftDownVectorBar LeftRightArrow LeftRightVector LeftTee LeftTeeArrow LeftTeeVector LeftTriangle LeftTriangleBar LeftTriangleEqual LeftUpDownVector LeftUpTeeVector LeftUpVector LeftUpVectorBar LeftVector LeftVectorBar LegendAppearance Legended LegendFunction LegendLabel LegendLayout LegendMargins LegendMarkers LegendMarkerSize LegendreP LegendreQ LegendreType Length LengthWhile LerchPhi Less LessEqual LessEqualGreater LessFullEqual LessGreater LessLess LessSlantEqual LessTilde LetterCharacter LetterQ Level LeveneTest LeviCivitaTensor LevyDistribution Lexicographic LibraryFunction LibraryFunctionError LibraryFunctionInformation LibraryFunctionLoad LibraryFunctionUnload LibraryLoad LibraryUnload LicenseID LiftingFilterData LiftingWaveletTransform LightBlue LightBrown LightCyan Lighter LightGray LightGreen Lighting LightingAngle LightMagenta LightOrange LightPink LightPurple LightRed LightSources LightYellow Likelihood Limit LimitsPositioning LimitsPositioningTokens LindleyDistribution Line Line3DBox LinearFilter LinearFractionalTransform LinearModelFit LinearOffsetFunction LinearProgramming LinearRecurrence LinearSolve LinearSolveFunction LineBox LineBreak LinebreakAdjustments LineBreakChart LineBreakWithin LineColor LineForm LineGraph LineIndent LineIndentMaxFraction LineIntegralConvolutionPlot LineIntegralConvolutionScale LineLegend LineOpacity LineSpacing LineWrapParts LinkActivate LinkClose LinkConnect LinkConnectedQ LinkCreate LinkError LinkFlush LinkFunction LinkHost LinkInterrupt LinkLaunch LinkMode LinkObject LinkOpen LinkOptions LinkPatterns LinkProtocol LinkRead LinkReadHeld LinkReadyQ Links LinkWrite LinkWriteHeld LiouvilleLambda List Listable ListAnimate ListContourPlot ListContourPlot3D ListConvolve ListCorrelate ListCurvePathPlot ListDeconvolve ListDensityPlot Listen ListFourierSequenceTransform ListInterpolation ListLineIntegralConvolutionPlot ListLinePlot ListLogLinearPlot ListLogLogPlot ListLogPlot ListPicker ListPickerBox ListPickerBoxBackground ListPickerBoxOptions ListPlay ListPlot ListPlot3D ListPointPlot3D ListPolarPlot ListQ ListStreamDensityPlot ListStreamPlot ListSurfacePlot3D ListVectorDensityPlot ListVectorPlot ListVectorPlot3D ListZTransform Literal LiteralSearch LocalClusteringCoefficient LocalizeVariables LocationEquivalenceTest LocationTest Locator LocatorAutoCreate LocatorBox LocatorBoxOptions LocatorCentering LocatorPane LocatorPaneBox LocatorPaneBoxOptions ' +
      'LocatorRegion Locked Log Log10 Log2 LogBarnesG LogGamma LogGammaDistribution LogicalExpand LogIntegral LogisticDistribution LogitModelFit LogLikelihood LogLinearPlot LogLogisticDistribution LogLogPlot LogMultinormalDistribution LogNormalDistribution LogPlot LogRankTest LogSeriesDistribution LongEqual Longest LongestAscendingSequence LongestCommonSequence LongestCommonSequencePositions LongestCommonSubsequence LongestCommonSubsequencePositions LongestMatch LongForm Longitude LongLeftArrow LongLeftRightArrow LongRightArrow Loopback LoopFreeGraphQ LowerCaseQ LowerLeftArrow LowerRightArrow LowerTriangularize LowpassFilter LQEstimatorGains LQGRegulator LQOutputRegulatorGains LQRegulatorGains LUBackSubstitution LucasL LuccioSamiComponents LUDecomposition LyapunovSolve LyonsGroupLy ' +
      'MachineID MachineName MachineNumberQ MachinePrecision MacintoshSystemPageSetup Magenta Magnification Magnify MainSolve MaintainDynamicCaches Majority MakeBoxes MakeExpression MakeRules MangoldtLambda ManhattanDistance Manipulate Manipulator MannWhitneyTest MantissaExponent Manual Map MapAll MapAt MapIndexed MAProcess MapThread MarcumQ MardiaCombinedTest MardiaKurtosisTest MardiaSkewnessTest MarginalDistribution MarkovProcessProperties Masking MatchingDissimilarity MatchLocalNameQ MatchLocalNames MatchQ Material MathematicaNotation MathieuC MathieuCharacteristicA MathieuCharacteristicB MathieuCharacteristicExponent MathieuCPrime MathieuGroupM11 MathieuGroupM12 MathieuGroupM22 MathieuGroupM23 MathieuGroupM24 MathieuS MathieuSPrime MathMLForm MathMLText Matrices MatrixExp MatrixForm MatrixFunction MatrixLog MatrixPlot MatrixPower MatrixQ MatrixRank Max MaxBend MaxDetect MaxExtraBandwidths MaxExtraConditions MaxFeatures MaxFilter Maximize MaxIterations MaxMemoryUsed MaxMixtureKernels MaxPlotPoints MaxPoints MaxRecursion MaxStableDistribution MaxStepFraction MaxSteps MaxStepSize MaxValue MaxwellDistribution McLaughlinGroupMcL Mean MeanClusteringCoefficient MeanDegreeConnectivity MeanDeviation MeanFilter MeanGraphDistance MeanNeighborDegree MeanShift MeanShiftFilter Median MedianDeviation MedianFilter Medium MeijerG MeixnerDistribution MemberQ MemoryConstrained MemoryInUse Menu MenuAppearance MenuCommandKey MenuEvaluator MenuItem MenuPacket MenuSortingValue MenuStyle MenuView MergeDifferences Mesh MeshFunctions MeshRange MeshShading MeshStyle Message MessageDialog MessageList MessageName MessageOptions MessagePacket Messages MessagesNotebook MetaCharacters MetaInformation Method MethodOptions MexicanHatWavelet MeyerWavelet Min MinDetect MinFilter MinimalPolynomial MinimalStateSpaceModel Minimize Minors MinRecursion MinSize MinStableDistribution Minus MinusPlus MinValue Missing MissingDataMethod MittagLefflerE MixedRadix MixedRadixQuantity MixtureDistribution Mod Modal Mode Modular ModularLambda Module Modulus MoebiusMu Moment Momentary MomentConvert MomentEvaluate MomentGeneratingFunction Monday Monitor MonomialList MonomialOrder MonsterGroupM MorletWavelet MorphologicalBinarize MorphologicalBranchPoints MorphologicalComponents MorphologicalEulerNumber MorphologicalGraph MorphologicalPerimeter MorphologicalTransform Most MouseAnnotation MouseAppearance MouseAppearanceTag MouseButtons Mouseover MousePointerNote MousePosition MovingAverage MovingMedian MoyalDistribution MultiedgeStyle MultilaunchWarning MultiLetterItalics MultiLetterStyle MultilineFunction Multinomial MultinomialDistribution MultinormalDistribution MultiplicativeOrder Multiplicity Multiselection MultivariateHypergeometricDistribution MultivariatePoissonDistribution MultivariateTDistribution ' +
      'N NakagamiDistribution NameQ Names NamespaceBox Nand NArgMax NArgMin NBernoulliB NCache NDSolve NDSolveValue Nearest NearestFunction NeedCurrentFrontEndPackagePacket NeedCurrentFrontEndSymbolsPacket NeedlemanWunschSimilarity Needs Negative NegativeBinomialDistribution NegativeMultinomialDistribution NeighborhoodGraph Nest NestedGreaterGreater NestedLessLess NestedScriptRules NestList NestWhile NestWhileList NevilleThetaC NevilleThetaD NevilleThetaN NevilleThetaS NewPrimitiveStyle NExpectation Next NextPrime NHoldAll NHoldFirst NHoldRest NicholsGridLines NicholsPlot NIntegrate NMaximize NMaxValue NMinimize NMinValue NominalVariables NonAssociative NoncentralBetaDistribution NoncentralChiSquareDistribution NoncentralFRatioDistribution NoncentralStudentTDistribution NonCommutativeMultiply NonConstants None NonlinearModelFit NonlocalMeansFilter NonNegative NonPositive Nor NorlundB Norm Normal NormalDistribution NormalGrouping Normalize NormalizedSquaredEuclideanDistance NormalsFunction NormFunction Not NotCongruent NotCupCap NotDoubleVerticalBar Notebook NotebookApply NotebookAutoSave NotebookClose NotebookConvertSettings NotebookCreate NotebookCreateReturnObject NotebookDefault NotebookDelete NotebookDirectory NotebookDynamicExpression NotebookEvaluate NotebookEventActions NotebookFileName NotebookFind NotebookFindReturnObject NotebookGet NotebookGetLayoutInformationPacket NotebookGetMisspellingsPacket NotebookInformation NotebookInterfaceObject NotebookLocate NotebookObject NotebookOpen NotebookOpenReturnObject NotebookPath NotebookPrint NotebookPut NotebookPutReturnObject NotebookRead NotebookResetGeneratedCells Notebooks NotebookSave NotebookSaveAs NotebookSelection NotebookSetupLayoutInformationPacket NotebooksMenu NotebookWrite NotElement NotEqualTilde NotExists NotGreater NotGreaterEqual NotGreaterFullEqual NotGreaterGreater NotGreaterLess NotGreaterSlantEqual NotGreaterTilde NotHumpDownHump NotHumpEqual NotLeftTriangle NotLeftTriangleBar NotLeftTriangleEqual NotLess NotLessEqual NotLessFullEqual NotLessGreater NotLessLess NotLessSlantEqual NotLessTilde NotNestedGreaterGreater NotNestedLessLess NotPrecedes NotPrecedesEqual NotPrecedesSlantEqual NotPrecedesTilde NotReverseElement NotRightTriangle NotRightTriangleBar NotRightTriangleEqual NotSquareSubset NotSquareSubsetEqual NotSquareSuperset NotSquareSupersetEqual NotSubset NotSubsetEqual NotSucceeds NotSucceedsEqual NotSucceedsSlantEqual NotSucceedsTilde NotSuperset NotSupersetEqual NotTilde NotTildeEqual NotTildeFullEqual NotTildeTilde NotVerticalBar NProbability NProduct NProductFactors NRoots NSolve NSum NSumTerms Null NullRecords NullSpace NullWords Number NumberFieldClassNumber NumberFieldDiscriminant NumberFieldFundamentalUnits NumberFieldIntegralBasis NumberFieldNormRepresentatives NumberFieldRegulator NumberFieldRootsOfUnity NumberFieldSignature NumberForm NumberFormat NumberMarks NumberMultiplier NumberPadding NumberPoint NumberQ NumberSeparator ' +
      'NumberSigns NumberString Numerator NumericFunction NumericQ NuttallWindow NValues NyquistGridLines NyquistPlot ' +
      'O ObservabilityGramian ObservabilityMatrix ObservableDecomposition ObservableModelQ OddQ Off Offset OLEData On ONanGroupON OneIdentity Opacity Open OpenAppend Opener OpenerBox OpenerBoxOptions OpenerView OpenFunctionInspectorPacket Opening OpenRead OpenSpecialOptions OpenTemporary OpenWrite Operate OperatingSystem OptimumFlowData Optional OptionInspectorSettings OptionQ Options OptionsPacket OptionsPattern OptionValue OptionValueBox OptionValueBoxOptions Or Orange Order OrderDistribution OrderedQ Ordering Orderless OrnsteinUhlenbeckProcess Orthogonalize Out Outer OutputAutoOverwrite OutputControllabilityMatrix OutputControllableModelQ OutputForm OutputFormData OutputGrouping OutputMathEditExpression OutputNamePacket OutputResponse OutputSizeLimit OutputStream Over OverBar OverDot Overflow OverHat Overlaps Overlay OverlayBox OverlayBoxOptions Overscript OverscriptBox OverscriptBoxOptions OverTilde OverVector OwenT OwnValues ' +
      'PackingMethod PaddedForm Padding PadeApproximant PadLeft PadRight PageBreakAbove PageBreakBelow PageBreakWithin PageFooterLines PageFooters PageHeaderLines PageHeaders PageHeight PageRankCentrality PageWidth PairedBarChart PairedHistogram PairedSmoothHistogram PairedTTest PairedZTest PaletteNotebook PalettePath Pane PaneBox PaneBoxOptions Panel PanelBox PanelBoxOptions Paneled PaneSelector PaneSelectorBox PaneSelectorBoxOptions PaperWidth ParabolicCylinderD ParagraphIndent ParagraphSpacing ParallelArray ParallelCombine ParallelDo ParallelEvaluate Parallelization Parallelize ParallelMap ParallelNeeds ParallelProduct ParallelSubmit ParallelSum ParallelTable ParallelTry Parameter ParameterEstimator ParameterMixtureDistribution ParameterVariables ParametricFunction ParametricNDSolve ParametricNDSolveValue ParametricPlot ParametricPlot3D ParentConnect ParentDirectory ParentForm Parenthesize ParentList ParetoDistribution Part PartialCorrelationFunction PartialD ParticleData Partition PartitionsP PartitionsQ ParzenWindow PascalDistribution PassEventsDown PassEventsUp Paste PasteBoxFormInlineCells PasteButton Path PathGraph PathGraphQ Pattern PatternSequence PatternTest PauliMatrix PaulWavelet Pause PausedTime PDF PearsonChiSquareTest PearsonCorrelationTest PearsonDistribution PerformanceGoal PeriodicInterpolation Periodogram PeriodogramArray PermutationCycles PermutationCyclesQ PermutationGroup PermutationLength PermutationList PermutationListQ PermutationMax PermutationMin PermutationOrder PermutationPower PermutationProduct PermutationReplace Permutations PermutationSupport Permute PeronaMalikFilter Perpendicular PERTDistribution PetersenGraph PhaseMargins Pi Pick PIDData PIDDerivativeFilter PIDFeedforward PIDTune Piecewise PiecewiseExpand PieChart PieChart3D PillaiTrace PillaiTraceTest Pink Pivoting PixelConstrained PixelValue PixelValuePositions Placed Placeholder PlaceholderReplace Plain PlanarGraphQ Play PlayRange Plot Plot3D Plot3Matrix PlotDivision PlotJoined PlotLabel PlotLayout PlotLegends PlotMarkers PlotPoints PlotRange PlotRangeClipping PlotRangePadding PlotRegion PlotStyle Plus PlusMinus Pochhammer PodStates PodWidth Point Point3DBox PointBox PointFigureChart PointForm PointLegend PointSize PoissonConsulDistribution PoissonDistribution PoissonProcess PoissonWindow PolarAxes PolarAxesOrigin PolarGridLines PolarPlot PolarTicks PoleZeroMarkers PolyaAeppliDistribution PolyGamma Polygon Polygon3DBox Polygon3DBoxOptions PolygonBox PolygonBoxOptions PolygonHoleScale PolygonIntersections PolygonScale PolyhedronData PolyLog PolynomialExtendedGCD PolynomialForm PolynomialGCD PolynomialLCM PolynomialMod PolynomialQ PolynomialQuotient PolynomialQuotientRemainder PolynomialReduce PolynomialRemainder Polynomials PopupMenu PopupMenuBox PopupMenuBoxOptions PopupView PopupWindow Position Positive PositiveDefiniteMatrixQ PossibleZeroQ Postfix PostScript Power PowerDistribution PowerExpand PowerMod PowerModList ' +
      'PowerSpectralDensity PowersRepresentations PowerSymmetricPolynomial Precedence PrecedenceForm Precedes PrecedesEqual PrecedesSlantEqual PrecedesTilde Precision PrecisionGoal PreDecrement PredictionRoot PreemptProtect PreferencesPath Prefix PreIncrement Prepend PrependTo PreserveImageOptions Previous PriceGraphDistribution PrimaryPlaceholder Prime PrimeNu PrimeOmega PrimePi PrimePowerQ PrimeQ Primes PrimeZetaP PrimitiveRoot PrincipalComponents PrincipalValue Print PrintAction PrintForm PrintingCopies PrintingOptions PrintingPageRange PrintingStartingPageNumber PrintingStyleEnvironment PrintPrecision PrintTemporary Prism PrismBox PrismBoxOptions PrivateCellOptions PrivateEvaluationOptions PrivateFontOptions PrivateFrontEndOptions PrivateNotebookOptions PrivatePaths Probability ProbabilityDistribution ProbabilityPlot ProbabilityPr ProbabilityScalePlot ProbitModelFit ProcessEstimator ProcessParameterAssumptions ProcessParameterQ ProcessStateDomain ProcessTimeDomain Product ProductDistribution ProductLog ProgressIndicator ProgressIndicatorBox ProgressIndicatorBoxOptions Projection Prolog PromptForm Properties Property PropertyList PropertyValue Proportion Proportional Protect Protected ProteinData Pruning PseudoInverse Purple Put PutAppend Pyramid PyramidBox PyramidBoxOptions ' +
      'QBinomial QFactorial QGamma QHypergeometricPFQ QPochhammer QPolyGamma QRDecomposition QuadraticIrrationalQ Quantile QuantilePlot Quantity QuantityForm QuantityMagnitude QuantityQ QuantityUnit Quartics QuartileDeviation Quartiles QuartileSkewness QueueingNetworkProcess QueueingProcess QueueProperties Quiet Quit Quotient QuotientRemainder ' +
      'RadialityCentrality RadicalBox RadicalBoxOptions RadioButton RadioButtonBar RadioButtonBox RadioButtonBoxOptions Radon RamanujanTau RamanujanTauL RamanujanTauTheta RamanujanTauZ Random RandomChoice RandomComplex RandomFunction RandomGraph RandomImage RandomInteger RandomPermutation RandomPrime RandomReal RandomSample RandomSeed RandomVariate RandomWalkProcess Range RangeFilter RangeSpecification RankedMax RankedMin Raster Raster3D Raster3DBox Raster3DBoxOptions RasterArray RasterBox RasterBoxOptions Rasterize RasterSize Rational RationalFunctions Rationalize Rationals Ratios Raw RawArray RawBoxes RawData RawMedium RayleighDistribution Re Read ReadList ReadProtected Real RealBlockDiagonalForm RealDigits RealExponent Reals Reap Record RecordLists RecordSeparators Rectangle RectangleBox RectangleBoxOptions RectangleChart RectangleChart3D RecurrenceFilter RecurrenceTable RecurringDigitsForm Red Reduce RefBox ReferenceLineStyle ReferenceMarkers ReferenceMarkerStyle Refine ReflectionMatrix ReflectionTransform Refresh RefreshRate RegionBinarize RegionFunction RegionPlot RegionPlot3D RegularExpression Regularization Reinstall Release ReleaseHold ReliabilityDistribution ReliefImage ReliefPlot Remove RemoveAlphaChannel RemoveAsynchronousTask Removed RemoveInputStreamMethod RemoveOutputStreamMethod RemoveProperty RemoveScheduledTask RenameDirectory RenameFile RenderAll RenderingOptions RenewalProcess RenkoChart Repeated RepeatedNull RepeatedString Replace ReplaceAll ReplaceHeldPart ReplaceImageValue ReplaceList ReplacePart ReplacePixelValue ReplaceRepeated Resampling Rescale RescalingTransform ResetDirectory ResetMenusPacket ResetScheduledTask Residue Resolve Rest Resultant ResumePacket Return ReturnExpressionPacket ReturnInputFormPacket ReturnPacket ReturnTextPacket Reverse ReverseBiorthogonalSplineWavelet ReverseElement ReverseEquilibrium ReverseGraph ReverseUpEquilibrium RevolutionAxis RevolutionPlot3D RGBColor RiccatiSolve RiceDistribution RidgeFilter RiemannR RiemannSiegelTheta RiemannSiegelZ Riffle Right RightArrow RightArrowBar RightArrowLeftArrow RightCosetRepresentative RightDownTeeVector RightDownVector RightDownVectorBar RightTee RightTeeArrow RightTeeVector RightTriangle RightTriangleBar RightTriangleEqual RightUpDownVector RightUpTeeVector RightUpVector RightUpVectorBar RightVector RightVectorBar RiskAchievementImportance RiskReductionImportance RogersTanimotoDissimilarity Root RootApproximant RootIntervals RootLocusPlot RootMeanSquare RootOfUnityQ RootReduce Roots RootSum Rotate RotateLabel RotateLeft RotateRight RotationAction RotationBox RotationBoxOptions RotationMatrix RotationTransform Round RoundImplies RoundingRadius Row RowAlignments RowBackgrounds RowBox RowHeights RowLines RowMinHeight RowReduce RowsEqual RowSpacings RSolve RudvalisGroupRu Rule RuleCondition RuleDelayed RuleForm RulerUnits Run RunScheduledTask RunThrough RuntimeAttributes RuntimeOptions RussellRaoDissimilarity ' +
      'SameQ SameTest SampleDepth SampledSoundFunction SampledSoundList SampleRate SamplingPeriod SARIMAProcess SARMAProcess SatisfiabilityCount SatisfiabilityInstances SatisfiableQ Saturday Save Saveable SaveAutoDelete SaveDefinitions SawtoothWave Scale Scaled ScaleDivisions ScaledMousePosition ScaleOrigin ScalePadding ScaleRanges ScaleRangeStyle ScalingFunctions ScalingMatrix ScalingTransform Scan ScheduledTaskActiveQ ScheduledTaskData ScheduledTaskObject ScheduledTasks SchurDecomposition ScientificForm ScreenRectangle ScreenStyleEnvironment ScriptBaselineShifts ScriptLevel ScriptMinSize ScriptRules ScriptSizeMultipliers Scrollbars ScrollingOptions ScrollPosition Sec Sech SechDistribution SectionGrouping SectorChart SectorChart3D SectorOrigin SectorSpacing SeedRandom Select Selectable SelectComponents SelectedCells SelectedNotebook Selection SelectionAnimate SelectionCell SelectionCellCreateCell SelectionCellDefaultStyle SelectionCellParentStyle SelectionCreateCell SelectionDebuggerTag SelectionDuplicateCell SelectionEvaluate SelectionEvaluateCreateCell SelectionMove SelectionPlaceholder SelectionSetStyle SelectWithContents SelfLoops SelfLoopStyle SemialgebraicComponentInstances SendMail Sequence SequenceAlignment SequenceForm SequenceHold SequenceLimit Series SeriesCoefficient SeriesData SessionTime Set SetAccuracy SetAlphaChannel SetAttributes Setbacks SetBoxFormNamesPacket SetDelayed SetDirectory SetEnvironment SetEvaluationNotebook SetFileDate SetFileLoadingContext SetNotebookStatusLine SetOptions SetOptionsPacket SetPrecision SetProperty SetSelectedNotebook SetSharedFunction SetSharedVariable SetSpeechParametersPacket SetStreamPosition SetSystemOptions Setter SetterBar SetterBox SetterBoxOptions Setting SetValue Shading Shallow ShannonWavelet ShapiroWilkTest Share Sharpen ShearingMatrix ShearingTransform ShenCastanMatrix Short ShortDownArrow Shortest ShortestMatch ShortestPathFunction ShortLeftArrow ShortRightArrow ShortUpArrow Show ShowAutoStyles ShowCellBracket ShowCellLabel ShowCellTags ShowClosedCellArea ShowContents ShowControls ShowCursorTracker ShowGroupOpenCloseIcon ShowGroupOpener ShowInvisibleCharacters ShowPageBreaks ShowPredictiveInterface ShowSelection ShowShortBoxForm ShowSpecialCharacters ShowStringCharacters ShowSyntaxStyles ShrinkingDelay ShrinkWrapBoundingBox SiegelTheta SiegelTukeyTest Sign Signature SignedRankTest SignificanceLevel SignPadding SignTest SimilarityRules SimpleGraph SimpleGraphQ Simplify Sin Sinc SinghMaddalaDistribution SingleEvaluation SingleLetterItalics SingleLetterStyle SingularValueDecomposition SingularValueList SingularValuePlot SingularValues Sinh SinhIntegral SinIntegral SixJSymbol Skeleton SkeletonTransform SkellamDistribution Skewness SkewNormalDistribution Skip SliceDistribution Slider Slider2D Slider2DBox Slider2DBoxOptions SliderBox SliderBoxOptions SlideView Slot SlotSequence Small SmallCircle Smaller SmithDelayCompensator SmithWatermanSimilarity ' +
      'SmoothDensityHistogram SmoothHistogram SmoothHistogram3D SmoothKernelDistribution SocialMediaData Socket SokalSneathDissimilarity Solve SolveAlways SolveDelayed Sort SortBy Sound SoundAndGraphics SoundNote SoundVolume Sow Space SpaceForm Spacer Spacings Span SpanAdjustments SpanCharacterRounding SpanFromAbove SpanFromBoth SpanFromLeft SpanLineThickness SpanMaxSize SpanMinSize SpanningCharacters SpanSymmetric SparseArray SpatialGraphDistribution Speak SpeakTextPacket SpearmanRankTest SpearmanRho Spectrogram SpectrogramArray Specularity SpellingCorrection SpellingDictionaries SpellingDictionariesPath SpellingOptions SpellingSuggestionsPacket Sphere SphereBox SphericalBesselJ SphericalBesselY SphericalHankelH1 SphericalHankelH2 SphericalHarmonicY SphericalPlot3D SphericalRegion SpheroidalEigenvalue SpheroidalJoiningFactor SpheroidalPS SpheroidalPSPrime SpheroidalQS SpheroidalQSPrime SpheroidalRadialFactor SpheroidalS1 SpheroidalS1Prime SpheroidalS2 SpheroidalS2Prime Splice SplicedDistribution SplineClosed SplineDegree SplineKnots SplineWeights Split SplitBy SpokenString Sqrt SqrtBox SqrtBoxOptions Square SquaredEuclideanDistance SquareFreeQ SquareIntersection SquaresR SquareSubset SquareSubsetEqual SquareSuperset SquareSupersetEqual SquareUnion SquareWave StabilityMargins StabilityMarginsStyle StableDistribution Stack StackBegin StackComplete StackInhibit StandardDeviation StandardDeviationFilter StandardForm Standardize StandbyDistribution Star StarGraph StartAsynchronousTask StartingStepSize StartOfLine StartOfString StartScheduledTask StartupSound StateDimensions StateFeedbackGains StateOutputEstimator StateResponse StateSpaceModel StateSpaceRealization StateSpaceTransform StationaryDistribution StationaryWaveletPacketTransform StationaryWaveletTransform StatusArea StatusCentrality StepMonitor StieltjesGamma StirlingS1 StirlingS2 StopAsynchronousTask StopScheduledTask StrataVariables StratonovichProcess StreamColorFunction StreamColorFunctionScaling StreamDensityPlot StreamPlot StreamPoints StreamPosition Streams StreamScale StreamStyle String StringBreak StringByteCount StringCases StringCount StringDrop StringExpression StringForm StringFormat StringFreeQ StringInsert StringJoin StringLength StringMatchQ StringPosition StringQ StringReplace StringReplaceList StringReplacePart StringReverse StringRotateLeft StringRotateRight StringSkeleton StringSplit StringTake StringToStream StringTrim StripBoxes StripOnInput StripWrapperBoxes StrokeForm StructuralImportance StructuredArray StructuredSelection StruveH StruveL Stub StudentTDistribution Style StyleBox StyleBoxAutoDelete StyleBoxOptions StyleData StyleDefinitions StyleForm StyleKeyMapping StyleMenuListing StyleNameDialogSettings StyleNames StylePrint StyleSheetPath Subfactorial Subgraph SubMinus SubPlus SubresultantPolynomialRemainders ' +
      'SubresultantPolynomials Subresultants Subscript SubscriptBox SubscriptBoxOptions Subscripted Subset SubsetEqual Subsets SubStar Subsuperscript SubsuperscriptBox SubsuperscriptBoxOptions Subtract SubtractFrom SubValues Succeeds SucceedsEqual SucceedsSlantEqual SucceedsTilde SuchThat Sum SumConvergence Sunday SuperDagger SuperMinus SuperPlus Superscript SuperscriptBox SuperscriptBoxOptions Superset SupersetEqual SuperStar Surd SurdForm SurfaceColor SurfaceGraphics SurvivalDistribution SurvivalFunction SurvivalModel SurvivalModelFit SuspendPacket SuzukiDistribution SuzukiGroupSuz SwatchLegend Switch Symbol SymbolName SymletWavelet Symmetric SymmetricGroup SymmetricMatrixQ SymmetricPolynomial SymmetricReduction Symmetrize SymmetrizedArray SymmetrizedArrayRules SymmetrizedDependentComponents SymmetrizedIndependentComponents SymmetrizedReplacePart SynchronousInitialization SynchronousUpdating Syntax SyntaxForm SyntaxInformation SyntaxLength SyntaxPacket SyntaxQ SystemDialogInput SystemException SystemHelpPath SystemInformation SystemInformationData SystemOpen SystemOptions SystemsModelDelay SystemsModelDelayApproximate SystemsModelDelete SystemsModelDimensions SystemsModelExtract SystemsModelFeedbackConnect SystemsModelLabels SystemsModelOrder SystemsModelParallelConnect SystemsModelSeriesConnect SystemsModelStateFeedbackConnect SystemStub ' +
      'Tab TabFilling Table TableAlignments TableDepth TableDirections TableForm TableHeadings TableSpacing TableView TableViewBox TabSpacings TabView TabViewBox TabViewBoxOptions TagBox TagBoxNote TagBoxOptions TaggingRules TagSet TagSetDelayed TagStyle TagUnset Take TakeWhile Tally Tan Tanh TargetFunctions TargetUnits TautologyQ TelegraphProcess TemplateBox TemplateBoxOptions TemplateSlotSequence TemporalData Temporary TemporaryVariable TensorContract TensorDimensions TensorExpand TensorProduct TensorQ TensorRank TensorReduce TensorSymmetry TensorTranspose TensorWedge Tetrahedron TetrahedronBox TetrahedronBoxOptions TeXForm TeXSave Text Text3DBox Text3DBoxOptions TextAlignment TextBand TextBoundingBox TextBox TextCell TextClipboardType TextData TextForm TextJustification TextLine TextPacket TextParagraph TextRecognize TextRendering TextStyle Texture TextureCoordinateFunction TextureCoordinateScaling Therefore ThermometerGauge Thick Thickness Thin Thinning ThisLink ThompsonGroupTh Thread ThreeJSymbol Threshold Through Throw Thumbnail Thursday Ticks TicksStyle Tilde TildeEqual TildeFullEqual TildeTilde TimeConstrained TimeConstraint Times TimesBy TimeSeriesForecast TimeSeriesInvertibility TimeUsed TimeValue TimeZone Timing Tiny TitleGrouping TitsGroupT ToBoxes ToCharacterCode ToColor ToContinuousTimeModel ToDate ToDiscreteTimeModel ToeplitzMatrix ToExpression ToFileName Together Toggle ToggleFalse Toggler TogglerBar TogglerBox TogglerBoxOptions ToHeldExpression ToInvertibleTimeSeries TokenWords Tolerance ToLowerCase ToNumberField TooBig Tooltip TooltipBox TooltipBoxOptions TooltipDelay TooltipStyle Top TopHatTransform TopologicalSort ToRadicals ToRules ToString Total TotalHeight TotalVariationFilter TotalWidth TouchscreenAutoZoom TouchscreenControlPlacement ToUpperCase Tr Trace TraceAbove TraceAction TraceBackward TraceDepth TraceDialog TraceForward TraceInternal TraceLevel TraceOff TraceOn TraceOriginal TracePrint TraceScan TrackedSymbols TradingChart TraditionalForm TraditionalFunctionNotation TraditionalNotation TraditionalOrder TransferFunctionCancel TransferFunctionExpand TransferFunctionFactor TransferFunctionModel TransferFunctionPoles TransferFunctionTransform TransferFunctionZeros TransformationFunction TransformationFunctions TransformationMatrix TransformedDistribution TransformedField Translate TranslationTransform TransparentColor Transpose TreeForm TreeGraph TreeGraphQ TreePlot TrendStyle TriangleWave TriangularDistribution Trig TrigExpand TrigFactor TrigFactorList Trigger TrigReduce TrigToExp TrimmedMean True TrueQ TruncatedDistribution TsallisQExponentialDistribution TsallisQGaussianDistribution TTest Tube TubeBezierCurveBox TubeBezierCurveBoxOptions TubeBox TubeBSplineCurveBox TubeBSplineCurveBoxOptions Tuesday TukeyLambdaDistribution TukeyWindow Tuples TuranGraph TuringMachine ' +
      'Transparent ' +
      'UnateQ Uncompress Undefined UnderBar Underflow Underlined Underoverscript UnderoverscriptBox UnderoverscriptBoxOptions Underscript UnderscriptBox UnderscriptBoxOptions UndirectedEdge UndirectedGraph UndirectedGraphQ UndocumentedTestFEParserPacket UndocumentedTestGetSelectionPacket Unequal Unevaluated UniformDistribution UniformGraphDistribution UniformSumDistribution Uninstall Union UnionPlus Unique UnitBox UnitConvert UnitDimensions Unitize UnitRootTest UnitSimplify UnitStep UnitTriangle UnitVector Unprotect UnsameQ UnsavedVariables Unset UnsetShared UntrackedVariables Up UpArrow UpArrowBar UpArrowDownArrow Update UpdateDynamicObjects UpdateDynamicObjectsSynchronous UpdateInterval UpDownArrow UpEquilibrium UpperCaseQ UpperLeftArrow UpperRightArrow UpperTriangularize Upsample UpSet UpSetDelayed UpTee UpTeeArrow UpValues URL URLFetch URLFetchAsynchronous URLSave URLSaveAsynchronous UseGraphicsRange Using UsingFrontEnd ' +
      'V2Get ValidationLength Value ValueBox ValueBoxOptions ValueForm ValueQ ValuesData Variables Variance VarianceEquivalenceTest VarianceEstimatorFunction VarianceGammaDistribution VarianceTest VectorAngle VectorColorFunction VectorColorFunctionScaling VectorDensityPlot VectorGlyphData VectorPlot VectorPlot3D VectorPoints VectorQ Vectors VectorScale VectorStyle Vee Verbatim Verbose VerboseConvertToPostScriptPacket VerifyConvergence VerifySolutions VerifyTestAssumptions Version VersionNumber VertexAdd VertexCapacity VertexColors VertexComponent VertexConnectivity VertexCoordinateRules VertexCoordinates VertexCorrelationSimilarity VertexCosineSimilarity VertexCount VertexCoverQ VertexDataCoordinates VertexDegree VertexDelete VertexDiceSimilarity VertexEccentricity VertexInComponent VertexInDegree VertexIndex VertexJaccardSimilarity VertexLabeling VertexLabels VertexLabelStyle VertexList VertexNormals VertexOutComponent VertexOutDegree VertexQ VertexRenderingFunction VertexReplace VertexShape VertexShapeFunction VertexSize VertexStyle VertexTextureCoordinates VertexWeight Vertical VerticalBar VerticalForm VerticalGauge VerticalSeparator VerticalSlider VerticalTilde ViewAngle ViewCenter ViewMatrix ViewPoint ViewPointSelectorSettings ViewPort ViewRange ViewVector ViewVertical VirtualGroupData Visible VisibleCell VoigtDistribution VonMisesDistribution ' +
      'WaitAll WaitAsynchronousTask WaitNext WaitUntil WakebyDistribution WalleniusHypergeometricDistribution WaringYuleDistribution WatershedComponents WatsonUSquareTest WattsStrogatzGraphDistribution WaveletBestBasis WaveletFilterCoefficients WaveletImagePlot WaveletListPlot WaveletMapIndexed WaveletMatrixPlot WaveletPhi WaveletPsi WaveletScale WaveletScalogram WaveletThreshold WeaklyConnectedComponents WeaklyConnectedGraphQ WeakStationarity WeatherData WeberE Wedge Wednesday WeibullDistribution WeierstrassHalfPeriods WeierstrassInvariants WeierstrassP WeierstrassPPrime WeierstrassSigma WeierstrassZeta WeightedAdjacencyGraph WeightedAdjacencyMatrix WeightedData WeightedGraphQ Weights WelchWindow WheelGraph WhenEvent Which While White Whitespace WhitespaceCharacter WhittakerM WhittakerW WienerFilter WienerProcess WignerD WignerSemicircleDistribution WilksW WilksWTest WindowClickSelect WindowElements WindowFloating WindowFrame WindowFrameElements WindowMargins WindowMovable WindowOpacity WindowSelected WindowSize WindowStatusArea WindowTitle WindowToolbars WindowWidth With WolframAlpha WolframAlphaDate WolframAlphaQuantity WolframAlphaResult Word WordBoundary WordCharacter WordData WordSearch WordSeparators WorkingPrecision Write WriteString Wronskian ' +
      'XMLElement XMLObject Xnor Xor ' +
      'Yellow YuleDissimilarity ' +
      'ZernikeR ZeroSymmetric ZeroTest ZeroWidthTimes Zeta ZetaZero ZipfDistribution ZTest ZTransform ' +
      '$Aborted $ActivationGroupID $ActivationKey $ActivationUserRegistered $AddOnsDirectory $AssertFunction $Assumptions $AsynchronousTask $BaseDirectory $BatchInput $BatchOutput $BoxForms $ByteOrdering $Canceled $CharacterEncoding $CharacterEncodings $CommandLine $CompilationTarget $ConditionHold $ConfiguredKernels $Context $ContextPath $ControlActiveSetting $CreationDate $CurrentLink $DateStringFormat $DefaultFont $DefaultFrontEnd $DefaultImagingDevice $DefaultPath $Display $DisplayFunction $DistributedContexts $DynamicEvaluation $Echo $Epilog $ExportFormats $Failed $FinancialDataSource $FormatType $FrontEnd $FrontEndSession $GeoLocation $HistoryLength $HomeDirectory $HTTPCookies $IgnoreEOF $ImagingDevices $ImportFormats $InitialDirectory $Input $InputFileName $InputStreamMethods $Inspector $InstallationDate $InstallationDirectory $InterfaceEnvironment $IterationLimit $KernelCount $KernelID $Language $LaunchDirectory $LibraryPath $LicenseExpirationDate $LicenseID $LicenseProcesses $LicenseServer $LicenseSubprocesses $LicenseType $Line $Linked $LinkSupported $LoadedFiles $MachineAddresses $MachineDomain $MachineDomains $MachineEpsilon $MachineID $MachineName $MachinePrecision $MachineType $MaxExtraPrecision $MaxLicenseProcesses $MaxLicenseSubprocesses $MaxMachineNumber $MaxNumber $MaxPiecewiseCases $MaxPrecision $MaxRootDegree $MessageGroups $MessageList $MessagePrePrint $Messages $MinMachineNumber $MinNumber $MinorReleaseNumber $MinPrecision $ModuleNumber $NetworkLicense $NewMessage $NewSymbol $Notebooks $NumberMarks $Off $OperatingSystem $Output $OutputForms $OutputSizeLimit $OutputStreamMethods $Packages $ParentLink $ParentProcessID $PasswordFile $PatchLevelID $Path $PathnameSeparator $PerformanceGoal $PipeSupported $Post $Pre $PreferencesDirectory $PrePrint $PreRead $PrintForms $PrintLiteral $ProcessID $ProcessorCount $ProcessorType $ProductInformation $ProgramName $RandomState $RecursionLimit $ReleaseNumber $RootDirectory $ScheduledTask $ScriptCommandLine $SessionID $SetParentLink $SharedFunctions $SharedVariables $SoundDisplay $SoundDisplayFunction $SuppressInputFormHeads $SynchronousEvaluation $SyntaxHandler $System $SystemCharacterEncoding $SystemID $SystemWordLength $TemporaryDirectory $TemporaryPrefix $TextStyle $TimedOut $TimeUnit $TimeZone $TopDirectory $TraceOff $TraceOn $TracePattern $TracePostAction $TracePreAction $Urgent $UserAddOnsDirectory $UserBaseDirectory $UserDocumentsDirectory $UserName $Version $VersionNumber',
    contains: [
      {
        className: "comment",
        begin: /\(\*/, end: /\*\)/
      },
      hljs.APOS_STRING_MODE,
      hljs.QUOTE_STRING_MODE,
      hljs.C_NUMBER_MODE,
      {
        className: 'list',
        begin: /\{/, end: /\}/,
        illegal: /:/
      }
    ]
  };
});

hljs.registerLanguage('matlab', function(hljs) {
  var COMMON_CONTAINS = [
    hljs.C_NUMBER_MODE,
    {
      className: 'string',
      begin: '\'', end: '\'',
      contains: [hljs.BACKSLASH_ESCAPE, {begin: '\'\''}]
    }
  ];
  var TRANSPOSE = {
    relevance: 0,
    contains: [
      {
        className: 'operator', begin: /'['\.]*/
      }
    ]
  };

  return {
    keywords: {
      keyword:
        'break case catch classdef continue else elseif end enumerated events for function ' +
        'global if methods otherwise parfor persistent properties return spmd switch try while',
      built_in:
        'sin sind sinh asin asind asinh cos cosd cosh acos acosd acosh tan tand tanh atan ' +
        'atand atan2 atanh sec secd sech asec asecd asech csc cscd csch acsc acscd acsch cot ' +
        'cotd coth acot acotd acoth hypot exp expm1 log log1p log10 log2 pow2 realpow reallog ' +
        'realsqrt sqrt nthroot nextpow2 abs angle complex conj imag real unwrap isreal ' +
        'cplxpair fix floor ceil round mod rem sign airy besselj bessely besselh besseli ' +
        'besselk beta betainc betaln ellipj ellipke erf erfc erfcx erfinv expint gamma ' +
        'gammainc gammaln psi legendre cross dot factor isprime primes gcd lcm rat rats perms ' +
        'nchoosek factorial cart2sph cart2pol pol2cart sph2cart hsv2rgb rgb2hsv zeros ones ' +
        'eye repmat rand randn linspace logspace freqspace meshgrid accumarray size length ' +
        'ndims numel disp isempty isequal isequalwithequalnans cat reshape diag blkdiag tril ' +
        'triu fliplr flipud flipdim rot90 find sub2ind ind2sub bsxfun ndgrid permute ipermute ' +
        'shiftdim circshift squeeze isscalar isvector ans eps realmax realmin pi i inf nan ' +
        'isnan isinf isfinite j why compan gallery hadamard hankel hilb invhilb magic pascal ' +
        'rosser toeplitz vander wilkinson'
    },
    illegal: '(//|"|#|/\\*|\\s+/\\w+)',
    contains: [
      {
        className: 'function',
        beginKeywords: 'function', end: '$',
        contains: [
          hljs.UNDERSCORE_TITLE_MODE,
          {
              className: 'params',
              begin: '\\(', end: '\\)'
          },
          {
              className: 'params',
              begin: '\\[', end: '\\]'
          }
        ]
      },
      {
        begin: /[a-zA-Z_][a-zA-Z_0-9]*'['\.]*/,
        returnBegin: true,
        relevance: 0,
        contains: [
          {begin: /[a-zA-Z_][a-zA-Z_0-9]*/, relevance: 0},
          TRANSPOSE.contains[0]
        ]
      },
      {
        className: 'matrix',
        begin: '\\[', end: '\\]',
        contains: COMMON_CONTAINS,
        relevance: 0,
        starts: TRANSPOSE
      },
      {
        className: 'cell',
        begin: '\\{', end: /}/,
        contains: COMMON_CONTAINS,
        relevance: 0,
        starts: TRANSPOSE
      },
      {
        // transpose operators at the end of a function call
        begin: /\)/,
        relevance: 0,
        starts: TRANSPOSE
      },
      hljs.COMMENT('^\\s*\\%\\{\\s*$', '^\\s*\\%\\}\\s*$'),
      hljs.COMMENT('\\%', '$')
    ].concat(COMMON_CONTAINS)
  };
});

hljs.registerLanguage('mel', function(hljs) {
  return {
    keywords:
      'int float string vector matrix if else switch case default while do for in break ' +
      'continue global proc return about abs addAttr addAttributeEditorNodeHelp addDynamic ' +
      'addNewShelfTab addPP addPanelCategory addPrefixToName advanceToNextDrivenKey ' +
      'affectedNet affects aimConstraint air alias aliasAttr align alignCtx alignCurve ' +
      'alignSurface allViewFit ambientLight angle angleBetween animCone animCurveEditor ' +
      'animDisplay animView annotate appendStringArray applicationName applyAttrPreset ' +
      'applyTake arcLenDimContext arcLengthDimension arclen arrayMapper art3dPaintCtx ' +
      'artAttrCtx artAttrPaintVertexCtx artAttrSkinPaintCtx artAttrTool artBuildPaintMenu ' +
      'artFluidAttrCtx artPuttyCtx artSelectCtx artSetPaintCtx artUserPaintCtx assignCommand ' +
      'assignInputDevice assignViewportFactories attachCurve attachDeviceAttr attachSurface ' +
      'attrColorSliderGrp attrCompatibility attrControlGrp attrEnumOptionMenu ' +
      'attrEnumOptionMenuGrp attrFieldGrp attrFieldSliderGrp attrNavigationControlGrp ' +
      'attrPresetEditWin attributeExists attributeInfo attributeMenu attributeQuery ' +
      'autoKeyframe autoPlace bakeClip bakeFluidShading bakePartialHistory bakeResults ' +
      'bakeSimulation basename basenameEx batchRender bessel bevel bevelPlus binMembership ' +
      'bindSkin blend2 blendShape blendShapeEditor blendShapePanel blendTwoAttr blindDataType ' +
      'boneLattice boundary boxDollyCtx boxZoomCtx bufferCurve buildBookmarkMenu ' +
      'buildKeyframeMenu button buttonManip CBG cacheFile cacheFileCombine cacheFileMerge ' +
      'cacheFileTrack camera cameraView canCreateManip canvas capitalizeString catch ' +
      'catchQuiet ceil changeSubdivComponentDisplayLevel changeSubdivRegion channelBox ' +
      'character characterMap characterOutlineEditor characterize chdir checkBox checkBoxGrp ' +
      'checkDefaultRenderGlobals choice circle circularFillet clamp clear clearCache clip ' +
      'clipEditor clipEditorCurrentTimeCtx clipSchedule clipSchedulerOutliner clipTrimBefore ' +
      'closeCurve closeSurface cluster cmdFileOutput cmdScrollFieldExecuter ' +
      'cmdScrollFieldReporter cmdShell coarsenSubdivSelectionList collision color ' +
      'colorAtPoint colorEditor colorIndex colorIndexSliderGrp colorSliderButtonGrp ' +
      'colorSliderGrp columnLayout commandEcho commandLine commandPort compactHairSystem ' +
      'componentEditor compositingInterop computePolysetVolume condition cone confirmDialog ' +
      'connectAttr connectControl connectDynamic connectJoint connectionInfo constrain ' +
      'constrainValue constructionHistory container containsMultibyte contextInfo control ' +
      'convertFromOldLayers convertIffToPsd convertLightmap convertSolidTx convertTessellation ' +
      'convertUnit copyArray copyFlexor copyKey copySkinWeights cos cpButton cpCache ' +
      'cpClothSet cpCollision cpConstraint cpConvClothToMesh cpForces cpGetSolverAttr cpPanel ' +
      'cpProperty cpRigidCollisionFilter cpSeam cpSetEdit cpSetSolverAttr cpSolver ' +
      'cpSolverTypes cpTool cpUpdateClothUVs createDisplayLayer createDrawCtx createEditor ' +
      'createLayeredPsdFile createMotionField createNewShelf createNode createRenderLayer ' +
      'createSubdivRegion cross crossProduct ctxAbort ctxCompletion ctxEditMode ctxTraverse ' +
      'currentCtx currentTime currentTimeCtx currentUnit curve curveAddPtCtx ' +
      'curveCVCtx curveEPCtx curveEditorCtx curveIntersect curveMoveEPCtx curveOnSurface ' +
      'curveSketchCtx cutKey cycleCheck cylinder dagPose date defaultLightListCheckBox ' +
      'defaultNavigation defineDataServer defineVirtualDevice deformer deg_to_rad delete ' +
      'deleteAttr deleteShadingGroupsAndMaterials deleteShelfTab deleteUI deleteUnusedBrushes ' +
      'delrandstr detachCurve detachDeviceAttr detachSurface deviceEditor devicePanel dgInfo ' +
      'dgdirty dgeval dgtimer dimWhen directKeyCtx directionalLight dirmap dirname disable ' +
      'disconnectAttr disconnectJoint diskCache displacementToPoly displayAffected ' +
      'displayColor displayCull displayLevelOfDetail displayPref displayRGBColor ' +
      'displaySmoothness displayStats displayString displaySurface distanceDimContext ' +
      'distanceDimension doBlur dolly dollyCtx dopeSheetEditor dot dotProduct ' +
      'doubleProfileBirailSurface drag dragAttrContext draggerContext dropoffLocator ' +
      'duplicate duplicateCurve duplicateSurface dynCache dynControl dynExport dynExpression ' +
      'dynGlobals dynPaintEditor dynParticleCtx dynPref dynRelEdPanel dynRelEditor ' +
      'dynamicLoad editAttrLimits editDisplayLayerGlobals editDisplayLayerMembers ' +
      'editRenderLayerAdjustment editRenderLayerGlobals editRenderLayerMembers editor ' +
      'editorTemplate effector emit emitter enableDevice encodeString endString endsWith env ' +
      'equivalent equivalentTol erf error eval evalDeferred evalEcho event ' +
      'exactWorldBoundingBox exclusiveLightCheckBox exec executeForEachObject exists exp ' +
      'expression expressionEditorListen extendCurve extendSurface extrude fcheck fclose feof ' +
      'fflush fgetline fgetword file fileBrowserDialog fileDialog fileExtension fileInfo ' +
      'filetest filletCurve filter filterCurve filterExpand filterStudioImport ' +
      'findAllIntersections findAnimCurves findKeyframe findMenuItem findRelatedSkinCluster ' +
      'finder firstParentOf fitBspline flexor floatEq floatField floatFieldGrp floatScrollBar ' +
      'floatSlider floatSlider2 floatSliderButtonGrp floatSliderGrp floor flow fluidCacheInfo ' +
      'fluidEmitter fluidVoxelInfo flushUndo fmod fontDialog fopen formLayout format fprint ' +
      'frameLayout fread freeFormFillet frewind fromNativePath fwrite gamma gauss ' +
      'geometryConstraint getApplicationVersionAsFloat getAttr getClassification ' +
      'getDefaultBrush getFileList getFluidAttr getInputDeviceRange getMayaPanelTypes ' +
      'getModifiers getPanel getParticleAttr getPluginResource getenv getpid glRender ' +
      'glRenderEditor globalStitch gmatch goal gotoBindPose grabColor gradientControl ' +
      'gradientControlNoAttr graphDollyCtx graphSelectContext graphTrackCtx gravity grid ' +
      'gridLayout group groupObjectsByName HfAddAttractorToAS HfAssignAS HfBuildEqualMap ' +
      'HfBuildFurFiles HfBuildFurImages HfCancelAFR HfConnectASToHF HfCreateAttractor ' +
      'HfDeleteAS HfEditAS HfPerformCreateAS HfRemoveAttractorFromAS HfSelectAttached ' +
      'HfSelectAttractors HfUnAssignAS hardenPointCurve hardware hardwareRenderPanel ' +
      'headsUpDisplay headsUpMessage help helpLine hermite hide hilite hitTest hotBox hotkey ' +
      'hotkeyCheck hsv_to_rgb hudButton hudSlider hudSliderButton hwReflectionMap hwRender ' +
      'hwRenderLoad hyperGraph hyperPanel hyperShade hypot iconTextButton iconTextCheckBox ' +
      'iconTextRadioButton iconTextRadioCollection iconTextScrollList iconTextStaticLabel ' +
      'ikHandle ikHandleCtx ikHandleDisplayScale ikSolver ikSplineHandleCtx ikSystem ' +
      'ikSystemInfo ikfkDisplayMethod illustratorCurves image imfPlugins inheritTransform ' +
      'insertJoint insertJointCtx insertKeyCtx insertKnotCurve insertKnotSurface instance ' +
      'instanceable instancer intField intFieldGrp intScrollBar intSlider intSliderGrp ' +
      'interToUI internalVar intersect iprEngine isAnimCurve isConnected isDirty isParentOf ' +
      'isSameObject isTrue isValidObjectName isValidString isValidUiName isolateSelect ' +
      'itemFilter itemFilterAttr itemFilterRender itemFilterType joint jointCluster jointCtx ' +
      'jointDisplayScale jointLattice keyTangent keyframe keyframeOutliner ' +
      'keyframeRegionCurrentTimeCtx keyframeRegionDirectKeyCtx keyframeRegionDollyCtx ' +
      'keyframeRegionInsertKeyCtx keyframeRegionMoveKeyCtx keyframeRegionScaleKeyCtx ' +
      'keyframeRegionSelectKeyCtx keyframeRegionSetKeyCtx keyframeRegionTrackCtx ' +
      'keyframeStats lassoContext lattice latticeDeformKeyCtx launch launchImageEditor ' +
      'layerButton layeredShaderPort layeredTexturePort layout layoutDialog lightList ' +
      'lightListEditor lightListPanel lightlink lineIntersection linearPrecision linstep ' +
      'listAnimatable listAttr listCameras listConnections listDeviceAttachments listHistory ' +
      'listInputDeviceAxes listInputDeviceButtons listInputDevices listMenuAnnotation ' +
      'listNodeTypes listPanelCategories listRelatives listSets listTransforms ' +
      'listUnselected listerEditor loadFluid loadNewShelf loadPlugin ' +
      'loadPluginLanguageResources loadPrefObjects localizedPanelLabel lockNode loft log ' +
      'longNameOf lookThru ls lsThroughFilter lsType lsUI Mayatomr mag makeIdentity makeLive ' +
      'makePaintable makeRoll makeSingleSurface makeTubeOn makebot manipMoveContext ' +
      'manipMoveLimitsCtx manipOptions manipRotateContext manipRotateLimitsCtx ' +
      'manipScaleContext manipScaleLimitsCtx marker match max memory menu menuBarLayout ' +
      'menuEditor menuItem menuItemToShelf menuSet menuSetPref messageLine min minimizeApp ' +
      'mirrorJoint modelCurrentTimeCtx modelEditor modelPanel mouse movIn movOut move ' +
      'moveIKtoFK moveKeyCtx moveVertexAlongDirection multiProfileBirailSurface mute ' +
      'nParticle nameCommand nameField namespace namespaceInfo newPanelItems newton nodeCast ' +
      'nodeIconButton nodeOutliner nodePreset nodeType noise nonLinear normalConstraint ' +
      'normalize nurbsBoolean nurbsCopyUVSet nurbsCube nurbsEditUV nurbsPlane nurbsSelect ' +
      'nurbsSquare nurbsToPoly nurbsToPolygonsPref nurbsToSubdiv nurbsToSubdivPref ' +
      'nurbsUVSet nurbsViewDirectionVector objExists objectCenter objectLayer objectType ' +
      'objectTypeUI obsoleteProc oceanNurbsPreviewPlane offsetCurve offsetCurveOnSurface ' +
      'offsetSurface openGLExtension openMayaPref optionMenu optionMenuGrp optionVar orbit ' +
      'orbitCtx orientConstraint outlinerEditor outlinerPanel overrideModifier ' +
      'paintEffectsDisplay pairBlend palettePort paneLayout panel panelConfiguration ' +
      'panelHistory paramDimContext paramDimension paramLocator parent parentConstraint ' +
      'particle particleExists particleInstancer particleRenderInfo partition pasteKey ' +
      'pathAnimation pause pclose percent performanceOptions pfxstrokes pickWalk picture ' +
      'pixelMove planarSrf plane play playbackOptions playblast plugAttr plugNode pluginInfo ' +
      'pluginResourceUtil pointConstraint pointCurveConstraint pointLight pointMatrixMult ' +
      'pointOnCurve pointOnSurface pointPosition poleVectorConstraint polyAppend ' +
      'polyAppendFacetCtx polyAppendVertex polyAutoProjection polyAverageNormal ' +
      'polyAverageVertex polyBevel polyBlendColor polyBlindData polyBoolOp polyBridgeEdge ' +
      'polyCacheMonitor polyCheck polyChipOff polyClipboard polyCloseBorder polyCollapseEdge ' +
      'polyCollapseFacet polyColorBlindData polyColorDel polyColorPerVertex polyColorSet ' +
      'polyCompare polyCone polyCopyUV polyCrease polyCreaseCtx polyCreateFacet ' +
      'polyCreateFacetCtx polyCube polyCut polyCutCtx polyCylinder polyCylindricalProjection ' +
      'polyDelEdge polyDelFacet polyDelVertex polyDuplicateAndConnect polyDuplicateEdge ' +
      'polyEditUV polyEditUVShell polyEvaluate polyExtrudeEdge polyExtrudeFacet ' +
      'polyExtrudeVertex polyFlipEdge polyFlipUV polyForceUV polyGeoSampler polyHelix ' +
      'polyInfo polyInstallAction polyLayoutUV polyListComponentConversion polyMapCut ' +
      'polyMapDel polyMapSew polyMapSewMove polyMergeEdge polyMergeEdgeCtx polyMergeFacet ' +
      'polyMergeFacetCtx polyMergeUV polyMergeVertex polyMirrorFace polyMoveEdge ' +
      'polyMoveFacet polyMoveFacetUV polyMoveUV polyMoveVertex polyNormal polyNormalPerVertex ' +
      'polyNormalizeUV polyOptUvs polyOptions polyOutput polyPipe polyPlanarProjection ' +
      'polyPlane polyPlatonicSolid polyPoke polyPrimitive polyPrism polyProjection ' +
      'polyPyramid polyQuad polyQueryBlindData polyReduce polySelect polySelectConstraint ' +
      'polySelectConstraintMonitor polySelectCtx polySelectEditCtx polySeparate ' +
      'polySetToFaceNormal polySewEdge polyShortestPathCtx polySmooth polySoftEdge ' +
      'polySphere polySphericalProjection polySplit polySplitCtx polySplitEdge polySplitRing ' +
      'polySplitVertex polyStraightenUVBorder polySubdivideEdge polySubdivideFacet ' +
      'polyToSubdiv polyTorus polyTransfer polyTriangulate polyUVSet polyUnite polyWedgeFace ' +
      'popen popupMenu pose pow preloadRefEd print progressBar progressWindow projFileViewer ' +
      'projectCurve projectTangent projectionContext projectionManip promptDialog propModCtx ' +
      'propMove psdChannelOutliner psdEditTextureFile psdExport psdTextureFile putenv pwd ' +
      'python querySubdiv quit rad_to_deg radial radioButton radioButtonGrp radioCollection ' +
      'radioMenuItemCollection rampColorPort rand randomizeFollicles randstate rangeControl ' +
      'readTake rebuildCurve rebuildSurface recordAttr recordDevice redo reference ' +
      'referenceEdit referenceQuery refineSubdivSelectionList refresh refreshAE ' +
      'registerPluginResource rehash reloadImage removeJoint removeMultiInstance ' +
      'removePanelCategory rename renameAttr renameSelectionList renameUI render ' +
      'renderGlobalsNode renderInfo renderLayerButton renderLayerParent ' +
      'renderLayerPostProcess renderLayerUnparent renderManip renderPartition ' +
      'renderQualityNode renderSettings renderThumbnailUpdate renderWindowEditor ' +
      'renderWindowSelectContext renderer reorder reorderDeformers requires reroot ' +
      'resampleFluid resetAE resetPfxToPolyCamera resetTool resolutionNode retarget ' +
      'reverseCurve reverseSurface revolve rgb_to_hsv rigidBody rigidSolver roll rollCtx ' +
      'rootOf rot rotate rotationInterpolation roundConstantRadius rowColumnLayout rowLayout ' +
      'runTimeCommand runup sampleImage saveAllShelves saveAttrPreset saveFluid saveImage ' +
      'saveInitialState saveMenu savePrefObjects savePrefs saveShelf saveToolSettings scale ' +
      'scaleBrushBrightness scaleComponents scaleConstraint scaleKey scaleKeyCtx sceneEditor ' +
      'sceneUIReplacement scmh scriptCtx scriptEditorInfo scriptJob scriptNode scriptTable ' +
      'scriptToShelf scriptedPanel scriptedPanelType scrollField scrollLayout sculpt ' +
      'searchPathArray seed selLoadSettings select selectContext selectCurveCV selectKey ' +
      'selectKeyCtx selectKeyframeRegionCtx selectMode selectPref selectPriority selectType ' +
      'selectedNodes selectionConnection separator setAttr setAttrEnumResource ' +
      'setAttrMapping setAttrNiceNameResource setConstraintRestPosition ' +
      'setDefaultShadingGroup setDrivenKeyframe setDynamic setEditCtx setEditor setFluidAttr ' +
      'setFocus setInfinity setInputDeviceMapping setKeyCtx setKeyPath setKeyframe ' +
      'setKeyframeBlendshapeTargetWts setMenuMode setNodeNiceNameResource setNodeTypeFlag ' +
      'setParent setParticleAttr setPfxToPolyCamera setPluginResource setProject ' +
      'setStampDensity setStartupMessage setState setToolTo setUITemplate setXformManip sets ' +
      'shadingConnection shadingGeometryRelCtx shadingLightRelCtx shadingNetworkCompare ' +
      'shadingNode shapeCompare shelfButton shelfLayout shelfTabLayout shellField ' +
      'shortNameOf showHelp showHidden showManipCtx showSelectionInTitle ' +
      'showShadingGroupAttrEditor showWindow sign simplify sin singleProfileBirailSurface ' +
      'size sizeBytes skinCluster skinPercent smoothCurve smoothTangentSurface smoothstep ' +
      'snap2to2 snapKey snapMode snapTogetherCtx snapshot soft softMod softModCtx sort sound ' +
      'soundControl source spaceLocator sphere sphrand spotLight spotLightPreviewPort ' +
      'spreadSheetEditor spring sqrt squareSurface srtContext stackTrace startString ' +
      'startsWith stitchAndExplodeShell stitchSurface stitchSurfacePoints strcmp ' +
      'stringArrayCatenate stringArrayContains stringArrayCount stringArrayInsertAtIndex ' +
      'stringArrayIntersector stringArrayRemove stringArrayRemoveAtIndex ' +
      'stringArrayRemoveDuplicates stringArrayRemoveExact stringArrayToString ' +
      'stringToStringArray strip stripPrefixFromName stroke subdAutoProjection ' +
      'subdCleanTopology subdCollapse subdDuplicateAndConnect subdEditUV ' +
      'subdListComponentConversion subdMapCut subdMapSewMove subdMatchTopology subdMirror ' +
      'subdToBlind subdToPoly subdTransferUVsToCache subdiv subdivCrease ' +
      'subdivDisplaySmoothness substitute substituteAllString substituteGeometry substring ' +
      'surface surfaceSampler surfaceShaderList swatchDisplayPort switchTable symbolButton ' +
      'symbolCheckBox sysFile system tabLayout tan tangentConstraint texLatticeDeformContext ' +
      'texManipContext texMoveContext texMoveUVShellContext texRotateContext texScaleContext ' +
      'texSelectContext texSelectShortestPathCtx texSmudgeUVContext texWinToolCtx text ' +
      'textCurves textField textFieldButtonGrp textFieldGrp textManip textScrollList ' +
      'textToShelf textureDisplacePlane textureHairColor texturePlacementContext ' +
      'textureWindow threadCount threePointArcCtx timeControl timePort timerX toNativePath ' +
      'toggle toggleAxis toggleWindowVisibility tokenize tokenizeList tolerance tolower ' +
      'toolButton toolCollection toolDropped toolHasOptions toolPropertyWindow torus toupper ' +
      'trace track trackCtx transferAttributes transformCompare transformLimits translator ' +
      'trim trunc truncateFluidCache truncateHairCache tumble tumbleCtx turbulence ' +
      'twoPointArcCtx uiRes uiTemplate unassignInputDevice undo undoInfo ungroup uniform unit ' +
      'unloadPlugin untangleUV untitledFileName untrim upAxis updateAE userCtx uvLink ' +
      'uvSnapshot validateShelfName vectorize view2dToolCtx viewCamera viewClipPlane ' +
      'viewFit viewHeadOn viewLookAt viewManip viewPlace viewSet visor volumeAxis vortex ' +
      'waitCursor warning webBrowser webBrowserPrefs whatIs window windowPref wire ' +
      'wireContext workspace wrinkle wrinkleContext writeTake xbmLangPathList xform',
    illegal: '</',
    contains: [
      hljs.C_NUMBER_MODE,
      hljs.APOS_STRING_MODE,
      hljs.QUOTE_STRING_MODE,
      {
        className: 'string',
        begin: '`', end: '`',
        contains: [hljs.BACKSLASH_ESCAPE]
      },
      {
        className: 'variable',
        variants: [
          {begin: '\\$\\d'},
          {begin: '[\\$\\%\\@](\\^\\w\\b|#\\w+|[^\\s\\w{]|{\\w+}|\\w+)'},
          {begin: '\\*(\\^\\w\\b|#\\w+|[^\\s\\w{]|{\\w+}|\\w+)', relevance: 0}
        ]
      },
      hljs.C_LINE_COMMENT_MODE,
      hljs.C_BLOCK_COMMENT_MODE
    ]
  };
});

hljs.registerLanguage('mercury', function(hljs) {
  var KEYWORDS = {
    keyword:
      'module use_module import_module include_module end_module initialise ' +
      'mutable initialize finalize finalise interface implementation pred ' +
      'mode func type inst solver any_pred any_func is semidet det nondet ' +
      'multi erroneous failure cc_nondet cc_multi typeclass instance where ' +
      'pragma promise external trace atomic or_else require_complete_switch ' +
      'require_det require_semidet require_multi require_nondet ' +
      'require_cc_multi require_cc_nondet require_erroneous require_failure',
    pragma:
      'inline no_inline type_spec source_file fact_table obsolete memo ' +
      'loop_check minimal_model terminates does_not_terminate ' +
      'check_termination promise_equivalent_clauses',
    preprocessor:
      'foreign_proc foreign_decl foreign_code foreign_type ' +
      'foreign_import_module foreign_export_enum foreign_export ' +
      'foreign_enum may_call_mercury will_not_call_mercury thread_safe ' +
      'not_thread_safe maybe_thread_safe promise_pure promise_semipure ' +
      'tabled_for_io local untrailed trailed attach_to_io_state ' +
      'can_pass_as_mercury_type stable will_not_throw_exception ' +
      'may_modify_trail will_not_modify_trail may_duplicate ' +
      'may_not_duplicate affects_liveness does_not_affect_liveness ' +
      'doesnt_affect_liveness no_sharing unknown_sharing sharing',
    built_in:
      'some all not if then else true fail false try catch catch_any ' +
      'semidet_true semidet_false semidet_fail impure_true impure semipure'
  };

  var TODO = {
    className: 'label',
    begin: 'XXX', end: '$', endsWithParent: true,
    relevance: 0
  };
  var COMMENT = hljs.inherit(hljs.C_LINE_COMMENT_MODE, {begin: '%'});
  var CCOMMENT = hljs.inherit(hljs.C_BLOCK_COMMENT_MODE, {relevance: 0});
  COMMENT.contains.push(TODO);
  CCOMMENT.contains.push(TODO);

  var NUMCODE = {
    className: 'number',
    begin: "0'.\\|0[box][0-9a-fA-F]*"
  };

  var ATOM = hljs.inherit(hljs.APOS_STRING_MODE, {relevance: 0});
  var STRING = hljs.inherit(hljs.QUOTE_STRING_MODE, {relevance: 0});
  var STRING_FMT = {
    className: 'constant',
    begin: '\\\\[abfnrtv]\\|\\\\x[0-9a-fA-F]*\\\\\\|%[-+# *.0-9]*[dioxXucsfeEgGp]',
    relevance: 0
  };
  STRING.contains.push(STRING_FMT);

  var IMPLICATION = {
    className: 'built_in',
    variants: [
      {begin: '<=>'},
      {begin: '<=', relevance: 0},
      {begin: '=>', relevance: 0},
      {begin: '/\\\\'},
      {begin: '\\\\/'}
    ]
  };

  var HEAD_BODY_CONJUNCTION = {
    className: 'built_in',
    variants: [
      {begin: ':-\\|-->'},
      {begin: '=', relevance: 0}
    ]
  };

  return {
    aliases: ['m', 'moo'],
    keywords: KEYWORDS,
    contains: [
      IMPLICATION,
      HEAD_BODY_CONJUNCTION,
      COMMENT,
      CCOMMENT,
      NUMCODE,
      hljs.NUMBER_MODE,
      ATOM,
      STRING,
      {begin: /:-/} // relevance booster
    ]
  };
});

hljs.registerLanguage('mizar', function(hljs) {
  return {
    keywords:
      'environ vocabularies notations constructors definitions ' +
      'registrations theorems schemes requirements begin end definition ' +
      'registration cluster existence pred func defpred deffunc theorem ' +
      'proof let take assume then thus hence ex for st holds consider ' +
      'reconsider such that and in provided of as from be being by means ' +
      'equals implies iff redefine define now not or attr is mode ' +
      'suppose per cases set thesis contradiction scheme reserve struct ' +
      'correctness compatibility coherence symmetry assymetry ' +
      'reflexivity irreflexivity connectedness uniqueness commutativity ' +
      'idempotence involutiveness projectivity',
    contains: [
      hljs.COMMENT('::', '$')
    ]
  };
});

hljs.registerLanguage('perl', function(hljs) {
  var PERL_KEYWORDS = 'getpwent getservent quotemeta msgrcv scalar kill dbmclose undef lc ' +
    'ma syswrite tr send umask sysopen shmwrite vec qx utime local oct semctl localtime ' +
    'readpipe do return format read sprintf dbmopen pop getpgrp not getpwnam rewinddir qq' +
    'fileno qw endprotoent wait sethostent bless s|0 opendir continue each sleep endgrent ' +
    'shutdown dump chomp connect getsockname die socketpair close flock exists index shmget' +
    'sub for endpwent redo lstat msgctl setpgrp abs exit select print ref gethostbyaddr ' +
    'unshift fcntl syscall goto getnetbyaddr join gmtime symlink semget splice x|0 ' +
    'getpeername recv log setsockopt cos last reverse gethostbyname getgrnam study formline ' +
    'endhostent times chop length gethostent getnetent pack getprotoent getservbyname rand ' +
    'mkdir pos chmod y|0 substr endnetent printf next open msgsnd readdir use unlink ' +
    'getsockopt getpriority rindex wantarray hex system getservbyport endservent int chr ' +
    'untie rmdir prototype tell listen fork shmread ucfirst setprotoent else sysseek link ' +
    'getgrgid shmctl waitpid unpack getnetbyname reset chdir grep split require caller ' +
    'lcfirst until warn while values shift telldir getpwuid my getprotobynumber delete and ' +
    'sort uc defined srand accept package seekdir getprotobyname semop our rename seek if q|0 ' +
    'chroot sysread setpwent no crypt getc chown sqrt write setnetent setpriority foreach ' +
    'tie sin msgget map stat getlogin unless elsif truncate exec keys glob tied closedir' +
    'ioctl socket readlink eval xor readline binmode setservent eof ord bind alarm pipe ' +
    'atan2 getgrent exp time push setgrent gt lt or ne m|0 break given say state when';
  var SUBST = {
    className: 'subst',
    begin: '[$@]\\{', end: '\\}',
    keywords: PERL_KEYWORDS
  };
  var METHOD = {
    begin: '->{', end: '}'
    // contains defined later
  };
  var VAR = {
    className: 'variable',
    variants: [
      {begin: /\$\d/},
      {begin: /[\$%@](\^\w\b|#\w+(::\w+)*|{\w+}|\w+(::\w*)*)/},
      {begin: /[\$%@][^\s\w{]/, relevance: 0}
    ]
  };
  var STRING_CONTAINS = [hljs.BACKSLASH_ESCAPE, SUBST, VAR];
  var PERL_DEFAULT_CONTAINS = [
    VAR,
    hljs.HASH_COMMENT_MODE,
    hljs.COMMENT(
      '^\\=\\w',
      '\\=cut',
      {
        endsWithParent: true
      }
    ),
    METHOD,
    {
      className: 'string',
      contains: STRING_CONTAINS,
      variants: [
        {
          begin: 'q[qwxr]?\\s*\\(', end: '\\)',
          relevance: 5
        },
        {
          begin: 'q[qwxr]?\\s*\\[', end: '\\]',
          relevance: 5
        },
        {
          begin: 'q[qwxr]?\\s*\\{', end: '\\}',
          relevance: 5
        },
        {
          begin: 'q[qwxr]?\\s*\\|', end: '\\|',
          relevance: 5
        },
        {
          begin: 'q[qwxr]?\\s*\\<', end: '\\>',
          relevance: 5
        },
        {
          begin: 'qw\\s+q', end: 'q',
          relevance: 5
        },
        {
          begin: '\'', end: '\'',
          contains: [hljs.BACKSLASH_ESCAPE]
        },
        {
          begin: '"', end: '"'
        },
        {
          begin: '`', end: '`',
          contains: [hljs.BACKSLASH_ESCAPE]
        },
        {
          begin: '{\\w+}',
          contains: [],
          relevance: 0
        },
        {
          begin: '\-?\\w+\\s*\\=\\>',
          contains: [],
          relevance: 0
        }
      ]
    },
    {
      className: 'number',
      begin: '(\\b0[0-7_]+)|(\\b0x[0-9a-fA-F_]+)|(\\b[1-9][0-9_]*(\\.[0-9_]+)?)|[0_]\\b',
      relevance: 0
    },
    { // regexp container
      begin: '(\\/\\/|' + hljs.RE_STARTERS_RE + '|\\b(split|return|print|reverse|grep)\\b)\\s*',
      keywords: 'split return print reverse grep',
      relevance: 0,
      contains: [
        hljs.HASH_COMMENT_MODE,
        {
          className: 'regexp',
          begin: '(s|tr|y)/(\\\\.|[^/])*/(\\\\.|[^/])*/[a-z]*',
          relevance: 10
        },
        {
          className: 'regexp',
          begin: '(m|qr)?/', end: '/[a-z]*',
          contains: [hljs.BACKSLASH_ESCAPE],
          relevance: 0 // allows empty "//" which is a common comment delimiter in other languages
        }
      ]
    },
    {
      className: 'sub',
      beginKeywords: 'sub', end: '(\\s*\\(.*?\\))?[;{]',
      relevance: 5
    },
    {
      className: 'operator',
      begin: '-\\w\\b',
      relevance: 0
    },
    {
      begin: "^__DATA__$",
      end: "^__END__$",
      subLanguage: 'mojolicious',
      contains: [
        {
            begin: "^@@.*",
            end: "$",
            className: "comment"
        }
      ]
    }
  ];
  SUBST.contains = PERL_DEFAULT_CONTAINS;
  METHOD.contains = PERL_DEFAULT_CONTAINS;

  return {
    aliases: ['pl'],
    keywords: PERL_KEYWORDS,
    contains: PERL_DEFAULT_CONTAINS
  };
});

hljs.registerLanguage('mojolicious', function(hljs) {
  return {
    subLanguage: 'xml',
    contains: [
      {
        className: 'preprocessor',
        begin: '^__(END|DATA)__$'
      },
    // mojolicious line
      {
        begin: "^\\s*%{1,2}={0,2}", end: '$',
        subLanguage: 'perl'
      },
    // mojolicious block
      {
        begin: "<%{1,2}={0,2}",
        end: "={0,1}%>",
        subLanguage: 'perl',
        excludeBegin: true,
        excludeEnd: true
      }
    ]
  };
});

hljs.registerLanguage('monkey', function(hljs) {
  var NUMBER = {
    className: 'number', relevance: 0,
    variants: [
      {
        begin: '[$][a-fA-F0-9]+'
      },
      hljs.NUMBER_MODE
    ]
  };

  return {
    case_insensitive: true,
    keywords: {
      keyword: 'public private property continue exit extern new try catch ' +
        'eachin not abstract final select case default const local global field ' +
        'end if then else elseif endif while wend repeat until forever for to step next return module inline throw',

      built_in: 'DebugLog DebugStop Error Print ACos ACosr ASin ASinr ATan ATan2 ATan2r ATanr Abs Abs Ceil ' +
        'Clamp Clamp Cos Cosr Exp Floor Log Max Max Min Min Pow Sgn Sgn Sin Sinr Sqrt Tan Tanr Seed PI HALFPI TWOPI',

      literal: 'true false null and or shl shr mod'
    },
    illegal: /\/\*/,
    contains: [
      hljs.COMMENT('#rem', '#end'),
      hljs.COMMENT(
        "'",
        '$',
        {
          relevance: 0
        }
      ),
      {
        className: 'function',
        beginKeywords: 'function method', end: '[(=:]|$',
        illegal: /\n/,
        contains: [
          hljs.UNDERSCORE_TITLE_MODE
        ]
      },
      {
        className: 'class',
        beginKeywords: 'class interface', end: '$',
        contains: [
          {
            beginKeywords: 'extends implements'
          },
          hljs.UNDERSCORE_TITLE_MODE
        ]
      },
      {
        className: 'variable',
        begin: '\\b(self|super)\\b'
      },
      {
        className: 'preprocessor',
        beginKeywords: 'import',
        end: '$'
      },
      {
        className: 'preprocessor',
        begin: '\\s*#', end: '$',
        keywords: 'if else elseif endif end then'
      },
      {
        className: 'pi',
        begin: '^\\s*strict\\b'
      },
      {
        beginKeywords: 'alias', end: '=',
        contains: [hljs.UNDERSCORE_TITLE_MODE]
      },
      hljs.QUOTE_STRING_MODE,
      NUMBER
    ]
  }
});

hljs.registerLanguage('nginx', function(hljs) {
  var VAR = {
    className: 'variable',
    variants: [
      {begin: /\$\d+/},
      {begin: /\$\{/, end: /}/},
      {begin: '[\\$\\@]' + hljs.UNDERSCORE_IDENT_RE}
    ]
  };
  var DEFAULT = {
    endsWithParent: true,
    lexemes: '[a-z/_]+',
    keywords: {
      built_in:
        'on off yes no true false none blocked debug info notice warn error crit ' +
        'select break last permanent redirect kqueue rtsig epoll poll /dev/poll'
    },
    relevance: 0,
    illegal: '=>',
    contains: [
      hljs.HASH_COMMENT_MODE,
      {
        className: 'string',
        contains: [hljs.BACKSLASH_ESCAPE, VAR],
        variants: [
          {begin: /"/, end: /"/},
          {begin: /'/, end: /'/}
        ]
      },
      {
        className: 'url',
        begin: '([a-z]+):/', end: '\\s', endsWithParent: true, excludeEnd: true,
        contains: [VAR]
      },
      {
        className: 'regexp',
        contains: [hljs.BACKSLASH_ESCAPE, VAR],
        variants: [
          {begin: "\\s\\^", end: "\\s|{|;", returnEnd: true},
          // regexp locations (~, ~*)
          {begin: "~\\*?\\s+", end: "\\s|{|;", returnEnd: true},
          // *.example.com
          {begin: "\\*(\\.[a-z\\-]+)+"},
          // sub.example.*
          {begin: "([a-z\\-]+\\.)+\\*"}
        ]
      },
      // IP
      {
        className: 'number',
        begin: '\\b\\d{1,3}\\.\\d{1,3}\\.\\d{1,3}\\.\\d{1,3}(:\\d{1,5})?\\b'
      },
      // units
      {
        className: 'number',
        begin: '\\b\\d+[kKmMgGdshdwy]*\\b',
        relevance: 0
      },
      VAR
    ]
  };

  return {
    aliases: ['nginxconf'],
    contains: [
      hljs.HASH_COMMENT_MODE,
      {
        begin: hljs.UNDERSCORE_IDENT_RE + '\\s', end: ';|{', returnBegin: true,
        contains: [
          {
            className: 'title',
            begin: hljs.UNDERSCORE_IDENT_RE,
            starts: DEFAULT
          }
        ],
        relevance: 0
      }
    ],
    illegal: '[^\\s\\}]'
  };
});

hljs.registerLanguage('nimrod', function(hljs) {
  return {
    aliases: ['nim'],
    keywords: {
      keyword: 'addr and as asm bind block break|0 case|0 cast const|0 continue|0 converter discard distinct|10 div do elif else|0 end|0 enum|0 except export finally for from generic if|0 import|0 in include|0 interface is isnot|10 iterator|10 let|0 macro method|10 mixin mod nil not notin|10 object|0 of or out proc|10 ptr raise ref|10 return shl shr static template try|0 tuple type|0 using|0 var|0 when while|0 with without xor yield',
      literal: 'shared guarded stdin stdout stderr result|10 true false'
    },
    contains: [ {
        className: 'decorator', // Actually pragma
        begin: /{\./,
        end: /\.}/,
        relevance: 10
      }, {
        className: 'string',
        begin: /[a-zA-Z]\w*"/,
        end: /"/,
        contains: [{begin: /""/}]
      }, {
        className: 'string',
        begin: /([a-zA-Z]\w*)?"""/,
        end: /"""/
      },
      hljs.QUOTE_STRING_MODE,
      {
        className: 'type',
        begin: /\b[A-Z]\w+\b/,
        relevance: 0
      }, {
        className: 'type',
        begin: /\b(int|int8|int16|int32|int64|uint|uint8|uint16|uint32|uint64|float|float32|float64|bool|char|string|cstring|pointer|expr|stmt|void|auto|any|range|array|openarray|varargs|seq|set|clong|culong|cchar|cschar|cshort|cint|csize|clonglong|cfloat|cdouble|clongdouble|cuchar|cushort|cuint|culonglong|cstringarray|semistatic)\b/
      }, {
        className: 'number',
        begin: /\b(0[xX][0-9a-fA-F][_0-9a-fA-F]*)('?[iIuU](8|16|32|64))?/,
        relevance: 0
      }, {
        className: 'number',
        begin: /\b(0o[0-7][_0-7]*)('?[iIuUfF](8|16|32|64))?/,
        relevance: 0
      }, {
        className: 'number',
        begin: /\b(0(b|B)[01][_01]*)('?[iIuUfF](8|16|32|64))?/,
        relevance: 0
      }, {
        className: 'number',
        begin: /\b(\d[_\d]*)('?[iIuUfF](8|16|32|64))?/,
        relevance: 0
      },
      hljs.HASH_COMMENT_MODE
    ]
  }
});

hljs.registerLanguage('nix', function(hljs) {
  var NIX_KEYWORDS = {
    keyword: 'rec with let in inherit assert if else then',
    constant: 'true false or and null',
    built_in:
      'import abort baseNameOf dirOf isNull builtins map removeAttrs throw toString derivation'
  };
  var ANTIQUOTE = {
    className: 'subst',
    begin: /\$\{/,
    end: /}/,
    keywords: NIX_KEYWORDS
  };
  var ATTRS = {
    className: 'variable',
    // TODO: we have to figure out a way how to exclude \s*=
    begin: /[a-zA-Z0-9-_]+(\s*=)/,
    relevance: 0
  };
  var SINGLE_QUOTE = {
    className: 'string',
    begin: "''",
    end: "''",
    contains: [
      ANTIQUOTE
    ]
  };
  var DOUBLE_QUOTE = {
    className: 'string',
    begin: '"',
    end: '"',
    contains: [
      ANTIQUOTE
    ]
  };
  var EXPRESSIONS = [
    hljs.NUMBER_MODE,
    hljs.HASH_COMMENT_MODE,
    hljs.C_BLOCK_COMMENT_MODE,
    SINGLE_QUOTE,
    DOUBLE_QUOTE,
    ATTRS
  ];
  ANTIQUOTE.contains = EXPRESSIONS;
  return {
    aliases: ["nixos"],
    keywords: NIX_KEYWORDS,
    contains: EXPRESSIONS
  };
});

hljs.registerLanguage('nsis', function(hljs) {
  var CONSTANTS = {
    className: 'symbol',
    begin: '\\$(ADMINTOOLS|APPDATA|CDBURN_AREA|CMDLINE|COMMONFILES32|COMMONFILES64|COMMONFILES|COOKIES|DESKTOP|DOCUMENTS|EXEDIR|EXEFILE|EXEPATH|FAVORITES|FONTS|HISTORY|HWNDPARENT|INSTDIR|INTERNET_CACHE|LANGUAGE|LOCALAPPDATA|MUSIC|NETHOOD|OUTDIR|PICTURES|PLUGINSDIR|PRINTHOOD|PROFILE|PROGRAMFILES32|PROGRAMFILES64|PROGRAMFILES|QUICKLAUNCH|RECENT|RESOURCES_LOCALIZED|RESOURCES|SENDTO|SMPROGRAMS|SMSTARTUP|STARTMENU|SYSDIR|TEMP|TEMPLATES|VIDEOS|WINDIR)'
  };

  var DEFINES = {
    // ${defines}
    className: 'constant',
    begin: '\\$+{[a-zA-Z0-9_]+}'
  };

  var VARIABLES = {
    // $variables
    className: 'variable',
    begin: '\\$+[a-zA-Z0-9_]+',
    illegal: '\\(\\){}'
  };

  var LANGUAGES = {
    // $(language_strings)
    className: 'constant',
    begin: '\\$+\\([a-zA-Z0-9_]+\\)'
  };

  var PARAMETERS = {
    // command parameters
    className: 'params',
    begin: '(ARCHIVE|FILE_ATTRIBUTE_ARCHIVE|FILE_ATTRIBUTE_NORMAL|FILE_ATTRIBUTE_OFFLINE|FILE_ATTRIBUTE_READONLY|FILE_ATTRIBUTE_SYSTEM|FILE_ATTRIBUTE_TEMPORARY|HKCR|HKCU|HKDD|HKEY_CLASSES_ROOT|HKEY_CURRENT_CONFIG|HKEY_CURRENT_USER|HKEY_DYN_DATA|HKEY_LOCAL_MACHINE|HKEY_PERFORMANCE_DATA|HKEY_USERS|HKLM|HKPD|HKU|IDABORT|IDCANCEL|IDIGNORE|IDNO|IDOK|IDRETRY|IDYES|MB_ABORTRETRYIGNORE|MB_DEFBUTTON1|MB_DEFBUTTON2|MB_DEFBUTTON3|MB_DEFBUTTON4|MB_ICONEXCLAMATION|MB_ICONINFORMATION|MB_ICONQUESTION|MB_ICONSTOP|MB_OK|MB_OKCANCEL|MB_RETRYCANCEL|MB_RIGHT|MB_RTLREADING|MB_SETFOREGROUND|MB_TOPMOST|MB_USERICON|MB_YESNO|NORMAL|OFFLINE|READONLY|SHCTX|SHELL_CONTEXT|SYSTEM|TEMPORARY)'
  };

  var COMPILER ={
    // !compiler_flags
    className: 'constant',
    begin: '\\!(addincludedir|addplugindir|appendfile|cd|define|delfile|echo|else|endif|error|execute|finalize|getdllversionsystem|ifdef|ifmacrodef|ifmacrondef|ifndef|if|include|insertmacro|macroend|macro|makensis|packhdr|searchparse|searchreplace|tempfile|undef|verbose|warning)'
  };

  return {
    case_insensitive: false,
    keywords: {
      keyword:
      'Abort AddBrandingImage AddSize AllowRootDirInstall AllowSkipFiles AutoCloseWindow BGFont BGGradient BrandingText BringToFront Call CallInstDLL Caption ChangeUI CheckBitmap ClearErrors CompletedText ComponentText CopyFiles CRCCheck CreateDirectory CreateFont CreateShortCut Delete DeleteINISec DeleteINIStr DeleteRegKey DeleteRegValue DetailPrint DetailsButtonText DirText DirVar DirVerify EnableWindow EnumRegKey EnumRegValue Exch Exec ExecShell ExecWait ExpandEnvStrings File FileBufSize FileClose FileErrorText FileOpen FileRead FileReadByte FileReadUTF16LE FileReadWord FileSeek FileWrite FileWriteByte FileWriteUTF16LE FileWriteWord FindClose FindFirst FindNext FindWindow FlushINI FunctionEnd GetCurInstType GetCurrentAddress GetDlgItem GetDLLVersion GetDLLVersionLocal GetErrorLevel GetFileTime GetFileTimeLocal GetFullPathName GetFunctionAddress GetInstDirError GetLabelAddress GetTempFileName Goto HideWindow Icon IfAbort IfErrors IfFileExists IfRebootFlag IfSilent InitPluginsDir InstallButtonText InstallColors InstallDir InstallDirRegKey InstProgressFlags InstType InstTypeGetText InstTypeSetText IntCmp IntCmpU IntFmt IntOp IsWindow LangString LicenseBkColor LicenseData LicenseForceSelection LicenseLangString LicenseText LoadLanguageFile LockWindow LogSet LogText ManifestDPIAware ManifestSupportedOS MessageBox MiscButtonText Name Nop OutFile Page PageCallbacks PageExEnd Pop Push Quit ReadEnvStr ReadINIStr ReadRegDWORD ReadRegStr Reboot RegDLL Rename RequestExecutionLevel ReserveFile Return RMDir SearchPath SectionEnd SectionGetFlags SectionGetInstTypes SectionGetSize SectionGetText SectionGroupEnd SectionIn SectionSetFlags SectionSetInstTypes SectionSetSize SectionSetText SendMessage SetAutoClose SetBrandingImage SetCompress SetCompressor SetCompressorDictSize SetCtlColors SetCurInstType SetDatablockOptimize SetDateSave SetDetailsPrint SetDetailsView SetErrorLevel SetErrors SetFileAttributes SetFont SetOutPath SetOverwrite SetPluginUnload SetRebootFlag SetRegView SetShellVarContext SetSilent ShowInstDetails ShowUninstDetails ShowWindow SilentInstall SilentUnInstall Sleep SpaceTexts StrCmp StrCmpS StrCpy StrLen SubCaption SubSectionEnd Unicode UninstallButtonText UninstallCaption UninstallIcon UninstallSubCaption UninstallText UninstPage UnRegDLL Var VIAddVersionKey VIFileVersion VIProductVersion WindowIcon WriteINIStr WriteRegBin WriteRegDWORD WriteRegExpandStr WriteRegStr WriteUninstaller XPStyle',
      literal:
      'admin all auto both colored current false force hide highest lastused leave listonly none normal notset off on open print show silent silentlog smooth textonly true user '
    },
    contains: [
      hljs.HASH_COMMENT_MODE,
      hljs.C_BLOCK_COMMENT_MODE,
      {
        className: 'string',
        begin: '"', end: '"',
        illegal: '\\n',
        contains: [
          { // $\n, $\r, $\t, $$
            className: 'symbol',
            begin: '\\$(\\\\(n|r|t)|\\$)'
          },
          CONSTANTS,
          DEFINES,
          VARIABLES,
          LANGUAGES
        ]
      },
      hljs.COMMENT(
        ';',
        '$',
        {
          relevance: 0
        }
      ),
      {
        className: 'function',
        beginKeywords: 'Function PageEx Section SectionGroup SubSection', end: '$'
      },
      COMPILER,
      DEFINES,
      VARIABLES,
      LANGUAGES,
      PARAMETERS,
      hljs.NUMBER_MODE,
      { // plug::ins
        className: 'literal',
        begin: hljs.IDENT_RE + '::' + hljs.IDENT_RE
      }
    ]
  };
});

hljs.registerLanguage('objectivec', function(hljs) {
  var API_CLASS = {
    className: 'built_in',
    begin: '(AV|CA|CF|CG|CI|MK|MP|NS|UI)\\w+',
  };
  var OBJC_KEYWORDS = {
    keyword:
      'int float while char export sizeof typedef const struct for union ' +
      'unsigned long volatile static bool mutable if do return goto void ' +
      'enum else break extern asm case short default double register explicit ' +
      'signed typename this switch continue wchar_t inline readonly assign ' +
      'readwrite self @synchronized id typeof ' +
      'nonatomic super unichar IBOutlet IBAction strong weak copy ' +
      'in out inout bycopy byref oneway __strong __weak __block __autoreleasing ' +
      '@private @protected @public @try @property @end @throw @catch @finally ' +
      '@autoreleasepool @synthesize @dynamic @selector @optional @required',
    literal:
      'false true FALSE TRUE nil YES NO NULL',
    built_in:
      'BOOL dispatch_once_t dispatch_queue_t dispatch_sync dispatch_async dispatch_once'
  };
  var LEXEMES = /[a-zA-Z@][a-zA-Z0-9_]*/;
  var CLASS_KEYWORDS = '@interface @class @protocol @implementation';
  return {
    aliases: ['mm', 'objc', 'obj-c'],
    keywords: OBJC_KEYWORDS,
    lexemes: LEXEMES,
    illegal: '</',
    contains: [
      API_CLASS,
      hljs.C_LINE_COMMENT_MODE,
      hljs.C_BLOCK_COMMENT_MODE,
      hljs.C_NUMBER_MODE,
      hljs.QUOTE_STRING_MODE,
      {
        className: 'string',
        variants: [
          {
            begin: '@"', end: '"',
            illegal: '\\n',
            contains: [hljs.BACKSLASH_ESCAPE]
          },
          {
            begin: '\'', end: '[^\\\\]\'',
            illegal: '[^\\\\][^\']'
          }
        ]
      },
      {
        className: 'preprocessor',
        begin: '#',
        end: '$',
        contains: [
          {
            className: 'title',
            variants: [
              { begin: '\"', end: '\"' },
              { begin: '<', end: '>' }
            ]
          }
        ]
      },
      {
        className: 'class',
        begin: '(' + CLASS_KEYWORDS.split(' ').join('|') + ')\\b', end: '({|$)', excludeEnd: true,
        keywords: CLASS_KEYWORDS, lexemes: LEXEMES,
        contains: [
          hljs.UNDERSCORE_TITLE_MODE
        ]
      },
      {
        className: 'variable',
        begin: '\\.'+hljs.UNDERSCORE_IDENT_RE,
        relevance: 0
      }
    ]
  };
});

hljs.registerLanguage('ocaml', function(hljs) {
  /* missing support for heredoc-like string (OCaml 4.0.2+) */
  return {
    aliases: ['ml'],
    keywords: {
      keyword:
        'and as assert asr begin class constraint do done downto else end ' +
        'exception external for fun function functor if in include ' +
        'inherit! inherit initializer land lazy let lor lsl lsr lxor match method!|10 method ' +
        'mod module mutable new object of open! open or private rec sig struct ' +
        'then to try type val! val virtual when while with ' +
        /* camlp4 */
        'parser value',
      built_in:
        /* built-in types */
        'array bool bytes char exn|5 float int int32 int64 list lazy_t|5 nativeint|5 string unit ' +
        /* (some) types in Pervasives */
        'in_channel out_channel ref',
      literal:
        'true false'
    },
    illegal: /\/\/|>>/,
    lexemes: '[a-z_]\\w*!?',
    contains: [
      {
        className: 'literal',
        begin: '\\[(\\|\\|)?\\]|\\(\\)',
        relevance: 0
      },
      hljs.COMMENT(
        '\\(\\*',
        '\\*\\)',
        {
          contains: ['self']
        }
      ),
      { /* type variable */
        className: 'symbol',
        begin: '\'[A-Za-z_](?!\')[\\w\']*'
        /* the grammar is ambiguous on how 'a'b should be interpreted but not the compiler */
      },
      { /* polymorphic variant */
        className: 'tag',
        begin: '`[A-Z][\\w\']*'
      },
      { /* module or constructor */
        className: 'type',
        begin: '\\b[A-Z][\\w\']*',
        relevance: 0
      },
      { /* don't color identifiers, but safely catch all identifiers with '*/
        begin: '[a-z_]\\w*\'[\\w\']*'
      },
      hljs.inherit(hljs.APOS_STRING_MODE, {className: 'char', relevance: 0}),
      hljs.inherit(hljs.QUOTE_STRING_MODE, {illegal: null}),
      {
        className: 'number',
        begin:
          '\\b(0[xX][a-fA-F0-9_]+[Lln]?|' +
          '0[oO][0-7_]+[Lln]?|' +
          '0[bB][01_]+[Lln]?|' +
          '[0-9][0-9_]*([Lln]|(\\.[0-9_]*)?([eE][-+]?[0-9_]+)?)?)',
        relevance: 0
      },
      {
        begin: /[-=]>/ // relevance booster
      }
    ]
  }
});

hljs.registerLanguage('openscad', function(hljs) {
	var SPECIAL_VARS = {
		className: 'keyword',
		begin: '\\$(f[asn]|t|vp[rtd]|children)'
	},
	LITERALS = {
		className: 'literal',
		begin: 'false|true|PI|undef'
	},
	NUMBERS = {
		className: 'number',
		begin: '\\b\\d+(\\.\\d+)?(e-?\\d+)?', //adds 1e5, 1e-10
		relevance: 0
	},
	STRING = hljs.inherit(hljs.QUOTE_STRING_MODE,{illegal: null}),
	PREPRO = {
		className: 'preprocessor',
		keywords: 'include use',
		begin: 'include|use <',
		end: '>'
	},
	PARAMS = {
		className: 'params',
		begin: '\\(', end: '\\)',
		contains: ['self', NUMBERS, STRING, SPECIAL_VARS, LITERALS]
	},
	MODIFIERS = {
		className: 'built_in',
		begin: '[*!#%]',
		relevance: 0
	},
	FUNCTIONS = {
		className: 'function',
		beginKeywords: 'module function',
		end: '\\=|\\{',
		contains: [PARAMS, hljs.UNDERSCORE_TITLE_MODE]
	};

	return {
		aliases: ['scad'],
		keywords: {
			keyword: 'function module include use for intersection_for if else \\%',
			literal: 'false true PI undef',
			built_in: 'circle square polygon text sphere cube cylinder polyhedron translate rotate scale resize mirror multmatrix color offset hull minkowski union difference intersection abs sign sin cos tan acos asin atan atan2 floor round ceil ln log pow sqrt exp rands min max concat lookup str chr search version version_num norm cross parent_module echo import import_dxf dxf_linear_extrude linear_extrude rotate_extrude surface projection render children dxf_cross dxf_dim let assign'
		},
		contains: [
			hljs.C_LINE_COMMENT_MODE,
			hljs.C_BLOCK_COMMENT_MODE,
			NUMBERS,
			PREPRO,
			STRING,
			SPECIAL_VARS,
			MODIFIERS,
			FUNCTIONS
		]
	}
});

hljs.registerLanguage('oxygene', function(hljs) {
  var OXYGENE_KEYWORDS = 'abstract add and array as asc aspect assembly async begin break block by case class concat const copy constructor continue '+
    'create default delegate desc distinct div do downto dynamic each else empty end ensure enum equals event except exit extension external false '+
    'final finalize finalizer finally flags for forward from function future global group has if implementation implements implies in index inherited '+
    'inline interface into invariants is iterator join locked locking loop matching method mod module namespace nested new nil not notify nullable of '+
    'old on operator or order out override parallel params partial pinned private procedure property protected public queryable raise read readonly '+
    'record reintroduce remove repeat require result reverse sealed select self sequence set shl shr skip static step soft take then to true try tuple '+
    'type union unit unsafe until uses using var virtual raises volatile where while with write xor yield await mapped deprecated stdcall cdecl pascal '+
    'register safecall overload library platform reference packed strict published autoreleasepool selector strong weak unretained';
  var CURLY_COMMENT =  hljs.COMMENT(
    '{',
    '}',
    {
      relevance: 0
    }
  );
  var PAREN_COMMENT = hljs.COMMENT(
    '\\(\\*',
    '\\*\\)',
    {
      relevance: 10
    }
  );
  var STRING = {
    className: 'string',
    begin: '\'', end: '\'',
    contains: [{begin: '\'\''}]
  };
  var CHAR_STRING = {
    className: 'string', begin: '(#\\d+)+'
  };
  var FUNCTION = {
    className: 'function',
    beginKeywords: 'function constructor destructor procedure method', end: '[:;]',
    keywords: 'function constructor|10 destructor|10 procedure|10 method|10',
    contains: [
      hljs.TITLE_MODE,
      {
        className: 'params',
        begin: '\\(', end: '\\)',
        keywords: OXYGENE_KEYWORDS,
        contains: [STRING, CHAR_STRING]
      },
      CURLY_COMMENT, PAREN_COMMENT
    ]
  };
  return {
    case_insensitive: true,
    keywords: OXYGENE_KEYWORDS,
    illegal: '("|\\$[G-Zg-z]|\\/\\*|</|=>|->)',
    contains: [
      CURLY_COMMENT, PAREN_COMMENT, hljs.C_LINE_COMMENT_MODE,
      STRING, CHAR_STRING,
      hljs.NUMBER_MODE,
      FUNCTION,
      {
        className: 'class',
        begin: '=\\bclass\\b', end: 'end;',
        keywords: OXYGENE_KEYWORDS,
        contains: [
          STRING, CHAR_STRING,
          CURLY_COMMENT, PAREN_COMMENT, hljs.C_LINE_COMMENT_MODE,
          FUNCTION
        ]
      }
    ]
  };
});

hljs.registerLanguage('parser3', function(hljs) {
  var CURLY_SUBCOMMENT = hljs.COMMENT(
    '{',
    '}',
    {
      contains: ['self']
    }
  );
  return {
    subLanguage: 'xml', relevance: 0,
    contains: [
      hljs.COMMENT('^#', '$'),
      hljs.COMMENT(
        '\\^rem{',
        '}',
        {
          relevance: 10,
          contains: [
            CURLY_SUBCOMMENT
          ]
        }
      ),
      {
        className: 'preprocessor',
        begin: '^@(?:BASE|USE|CLASS|OPTIONS)$',
        relevance: 10
      },
      {
        className: 'title',
        begin: '@[\\w\\-]+\\[[\\w^;\\-]*\\](?:\\[[\\w^;\\-]*\\])?(?:.*)$'
      },
      {
        className: 'variable',
        begin: '\\$\\{?[\\w\\-\\.\\:]+\\}?'
      },
      {
        className: 'keyword',
        begin: '\\^[\\w\\-\\.\\:]+'
      },
      {
        className: 'number',
        begin: '\\^#[0-9a-fA-F]+'
      },
      hljs.C_NUMBER_MODE
    ]
  };
});

hljs.registerLanguage('pf', function(hljs) {
  var MACRO = {
    className: 'variable',
    begin: /\$[\w\d#@][\w\d_]*/
  };
  var TABLE = {
    className: 'variable',
    begin: /</, end: />/
  };
  var QUOTE_STRING = {
    className: 'string',
    begin: /"/, end: /"/
  };

  return {
    aliases: ['pf.conf'],
    lexemes: /[a-z0-9_<>-]+/,
    keywords: {
      built_in: /* block match pass are "actions" in pf.conf(5), the rest are
                 * lexically similar top-level commands.
                 */
        'block match pass load anchor|5 antispoof|10 set table',
      keyword:
        'in out log quick on rdomain inet inet6 proto from port os to route' +
        'allow-opts divert-packet divert-reply divert-to flags group icmp-type' +
        'icmp6-type label once probability recieved-on rtable prio queue' +
        'tos tag tagged user keep fragment for os drop' +
        'af-to|10 binat-to|10 nat-to|10 rdr-to|10 bitmask least-stats random round-robin' +
        'source-hash static-port' +
        'dup-to reply-to route-to' +
        'parent bandwidth default min max qlimit' +
        'block-policy debug fingerprints hostid limit loginterface optimization' +
        'reassemble ruleset-optimization basic none profile skip state-defaults' +
        'state-policy timeout' +
        'const counters persist' +
        'no modulate synproxy state|5 floating if-bound no-sync pflow|10 sloppy' +
        'source-track global rule max-src-nodes max-src-states max-src-conn' +
        'max-src-conn-rate overload flush' +
        'scrub|5 max-mss min-ttl no-df|10 random-id',
      literal:
        'all any no-route self urpf-failed egress|5 unknown'
    },
    contains: [
      hljs.HASH_COMMENT_MODE,
      hljs.NUMBER_MODE,
      hljs.QUOTE_STRING_MODE,
      MACRO,
      TABLE
    ]
  };
});

hljs.registerLanguage('php', function(hljs) {
  var VARIABLE = {
    className: 'variable', begin: '\\$+[a-zA-Z_\x7f-\xff][a-zA-Z0-9_\x7f-\xff]*'
  };
  var PREPROCESSOR = {
    className: 'preprocessor', begin: /<\?(php)?|\?>/
  };
  var STRING = {
    className: 'string',
    contains: [hljs.BACKSLASH_ESCAPE, PREPROCESSOR],
    variants: [
      {
        begin: 'b"', end: '"'
      },
      {
        begin: 'b\'', end: '\''
      },
      hljs.inherit(hljs.APOS_STRING_MODE, {illegal: null}),
      hljs.inherit(hljs.QUOTE_STRING_MODE, {illegal: null})
    ]
  };
  var NUMBER = {variants: [hljs.BINARY_NUMBER_MODE, hljs.C_NUMBER_MODE]};
  return {
    aliases: ['php3', 'php4', 'php5', 'php6'],
    case_insensitive: true,
    keywords:
      'and include_once list abstract global private echo interface as static endswitch ' +
      'array null if endwhile or const for endforeach self var while isset public ' +
      'protected exit foreach throw elseif include __FILE__ empty require_once do xor ' +
      'return parent clone use __CLASS__ __LINE__ else break print eval new ' +
      'catch __METHOD__ case exception default die require __FUNCTION__ ' +
      'enddeclare final try switch continue endfor endif declare unset true false ' +
      'trait goto instanceof insteadof __DIR__ __NAMESPACE__ ' +
      'yield finally',
    contains: [
      hljs.C_LINE_COMMENT_MODE,
      hljs.HASH_COMMENT_MODE,
      hljs.COMMENT(
        '/\\*',
        '\\*/',
        {
          contains: [
            {
              className: 'doctag',
              begin: '@[A-Za-z]+'
            },
            PREPROCESSOR
          ]
        }
      ),
      hljs.COMMENT(
        '__halt_compiler.+?;',
        false,
        {
          endsWithParent: true,
          keywords: '__halt_compiler',
          lexemes: hljs.UNDERSCORE_IDENT_RE
        }
      ),
      {
        className: 'string',
        begin: /<<<['"]?\w+['"]?$/, end: /^\w+;?$/,
        contains: [
          hljs.BACKSLASH_ESCAPE,
          {
            className: 'subst',
            variants: [
              {begin: /\$\w+/},
              {begin: /\{\$/, end: /\}/}
            ]
          }
        ]
      },
      PREPROCESSOR,
      VARIABLE,
      {
        // swallow composed identifiers to avoid parsing them as keywords
        begin: /(::|->)+[a-zA-Z_\x7f-\xff][a-zA-Z0-9_\x7f-\xff]*/
      },
      {
        className: 'function',
        beginKeywords: 'function', end: /[;{]/, excludeEnd: true,
        illegal: '\\$|\\[|%',
        contains: [
          hljs.UNDERSCORE_TITLE_MODE,
          {
            className: 'params',
            begin: '\\(', end: '\\)',
            contains: [
              'self',
              VARIABLE,
              hljs.C_BLOCK_COMMENT_MODE,
              STRING,
              NUMBER
            ]
          }
        ]
      },
      {
        className: 'class',
        beginKeywords: 'class interface', end: '{', excludeEnd: true,
        illegal: /[:\(\$"]/,
        contains: [
          {beginKeywords: 'extends implements'},
          hljs.UNDERSCORE_TITLE_MODE
        ]
      },
      {
        beginKeywords: 'namespace', end: ';',
        illegal: /[\.']/,
        contains: [hljs.UNDERSCORE_TITLE_MODE]
      },
      {
        beginKeywords: 'use', end: ';',
        contains: [hljs.UNDERSCORE_TITLE_MODE]
      },
      {
        begin: '=>' // No markup, just a relevance booster
      },
      STRING,
      NUMBER
    ]
  };
});

hljs.registerLanguage('powershell', function(hljs) {
  var backtickEscape = {
    begin: '`[\\s\\S]',
    relevance: 0
  };
  var VAR = {
    className: 'variable',
    variants: [
      {begin: /\$[\w\d][\w\d_:]*/}
    ]
  };
  var QUOTE_STRING = {
    className: 'string',
    begin: /"/, end: /"/,
    contains: [
      backtickEscape,
      VAR,
      {
        className: 'variable',
        begin: /\$[A-z]/, end: /[^A-z]/
      }
    ]
  };
  var APOS_STRING = {
    className: 'string',
    begin: /'/, end: /'/
  };

  return {
    aliases: ['ps'],
    lexemes: /-?[A-z\.\-]+/,
    case_insensitive: true,
    keywords: {
      keyword: 'if else foreach return function do while until elseif begin for trap data dynamicparam end break throw param continue finally in switch exit filter try process catch',
      literal: '$null $true $false',
      built_in: 'Add-Content Add-History Add-Member Add-PSSnapin Clear-Content Clear-Item Clear-Item Property Clear-Variable Compare-Object ConvertFrom-SecureString Convert-Path ConvertTo-Html ConvertTo-SecureString Copy-Item Copy-ItemProperty Export-Alias Export-Clixml Export-Console Export-Csv ForEach-Object Format-Custom Format-List Format-Table Format-Wide Get-Acl Get-Alias Get-AuthenticodeSignature Get-ChildItem Get-Command Get-Content Get-Credential Get-Culture Get-Date Get-EventLog Get-ExecutionPolicy Get-Help Get-History Get-Host Get-Item Get-ItemProperty Get-Location Get-Member Get-PfxCertificate Get-Process Get-PSDrive Get-PSProvider Get-PSSnapin Get-Service Get-TraceSource Get-UICulture Get-Unique Get-Variable Get-WmiObject Group-Object Import-Alias Import-Clixml Import-Csv Invoke-Expression Invoke-History Invoke-Item Join-Path Measure-Command Measure-Object Move-Item Move-ItemProperty New-Alias New-Item New-ItemProperty New-Object New-PSDrive New-Service New-TimeSpan New-Variable Out-Default Out-File Out-Host Out-Null Out-Printer Out-String Pop-Location Push-Location Read-Host Remove-Item Remove-ItemProperty Remove-PSDrive Remove-PSSnapin Remove-Variable Rename-Item Rename-ItemProperty Resolve-Path Restart-Service Resume-Service Select-Object Select-String Set-Acl Set-Alias Set-AuthenticodeSignature Set-Content Set-Date Set-ExecutionPolicy Set-Item Set-ItemProperty Set-Location Set-PSDebug Set-Service Set-TraceSource Set-Variable Sort-Object Split-Path Start-Service Start-Sleep Start-Transcript Stop-Process Stop-Service Stop-Transcript Suspend-Service Tee-Object Test-Path Trace-Command Update-FormatData Update-TypeData Where-Object Write-Debug Write-Error Write-Host Write-Output Write-Progress Write-Verbose Write-Warning',
      operator: '-ne -eq -lt -gt -ge -le -not -like -notlike -match -notmatch -contains -notcontains -in -notin -replace'
    },
    contains: [
      hljs.HASH_COMMENT_MODE,
      hljs.NUMBER_MODE,
      QUOTE_STRING,
      APOS_STRING,
      VAR
    ]
  };
});

hljs.registerLanguage('processing', function(hljs) {
  return {
    keywords: {
      keyword: 'BufferedReader PVector PFont PImage PGraphics HashMap boolean byte char color ' +
        'double float int long String Array FloatDict FloatList IntDict IntList JSONArray JSONObject ' +
        'Object StringDict StringList Table TableRow XML ' +
        // Java keywords
        'false synchronized int abstract float private char boolean static null if const ' +
        'for true while long throw strictfp finally protected import native final return void ' +
        'enum else break transient new catch instanceof byte super volatile case assert short ' +
        'package default double public try this switch continue throws protected public private',
      constant: 'P2D P3D HALF_PI PI QUARTER_PI TAU TWO_PI',
      variable: 'displayHeight displayWidth mouseY mouseX mousePressed pmouseX pmouseY key ' +
        'keyCode pixels focused frameCount frameRate height width',
      title: 'setup draw',
      built_in: 'size createGraphics beginDraw createShape loadShape PShape arc ellipse line point ' +
        'quad rect triangle bezier bezierDetail bezierPoint bezierTangent curve curveDetail curvePoint ' +
        'curveTangent curveTightness shape shapeMode beginContour beginShape bezierVertex curveVertex ' +
        'endContour endShape quadraticVertex vertex ellipseMode noSmooth rectMode smooth strokeCap ' +
        'strokeJoin strokeWeight mouseClicked mouseDragged mouseMoved mousePressed mouseReleased ' +
        'mouseWheel keyPressed keyPressedkeyReleased keyTyped print println save saveFrame day hour ' +
        'millis minute month second year background clear colorMode fill noFill noStroke stroke alpha ' +
        'blue brightness color green hue lerpColor red saturation modelX modelY modelZ screenX screenY ' +
        'screenZ ambient emissive shininess specular add createImage beginCamera camera endCamera frustum ' +
        'ortho perspective printCamera printProjection cursor frameRate noCursor exit loop noLoop popStyle ' +
        'pushStyle redraw binary boolean byte char float hex int str unbinary unhex join match matchAll nf ' +
        'nfc nfp nfs split splitTokens trim append arrayCopy concat expand reverse shorten sort splice subset ' +
        'box sphere sphereDetail createInput createReader loadBytes loadJSONArray loadJSONObject loadStrings ' +
        'loadTable loadXML open parseXML saveTable selectFolder selectInput beginRaw beginRecord createOutput ' +
        'createWriter endRaw endRecord PrintWritersaveBytes saveJSONArray saveJSONObject saveStream saveStrings ' +
        'saveXML selectOutput popMatrix printMatrix pushMatrix resetMatrix rotate rotateX rotateY rotateZ scale ' +
        'shearX shearY translate ambientLight directionalLight lightFalloff lights lightSpecular noLights normal ' +
        'pointLight spotLight image imageMode loadImage noTint requestImage tint texture textureMode textureWrap ' +
        'blend copy filter get loadPixels set updatePixels blendMode loadShader PShaderresetShader shader createFont ' +
        'loadFont text textFont textAlign textLeading textMode textSize textWidth textAscent textDescent abs ceil ' +
        'constrain dist exp floor lerp log mag map max min norm pow round sq sqrt acos asin atan atan2 cos degrees ' +
        'radians sin tan noise noiseDetail noiseSeed random randomGaussian randomSeed'
    },
    contains: [
      hljs.C_LINE_COMMENT_MODE,
      hljs.C_BLOCK_COMMENT_MODE,
      hljs.APOS_STRING_MODE,
      hljs.QUOTE_STRING_MODE,
      hljs.C_NUMBER_MODE
    ]
  };
});

hljs.registerLanguage('profile', function(hljs) {
  return {
    contains: [
      hljs.C_NUMBER_MODE,
      {
        className: 'built_in',
        begin: '{', end: '}$',
        excludeBegin: true, excludeEnd: true,
        contains: [hljs.APOS_STRING_MODE, hljs.QUOTE_STRING_MODE],
        relevance: 0
      },
      {
        className: 'filename',
        begin: '[a-zA-Z_][\\da-zA-Z_]+\\.[\\da-zA-Z_]{1,3}', end: ':',
        excludeEnd: true
      },
      {
        className: 'header',
        begin: '(ncalls|tottime|cumtime)', end: '$',
        keywords: 'ncalls tottime|10 cumtime|10 filename',
        relevance: 10
      },
      {
        className: 'summary',
        begin: 'function calls', end: '$',
        contains: [hljs.C_NUMBER_MODE],
        relevance: 10
      },
      hljs.APOS_STRING_MODE,
      hljs.QUOTE_STRING_MODE,
      {
        className: 'function',
        begin: '\\(', end: '\\)$',
        contains: [
          hljs.UNDERSCORE_TITLE_MODE
        ],
        relevance: 0
      }
    ]
  };
});

hljs.registerLanguage('prolog', function(hljs) {

  var ATOM = {

    className: 'atom',
    begin: /[a-z][A-Za-z0-9_]*/,
    relevance: 0
  };

  var VAR = {

    className: 'name',
    variants: [
      {begin: /[A-Z][a-zA-Z0-9_]*/},
      {begin: /_[A-Za-z0-9_]*/},
    ],
    relevance: 0
  };

  var PARENTED = {

    begin: /\(/,
    end: /\)/,
    relevance: 0
  };

  var LIST = {

    begin: /\[/,
    end: /\]/
  };

  var LINE_COMMENT = {

    className: 'comment',
    begin: /%/, end: /$/,
    contains: [hljs.PHRASAL_WORDS_MODE]
  };

  var BACKTICK_STRING = {

    className: 'string',
    begin: /`/, end: /`/,
    contains: [hljs.BACKSLASH_ESCAPE]
  };

  var CHAR_CODE = {

    className: 'string', // 0'a etc.
    begin: /0\'(\\\'|.)/
  };

  var SPACE_CODE = {

    className: 'string',
    begin: /0\'\\s/ // 0'\s
  };

  var PRED_OP = { // relevance booster
    begin: /:-/
  };

  var inner = [

    ATOM,
    VAR,
    PARENTED,
    PRED_OP,
    LIST,
    LINE_COMMENT,
    hljs.C_BLOCK_COMMENT_MODE,
    hljs.QUOTE_STRING_MODE,
    hljs.APOS_STRING_MODE,
    BACKTICK_STRING,
    CHAR_CODE,
    SPACE_CODE,
    hljs.C_NUMBER_MODE
  ];

  PARENTED.contains = inner;
  LIST.contains = inner;

  return {
    contains: inner.concat([
      {begin: /\.$/} // relevance booster
    ])
  };
});

hljs.registerLanguage('protobuf', function(hljs) {
  return {
    keywords: {
      keyword: 'package import option optional required repeated group',
      built_in: 'double float int32 int64 uint32 uint64 sint32 sint64 ' +
        'fixed32 fixed64 sfixed32 sfixed64 bool string bytes',
      literal: 'true false'
    },
    contains: [
      hljs.QUOTE_STRING_MODE,
      hljs.NUMBER_MODE,
      hljs.C_LINE_COMMENT_MODE,
      {
        className: 'class',
        beginKeywords: 'message enum service', end: /\{/,
        illegal: /\n/,
        contains: [
          hljs.inherit(hljs.TITLE_MODE, {
            starts: {endsWithParent: true, excludeEnd: true} // hack: eating everything after the first title
          })
        ]
      },
      {
        className: 'function',
        beginKeywords: 'rpc',
        end: /;/, excludeEnd: true,
        keywords: 'rpc returns'
      },
      {
        className: 'constant',
        begin: /^\s*[A-Z_]+/,
        end: /\s*=/, excludeEnd: true
      }
    ]
  };
});

hljs.registerLanguage('puppet', function(hljs) {

  var PUPPET_KEYWORDS = {
    keyword:
    /* language keywords */
      'and case default else elsif false if in import enherits node or true undef unless main settings $string ',
    literal:
    /* metaparameters */
      'alias audit before loglevel noop require subscribe tag ' +
    /* normal attributes */
      'owner ensure group mode name|0 changes context force incl lens load_path onlyif provider returns root show_diff type_check ' +
      'en_address ip_address realname command environment hour monute month monthday special target weekday '+
      'creates cwd ogoutput refresh refreshonly tries try_sleep umask backup checksum content ctime force ignore ' +
      'links mtime purge recurse recurselimit replace selinux_ignore_defaults selrange selrole seltype seluser source ' +
      'souirce_permissions sourceselect validate_cmd validate_replacement allowdupe attribute_membership auth_membership forcelocal gid '+
      'ia_load_module members system host_aliases ip allowed_trunk_vlans description device_url duplex encapsulation etherchannel ' +
      'native_vlan speed principals allow_root auth_class auth_type authenticate_user k_of_n mechanisms rule session_owner shared options ' +
      'device fstype enable hasrestart directory present absent link atboot blockdevice device dump pass remounts poller_tag use ' +
      'message withpath adminfile allow_virtual allowcdrom category configfiles flavor install_options instance package_settings platform ' +
      'responsefile status uninstall_options vendor unless_system_user unless_uid binary control flags hasstatus manifest pattern restart running ' +
      'start stop allowdupe auths expiry gid groups home iterations key_membership keys managehome membership password password_max_age ' +
      'password_min_age profile_membership profiles project purge_ssh_keys role_membership roles salt shell uid baseurl cost descr enabled ' +
      'enablegroups exclude failovermethod gpgcheck gpgkey http_caching include includepkgs keepalive metadata_expire metalink mirrorlist ' +
      'priority protect proxy proxy_password proxy_username repo_gpgcheck s3_enabled skip_if_unavailable sslcacert sslclientcert sslclientkey ' +
      'sslverify mounted',
    built_in:
    /* core facts */
      'architecture augeasversion blockdevices boardmanufacturer boardproductname boardserialnumber cfkey dhcp_servers ' +
      'domain ec2_ ec2_userdata facterversion filesystems ldom fqdn gid hardwareisa hardwaremodel hostname id|0 interfaces '+
      'ipaddress ipaddress_ ipaddress6 ipaddress6_ iphostnumber is_virtual kernel kernelmajversion kernelrelease kernelversion ' +
      'kernelrelease kernelversion lsbdistcodename lsbdistdescription lsbdistid lsbdistrelease lsbmajdistrelease lsbminordistrelease ' +
      'lsbrelease macaddress macaddress_ macosx_buildversion macosx_productname macosx_productversion macosx_productverson_major ' +
      'macosx_productversion_minor manufacturer memoryfree memorysize netmask metmask_ network_ operatingsystem operatingsystemmajrelease '+
      'operatingsystemrelease osfamily partitions path physicalprocessorcount processor processorcount productname ps puppetversion '+
      'rubysitedir rubyversion selinux selinux_config_mode selinux_config_policy selinux_current_mode selinux_current_mode selinux_enforced '+
      'selinux_policyversion serialnumber sp_ sshdsakey sshecdsakey sshrsakey swapencrypted swapfree swapsize timezone type uniqueid uptime '+
      'uptime_days uptime_hours uptime_seconds uuid virtual vlans xendomains zfs_version zonenae zones zpool_version'
  };

  var COMMENT = hljs.COMMENT('#', '$');

  var IDENT_RE = '([A-Za-z_]|::)(\\w|::)*';

  var TITLE = hljs.inherit(hljs.TITLE_MODE, {begin: IDENT_RE});

  var VARIABLE = {className: 'variable', begin: '\\$' + IDENT_RE};

  var STRING = {
    className: 'string',
    contains: [hljs.BACKSLASH_ESCAPE, VARIABLE],
    variants: [
      {begin: /'/, end: /'/},
      {begin: /"/, end: /"/}
    ]
  };

  return {
    aliases: ['pp'],
    contains: [
      COMMENT,
      VARIABLE,
      STRING,
      {
        beginKeywords: 'class', end: '\\{|;',
        illegal: /=/,
        contains: [TITLE, COMMENT]
      },
      {
        beginKeywords: 'define', end: /\{/,
        contains: [
          {
            className: 'title', begin: hljs.IDENT_RE, endsParent: true
          }
        ]
      },
      {
        begin: hljs.IDENT_RE + '\\s+\\{', returnBegin: true,
        end: /\S/,
        contains: [
          {
            className: 'name',
            begin: hljs.IDENT_RE
          },
          {
            begin: /\{/, end: /\}/,
            keywords: PUPPET_KEYWORDS,
            relevance: 0,
            contains: [
              STRING,
              COMMENT,
              {
                begin:'[a-zA-Z_]+\\s*=>'
              },
              {
                className: 'number',
                begin: '(\\b0[0-7_]+)|(\\b0x[0-9a-fA-F_]+)|(\\b[1-9][0-9_]*(\\.[0-9_]+)?)|[0_]\\b',
                relevance: 0
              },
              VARIABLE
            ]
          }
        ],
        relevance: 0
      }
    ]
  }
});

hljs.registerLanguage('python', function(hljs) {
  var PROMPT = {
    className: 'prompt',  begin: /^(>>>|\.\.\.) /
  };
  var STRING = {
    className: 'string',
    contains: [hljs.BACKSLASH_ESCAPE],
    variants: [
      {
        begin: /(u|b)?r?'''/, end: /'''/,
        contains: [PROMPT],
        relevance: 10
      },
      {
        begin: /(u|b)?r?"""/, end: /"""/,
        contains: [PROMPT],
        relevance: 10
      },
      {
        begin: /(u|r|ur)'/, end: /'/,
        relevance: 10
      },
      {
        begin: /(u|r|ur)"/, end: /"/,
        relevance: 10
      },
      {
        begin: /(b|br)'/, end: /'/
      },
      {
        begin: /(b|br)"/, end: /"/
      },
      hljs.APOS_STRING_MODE,
      hljs.QUOTE_STRING_MODE
    ]
  };
  var NUMBER = {
    className: 'number', relevance: 0,
    variants: [
      {begin: hljs.BINARY_NUMBER_RE + '[lLjJ]?'},
      {begin: '\\b(0o[0-7]+)[lLjJ]?'},
      {begin: hljs.C_NUMBER_RE + '[lLjJ]?'}
    ]
  };
  var PARAMS = {
    className: 'params',
    begin: /\(/, end: /\)/,
    contains: ['self', PROMPT, NUMBER, STRING]
  };
  return {
    aliases: ['py', 'gyp'],
    keywords: {
      keyword:
        'and elif is global as in if from raise for except finally print import pass return ' +
        'exec else break not with class assert yield try while continue del or def lambda ' +
        'async await nonlocal|10 None True False',
      built_in:
        'Ellipsis NotImplemented'
    },
    illegal: /(<\/|->|\?)/,
    contains: [
      PROMPT,
      NUMBER,
      STRING,
      hljs.HASH_COMMENT_MODE,
      {
        variants: [
          {className: 'function', beginKeywords: 'def', relevance: 10},
          {className: 'class', beginKeywords: 'class'}
        ],
        end: /:/,
        illegal: /[${=;\n,]/,
        contains: [hljs.UNDERSCORE_TITLE_MODE, PARAMS]
      },
      {
        className: 'decorator',
        begin: /^[\t ]*@/, end: /$/
      },
      {
        begin: /\b(print|exec)\(/ // don’t highlight keywords-turned-functions in Python 3
      }
    ]
  };
});

hljs.registerLanguage('q', function(hljs) {
  var Q_KEYWORDS = {
  keyword:
    'do while select delete by update from',
  constant:
    '0b 1b',
  built_in:
    'neg not null string reciprocal floor ceiling signum mod xbar xlog and or each scan over prior mmu lsq inv md5 ltime gtime count first var dev med cov cor all any rand sums prds mins maxs fills deltas ratios avgs differ prev next rank reverse iasc idesc asc desc msum mcount mavg mdev xrank mmin mmax xprev rotate distinct group where flip type key til get value attr cut set upsert raze union inter except cross sv vs sublist enlist read0 read1 hopen hclose hdel hsym hcount peach system ltrim rtrim trim lower upper ssr view tables views cols xcols keys xkey xcol xasc xdesc fkeys meta lj aj aj0 ij pj asof uj ww wj wj1 fby xgroup ungroup ej save load rsave rload show csv parse eval min max avg wavg wsum sin cos tan sum',
  typename:
    '`float `double int `timestamp `timespan `datetime `time `boolean `symbol `char `byte `short `long `real `month `date `minute `second `guid'
  };
  return {
  aliases:['k', 'kdb'],
  keywords: Q_KEYWORDS,
  lexemes: /\b(`?)[A-Za-z0-9_]+\b/,
  contains: [
  hljs.C_LINE_COMMENT_MODE,
    hljs.QUOTE_STRING_MODE,
    hljs.C_NUMBER_MODE
     ]
  };
});

hljs.registerLanguage('r', function(hljs) {
  var IDENT_RE = '([a-zA-Z]|\\.[a-zA-Z.])[a-zA-Z0-9._]*';

  return {
    contains: [
      hljs.HASH_COMMENT_MODE,
      {
        begin: IDENT_RE,
        lexemes: IDENT_RE,
        keywords: {
          keyword:
            'function if in break next repeat else for return switch while try tryCatch ' +
            'stop warning require library attach detach source setMethod setGeneric ' +
            'setGroupGeneric setClass ...',
          literal:
            'NULL NA TRUE FALSE T F Inf NaN NA_integer_|10 NA_real_|10 NA_character_|10 ' +
            'NA_complex_|10'
        },
        relevance: 0
      },
      {
        // hex value
        className: 'number',
        begin: "0[xX][0-9a-fA-F]+[Li]?\\b",
        relevance: 0
      },
      {
        // explicit integer
        className: 'number',
        begin: "\\d+(?:[eE][+\\-]?\\d*)?L\\b",
        relevance: 0
      },
      {
        // number with trailing decimal
        className: 'number',
        begin: "\\d+\\.(?!\\d)(?:i\\b)?",
        relevance: 0
      },
      {
        // number
        className: 'number',
        begin: "\\d+(?:\\.\\d*)?(?:[eE][+\\-]?\\d*)?i?\\b",
        relevance: 0
      },
      {
        // number with leading decimal
        className: 'number',
        begin: "\\.\\d+(?:[eE][+\\-]?\\d*)?i?\\b",
        relevance: 0
      },

      {
        // escaped identifier
        begin: '`',
        end: '`',
        relevance: 0
      },

      {
        className: 'string',
        contains: [hljs.BACKSLASH_ESCAPE],
        variants: [
          {begin: '"', end: '"'},
          {begin: "'", end: "'"}
        ]
      }
    ]
  };
});

hljs.registerLanguage('rib', function(hljs) {
  return {
    keywords:
      'ArchiveRecord AreaLightSource Atmosphere Attribute AttributeBegin AttributeEnd Basis ' +
      'Begin Blobby Bound Clipping ClippingPlane Color ColorSamples ConcatTransform Cone ' +
      'CoordinateSystem CoordSysTransform CropWindow Curves Cylinder DepthOfField Detail ' +
      'DetailRange Disk Displacement Display End ErrorHandler Exposure Exterior Format ' +
      'FrameAspectRatio FrameBegin FrameEnd GeneralPolygon GeometricApproximation Geometry ' +
      'Hider Hyperboloid Identity Illuminate Imager Interior LightSource ' +
      'MakeCubeFaceEnvironment MakeLatLongEnvironment MakeShadow MakeTexture Matte ' +
      'MotionBegin MotionEnd NuPatch ObjectBegin ObjectEnd ObjectInstance Opacity Option ' +
      'Orientation Paraboloid Patch PatchMesh Perspective PixelFilter PixelSamples ' +
      'PixelVariance Points PointsGeneralPolygons PointsPolygons Polygon Procedural Projection ' +
      'Quantize ReadArchive RelativeDetail ReverseOrientation Rotate Scale ScreenWindow ' +
      'ShadingInterpolation ShadingRate Shutter Sides Skew SolidBegin SolidEnd Sphere ' +
      'SubdivisionMesh Surface TextureCoordinates Torus Transform TransformBegin TransformEnd ' +
      'TransformPoints Translate TrimCurve WorldBegin WorldEnd',
    illegal: '</',
    contains: [
      hljs.HASH_COMMENT_MODE,
      hljs.C_NUMBER_MODE,
      hljs.APOS_STRING_MODE,
      hljs.QUOTE_STRING_MODE
    ]
  };
});

hljs.registerLanguage('roboconf', function(hljs) {
  var IDENTIFIER = '[a-zA-Z-_][^\n{\r\n]+\\{';

  return {
    aliases: ['graph', 'instances'],
    case_insensitive: true,
    keywords: 'import',
    contains: [
      // Facet sections
      {
        className: 'facet',
        begin: '^facet ' + IDENTIFIER,
        end: '}',
        keywords: 'facet installer exports children extends',
        contains: [
          hljs.HASH_COMMENT_MODE
        ]
      },

      // Instance sections
      {
        className: 'instance-of',
        begin: '^instance of ' + IDENTIFIER,
        end: '}',
        keywords: 'name count channels instance-data instance-state instance of',
        contains: [
          // Instance overridden properties
          {
            className: 'keyword',
            begin: '[a-zA-Z-_]+( |\t)*:'
          },
          hljs.HASH_COMMENT_MODE
        ]
      },

      // Component sections
      {
        className: 'component',
        begin: '^' + IDENTIFIER,
        end: '}',
        lexemes: '\\(?[a-zA-Z]+\\)?',
        keywords: 'installer exports children extends imports facets alias (optional)',
        contains: [
          // Imported component variables
          {
            className: 'string',
            begin: '\\.[a-zA-Z-_]+',
            end: '\\s|,|;',
            excludeEnd: true
          },
          hljs.HASH_COMMENT_MODE
        ]
      },

      // Comments
      hljs.HASH_COMMENT_MODE
    ]
  };
});

hljs.registerLanguage('rsl', function(hljs) {
  return {
    keywords: {
      keyword:
        'float color point normal vector matrix while for if do return else break extern continue',
      built_in:
        'abs acos ambient area asin atan atmosphere attribute calculatenormal ceil cellnoise ' +
        'clamp comp concat cos degrees depth Deriv diffuse distance Du Dv environment exp ' +
        'faceforward filterstep floor format fresnel incident length lightsource log match ' +
        'max min mod noise normalize ntransform opposite option phong pnoise pow printf ' +
        'ptlined radians random reflect refract renderinfo round setcomp setxcomp setycomp ' +
        'setzcomp shadow sign sin smoothstep specular specularbrdf spline sqrt step tan ' +
        'texture textureinfo trace transform vtransform xcomp ycomp zcomp'
    },
    illegal: '</',
    contains: [
      hljs.C_LINE_COMMENT_MODE,
      hljs.C_BLOCK_COMMENT_MODE,
      hljs.QUOTE_STRING_MODE,
      hljs.APOS_STRING_MODE,
      hljs.C_NUMBER_MODE,
      {
        className: 'preprocessor',
        begin: '#', end: '$'
      },
      {
        className: 'shader',
        beginKeywords: 'surface displacement light volume imager', end: '\\('
      },
      {
        className: 'shading',
        beginKeywords: 'illuminate illuminance gather', end: '\\('
      }
    ]
  };
});

hljs.registerLanguage('ruleslanguage', function(hljs) {
  return {
    keywords: {
       keyword: 'BILL_PERIOD BILL_START BILL_STOP RS_EFFECTIVE_START RS_EFFECTIVE_STOP RS_JURIS_CODE RS_OPCO_CODE ' +
         'INTDADDATTRIBUTE|5 INTDADDVMSG|5 INTDBLOCKOP|5 INTDBLOCKOPNA|5 INTDCLOSE|5 INTDCOUNT|5 ' +
         'INTDCOUNTSTATUSCODE|5 INTDCREATEMASK|5 INTDCREATEDAYMASK|5 INTDCREATEFACTORMASK|5 ' +
         'INTDCREATEHANDLE|5 INTDCREATEOVERRIDEDAYMASK|5 INTDCREATEOVERRIDEMASK|5 ' +
         'INTDCREATESTATUSCODEMASK|5 INTDCREATETOUPERIOD|5 INTDDELETE|5 INTDDIPTEST|5 INTDEXPORT|5 ' +
         'INTDGETERRORCODE|5 INTDGETERRORMESSAGE|5 INTDISEQUAL|5 INTDJOIN|5 INTDLOAD|5 INTDLOADACTUALCUT|5 ' +
         'INTDLOADDATES|5 INTDLOADHIST|5 INTDLOADLIST|5 INTDLOADLISTDATES|5 INTDLOADLISTENERGY|5 ' +
         'INTDLOADLISTHIST|5 INTDLOADRELATEDCHANNEL|5 INTDLOADSP|5 INTDLOADSTAGING|5 INTDLOADUOM|5 ' +
         'INTDLOADUOMDATES|5 INTDLOADUOMHIST|5 INTDLOADVERSION|5 INTDOPEN|5 INTDREADFIRST|5 INTDREADNEXT|5 ' +
         'INTDRECCOUNT|5 INTDRELEASE|5 INTDREPLACE|5 INTDROLLAVG|5 INTDROLLPEAK|5 INTDSCALAROP|5 INTDSCALE|5 ' +
         'INTDSETATTRIBUTE|5 INTDSETDSTPARTICIPANT|5 INTDSETSTRING|5 INTDSETVALUE|5 INTDSETVALUESTATUS|5 ' +
         'INTDSHIFTSTARTTIME|5 INTDSMOOTH|5 INTDSORT|5 INTDSPIKETEST|5 INTDSUBSET|5 INTDTOU|5 ' +
         'INTDTOURELEASE|5 INTDTOUVALUE|5 INTDUPDATESTATS|5 INTDVALUE|5 STDEV INTDDELETEEX|5 ' +
         'INTDLOADEXACTUAL|5 INTDLOADEXCUT|5 INTDLOADEXDATES|5 INTDLOADEX|5 INTDLOADEXRELATEDCHANNEL|5 ' +
         'INTDSAVEEX|5 MVLOAD|5 MVLOADACCT|5 MVLOADACCTDATES|5 MVLOADACCTHIST|5 MVLOADDATES|5 MVLOADHIST|5 ' +
         'MVLOADLIST|5 MVLOADLISTDATES|5 MVLOADLISTHIST|5 IF FOR NEXT DONE SELECT END CALL ABORT CLEAR CHANNEL FACTOR LIST NUMBER ' +
         'OVERRIDE SET WEEK DISTRIBUTIONNODE ELSE WHEN THEN OTHERWISE IENUM CSV INCLUDE LEAVE RIDER SAVE DELETE ' +
         'NOVALUE SECTION WARN SAVE_UPDATE DETERMINANT LABEL REPORT REVENUE EACH ' +
         'IN FROM TOTAL CHARGE BLOCK AND OR CSV_FILE RATE_CODE AUXILIARY_DEMAND ' +
         'UIDACCOUNT RS BILL_PERIOD_SELECT HOURS_PER_MONTH INTD_ERROR_STOP SEASON_SCHEDULE_NAME ' +
         'ACCOUNTFACTOR ARRAYUPPERBOUND CALLSTOREDPROC GETADOCONNECTION GETCONNECT GETDATASOURCE ' +
         'GETQUALIFIER GETUSERID HASVALUE LISTCOUNT LISTOP LISTUPDATE LISTVALUE PRORATEFACTOR RSPRORATE ' +
         'SETBINPATH SETDBMONITOR WQ_OPEN BILLINGHOURS DATE DATEFROMFLOAT DATETIMEFROMSTRING ' +
         'DATETIMETOSTRING DATETOFLOAT DAY DAYDIFF DAYNAME DBDATETIME HOUR MINUTE MONTH MONTHDIFF ' +
         'MONTHHOURS MONTHNAME ROUNDDATE SAMEWEEKDAYLASTYEAR SECOND WEEKDAY WEEKDIFF YEAR YEARDAY ' +
         'YEARSTR COMPSUM HISTCOUNT HISTMAX HISTMIN HISTMINNZ HISTVALUE MAXNRANGE MAXRANGE MINRANGE ' +
         'COMPIKVA COMPKVA COMPKVARFROMKQKW COMPLF IDATTR FLAG LF2KW LF2KWH MAXKW POWERFACTOR ' +
         'READING2USAGE AVGSEASON MAXSEASON MONTHLYMERGE SEASONVALUE SUMSEASON ACCTREADDATES ' +
         'ACCTTABLELOAD CONFIGADD CONFIGGET CREATEOBJECT CREATEREPORT EMAILCLIENT EXPBLKMDMUSAGE ' +
         'EXPMDMUSAGE EXPORT_USAGE FACTORINEFFECT GETUSERSPECIFIEDSTOP INEFFECT ISHOLIDAY RUNRATE ' +
         'SAVE_PROFILE SETREPORTTITLE USEREXIT WATFORRUNRATE TO TABLE ACOS ASIN ATAN ATAN2 BITAND CEIL ' +
         'COS COSECANT COSH COTANGENT DIVQUOT DIVREM EXP FABS FLOOR FMOD FREPM FREXPN LOG LOG10 MAX MAXN ' +
         'MIN MINNZ MODF POW ROUND ROUND2VALUE ROUNDINT SECANT SIN SINH SQROOT TAN TANH FLOAT2STRING ' +
         'FLOAT2STRINGNC INSTR LEFT LEN LTRIM MID RIGHT RTRIM STRING STRINGNC TOLOWER TOUPPER TRIM ' +
         'NUMDAYS READ_DATE STAGING',
       built_in: 'IDENTIFIER OPTIONS XML_ELEMENT XML_OP XML_ELEMENT_OF DOMDOCCREATE DOMDOCLOADFILE DOMDOCLOADXML ' +
         'DOMDOCSAVEFILE DOMDOCGETROOT DOMDOCADDPI DOMNODEGETNAME DOMNODEGETTYPE DOMNODEGETVALUE DOMNODEGETCHILDCT ' +
         'DOMNODEGETFIRSTCHILD DOMNODEGETSIBLING DOMNODECREATECHILDELEMENT DOMNODESETATTRIBUTE ' +
         'DOMNODEGETCHILDELEMENTCT DOMNODEGETFIRSTCHILDELEMENT DOMNODEGETSIBLINGELEMENT DOMNODEGETATTRIBUTECT ' +
         'DOMNODEGETATTRIBUTEI DOMNODEGETATTRIBUTEBYNAME DOMNODEGETBYNAME'
    },
    contains: [
      hljs.C_LINE_COMMENT_MODE,
      hljs.C_BLOCK_COMMENT_MODE,
      hljs.APOS_STRING_MODE,
      hljs.QUOTE_STRING_MODE,
      hljs.C_NUMBER_MODE,
      {
        className: 'array',
        variants: [
          {begin: '#\\s+[a-zA-Z\\ \\.]*', relevance: 0}, // looks like #-comment
          {begin: '#[a-zA-Z\\ \\.]+'}
        ]
      }
    ]
  };
});

hljs.registerLanguage('rust', function(hljs) {
  var NUM_SUFFIX = '([uif](8|16|32|64|size))\?';
  var BLOCK_COMMENT = hljs.inherit(hljs.C_BLOCK_COMMENT_MODE);
  BLOCK_COMMENT.contains.push('self');
  return {
    aliases: ['rs'],
    keywords: {
      keyword:
        'alignof as be box break const continue crate do else enum extern ' +
        'false fn for if impl in let loop match mod mut offsetof once priv ' +
        'proc pub pure ref return self Self sizeof static struct super trait true ' +
        'type typeof unsafe unsized use virtual while where yield ' +
        'int i8 i16 i32 i64 ' +
        'uint u8 u32 u64 ' +
        'float f32 f64 ' +
        'str char bool',
      built_in:
        // prelude
        'Copy Send Sized Sync Drop Fn FnMut FnOnce drop Box ToOwned Clone ' +
        'PartialEq PartialOrd Eq Ord AsRef AsMut Into From Default Iterator ' +
        'Extend IntoIterator DoubleEndedIterator ExactSizeIterator Option ' +
        'Some None Result Ok Err SliceConcatExt String ToString Vec ' +
        // macros
        'assert! assert_eq! bitflags! bytes! cfg! col! concat! concat_idents! ' +
        'debug_assert! debug_assert_eq! env! panic! file! format! format_args! ' +
        'include_bin! include_str! line! local_data_key! module_path! ' +
        'option_env! print! println! select! stringify! try! unimplemented! ' +
        'unreachable! vec! write! writeln!'
    },
    lexemes: hljs.IDENT_RE + '!?',
    illegal: '</',
    contains: [
      hljs.C_LINE_COMMENT_MODE,
      BLOCK_COMMENT,
      hljs.inherit(hljs.QUOTE_STRING_MODE, {illegal: null}),
      {
        className: 'string',
        variants: [
           { begin: /r(#*)".*?"\1(?!#)/ },
           { begin: /'\\?(x\w{2}|u\w{4}|U\w{8}|.)'/ },
           { begin: /'[a-zA-Z_][a-zA-Z0-9_]*/ }
        ]
      },
      {
        className: 'number',
        variants: [
          { begin: '\\b0b([01_]+)' + NUM_SUFFIX },
          { begin: '\\b0o([0-7_]+)' + NUM_SUFFIX },
          { begin: '\\b0x([A-Fa-f0-9_]+)' + NUM_SUFFIX },
          { begin: '\\b(\\d[\\d_]*(\\.[0-9_]+)?([eE][+-]?[0-9_]+)?)' +
                   NUM_SUFFIX
          }
        ],
        relevance: 0
      },
      {
        className: 'function',
        beginKeywords: 'fn', end: '(\\(|<)', excludeEnd: true,
        contains: [hljs.UNDERSCORE_TITLE_MODE]
      },
      {
        className: 'preprocessor',
        begin: '#\\!?\\[', end: '\\]'
      },
      {
        beginKeywords: 'type', end: '(=|<)',
        contains: [hljs.UNDERSCORE_TITLE_MODE],
        illegal: '\\S'
      },
      {
        beginKeywords: 'trait enum', end: '{',
        contains: [
          hljs.inherit(hljs.UNDERSCORE_TITLE_MODE, {endsParent: true})
        ],
        illegal: '[\\w\\d]'
      },
      {
        begin: hljs.IDENT_RE + '::'
      },
      {
        begin: '->'
      }
    ]
  };
});

hljs.registerLanguage('scala', function(hljs) {

  var ANNOTATION = {
    className: 'annotation', begin: '@[A-Za-z]+'
  };

  var STRING = {
    className: 'string',
    begin: 'u?r?"""', end: '"""',
    relevance: 10
  };

  var SYMBOL = {
    className: 'symbol',
    begin: '\'\\w[\\w\\d_]*(?!\')'
  };

  var TYPE = {
    className: 'type',
    begin: '\\b[A-Z][A-Za-z0-9_]*',
    relevance: 0
  };

  var NAME = {
    className: 'title',
    begin: /[^0-9\n\t "'(),.`{}\[\]:;][^\n\t "'(),.`{}\[\]:;]+|[^0-9\n\t "'(),.`{}\[\]:;=]/,
    relevance: 0
  };

  var CLASS = {
    className: 'class',
    beginKeywords: 'class object trait type',
    end: /[:={\[(\n;]/,
    contains: [{className: 'keyword', beginKeywords: 'extends with', relevance: 10}, NAME]
  };

  var METHOD = {
    className: 'function',
    beginKeywords: 'def',
    end: /[:={\[(\n;]/,
    contains: [NAME]
  };

  return {
    keywords: {
      literal: 'true false null',
      keyword: 'type yield lazy override def with val var sealed abstract private trait object if forSome for while throw finally protected extends import final return else break new catch super class case package default try this match continue throws implicit'
    },
    contains: [
      hljs.C_LINE_COMMENT_MODE,
      hljs.C_BLOCK_COMMENT_MODE,
      STRING,
      hljs.QUOTE_STRING_MODE,
      SYMBOL,
      TYPE,
      METHOD,
      CLASS,
      hljs.C_NUMBER_MODE,
      ANNOTATION
    ]
  };
});

hljs.registerLanguage('scheme', function(hljs) {
  var SCHEME_IDENT_RE = '[^\\(\\)\\[\\]\\{\\}",\'`;#|\\\\\\s]+';
  var SCHEME_SIMPLE_NUMBER_RE = '(\\-|\\+)?\\d+([./]\\d+)?';
  var SCHEME_COMPLEX_NUMBER_RE = SCHEME_SIMPLE_NUMBER_RE + '[+\\-]' + SCHEME_SIMPLE_NUMBER_RE + 'i';
  var BUILTINS = {
    built_in:
      'case-lambda call/cc class define-class exit-handler field import ' +
      'inherit init-field interface let*-values let-values let/ec mixin ' +
      'opt-lambda override protect provide public rename require ' +
      'require-for-syntax syntax syntax-case syntax-error unit/sig unless ' +
      'when with-syntax and begin call-with-current-continuation ' +
      'call-with-input-file call-with-output-file case cond define ' +
      'define-syntax delay do dynamic-wind else for-each if lambda let let* ' +
      'let-syntax letrec letrec-syntax map or syntax-rules \' * + , ,@ - ... / ' +
      '; < <= = => > >= ` abs acos angle append apply asin assoc assq assv atan ' +
      'boolean? caar cadr call-with-input-file call-with-output-file ' +
      'call-with-values car cdddar cddddr cdr ceiling char->integer ' +
      'char-alphabetic? char-ci<=? char-ci<? char-ci=? char-ci>=? char-ci>? ' +
      'char-downcase char-lower-case? char-numeric? char-ready? char-upcase ' +
      'char-upper-case? char-whitespace? char<=? char<? char=? char>=? char>? ' +
      'char? close-input-port close-output-port complex? cons cos ' +
      'current-input-port current-output-port denominator display eof-object? ' +
      'eq? equal? eqv? eval even? exact->inexact exact? exp expt floor ' +
      'force gcd imag-part inexact->exact inexact? input-port? integer->char ' +
      'integer? interaction-environment lcm length list list->string ' +
      'list->vector list-ref list-tail list? load log magnitude make-polar ' +
      'make-rectangular make-string make-vector max member memq memv min ' +
      'modulo negative? newline not null-environment null? number->string ' +
      'number? numerator odd? open-input-file open-output-file output-port? ' +
      'pair? peek-char port? positive? procedure? quasiquote quote quotient ' +
      'rational? rationalize read read-char real-part real? remainder reverse ' +
      'round scheme-report-environment set! set-car! set-cdr! sin sqrt string ' +
      'string->list string->number string->symbol string-append string-ci<=? ' +
      'string-ci<? string-ci=? string-ci>=? string-ci>? string-copy ' +
      'string-fill! string-length string-ref string-set! string<=? string<? ' +
      'string=? string>=? string>? string? substring symbol->string symbol? ' +
      'tan transcript-off transcript-on truncate values vector ' +
      'vector->list vector-fill! vector-length vector-ref vector-set! ' +
      'with-input-from-file with-output-to-file write write-char zero?'
  };

  var SHEBANG = {
    className: 'shebang',
    begin: '^#!',
    end: '$'
  };

  var LITERAL = {
    className: 'literal',
    begin: '(#t|#f|#\\\\' + SCHEME_IDENT_RE + '|#\\\\.)'
  };

  var NUMBER = {
    className: 'number',
    variants: [
      { begin: SCHEME_SIMPLE_NUMBER_RE, relevance: 0 },
      { begin: SCHEME_COMPLEX_NUMBER_RE, relevance: 0 },
      { begin: '#b[0-1]+(/[0-1]+)?' },
      { begin: '#o[0-7]+(/[0-7]+)?' },
      { begin: '#x[0-9a-f]+(/[0-9a-f]+)?' }
    ]
  };

  var STRING = hljs.QUOTE_STRING_MODE;

  var REGULAR_EXPRESSION = {
    className: 'regexp',
    begin: '#[pr]x"',
    end: '[^\\\\]"'
  };

  var COMMENT_MODES = [
    hljs.COMMENT(
      ';',
      '$',
      {
        relevance: 0
      }
    ),
    hljs.COMMENT('#\\|', '\\|#')
  ];

  var IDENT = {
    begin: SCHEME_IDENT_RE,
    relevance: 0
  };

  var QUOTED_IDENT = {
    className: 'variable',
    begin: '\'' + SCHEME_IDENT_RE
  };

  var BODY = {
    endsWithParent: true,
    relevance: 0
  };

  var LIST = {
    className: 'list',
    variants: [
      { begin: '\\(', end: '\\)' },
      { begin: '\\[', end: '\\]' }
    ],
    contains: [
      {
        className: 'keyword',
        begin: SCHEME_IDENT_RE,
        lexemes: SCHEME_IDENT_RE,
        keywords: BUILTINS
      },
      BODY
    ]
  };

  BODY.contains = [LITERAL, NUMBER, STRING, IDENT, QUOTED_IDENT, LIST].concat(COMMENT_MODES);

  return {
    illegal: /\S/,
    contains: [SHEBANG, NUMBER, STRING, QUOTED_IDENT, LIST].concat(COMMENT_MODES)
  };
});

hljs.registerLanguage('scilab', function(hljs) {

  var COMMON_CONTAINS = [
    hljs.C_NUMBER_MODE,
    {
      className: 'string',
      begin: '\'|\"', end: '\'|\"',
      contains: [hljs.BACKSLASH_ESCAPE, {begin: '\'\''}]
    }
  ];

  return {
    aliases: ['sci'],
    keywords: {
      keyword: 'abort break case clear catch continue do elseif else endfunction end for function'+
        'global if pause return resume select try then while'+
        '%f %F %t %T %pi %eps %inf %nan %e %i %z %s',
      built_in: // Scilab has more than 2000 functions. Just list the most commons
       'abs and acos asin atan ceil cd chdir clearglobal cosh cos cumprod deff disp error'+
       'exec execstr exists exp eye gettext floor fprintf fread fsolve imag isdef isempty'+
       'isinfisnan isvector lasterror length load linspace list listfiles log10 log2 log'+
       'max min msprintf mclose mopen ones or pathconvert poly printf prod pwd rand real'+
       'round sinh sin size gsort sprintf sqrt strcat strcmps tring sum system tanh tan'+
       'type typename warning zeros matrix'
    },
    illegal: '("|#|/\\*|\\s+/\\w+)',
    contains: [
      {
        className: 'function',
        beginKeywords: 'function endfunction', end: '$',
        keywords: 'function endfunction|10',
        contains: [
          hljs.UNDERSCORE_TITLE_MODE,
          {
            className: 'params',
            begin: '\\(', end: '\\)'
          }
        ]
      },
      {
        className: 'transposed_variable',
        begin: '[a-zA-Z_][a-zA-Z_0-9]*(\'+[\\.\']*|[\\.\']+)', end: '',
        relevance: 0
      },
      {
        className: 'matrix',
        begin: '\\[', end: '\\]\'*[\\.\']*',
        relevance: 0,
        contains: COMMON_CONTAINS
      },
      hljs.COMMENT('//', '$')
    ].concat(COMMON_CONTAINS)
  };
});

hljs.registerLanguage('scss', function(hljs) {
  var IDENT_RE = '[a-zA-Z-][a-zA-Z0-9_-]*';
  var VARIABLE = {
    className: 'variable',
    begin: '(\\$' + IDENT_RE + ')\\b'
  };
  var FUNCTION = {
    className: 'function',
    begin: IDENT_RE + '\\(',
    returnBegin: true,
    excludeEnd: true,
    end: '\\('
  };
  var HEXCOLOR = {
    className: 'hexcolor', begin: '#[0-9A-Fa-f]+'
  };
  var DEF_INTERNALS = {
    className: 'attribute',
    begin: '[A-Z\\_\\.\\-]+', end: ':',
    excludeEnd: true,
    illegal: '[^\\s]',
    starts: {
      className: 'value',
      endsWithParent: true, excludeEnd: true,
      contains: [
        FUNCTION,
        HEXCOLOR,
        hljs.CSS_NUMBER_MODE,
        hljs.QUOTE_STRING_MODE,
        hljs.APOS_STRING_MODE,
        hljs.C_BLOCK_COMMENT_MODE,
        {
          className: 'important', begin: '!important'
        }
      ]
    }
  };
  return {
    case_insensitive: true,
    illegal: '[=/|\']',
    contains: [
      hljs.C_LINE_COMMENT_MODE,
      hljs.C_BLOCK_COMMENT_MODE,
      FUNCTION,
      {
        className: 'id', begin: '\\#[A-Za-z0-9_-]+',
        relevance: 0
      },
      {
        className: 'class', begin: '\\.[A-Za-z0-9_-]+',
        relevance: 0
      },
      {
        className: 'attr_selector',
        begin: '\\[', end: '\\]',
        illegal: '$'
      },
      {
        className: 'tag', // begin: IDENT_RE, end: '[,|\\s]'
        begin: '\\b(a|abbr|acronym|address|area|article|aside|audio|b|base|big|blockquote|body|br|button|canvas|caption|cite|code|col|colgroup|command|datalist|dd|del|details|dfn|div|dl|dt|em|embed|fieldset|figcaption|figure|footer|form|frame|frameset|(h[1-6])|head|header|hgroup|hr|html|i|iframe|img|input|ins|kbd|keygen|label|legend|li|link|map|mark|meta|meter|nav|noframes|noscript|object|ol|optgroup|option|output|p|param|pre|progress|q|rp|rt|ruby|samp|script|section|select|small|span|strike|strong|style|sub|sup|table|tbody|td|textarea|tfoot|th|thead|time|title|tr|tt|ul|var|video)\\b',
        relevance: 0
      },
      {
        className: 'pseudo',
        begin: ':(visited|valid|root|right|required|read-write|read-only|out-range|optional|only-of-type|only-child|nth-of-type|nth-last-of-type|nth-last-child|nth-child|not|link|left|last-of-type|last-child|lang|invalid|indeterminate|in-range|hover|focus|first-of-type|first-line|first-letter|first-child|first|enabled|empty|disabled|default|checked|before|after|active)'
      },
      {
        className: 'pseudo',
        begin: '::(after|before|choices|first-letter|first-line|repeat-index|repeat-item|selection|value)'
      },
      VARIABLE,
      {
        className: 'attribute',
        begin: '\\b(z-index|word-wrap|word-spacing|word-break|width|widows|white-space|visibility|vertical-align|unicode-bidi|transition-timing-function|transition-property|transition-duration|transition-delay|transition|transform-style|transform-origin|transform|top|text-underline-position|text-transform|text-shadow|text-rendering|text-overflow|text-indent|text-decoration-style|text-decoration-line|text-decoration-color|text-decoration|text-align-last|text-align|tab-size|table-layout|right|resize|quotes|position|pointer-events|perspective-origin|perspective|page-break-inside|page-break-before|page-break-after|padding-top|padding-right|padding-left|padding-bottom|padding|overflow-y|overflow-x|overflow-wrap|overflow|outline-width|outline-style|outline-offset|outline-color|outline|orphans|order|opacity|object-position|object-fit|normal|none|nav-up|nav-right|nav-left|nav-index|nav-down|min-width|min-height|max-width|max-height|mask|marks|margin-top|margin-right|margin-left|margin-bottom|margin|list-style-type|list-style-position|list-style-image|list-style|line-height|letter-spacing|left|justify-content|initial|inherit|ime-mode|image-orientation|image-resolution|image-rendering|icon|hyphens|height|font-weight|font-variant-ligatures|font-variant|font-style|font-stretch|font-size-adjust|font-size|font-language-override|font-kerning|font-feature-settings|font-family|font|float|flex-wrap|flex-shrink|flex-grow|flex-flow|flex-direction|flex-basis|flex|filter|empty-cells|display|direction|cursor|counter-reset|counter-increment|content|column-width|column-span|column-rule-width|column-rule-style|column-rule-color|column-rule|column-gap|column-fill|column-count|columns|color|clip-path|clip|clear|caption-side|break-inside|break-before|break-after|box-sizing|box-shadow|box-decoration-break|bottom|border-width|border-top-width|border-top-style|border-top-right-radius|border-top-left-radius|border-top-color|border-top|border-style|border-spacing|border-right-width|border-right-style|border-right-color|border-right|border-radius|border-left-width|border-left-style|border-left-color|border-left|border-image-width|border-image-source|border-image-slice|border-image-repeat|border-image-outset|border-image|border-color|border-collapse|border-bottom-width|border-bottom-style|border-bottom-right-radius|border-bottom-left-radius|border-bottom-color|border-bottom|border|background-size|background-repeat|background-position|background-origin|background-image|background-color|background-clip|background-attachment|background-blend-mode|background|backface-visibility|auto|animation-timing-function|animation-play-state|animation-name|animation-iteration-count|animation-fill-mode|animation-duration|animation-direction|animation-delay|animation|align-self|align-items|align-content)\\b',
        illegal: '[^\\s]'
      },
      {
        className: 'value',
        begin: '\\b(whitespace|wait|w-resize|visible|vertical-text|vertical-ideographic|uppercase|upper-roman|upper-alpha|underline|transparent|top|thin|thick|text|text-top|text-bottom|tb-rl|table-header-group|table-footer-group|sw-resize|super|strict|static|square|solid|small-caps|separate|se-resize|scroll|s-resize|rtl|row-resize|ridge|right|repeat|repeat-y|repeat-x|relative|progress|pointer|overline|outside|outset|oblique|nowrap|not-allowed|normal|none|nw-resize|no-repeat|no-drop|newspaper|ne-resize|n-resize|move|middle|medium|ltr|lr-tb|lowercase|lower-roman|lower-alpha|loose|list-item|line|line-through|line-edge|lighter|left|keep-all|justify|italic|inter-word|inter-ideograph|inside|inset|inline|inline-block|inherit|inactive|ideograph-space|ideograph-parenthesis|ideograph-numeric|ideograph-alpha|horizontal|hidden|help|hand|groove|fixed|ellipsis|e-resize|double|dotted|distribute|distribute-space|distribute-letter|distribute-all-lines|disc|disabled|default|decimal|dashed|crosshair|collapse|col-resize|circle|char|center|capitalize|break-word|break-all|bottom|both|bolder|bold|block|bidi-override|below|baseline|auto|always|all-scroll|absolute|table|table-cell)\\b'
      },
      {
        className: 'value',
        begin: ':', end: ';',
        contains: [
          FUNCTION,
          VARIABLE,
          HEXCOLOR,
          hljs.CSS_NUMBER_MODE,
          hljs.QUOTE_STRING_MODE,
          hljs.APOS_STRING_MODE,
          {
            className: 'important', begin: '!important'
          }
        ]
      },
      {
        className: 'at_rule',
        begin: '@', end: '[{;]',
        keywords: 'mixin include extend for if else each while charset import debug media page content font-face namespace warn',
        contains: [
          FUNCTION,
          VARIABLE,
          hljs.QUOTE_STRING_MODE,
          hljs.APOS_STRING_MODE,
          HEXCOLOR,
          hljs.CSS_NUMBER_MODE,
          {
            className: 'preprocessor',
            begin: '\\s[A-Za-z0-9_.-]+',
            relevance: 0
          }
        ]
      }
    ]
  };
});

hljs.registerLanguage('smali', function(hljs) {
  var smali_instr_low_prio = ['add', 'and', 'cmp', 'cmpg', 'cmpl', 'const', 'div', 'double', 'float', 'goto', 'if', 'int', 'long', 'move', 'mul', 'neg', 'new', 'nop', 'not', 'or', 'rem', 'return', 'shl', 'shr', 'sput', 'sub', 'throw', 'ushr', 'xor'];
  var smali_instr_high_prio = ['aget', 'aput', 'array', 'check', 'execute', 'fill', 'filled', 'goto/16', 'goto/32', 'iget', 'instance', 'invoke', 'iput', 'monitor', 'packed', 'sget', 'sparse'];
  var smali_keywords = ['transient', 'constructor', 'abstract', 'final', 'synthetic', 'public', 'private', 'protected', 'static', 'bridge', 'system'];
  return {
    aliases: ['smali'],
    contains: [
      {
        className: 'string',
        begin: '"', end: '"',
        relevance: 0
      },
      hljs.COMMENT(
        '#',
        '$',
        {
          relevance: 0
        }
      ),
      {
        className: 'keyword',
        begin: '\\s*\\.end\\s[a-zA-Z0-9]*',
        relevance: 1
      },
      {
        className: 'keyword',
        begin: '^[ ]*\\.[a-zA-Z]*',
        relevance: 0
      },
      {
        className: 'keyword',
        begin: '\\s:[a-zA-Z_0-9]*',
        relevance: 0
      },
      {
        className: 'keyword',
        begin: '\\s('+smali_keywords.join('|')+')',
        relevance: 1
      },
      {
        className: 'keyword',
        begin: '\\[',
        relevance: 0
      },
      {
        className: 'instruction',
        begin: '\\s('+smali_instr_low_prio.join('|')+')\\s',
        relevance: 1
      },
      {
        className: 'instruction',
        begin: '\\s('+smali_instr_low_prio.join('|')+')((\\-|/)[a-zA-Z0-9]+)+\\s',
        relevance: 10
      },
      {
        className: 'instruction',
        begin: '\\s('+smali_instr_high_prio.join('|')+')((\\-|/)[a-zA-Z0-9]+)*\\s',
        relevance: 10
      },
      {
        className: 'class',
        begin: 'L[^\(;:\n]*;',
        relevance: 0
      },
      {
        className: 'function',
        begin: '( |->)[^(\n ;"]*\\(',
        relevance: 0
      },
      {
        className: 'function',
        begin: '\\)',
        relevance: 0
      },
      {
        className: 'variable',
        begin: '[vp][0-9]+',
        relevance: 0
      }
    ]
  };
});

hljs.registerLanguage('smalltalk', function(hljs) {
  var VAR_IDENT_RE = '[a-z][a-zA-Z0-9_]*';
  var CHAR = {
    className: 'char',
    begin: '\\$.{1}'
  };
  var SYMBOL = {
    className: 'symbol',
    begin: '#' + hljs.UNDERSCORE_IDENT_RE
  };
  return {
    aliases: ['st'],
    keywords: 'self super nil true false thisContext', // only 6
    contains: [
      hljs.COMMENT('"', '"'),
      hljs.APOS_STRING_MODE,
      {
        className: 'class',
        begin: '\\b[A-Z][A-Za-z0-9_]*',
        relevance: 0
      },
      {
        className: 'method',
        begin: VAR_IDENT_RE + ':',
        relevance: 0
      },
      hljs.C_NUMBER_MODE,
      SYMBOL,
      CHAR,
      {
        className: 'localvars',
        // This looks more complicated than needed to avoid combinatorial
        // explosion under V8. It effectively means `| var1 var2 ... |` with
        // whitespace adjacent to `|` being optional.
        begin: '\\|[ ]*' + VAR_IDENT_RE + '([ ]+' + VAR_IDENT_RE + ')*[ ]*\\|',
        returnBegin: true, end: /\|/,
        illegal: /\S/,
        contains: [{begin: '(\\|[ ]*)?' + VAR_IDENT_RE}]
      },
      {
        className: 'array',
        begin: '\\#\\(', end: '\\)',
        contains: [
          hljs.APOS_STRING_MODE,
          CHAR,
          hljs.C_NUMBER_MODE,
          SYMBOL
        ]
      }
    ]
  };
});

hljs.registerLanguage('sml', function(hljs) {
  return {
    aliases: ['ml'],
    keywords: {
      keyword:
        /* according to Definition of Standard ML 97  */
        'abstype and andalso as case datatype do else end eqtype ' +
        'exception fn fun functor handle if in include infix infixr ' +
        'let local nonfix of op open orelse raise rec sharing sig ' +
        'signature struct structure then type val with withtype where while',
      built_in:
        /* built-in types according to basis library */
        'array bool char exn int list option order real ref string substring vector unit word',
      literal:
        'true false NONE SOME LESS EQUAL GREATER nil'
    },
    illegal: /\/\/|>>/,
    lexemes: '[a-z_]\\w*!?',
    contains: [
      {
        className: 'literal',
        begin: '\\[(\\|\\|)?\\]|\\(\\)'
      },
      hljs.COMMENT(
        '\\(\\*',
        '\\*\\)',
        {
          contains: ['self']
        }
      ),
      { /* type variable */
        className: 'symbol',
        begin: '\'[A-Za-z_](?!\')[\\w\']*'
        /* the grammar is ambiguous on how 'a'b should be interpreted but not the compiler */
      },
      { /* polymorphic variant */
        className: 'tag',
        begin: '`[A-Z][\\w\']*'
      },
      { /* module or constructor */
        className: 'type',
        begin: '\\b[A-Z][\\w\']*',
        relevance: 0
      },
      { /* don't color identifiers, but safely catch all identifiers with '*/
        begin: '[a-z_]\\w*\'[\\w\']*'
      },
      hljs.inherit(hljs.APOS_STRING_MODE, {className: 'char', relevance: 0}),
      hljs.inherit(hljs.QUOTE_STRING_MODE, {illegal: null}),
      {
        className: 'number',
        begin:
          '\\b(0[xX][a-fA-F0-9_]+[Lln]?|' +
          '0[oO][0-7_]+[Lln]?|' +
          '0[bB][01_]+[Lln]?|' +
          '[0-9][0-9_]*([Lln]|(\\.[0-9_]*)?([eE][-+]?[0-9_]+)?)?)',
        relevance: 0
      },
      {
        begin: /[-=]>/ // relevance booster
      }
    ]
  };
});

hljs.registerLanguage('sqf', function(hljs) {
  var allCommands = ['!', '-', '+', '!=', '%', '&&', '*', '/', '=', '==', '>', '>=', '<', '<=', 'or', 'plus', '^', ':', '>>', 'abs', 'accTime', 'acos', 'action', 'actionKeys', 'actionKeysImages', 'actionKeysNames', 'actionKeysNamesArray', 'actionName', 'activateAddons', 'activatedAddons', 'activateKey', 'addAction', 'addBackpack', 'addBackpackCargo', 'addBackpackCargoGlobal', 'addBackpackGlobal', 'addCamShake', 'addCuratorAddons', 'addCuratorCameraArea', 'addCuratorEditableObjects', 'addCuratorEditingArea', 'addCuratorPoints', 'addEditorObject', 'addEventHandler', 'addGoggles', 'addGroupIcon', 'addHandgunItem', 'addHeadgear', 'addItem', 'addItemCargo', 'addItemCargoGlobal', 'addItemPool', 'addItemToBackpack', 'addItemToUniform', 'addItemToVest', 'addLiveStats', 'addMagazine', 'addMagazine array', 'addMagazineAmmoCargo', 'addMagazineCargo', 'addMagazineCargoGlobal', 'addMagazineGlobal', 'addMagazinePool', 'addMagazines', 'addMagazineTurret', 'addMenu', 'addMenuItem', 'addMissionEventHandler', 'addMPEventHandler', 'addMusicEventHandler', 'addPrimaryWeaponItem', 'addPublicVariableEventHandler', 'addRating', 'addResources', 'addScore', 'addScoreSide', 'addSecondaryWeaponItem', 'addSwitchableUnit', 'addTeamMember', 'addToRemainsCollector', 'addUniform', 'addVehicle', 'addVest', 'addWaypoint', 'addWeapon', 'addWeaponCargo', 'addWeaponCargoGlobal', 'addWeaponGlobal', 'addWeaponPool', 'addWeaponTurret', 'agent', 'agents', 'AGLToASL', 'aimedAtTarget', 'aimPos', 'airDensityRTD', 'airportSide', 'AISFinishHeal', 'alive', 'allControls', 'allCurators', 'allDead', 'allDeadMen', 'allDisplays', 'allGroups', 'allMapMarkers', 'allMines', 'allMissionObjects', 'allow3DMode', 'allowCrewInImmobile', 'allowCuratorLogicIgnoreAreas', 'allowDamage', 'allowDammage', 'allowFileOperations', 'allowFleeing', 'allowGetIn', 'allPlayers', 'allSites', 'allTurrets', 'allUnits', 'allUnitsUAV', 'allVariables', 'ammo', 'and', 'animate', 'animateDoor', 'animationPhase', 'animationState', 'append', 'armoryPoints', 'arrayIntersect', 'asin', 'ASLToAGL', 'ASLToATL', 'assert', 'assignAsCargo', 'assignAsCargoIndex', 'assignAsCommander', 'assignAsDriver', 'assignAsGunner', 'assignAsTurret', 'assignCurator', 'assignedCargo', 'assignedCommander', 'assignedDriver', 'assignedGunner', 'assignedItems', 'assignedTarget', 'assignedTeam', 'assignedVehicle', 'assignedVehicleRole', 'assignItem', 'assignTeam', 'assignToAirport', 'atan', 'atan2', 'atg', 'ATLToASL', 'attachedObject', 'attachedObjects', 'attachedTo', 'attachObject', 'attachTo', 'attackEnabled', 'backpack', 'backpackCargo', 'backpackContainer', 'backpackItems', 'backpackMagazines', 'backpackSpaceFor', 'behaviour', 'benchmark', 'binocular', 'blufor', 'boundingBox', 'boundingBoxReal', 'boundingCenter', 'breakOut', 'breakTo', 'briefingName', 'buildingExit', 'buildingPos', 'buttonAction', 'buttonSetAction', 'cadetMode', 'call', 'callExtension', 'camCommand', 'camCommit', 'camCommitPrepared', 'camCommitted', 'camConstuctionSetParams', 'camCreate', 'camDestroy', 'cameraEffect', 'cameraEffectEnableHUD', 'cameraInterest', 'cameraOn', 'cameraView', 'campaignConfigFile', 'camPreload', 'camPreloaded', 'camPrepareBank', 'camPrepareDir', 'camPrepareDive', 'camPrepareFocus', 'camPrepareFov', 'camPrepareFovRange', 'camPreparePos', 'camPrepareRelPos', 'camPrepareTarget', 'camSetBank', 'camSetDir', 'camSetDive', 'camSetFocus', 'camSetFov', 'camSetFovRange', 'camSetPos', 'camSetRelPos', 'camSetTarget', 'camTarget', 'camUseNVG', 'canAdd', 'canAddItemToBackpack', 'canAddItemToUniform', 'canAddItemToVest', 'cancelSimpleTaskDestination', 'canFire', 'canMove', 'canSlingLoad', 'canStand', 'canUnloadInCombat', 'captive', 'captiveNum', 'case', 'catch', 'cbChecked', 'cbSetChecked', 'ceil', 'cheatsEnabled', 'checkAIFeature', 'civilian', 'className', 'clearAllItemsFromBackpack', 'clearBackpackCargo', 'clearBackpackCargoGlobal', 'clearGroupIcons', 'clearItemCargo', 'clearItemCargoGlobal', 'clearItemPool', 'clearMagazineCargo', 'clearMagazineCargoGlobal', 'clearMagazinePool', 'clearOverlay', 'clearRadio', 'clearWeaponCargo', 'clearWeaponCargoGlobal', 'clearWeaponPool', 'closeDialog', 'closeDisplay', 'closeOverlay', 'collapseObjectTree', 'combatMode', 'commandArtilleryFire', 'commandChat', 'commander', 'commandFire', 'commandFollow', 'commandFSM', 'commandGetOut', 'commandingMenu', 'commandMove', 'commandRadio', 'commandStop', 'commandTarget', 'commandWatch', 'comment', 'commitOverlay', 'compile', 'compileFinal', 'completedFSM', 'composeText', 'configClasses', 'configFile', 'configHierarchy', 'configName', 'configProperties', 'configSourceMod', 'configSourceModList', 'connectTerminalToUAV', 'controlNull', 'controlsGroupCtrl', 'copyFromClipboard', 'copyToClipboard', 'copyWaypoints', 'cos', 'count', 'countEnemy', 'countFriendly', 'countSide', 'countType', 'countUnknown', 'createAgent', 'createCenter', 'createDialog', 'createDiaryLink', 'createDiaryRecord', 'createDiarySubject', 'createDisplay', 'createGearDialog', 'createGroup', 'createGuardedPoint', 'createLocation', 'createMarker', 'createMarkerLocal', 'createMenu', 'createMine', 'createMissionDisplay', 'createSimpleTask', 'createSite', 'createSoundSource', 'createTask', 'createTeam', 'createTrigger', 'createUnit', 'createUnit array', 'createVehicle', 'createVehicle array', 'createVehicleCrew', 'createVehicleLocal', 'crew', 'ctrlActivate', 'ctrlAddEventHandler', 'ctrlAutoScrollDelay', 'ctrlAutoScrollRewind', 'ctrlAutoScrollSpeed', 'ctrlChecked', 'ctrlClassName', 'ctrlCommit', 'ctrlCommitted', 'ctrlCreate', 'ctrlDelete', 'ctrlEnable', 'ctrlEnabled', 'ctrlFade', 'ctrlHTMLLoaded', 'ctrlIDC', 'ctrlIDD', 'ctrlMapAnimAdd', 'ctrlMapAnimClear', 'ctrlMapAnimCommit', 'ctrlMapAnimDone', 'ctrlMapCursor', 'ctrlMapMouseOver', 'ctrlMapScale', 'ctrlMapScreenToWorld', 'ctrlMapWorldToScreen', 'ctrlModel', 'ctrlModelDirAndUp', 'ctrlModelScale', 'ctrlParent', 'ctrlPosition', 'ctrlRemoveAllEventHandlers', 'ctrlRemoveEventHandler', 'ctrlScale', 'ctrlSetActiveColor', 'ctrlSetAutoScrollDelay', 'ctrlSetAutoScrollRewind', 'ctrlSetAutoScrollSpeed', 'ctrlSetBackgroundColor', 'ctrlSetChecked', 'ctrlSetEventHandler', 'ctrlSetFade', 'ctrlSetFocus', 'ctrlSetFont', 'ctrlSetFontH1', 'ctrlSetFontH1B', 'ctrlSetFontH2', 'ctrlSetFontH2B', 'ctrlSetFontH3', 'ctrlSetFontH3B', 'ctrlSetFontH4', 'ctrlSetFontH4B', 'ctrlSetFontH5', 'ctrlSetFontH5B', 'ctrlSetFontH6', 'ctrlSetFontH6B', 'ctrlSetFontHeight', 'ctrlSetFontHeightH1', 'ctrlSetFontHeightH2', 'ctrlSetFontHeightH3', 'ctrlSetFontHeightH4', 'ctrlSetFontHeightH5', 'ctrlSetFontHeightH6', 'ctrlSetFontP', 'ctrlSetFontPB', 'ctrlSetForegroundColor', 'ctrlSetModel', 'ctrlSetModelDirAndUp', 'ctrlSetModelScale', 'ctrlSetPosition', 'ctrlSetScale', 'ctrlSetStructuredText', 'ctrlSetText', 'ctrlSetTextColor', 'ctrlSetTooltip', 'ctrlSetTooltipColorBox', 'ctrlSetTooltipColorShade', 'ctrlSetTooltipColorText', 'ctrlShow', 'ctrlShown', 'ctrlText', 'ctrlTextHeight', 'ctrlType', 'ctrlVisible', 'curatorAddons', 'curatorCamera', 'curatorCameraArea', 'curatorCameraAreaCeiling', 'curatorCoef', 'curatorEditableObjects', 'curatorEditingArea', 'curatorEditingAreaType', 'curatorMouseOver', 'curatorPoints', 'curatorRegisteredObjects', 'curatorSelected', 'curatorWaypointCost', 'currentChannel', 'currentCommand', 'currentMagazine', 'currentMagazineDetail', 'currentMagazineDetailTurret', 'currentMagazineTurret', 'currentMuzzle', 'currentNamespace', 'currentTask', 'currentTasks', 'currentThrowable', 'currentVisionMode', 'currentWaypoint', 'currentWeapon', 'currentWeaponMode', 'currentWeaponTurret', 'currentZeroing', 'cursorTarget', 'customChat', 'customRadio', 'cutFadeOut', 'cutObj', 'cutRsc', 'cutText', 'damage', 'date', 'dateToNumber', 'daytime', 'deActivateKey', 'debriefingText', 'debugFSM', 'debugLog', 'default', 'deg', 'deleteAt', 'deleteCenter', 'deleteCollection', 'deleteEditorObject', 'deleteGroup', 'deleteIdentity', 'deleteLocation', 'deleteMarker', 'deleteMarkerLocal', 'deleteRange', 'deleteResources', 'deleteSite', 'deleteStatus', 'deleteTeam', 'deleteVehicle', 'deleteVehicleCrew', 'deleteWaypoint', 'detach', 'detectedMines', 'diag activeMissionFSMs', 'diag activeSQFScripts', 'diag activeSQSScripts', 'diag captureFrame', 'diag captureSlowFrame', 'diag fps', 'diag fpsMin', 'diag frameNo', 'diag log', 'diag logSlowFrame', 'diag tickTime', 'dialog', 'diarySubjectExists', 'didJIP', 'didJIPOwner', 'difficulty', 'difficultyEnabled', 'difficultyEnabledRTD', 'direction', 'directSay', 'disableAI', 'disableCollisionWith', 'disableConversation', 'disableDebriefingStats', 'disableSerialization', 'disableTIEquipment', 'disableUAVConnectability', 'disableUserInput', 'displayAddEventHandler', 'displayCtrl', 'displayNull', 'displayRemoveAllEventHandlers', 'displayRemoveEventHandler', 'displaySetEventHandler', 'dissolveTeam', 'distance', 'distance2D', 'distanceSqr', 'distributionRegion', 'do', 'doArtilleryFire', 'doFire', 'doFollow', 'doFSM', 'doGetOut', 'doMove', 'doorPhase', 'doStop', 'doTarget', 'doWatch', 'drawArrow', 'drawEllipse', 'drawIcon', 'drawIcon3D', 'drawLine', 'drawLine3D', 'drawLink', 'drawLocation', 'drawRectangle', 'driver', 'drop', 'east', 'echo', 'editObject', 'editorSetEventHandler', 'effectiveCommander', 'else', 'emptyPositions', 'enableAI', 'enableAIFeature', 'enableAttack', 'enableCamShake', 'enableCaustics', 'enableCollisionWith', 'enableCopilot', 'enableDebriefingStats', 'enableDiagLegend', 'enableEndDialog', 'enableEngineArtillery', 'enableEnvironment', 'enableFatigue', 'enableGunLights', 'enableIRLasers', 'enableMimics', 'enablePersonTurret', 'enableRadio', 'enableReload', 'enableRopeAttach', 'enableSatNormalOnDetail', 'enableSaving', 'enableSentences', 'enableSimulation', 'enableSimulationGlobal', 'enableTeamSwitch', 'enableUAVConnectability', 'enableUAVWaypoints', 'endLoadingScreen', 'endMission', 'engineOn', 'enginesIsOnRTD', 'enginesRpmRTD', 'enginesTorqueRTD', 'entities', 'estimatedEndServerTime', 'estimatedTimeLeft', 'evalObjectArgument', 'everyBackpack', 'everyContainer', 'exec', 'execEditorScript', 'execFSM', 'execVM', 'exit', 'exitWith', 'exp', 'expectedDestination', 'eyeDirection', 'eyePos', 'face', 'faction', 'fadeMusic', 'fadeRadio', 'fadeSound', 'fadeSpeech', 'failMission', 'false', 'fillWeaponsFromPool', 'find', 'findCover', 'findDisplay', 'findEditorObject', 'findEmptyPosition', 'findEmptyPositionReady', 'findNearestEnemy', 'finishMissionInit', 'finite', 'fire', 'fireAtTarget', 'firstBackpack', 'flag', 'flagOwner', 'fleeing', 'floor', 'flyInHeight', 'fog', 'fogForecast', 'fogParams', 'for', 'forceAddUniform', 'forceEnd', 'forceMap', 'forceRespawn', 'forceSpeed', 'forceWalk', 'forceWeaponFire', 'forceWeatherChange', 'forEach', 'forEachMember', 'forEachMemberAgent', 'forEachMemberTeam', 'format', 'formation', 'formationDirection', 'formationLeader', 'formationMembers', 'formationPosition', 'formationTask', 'formatText', 'formLeader', 'freeLook', 'from', 'fromEditor', 'fuel', 'fullCrew', 'gearSlotAmmoCount', 'gearSlotData', 'getAllHitPointsDamage', 'getAmmoCargo', 'getArray', 'getArtilleryAmmo', 'getArtilleryComputerSettings', 'getArtilleryETA', 'getAssignedCuratorLogic', 'getAssignedCuratorUnit', 'getBackpackCargo', 'getBleedingRemaining', 'getBurningValue', 'getCargoIndex', 'getCenterOfMass', 'getClientState', 'getConnectedUAV', 'getDammage', 'getDescription', 'getDir', 'getDirVisual', 'getDLCs', 'getEditorCamera', 'getEditorMode', 'getEditorObjectScope', 'getElevationOffset', 'getFatigue', 'getFriend', 'getFSMVariable', 'getFuelCargo', 'getGroupIcon', 'getGroupIconParams', 'getGroupIcons', 'getHideFrom', 'getHit', 'getHitIndex', 'getHitPointDamage', 'getItemCargo', 'getMagazineCargo', 'getMarkerColor', 'getMarkerPos', 'getMarkerSize', 'getMarkerType', 'getMass', 'getModelInfo', 'getNumber', 'getObjectArgument', 'getObjectChildren', 'getObjectDLC', 'getObjectMaterials', 'getObjectProxy', 'getObjectTextures', 'getObjectType', 'getObjectViewDistance', 'getOxygenRemaining', 'getPersonUsedDLCs', 'getPlayerChannel', 'getPlayerUID', 'getPos', 'getPosASL', 'getPosASLVisual', 'getPosASLW', 'getPosATL', 'getPosATLVisual', 'getPosVisual', 'getPosWorld', 'getRepairCargo', 'getResolution', 'getShadowDistance', 'getSlingLoad', 'getSpeed', 'getSuppression', 'getTerrainHeightASL', 'getText', 'getVariable', 'getWeaponCargo', 'getWPPos', 'glanceAt', 'globalChat', 'globalRadio', 'goggles', 'goto', 'group', 'groupChat', 'groupFromNetId', 'groupIconSelectable', 'groupIconsVisible', 'groupId', 'groupOwner', 'groupRadio', 'groupSelectedUnits', 'groupSelectUnit', 'grpNull', 'gunner', 'gusts', 'halt', 'handgunItems', 'handgunMagazine', 'handgunWeapon', 'handsHit', 'hasInterface', 'hasWeapon', 'hcAllGroups', 'hcGroupParams', 'hcLeader', 'hcRemoveAllGroups', 'hcRemoveGroup', 'hcSelected', 'hcSelectGroup', 'hcSetGroup', 'hcShowBar', 'hcShownBar', 'headgear', 'hideBody', 'hideObject', 'hideObjectGlobal', 'hint', 'hintC', 'hintCadet', 'hintSilent', 'hmd', 'hostMission', 'htmlLoad', 'HUDMovementLevels', 'humidity', 'if', 'image', 'importAllGroups', 'importance', 'in', 'incapacitatedState', 'independent', 'inflame', 'inflamed', 'inGameUISetEventHandler', 'inheritsFrom', 'initAmbientLife', 'inputAction', 'inRangeOfArtillery', 'insertEditorObject', 'intersect', 'isAbleToBreathe', 'isAgent', 'isArray', 'isAutoHoverOn', 'isAutonomous', 'isAutotest', 'isBleeding', 'isBurning', 'isClass', 'isCollisionLightOn', 'isCopilotEnabled', 'isDedicated', 'isDLCAvailable', 'isEngineOn', 'isEqualTo', 'isFlashlightOn', 'isFlatEmpty', 'isForcedWalk', 'isFormationLeader', 'isHidden', 'isInRemainsCollector', 'isInstructorFigureEnabled', 'isIRLaserOn', 'isKeyActive', 'isKindOf', 'isLightOn', 'isLocalized', 'isManualFire', 'isMarkedForCollection', 'isMultiplayer', 'isNil', 'isNull', 'isNumber', 'isObjectHidden', 'isObjectRTD', 'isOnRoad', 'isPipEnabled', 'isPlayer', 'isRealTime', 'isServer', 'isShowing3DIcons', 'isSteamMission', 'isStreamFriendlyUIEnabled', 'isText', 'isTouchingGround', 'isTurnedOut', 'isTutHintsEnabled', 'isUAVConnectable', 'isUAVConnected', 'isUniformAllowed', 'isWalking', 'isWeaponDeployed', 'isWeaponRested', 'itemCargo', 'items', 'itemsWithMagazines', 'join', 'joinAs', 'joinAsSilent', 'joinSilent', 'joinString', 'kbAddDatabase', 'kbAddDatabaseTargets', 'kbAddTopic', 'kbHasTopic', 'kbReact', 'kbRemoveTopic', 'kbTell', 'kbWasSaid', 'keyImage', 'keyName', 'knowsAbout', 'land', 'landAt', 'landResult', 'language', 'laserTarget', 'lbAdd', 'lbClear', 'lbColor', 'lbCurSel', 'lbData', 'lbDelete', 'lbIsSelected', 'lbPicture', 'lbSelection', 'lbSetColor', 'lbSetCurSel', 'lbSetData', 'lbSetPicture', 'lbSetPictureColor', 'lbSetPictureColorDisabled', 'lbSetPictureColorSelected', 'lbSetSelectColor', 'lbSetSelectColorRight', 'lbSetSelected', 'lbSetTooltip', 'lbSetValue', 'lbSize', 'lbSort', 'lbSortByValue', 'lbText', 'lbValue', 'leader', 'leaderboardDeInit', 'leaderboardGetRows', 'leaderboardInit', 'leaveVehicle', 'libraryCredits', 'libraryDisclaimers', 'lifeState', 'lightAttachObject', 'lightDetachObject', 'lightIsOn', 'lightnings', 'limitSpeed', 'linearConversion', 'lineBreak', 'lineIntersects', 'lineIntersectsObjs', 'lineIntersectsSurfaces', 'lineIntersectsWith', 'linkItem', 'list', 'listObjects', 'ln', 'lnbAddArray', 'lnbAddColumn', 'lnbAddRow', 'lnbClear', 'lnbColor', 'lnbCurSelRow', 'lnbData', 'lnbDeleteColumn', 'lnbDeleteRow', 'lnbGetColumnsPosition', 'lnbPicture', 'lnbSetColor', 'lnbSetColumnsPos', 'lnbSetCurSelRow', 'lnbSetData', 'lnbSetPicture', 'lnbSetText', 'lnbSetValue', 'lnbSize', 'lnbText', 'lnbValue', 'load', 'loadAbs', 'loadBackpack', 'loadFile', 'loadGame', 'loadIdentity', 'loadMagazine', 'loadOverlay', 'loadStatus', 'loadUniform', 'loadVest', 'local', 'localize', 'locationNull', 'locationPosition', 'lock', 'lockCameraTo', 'lockCargo', 'lockDriver', 'locked', 'lockedCargo', 'lockedDriver', 'lockedTurret', 'lockTurret', 'lockWP', 'log', 'logEntities', 'lookAt', 'lookAtPos', 'magazineCargo', 'magazines', 'magazinesAllTurrets', 'magazinesAmmo', 'magazinesAmmoCargo', 'magazinesAmmoFull', 'magazinesDetail', 'magazinesDetailBackpack', 'magazinesDetailUniform', 'magazinesDetailVest', 'magazinesTurret', 'magazineTurretAmmo', 'mapAnimAdd', 'mapAnimClear', 'mapAnimCommit', 'mapAnimDone', 'mapCenterOnCamera', 'mapGridPosition', 'markAsFinishedOnSteam', 'markerAlpha', 'markerBrush', 'markerColor', 'markerDir', 'markerPos', 'markerShape', 'markerSize', 'markerText', 'markerType', 'max', 'members', 'min', 'mineActive', 'mineDetectedBy', 'missionConfigFile', 'missionName', 'missionNamespace', 'missionStart', 'mod', 'modelToWorld', 'modelToWorldVisual', 'moonIntensity', 'morale', 'move', 'moveInAny', 'moveInCargo', 'moveInCommander', 'moveInDriver', 'moveInGunner', 'moveInTurret', 'moveObjectToEnd', 'moveOut', 'moveTime', 'moveTo', 'moveToCompleted', 'moveToFailed', 'musicVolume', 'name', 'name location', 'nameSound', 'nearEntities', 'nearestBuilding', 'nearestLocation', 'nearestLocations', 'nearestLocationWithDubbing', 'nearestObject', 'nearestObjects', 'nearObjects', 'nearObjectsReady', 'nearRoads', 'nearSupplies', 'nearTargets', 'needReload', 'netId', 'netObjNull', 'newOverlay', 'nextMenuItemIndex', 'nextWeatherChange', 'nil', 'nMenuItems', 'not', 'numberToDate', 'objectCurators', 'objectFromNetId', 'objectParent', 'objNull', 'objStatus', 'onBriefingGroup', 'onBriefingNotes', 'onBriefingPlan', 'onBriefingTeamSwitch', 'onCommandModeChanged', 'onDoubleClick', 'onEachFrame', 'onGroupIconClick', 'onGroupIconOverEnter', 'onGroupIconOverLeave', 'onHCGroupSelectionChanged', 'onMapSingleClick', 'onPlayerConnected', 'onPlayerDisconnected', 'onPreloadFinished', 'onPreloadStarted', 'onShowNewObject', 'onTeamSwitch', 'openCuratorInterface', 'openMap', 'openYoutubeVideo', 'opfor', 'or', 'orderGetIn', 'overcast', 'overcastForecast', 'owner', 'param', 'params', 'parseNumber', 'parseText', 'parsingNamespace', 'particlesQuality', 'pi', 'pickWeaponPool', 'pitch', 'playableSlotsNumber', 'playableUnits', 'playAction', 'playActionNow', 'player', 'playerRespawnTime', 'playerSide', 'playersNumber', 'playGesture', 'playMission', 'playMove', 'playMoveNow', 'playMusic', 'playScriptedMission', 'playSound', 'playSound3D', 'position', 'positionCameraToWorld', 'posScreenToWorld', 'posWorldToScreen', 'ppEffectAdjust', 'ppEffectCommit', 'ppEffectCommitted', 'ppEffectCreate', 'ppEffectDestroy', 'ppEffectEnable', 'ppEffectForceInNVG', 'precision', 'preloadCamera', 'preloadObject', 'preloadSound', 'preloadTitleObj', 'preloadTitleRsc', 'preprocessFile', 'preprocessFileLineNumbers', 'primaryWeapon', 'primaryWeaponItems', 'primaryWeaponMagazine', 'priority', 'private', 'processDiaryLink', 'productVersion', 'profileName', 'profileNamespace', 'profileNameSteam', 'progressLoadingScreen', 'progressPosition', 'progressSetPosition', 'publicVariable', 'publicVariableClient', 'publicVariableServer', 'pushBack', 'putWeaponPool', 'queryItemsPool', 'queryMagazinePool', 'queryWeaponPool', 'rad', 'radioChannelAdd', 'radioChannelCreate', 'radioChannelRemove', 'radioChannelSetCallSign', 'radioChannelSetLabel', 'radioVolume', 'rain', 'rainbow', 'random', 'rank', 'rankId', 'rating', 'rectangular', 'registeredTasks', 'registerTask', 'reload', 'reloadEnabled', 'remoteControl', 'remoteExec', 'remoteExecCall', 'removeAction', 'removeAllActions', 'removeAllAssignedItems', 'removeAllContainers', 'removeAllCuratorAddons', 'removeAllCuratorCameraAreas', 'removeAllCuratorEditingAreas', 'removeAllEventHandlers', 'removeAllHandgunItems', 'removeAllItems', 'removeAllItemsWithMagazines', 'removeAllMissionEventHandlers', 'removeAllMPEventHandlers', 'removeAllMusicEventHandlers', 'removeAllPrimaryWeaponItems', 'removeAllWeapons', 'removeBackpack', 'removeBackpackGlobal', 'removeCuratorAddons', 'removeCuratorCameraArea', 'removeCuratorEditableObjects', 'removeCuratorEditingArea', 'removeDrawIcon', 'removeDrawLinks', 'removeEventHandler', 'removeFromRemainsCollector', 'removeGoggles', 'removeGroupIcon', 'removeHandgunItem', 'removeHeadgear', 'removeItem', 'removeItemFromBackpack', 'removeItemFromUniform', 'removeItemFromVest', 'removeItems', 'removeMagazine', 'removeMagazineGlobal', 'removeMagazines', 'removeMagazinesTurret', 'removeMagazineTurret', 'removeMenuItem', 'removeMissionEventHandler', 'removeMPEventHandler', 'removeMusicEventHandler', 'removePrimaryWeaponItem', 'removeSecondaryWeaponItem', 'removeSimpleTask', 'removeSwitchableUnit', 'removeTeamMember', 'removeUniform', 'removeVest', 'removeWeapon', 'removeWeaponGlobal', 'removeWeaponTurret', 'requiredVersion', 'resetCamShake', 'resetSubgroupDirection', 'resistance', 'resize', 'resources', 'respawnVehicle', 'restartEditorCamera', 'reveal', 'revealMine', 'reverse', 'reversedMouseY', 'roadsConnectedTo', 'roleDescription', 'ropeAttachedObjects', 'ropeAttachedTo', 'ropeAttachEnabled', 'ropeAttachTo', 'ropeCreate', 'ropeCut', 'ropeEndPosition', 'ropeLength', 'ropes', 'ropeUnwind', 'ropeUnwound', 'rotorsForcesRTD', 'rotorsRpmRTD', 'round', 'runInitScript', 'safeZoneH', 'safeZoneW', 'safeZoneWAbs', 'safeZoneX', 'safeZoneXAbs', 'safeZoneY', 'saveGame', 'saveIdentity', 'saveJoysticks', 'saveOverlay', 'saveProfileNamespace', 'saveStatus', 'saveVar', 'savingEnabled', 'say', 'say2D', 'say3D', 'scopeName', 'score', 'scoreSide', 'screenToWorld', 'scriptDone', 'scriptName', 'scriptNull', 'scudState', 'secondaryWeapon', 'secondaryWeaponItems', 'secondaryWeaponMagazine', 'select', 'selectBestPlaces', 'selectDiarySubject', 'selectedEditorObjects', 'selectEditorObject', 'selectionPosition', 'selectLeader', 'selectNoPlayer', 'selectPlayer', 'selectWeapon', 'selectWeaponTurret', 'sendAUMessage', 'sendSimpleCommand', 'sendTask', 'sendTaskResult', 'sendUDPMessage', 'serverCommand', 'serverCommandAvailable', 'serverCommandExecutable', 'serverName', 'serverTime', 'set', 'setAccTime', 'setAirportSide', 'setAmmo', 'setAmmoCargo', 'setAperture', 'setApertureNew', 'setArmoryPoints', 'setAttributes', 'setAutonomous', 'setBehaviour', 'setBleedingRemaining', 'setCameraInterest', 'setCamShakeDefParams', 'setCamShakeParams', 'setCamUseTi', 'setCaptive', 'setCenterOfMass', 'setCollisionLight', 'setCombatMode', 'setCompassOscillation', 'setCuratorCameraAreaCeiling', 'setCuratorCoef', 'setCuratorEditingAreaType', 'setCuratorWaypointCost', 'setCurrentChannel', 'setCurrentTask', 'setCurrentWaypoint', 'setDamage', 'setDammage', 'setDate', 'setDebriefingText', 'setDefaultCamera', 'setDestination', 'setDetailMapBlendPars', 'setDir', 'setDirection', 'setDrawIcon', 'setDropInterval', 'setEditorMode', 'setEditorObjectScope', 'setEffectCondition', 'setFace', 'setFaceAnimation', 'setFatigue', 'setFlagOwner', 'setFlagSide', 'setFlagTexture', 'setFog', 'setFog array', 'setFormation', 'setFormationTask', 'setFormDir', 'setFriend', 'setFromEditor', 'setFSMVariable', 'setFuel', 'setFuelCargo', 'setGroupIcon', 'setGroupIconParams', 'setGroupIconsSelectable', 'setGroupIconsVisible', 'setGroupId', 'setGroupIdGlobal', 'setGroupOwner', 'setGusts', 'setHideBehind', 'setHit', 'setHitIndex', 'setHitPointDamage', 'setHorizonParallaxCoef', 'setHUDMovementLevels', 'setIdentity', 'setImportance', 'setLeader', 'setLightAmbient', 'setLightAttenuation', 'setLightBrightness', 'setLightColor', 'setLightDayLight', 'setLightFlareMaxDistance', 'setLightFlareSize', 'setLightIntensity', 'setLightnings', 'setLightUseFlare', 'setLocalWindParams', 'setMagazineTurretAmmo', 'setMarkerAlpha', 'setMarkerAlphaLocal', 'setMarkerBrush', 'setMarkerBrushLocal', 'setMarkerColor', 'setMarkerColorLocal', 'setMarkerDir', 'setMarkerDirLocal', 'setMarkerPos', 'setMarkerPosLocal', 'setMarkerShape', 'setMarkerShapeLocal', 'setMarkerSize', 'setMarkerSizeLocal', 'setMarkerText', 'setMarkerTextLocal', 'setMarkerType', 'setMarkerTypeLocal', 'setMass', 'setMimic', 'setMousePosition', 'setMusicEffect', 'setMusicEventHandler', 'setName', 'setNameSound', 'setObjectArguments', 'setObjectMaterial', 'setObjectProxy', 'setObjectTexture', 'setObjectTextureGlobal', 'setObjectViewDistance', 'setOvercast', 'setOwner', 'setOxygenRemaining', 'setParticleCircle', 'setParticleClass', 'setParticleFire', 'setParticleParams', 'setParticleRandom', 'setPilotLight', 'setPiPEffect', 'setPitch', 'setPlayable', 'setPlayerRespawnTime', 'setPos', 'setPosASL', 'setPosASL2', 'setPosASLW', 'setPosATL', 'setPosition', 'setPosWorld', 'setRadioMsg', 'setRain', 'setRainbow', 'setRandomLip', 'setRank', 'setRectangular', 'setRepairCargo', 'setShadowDistance', 'setSide', 'setSimpleTaskDescription', 'setSimpleTaskDestination', 'setSimpleTaskTarget', 'setSimulWeatherLayers', 'setSize', 'setSkill', 'setSkill array', 'setSlingLoad', 'setSoundEffect', 'setSpeaker', 'setSpeech', 'setSpeedMode', 'setStatValue', 'setSuppression', 'setSystemOfUnits', 'setTargetAge', 'setTaskResult', 'setTaskState', 'setTerrainGrid', 'setText', 'setTimeMultiplier', 'setTitleEffect', 'setTriggerActivation', 'setTriggerArea', 'setTriggerStatements', 'setTriggerText', 'setTriggerTimeout', 'setTriggerType', 'setType', 'setUnconscious', 'setUnitAbility', 'setUnitPos', 'setUnitPosWeak', 'setUnitRank', 'setUnitRecoilCoefficient', 'setUnloadInCombat', 'setUserActionText', 'setVariable', 'setVectorDir', 'setVectorDirAndUp', 'setVectorUp', 'setVehicleAmmo', 'setVehicleAmmoDef', 'setVehicleArmor', 'setVehicleId', 'setVehicleLock', 'setVehiclePosition', 'setVehicleTiPars', 'setVehicleVarName', 'setVelocity', 'setVelocityTransformation', 'setViewDistance', 'setVisibleIfTreeCollapsed', 'setWaves', 'setWaypointBehaviour', 'setWaypointCombatMode', 'setWaypointCompletionRadius', 'setWaypointDescription', 'setWaypointFormation', 'setWaypointHousePosition', 'setWaypointLoiterRadius', 'setWaypointLoiterType', 'setWaypointName', 'setWaypointPosition', 'setWaypointScript', 'setWaypointSpeed', 'setWaypointStatements', 'setWaypointTimeout', 'setWaypointType', 'setWaypointVisible', 'setWeaponReloadingTime', 'setWind', 'setWindDir', 'setWindForce', 'setWindStr', 'setWPPos', 'show3DIcons', 'showChat', 'showCinemaBorder', 'showCommandingMenu', 'showCompass', 'showCuratorCompass', 'showGPS', 'showHUD', 'showLegend', 'showMap', 'shownArtilleryComputer', 'shownChat', 'shownCompass', 'shownCuratorCompass', 'showNewEditorObject', 'shownGPS', 'shownHUD', 'shownMap', 'shownPad', 'shownRadio', 'shownUAVFeed', 'shownWarrant', 'shownWatch', 'showPad', 'showRadio', 'showSubtitles', 'showUAVFeed', 'showWarrant', 'showWatch', 'showWaypoint', 'side', 'sideChat', 'sideEnemy', 'sideFriendly', 'sideLogic', 'sideRadio', 'sideUnknown', 'simpleTasks', 'simulationEnabled', 'simulCloudDensity', 'simulCloudOcclusion', 'simulInClouds', 'simulWeatherSync', 'sin', 'size', 'sizeOf', 'skill', 'skillFinal', 'skipTime', 'sleep', 'sliderPosition', 'sliderRange', 'sliderSetPosition', 'sliderSetRange', 'sliderSetSpeed', 'sliderSpeed', 'slingLoadAssistantShown', 'soldierMagazines', 'someAmmo', 'sort', 'soundVolume', 'spawn', 'speaker', 'speed', 'speedMode', 'splitString', 'sqrt', 'squadParams', 'stance', 'startLoadingScreen', 'step', 'stop', 'stopped', 'str', 'sunOrMoon', 'supportInfo', 'suppressFor', 'surfaceIsWater', 'surfaceNormal', 'surfaceType', 'swimInDepth', 'switch', 'switchableUnits', 'switchAction', 'switchCamera', 'switchGesture', 'switchLight', 'switchMove', 'synchronizedObjects', 'synchronizedTriggers', 'synchronizedWaypoints', 'synchronizeObjectsAdd', 'synchronizeObjectsRemove', 'synchronizeTrigger', 'synchronizeWaypoint', 'synchronizeWaypoint trigger', 'systemChat', 'systemOfUnits', 'tan', 'targetKnowledge', 'targetsAggregate', 'targetsQuery', 'taskChildren', 'taskCompleted', 'taskDescription', 'taskDestination', 'taskHint', 'taskNull', 'taskParent', 'taskResult', 'taskState', 'teamMember', 'teamMemberNull', 'teamName', 'teams', 'teamSwitch', 'teamSwitchEnabled', 'teamType', 'terminate', 'terrainIntersect', 'terrainIntersectASL', 'text', 'text location', 'textLog', 'textLogFormat', 'tg', 'then', 'throw', 'time', 'timeMultiplier', 'titleCut', 'titleFadeOut', 'titleObj', 'titleRsc', 'titleText', 'to', 'toArray', 'toLower', 'toString', 'toUpper', 'triggerActivated', 'triggerActivation', 'triggerArea', 'triggerAttachedVehicle', 'triggerAttachObject', 'triggerAttachVehicle', 'triggerStatements', 'triggerText', 'triggerTimeout', 'triggerTimeoutCurrent', 'triggerType', 'true', 'try', 'turretLocal', 'turretOwner', 'turretUnit', 'tvAdd', 'tvClear', 'tvCollapse', 'tvCount', 'tvCurSel', 'tvData', 'tvDelete', 'tvExpand', 'tvPicture', 'tvSetCurSel', 'tvSetData', 'tvSetPicture', 'tvSetPictureColor', 'tvSetTooltip', 'tvSetValue', 'tvSort', 'tvSortByValue', 'tvText', 'tvValue', 'type', 'typeName', 'typeOf', 'UAVControl', 'uiNamespace', 'uiSleep', 'unassignCurator', 'unassignItem', 'unassignTeam', 'unassignVehicle', 'underwater', 'uniform', 'uniformContainer', 'uniformItems', 'uniformMagazines', 'unitAddons', 'unitBackpack', 'unitPos', 'unitReady', 'unitRecoilCoefficient', 'units', 'unitsBelowHeight', 'unlinkItem', 'unlockAchievement', 'unregisterTask', 'updateDrawIcon', 'updateMenuItem', 'updateObjectTree', 'useAudioTimeForMoves', 'vectorAdd', 'vectorCos', 'vectorCrossProduct', 'vectorDiff', 'vectorDir', 'vectorDirVisual', 'vectorDistance', 'vectorDistanceSqr', 'vectorDotProduct', 'vectorFromTo', 'vectorMagnitude', 'vectorMagnitudeSqr', 'vectorMultiply', 'vectorNormalized', 'vectorUp', 'vectorUpVisual', 'vehicle', 'vehicleChat', 'vehicleRadio', 'vehicles', 'vehicleVarName', 'velocity', 'velocityModelSpace', 'verifySignature', 'vest', 'vestContainer', 'vestItems', 'vestMagazines', 'viewDistance', 'visibleCompass', 'visibleGPS', 'visibleMap', 'visiblePosition', 'visiblePositionASL', 'visibleWatch', 'waitUntil', 'waves', 'waypointAttachedObject', 'waypointAttachedVehicle', 'waypointAttachObject', 'waypointAttachVehicle', 'waypointBehaviour', 'waypointCombatMode', 'waypointCompletionRadius', 'waypointDescription', 'waypointFormation', 'waypointHousePosition', 'waypointLoiterRadius', 'waypointLoiterType', 'waypointName', 'waypointPosition', 'waypoints', 'waypointScript', 'waypointsEnabledUAV', 'waypointShow', 'waypointSpeed', 'waypointStatements', 'waypointTimeout', 'waypointTimeoutCurrent', 'waypointType', 'waypointVisible', 'weaponAccessories', 'weaponCargo', 'weaponDirection', 'weaponLowered', 'weapons', 'weaponsItems', 'weaponsItemsCargo', 'weaponState', 'weaponsTurret', 'weightRTD', 'west', 'WFSideText', 'while', 'wind', 'windDir', 'windStr', 'wingsForcesRTD', 'with', 'worldName', 'worldSize', 'worldToModel', 'worldToModelVisual', 'worldToScreen'];
  var control = ['case', 'catch', 'default', 'do', 'else', 'exit', 'exitWith|5', 'for', 'forEach', 'from', 'if', 'switch', 'then', 'throw', 'to', 'try', 'while', 'with'];
  var operators = ['!', '-', '+', '!=', '%', '&&', '*', '/', '=', '==', '>', '>=', '<', '<=', '^', ':', '>>'];
  var specials = ['_forEachIndex|10', '_this|10', '_x|10'];
  var literals = ['true', 'false', 'nil'];
  var builtins = allCommands.filter(function (command) {
    return control.indexOf(command) == -1 &&
        literals.indexOf(command) == -1 &&
        operators.indexOf(command) == -1;
  });
  //Note: operators will not be treated as builtins due to the lexeme rules
  builtins = builtins.concat(specials);

  // In SQF strings, quotes matching the start are escaped by adding a consecutive.
  // Example of single escaped quotes: " "" " and  ' '' '.
  var STRINGS = {
    className: 'string',
    relevance: 0,
    variants: [
      {
        begin: '"',
        end: '"',
        contains: [{begin: '""'}]
      },
      {
        begin: '\'',
        end: '\'',
        contains: [{begin: '\'\''}]
      }
    ]
  };

  var NUMBERS = {
    className: 'number',
    begin: hljs.NUMBER_RE,
    relevance: 0
  };

  // Preprocessor definitions borrowed from C++
  var PREPROCESSOR_STRINGS = {
    className: 'string',
    variants: [
      hljs.QUOTE_STRING_MODE,
      {
        begin: '\'\\\\?.', end: '\'',
        illegal: '.'
      }
    ]
  };

  var PREPROCESSOR =       {
    className: 'preprocessor',
    begin: '#', end: '$',
    keywords: 'if else elif endif define undef warning error line ' +
              'pragma ifdef ifndef',
    contains: [
      {
        begin: /\\\n/, relevance: 0
      },
      {
        beginKeywords: 'include', end: '$',
        contains: [
          PREPROCESSOR_STRINGS,
          {
            className: 'string',
            begin: '<', end: '>',
            illegal: '\\n',
          }
        ]
      },
      PREPROCESSOR_STRINGS,
      NUMBERS,
      hljs.C_LINE_COMMENT_MODE,
      hljs.C_BLOCK_COMMENT_MODE
    ]
  };

  return {
    aliases: ['sqf'],
    case_insensitive: true,
    keywords: {
      keyword: control.join(' '),
      built_in: builtins.join(' '),
      literal: literals.join(' ')
    },
    contains: [
      hljs.C_LINE_COMMENT_MODE,
      hljs.C_BLOCK_COMMENT_MODE,
      NUMBERS,
      STRINGS,
      PREPROCESSOR
    ]
  };
});

hljs.registerLanguage('sql', function(hljs) {
  var COMMENT_MODE = hljs.COMMENT('--', '$');
  return {
    case_insensitive: true,
    illegal: /[<>{}*]/,
    contains: [
      {
        className: 'operator',
        beginKeywords:
          'begin end start commit rollback savepoint lock alter create drop rename call ' +
          'delete do handler insert load replace select truncate update set show pragma grant ' +
          'merge describe use explain help declare prepare execute deallocate release ' +
          'unlock purge reset change stop analyze cache flush optimize repair kill ' +
          'install uninstall checksum restore check backup revoke',
        end: /;/, endsWithParent: true,
        keywords: {
          keyword:
            'abort abs absolute acc acce accep accept access accessed accessible account acos action activate add ' +
            'addtime admin administer advanced advise aes_decrypt aes_encrypt after agent aggregate ali alia alias ' +
            'allocate allow alter always analyze ancillary and any anydata anydataset anyschema anytype apply ' +
            'archive archived archivelog are as asc ascii asin assembly assertion associate asynchronous at atan ' +
            'atn2 attr attri attrib attribu attribut attribute attributes audit authenticated authentication authid ' +
            'authors auto autoallocate autodblink autoextend automatic availability avg backup badfile basicfile ' +
            'before begin beginning benchmark between bfile bfile_base big bigfile bin binary_double binary_float ' +
            'binlog bit_and bit_count bit_length bit_or bit_xor bitmap blob_base block blocksize body both bound ' +
            'buffer_cache buffer_pool build bulk by byte byteordermark bytes c cache caching call calling cancel ' +
            'capacity cascade cascaded case cast catalog category ceil ceiling chain change changed char_base ' +
            'char_length character_length characters characterset charindex charset charsetform charsetid check ' +
            'checksum checksum_agg child choose chr chunk class cleanup clear client clob clob_base clone close ' +
            'cluster_id cluster_probability cluster_set clustering coalesce coercibility col collate collation ' +
            'collect colu colum column column_value columns columns_updated comment commit compact compatibility ' +
            'compiled complete composite_limit compound compress compute concat concat_ws concurrent confirm conn ' +
            'connec connect connect_by_iscycle connect_by_isleaf connect_by_root connect_time connection ' +
            'consider consistent constant constraint constraints constructor container content contents context ' +
            'contributors controlfile conv convert convert_tz corr corr_k corr_s corresponding corruption cos cost ' +
            'count count_big counted covar_pop covar_samp cpu_per_call cpu_per_session crc32 create creation ' +
            'critical cross cube cume_dist curdate current current_date current_time current_timestamp current_user ' +
            'cursor curtime customdatum cycle d data database databases datafile datafiles datalength date_add ' +
            'date_cache date_format date_sub dateadd datediff datefromparts datename datepart datetime2fromparts ' +
            'day day_to_second dayname dayofmonth dayofweek dayofyear days db_role_change dbtimezone ddl deallocate ' +
            'declare decode decompose decrement decrypt deduplicate def defa defau defaul default defaults ' +
            'deferred defi defin define degrees delayed delegate delete delete_all delimited demand dense_rank ' +
            'depth dequeue des_decrypt des_encrypt des_key_file desc descr descri describ describe descriptor ' +
            'deterministic diagnostics difference dimension direct_load directory disable disable_all ' +
            'disallow disassociate discardfile disconnect diskgroup distinct distinctrow distribute distributed div ' +
            'do document domain dotnet double downgrade drop dumpfile duplicate duration e each edition editionable ' +
            'editions element ellipsis else elsif elt empty enable enable_all enclosed encode encoding encrypt ' +
            'end end-exec endian enforced engine engines enqueue enterprise entityescaping eomonth error errors ' +
            'escaped evalname evaluate event eventdata events except exception exceptions exchange exclude excluding ' +
            'execu execut execute exempt exists exit exp expire explain export export_set extended extent external ' +
            'external_1 external_2 externally extract f failed failed_login_attempts failover failure far fast ' +
            'feature_set feature_value fetch field fields file file_name_convert filesystem_like_logging final ' +
            'finish first first_value fixed flash_cache flashback floor flush following follows for forall force ' +
            'form forma format found found_rows freelist freelists freepools fresh from from_base64 from_days ' +
            'ftp full function g general generated get get_format get_lock getdate getutcdate global global_name ' +
            'globally go goto grant grants greatest group group_concat group_id grouping grouping_id groups ' +
            'gtid_subtract guarantee guard handler hash hashkeys having hea head headi headin heading heap help hex ' +
            'hierarchy high high_priority hosts hour http i id ident_current ident_incr ident_seed identified ' +
            'identity idle_time if ifnull ignore iif ilike ilm immediate import in include including increment ' +
            'index indexes indexing indextype indicator indices inet6_aton inet6_ntoa inet_aton inet_ntoa infile ' +
            'initial initialized initially initrans inmemory inner innodb input insert install instance instantiable ' +
            'instr interface interleaved intersect into invalidate invisible is is_free_lock is_ipv4 is_ipv4_compat ' +
            'is_not is_not_null is_used_lock isdate isnull isolation iterate java join json json_exists ' +
            'k keep keep_duplicates key keys kill l language large last last_day last_insert_id last_value lax lcase ' +
            'lead leading least leaves left len lenght length less level levels library like like2 like4 likec limit ' +
            'lines link list listagg little ln load load_file lob lobs local localtime localtimestamp locate ' +
            'locator lock locked log log10 log2 logfile logfiles logging logical logical_reads_per_call ' +
            'logoff logon logs long loop low low_priority lower lpad lrtrim ltrim m main make_set makedate maketime ' +
            'managed management manual map mapping mask master master_pos_wait match matched materialized max ' +
            'maxextents maximize maxinstances maxlen maxlogfiles maxloghistory maxlogmembers maxsize maxtrans ' +
            'md5 measures median medium member memcompress memory merge microsecond mid migration min minextents ' +
            'minimum mining minus minute minvalue missing mod mode model modification modify module monitoring month ' +
            'months mount move movement multiset mutex n name name_const names nan national native natural nav nchar ' +
            'nclob nested never new newline next nextval no no_write_to_binlog noarchivelog noaudit nobadfile ' +
            'nocheck nocompress nocopy nocycle nodelay nodiscardfile noentityescaping noguarantee nokeep nologfile ' +
            'nomapping nomaxvalue nominimize nominvalue nomonitoring none noneditionable nonschema noorder ' +
            'nopr nopro noprom nopromp noprompt norely noresetlogs noreverse normal norowdependencies noschemacheck ' +
            'noswitch not nothing notice notrim novalidate now nowait nth_value nullif nulls num numb numbe ' +
            'nvarchar nvarchar2 object ocicoll ocidate ocidatetime ociduration ociinterval ociloblocator ocinumber ' +
            'ociref ocirefcursor ocirowid ocistring ocitype oct octet_length of off offline offset oid oidindex old ' +
            'on online only opaque open operations operator optimal optimize option optionally or oracle oracle_date ' +
            'oradata ord ordaudio orddicom orddoc order ordimage ordinality ordvideo organization orlany orlvary ' +
            'out outer outfile outline output over overflow overriding p package pad parallel parallel_enable ' +
            'parameters parent parse partial partition partitions pascal passing password password_grace_time ' +
            'password_lock_time password_reuse_max password_reuse_time password_verify_function patch path patindex ' +
            'pctincrease pctthreshold pctused pctversion percent percent_rank percentile_cont percentile_disc ' +
            'performance period period_add period_diff permanent physical pi pipe pipelined pivot pluggable plugin ' +
            'policy position post_transaction pow power pragma prebuilt precedes preceding precision prediction ' +
            'prediction_cost prediction_details prediction_probability prediction_set prepare present preserve ' +
            'prior priority private private_sga privileges procedural procedure procedure_analyze processlist ' +
            'profiles project prompt protection public publishingservername purge quarter query quick quiesce quota ' +
            'quotename radians raise rand range rank raw read reads readsize rebuild record records ' +
            'recover recovery recursive recycle redo reduced ref reference referenced references referencing refresh ' +
            'regexp_like register regr_avgx regr_avgy regr_count regr_intercept regr_r2 regr_slope regr_sxx regr_sxy ' +
            'reject rekey relational relative relaylog release release_lock relies_on relocate rely rem remainder rename ' +
            'repair repeat replace replicate replication required reset resetlogs resize resource respect restore ' +
            'restricted result result_cache resumable resume retention return returning returns reuse reverse revoke ' +
            'right rlike role roles rollback rolling rollup round row row_count rowdependencies rowid rownum rows ' +
            'rtrim rules safe salt sample save savepoint sb1 sb2 sb4 scan schema schemacheck scn scope scroll ' +
            'sdo_georaster sdo_topo_geometry search sec_to_time second section securefile security seed segment select ' +
            'self sequence sequential serializable server servererror session session_user sessions_per_user set ' +
            'sets settings sha sha1 sha2 share shared shared_pool short show shrink shutdown si_averagecolor ' +
            'si_colorhistogram si_featurelist si_positionalcolor si_stillimage si_texture siblings sid sign sin ' +
            'size size_t sizes skip slave sleep smalldatetimefromparts smallfile snapshot some soname sort soundex ' +
            'source space sparse spfile split sql sql_big_result sql_buffer_result sql_cache sql_calc_found_rows ' +
            'sql_small_result sql_variant_property sqlcode sqldata sqlerror sqlname sqlstate sqrt square standalone ' +
            'standby start starting startup statement static statistics stats_binomial_test stats_crosstab ' +
            'stats_ks_test stats_mode stats_mw_test stats_one_way_anova stats_t_test_ stats_t_test_indep ' +
            'stats_t_test_one stats_t_test_paired stats_wsr_test status std stddev stddev_pop stddev_samp stdev ' +
            'stop storage store stored str str_to_date straight_join strcmp strict string struct stuff style subdate ' +
            'subpartition subpartitions substitutable substr substring subtime subtring_index subtype success sum ' +
            'suspend switch switchoffset switchover sync synchronous synonym sys sys_xmlagg sysasm sysaux sysdate ' +
            'sysdatetimeoffset sysdba sysoper system system_user sysutcdatetime t table tables tablespace tan tdo ' +
            'template temporary terminated tertiary_weights test than then thread through tier ties time time_format ' +
            'time_zone timediff timefromparts timeout timestamp timestampadd timestampdiff timezone_abbr ' +
            'timezone_minute timezone_region to to_base64 to_date to_days to_seconds todatetimeoffset trace tracking ' +
            'transaction transactional translate translation treat trigger trigger_nestlevel triggers trim truncate ' +
            'try_cast try_convert try_parse type ub1 ub2 ub4 ucase unarchived unbounded uncompress ' +
            'under undo unhex unicode uniform uninstall union unique unix_timestamp unknown unlimited unlock unpivot ' +
            'unrecoverable unsafe unsigned until untrusted unusable unused update updated upgrade upped upper upsert ' +
            'url urowid usable usage use use_stored_outlines user user_data user_resources users using utc_date ' +
            'utc_timestamp uuid uuid_short validate validate_password_strength validation valist value values var ' +
            'var_samp varcharc vari varia variab variabl variable variables variance varp varraw varrawc varray ' +
            'verify version versions view virtual visible void wait wallet warning warnings week weekday weekofyear ' +
            'wellformed when whene whenev wheneve whenever where while whitespace with within without work wrapped ' +
            'xdb xml xmlagg xmlattributes xmlcast xmlcolattval xmlelement xmlexists xmlforest xmlindex xmlnamespaces ' +
            'xmlpi xmlquery xmlroot xmlschema xmlserialize xmltable xmltype xor year year_to_month years yearweek',
          literal:
            'true false null',
          built_in:
            'array bigint binary bit blob boolean char character date dec decimal float int int8 integer interval number ' +
            'numeric real record serial serial8 smallint text varchar varying void'
        },
        contains: [
          {
            className: 'string',
            begin: '\'', end: '\'',
            contains: [hljs.BACKSLASH_ESCAPE, {begin: '\'\''}]
          },
          {
            className: 'string',
            begin: '"', end: '"',
            contains: [hljs.BACKSLASH_ESCAPE, {begin: '""'}]
          },
          {
            className: 'string',
            begin: '`', end: '`',
            contains: [hljs.BACKSLASH_ESCAPE]
          },
          hljs.C_NUMBER_MODE,
          hljs.C_BLOCK_COMMENT_MODE,
          COMMENT_MODE
        ]
      },
      hljs.C_BLOCK_COMMENT_MODE,
      COMMENT_MODE
    ]
  };
});

hljs.registerLanguage('stata', function(hljs) {
  return {
    aliases: ['do', 'ado'],
    case_insensitive: true,
    keywords: 'if else in foreach for forv forva forval forvalu forvalue forvalues by bys bysort xi quietly qui capture about ac ac_7 acprplot acprplot_7 adjust ado adopath adoupdate alpha ameans an ano anov anova anova_estat anova_terms anovadef aorder ap app appe appen append arch arch_dr arch_estat arch_p archlm areg areg_p args arima arima_dr arima_estat arima_p as asmprobit asmprobit_estat asmprobit_lf asmprobit_mfx__dlg asmprobit_p ass asse asser assert avplot avplot_7 avplots avplots_7 bcskew0 bgodfrey binreg bip0_lf biplot bipp_lf bipr_lf bipr_p biprobit bitest bitesti bitowt blogit bmemsize boot bootsamp bootstrap bootstrap_8 boxco_l boxco_p boxcox boxcox_6 boxcox_p bprobit br break brier bro brow brows browse brr brrstat bs bs_7 bsampl_w bsample bsample_7 bsqreg bstat bstat_7 bstat_8 bstrap bstrap_7 ca ca_estat ca_p cabiplot camat canon canon_8 canon_8_p canon_estat canon_p cap caprojection capt captu captur capture cat cc cchart cchart_7 cci cd censobs_table centile cf char chdir checkdlgfiles checkestimationsample checkhlpfiles checksum chelp ci cii cl class classutil clear cli clis clist clo clog clog_lf clog_p clogi clogi_sw clogit clogit_lf clogit_p clogitp clogl_sw cloglog clonevar clslistarray cluster cluster_measures cluster_stop cluster_tree cluster_tree_8 clustermat cmdlog cnr cnre cnreg cnreg_p cnreg_sw cnsreg codebook collaps4 collapse colormult_nb colormult_nw compare compress conf confi confir confirm conren cons const constr constra constrai constrain constraint continue contract copy copyright copysource cor corc corr corr2data corr_anti corr_kmo corr_smc corre correl correla correlat correlate corrgram cou coun count cox cox_p cox_sw coxbase coxhaz coxvar cprplot cprplot_7 crc cret cretu cretur creturn cross cs cscript cscript_log csi ct ct_is ctset ctst_5 ctst_st cttost cumsp cumsp_7 cumul cusum cusum_7 cutil d datasig datasign datasigna datasignat datasignatu datasignatur datasignature datetof db dbeta de dec deco decod decode deff des desc descr descri describ describe destring dfbeta dfgls dfuller di di_g dir dirstats dis discard disp disp_res disp_s displ displa display distinct do doe doed doedi doedit dotplot dotplot_7 dprobit drawnorm drop ds ds_util dstdize duplicates durbina dwstat dydx e ed edi edit egen eivreg emdef en enc enco encod encode eq erase ereg ereg_lf ereg_p ereg_sw ereghet ereghet_glf ereghet_glf_sh ereghet_gp ereghet_ilf ereghet_ilf_sh ereghet_ip eret eretu eretur ereturn err erro error est est_cfexist est_cfname est_clickable est_expand est_hold est_table est_unhold est_unholdok estat estat_default estat_summ estat_vce_only esti estimates etodow etof etomdy ex exi exit expand expandcl fac fact facto factor factor_estat factor_p factor_pca_rotated factor_rotate factormat fcast fcast_compute fcast_graph fdades fdadesc fdadescr fdadescri fdadescrib fdadescribe fdasav fdasave fdause fh_st file open file read file close file filefilter fillin find_hlp_file findfile findit findit_7 fit fl fli flis flist for5_0 form forma format fpredict frac_154 frac_adj frac_chk frac_cox frac_ddp frac_dis frac_dv frac_in frac_mun frac_pp frac_pq frac_pv frac_wgt frac_xo fracgen fracplot fracplot_7 fracpoly fracpred fron_ex fron_hn fron_p fron_tn fron_tn2 frontier ftodate ftoe ftomdy ftowdate g gamhet_glf gamhet_gp gamhet_ilf gamhet_ip gamma gamma_d2 gamma_p gamma_sw gammahet gdi_hexagon gdi_spokes ge gen gene gener genera generat generate genrank genstd genvmean gettoken gl gladder gladder_7 glim_l01 glim_l02 glim_l03 glim_l04 glim_l05 glim_l06 glim_l07 glim_l08 glim_l09 glim_l10 glim_l11 glim_l12 glim_lf glim_mu glim_nw1 glim_nw2 glim_nw3 glim_p glim_v1 glim_v2 glim_v3 glim_v4 glim_v5 glim_v6 glim_v7 glm glm_6 glm_p glm_sw glmpred glo glob globa global glogit glogit_8 glogit_p gmeans gnbre_lf gnbreg gnbreg_5 gnbreg_p gomp_lf gompe_sw gomper_p gompertz gompertzhet gomphet_glf gomphet_glf_sh gomphet_gp gomphet_ilf gomphet_ilf_sh gomphet_ip gphdot gphpen gphprint gprefs gprobi_p gprobit gprobit_8 gr gr7 gr_copy gr_current gr_db gr_describe gr_dir gr_draw gr_draw_replay gr_drop gr_edit gr_editviewopts gr_example gr_example2 gr_export gr_print gr_qscheme gr_query gr_read gr_rename gr_replay gr_save gr_set gr_setscheme gr_table gr_undo gr_use graph graph7 grebar greigen greigen_7 greigen_8 grmeanby grmeanby_7 gs_fileinfo gs_filetype gs_graphinfo gs_stat gsort gwood h hadimvo hareg hausman haver he heck_d2 heckma_p heckman heckp_lf heckpr_p heckprob hel help hereg hetpr_lf hetpr_p hetprob hettest hexdump hilite hist hist_7 histogram hlogit hlu hmeans hotel hotelling hprobit hreg hsearch icd9 icd9_ff icd9p iis impute imtest inbase include inf infi infil infile infix inp inpu input ins insheet insp inspe inspec inspect integ inten intreg intreg_7 intreg_p intrg2_ll intrg_ll intrg_ll2 ipolate iqreg ir irf irf_create irfm iri is_svy is_svysum isid istdize ivprob_1_lf ivprob_lf ivprobit ivprobit_p ivreg ivreg_footnote ivtob_1_lf ivtob_lf ivtobit ivtobit_p jackknife jacknife jknife jknife_6 jknife_8 jkstat joinby kalarma1 kap kap_3 kapmeier kappa kapwgt kdensity kdensity_7 keep ksm ksmirnov ktau kwallis l la lab labe label labelbook ladder levels levelsof leverage lfit lfit_p li lincom line linktest lis list lloghet_glf lloghet_glf_sh lloghet_gp lloghet_ilf lloghet_ilf_sh lloghet_ip llogi_sw llogis_p llogist llogistic llogistichet lnorm_lf lnorm_sw lnorma_p lnormal lnormalhet lnormhet_glf lnormhet_glf_sh lnormhet_gp lnormhet_ilf lnormhet_ilf_sh lnormhet_ip lnskew0 loadingplot loc loca local log logi logis_lf logistic logistic_p logit logit_estat logit_p loglogs logrank loneway lookfor lookup lowess lowess_7 lpredict lrecomp lroc lroc_7 lrtest ls lsens lsens_7 lsens_x lstat ltable ltable_7 ltriang lv lvr2plot lvr2plot_7 m ma mac macr macro makecns man manova manova_estat manova_p manovatest mantel mark markin markout marksample mat mat_capp mat_order mat_put_rr mat_rapp mata mata_clear mata_describe mata_drop mata_matdescribe mata_matsave mata_matuse mata_memory mata_mlib mata_mosave mata_rename mata_which matalabel matcproc matlist matname matr matri matrix matrix_input__dlg matstrik mcc mcci md0_ md1_ md1debug_ md2_ md2debug_ mds mds_estat mds_p mdsconfig mdslong mdsmat mdsshepard mdytoe mdytof me_derd mean means median memory memsize meqparse mer merg merge mfp mfx mhelp mhodds minbound mixed_ll mixed_ll_reparm mkassert mkdir mkmat mkspline ml ml_5 ml_adjs ml_bhhhs ml_c_d ml_check ml_clear ml_cnt ml_debug ml_defd ml_e0 ml_e0_bfgs ml_e0_cycle ml_e0_dfp ml_e0i ml_e1 ml_e1_bfgs ml_e1_bhhh ml_e1_cycle ml_e1_dfp ml_e2 ml_e2_cycle ml_ebfg0 ml_ebfr0 ml_ebfr1 ml_ebh0q ml_ebhh0 ml_ebhr0 ml_ebr0i ml_ecr0i ml_edfp0 ml_edfr0 ml_edfr1 ml_edr0i ml_eds ml_eer0i ml_egr0i ml_elf ml_elf_bfgs ml_elf_bhhh ml_elf_cycle ml_elf_dfp ml_elfi ml_elfs ml_enr0i ml_enrr0 ml_erdu0 ml_erdu0_bfgs ml_erdu0_bhhh ml_erdu0_bhhhq ml_erdu0_cycle ml_erdu0_dfp ml_erdu0_nrbfgs ml_exde ml_footnote ml_geqnr ml_grad0 ml_graph ml_hbhhh ml_hd0 ml_hold ml_init ml_inv ml_log ml_max ml_mlout ml_mlout_8 ml_model ml_nb0 ml_opt ml_p ml_plot ml_query ml_rdgrd ml_repor ml_s_e ml_score ml_searc ml_technique ml_unhold mleval mlf_ mlmatbysum mlmatsum mlog mlogi mlogit mlogit_footnote mlogit_p mlopts mlsum mlvecsum mnl0_ mor more mov move mprobit mprobit_lf mprobit_p mrdu0_ mrdu1_ mvdecode mvencode mvreg mvreg_estat n nbreg nbreg_al nbreg_lf nbreg_p nbreg_sw nestreg net newey newey_7 newey_p news nl nl_7 nl_9 nl_9_p nl_p nl_p_7 nlcom nlcom_p nlexp2 nlexp2_7 nlexp2a nlexp2a_7 nlexp3 nlexp3_7 nlgom3 nlgom3_7 nlgom4 nlgom4_7 nlinit nllog3 nllog3_7 nllog4 nllog4_7 nlog_rd nlogit nlogit_p nlogitgen nlogittree nlpred no nobreak noi nois noisi noisil noisily note notes notes_dlg nptrend numlabel numlist odbc old_ver olo olog ologi ologi_sw ologit ologit_p ologitp on one onew onewa oneway op_colnm op_comp op_diff op_inv op_str opr opro oprob oprob_sw oprobi oprobi_p oprobit oprobitp opts_exclusive order orthog orthpoly ou out outf outfi outfil outfile outs outsh outshe outshee outsheet ovtest pac pac_7 palette parse parse_dissim pause pca pca_8 pca_display pca_estat pca_p pca_rotate pcamat pchart pchart_7 pchi pchi_7 pcorr pctile pentium pergram pergram_7 permute permute_8 personal peto_st pkcollapse pkcross pkequiv pkexamine pkexamine_7 pkshape pksumm pksumm_7 pl plo plot plugin pnorm pnorm_7 poisgof poiss_lf poiss_sw poisso_p poisson poisson_estat post postclose postfile postutil pperron pr prais prais_e prais_e2 prais_p predict predictnl preserve print pro prob probi probit probit_estat probit_p proc_time procoverlay procrustes procrustes_estat procrustes_p profiler prog progr progra program prop proportion prtest prtesti pwcorr pwd q\\s qby qbys qchi qchi_7 qladder qladder_7 qnorm qnorm_7 qqplot qqplot_7 qreg qreg_c qreg_p qreg_sw qu quadchk quantile quantile_7 que quer query range ranksum ratio rchart rchart_7 rcof recast reclink recode reg reg3 reg3_p regdw regr regre regre_p2 regres regres_p regress regress_estat regriv_p remap ren rena renam rename renpfix repeat replace report reshape restore ret retu retur return rm rmdir robvar roccomp roccomp_7 roccomp_8 rocf_lf rocfit rocfit_8 rocgold rocplot rocplot_7 roctab roctab_7 rolling rologit rologit_p rot rota rotat rotate rotatemat rreg rreg_p ru run runtest rvfplot rvfplot_7 rvpplot rvpplot_7 sa safesum sample sampsi sav save savedresults saveold sc sca scal scala scalar scatter scm_mine sco scob_lf scob_p scobi_sw scobit scor score scoreplot scoreplot_help scree screeplot screeplot_help sdtest sdtesti se search separate seperate serrbar serrbar_7 serset set set_defaults sfrancia sh she shel shell shewhart shewhart_7 signestimationsample signrank signtest simul simul_7 simulate simulate_8 sktest sleep slogit slogit_d2 slogit_p smooth snapspan so sor sort spearman spikeplot spikeplot_7 spikeplt spline_x split sqreg sqreg_p sret sretu sretur sreturn ssc st st_ct st_hc st_hcd st_hcd_sh st_is st_issys st_note st_promo st_set st_show st_smpl st_subid stack statsby statsby_8 stbase stci stci_7 stcox stcox_estat stcox_fr stcox_fr_ll stcox_p stcox_sw stcoxkm stcoxkm_7 stcstat stcurv stcurve stcurve_7 stdes stem stepwise stereg stfill stgen stir stjoin stmc stmh stphplot stphplot_7 stphtest stphtest_7 stptime strate strate_7 streg streg_sw streset sts sts_7 stset stsplit stsum sttocc sttoct stvary stweib su suest suest_8 sum summ summa summar summari summariz summarize sunflower sureg survcurv survsum svar svar_p svmat svy svy_disp svy_dreg svy_est svy_est_7 svy_estat svy_get svy_gnbreg_p svy_head svy_header svy_heckman_p svy_heckprob_p svy_intreg_p svy_ivreg_p svy_logistic_p svy_logit_p svy_mlogit_p svy_nbreg_p svy_ologit_p svy_oprobit_p svy_poisson_p svy_probit_p svy_regress_p svy_sub svy_sub_7 svy_x svy_x_7 svy_x_p svydes svydes_8 svygen svygnbreg svyheckman svyheckprob svyintreg svyintreg_7 svyintrg svyivreg svylc svylog_p svylogit svymarkout svymarkout_8 svymean svymlog svymlogit svynbreg svyolog svyologit svyoprob svyoprobit svyopts svypois svypois_7 svypoisson svyprobit svyprobt svyprop svyprop_7 svyratio svyreg svyreg_p svyregress svyset svyset_7 svyset_8 svytab svytab_7 svytest svytotal sw sw_8 swcnreg swcox swereg swilk swlogis swlogit swologit swoprbt swpois swprobit swqreg swtobit swweib symmetry symmi symplot symplot_7 syntax sysdescribe sysdir sysuse szroeter ta tab tab1 tab2 tab_or tabd tabdi tabdis tabdisp tabi table tabodds tabodds_7 tabstat tabu tabul tabula tabulat tabulate te tempfile tempname tempvar tes test testnl testparm teststd tetrachoric time_it timer tis tob tobi tobit tobit_p tobit_sw token tokeni tokeniz tokenize tostring total translate translator transmap treat_ll treatr_p treatreg trim trnb_cons trnb_mean trpoiss_d2 trunc_ll truncr_p truncreg tsappend tset tsfill tsline tsline_ex tsreport tsrevar tsrline tsset tssmooth tsunab ttest ttesti tut_chk tut_wait tutorial tw tware_st two twoway twoway__fpfit_serset twoway__function_gen twoway__histogram_gen twoway__ipoint_serset twoway__ipoints_serset twoway__kdensity_gen twoway__lfit_serset twoway__normgen_gen twoway__pci_serset twoway__qfit_serset twoway__scatteri_serset twoway__sunflower_gen twoway_ksm_serset ty typ type typeof u unab unabbrev unabcmd update us use uselabel var var_mkcompanion var_p varbasic varfcast vargranger varirf varirf_add varirf_cgraph varirf_create varirf_ctable varirf_describe varirf_dir varirf_drop varirf_erase varirf_graph varirf_ograph varirf_rename varirf_set varirf_table varlist varlmar varnorm varsoc varstable varstable_w varstable_w2 varwle vce vec vec_fevd vec_mkphi vec_p vec_p_w vecirf_create veclmar veclmar_w vecnorm vecnorm_w vecrank vecstable verinst vers versi versio version view viewsource vif vwls wdatetof webdescribe webseek webuse weib1_lf weib2_lf weib_lf weib_lf0 weibhet_glf weibhet_glf_sh weibhet_glfa weibhet_glfa_sh weibhet_gp weibhet_ilf weibhet_ilf_sh weibhet_ilfa weibhet_ilfa_sh weibhet_ip weibu_sw weibul_p weibull weibull_c weibull_s weibullhet wh whelp whi which whil while wilc_st wilcoxon win wind windo window winexec wntestb wntestb_7 wntestq xchart xchart_7 xcorr xcorr_7 xi xi_6 xmlsav xmlsave xmluse xpose xsh xshe xshel xshell xt_iis xt_tis xtab_p xtabond xtbin_p xtclog xtcloglog xtcloglog_8 xtcloglog_d2 xtcloglog_pa_p xtcloglog_re_p xtcnt_p xtcorr xtdata xtdes xtfront_p xtfrontier xtgee xtgee_elink xtgee_estat xtgee_makeivar xtgee_p xtgee_plink xtgls xtgls_p xthaus xthausman xtht_p xthtaylor xtile xtint_p xtintreg xtintreg_8 xtintreg_d2 xtintreg_p xtivp_1 xtivp_2 xtivreg xtline xtline_ex xtlogit xtlogit_8 xtlogit_d2 xtlogit_fe_p xtlogit_pa_p xtlogit_re_p xtmixed xtmixed_estat xtmixed_p xtnb_fe xtnb_lf xtnbreg xtnbreg_pa_p xtnbreg_refe_p xtpcse xtpcse_p xtpois xtpoisson xtpoisson_d2 xtpoisson_pa_p xtpoisson_refe_p xtpred xtprobit xtprobit_8 xtprobit_d2 xtprobit_re_p xtps_fe xtps_lf xtps_ren xtps_ren_8 xtrar_p xtrc xtrc_p xtrchh xtrefe_p xtreg xtreg_be xtreg_fe xtreg_ml xtreg_pa_p xtreg_re xtregar xtrere_p xtset xtsf_ll xtsf_llti xtsum xttab xttest0 xttobit xttobit_8 xttobit_p xttrans yx yxview__barlike_draw yxview_area_draw yxview_bar_draw yxview_dot_draw yxview_dropline_draw yxview_function_draw yxview_iarrow_draw yxview_ilabels_draw yxview_normal_draw yxview_pcarrow_draw yxview_pcbarrow_draw yxview_pccapsym_draw yxview_pcscatter_draw yxview_pcspike_draw yxview_rarea_draw yxview_rbar_draw yxview_rbarm_draw yxview_rcap_draw yxview_rcapsym_draw yxview_rconnected_draw yxview_rline_draw yxview_rscatter_draw yxview_rspike_draw yxview_spike_draw yxview_sunflower_draw zap_s zinb zinb_llf zinb_plf zip zip_llf zip_p zip_plf zt_ct_5 zt_hc_5 zt_hcd_5 zt_is_5 zt_iss_5 zt_sho_5 zt_smp_5 ztbase_5 ztcox_5 ztdes_5 ztereg_5 ztfill_5 ztgen_5 ztir_5 ztjoin_5 ztnb ztnb_p ztp ztp_p zts_5 ztset_5 ztspli_5 ztsum_5 zttoct_5 ztvary_5 ztweib_5',
        contains: [
      {
        className: 'label',
        variants: [
          {begin: "\\$\\{?[a-zA-Z0-9_]+\\}?"},
          {begin: "`[a-zA-Z0-9_]+'"}

        ]
      },
      {
        className: 'string',
        variants: [
          {begin: '`"[^\r\n]*?"\''},
          {begin: '"[^\r\n"]*"'}
        ]
      },

      {
        className: 'literal',
        variants: [
          {
            begin: '\\b(abs|acos|asin|atan|atan2|atanh|ceil|cloglog|comb|cos|digamma|exp|floor|invcloglog|invlogit|ln|lnfact|lnfactorial|lngamma|log|log10|max|min|mod|reldif|round|sign|sin|sqrt|sum|tan|tanh|trigamma|trunc|betaden|Binomial|binorm|binormal|chi2|chi2tail|dgammapda|dgammapdada|dgammapdadx|dgammapdx|dgammapdxdx|F|Fden|Ftail|gammaden|gammap|ibeta|invbinomial|invchi2|invchi2tail|invF|invFtail|invgammap|invibeta|invnchi2|invnFtail|invnibeta|invnorm|invnormal|invttail|nbetaden|nchi2|nFden|nFtail|nibeta|norm|normal|normalden|normd|npnchi2|tden|ttail|uniform|abbrev|char|index|indexnot|length|lower|ltrim|match|plural|proper|real|regexm|regexr|regexs|reverse|rtrim|string|strlen|strlower|strltrim|strmatch|strofreal|strpos|strproper|strreverse|strrtrim|strtrim|strupper|subinstr|subinword|substr|trim|upper|word|wordcount|_caller|autocode|byteorder|chop|clip|cond|e|epsdouble|epsfloat|group|inlist|inrange|irecode|matrix|maxbyte|maxdouble|maxfloat|maxint|maxlong|mi|minbyte|mindouble|minfloat|minint|minlong|missing|r|recode|replay|return|s|scalar|d|date|day|dow|doy|halfyear|mdy|month|quarter|week|year|d|daily|dofd|dofh|dofm|dofq|dofw|dofy|h|halfyearly|hofd|m|mofd|monthly|q|qofd|quarterly|tin|twithin|w|weekly|wofd|y|yearly|yh|ym|yofd|yq|yw|cholesky|colnumb|colsof|corr|det|diag|diag0cnt|el|get|hadamard|I|inv|invsym|issym|issymmetric|J|matmissing|matuniform|mreldif|nullmat|rownumb|rowsof|sweep|syminv|trace|vec|vecdiag)(?=\\(|$)'
          }
        ]
      },

      hljs.COMMENT('^[ \t]*\\*.*$', false),
      hljs.C_LINE_COMMENT_MODE,
      hljs.C_BLOCK_COMMENT_MODE
    ]
  };
});

hljs.registerLanguage('step21', function(hljs) {
  var STEP21_IDENT_RE = '[A-Z_][A-Z0-9_.]*';
  var STEP21_CLOSE_RE = 'END-ISO-10303-21;';
  var STEP21_KEYWORDS = {
    literal: '',
    built_in: '',
    keyword:
    'HEADER ENDSEC DATA'
  };
  var STEP21_START = {
    className: 'preprocessor',
    begin: 'ISO-10303-21;',
    relevance: 10
  };
  var STEP21_CODE = [
    hljs.C_LINE_COMMENT_MODE,
    hljs.C_BLOCK_COMMENT_MODE,
    hljs.COMMENT('/\\*\\*!', '\\*/'),
    hljs.C_NUMBER_MODE,
    hljs.inherit(hljs.APOS_STRING_MODE, {illegal: null}),
    hljs.inherit(hljs.QUOTE_STRING_MODE, {illegal: null}),
    {
      className: 'string',
      begin: "'", end: "'"
    },
    {
      className: 'label',
      variants: [
        {
          begin: '#', end: '\\d+',
          illegal: '\\W'
        }
      ]
    }
  ];

  return {
    aliases: ['p21', 'step', 'stp'],
    case_insensitive: true, // STEP 21 is case insensitive in theory, in practice all non-comments are capitalized.
    lexemes: STEP21_IDENT_RE,
    keywords: STEP21_KEYWORDS,
    contains: [
      {
        className: 'preprocessor',
        begin: STEP21_CLOSE_RE,
        relevance: 10
      },
      STEP21_START
    ].concat(STEP21_CODE)
  };
});

hljs.registerLanguage('stylus', function(hljs) {

  var VARIABLE = {
    className: 'variable',
    begin: '\\$' + hljs.IDENT_RE
  };

  var HEX_COLOR = {
    className: 'hexcolor',
    begin: '#([a-fA-F0-9]{6}|[a-fA-F0-9]{3})',
    relevance: 10
  };

  var AT_KEYWORDS = [
    'charset',
    'css',
    'debug',
    'extend',
    'font-face',
    'for',
    'import',
    'include',
    'media',
    'mixin',
    'page',
    'warn',
    'while'
  ];

  var PSEUDO_SELECTORS = [
    'after',
    'before',
    'first-letter',
    'first-line',
    'active',
    'first-child',
    'focus',
    'hover',
    'lang',
    'link',
    'visited'
  ];

  var TAGS = [
    'a',
    'abbr',
    'address',
    'article',
    'aside',
    'audio',
    'b',
    'blockquote',
    'body',
    'button',
    'canvas',
    'caption',
    'cite',
    'code',
    'dd',
    'del',
    'details',
    'dfn',
    'div',
    'dl',
    'dt',
    'em',
    'fieldset',
    'figcaption',
    'figure',
    'footer',
    'form',
    'h1',
    'h2',
    'h3',
    'h4',
    'h5',
    'h6',
    'header',
    'hgroup',
    'html',
    'i',
    'iframe',
    'img',
    'input',
    'ins',
    'kbd',
    'label',
    'legend',
    'li',
    'mark',
    'menu',
    'nav',
    'object',
    'ol',
    'p',
    'q',
    'quote',
    'samp',
    'section',
    'span',
    'strong',
    'summary',
    'sup',
    'table',
    'tbody',
    'td',
    'textarea',
    'tfoot',
    'th',
    'thead',
    'time',
    'tr',
    'ul',
    'var',
    'video'
  ];

  var TAG_END = '[\\.\\s\\n\\[\\:,]';

  var ATTRIBUTES = [
    'align-content',
    'align-items',
    'align-self',
    'animation',
    'animation-delay',
    'animation-direction',
    'animation-duration',
    'animation-fill-mode',
    'animation-iteration-count',
    'animation-name',
    'animation-play-state',
    'animation-timing-function',
    'auto',
    'backface-visibility',
    'background',
    'background-attachment',
    'background-clip',
    'background-color',
    'background-image',
    'background-origin',
    'background-position',
    'background-repeat',
    'background-size',
    'border',
    'border-bottom',
    'border-bottom-color',
    'border-bottom-left-radius',
    'border-bottom-right-radius',
    'border-bottom-style',
    'border-bottom-width',
    'border-collapse',
    'border-color',
    'border-image',
    'border-image-outset',
    'border-image-repeat',
    'border-image-slice',
    'border-image-source',
    'border-image-width',
    'border-left',
    'border-left-color',
    'border-left-style',
    'border-left-width',
    'border-radius',
    'border-right',
    'border-right-color',
    'border-right-style',
    'border-right-width',
    'border-spacing',
    'border-style',
    'border-top',
    'border-top-color',
    'border-top-left-radius',
    'border-top-right-radius',
    'border-top-style',
    'border-top-width',
    'border-width',
    'bottom',
    'box-decoration-break',
    'box-shadow',
    'box-sizing',
    'break-after',
    'break-before',
    'break-inside',
    'caption-side',
    'clear',
    'clip',
    'clip-path',
    'color',
    'column-count',
    'column-fill',
    'column-gap',
    'column-rule',
    'column-rule-color',
    'column-rule-style',
    'column-rule-width',
    'column-span',
    'column-width',
    'columns',
    'content',
    'counter-increment',
    'counter-reset',
    'cursor',
    'direction',
    'display',
    'empty-cells',
    'filter',
    'flex',
    'flex-basis',
    'flex-direction',
    'flex-flow',
    'flex-grow',
    'flex-shrink',
    'flex-wrap',
    'float',
    'font',
    'font-family',
    'font-feature-settings',
    'font-kerning',
    'font-language-override',
    'font-size',
    'font-size-adjust',
    'font-stretch',
    'font-style',
    'font-variant',
    'font-variant-ligatures',
    'font-weight',
    'height',
    'hyphens',
    'icon',
    'image-orientation',
    'image-rendering',
    'image-resolution',
    'ime-mode',
    'inherit',
    'initial',
    'justify-content',
    'left',
    'letter-spacing',
    'line-height',
    'list-style',
    'list-style-image',
    'list-style-position',
    'list-style-type',
    'margin',
    'margin-bottom',
    'margin-left',
    'margin-right',
    'margin-top',
    'marks',
    'mask',
    'max-height',
    'max-width',
    'min-height',
    'min-width',
    'nav-down',
    'nav-index',
    'nav-left',
    'nav-right',
    'nav-up',
    'none',
    'normal',
    'object-fit',
    'object-position',
    'opacity',
    'order',
    'orphans',
    'outline',
    'outline-color',
    'outline-offset',
    'outline-style',
    'outline-width',
    'overflow',
    'overflow-wrap',
    'overflow-x',
    'overflow-y',
    'padding',
    'padding-bottom',
    'padding-left',
    'padding-right',
    'padding-top',
    'page-break-after',
    'page-break-before',
    'page-break-inside',
    'perspective',
    'perspective-origin',
    'pointer-events',
    'position',
    'quotes',
    'resize',
    'right',
    'tab-size',
    'table-layout',
    'text-align',
    'text-align-last',
    'text-decoration',
    'text-decoration-color',
    'text-decoration-line',
    'text-decoration-style',
    'text-indent',
    'text-overflow',
    'text-rendering',
    'text-shadow',
    'text-transform',
    'text-underline-position',
    'top',
    'transform',
    'transform-origin',
    'transform-style',
    'transition',
    'transition-delay',
    'transition-duration',
    'transition-property',
    'transition-timing-function',
    'unicode-bidi',
    'vertical-align',
    'visibility',
    'white-space',
    'widows',
    'width',
    'word-break',
    'word-spacing',
    'word-wrap',
    'z-index'
  ];

  // illegals
  var ILLEGAL = [
    '\\{',
    '\\}',
    '\\?',
    '(\\bReturn\\b)', // monkey
    '(\\bEnd\\b)', // monkey
    '(\\bend\\b)', // vbscript
    ';', // sql
    '#\\s', // markdown
    '\\*\\s', // markdown
    '===\\s', // markdown
    '\\|',
    '%', // prolog
  ];

  return {
    aliases: ['styl'],
    case_insensitive: false,
    illegal: '(' + ILLEGAL.join('|') + ')',
    keywords: 'if else for in',
    contains: [

      // strings
      hljs.QUOTE_STRING_MODE,
      hljs.APOS_STRING_MODE,

      // comments
      hljs.C_LINE_COMMENT_MODE,
      hljs.C_BLOCK_COMMENT_MODE,

      // hex colors
      HEX_COLOR,

      // class tag
      {
        begin: '\\.[a-zA-Z][a-zA-Z0-9_-]*' + TAG_END,
        returnBegin: true,
        contains: [
          {className: 'class', begin: '\\.[a-zA-Z][a-zA-Z0-9_-]*'}
        ]
      },

      // id tag
      {
        begin: '\\#[a-zA-Z][a-zA-Z0-9_-]*' + TAG_END,
        returnBegin: true,
        contains: [
          {className: 'id', begin: '\\#[a-zA-Z][a-zA-Z0-9_-]*'}
        ]
      },

      // tags
      {
        begin: '\\b(' + TAGS.join('|') + ')' + TAG_END,
        returnBegin: true,
        contains: [
          {className: 'tag', begin: '\\b[a-zA-Z][a-zA-Z0-9_-]*'}
        ]
      },

      // psuedo selectors
      {
        className: 'pseudo',
        begin: '&?:?:\\b(' + PSEUDO_SELECTORS.join('|') + ')' + TAG_END
      },

      // @ keywords
      {
        className: 'at_rule',
        begin: '\@(' + AT_KEYWORDS.join('|') + ')\\b'
      },

      // variables
      VARIABLE,

      // dimension
      hljs.CSS_NUMBER_MODE,

      // number
      hljs.NUMBER_MODE,

      // functions
      //  - only from beginning of line + whitespace
      {
        className: 'function',
        begin: '\\b[a-zA-Z][a-zA-Z0-9_\-]*\\(.*\\)',
        illegal: '[\\n]',
        returnBegin: true,
        contains: [
          {className: 'title', begin: '\\b[a-zA-Z][a-zA-Z0-9_\-]*'},
          {
            className: 'params',
            begin: /\(/,
            end: /\)/,
            contains: [
              HEX_COLOR,
              VARIABLE,
              hljs.APOS_STRING_MODE,
              hljs.CSS_NUMBER_MODE,
              hljs.NUMBER_MODE,
              hljs.QUOTE_STRING_MODE
            ]
          }
        ]
      },

      // attributes
      //  - only from beginning of line + whitespace
      //  - must have whitespace after it
      {
        className: 'attribute',
        begin: '\\b(' + ATTRIBUTES.reverse().join('|') + ')\\b'
      }
    ]
  };
});

hljs.registerLanguage('swift', function(hljs) {
  var SWIFT_KEYWORDS = {
      keyword: '__COLUMN__ __FILE__ __FUNCTION__ __LINE__ as as! as? associativity ' +
        'break case catch class continue convenience default defer deinit didSet do ' +
        'dynamic dynamicType else enum extension fallthrough false final for func ' +
        'get guard if import in indirect infix init inout internal is lazy left let ' +
        'mutating nil none nonmutating operator optional override postfix precedence ' +
        'prefix private protocol Protocol public repeat required rethrows return ' +
        'right self Self set static struct subscript super switch throw throws true ' +
        'try try! try? Type typealias unowned var weak where while willSet',
      literal: 'true false nil',
      built_in: 'abs advance alignof alignofValue anyGenerator assert assertionFailure ' +
        'bridgeFromObjectiveC bridgeFromObjectiveCUnconditional bridgeToObjectiveC ' +
        'bridgeToObjectiveCUnconditional c contains count countElements countLeadingZeros ' +
        'debugPrint debugPrintln distance dropFirst dropLast dump encodeBitsAsWords ' +
        'enumerate equal fatalError filter find getBridgedObjectiveCType getVaList ' +
        'indices insertionSort isBridgedToObjectiveC isBridgedVerbatimToObjectiveC ' +
        'isUniquelyReferenced isUniquelyReferencedNonObjC join lazy lexicographicalCompare ' +
        'map max maxElement min minElement numericCast overlaps partition posix ' +
        'precondition preconditionFailure print println quickSort readLine reduce reflect ' +
        'reinterpretCast reverse roundUpToAlignment sizeof sizeofValue sort split ' +
        'startsWith stride strideof strideofValue swap toString transcode ' +
        'underestimateCount unsafeAddressOf unsafeBitCast unsafeDowncast unsafeUnwrap ' +
        'unsafeReflect withExtendedLifetime withObjectAtPlusZero withUnsafePointer ' +
        'withUnsafePointerToObject withUnsafeMutablePointer withUnsafeMutablePointers ' +
        'withUnsafePointer withUnsafePointers withVaList zip'
    };

  var TYPE = {
    className: 'type',
    begin: '\\b[A-Z][\\w\']*',
    relevance: 0
  };
  var BLOCK_COMMENT = hljs.COMMENT(
    '/\\*',
    '\\*/',
    {
      contains: ['self']
    }
  );
  var SUBST = {
    className: 'subst',
    begin: /\\\(/, end: '\\)',
    keywords: SWIFT_KEYWORDS,
    contains: [] // assigned later
  };
  var NUMBERS = {
      className: 'number',
      begin: '\\b([\\d_]+(\\.[\\deE_]+)?|0x[a-fA-F0-9_]+(\\.[a-fA-F0-9p_]+)?|0b[01_]+|0o[0-7_]+)\\b',
      relevance: 0
  };
  var QUOTE_STRING_MODE = hljs.inherit(hljs.QUOTE_STRING_MODE, {
    contains: [SUBST, hljs.BACKSLASH_ESCAPE]
  });
  SUBST.contains = [NUMBERS];

  return {
    keywords: SWIFT_KEYWORDS,
    contains: [
      QUOTE_STRING_MODE,
      hljs.C_LINE_COMMENT_MODE,
      BLOCK_COMMENT,
      TYPE,
      NUMBERS,
      {
        className: 'func',
        beginKeywords: 'func', end: '{', excludeEnd: true,
        contains: [
          hljs.inherit(hljs.TITLE_MODE, {
            begin: /[A-Za-z$_][0-9A-Za-z$_]*/,
            illegal: /\(/
          }),
          {
            className: 'generics',
            begin: /</, end: />/,
            illegal: />/
          },
          {
            className: 'params',
            begin: /\(/, end: /\)/, endsParent: true,
            keywords: SWIFT_KEYWORDS,
            contains: [
              'self',
              NUMBERS,
              QUOTE_STRING_MODE,
              hljs.C_BLOCK_COMMENT_MODE,
              {begin: ':'} // relevance booster
            ],
            illegal: /["']/
          }
        ],
        illegal: /\[|%/
      },
      {
        className: 'class',
        beginKeywords: 'struct protocol class extension enum',
        keywords: SWIFT_KEYWORDS,
        end: '\\{',
        excludeEnd: true,
        contains: [
          hljs.inherit(hljs.TITLE_MODE, {begin: /[A-Za-z$_][0-9A-Za-z$_]*/})
        ]
      },
      {
        className: 'preprocessor', // @attributes
        begin: '(@warn_unused_result|@exported|@lazy|@noescape|' +
                  '@NSCopying|@NSManaged|@objc|@convention|@required|' +
                  '@noreturn|@IBAction|@IBDesignable|@IBInspectable|@IBOutlet|' +
                  '@infix|@prefix|@postfix|@autoclosure|@testable|@available|' +
                  '@nonobjc|@NSApplicationMain|@UIApplicationMain)'

      },
      {
        beginKeywords: 'import', end: /$/,
        contains: [hljs.C_LINE_COMMENT_MODE, BLOCK_COMMENT]
      }
    ]
  };
});

hljs.registerLanguage('tcl', function(hljs) {
  return {
    aliases: ['tk'],
    keywords: 'after append apply array auto_execok auto_import auto_load auto_mkindex ' +
      'auto_mkindex_old auto_qualify auto_reset bgerror binary break catch cd chan clock ' +
      'close concat continue dde dict encoding eof error eval exec exit expr fblocked ' +
      'fconfigure fcopy file fileevent filename flush for foreach format gets glob global ' +
      'history http if incr info interp join lappend|10 lassign|10 lindex|10 linsert|10 list ' +
      'llength|10 load lrange|10 lrepeat|10 lreplace|10 lreverse|10 lsearch|10 lset|10 lsort|10 '+
      'mathfunc mathop memory msgcat namespace open package parray pid pkg::create pkg_mkIndex '+
      'platform platform::shell proc puts pwd read refchan regexp registry regsub|10 rename '+
      'return safe scan seek set socket source split string subst switch tcl_endOfWord '+
      'tcl_findLibrary tcl_startOfNextWord tcl_startOfPreviousWord tcl_wordBreakAfter '+
      'tcl_wordBreakBefore tcltest tclvars tell time tm trace unknown unload unset update '+
      'uplevel upvar variable vwait while',
    contains: [
      hljs.COMMENT(';[ \\t]*#', '$'),
      hljs.COMMENT('^[ \\t]*#', '$'),
      {
        beginKeywords: 'proc',
        end: '[\\{]',
        excludeEnd: true,
        contains: [
          {
            className: 'symbol',
            begin: '[ \\t\\n\\r]+(::)?[a-zA-Z_]((::)?[a-zA-Z0-9_])*',
            end: '[ \\t\\n\\r]',
            endsWithParent: true,
            excludeEnd: true
          }
        ]
      },
      {
        className: 'variable',
        excludeEnd: true,
        variants: [
          {
            begin: '\\$(\\{)?(::)?[a-zA-Z_]((::)?[a-zA-Z0-9_])*\\(([a-zA-Z0-9_])*\\)',
            end: '[^a-zA-Z0-9_\\}\\$]'
          },
          {
            begin: '\\$(\\{)?(::)?[a-zA-Z_]((::)?[a-zA-Z0-9_])*',
            end: '(\\))?[^a-zA-Z0-9_\\}\\$]'
          }
        ]
      },
      {
        className: 'string',
        contains: [hljs.BACKSLASH_ESCAPE],
        variants: [
          hljs.inherit(hljs.APOS_STRING_MODE, {illegal: null}),
          hljs.inherit(hljs.QUOTE_STRING_MODE, {illegal: null})
        ]
      },
      {
        className: 'number',
        variants: [hljs.BINARY_NUMBER_MODE, hljs.C_NUMBER_MODE]
      }
    ]
  }
});

hljs.registerLanguage('tex', function(hljs) {
  var COMMAND1 = {
    className: 'command',
    begin: '\\\\[a-zA-Zа-яА-я]+[\\*]?'
  };
  var COMMAND2 = {
    className: 'command',
    begin: '\\\\[^a-zA-Zа-яА-я0-9]'
  };
  var SPECIAL = {
    className: 'special',
    begin: '[{}\\[\\]\\&#~]',
    relevance: 0
  };

  return {
    contains: [
      { // parameter
        begin: '\\\\[a-zA-Zа-яА-я]+[\\*]? *= *-?\\d*\\.?\\d+(pt|pc|mm|cm|in|dd|cc|ex|em)?',
        returnBegin: true,
        contains: [
          COMMAND1, COMMAND2,
          {
            className: 'number',
            begin: ' *=', end: '-?\\d*\\.?\\d+(pt|pc|mm|cm|in|dd|cc|ex|em)?',
            excludeBegin: true
          }
        ],
        relevance: 10
      },
      COMMAND1, COMMAND2,
      SPECIAL,
      {
        className: 'formula',
        begin: '\\$\\$', end: '\\$\\$',
        contains: [COMMAND1, COMMAND2, SPECIAL],
        relevance: 0
      },
      {
        className: 'formula',
        begin: '\\$', end: '\\$',
        contains: [COMMAND1, COMMAND2, SPECIAL],
        relevance: 0
      },
      hljs.COMMENT(
        '%',
        '$',
        {
          relevance: 0
        }
      )
    ]
  };
});

hljs.registerLanguage('thrift', function(hljs) {
  var BUILT_IN_TYPES = 'bool byte i16 i32 i64 double string binary';
  return {
    keywords: {
      keyword:
        'namespace const typedef struct enum service exception void oneway set list map required optional',
      built_in:
        BUILT_IN_TYPES,
      literal:
        'true false'
    },
    contains: [
      hljs.QUOTE_STRING_MODE,
      hljs.NUMBER_MODE,
      hljs.C_LINE_COMMENT_MODE,
      hljs.C_BLOCK_COMMENT_MODE,
      {
        className: 'class',
        beginKeywords: 'struct enum service exception', end: /\{/,
        illegal: /\n/,
        contains: [
          hljs.inherit(hljs.TITLE_MODE, {
            starts: {endsWithParent: true, excludeEnd: true} // hack: eating everything after the first title
          })
        ]
      },
      {
        begin: '\\b(set|list|map)\\s*<', end: '>',
        keywords: BUILT_IN_TYPES,
        contains: ['self']
      }
    ]
  };
});

hljs.registerLanguage('tp', function(hljs) {
  var TPID = {
    className: 'number',
    begin: '[1-9][0-9]*', /* no leading zeros */
    relevance: 0
  };
  var TPLABEL = {
    className: 'comment',
    begin: ':[^\\]]+'
  };
  var TPDATA = {
    className: 'built_in',
    begin: '(AR|P|PAYLOAD|PR|R|SR|RSR|LBL|VR|UALM|MESSAGE|UTOOL|UFRAME|TIMER|\
    TIMER_OVERFLOW|JOINT_MAX_SPEED|RESUME_PROG|DIAG_REC)\\[', end: '\\]',
    contains: [
      'self',
      TPID,
      TPLABEL
    ]
  };
  var TPIO = {
    className: 'built_in',
    begin: '(AI|AO|DI|DO|F|RI|RO|UI|UO|GI|GO|SI|SO)\\[', end: '\\]',
    contains: [
      'self',
      TPID,
      hljs.QUOTE_STRING_MODE, /* for pos section at bottom */
      TPLABEL
    ]
  };

  return {
    keywords: {
      keyword:
        'ABORT ACC ADJUST AND AP_LD BREAK CALL CNT COL CONDITION CONFIG DA DB ' +
        'DIV DETECT ELSE END ENDFOR ERR_NUM ERROR_PROG FINE FOR GP GUARD INC ' +
        'IF JMP LINEAR_MAX_SPEED LOCK MOD MONITOR OFFSET Offset OR OVERRIDE ' +
        'PAUSE PREG PTH RT_LD RUN SELECT SKIP Skip TA TB TO TOOL_OFFSET ' +
        'Tool_Offset UF UT UFRAME_NUM UTOOL_NUM UNLOCK WAIT X Y Z W P R STRLEN ' +
        'SUBSTR FINDSTR VOFFSET',
      constant:
        'ON OFF max_speed LPOS JPOS ENABLE DISABLE START STOP RESET'
    },
    contains: [
      TPDATA,
      TPIO,
      {
        className: 'keyword',
        begin: '/(PROG|ATTR|MN|POS|END)\\b'
      },
      {
        /* this is for cases like ,CALL */
        className: 'keyword',
        begin: '(CALL|RUN|POINT_LOGIC|LBL)\\b'
      },
      {
        /* this is for cases like CNT100 where the default lexemes do not
         * separate the keyword and the number */
        className: 'keyword',
        begin: '\\b(ACC|CNT|Skip|Offset|PSPD|RT_LD|AP_LD|Tool_Offset)'
      },
      {
        /* to catch numbers that do not have a word boundary on the left */
        className: 'number',
        begin: '\\d+(sec|msec|mm/sec|cm/min|inch/min|deg/sec|mm|in|cm)?\\b',
        relevance: 0
      },
      hljs.COMMENT('//', '[;$]'),
      hljs.COMMENT('!', '[;$]'),
      hljs.COMMENT('--eg:', '$'),
      hljs.QUOTE_STRING_MODE,
      {
        className: 'string',
        begin: '\'', end: '\''
      },
      hljs.C_NUMBER_MODE,
      {
        className: 'variable',
        begin: '\\$[A-Za-z0-9_]+'
      }
    ]
  };
});

hljs.registerLanguage('twig', function(hljs) {
  var PARAMS = {
    className: 'params',
    begin: '\\(', end: '\\)'
  };

  var FUNCTION_NAMES = 'attribute block constant cycle date dump include ' +
                  'max min parent random range source template_from_string';

  var FUNCTIONS = {
    className: 'function',
    beginKeywords: FUNCTION_NAMES,
    relevance: 0,
    contains: [
      PARAMS
    ]
  };

  var FILTER = {
    className: 'filter',
    begin: /\|[A-Za-z_]+:?/,
    keywords:
      'abs batch capitalize convert_encoding date date_modify default ' +
      'escape first format join json_encode keys last length lower ' +
      'merge nl2br number_format raw replace reverse round slice sort split ' +
      'striptags title trim upper url_encode',
    contains: [
      FUNCTIONS
    ]
  };

  var TAGS = 'autoescape block do embed extends filter flush for ' +
    'if import include macro sandbox set spaceless use verbatim';

  TAGS = TAGS + ' ' + TAGS.split(' ').map(function(t){return 'end' + t}).join(' ');

  return {
    aliases: ['craftcms'],
    case_insensitive: true,
    subLanguage: 'xml',
    contains: [
      hljs.COMMENT(/\{#/, /#}/),
      {
        className: 'template_tag',
        begin: /\{%/, end: /%}/,
        keywords: TAGS,
        contains: [FILTER, FUNCTIONS]
      },
      {
        className: 'variable',
        begin: /\{\{/, end: /}}/,
        contains: [FILTER, FUNCTIONS]
      }
    ]
  };
});

hljs.registerLanguage('typescript', function(hljs) {
  var KEYWORDS = {
    keyword:
      'in if for while finally var new function|0 do return void else break catch ' +
      'instanceof with throw case default try this switch continue typeof delete ' +
      'let yield const class public private protected get set super ' +
      'static implements enum export import declare type namespace abstract',
    literal:
      'true false null undefined NaN Infinity',
    built_in:
      'eval isFinite isNaN parseFloat parseInt decodeURI decodeURIComponent ' +
      'encodeURI encodeURIComponent escape unescape Object Function Boolean Error ' +
      'EvalError InternalError RangeError ReferenceError StopIteration SyntaxError ' +
      'TypeError URIError Number Math Date String RegExp Array Float32Array ' +
      'Float64Array Int16Array Int32Array Int8Array Uint16Array Uint32Array ' +
      'Uint8Array Uint8ClampedArray ArrayBuffer DataView JSON Intl arguments require ' +
      'module console window document any number boolean string void'
  };

  return {
    aliases: ['ts'],
    keywords: KEYWORDS,
    contains: [
      {
        className: 'pi',
        begin: /^\s*['"]use strict['"]/,
        relevance: 0
      },
      hljs.APOS_STRING_MODE,
      hljs.QUOTE_STRING_MODE,
      hljs.C_LINE_COMMENT_MODE,
      hljs.C_BLOCK_COMMENT_MODE,
      {
        className: 'number',
        variants: [
          { begin: '\\b(0[bB][01]+)' },
          { begin: '\\b(0[oO][0-7]+)' },
          { begin: hljs.C_NUMBER_RE }
        ],
        relevance: 0
      },
      { // "value" container
        begin: '(' + hljs.RE_STARTERS_RE + '|\\b(case|return|throw)\\b)\\s*',
        keywords: 'return throw case',
        contains: [
          hljs.C_LINE_COMMENT_MODE,
          hljs.C_BLOCK_COMMENT_MODE,
          hljs.REGEXP_MODE
        ],
        relevance: 0
      },
      {
        className: 'function',
        begin: 'function', end: /[\{;]/, excludeEnd: true,
        keywords: KEYWORDS,
        contains: [
          'self',
          hljs.inherit(hljs.TITLE_MODE, {begin: /[A-Za-z$_][0-9A-Za-z$_]*/}),
          {
            className: 'params',
            begin: /\(/, end: /\)/,
            excludeBegin: true,
            excludeEnd: true,
            keywords: KEYWORDS,
            contains: [
              hljs.C_LINE_COMMENT_MODE,
              hljs.C_BLOCK_COMMENT_MODE
            ],
            illegal: /["'\(]/
          }
        ],
        illegal: /\[|%/,
        relevance: 0 // () => {} is more typical in TypeScript
      },
      {
        className: 'constructor',
        beginKeywords: 'constructor', end: /\{/, excludeEnd: true,
        relevance: 10
      },
      {
        className: 'module',
        beginKeywords: 'module', end: /\{/, excludeEnd: true
      },
      {
        className: 'interface',
        beginKeywords: 'interface', end: /\{/, excludeEnd: true,
        keywords: 'interface extends'
      },
      {
        begin: /\$[(.]/ // relevance booster for a pattern common to JS libs: `$(something)` and `$.something`
      },
      {
        begin: '\\.' + hljs.IDENT_RE, relevance: 0 // hack: prevents detection of keywords after dots
      }
    ]
  };
});

hljs.registerLanguage('vala', function(hljs) {
  return {
    keywords: {
      keyword:
        // Value types
        'char uchar unichar int uint long ulong short ushort int8 int16 int32 int64 uint8 ' +
        'uint16 uint32 uint64 float double bool struct enum string void ' +
        // Reference types
        'weak unowned owned ' +
        // Modifiers
        'async signal static abstract interface override ' +
        // Control Structures
        'while do for foreach else switch case break default return try catch ' +
        // Visibility
        'public private protected internal ' +
        // Other
        'using new this get set const stdout stdin stderr var',
      built_in:
        'DBus GLib CCode Gee Object',
      literal:
        'false true null'
    },
    contains: [
      {
        className: 'class',
        beginKeywords: 'class interface delegate namespace', end: '{', excludeEnd: true,
        illegal: '[^,:\\n\\s\\.]',
        contains: [
          hljs.UNDERSCORE_TITLE_MODE
        ]
      },
      hljs.C_LINE_COMMENT_MODE,
      hljs.C_BLOCK_COMMENT_MODE,
      {
        className: 'string',
        begin: '"""', end: '"""',
        relevance: 5
      },
      hljs.APOS_STRING_MODE,
      hljs.QUOTE_STRING_MODE,
      hljs.C_NUMBER_MODE,
      {
        className: 'preprocessor',
        begin: '^#', end: '$',
        relevance: 2
      },
      {
        className: 'constant',
        begin: ' [A-Z_]+ ',
        relevance: 0
      }
    ]
  };
});

hljs.registerLanguage('vbnet', function(hljs) {
  return {
    aliases: ['vb'],
    case_insensitive: true,
    keywords: {
      keyword:
        'addhandler addressof alias and andalso aggregate ansi as assembly auto binary by byref byval ' + /* a-b */
        'call case catch class compare const continue custom declare default delegate dim distinct do ' + /* c-d */
        'each equals else elseif end enum erase error event exit explicit finally for friend from function ' + /* e-f */
        'get global goto group handles if implements imports in inherits interface into is isfalse isnot istrue ' + /* g-i */
        'join key let lib like loop me mid mod module mustinherit mustoverride mybase myclass ' + /* j-m */
        'namespace narrowing new next not notinheritable notoverridable ' + /* n */
        'of off on operator option optional or order orelse overloads overridable overrides ' + /* o */
        'paramarray partial preserve private property protected public ' + /* p */
        'raiseevent readonly redim rem removehandler resume return ' + /* r */
        'select set shadows shared skip static step stop structure strict sub synclock ' + /* s */
        'take text then throw to try unicode until using when where while widening with withevents writeonly xor', /* t-x */
      built_in:
        'boolean byte cbool cbyte cchar cdate cdec cdbl char cint clng cobj csbyte cshort csng cstr ctype ' +  /* b-c */
        'date decimal directcast double gettype getxmlnamespace iif integer long object ' + /* d-o */
        'sbyte short single string trycast typeof uinteger ulong ushort', /* s-u */
      literal:
        'true false nothing'
    },
    illegal: '//|{|}|endif|gosub|variant|wend', /* reserved deprecated keywords */
    contains: [
      hljs.inherit(hljs.QUOTE_STRING_MODE, {contains: [{begin: '""'}]}),
      hljs.COMMENT(
        '\'',
        '$',
        {
          returnBegin: true,
          contains: [
            {
              className: 'xmlDocTag',
              begin: '\'\'\'|<!--|-->',
              contains: [hljs.PHRASAL_WORDS_MODE]
            },
            {
              className: 'xmlDocTag',
              begin: '</?', end: '>',
              contains: [hljs.PHRASAL_WORDS_MODE]
            }
          ]
        }
      ),
      hljs.C_NUMBER_MODE,
      {
        className: 'preprocessor',
        begin: '#', end: '$',
        keywords: 'if else elseif end region externalsource'
      }
    ]
  };
});

hljs.registerLanguage('vbscript', function(hljs) {
  return {
    aliases: ['vbs'],
    case_insensitive: true,
    keywords: {
      keyword:
        'call class const dim do loop erase execute executeglobal exit for each next function ' +
        'if then else on error option explicit new private property let get public randomize ' +
        'redim rem select case set stop sub while wend with end to elseif is or xor and not ' +
        'class_initialize class_terminate default preserve in me byval byref step resume goto',
      built_in:
        'lcase month vartype instrrev ubound setlocale getobject rgb getref string ' +
        'weekdayname rnd dateadd monthname now day minute isarray cbool round formatcurrency ' +
        'conversions csng timevalue second year space abs clng timeserial fixs len asc ' +
        'isempty maths dateserial atn timer isobject filter weekday datevalue ccur isdate ' +
        'instr datediff formatdatetime replace isnull right sgn array snumeric log cdbl hex ' +
        'chr lbound msgbox ucase getlocale cos cdate cbyte rtrim join hour oct typename trim ' +
        'strcomp int createobject loadpicture tan formatnumber mid scriptenginebuildversion ' +
        'scriptengine split scriptengineminorversion cint sin datepart ltrim sqr ' +
        'scriptenginemajorversion time derived eval date formatpercent exp inputbox left ascw ' +
        'chrw regexp server response request cstr err',
      literal:
        'true false null nothing empty'
    },
    illegal: '//',
    contains: [
      hljs.inherit(hljs.QUOTE_STRING_MODE, {contains: [{begin: '""'}]}),
      hljs.COMMENT(
        /'/,
        /$/,
        {
          relevance: 0
        }
      ),
      hljs.C_NUMBER_MODE
    ]
  };
});

hljs.registerLanguage('vbscript-html', function(hljs) {
  return {
    subLanguage: 'xml',
    contains: [
      {
        begin: '<%', end: '%>',
        subLanguage: 'vbscript'
      }
    ]
  };
});

hljs.registerLanguage('verilog', function(hljs) {
  return {
    aliases: ['v'],
    case_insensitive: true,
    keywords: {
      keyword:
        'always and assign begin buf bufif0 bufif1 case casex casez cmos deassign ' +
        'default defparam disable edge else end endcase endfunction endmodule ' +
        'endprimitive endspecify endtable endtask event for force forever fork ' +
        'function if ifnone initial inout input join macromodule module nand ' +
        'negedge nmos nor not notif0 notif1 or output parameter pmos posedge ' +
        'primitive pulldown pullup rcmos release repeat rnmos rpmos rtran ' +
        'rtranif0 rtranif1 specify specparam table task timescale tran ' +
        'tranif0 tranif1 wait while xnor xor',
      typename:
        'highz0 highz1 integer large medium pull0 pull1 real realtime reg ' +
        'scalared signed small strong0 strong1 supply0 supply0 supply1 supply1 ' +
        'time tri tri0 tri1 triand trior trireg vectored wand weak0 weak1 wire wor'
    },
    contains: [
      hljs.C_BLOCK_COMMENT_MODE,
      hljs.C_LINE_COMMENT_MODE,
      hljs.QUOTE_STRING_MODE,
      {
        className: 'number',
        begin: '\\b(\\d+\'(b|h|o|d|B|H|O|D))?[0-9xzXZ]+',
        contains: [hljs.BACKSLASH_ESCAPE],
        relevance: 0
      },
      /* ports in instances */
      {
        className: 'typename',
        begin: '\\.\\w+',
        relevance: 0
      },
      /* parameters to instances */
      {
        className: 'value',
        begin: '#\\((?!parameter).+\\)'
      },
      /* operators */
      {
        className: 'keyword',
        begin: '\\+|-|\\*|/|%|<|>|=|#|`|\\!|&|\\||@|:|\\^|~|\\{|\\}',
        relevance: 0
      }
    ]
  }; // return
});

hljs.registerLanguage('vhdl', function(hljs) {
  // Regular expression for VHDL numeric literals.

  // Decimal literal:
  var INTEGER_RE = '\\d(_|\\d)*';
  var EXPONENT_RE = '[eE][-+]?' + INTEGER_RE;
  var DECIMAL_LITERAL_RE = INTEGER_RE + '(\\.' + INTEGER_RE + ')?' + '(' + EXPONENT_RE + ')?';
  // Based literal:
  var BASED_INTEGER_RE = '\\w+';
  var BASED_LITERAL_RE = INTEGER_RE + '#' + BASED_INTEGER_RE + '(\\.' + BASED_INTEGER_RE + ')?' + '#' + '(' + EXPONENT_RE + ')?';

  var NUMBER_RE = '\\b(' + BASED_LITERAL_RE + '|' + DECIMAL_LITERAL_RE + ')';

  return {
    case_insensitive: true,
    keywords: {
      keyword:
        'abs access after alias all and architecture array assert attribute begin block ' +
        'body buffer bus case component configuration constant context cover disconnect ' +
        'downto default else elsif end entity exit fairness file for force function generate ' +
        'generic group guarded if impure in inertial inout is label library linkage literal ' +
        'loop map mod nand new next nor not null of on open or others out package port ' +
        'postponed procedure process property protected pure range record register reject ' +
        'release rem report restrict restrict_guarantee return rol ror select sequence ' +
        'severity shared signal sla sll sra srl strong subtype then to transport type ' +
        'unaffected units until use variable vmode vprop vunit wait when while with xnor xor',
      typename:
        'boolean bit character severity_level integer time delay_length natural positive ' +
        'string bit_vector file_open_kind file_open_status std_ulogic std_ulogic_vector ' +
        'std_logic std_logic_vector unsigned signed boolean_vector integer_vector ' +
        'real_vector time_vector'
    },
    illegal: '{',
    contains: [
      hljs.C_BLOCK_COMMENT_MODE,        // VHDL-2008 block commenting.
      hljs.COMMENT('--', '$'),
      hljs.QUOTE_STRING_MODE,
      {
        className: 'number',
        begin: NUMBER_RE,
        relevance: 0
      },
      {
        className: 'literal',
        begin: '\'(U|X|0|1|Z|W|L|H|-)\'',
        contains: [hljs.BACKSLASH_ESCAPE]
      },
      {
        className: 'attribute',
        begin: '\'[A-Za-z](_?[A-Za-z0-9])*',
        contains: [hljs.BACKSLASH_ESCAPE]
      }
    ]
  };
});

hljs.registerLanguage('vim', function(hljs) {
  return {
    lexemes: /[!#@\w]+/,
    keywords: {
      keyword: //ex command
        // express version except: ! & * < = > !! # @ @@
        'N|0 P|0 X|0 a|0 ab abc abo al am an|0 ar arga argd arge argdo argg argl argu as au aug aun b|0 bN ba bad bd be bel bf bl bm bn bo bp br brea breaka breakd breakl bro bufdo buffers bun bw c|0 cN cNf ca cabc caddb cad caddf cal cat cb cc ccl cd ce cex cf cfir cgetb cgete cg changes chd che checkt cl cla clo cm cmapc cme cn cnew cnf cno cnorea cnoreme co col colo com comc comp con conf cope '+
        'cp cpf cq cr cs cst cu cuna cunme cw d|0 delm deb debugg delc delf dif diffg diffo diffp diffpu diffs diffthis dig di dl dell dj dli do doautoa dp dr ds dsp e|0 ea ec echoe echoh echom echon el elsei em en endfo endf endt endw ene ex exe exi exu f|0 files filet fin fina fini fir fix fo foldc foldd folddoc foldo for fu g|0 go gr grepa gu gv ha h|0 helpf helpg helpt hi hid his i|0 ia iabc if ij il im imapc '+
        'ime ino inorea inoreme int is isp iu iuna iunme j|0 ju k|0 keepa kee keepj lN lNf l|0 lad laddb laddf la lan lat lb lc lch lcl lcs le lefta let lex lf lfir lgetb lgete lg lgr lgrepa lh ll lla lli lmak lm lmapc lne lnew lnf ln loadk lo loc lockv lol lope lp lpf lr ls lt lu lua luad luaf lv lvimgrepa lw m|0 ma mak map mapc marks mat me menut mes mk mks mksp mkv mkvie mod mz mzf nbc nb nbs n|0 new nm nmapc nme nn nnoreme noa no noh norea noreme norm nu nun nunme ol o|0 om omapc ome on ono onoreme opt ou ounme ow p|0 '+
        'profd prof pro promptr pc ped pe perld po popu pp pre prev ps pt ptN ptf ptj ptl ptn ptp ptr pts pu pw py3 python3 py3d py3f py pyd pyf q|0 quita qa r|0 rec red redi redr redraws reg res ret retu rew ri rightb rub rubyd rubyf rund ru rv s|0 sN san sa sal sav sb sbN sba sbf sbl sbm sbn sbp sbr scrip scripte scs se setf setg setl sf sfir sh sim sig sil sl sla sm smap smapc sme sn sni sno snor snoreme sor '+
        'so spelld spe spelli spellr spellu spellw sp spr sre st sta startg startr star stopi stj sts sun sunm sunme sus sv sw sy synti sync t|0 tN tabN tabc tabdo tabe tabf tabfir tabl tabm tabnew '+
        'tabn tabo tabp tabr tabs tab ta tags tc tcld tclf te tf th tj tl tm tn to tp tr try ts tu u|0 undoj undol una unh unl unlo unm unme uns up v|0 ve verb vert vim vimgrepa vi viu vie vm vmapc vme vne vn vnoreme vs vu vunme windo w|0 wN wa wh wi winc winp wn wp wq wqa ws wu wv x|0 xa xmapc xm xme xn xnoreme xu xunme y|0 z|0 ~ '+
        // full version
        'Next Print append abbreviate abclear aboveleft all amenu anoremenu args argadd argdelete argedit argglobal arglocal argument ascii autocmd augroup aunmenu buffer bNext ball badd bdelete behave belowright bfirst blast bmodified bnext botright bprevious brewind break breakadd breakdel breaklist browse bunload '+
        'bwipeout change cNext cNfile cabbrev cabclear caddbuffer caddexpr caddfile call catch cbuffer cclose center cexpr cfile cfirst cgetbuffer cgetexpr cgetfile chdir checkpath checktime clist clast close cmap cmapclear cmenu cnext cnewer cnfile cnoremap cnoreabbrev cnoremenu copy colder colorscheme command comclear compiler continue confirm copen cprevious cpfile cquit crewind cscope cstag cunmap '+
        'cunabbrev cunmenu cwindow delete delmarks debug debuggreedy delcommand delfunction diffupdate diffget diffoff diffpatch diffput diffsplit digraphs display deletel djump dlist doautocmd doautoall deletep drop dsearch dsplit edit earlier echo echoerr echohl echomsg else elseif emenu endif endfor '+
        'endfunction endtry endwhile enew execute exit exusage file filetype find finally finish first fixdel fold foldclose folddoopen folddoclosed foldopen function global goto grep grepadd gui gvim hardcopy help helpfind helpgrep helptags highlight hide history insert iabbrev iabclear ijump ilist imap '+
        'imapclear imenu inoremap inoreabbrev inoremenu intro isearch isplit iunmap iunabbrev iunmenu join jumps keepalt keepmarks keepjumps lNext lNfile list laddexpr laddbuffer laddfile last language later lbuffer lcd lchdir lclose lcscope left leftabove lexpr lfile lfirst lgetbuffer lgetexpr lgetfile lgrep lgrepadd lhelpgrep llast llist lmake lmap lmapclear lnext lnewer lnfile lnoremap loadkeymap loadview '+
        'lockmarks lockvar lolder lopen lprevious lpfile lrewind ltag lunmap luado luafile lvimgrep lvimgrepadd lwindow move mark make mapclear match menu menutranslate messages mkexrc mksession mkspell mkvimrc mkview mode mzscheme mzfile nbclose nbkey nbsart next nmap nmapclear nmenu nnoremap '+
        'nnoremenu noautocmd noremap nohlsearch noreabbrev noremenu normal number nunmap nunmenu oldfiles open omap omapclear omenu only onoremap onoremenu options ounmap ounmenu ownsyntax print profdel profile promptfind promptrepl pclose pedit perl perldo pop popup ppop preserve previous psearch ptag ptNext '+
        'ptfirst ptjump ptlast ptnext ptprevious ptrewind ptselect put pwd py3do py3file python pydo pyfile quit quitall qall read recover redo redir redraw redrawstatus registers resize retab return rewind right rightbelow ruby rubydo rubyfile rundo runtime rviminfo substitute sNext sandbox sargument sall saveas sbuffer sbNext sball sbfirst sblast sbmodified sbnext sbprevious sbrewind scriptnames scriptencoding '+
        'scscope set setfiletype setglobal setlocal sfind sfirst shell simalt sign silent sleep slast smagic smapclear smenu snext sniff snomagic snoremap snoremenu sort source spelldump spellgood spellinfo spellrepall spellundo spellwrong split sprevious srewind stop stag startgreplace startreplace '+
        'startinsert stopinsert stjump stselect sunhide sunmap sunmenu suspend sview swapname syntax syntime syncbind tNext tabNext tabclose tabedit tabfind tabfirst tablast tabmove tabnext tabonly tabprevious tabrewind tag tcl tcldo tclfile tearoff tfirst throw tjump tlast tmenu tnext topleft tprevious '+'trewind tselect tunmenu undo undojoin undolist unabbreviate unhide unlet unlockvar unmap unmenu unsilent update vglobal version verbose vertical vimgrep vimgrepadd visual viusage view vmap vmapclear vmenu vnew '+
        'vnoremap vnoremenu vsplit vunmap vunmenu write wNext wall while winsize wincmd winpos wnext wprevious wqall wsverb wundo wviminfo xit xall xmapclear xmap xmenu xnoremap xnoremenu xunmap xunmenu yank',
      built_in: //built in func
        'abs acos add and append argc argidx argv asin atan atan2 browse browsedir bufexists buflisted bufloaded bufname bufnr bufwinnr byte2line byteidx call ceil changenr char2nr cindent clearmatches col complete complete_add complete_check confirm copy cos cosh count cscope_connection cursor '+
        'deepcopy delete did_filetype diff_filler diff_hlID empty escape eval eventhandler executable exists exp expand extend feedkeys filereadable filewritable filter finddir findfile float2nr floor fmod fnameescape fnamemodify foldclosed foldclosedend foldlevel foldtext foldtextresult foreground function '+
        'garbagecollect get getbufline getbufvar getchar getcharmod getcmdline getcmdpos getcmdtype getcwd getfontname getfperm getfsize getftime getftype getline getloclist getmatches getpid getpos getqflist getreg getregtype gettabvar gettabwinvar getwinposx getwinposy getwinvar glob globpath has has_key '+
        'haslocaldir hasmapto histadd histdel histget histnr hlexists hlID hostname iconv indent index input inputdialog inputlist inputrestore inputsave inputsecret insert invert isdirectory islocked items join keys len libcall libcallnr line line2byte lispindent localtime log log10 luaeval map maparg mapcheck '+
        'match matchadd matcharg matchdelete matchend matchlist matchstr max min mkdir mode mzeval nextnonblank nr2char or pathshorten pow prevnonblank printf pumvisible py3eval pyeval range readfile reltime reltimestr remote_expr remote_foreground remote_peek remote_read remote_send remove rename repeat '+
        'resolve reverse round screenattr screenchar screencol screenrow search searchdecl searchpair searchpairpos searchpos server2client serverlist setbufvar setcmdpos setline setloclist setmatches setpos setqflist setreg settabvar settabwinvar setwinvar sha256 shellescape shiftwidth simplify sin '+
        'sinh sort soundfold spellbadword spellsuggest split sqrt str2float str2nr strchars strdisplaywidth strftime stridx string strlen strpart strridx strtrans strwidth submatch substitute synconcealed synID synIDattr '+
        'synIDtrans synstack system tabpagebuflist tabpagenr tabpagewinnr tagfiles taglist tan tanh tempname tolower toupper tr trunc type undofile undotree values virtcol visualmode wildmenumode winbufnr wincol winheight winline winnr winrestcmd winrestview winsaveview winwidth writefile xor'
    },
    illegal: /[{:]/,
    contains: [
      hljs.NUMBER_MODE,
      hljs.APOS_STRING_MODE,
      {
        className: 'string',
        // quote with escape, comment as quote
        begin: /"((\\")|[^"\n])*("|\n)/
      },
      {
        className: 'variable',
        begin: /[bwtglsav]:[\w\d_]*/
      },
      {
        className: 'function',
        beginKeywords: 'function function!', end: '$',
        relevance: 0,
        contains: [
          hljs.TITLE_MODE,
          {
            className: 'params',
            begin: '\\(', end: '\\)'
          }
        ]
      }
    ]
  };
});

hljs.registerLanguage('x86asm', function(hljs) {
  return {
    case_insensitive: true,
    lexemes: '\\.?' + hljs.IDENT_RE,
    keywords: {
      keyword:
        'lock rep repe repz repne repnz xaquire xrelease bnd nobnd ' +
        'aaa aad aam aas adc add and arpl bb0_reset bb1_reset bound bsf bsr bswap bt btc btr bts call cbw cdq cdqe clc cld cli clts cmc cmp cmpsb cmpsd cmpsq cmpsw cmpxchg cmpxchg486 cmpxchg8b cmpxchg16b cpuid cpu_read cpu_write cqo cwd cwde daa das dec div dmint emms enter equ f2xm1 fabs fadd faddp fbld fbstp fchs fclex fcmovb fcmovbe fcmove fcmovnb fcmovnbe fcmovne fcmovnu fcmovu fcom fcomi fcomip fcomp fcompp fcos fdecstp fdisi fdiv fdivp fdivr fdivrp femms feni ffree ffreep fiadd ficom ficomp fidiv fidivr fild fimul fincstp finit fist fistp fisttp fisub fisubr fld fld1 fldcw fldenv fldl2e fldl2t fldlg2 fldln2 fldpi fldz fmul fmulp fnclex fndisi fneni fninit fnop fnsave fnstcw fnstenv fnstsw fpatan fprem fprem1 fptan frndint frstor fsave fscale fsetpm fsin fsincos fsqrt fst fstcw fstenv fstp fstsw fsub fsubp fsubr fsubrp ftst fucom fucomi fucomip fucomp fucompp fxam fxch fxtract fyl2x fyl2xp1 hlt ibts icebp idiv imul in inc incbin insb insd insw int int01 int1 int03 int3 into invd invpcid invlpg invlpga iret iretd iretq iretw jcxz jecxz jrcxz jmp jmpe lahf lar lds lea leave les lfence lfs lgdt lgs lidt lldt lmsw loadall loadall286 lodsb lodsd lodsq lodsw loop loope loopne loopnz loopz lsl lss ltr mfence monitor mov movd movq movsb movsd movsq movsw movsx movsxd movzx mul mwait neg nop not or out outsb outsd outsw packssdw packsswb packuswb paddb paddd paddsb paddsiw paddsw paddusb paddusw paddw pand pandn pause paveb pavgusb pcmpeqb pcmpeqd pcmpeqw pcmpgtb pcmpgtd pcmpgtw pdistib pf2id pfacc pfadd pfcmpeq pfcmpge pfcmpgt pfmax pfmin pfmul pfrcp pfrcpit1 pfrcpit2 pfrsqit1 pfrsqrt pfsub pfsubr pi2fd pmachriw pmaddwd pmagw pmulhriw pmulhrwa pmulhrwc pmulhw pmullw pmvgezb pmvlzb pmvnzb pmvzb pop popa popad popaw popf popfd popfq popfw por prefetch prefetchw pslld psllq psllw psrad psraw psrld psrlq psrlw psubb psubd psubsb psubsiw psubsw psubusb psubusw psubw punpckhbw punpckhdq punpckhwd punpcklbw punpckldq punpcklwd push pusha pushad pushaw pushf pushfd pushfq pushfw pxor rcl rcr rdshr rdmsr rdpmc rdtsc rdtscp ret retf retn rol ror rdm rsdc rsldt rsm rsts sahf sal salc sar sbb scasb scasd scasq scasw sfence sgdt shl shld shr shrd sidt sldt skinit smi smint smintold smsw stc std sti stosb stosd stosq stosw str sub svdc svldt svts swapgs syscall sysenter sysexit sysret test ud0 ud1 ud2b ud2 ud2a umov verr verw fwait wbinvd wrshr wrmsr xadd xbts xchg xlatb xlat xor cmove cmovz cmovne cmovnz cmova cmovnbe cmovae cmovnb cmovb cmovnae cmovbe cmovna cmovg cmovnle cmovge cmovnl cmovl cmovnge cmovle cmovng cmovc cmovnc cmovo cmovno cmovs cmovns cmovp cmovpe cmovnp cmovpo je jz jne jnz ja jnbe jae jnb jb jnae jbe jna jg jnle jge jnl jl jnge jle jng jc jnc jo jno js jns jpo jnp jpe jp sete setz setne setnz seta setnbe setae setnb setnc setb setnae setcset setbe setna setg setnle setge setnl setl setnge setle setng sets setns seto setno setpe setp setpo setnp addps addss andnps andps cmpeqps cmpeqss cmpleps cmpless cmpltps cmpltss cmpneqps cmpneqss cmpnleps cmpnless cmpnltps cmpnltss cmpordps cmpordss cmpunordps cmpunordss cmpps cmpss comiss cvtpi2ps cvtps2pi cvtsi2ss cvtss2si cvttps2pi cvttss2si divps divss ldmxcsr maxps maxss minps minss movaps movhps movlhps movlps movhlps movmskps movntps movss movups mulps mulss orps rcpps rcpss rsqrtps rsqrtss shufps sqrtps sqrtss stmxcsr subps subss ucomiss unpckhps unpcklps xorps fxrstor fxrstor64 fxsave fxsave64 xgetbv xsetbv xsave xsave64 xsaveopt xsaveopt64 xrstor xrstor64 prefetchnta prefetcht0 prefetcht1 prefetcht2 maskmovq movntq pavgb pavgw pextrw pinsrw pmaxsw pmaxub pminsw pminub pmovmskb pmulhuw psadbw pshufw pf2iw pfnacc pfpnacc pi2fw pswapd maskmovdqu clflush movntdq movnti movntpd movdqa movdqu movdq2q movq2dq paddq pmuludq pshufd pshufhw pshuflw pslldq psrldq psubq punpckhqdq punpcklqdq addpd addsd andnpd andpd cmpeqpd cmpeqsd cmplepd cmplesd cmpltpd cmpltsd cmpneqpd cmpneqsd cmpnlepd cmpnlesd cmpnltpd cmpnltsd cmpordpd cmpordsd cmpunordpd cmpunordsd cmppd comisd cvtdq2pd cvtdq2ps cvtpd2dq cvtpd2pi cvtpd2ps cvtpi2pd cvtps2dq cvtps2pd cvtsd2si cvtsd2ss cvtsi2sd cvtss2sd cvttpd2pi cvttpd2dq cvttps2dq cvttsd2si divpd divsd maxpd maxsd minpd minsd movapd movhpd movlpd movmskpd movupd mulpd mulsd orpd shufpd sqrtpd sqrtsd subpd subsd ucomisd unpckhpd unpcklpd xorpd addsubpd addsubps haddpd haddps hsubpd hsubps lddqu movddup movshdup movsldup clgi stgi vmcall vmclear vmfunc vmlaunch vmload vmmcall vmptrld vmptrst vmread vmresume vmrun vmsave vmwrite vmxoff vmxon invept invvpid pabsb pabsw pabsd palignr phaddw phaddd phaddsw phsubw phsubd phsubsw pmaddubsw pmulhrsw pshufb psignb psignw psignd extrq insertq movntsd movntss lzcnt blendpd blendps blendvpd blendvps dppd dpps extractps insertps movntdqa mpsadbw packusdw pblendvb pblendw pcmpeqq pextrb pextrd pextrq phminposuw pinsrb pinsrd pinsrq pmaxsb pmaxsd pmaxud pmaxuw pminsb pminsd pminud pminuw pmovsxbw pmovsxbd pmovsxbq pmovsxwd pmovsxwq pmovsxdq pmovzxbw pmovzxbd pmovzxbq pmovzxwd pmovzxwq pmovzxdq pmuldq pmulld ptest roundpd roundps roundsd roundss crc32 pcmpestri pcmpestrm pcmpistri pcmpistrm pcmpgtq popcnt getsec pfrcpv pfrsqrtv movbe aesenc aesenclast aesdec aesdeclast aesimc aeskeygenassist vaesenc vaesenclast vaesdec vaesdeclast vaesimc vaeskeygenassist vaddpd vaddps vaddsd vaddss vaddsubpd vaddsubps vandpd vandps vandnpd vandnps vblendpd vblendps vblendvpd vblendvps vbroadcastss vbroadcastsd vbroadcastf128 vcmpeq_ospd vcmpeqpd vcmplt_ospd vcmpltpd vcmple_ospd vcmplepd vcmpunord_qpd vcmpunordpd vcmpneq_uqpd vcmpneqpd vcmpnlt_uspd vcmpnltpd vcmpnle_uspd vcmpnlepd vcmpord_qpd vcmpordpd vcmpeq_uqpd vcmpnge_uspd vcmpngepd vcmpngt_uspd vcmpngtpd vcmpfalse_oqpd vcmpfalsepd vcmpneq_oqpd vcmpge_ospd vcmpgepd vcmpgt_ospd vcmpgtpd vcmptrue_uqpd vcmptruepd vcmplt_oqpd vcmple_oqpd vcmpunord_spd vcmpneq_uspd vcmpnlt_uqpd vcmpnle_uqpd vcmpord_spd vcmpeq_uspd vcmpnge_uqpd vcmpngt_uqpd vcmpfalse_ospd vcmpneq_ospd vcmpge_oqpd vcmpgt_oqpd vcmptrue_uspd vcmppd vcmpeq_osps vcmpeqps vcmplt_osps vcmpltps vcmple_osps vcmpleps vcmpunord_qps vcmpunordps vcmpneq_uqps vcmpneqps vcmpnlt_usps vcmpnltps vcmpnle_usps vcmpnleps vcmpord_qps vcmpordps vcmpeq_uqps vcmpnge_usps vcmpngeps vcmpngt_usps vcmpngtps vcmpfalse_oqps vcmpfalseps vcmpneq_oqps vcmpge_osps vcmpgeps vcmpgt_osps vcmpgtps vcmptrue_uqps vcmptrueps vcmplt_oqps vcmple_oqps vcmpunord_sps vcmpneq_usps vcmpnlt_uqps vcmpnle_uqps vcmpord_sps vcmpeq_usps vcmpnge_uqps vcmpngt_uqps vcmpfalse_osps vcmpneq_osps vcmpge_oqps vcmpgt_oqps vcmptrue_usps vcmpps vcmpeq_ossd vcmpeqsd vcmplt_ossd vcmpltsd vcmple_ossd vcmplesd vcmpunord_qsd vcmpunordsd vcmpneq_uqsd vcmpneqsd vcmpnlt_ussd vcmpnltsd vcmpnle_ussd vcmpnlesd vcmpord_qsd vcmpordsd vcmpeq_uqsd vcmpnge_ussd vcmpngesd vcmpngt_ussd vcmpngtsd vcmpfalse_oqsd vcmpfalsesd vcmpneq_oqsd vcmpge_ossd vcmpgesd vcmpgt_ossd vcmpgtsd vcmptrue_uqsd vcmptruesd vcmplt_oqsd vcmple_oqsd vcmpunord_ssd vcmpneq_ussd vcmpnlt_uqsd vcmpnle_uqsd vcmpord_ssd vcmpeq_ussd vcmpnge_uqsd vcmpngt_uqsd vcmpfalse_ossd vcmpneq_ossd vcmpge_oqsd vcmpgt_oqsd vcmptrue_ussd vcmpsd vcmpeq_osss vcmpeqss vcmplt_osss vcmpltss vcmple_osss vcmpless vcmpunord_qss vcmpunordss vcmpneq_uqss vcmpneqss vcmpnlt_usss vcmpnltss vcmpnle_usss vcmpnless vcmpord_qss vcmpordss vcmpeq_uqss vcmpnge_usss vcmpngess vcmpngt_usss vcmpngtss vcmpfalse_oqss vcmpfalsess vcmpneq_oqss vcmpge_osss vcmpgess vcmpgt_osss vcmpgtss vcmptrue_uqss vcmptruess vcmplt_oqss vcmple_oqss vcmpunord_sss vcmpneq_usss vcmpnlt_uqss vcmpnle_uqss vcmpord_sss vcmpeq_usss vcmpnge_uqss vcmpngt_uqss vcmpfalse_osss vcmpneq_osss vcmpge_oqss vcmpgt_oqss vcmptrue_usss vcmpss vcomisd vcomiss vcvtdq2pd vcvtdq2ps vcvtpd2dq vcvtpd2ps vcvtps2dq vcvtps2pd vcvtsd2si vcvtsd2ss vcvtsi2sd vcvtsi2ss vcvtss2sd vcvtss2si vcvttpd2dq vcvttps2dq vcvttsd2si vcvttss2si vdivpd vdivps vdivsd vdivss vdppd vdpps vextractf128 vextractps vhaddpd vhaddps vhsubpd vhsubps vinsertf128 vinsertps vlddqu vldqqu vldmxcsr vmaskmovdqu vmaskmovps vmaskmovpd vmaxpd vmaxps vmaxsd vmaxss vminpd vminps vminsd vminss vmovapd vmovaps vmovd vmovq vmovddup vmovdqa vmovqqa vmovdqu vmovqqu vmovhlps vmovhpd vmovhps vmovlhps vmovlpd vmovlps vmovmskpd vmovmskps vmovntdq vmovntqq vmovntdqa vmovntpd vmovntps vmovsd vmovshdup vmovsldup vmovss vmovupd vmovups vmpsadbw vmulpd vmulps vmulsd vmulss vorpd vorps vpabsb vpabsw vpabsd vpacksswb vpackssdw vpackuswb vpackusdw vpaddb vpaddw vpaddd vpaddq vpaddsb vpaddsw vpaddusb vpaddusw vpalignr vpand vpandn vpavgb vpavgw vpblendvb vpblendw vpcmpestri vpcmpestrm vpcmpistri vpcmpistrm vpcmpeqb vpcmpeqw vpcmpeqd vpcmpeqq vpcmpgtb vpcmpgtw vpcmpgtd vpcmpgtq vpermilpd vpermilps vperm2f128 vpextrb vpextrw vpextrd vpextrq vphaddw vphaddd vphaddsw vphminposuw vphsubw vphsubd vphsubsw vpinsrb vpinsrw vpinsrd vpinsrq vpmaddwd vpmaddubsw vpmaxsb vpmaxsw vpmaxsd vpmaxub vpmaxuw vpmaxud vpminsb vpminsw vpminsd vpminub vpminuw vpminud vpmovmskb vpmovsxbw vpmovsxbd vpmovsxbq vpmovsxwd vpmovsxwq vpmovsxdq vpmovzxbw vpmovzxbd vpmovzxbq vpmovzxwd vpmovzxwq vpmovzxdq vpmulhuw vpmulhrsw vpmulhw vpmullw vpmulld vpmuludq vpmuldq vpor vpsadbw vpshufb vpshufd vpshufhw vpshuflw vpsignb vpsignw vpsignd vpslldq vpsrldq vpsllw vpslld vpsllq vpsraw vpsrad vpsrlw vpsrld vpsrlq vptest vpsubb vpsubw vpsubd vpsubq vpsubsb vpsubsw vpsubusb vpsubusw vpunpckhbw vpunpckhwd vpunpckhdq vpunpckhqdq vpunpcklbw vpunpcklwd vpunpckldq vpunpcklqdq vpxor vrcpps vrcpss vrsqrtps vrsqrtss vroundpd vroundps vroundsd vroundss vshufpd vshufps vsqrtpd vsqrtps vsqrtsd vsqrtss vstmxcsr vsubpd vsubps vsubsd vsubss vtestps vtestpd vucomisd vucomiss vunpckhpd vunpckhps vunpcklpd vunpcklps vxorpd vxorps vzeroall vzeroupper pclmullqlqdq pclmulhqlqdq pclmullqhqdq pclmulhqhqdq pclmulqdq vpclmullqlqdq vpclmulhqlqdq vpclmullqhqdq vpclmulhqhqdq vpclmulqdq vfmadd132ps vfmadd132pd vfmadd312ps vfmadd312pd vfmadd213ps vfmadd213pd vfmadd123ps vfmadd123pd vfmadd231ps vfmadd231pd vfmadd321ps vfmadd321pd vfmaddsub132ps vfmaddsub132pd vfmaddsub312ps vfmaddsub312pd vfmaddsub213ps vfmaddsub213pd vfmaddsub123ps vfmaddsub123pd vfmaddsub231ps vfmaddsub231pd vfmaddsub321ps vfmaddsub321pd vfmsub132ps vfmsub132pd vfmsub312ps vfmsub312pd vfmsub213ps vfmsub213pd vfmsub123ps vfmsub123pd vfmsub231ps vfmsub231pd vfmsub321ps vfmsub321pd vfmsubadd132ps vfmsubadd132pd vfmsubadd312ps vfmsubadd312pd vfmsubadd213ps vfmsubadd213pd vfmsubadd123ps vfmsubadd123pd vfmsubadd231ps vfmsubadd231pd vfmsubadd321ps vfmsubadd321pd vfnmadd132ps vfnmadd132pd vfnmadd312ps vfnmadd312pd vfnmadd213ps vfnmadd213pd vfnmadd123ps vfnmadd123pd vfnmadd231ps vfnmadd231pd vfnmadd321ps vfnmadd321pd vfnmsub132ps vfnmsub132pd vfnmsub312ps vfnmsub312pd vfnmsub213ps vfnmsub213pd vfnmsub123ps vfnmsub123pd vfnmsub231ps vfnmsub231pd vfnmsub321ps vfnmsub321pd vfmadd132ss vfmadd132sd vfmadd312ss vfmadd312sd vfmadd213ss vfmadd213sd vfmadd123ss vfmadd123sd vfmadd231ss vfmadd231sd vfmadd321ss vfmadd321sd vfmsub132ss vfmsub132sd vfmsub312ss vfmsub312sd vfmsub213ss vfmsub213sd vfmsub123ss vfmsub123sd vfmsub231ss vfmsub231sd vfmsub321ss vfmsub321sd vfnmadd132ss vfnmadd132sd vfnmadd312ss vfnmadd312sd vfnmadd213ss vfnmadd213sd vfnmadd123ss vfnmadd123sd vfnmadd231ss vfnmadd231sd vfnmadd321ss vfnmadd321sd vfnmsub132ss vfnmsub132sd vfnmsub312ss vfnmsub312sd vfnmsub213ss vfnmsub213sd vfnmsub123ss vfnmsub123sd vfnmsub231ss vfnmsub231sd vfnmsub321ss vfnmsub321sd rdfsbase rdgsbase rdrand wrfsbase wrgsbase vcvtph2ps vcvtps2ph adcx adox rdseed clac stac xstore xcryptecb xcryptcbc xcryptctr xcryptcfb xcryptofb montmul xsha1 xsha256 llwpcb slwpcb lwpval lwpins vfmaddpd vfmaddps vfmaddsd vfmaddss vfmaddsubpd vfmaddsubps vfmsubaddpd vfmsubaddps vfmsubpd vfmsubps vfmsubsd vfmsubss vfnmaddpd vfnmaddps vfnmaddsd vfnmaddss vfnmsubpd vfnmsubps vfnmsubsd vfnmsubss vfrczpd vfrczps vfrczsd vfrczss vpcmov vpcomb vpcomd vpcomq vpcomub vpcomud vpcomuq vpcomuw vpcomw vphaddbd vphaddbq vphaddbw vphadddq vphaddubd vphaddubq vphaddubw vphaddudq vphadduwd vphadduwq vphaddwd vphaddwq vphsubbw vphsubdq vphsubwd vpmacsdd vpmacsdqh vpmacsdql vpmacssdd vpmacssdqh vpmacssdql vpmacsswd vpmacssww vpmacswd vpmacsww vpmadcsswd vpmadcswd vpperm vprotb vprotd vprotq vprotw vpshab vpshad vpshaq vpshaw vpshlb vpshld vpshlq vpshlw vbroadcasti128 vpblendd vpbroadcastb vpbroadcastw vpbroadcastd vpbroadcastq vpermd vpermpd vpermps vpermq vperm2i128 vextracti128 vinserti128 vpmaskmovd vpmaskmovq vpsllvd vpsllvq vpsravd vpsrlvd vpsrlvq vgatherdpd vgatherqpd vgatherdps vgatherqps vpgatherdd vpgatherqd vpgatherdq vpgatherqq xabort xbegin xend xtest andn bextr blci blcic blsi blsic blcfill blsfill blcmsk blsmsk blsr blcs bzhi mulx pdep pext rorx sarx shlx shrx tzcnt tzmsk t1mskc valignd valignq vblendmpd vblendmps vbroadcastf32x4 vbroadcastf64x4 vbroadcasti32x4 vbroadcasti64x4 vcompresspd vcompressps vcvtpd2udq vcvtps2udq vcvtsd2usi vcvtss2usi vcvttpd2udq vcvttps2udq vcvttsd2usi vcvttss2usi vcvtudq2pd vcvtudq2ps vcvtusi2sd vcvtusi2ss vexpandpd vexpandps vextractf32x4 vextractf64x4 vextracti32x4 vextracti64x4 vfixupimmpd vfixupimmps vfixupimmsd vfixupimmss vgetexppd vgetexpps vgetexpsd vgetexpss vgetmantpd vgetmantps vgetmantsd vgetmantss vinsertf32x4 vinsertf64x4 vinserti32x4 vinserti64x4 vmovdqa32 vmovdqa64 vmovdqu32 vmovdqu64 vpabsq vpandd vpandnd vpandnq vpandq vpblendmd vpblendmq vpcmpltd vpcmpled vpcmpneqd vpcmpnltd vpcmpnled vpcmpd vpcmpltq vpcmpleq vpcmpneqq vpcmpnltq vpcmpnleq vpcmpq vpcmpequd vpcmpltud vpcmpleud vpcmpnequd vpcmpnltud vpcmpnleud vpcmpud vpcmpequq vpcmpltuq vpcmpleuq vpcmpnequq vpcmpnltuq vpcmpnleuq vpcmpuq vpcompressd vpcompressq vpermi2d vpermi2pd vpermi2ps vpermi2q vpermt2d vpermt2pd vpermt2ps vpermt2q vpexpandd vpexpandq vpmaxsq vpmaxuq vpminsq vpminuq vpmovdb vpmovdw vpmovqb vpmovqd vpmovqw vpmovsdb vpmovsdw vpmovsqb vpmovsqd vpmovsqw vpmovusdb vpmovusdw vpmovusqb vpmovusqd vpmovusqw vpord vporq vprold vprolq vprolvd vprolvq vprord vprorq vprorvd vprorvq vpscatterdd vpscatterdq vpscatterqd vpscatterqq vpsraq vpsravq vpternlogd vpternlogq vptestmd vptestmq vptestnmd vptestnmq vpxord vpxorq vrcp14pd vrcp14ps vrcp14sd vrcp14ss vrndscalepd vrndscaleps vrndscalesd vrndscaless vrsqrt14pd vrsqrt14ps vrsqrt14sd vrsqrt14ss vscalefpd vscalefps vscalefsd vscalefss vscatterdpd vscatterdps vscatterqpd vscatterqps vshuff32x4 vshuff64x2 vshufi32x4 vshufi64x2 kandnw kandw kmovw knotw kortestw korw kshiftlw kshiftrw kunpckbw kxnorw kxorw vpbroadcastmb2q vpbroadcastmw2d vpconflictd vpconflictq vplzcntd vplzcntq vexp2pd vexp2ps vrcp28pd vrcp28ps vrcp28sd vrcp28ss vrsqrt28pd vrsqrt28ps vrsqrt28sd vrsqrt28ss vgatherpf0dpd vgatherpf0dps vgatherpf0qpd vgatherpf0qps vgatherpf1dpd vgatherpf1dps vgatherpf1qpd vgatherpf1qps vscatterpf0dpd vscatterpf0dps vscatterpf0qpd vscatterpf0qps vscatterpf1dpd vscatterpf1dps vscatterpf1qpd vscatterpf1qps prefetchwt1 bndmk bndcl bndcu bndcn bndmov bndldx bndstx sha1rnds4 sha1nexte sha1msg1 sha1msg2 sha256rnds2 sha256msg1 sha256msg2 hint_nop0 hint_nop1 hint_nop2 hint_nop3 hint_nop4 hint_nop5 hint_nop6 hint_nop7 hint_nop8 hint_nop9 hint_nop10 hint_nop11 hint_nop12 hint_nop13 hint_nop14 hint_nop15 hint_nop16 hint_nop17 hint_nop18 hint_nop19 hint_nop20 hint_nop21 hint_nop22 hint_nop23 hint_nop24 hint_nop25 hint_nop26 hint_nop27 hint_nop28 hint_nop29 hint_nop30 hint_nop31 hint_nop32 hint_nop33 hint_nop34 hint_nop35 hint_nop36 hint_nop37 hint_nop38 hint_nop39 hint_nop40 hint_nop41 hint_nop42 hint_nop43 hint_nop44 hint_nop45 hint_nop46 hint_nop47 hint_nop48 hint_nop49 hint_nop50 hint_nop51 hint_nop52 hint_nop53 hint_nop54 hint_nop55 hint_nop56 hint_nop57 hint_nop58 hint_nop59 hint_nop60 hint_nop61 hint_nop62 hint_nop63',
      literal:
        // Instruction pointer
        'ip eip rip ' +
        // 8-bit registers
        'al ah bl bh cl ch dl dh sil dil bpl spl r8b r9b r10b r11b r12b r13b r14b r15b ' +
        // 16-bit registers
        'ax bx cx dx si di bp sp r8w r9w r10w r11w r12w r13w r14w r15w ' +
        // 32-bit registers
        'eax ebx ecx edx esi edi ebp esp eip r8d r9d r10d r11d r12d r13d r14d r15d ' +
        // 64-bit registers
        'rax rbx rcx rdx rsi rdi rbp rsp r8 r9 r10 r11 r12 r13 r14 r15 ' +
        // Segment registers
        'cs ds es fs gs ss ' +
        // Floating point stack registers
        'st st0 st1 st2 st3 st4 st5 st6 st7 ' +
        // MMX Registers
        'mm0 mm1 mm2 mm3 mm4 mm5 mm6 mm7 ' +
        // SSE registers
        'xmm0  xmm1  xmm2  xmm3  xmm4  xmm5  xmm6  xmm7  xmm8  xmm9 xmm10  xmm11 xmm12 xmm13 xmm14 xmm15 ' +
        'xmm16 xmm17 xmm18 xmm19 xmm20 xmm21 xmm22 xmm23 xmm24 xmm25 xmm26 xmm27 xmm28 xmm29 xmm30 xmm31 ' +
        // AVX registers
        'ymm0  ymm1  ymm2  ymm3  ymm4  ymm5  ymm6  ymm7  ymm8  ymm9 ymm10  ymm11 ymm12 ymm13 ymm14 ymm15 ' +
        'ymm16 ymm17 ymm18 ymm19 ymm20 ymm21 ymm22 ymm23 ymm24 ymm25 ymm26 ymm27 ymm28 ymm29 ymm30 ymm31 ' +
        // AVX-512F registers
        'zmm0  zmm1  zmm2  zmm3  zmm4  zmm5  zmm6  zmm7  zmm8  zmm9 zmm10  zmm11 zmm12 zmm13 zmm14 zmm15 ' +
        'zmm16 zmm17 zmm18 zmm19 zmm20 zmm21 zmm22 zmm23 zmm24 zmm25 zmm26 zmm27 zmm28 zmm29 zmm30 zmm31 ' +
        // AVX-512F mask registers
        'k0 k1 k2 k3 k4 k5 k6 k7 ' +
        // Bound (MPX) register
        'bnd0 bnd1 bnd2 bnd3 ' +
        // Special register
        'cr0 cr1 cr2 cr3 cr4 cr8 dr0 dr1 dr2 dr3 dr8 tr3 tr4 tr5 tr6 tr7 ' +
        // NASM altreg package
        'r0 r1 r2 r3 r4 r5 r6 r7 r0b r1b r2b r3b r4b r5b r6b r7b ' +
        'r0w r1w r2w r3w r4w r5w r6w r7w r0d r1d r2d r3d r4d r5d r6d r7d ' +
        'r0h r1h r2h r3h ' +
        'r0l r1l r2l r3l r4l r5l r6l r7l r8l r9l r10l r11l r12l r13l r14l r15l',

      pseudo:
        'db dw dd dq dt ddq do dy dz ' +
        'resb resw resd resq rest resdq reso resy resz ' +
        'incbin equ times',

      preprocessor:
        '%define %xdefine %+ %undef %defstr %deftok %assign %strcat %strlen %substr %rotate %elif %else %endif ' +
        '%ifmacro %ifctx %ifidn %ifidni %ifid %ifnum %ifstr %iftoken %ifempty %ifenv %error %warning %fatal %rep ' +
        '%endrep %include %push %pop %repl %pathsearch %depend %use %arg %stacksize %local %line %comment %endcomment ' +
        '.nolist ' +
        'byte word dword qword nosplit rel abs seg wrt strict near far a32 ptr ' +
        '__FILE__ __LINE__ __SECT__  __BITS__ __OUTPUT_FORMAT__ __DATE__ __TIME__ __DATE_NUM__ __TIME_NUM__ ' +
        '__UTC_DATE__ __UTC_TIME__ __UTC_DATE_NUM__ __UTC_TIME_NUM__  __PASS__ struc endstruc istruc at iend ' +
        'align alignb sectalign daz nodaz up down zero default option assume public ',

      built_in:
        'bits use16 use32 use64 default section segment absolute extern global common cpu float ' +
        '__utf16__ __utf16le__ __utf16be__ __utf32__ __utf32le__ __utf32be__ ' +
        '__float8__ __float16__ __float32__ __float64__ __float80m__ __float80e__ __float128l__ __float128h__ ' +
        '__Infinity__ __QNaN__ __SNaN__ Inf NaN QNaN SNaN float8 float16 float32 float64 float80m float80e ' +
        'float128l float128h __FLOAT_DAZ__ __FLOAT_ROUND__ __FLOAT__'
    },
    contains: [
      hljs.COMMENT(
        ';',
        '$',
        {
          relevance: 0
        }
      ),
      {
        className: 'number',
        variants: [
          // Float number and x87 BCD
          {
            begin: '\\b(?:([0-9][0-9_]*)?\\.[0-9_]*(?:[eE][+-]?[0-9_]+)?|' +
                   '(0[Xx])?[0-9][0-9_]*\\.?[0-9_]*(?:[pP](?:[+-]?[0-9_]+)?)?)\\b',
            relevance: 0
          },

          // Hex number in $
          { begin: '\\$[0-9][0-9A-Fa-f]*', relevance: 0 },

          // Number in H,D,T,Q,O,B,Y suffix
          { begin: '\\b(?:[0-9A-Fa-f][0-9A-Fa-f_]*[Hh]|[0-9][0-9_]*[DdTt]?|[0-7][0-7_]*[QqOo]|[0-1][0-1_]*[BbYy])\\b' },

          // Number in X,D,T,Q,O,B,Y prefix
          { begin: '\\b(?:0[Xx][0-9A-Fa-f_]+|0[DdTt][0-9_]+|0[QqOo][0-7_]+|0[BbYy][0-1_]+)\\b'}
        ]
      },
      // Double quote string
      hljs.QUOTE_STRING_MODE,
      {
        className: 'string',
        variants: [
          // Single-quoted string
          { begin: '\'', end: '[^\\\\]\'' },
          // Backquoted string
          { begin: '`', end: '[^\\\\]`' },
          // Section name
          { begin: '\\.[A-Za-z0-9]+' }
        ],
        relevance: 0
      },
      {
        className: 'label',
        variants: [
          // Global label and local label
          { begin: '^\\s*[A-Za-z._?][A-Za-z0-9_$#@~.?]*(:|\\s+label)' },
          // Macro-local label
          { begin: '^\\s*%%[A-Za-z0-9_$#@~.?]*:' }
        ],
        relevance: 0
      },
      // Macro parameter
      {
        className: 'argument',
        begin: '%[0-9]+',
        relevance: 0
      },
      // Macro parameter
      {
        className: 'built_in',
        begin: '%!\S+',
        relevance: 0
      }
    ]
  };
});

hljs.registerLanguage('xl', function(hljs) {
  var BUILTIN_MODULES =
    'ObjectLoader Animate MovieCredits Slides Filters Shading Materials LensFlare Mapping VLCAudioVideo ' +
    'StereoDecoder PointCloud NetworkAccess RemoteControl RegExp ChromaKey Snowfall NodeJS Speech Charts';

  var XL_KEYWORDS = {
    keyword: 'if then else do while until for loop import with is as where when by data constant',
    literal: 'true false nil',
    type: 'integer real text name boolean symbol infix prefix postfix block tree',
    built_in: 'in mod rem and or xor not abs sign floor ceil sqrt sin cos tan asin acos atan exp expm1 log log2 log10 log1p pi at',
    module: BUILTIN_MODULES,
    id:
      'text_length text_range text_find text_replace contains page slide basic_slide title_slide title subtitle ' +
      'fade_in fade_out fade_at clear_color color line_color line_width texture_wrap texture_transform texture ' +
      'scale_?x scale_?y scale_?z? translate_?x translate_?y translate_?z? rotate_?x rotate_?y rotate_?z? rectangle ' +
      'circle ellipse sphere path line_to move_to quad_to curve_to theme background contents locally time mouse_?x ' +
      'mouse_?y mouse_buttons'
  };

  var XL_CONSTANT = {
    className: 'constant',
    begin: '[A-Z][A-Z_0-9]+',
    relevance: 0
  };
  var XL_VARIABLE = {
    className: 'variable',
    begin: '([A-Z][a-z_0-9]+)+',
    relevance: 0
  };
  var XL_ID = {
    className: 'id',
    begin: '[a-z][a-z_0-9]+',
    relevance: 0
  };

  var DOUBLE_QUOTE_TEXT = {
    className: 'string',
    begin: '"', end: '"', illegal: '\\n'
  };
  var SINGLE_QUOTE_TEXT = {
    className: 'string',
    begin: '\'', end: '\'', illegal: '\\n'
  };
  var LONG_TEXT = {
    className: 'string',
    begin: '<<', end: '>>'
  };
  var BASED_NUMBER = {
    className: 'number',
    begin: '[0-9]+#[0-9A-Z_]+(\\.[0-9-A-Z_]+)?#?([Ee][+-]?[0-9]+)?',
    relevance: 10
  };
  var IMPORT = {
    className: 'import',
    beginKeywords: 'import', end: '$',
    keywords: {
      keyword: 'import',
      module: BUILTIN_MODULES
    },
    relevance: 0,
    contains: [DOUBLE_QUOTE_TEXT]
  };
  var FUNCTION_DEFINITION = {
    className: 'function',
    begin: '[a-z].*->'
  };
  return {
    aliases: ['tao'],
    lexemes: /[a-zA-Z][a-zA-Z0-9_?]*/,
    keywords: XL_KEYWORDS,
    contains: [
    hljs.C_LINE_COMMENT_MODE,
    hljs.C_BLOCK_COMMENT_MODE,
    DOUBLE_QUOTE_TEXT,
    SINGLE_QUOTE_TEXT,
    LONG_TEXT,
    FUNCTION_DEFINITION,
    IMPORT,
    XL_CONSTANT,
    XL_VARIABLE,
    XL_ID,
    BASED_NUMBER,
    hljs.NUMBER_MODE
    ]
  };
});

hljs.registerLanguage('xquery', function(hljs) {
  var KEYWORDS = 'for let if while then else return where group by xquery encoding version' +
    'module namespace boundary-space preserve strip default collation base-uri ordering' +
    'copy-namespaces order declare import schema namespace function option in allowing empty' +
    'at tumbling window sliding window start when only end when previous next stable ascending' +
    'descending empty greatest least some every satisfies switch case typeswitch try catch and' +
    'or to union intersect instance of treat as castable cast map array delete insert into' +
    'replace value rename copy modify update';
  var LITERAL = 'false true xs:string xs:integer element item xs:date xs:datetime xs:float xs:double xs:decimal QName xs:anyURI xs:long xs:int xs:short xs:byte attribute';
  var VAR = {
    className: 'variable',
    begin: /\$[a-zA-Z0-9\-]+/,
    relevance: 5
  };

  var NUMBER = {
    className: 'number',
    begin: '(\\b0[0-7_]+)|(\\b0x[0-9a-fA-F_]+)|(\\b[1-9][0-9_]*(\\.[0-9_]+)?)|[0_]\\b',
    relevance: 0
  };

  var STRING = {
    className: 'string',
    variants: [
      {begin: /"/, end: /"/, contains: [{begin: /""/, relevance: 0}]},
      {begin: /'/, end: /'/, contains: [{begin: /''/, relevance: 0}]}
    ]
  };

  var ANNOTATION = {
    className: 'decorator',
    begin: '%\\w+'
  };

  var COMMENT = {
    className: 'comment',
    begin: '\\(:', end: ':\\)',
    relevance: 10,
    contains: [
      {
        className: 'doc', begin: '@\\w+'
      }
    ]
  };

  var METHOD = {
    begin: '{', end: '}'
  };

  var CONTAINS = [
    VAR,
    STRING,
    NUMBER,
    COMMENT,
    ANNOTATION,
    METHOD
  ];
  METHOD.contains = CONTAINS;


  return {
    aliases: ['xpath', 'xq'],
    case_insensitive: false,
    lexemes: /[a-zA-Z\$][a-zA-Z0-9_:\-]*/,
    illegal: /(proc)|(abstract)|(extends)|(until)|(#)/,
    keywords: {
      keyword: KEYWORDS,
      literal: LITERAL
    },
    contains: CONTAINS
  };
});

hljs.registerLanguage('zephir', function(hljs) {
  var STRING = {
    className: 'string',
    contains: [hljs.BACKSLASH_ESCAPE],
    variants: [
      {
        begin: 'b"', end: '"'
      },
      {
        begin: 'b\'', end: '\''
      },
      hljs.inherit(hljs.APOS_STRING_MODE, {illegal: null}),
      hljs.inherit(hljs.QUOTE_STRING_MODE, {illegal: null})
    ]
  };
  var NUMBER = {variants: [hljs.BINARY_NUMBER_MODE, hljs.C_NUMBER_MODE]};
  return {
    aliases: ['zep'],
    case_insensitive: true,
    keywords:
    'and include_once list abstract global private echo interface as static endswitch ' +
    'array null if endwhile or const for endforeach self var let while isset public ' +
    'protected exit foreach throw elseif include __FILE__ empty require_once do xor ' +
    'return parent clone use __CLASS__ __LINE__ else break print eval new ' +
    'catch __METHOD__ case exception default die require __FUNCTION__ ' +
    'enddeclare final try switch continue endfor endif declare unset true false ' +
    'trait goto instanceof insteadof __DIR__ __NAMESPACE__ ' +
    'yield finally int uint long ulong char uchar double float bool boolean string' +
    'likely unlikely',
    contains: [
      hljs.C_LINE_COMMENT_MODE,
      hljs.HASH_COMMENT_MODE,
      hljs.COMMENT(
        '/\\*',
        '\\*/',
        {
          contains: [
            {
              className: 'doctag',
              begin: '@[A-Za-z]+'
            }
          ]
        }
      ),
      hljs.COMMENT(
        '__halt_compiler.+?;',
        false,
        {
          endsWithParent: true,
          keywords: '__halt_compiler',
          lexemes: hljs.UNDERSCORE_IDENT_RE
        }
      ),
      {
        className: 'string',
        begin: '<<<[\'"]?\\w+[\'"]?$', end: '^\\w+;',
        contains: [hljs.BACKSLASH_ESCAPE]
      },
      {
        // swallow composed identifiers to avoid parsing them as keywords
        begin: /(::|->)+[a-zA-Z_\x7f-\xff][a-zA-Z0-9_\x7f-\xff]*/
      },
      {
        className: 'function',
        beginKeywords: 'function', end: /[;{]/, excludeEnd: true,
        illegal: '\\$|\\[|%',
        contains: [
          hljs.UNDERSCORE_TITLE_MODE,
          {
            className: 'params',
            begin: '\\(', end: '\\)',
            contains: [
              'self',
              hljs.C_BLOCK_COMMENT_MODE,
              STRING,
              NUMBER
            ]
          }
        ]
      },
      {
        className: 'class',
        beginKeywords: 'class interface', end: '{', excludeEnd: true,
        illegal: /[:\(\$"]/,
        contains: [
          {beginKeywords: 'extends implements'},
          hljs.UNDERSCORE_TITLE_MODE
        ]
      },
      {
        beginKeywords: 'namespace', end: ';',
        illegal: /[\.']/,
        contains: [hljs.UNDERSCORE_TITLE_MODE]
      },
      {
        beginKeywords: 'use', end: ';',
        contains: [hljs.UNDERSCORE_TITLE_MODE]
      },
      {
        begin: '=>' // No markup, just a relevance booster
      },
      STRING,
      NUMBER
    ]
  };
});

  return hljs;
}));

/**
* vkBeautify - javascript plugin to pretty-print or minify text in XML, JSON, CSS and SQL formats.
*  
* Version - 0.99.00.beta 
* Copyright (c) 2012 Vadim Kiryukhin
* vkiryukhin @ gmail.com
* http://www.eslinstructor.net/vkbeautify/
* 
* Dual licensed under the MIT and GPL licenses:
*   http://www.opensource.org/licenses/mit-license.php
*   http://www.gnu.org/licenses/gpl.html
*
*   Pretty print
*
*        vkbeautify.xml(text [,indent_pattern]);
*        vkbeautify.json(text [,indent_pattern]);
*        vkbeautify.css(text [,indent_pattern]);
*        vkbeautify.sql(text [,indent_pattern]);
*
*        @text - String; text to beatufy;
*        @indent_pattern - Integer | String;
*                Integer:  number of white spaces;
*                String:   character string to visualize indentation ( can also be a set of white spaces )
*   Minify
*
*        vkbeautify.xmlmin(text [,preserve_comments]);
*        vkbeautify.jsonmin(text);
*        vkbeautify.cssmin(text [,preserve_comments]);
*        vkbeautify.sqlmin(text);
*
*        @text - String; text to minify;
*        @preserve_comments - Bool; [optional];
*                Set this flag to true to prevent removing comments from @text ( minxml and mincss functions only. )
*
*   Examples:
*        vkbeautify.xml(text); // pretty print XML
*        vkbeautify.json(text, 4 ); // pretty print JSON
*        vkbeautify.css(text, '. . . .'); // pretty print CSS
*        vkbeautify.sql(text, '----'); // pretty print SQL
*
*        vkbeautify.xmlmin(text, true);// minify XML, preserve comments
*        vkbeautify.jsonmin(text);// minify JSON
*        vkbeautify.cssmin(text);// minify CSS, remove comments ( default )
*        vkbeautify.sqlmin(text);// minify SQL
*
*/

(function() {

function createShiftArr(step) {

	var space = '    ';
	
	if ( isNaN(parseInt(step)) ) {  // argument is string
		space = step;
	} else { // argument is integer
		switch(step) {
			case 1: space = ' '; break;
			case 2: space = '  '; break;
			case 3: space = '   '; break;
			case 4: space = '    '; break;
			case 5: space = '     '; break;
			case 6: space = '      '; break;
			case 7: space = '       '; break;
			case 8: space = '        '; break;
			case 9: space = '         '; break;
			case 10: space = '          '; break;
			case 11: space = '           '; break;
			case 12: space = '            '; break;
		}
	}

	var shift = ['\n']; // array of shifts
	for(ix=0;ix<100;ix++){
		shift.push(shift[ix]+space); 
	}
	return shift;
}

function vkbeautify(){
	this.step = '    '; // 4 spaces
	this.shift = createShiftArr(this.step);
};

vkbeautify.prototype.xml = function(text,step) {

	var ar = text.replace(/>\s{0,}</g,"><")
				 .replace(/</g,"~::~<")
				 .replace(/\s*xmlns\:/g,"~::~xmlns:")
				 .replace(/\s*xmlns\=/g,"~::~xmlns=")
				 .split('~::~'),
		len = ar.length,
		inComment = false,
		deep = 0,
		str = '',
		ix = 0,
		shift = step ? createShiftArr(step) : this.shift;

		for(ix=0;ix<len;ix++) {
			// start comment or <![CDATA[...]]> or <!DOCTYPE //
			if(ar[ix].search(/<!/) > -1) { 
				str += shift[deep]+ar[ix];
				inComment = true; 
				// end comment  or <![CDATA[...]]> //
				if(ar[ix].search(/-->/) > -1 || ar[ix].search(/\]>/) > -1 || ar[ix].search(/!DOCTYPE/) > -1 ) { 
					inComment = false; 
				}
			} else 
			// end comment  or <![CDATA[...]]> //
			if(ar[ix].search(/-->/) > -1 || ar[ix].search(/\]>/) > -1) { 
				str += ar[ix];
				inComment = false; 
			} else 
			// <elm></elm> //
			if( /^<\w/.exec(ar[ix-1]) && /^<\/\w/.exec(ar[ix]) &&
				/^<[\w:\-\.\,]+/.exec(ar[ix-1]) == /^<\/[\w:\-\.\,]+/.exec(ar[ix])[0].replace('/','')) { 
				str += ar[ix];
				if(!inComment) deep--;
			} else
			 // <elm> //
			if(ar[ix].search(/<\w/) > -1 && ar[ix].search(/<\//) == -1 && ar[ix].search(/\/>/) == -1 ) {
				str = !inComment ? str += shift[deep++]+ar[ix] : str += ar[ix];
			} else 
			 // <elm>...</elm> //
			if(ar[ix].search(/<\w/) > -1 && ar[ix].search(/<\//) > -1) {
				str = !inComment ? str += shift[deep]+ar[ix] : str += ar[ix];
			} else 
			// </elm> //
			if(ar[ix].search(/<\//) > -1) { 
				str = !inComment ? str += shift[--deep]+ar[ix] : str += ar[ix];
			} else 
			// <elm/> //
			if(ar[ix].search(/\/>/) > -1 ) { 
				str = !inComment ? str += shift[deep]+ar[ix] : str += ar[ix];
			} else 
			// <? xml ... ?> //
			if(ar[ix].search(/<\?/) > -1) { 
				str += shift[deep]+ar[ix];
			} else 
			// xmlns //
			if( ar[ix].search(/xmlns\:/) > -1  || ar[ix].search(/xmlns\=/) > -1) { 
				str += shift[deep]+ar[ix];
			} 
			
			else {
				str += ar[ix];
			}
		}
		
	return  (str[0] == '\n') ? str.slice(1) : str;
}

vkbeautify.prototype.json = function(text,step) {

	var step = step ? step : this.step;
	
	if (typeof JSON === 'undefined' ) return text; 
	
	if ( typeof text === "string" ) return JSON.stringify(JSON.parse(text), null, step);
	if ( typeof text === "object" ) return JSON.stringify(text, null, step);
		
	return text; // text is not string nor object
}

vkbeautify.prototype.css = function(text, step) {

	var ar = text.replace(/\s{1,}/g,' ')
				.replace(/\{/g,"{~::~")
				.replace(/\}/g,"~::~}~::~")
				.replace(/\;/g,";~::~")
				.replace(/\/\*/g,"~::~/*")
				.replace(/\*\//g,"*/~::~")
				.replace(/~::~\s{0,}~::~/g,"~::~")
				.split('~::~'),
		len = ar.length,
		deep = 0,
		str = '',
		ix = 0,
		shift = step ? createShiftArr(step) : this.shift;
		
		for(ix=0;ix<len;ix++) {

			if( /\{/.exec(ar[ix]))  { 
				str += shift[deep++]+ar[ix];
			} else 
			if( /\}/.exec(ar[ix]))  { 
				str += shift[--deep]+ar[ix];
			} else
			if( /\*\\/.exec(ar[ix]))  { 
				str += shift[deep]+ar[ix];
			}
			else {
				str += shift[deep]+ar[ix];
			}
		}
		return str.replace(/^\n{1,}/,'');
}

//----------------------------------------------------------------------------

function isSubquery(str, parenthesisLevel) {
	return  parenthesisLevel - (str.replace(/\(/g,'').length - str.replace(/\)/g,'').length )
}

function split_sql(str, tab) {

	return str.replace(/\s{1,}/g," ")

				.replace(/ AND /ig,"~::~"+tab+tab+"AND ")
				.replace(/ BETWEEN /ig,"~::~"+tab+"BETWEEN ")
				.replace(/ CASE /ig,"~::~"+tab+"CASE ")
				.replace(/ ELSE /ig,"~::~"+tab+"ELSE ")
				.replace(/ END /ig,"~::~"+tab+"END ")
				.replace(/ FROM /ig,"~::~FROM ")
				.replace(/ GROUP\s{1,}BY/ig,"~::~GROUP BY ")
				.replace(/ HAVING /ig,"~::~HAVING ")
				//.replace(/ SET /ig," SET~::~")
				.replace(/ IN /ig," IN ")
				
				.replace(/ JOIN /ig,"~::~JOIN ")
				.replace(/ CROSS~::~{1,}JOIN /ig,"~::~CROSS JOIN ")
				.replace(/ INNER~::~{1,}JOIN /ig,"~::~INNER JOIN ")
				.replace(/ LEFT~::~{1,}JOIN /ig,"~::~LEFT JOIN ")
				.replace(/ RIGHT~::~{1,}JOIN /ig,"~::~RIGHT JOIN ")
				
				.replace(/ ON /ig,"~::~"+tab+"ON ")
				.replace(/ OR /ig,"~::~"+tab+tab+"OR ")
				.replace(/ ORDER\s{1,}BY/ig,"~::~ORDER BY ")
				.replace(/ OVER /ig,"~::~"+tab+"OVER ")

				.replace(/\(\s{0,}SELECT /ig,"~::~(SELECT ")
				.replace(/\)\s{0,}SELECT /ig,")~::~SELECT ")
				
				.replace(/ THEN /ig," THEN~::~"+tab+"")
				.replace(/ UNION /ig,"~::~UNION~::~")
				.replace(/ USING /ig,"~::~USING ")
				.replace(/ WHEN /ig,"~::~"+tab+"WHEN ")
				.replace(/ WHERE /ig,"~::~WHERE ")
				.replace(/ WITH /ig,"~::~WITH ")
				
				//.replace(/\,\s{0,}\(/ig,",~::~( ")
				//.replace(/\,/ig,",~::~"+tab+tab+"")

				.replace(/ ALL /ig," ALL ")
				.replace(/ AS /ig," AS ")
				.replace(/ ASC /ig," ASC ")	
				.replace(/ DESC /ig," DESC ")	
				.replace(/ DISTINCT /ig," DISTINCT ")
				.replace(/ EXISTS /ig," EXISTS ")
				.replace(/ NOT /ig," NOT ")
				.replace(/ NULL /ig," NULL ")
				.replace(/ LIKE /ig," LIKE ")
				.replace(/\s{0,}SELECT /ig,"SELECT ")
				.replace(/\s{0,}UPDATE /ig,"UPDATE ")
				.replace(/ SET /ig," SET ")
							
				.replace(/~::~{1,}/g,"~::~")
				.split('~::~');
}

vkbeautify.prototype.sql = function(text,step) {

	var ar_by_quote = text.replace(/\s{1,}/g," ")
							.replace(/\'/ig,"~::~\'")
							.split('~::~'),
		len = ar_by_quote.length,
		ar = [],
		deep = 0,
		tab = this.step,//+this.step,
		inComment = true,
		inQuote = false,
		parenthesisLevel = 0,
		str = '',
		ix = 0,
		shift = step ? createShiftArr(step) : this.shift;;

		for(ix=0;ix<len;ix++) {
			if(ix%2) {
				ar = ar.concat(ar_by_quote[ix]);
			} else {
				ar = ar.concat(split_sql(ar_by_quote[ix], tab) );
			}
		}
		
		len = ar.length;
		for(ix=0;ix<len;ix++) {
			
			parenthesisLevel = isSubquery(ar[ix], parenthesisLevel);
			
			if( /\s{0,}\s{0,}SELECT\s{0,}/.exec(ar[ix]))  { 
				ar[ix] = ar[ix].replace(/\,/g,",\n"+tab+tab+"")
			} 
			
			if( /\s{0,}\s{0,}SET\s{0,}/.exec(ar[ix]))  { 
				ar[ix] = ar[ix].replace(/\,/g,",\n"+tab+tab+"")
			} 
			
			if( /\s{0,}\(\s{0,}SELECT\s{0,}/.exec(ar[ix]))  { 
				deep++;
				str += shift[deep]+ar[ix];
			} else 
			if( /\'/.exec(ar[ix]) )  { 
				if(parenthesisLevel<1 && deep) {
					deep--;
				}
				str += ar[ix];
			}
			else  { 
				str += shift[deep]+ar[ix];
				if(parenthesisLevel<1 && deep) {
					deep--;
				}
			} 
			var junk = 0;
		}

		str = str.replace(/^\n{1,}/,'').replace(/\n{1,}/g,"\n");
		return str;
}


vkbeautify.prototype.xmlmin = function(text, preserveComments) {

	var str = preserveComments ? text
							   : text.replace(/\<![ \r\n\t]*(--([^\-]|[\r\n]|-[^\-])*--[ \r\n\t]*)\>/g,"")
									 .replace(/[ \r\n\t]{1,}xmlns/g, ' xmlns');
	return  str.replace(/>\s{0,}</g,"><"); 
}

vkbeautify.prototype.jsonmin = function(text) {

	if (typeof JSON === 'undefined' ) return text; 
	
	return JSON.stringify(JSON.parse(text), null, 0); 
				
}

vkbeautify.prototype.cssmin = function(text, preserveComments) {
	
	var str = preserveComments ? text
							   : text.replace(/\/\*([^*]|[\r\n]|(\*+([^*/]|[\r\n])))*\*+\//g,"") ;

	return str.replace(/\s{1,}/g,' ')
			  .replace(/\{\s{1,}/g,"{")
			  .replace(/\}\s{1,}/g,"}")
			  .replace(/\;\s{1,}/g,";")
			  .replace(/\/\*\s{1,}/g,"/*")
			  .replace(/\*\/\s{1,}/g,"*/");
}

vkbeautify.prototype.sqlmin = function(text) {
	return text.replace(/\s{1,}/g," ").replace(/\s{1,}\(/,"(").replace(/\s{1,}\)/,")");
}

window.vkbeautify = new vkbeautify();

})();


/*
CryptoJS v3.1.2
code.google.com/p/crypto-js
(c) 2009-2013 by Jeff Mott. All rights reserved.
code.google.com/p/crypto-js/wiki/License
*/
var CryptoJS=CryptoJS||function(g,l){var e={},d=e.lib={},m=function(){},k=d.Base={extend:function(a){m.prototype=this;var c=new m;a&&c.mixIn(a);c.hasOwnProperty("init")||(c.init=function(){c.$super.init.apply(this,arguments)});c.init.prototype=c;c.$super=this;return c},create:function(){var a=this.extend();a.init.apply(a,arguments);return a},init:function(){},mixIn:function(a){for(var c in a)a.hasOwnProperty(c)&&(this[c]=a[c]);a.hasOwnProperty("toString")&&(this.toString=a.toString)},clone:function(){return this.init.prototype.extend(this)}},
p=d.WordArray=k.extend({init:function(a,c){a=this.words=a||[];this.sigBytes=c!=l?c:4*a.length},toString:function(a){return(a||n).stringify(this)},concat:function(a){var c=this.words,q=a.words,f=this.sigBytes;a=a.sigBytes;this.clamp();if(f%4)for(var b=0;b<a;b++)c[f+b>>>2]|=(q[b>>>2]>>>24-8*(b%4)&255)<<24-8*((f+b)%4);else if(65535<q.length)for(b=0;b<a;b+=4)c[f+b>>>2]=q[b>>>2];else c.push.apply(c,q);this.sigBytes+=a;return this},clamp:function(){var a=this.words,c=this.sigBytes;a[c>>>2]&=4294967295<<
32-8*(c%4);a.length=g.ceil(c/4)},clone:function(){var a=k.clone.call(this);a.words=this.words.slice(0);return a},random:function(a){for(var c=[],b=0;b<a;b+=4)c.push(4294967296*g.random()|0);return new p.init(c,a)}}),b=e.enc={},n=b.Hex={stringify:function(a){var c=a.words;a=a.sigBytes;for(var b=[],f=0;f<a;f++){var d=c[f>>>2]>>>24-8*(f%4)&255;b.push((d>>>4).toString(16));b.push((d&15).toString(16))}return b.join("")},parse:function(a){for(var c=a.length,b=[],f=0;f<c;f+=2)b[f>>>3]|=parseInt(a.substr(f,
2),16)<<24-4*(f%8);return new p.init(b,c/2)}},j=b.Latin1={stringify:function(a){var c=a.words;a=a.sigBytes;for(var b=[],f=0;f<a;f++)b.push(String.fromCharCode(c[f>>>2]>>>24-8*(f%4)&255));return b.join("")},parse:function(a){for(var c=a.length,b=[],f=0;f<c;f++)b[f>>>2]|=(a.charCodeAt(f)&255)<<24-8*(f%4);return new p.init(b,c)}},h=b.Utf8={stringify:function(a){try{return decodeURIComponent(escape(j.stringify(a)))}catch(c){throw Error("Malformed UTF-8 data");}},parse:function(a){return j.parse(unescape(encodeURIComponent(a)))}},
r=d.BufferedBlockAlgorithm=k.extend({reset:function(){this._data=new p.init;this._nDataBytes=0},_append:function(a){"string"==typeof a&&(a=h.parse(a));this._data.concat(a);this._nDataBytes+=a.sigBytes},_process:function(a){var c=this._data,b=c.words,f=c.sigBytes,d=this.blockSize,e=f/(4*d),e=a?g.ceil(e):g.max((e|0)-this._minBufferSize,0);a=e*d;f=g.min(4*a,f);if(a){for(var k=0;k<a;k+=d)this._doProcessBlock(b,k);k=b.splice(0,a);c.sigBytes-=f}return new p.init(k,f)},clone:function(){var a=k.clone.call(this);
a._data=this._data.clone();return a},_minBufferSize:0});d.Hasher=r.extend({cfg:k.extend(),init:function(a){this.cfg=this.cfg.extend(a);this.reset()},reset:function(){r.reset.call(this);this._doReset()},update:function(a){this._append(a);this._process();return this},finalize:function(a){a&&this._append(a);return this._doFinalize()},blockSize:16,_createHelper:function(a){return function(b,d){return(new a.init(d)).finalize(b)}},_createHmacHelper:function(a){return function(b,d){return(new s.HMAC.init(a,
d)).finalize(b)}}});var s=e.algo={};return e}(Math);
(function(){var g=CryptoJS,l=g.lib,e=l.WordArray,d=l.Hasher,m=[],l=g.algo.SHA1=d.extend({_doReset:function(){this._hash=new e.init([1732584193,4023233417,2562383102,271733878,3285377520])},_doProcessBlock:function(d,e){for(var b=this._hash.words,n=b[0],j=b[1],h=b[2],g=b[3],l=b[4],a=0;80>a;a++){if(16>a)m[a]=d[e+a]|0;else{var c=m[a-3]^m[a-8]^m[a-14]^m[a-16];m[a]=c<<1|c>>>31}c=(n<<5|n>>>27)+l+m[a];c=20>a?c+((j&h|~j&g)+1518500249):40>a?c+((j^h^g)+1859775393):60>a?c+((j&h|j&g|h&g)-1894007588):c+((j^h^
g)-899497514);l=g;g=h;h=j<<30|j>>>2;j=n;n=c}b[0]=b[0]+n|0;b[1]=b[1]+j|0;b[2]=b[2]+h|0;b[3]=b[3]+g|0;b[4]=b[4]+l|0},_doFinalize:function(){var d=this._data,e=d.words,b=8*this._nDataBytes,g=8*d.sigBytes;e[g>>>5]|=128<<24-g%32;e[(g+64>>>9<<4)+14]=Math.floor(b/4294967296);e[(g+64>>>9<<4)+15]=b;d.sigBytes=4*e.length;this._process();return this._hash},clone:function(){var e=d.clone.call(this);e._hash=this._hash.clone();return e}});g.SHA1=d._createHelper(l);g.HmacSHA1=d._createHmacHelper(l)})();
(function(){var g=CryptoJS,l=g.enc.Utf8;g.algo.HMAC=g.lib.Base.extend({init:function(e,d){e=this._hasher=new e.init;"string"==typeof d&&(d=l.parse(d));var g=e.blockSize,k=4*g;d.sigBytes>k&&(d=e.finalize(d));d.clamp();for(var p=this._oKey=d.clone(),b=this._iKey=d.clone(),n=p.words,j=b.words,h=0;h<g;h++)n[h]^=1549556828,j[h]^=909522486;p.sigBytes=b.sigBytes=k;this.reset()},reset:function(){var e=this._hasher;e.reset();e.update(this._iKey)},update:function(e){this._hasher.update(e);return this},finalize:function(e){var d=
this._hasher;e=d.finalize(e);d.reset();return d.finalize(this._oKey.clone().concat(e))}})})();

/*
CryptoJS v3.1.2
code.google.com/p/crypto-js
(c) 2009-2013 by Jeff Mott. All rights reserved.
code.google.com/p/crypto-js/wiki/License
*/
(function () {
    // Shortcuts
    var C = CryptoJS;
    var C_lib = C.lib;
    var WordArray = C_lib.WordArray;
    var C_enc = C.enc;

    /**
     * Base64 encoding strategy.
     */
    var Base64 = C_enc.Base64 = {
        /**
         * Converts a word array to a Base64 string.
         *
         * @param {WordArray} wordArray The word array.
         *
         * @return {string} The Base64 string.
         *
         * @static
         *
         * @example
         *
         *     var base64String = CryptoJS.enc.Base64.stringify(wordArray);
         */
        stringify: function (wordArray) {
            // Shortcuts
            var words = wordArray.words;
            var sigBytes = wordArray.sigBytes;
            var map = this._map;

            // Clamp excess bits
            wordArray.clamp();

            // Convert
            var base64Chars = [];
            for (var i = 0; i < sigBytes; i += 3) {
                var byte1 = (words[i >>> 2]       >>> (24 - (i % 4) * 8))       & 0xff;
                var byte2 = (words[(i + 1) >>> 2] >>> (24 - ((i + 1) % 4) * 8)) & 0xff;
                var byte3 = (words[(i + 2) >>> 2] >>> (24 - ((i + 2) % 4) * 8)) & 0xff;

                var triplet = (byte1 << 16) | (byte2 << 8) | byte3;

                for (var j = 0; (j < 4) && (i + j * 0.75 < sigBytes); j++) {
                    base64Chars.push(map.charAt((triplet >>> (6 * (3 - j))) & 0x3f));
                }
            }

            // Add padding
            var paddingChar = map.charAt(64);
            if (paddingChar) {
                while (base64Chars.length % 4) {
                    base64Chars.push(paddingChar);
                }
            }

            return base64Chars.join('');
        },

        /**
         * Converts a Base64 string to a word array.
         *
         * @param {string} base64Str The Base64 string.
         *
         * @return {WordArray} The word array.
         *
         * @static
         *
         * @example
         *
         *     var wordArray = CryptoJS.enc.Base64.parse(base64String);
         */
        parse: function (base64Str) {
            // Shortcuts
            var base64StrLength = base64Str.length;
            var map = this._map;

            // Ignore padding
            var paddingChar = map.charAt(64);
            if (paddingChar) {
                var paddingIndex = base64Str.indexOf(paddingChar);
                if (paddingIndex != -1) {
                    base64StrLength = paddingIndex;
                }
            }

            // Convert
            var words = [];
            var nBytes = 0;
            for (var i = 0; i < base64StrLength; i++) {
                if (i % 4) {
                    var bits1 = map.indexOf(base64Str.charAt(i - 1)) << ((i % 4) * 2);
                    var bits2 = map.indexOf(base64Str.charAt(i)) >>> (6 - (i % 4) * 2);
                    words[nBytes >>> 2] |= (bits1 | bits2) << (24 - (nBytes % 4) * 8);
                    nBytes++;
                }
            }

            return WordArray.create(words, nBytes);
        },

        _map: 'ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/='
    };
}());

// CodeMirror is the only global var we claim
window.CodeMirror = (function() {
  "use strict";

  // BROWSER SNIFFING

  // Crude, but necessary to handle a number of hard-to-feature-detect
  // bugs and behavior differences.
  var gecko = /gecko\/\d/i.test(navigator.userAgent);
  var ie = /MSIE \d/.test(navigator.userAgent);
  var ie_lt8 = ie && (document.documentMode == null || document.documentMode < 8);
  var ie_lt9 = ie && (document.documentMode == null || document.documentMode < 9);
  var webkit = /WebKit\//.test(navigator.userAgent);
  var qtwebkit = webkit && /Qt\/\d+\.\d+/.test(navigator.userAgent);
  var chrome = /Chrome\//.test(navigator.userAgent);
  var opera = /Opera\//.test(navigator.userAgent);
  var safari = /Apple Computer/.test(navigator.vendor);
  var khtml = /KHTML\//.test(navigator.userAgent);
  var mac_geLion = /Mac OS X 1\d\D([7-9]|\d\d)\D/.test(navigator.userAgent);
  var mac_geMountainLion = /Mac OS X 1\d\D([8-9]|\d\d)\D/.test(navigator.userAgent);
  var phantom = /PhantomJS/.test(navigator.userAgent);

  var ios = /AppleWebKit/.test(navigator.userAgent) && /Mobile\/\w+/.test(navigator.userAgent);
  // This is woefully incomplete. Suggestions for alternative methods welcome.
  var mobile = ios || /Android|webOS|BlackBerry|Opera Mini|Opera Mobi|IEMobile/i.test(navigator.userAgent);
  var mac = ios || /Mac/.test(navigator.platform);
  var windows = /windows/i.test(navigator.platform);

  var opera_version = opera && navigator.userAgent.match(/Version\/(\d*\.\d*)/);
  if (opera_version) opera_version = Number(opera_version[1]);
  if (opera_version && opera_version >= 15) { opera = false; webkit = true; }
  // Some browsers use the wrong event properties to signal cmd/ctrl on OS X
  var flipCtrlCmd = mac && (qtwebkit || opera && (opera_version == null || opera_version < 12.11));
  var captureMiddleClick = gecko || (ie && !ie_lt9);

  // Optimize some code when these features are not used
  var sawReadOnlySpans = false, sawCollapsedSpans = false;

  // CONSTRUCTOR

  function CodeMirror(place, options) {
    if (!(this instanceof CodeMirror)) return new CodeMirror(place, options);

    this.options = options = options || {};
    // Determine effective options based on given values and defaults.
    for (var opt in defaults) if (!options.hasOwnProperty(opt) && defaults.hasOwnProperty(opt))
      options[opt] = defaults[opt];
    setGuttersForLineNumbers(options);

    var docStart = typeof options.value == "string" ? 0 : options.value.first;
    var display = this.display = makeDisplay(place, docStart);
    display.wrapper.CodeMirror = this;
    updateGutters(this);
    if (options.autofocus && !mobile) focusInput(this);

    this.state = {keyMaps: [],
                  overlays: [],
                  modeGen: 0,
                  overwrite: false, focused: false,
                  suppressEdits: false, pasteIncoming: false,
                  draggingText: false,
                  highlight: new Delayed()};

    themeChanged(this);
    if (options.lineWrapping)
      this.display.wrapper.className += " CodeMirror-wrap";

    var doc = options.value;
    if (typeof doc == "string") doc = new Doc(options.value, options.mode);
    operation(this, attachDoc)(this, doc);

    // Override magic textarea content restore that IE sometimes does
    // on our hidden textarea on reload
    if (ie) setTimeout(bind(resetInput, this, true), 20);

    registerEventHandlers(this);
    // IE throws unspecified error in certain cases, when
    // trying to access activeElement before onload
    var hasFocus; try { hasFocus = (document.activeElement == display.input); } catch(e) { }
    if (hasFocus || (options.autofocus && !mobile)) setTimeout(bind(onFocus, this), 20);
    else onBlur(this);

    operation(this, function() {
      for (var opt in optionHandlers)
        if (optionHandlers.propertyIsEnumerable(opt))
          optionHandlers[opt](this, options[opt], Init);
      for (var i = 0; i < initHooks.length; ++i) initHooks[i](this);
    })();
  }

  // DISPLAY CONSTRUCTOR

  function makeDisplay(place, docStart) {
    var d = {};

    var input = d.input = elt("textarea", null, null, "position: absolute; padding: 0; width: 1px; height: 1em; outline: none; font-size: 4px;");
    if (webkit) input.style.width = "1000px";
    else input.setAttribute("wrap", "off");
    // if border: 0; -- iOS fails to open keyboard (issue #1287)
    if (ios) input.style.border = "1px solid black";
    input.setAttribute("autocorrect", "off"); input.setAttribute("autocapitalize", "off"); input.setAttribute("spellcheck", "false");

    // Wraps and hides input textarea
    d.inputDiv = elt("div", [input], null, "overflow: hidden; position: relative; width: 3px; height: 0px;");
    // The actual fake scrollbars.
    d.scrollbarH = elt("div", [elt("div", null, null, "height: 1px")], "CodeMirror-hscrollbar");
    d.scrollbarV = elt("div", [elt("div", null, null, "width: 1px")], "CodeMirror-vscrollbar");
    d.scrollbarFiller = elt("div", null, "CodeMirror-scrollbar-filler");
    d.gutterFiller = elt("div", null, "CodeMirror-gutter-filler");
    // DIVs containing the selection and the actual code
    d.lineDiv = elt("div", null, "CodeMirror-code");
    d.selectionDiv = elt("div", null, null, "position: relative; z-index: 1");
    // Blinky cursor, and element used to ensure cursor fits at the end of a line
    d.cursor = elt("div", "\u00a0", "CodeMirror-cursor");
    // Secondary cursor, shown when on a 'jump' in bi-directional text
    d.otherCursor = elt("div", "\u00a0", "CodeMirror-cursor CodeMirror-secondarycursor");
    // Used to measure text size
    d.measure = elt("div", null, "CodeMirror-measure");
    // Wraps everything that needs to exist inside the vertically-padded coordinate system
    d.lineSpace = elt("div", [d.measure, d.selectionDiv, d.lineDiv, d.cursor, d.otherCursor],
                         null, "position: relative; outline: none");
    // Moved around its parent to cover visible view
    d.mover = elt("div", [elt("div", [d.lineSpace], "CodeMirror-lines")], null, "position: relative");
    // Set to the height of the text, causes scrolling
    d.sizer = elt("div", [d.mover], "CodeMirror-sizer");
    // D is needed because behavior of elts with overflow: auto and padding is inconsistent across browsers
    d.heightForcer = elt("div", null, null, "position: absolute; height: " + scrollerCutOff + "px; width: 1px;");
    // Will contain the gutters, if any
    d.gutters = elt("div", null, "CodeMirror-gutters");
    d.lineGutter = null;
    // Provides scrolling
    d.scroller = elt("div", [d.sizer, d.heightForcer, d.gutters], "CodeMirror-scroll");
    d.scroller.setAttribute("tabIndex", "-1");
    // The element in which the editor lives.
    d.wrapper = elt("div", [d.inputDiv, d.scrollbarH, d.scrollbarV,
                            d.scrollbarFiller, d.gutterFiller, d.scroller], "CodeMirror");
    // Work around IE7 z-index bug
    if (ie_lt8) { d.gutters.style.zIndex = -1; d.scroller.style.paddingRight = 0; }
    if (place.appendChild) place.appendChild(d.wrapper); else place(d.wrapper);

    // Needed to hide big blue blinking cursor on Mobile Safari
    if (ios) input.style.width = "0px";
    if (!webkit) d.scroller.draggable = true;
    // Needed to handle Tab key in KHTML
    if (khtml) { d.inputDiv.style.height = "1px"; d.inputDiv.style.position = "absolute"; }
    // Need to set a minimum width to see the scrollbar on IE7 (but must not set it on IE8).
    else if (ie_lt8) d.scrollbarH.style.minWidth = d.scrollbarV.style.minWidth = "18px";

    // Current visible range (may be bigger than the view window).
    d.viewOffset = d.lastSizeC = 0;
    d.showingFrom = d.showingTo = docStart;

    // Used to only resize the line number gutter when necessary (when
    // the amount of lines crosses a boundary that makes its width change)
    d.lineNumWidth = d.lineNumInnerWidth = d.lineNumChars = null;
    // See readInput and resetInput
    d.prevInput = "";
    // Set to true when a non-horizontal-scrolling widget is added. As
    // an optimization, widget aligning is skipped when d is false.
    d.alignWidgets = false;
    // Flag that indicates whether we currently expect input to appear
    // (after some event like 'keypress' or 'input') and are polling
    // intensively.
    d.pollingFast = false;
    // Self-resetting timeout for the poller
    d.poll = new Delayed();

    d.cachedCharWidth = d.cachedTextHeight = null;
    d.measureLineCache = [];
    d.measureLineCachePos = 0;

    // Tracks when resetInput has punted to just putting a short
    // string instead of the (large) selection.
    d.inaccurateSelection = false;

    // Tracks the maximum line length so that the horizontal scrollbar
    // can be kept static when scrolling.
    d.maxLine = null;
    d.maxLineLength = 0;
    d.maxLineChanged = false;

    // Used for measuring wheel scrolling granularity
    d.wheelDX = d.wheelDY = d.wheelStartX = d.wheelStartY = null;

    return d;
  }

  // STATE UPDATES

  // Used to get the editor into a consistent state again when options change.

  function loadMode(cm) {
    cm.doc.mode = CodeMirror.getMode(cm.options, cm.doc.modeOption);
    cm.doc.iter(function(line) {
      if (line.stateAfter) line.stateAfter = null;
      if (line.styles) line.styles = null;
    });
    cm.doc.frontier = cm.doc.first;
    startWorker(cm, 100);
    cm.state.modeGen++;
    if (cm.curOp) regChange(cm);
  }

  function wrappingChanged(cm) {
    if (cm.options.lineWrapping) {
      cm.display.wrapper.className += " CodeMirror-wrap";
      cm.display.sizer.style.minWidth = "";
    } else {
      cm.display.wrapper.className = cm.display.wrapper.className.replace(" CodeMirror-wrap", "");
      computeMaxLength(cm);
    }
    estimateLineHeights(cm);
    regChange(cm);
    clearCaches(cm);
    setTimeout(function(){updateScrollbars(cm);}, 100);
  }

  function estimateHeight(cm) {
    var th = textHeight(cm.display), wrapping = cm.options.lineWrapping;
    var perLine = wrapping && Math.max(5, cm.display.scroller.clientWidth / charWidth(cm.display) - 3);
    return function(line) {
      if (lineIsHidden(cm.doc, line))
        return 0;
      else if (wrapping)
        return (Math.ceil(line.text.length / perLine) || 1) * th;
      else
        return th;
    };
  }

  function estimateLineHeights(cm) {
    var doc = cm.doc, est = estimateHeight(cm);
    doc.iter(function(line) {
      var estHeight = est(line);
      if (estHeight != line.height) updateLineHeight(line, estHeight);
    });
  }

  function keyMapChanged(cm) {
    var map = keyMap[cm.options.keyMap], style = map.style;
    cm.display.wrapper.className = cm.display.wrapper.className.replace(/\s*cm-keymap-\S+/g, "") +
      (style ? " cm-keymap-" + style : "");
    cm.state.disableInput = map.disableInput;
  }

  function themeChanged(cm) {
    cm.display.wrapper.className = cm.display.wrapper.className.replace(/\s*cm-s-\S+/g, "") +
      cm.options.theme.replace(/(^|\s)\s*/g, " cm-s-");
    clearCaches(cm);
  }

  function guttersChanged(cm) {
    updateGutters(cm);
    regChange(cm);
    setTimeout(function(){alignHorizontally(cm);}, 20);
  }

  function updateGutters(cm) {
    var gutters = cm.display.gutters, specs = cm.options.gutters;
    removeChildren(gutters);
    for (var i = 0; i < specs.length; ++i) {
      var gutterClass = specs[i];
      var gElt = gutters.appendChild(elt("div", null, "CodeMirror-gutter " + gutterClass));
      if (gutterClass == "CodeMirror-linenumbers") {
        cm.display.lineGutter = gElt;
        gElt.style.width = (cm.display.lineNumWidth || 1) + "px";
      }
    }
    gutters.style.display = i ? "" : "none";
  }

  function lineLength(doc, line) {
    if (line.height == 0) return 0;
    var len = line.text.length, merged, cur = line;
    while (merged = collapsedSpanAtStart(cur)) {
      var found = merged.find();
      cur = getLine(doc, found.from.line);
      len += found.from.ch - found.to.ch;
    }
    cur = line;
    while (merged = collapsedSpanAtEnd(cur)) {
      var found = merged.find();
      len -= cur.text.length - found.from.ch;
      cur = getLine(doc, found.to.line);
      len += cur.text.length - found.to.ch;
    }
    return len;
  }

  function computeMaxLength(cm) {
    var d = cm.display, doc = cm.doc;
    d.maxLine = getLine(doc, doc.first);
    d.maxLineLength = lineLength(doc, d.maxLine);
    d.maxLineChanged = true;
    doc.iter(function(line) {
      var len = lineLength(doc, line);
      if (len > d.maxLineLength) {
        d.maxLineLength = len;
        d.maxLine = line;
      }
    });
  }

  // Make sure the gutters options contains the element
  // "CodeMirror-linenumbers" when the lineNumbers option is true.
  function setGuttersForLineNumbers(options) {
    var found = false;
    for (var i = 0; i < options.gutters.length; ++i) {
      if (options.gutters[i] == "CodeMirror-linenumbers") {
        if (options.lineNumbers) found = true;
        else options.gutters.splice(i--, 1);
      }
    }
    if (!found && options.lineNumbers)
      options.gutters.push("CodeMirror-linenumbers");
  }

  // SCROLLBARS

  // Re-synchronize the fake scrollbars with the actual size of the
  // content. Optionally force a scrollTop.
  function updateScrollbars(cm) {
    var d = cm.display, docHeight = cm.doc.height;
    var totalHeight = docHeight + paddingVert(d);
    d.sizer.style.minHeight = d.heightForcer.style.top = totalHeight + "px";
    d.gutters.style.height = Math.max(totalHeight, d.scroller.clientHeight - scrollerCutOff) + "px";
    var scrollHeight = Math.max(totalHeight, d.scroller.scrollHeight);
    var needsH = d.scroller.scrollWidth > (d.scroller.clientWidth + 1);
    var needsV = scrollHeight > (d.scroller.clientHeight + 1);
    if (needsV) {
      d.scrollbarV.style.display = "block";
      d.scrollbarV.style.bottom = needsH ? scrollbarWidth(d.measure) + "px" : "0";
      d.scrollbarV.firstChild.style.height =
        (scrollHeight - d.scroller.clientHeight + d.scrollbarV.clientHeight) + "px";
    } else d.scrollbarV.style.display = "";
    if (needsH) {
      d.scrollbarH.style.display = "block";
      d.scrollbarH.style.right = needsV ? scrollbarWidth(d.measure) + "px" : "0";
      d.scrollbarH.firstChild.style.width =
        (d.scroller.scrollWidth - d.scroller.clientWidth + d.scrollbarH.clientWidth) + "px";
    } else d.scrollbarH.style.display = "";
    if (needsH && needsV) {
      d.scrollbarFiller.style.display = "block";
      d.scrollbarFiller.style.height = d.scrollbarFiller.style.width = scrollbarWidth(d.measure) + "px";
    } else d.scrollbarFiller.style.display = "";
    if (needsH && cm.options.coverGutterNextToScrollbar && cm.options.fixedGutter) {
      d.gutterFiller.style.display = "block";
      d.gutterFiller.style.height = scrollbarWidth(d.measure) + "px";
      d.gutterFiller.style.width = d.gutters.offsetWidth + "px";
    } else d.gutterFiller.style.display = "";

    if (mac_geLion && scrollbarWidth(d.measure) === 0)
      d.scrollbarV.style.minWidth = d.scrollbarH.style.minHeight = mac_geMountainLion ? "18px" : "12px";
  }

  function visibleLines(display, doc, viewPort) {
    var top = display.scroller.scrollTop, height = display.wrapper.clientHeight;
    if (typeof viewPort == "number") top = viewPort;
    else if (viewPort) {top = viewPort.top; height = viewPort.bottom - viewPort.top;}
    top = Math.floor(top - paddingTop(display));
    var bottom = Math.ceil(top + height);
    return {from: lineAtHeight(doc, top), to: lineAtHeight(doc, bottom)};
  }

  // LINE NUMBERS

  function alignHorizontally(cm) {
    var display = cm.display;
    if (!display.alignWidgets && (!display.gutters.firstChild || !cm.options.fixedGutter)) return;
    var comp = compensateForHScroll(display) - display.scroller.scrollLeft + cm.doc.scrollLeft;
    var gutterW = display.gutters.offsetWidth, l = comp + "px";
    for (var n = display.lineDiv.firstChild; n; n = n.nextSibling) if (n.alignable) {
      for (var i = 0, a = n.alignable; i < a.length; ++i) a[i].style.left = l;
    }
    if (cm.options.fixedGutter)
      display.gutters.style.left = (comp + gutterW) + "px";
  }

  function maybeUpdateLineNumberWidth(cm) {
    if (!cm.options.lineNumbers) return false;
    var doc = cm.doc, last = lineNumberFor(cm.options, doc.first + doc.size - 1), display = cm.display;
    if (last.length != display.lineNumChars) {
      var test = display.measure.appendChild(elt("div", [elt("div", last)],
                                                 "CodeMirror-linenumber CodeMirror-gutter-elt"));
      var innerW = test.firstChild.offsetWidth, padding = test.offsetWidth - innerW;
      display.lineGutter.style.width = "";
      display.lineNumInnerWidth = Math.max(innerW, display.lineGutter.offsetWidth - padding);
      display.lineNumWidth = display.lineNumInnerWidth + padding;
      display.lineNumChars = display.lineNumInnerWidth ? last.length : -1;
      display.lineGutter.style.width = display.lineNumWidth + "px";
      return true;
    }
    return false;
  }

  function lineNumberFor(options, i) {
    return String(options.lineNumberFormatter(i + options.firstLineNumber));
  }
  function compensateForHScroll(display) {
    return getRect(display.scroller).left - getRect(display.sizer).left;
  }

  // DISPLAY DRAWING

  function updateDisplay(cm, changes, viewPort, forced) {
    var oldFrom = cm.display.showingFrom, oldTo = cm.display.showingTo, updated;
    var visible = visibleLines(cm.display, cm.doc, viewPort);
    for (;;) {
      if (!updateDisplayInner(cm, changes, visible, forced)) break;
      forced = false;
      updated = true;
      updateSelection(cm);
      updateScrollbars(cm);

      // Clip forced viewport to actual scrollable area
      if (viewPort)
        viewPort = Math.min(cm.display.scroller.scrollHeight - cm.display.scroller.clientHeight,
                            typeof viewPort == "number" ? viewPort : viewPort.top);
      visible = visibleLines(cm.display, cm.doc, viewPort);
      if (visible.from >= cm.display.showingFrom && visible.to <= cm.display.showingTo)
        break;
      changes = [];
    }

    if (updated) {
      signalLater(cm, "update", cm);
      if (cm.display.showingFrom != oldFrom || cm.display.showingTo != oldTo)
        signalLater(cm, "viewportChange", cm, cm.display.showingFrom, cm.display.showingTo);
    }
    return updated;
  }

  // Uses a set of changes plus the current scroll position to
  // determine which DOM updates have to be made, and makes the
  // updates.
  function updateDisplayInner(cm, changes, visible, forced) {
    var display = cm.display, doc = cm.doc;
    if (!display.wrapper.clientWidth) {
      display.showingFrom = display.showingTo = doc.first;
      display.viewOffset = 0;
      return;
    }

    // Bail out if the visible area is already rendered and nothing changed.
    if (!forced && changes.length == 0 &&
        visible.from > display.showingFrom && visible.to < display.showingTo)
      return;

    if (maybeUpdateLineNumberWidth(cm))
      changes = [{from: doc.first, to: doc.first + doc.size}];
    var gutterW = display.sizer.style.marginLeft = display.gutters.offsetWidth + "px";
    display.scrollbarH.style.left = cm.options.fixedGutter ? gutterW : "0";

    // Used to determine which lines need their line numbers updated
    var positionsChangedFrom = Infinity;
    if (cm.options.lineNumbers)
      for (var i = 0; i < changes.length; ++i)
        if (changes[i].diff) { positionsChangedFrom = changes[i].from; break; }

    var end = doc.first + doc.size;
    var from = Math.max(visible.from - cm.options.viewportMargin, doc.first);
    var to = Math.min(end, visible.to + cm.options.viewportMargin);
    if (display.showingFrom < from && from - display.showingFrom < 20) from = Math.max(doc.first, display.showingFrom);
    if (display.showingTo > to && display.showingTo - to < 20) to = Math.min(end, display.showingTo);
    if (sawCollapsedSpans) {
      from = lineNo(visualLine(doc, getLine(doc, from)));
      while (to < end && lineIsHidden(doc, getLine(doc, to))) ++to;
    }

    // Create a range of theoretically intact lines, and punch holes
    // in that using the change info.
    var intact = [{from: Math.max(display.showingFrom, doc.first),
                   to: Math.min(display.showingTo, end)}];
    if (intact[0].from >= intact[0].to) intact = [];
    else intact = computeIntact(intact, changes);
    // When merged lines are present, we might have to reduce the
    // intact ranges because changes in continued fragments of the
    // intact lines do require the lines to be redrawn.
    if (sawCollapsedSpans)
      for (var i = 0; i < intact.length; ++i) {
        var range = intact[i], merged;
        while (merged = collapsedSpanAtEnd(getLine(doc, range.to - 1))) {
          var newTo = merged.find().from.line;
          if (newTo > range.from) range.to = newTo;
          else { intact.splice(i--, 1); break; }
        }
      }

    // Clip off the parts that won't be visible
    var intactLines = 0;
    for (var i = 0; i < intact.length; ++i) {
      var range = intact[i];
      if (range.from < from) range.from = from;
      if (range.to > to) range.to = to;
      if (range.from >= range.to) intact.splice(i--, 1);
      else intactLines += range.to - range.from;
    }
    if (!forced && intactLines == to - from && from == display.showingFrom && to == display.showingTo) {
      updateViewOffset(cm);
      return;
    }
    intact.sort(function(a, b) {return a.from - b.from;});

    // Avoid crashing on IE's "unspecified error" when in iframes
    try {
      var focused = document.activeElement;
    } catch(e) {}
    if (intactLines < (to - from) * .7) display.lineDiv.style.display = "none";
    patchDisplay(cm, from, to, intact, positionsChangedFrom);
    display.lineDiv.style.display = "";
    if (focused && document.activeElement != focused && focused.offsetHeight) focused.focus();

    var different = from != display.showingFrom || to != display.showingTo ||
      display.lastSizeC != display.wrapper.clientHeight;
    // This is just a bogus formula that detects when the editor is
    // resized or the font size changes.
    if (different) {
      display.lastSizeC = display.wrapper.clientHeight;
      startWorker(cm, 400);
    }
    display.showingFrom = from; display.showingTo = to;

    updateHeightsInViewport(cm);
    updateViewOffset(cm);

    return true;
  }

  function updateHeightsInViewport(cm) {
    var display = cm.display;
    var prevBottom = display.lineDiv.offsetTop;
    for (var node = display.lineDiv.firstChild, height; node; node = node.nextSibling) if (node.lineObj) {
      if (ie_lt8) {
        var bot = node.offsetTop + node.offsetHeight;
        height = bot - prevBottom;
        prevBottom = bot;
      } else {
        var box = getRect(node);
        height = box.bottom - box.top;
      }
      var diff = node.lineObj.height - height;
      if (height < 2) height = textHeight(display);
      if (diff > .001 || diff < -.001) {
        updateLineHeight(node.lineObj, height);
        var widgets = node.lineObj.widgets;
        if (widgets) for (var i = 0; i < widgets.length; ++i)
          widgets[i].height = widgets[i].node.offsetHeight;
      }
    }
  }

  function updateViewOffset(cm) {
    var off = cm.display.viewOffset = heightAtLine(cm, getLine(cm.doc, cm.display.showingFrom));
    // Position the mover div to align with the current virtual scroll position
    cm.display.mover.style.top = off + "px";
  }

  function computeIntact(intact, changes) {
    for (var i = 0, l = changes.length || 0; i < l; ++i) {
      var change = changes[i], intact2 = [], diff = change.diff || 0;
      for (var j = 0, l2 = intact.length; j < l2; ++j) {
        var range = intact[j];
        if (change.to <= range.from && change.diff) {
          intact2.push({from: range.from + diff, to: range.to + diff});
        } else if (change.to <= range.from || change.from >= range.to) {
          intact2.push(range);
        } else {
          if (change.from > range.from)
            intact2.push({from: range.from, to: change.from});
          if (change.to < range.to)
            intact2.push({from: change.to + diff, to: range.to + diff});
        }
      }
      intact = intact2;
    }
    return intact;
  }

  function getDimensions(cm) {
    var d = cm.display, left = {}, width = {};
    for (var n = d.gutters.firstChild, i = 0; n; n = n.nextSibling, ++i) {
      left[cm.options.gutters[i]] = n.offsetLeft;
      width[cm.options.gutters[i]] = n.offsetWidth;
    }
    return {fixedPos: compensateForHScroll(d),
            gutterTotalWidth: d.gutters.offsetWidth,
            gutterLeft: left,
            gutterWidth: width,
            wrapperWidth: d.wrapper.clientWidth};
  }

  function patchDisplay(cm, from, to, intact, updateNumbersFrom) {
    var dims = getDimensions(cm);
    var display = cm.display, lineNumbers = cm.options.lineNumbers;
    if (!intact.length && (!webkit || !cm.display.currentWheelTarget))
      removeChildren(display.lineDiv);
    var container = display.lineDiv, cur = container.firstChild;

    function rm(node) {
      var next = node.nextSibling;
      if (webkit && mac && cm.display.currentWheelTarget == node) {
        node.style.display = "none";
        node.lineObj = null;
      } else {
        node.parentNode.removeChild(node);
      }
      return next;
    }

    var nextIntact = intact.shift(), lineN = from;
    cm.doc.iter(from, to, function(line) {
      if (nextIntact && nextIntact.to == lineN) nextIntact = intact.shift();
      if (lineIsHidden(cm.doc, line)) {
        if (line.height != 0) updateLineHeight(line, 0);
        if (line.widgets && cur.previousSibling) for (var i = 0; i < line.widgets.length; ++i) {
          var w = line.widgets[i];
          if (w.showIfHidden) {
            var prev = cur.previousSibling;
            if (/pre/i.test(prev.nodeName)) {
              var wrap = elt("div", null, null, "position: relative");
              prev.parentNode.replaceChild(wrap, prev);
              wrap.appendChild(prev);
              prev = wrap;
            }
            var wnode = prev.appendChild(elt("div", [w.node], "CodeMirror-linewidget"));
            if (!w.handleMouseEvents) wnode.ignoreEvents = true;
            positionLineWidget(w, wnode, prev, dims);
          }
        }
      } else if (nextIntact && nextIntact.from <= lineN && nextIntact.to > lineN) {
        // This line is intact. Skip to the actual node. Update its
        // line number if needed.
        while (cur.lineObj != line) cur = rm(cur);
        if (lineNumbers && updateNumbersFrom <= lineN && cur.lineNumber)
          setTextContent(cur.lineNumber, lineNumberFor(cm.options, lineN));
        cur = cur.nextSibling;
      } else {
        // For lines with widgets, make an attempt to find and reuse
        // the existing element, so that widgets aren't needlessly
        // removed and re-inserted into the dom
        if (line.widgets) for (var j = 0, search = cur, reuse; search && j < 20; ++j, search = search.nextSibling)
          if (search.lineObj == line && /div/i.test(search.nodeName)) { reuse = search; break; }
        // This line needs to be generated.
        var lineNode = buildLineElement(cm, line, lineN, dims, reuse);
        if (lineNode != reuse) {
          container.insertBefore(lineNode, cur);
        } else {
          while (cur != reuse) cur = rm(cur);
          cur = cur.nextSibling;
        }

        lineNode.lineObj = line;
      }
      ++lineN;
    });
    while (cur) cur = rm(cur);
  }

  function buildLineElement(cm, line, lineNo, dims, reuse) {
    var lineElement = lineContent(cm, line);
    var markers = line.gutterMarkers, display = cm.display, wrap;

    if (!cm.options.lineNumbers && !markers && !line.bgClass && !line.wrapClass && !line.widgets)
      return lineElement;

    // Lines with gutter elements, widgets or a background class need
    // to be wrapped again, and have the extra elements added to the
    // wrapper div

    if (reuse) {
      reuse.alignable = null;
      var isOk = true, widgetsSeen = 0, insertBefore = null;
      for (var n = reuse.firstChild, next; n; n = next) {
        next = n.nextSibling;
        if (!/\bCodeMirror-linewidget\b/.test(n.className)) {
          reuse.removeChild(n);
        } else {
          for (var i = 0; i < line.widgets.length; ++i) {
            var widget = line.widgets[i];
            if (widget.node == n.firstChild) {
              if (!widget.above && !insertBefore) insertBefore = n;
              positionLineWidget(widget, n, reuse, dims);
              ++widgetsSeen;
              break;
            }
          }
          if (i == line.widgets.length) { isOk = false; break; }
        }
      }
      reuse.insertBefore(lineElement, insertBefore);
      if (isOk && widgetsSeen == line.widgets.length) {
        wrap = reuse;
        reuse.className = line.wrapClass || "";
      }
    }
    if (!wrap) {
      wrap = elt("div", null, line.wrapClass, "position: relative");
      wrap.appendChild(lineElement);
    }
    // Kludge to make sure the styled element lies behind the selection (by z-index)
    if (line.bgClass)
      wrap.insertBefore(elt("div", null, line.bgClass + " CodeMirror-linebackground"), wrap.firstChild);
    if (cm.options.lineNumbers || markers) {
      var gutterWrap = wrap.insertBefore(elt("div", null, null, "position: absolute; left: " +
                                             (cm.options.fixedGutter ? dims.fixedPos : -dims.gutterTotalWidth) + "px"),
                                         wrap.firstChild);
      if (cm.options.fixedGutter) (wrap.alignable || (wrap.alignable = [])).push(gutterWrap);
      if (cm.options.lineNumbers && (!markers || !markers["CodeMirror-linenumbers"]))
        wrap.lineNumber = gutterWrap.appendChild(
          elt("div", lineNumberFor(cm.options, lineNo),
              "CodeMirror-linenumber CodeMirror-gutter-elt",
              "left: " + dims.gutterLeft["CodeMirror-linenumbers"] + "px; width: "
              + display.lineNumInnerWidth + "px"));
      if (markers)
        for (var k = 0; k < cm.options.gutters.length; ++k) {
          var id = cm.options.gutters[k], found = markers.hasOwnProperty(id) && markers[id];
          if (found)
            gutterWrap.appendChild(elt("div", [found], "CodeMirror-gutter-elt", "left: " +
                                       dims.gutterLeft[id] + "px; width: " + dims.gutterWidth[id] + "px"));
        }
    }
    if (ie_lt8) wrap.style.zIndex = 2;
    if (line.widgets && wrap != reuse) for (var i = 0, ws = line.widgets; i < ws.length; ++i) {
      var widget = ws[i], node = elt("div", [widget.node], "CodeMirror-linewidget");
      if (!widget.handleMouseEvents) node.ignoreEvents = true;
      positionLineWidget(widget, node, wrap, dims);
      if (widget.above)
        wrap.insertBefore(node, cm.options.lineNumbers && line.height != 0 ? gutterWrap : lineElement);
      else
        wrap.appendChild(node);
      signalLater(widget, "redraw");
    }
    return wrap;
  }

  function positionLineWidget(widget, node, wrap, dims) {
    if (widget.noHScroll) {
      (wrap.alignable || (wrap.alignable = [])).push(node);
      var width = dims.wrapperWidth;
      node.style.left = dims.fixedPos + "px";
      if (!widget.coverGutter) {
        width -= dims.gutterTotalWidth;
        node.style.paddingLeft = dims.gutterTotalWidth + "px";
      }
      node.style.width = width + "px";
    }
    if (widget.coverGutter) {
      node.style.zIndex = 5;
      node.style.position = "relative";
      if (!widget.noHScroll) node.style.marginLeft = -dims.gutterTotalWidth + "px";
    }
  }

  // SELECTION / CURSOR

  function updateSelection(cm) {
    var display = cm.display;
    var collapsed = posEq(cm.doc.sel.from, cm.doc.sel.to);
    if (collapsed || cm.options.showCursorWhenSelecting)
      updateSelectionCursor(cm);
    else
      display.cursor.style.display = display.otherCursor.style.display = "none";
    if (!collapsed)
      updateSelectionRange(cm);
    else
      display.selectionDiv.style.display = "none";

    // Move the hidden textarea near the cursor to prevent scrolling artifacts
    if (cm.options.moveInputWithCursor) {
      var headPos = cursorCoords(cm, cm.doc.sel.head, "div");
      var wrapOff = getRect(display.wrapper), lineOff = getRect(display.lineDiv);
      display.inputDiv.style.top = Math.max(0, Math.min(display.wrapper.clientHeight - 10,
                                                        headPos.top + lineOff.top - wrapOff.top)) + "px";
      display.inputDiv.style.left = Math.max(0, Math.min(display.wrapper.clientWidth - 10,
                                                         headPos.left + lineOff.left - wrapOff.left)) + "px";
    }
  }

  // No selection, plain cursor
  function updateSelectionCursor(cm) {
    var display = cm.display, pos = cursorCoords(cm, cm.doc.sel.head, "div");
    display.cursor.style.left = pos.left + "px";
    display.cursor.style.top = pos.top + "px";
    display.cursor.style.height = Math.max(0, pos.bottom - pos.top) * cm.options.cursorHeight + "px";
    display.cursor.style.display = "";

    if (pos.other) {
      display.otherCursor.style.display = "";
      display.otherCursor.style.left = pos.other.left + "px";
      display.otherCursor.style.top = pos.other.top + "px";
      display.otherCursor.style.height = (pos.other.bottom - pos.other.top) * .85 + "px";
    } else { display.otherCursor.style.display = "none"; }
  }

  // Highlight selection
  function updateSelectionRange(cm) {
    var display = cm.display, doc = cm.doc, sel = cm.doc.sel;
    var fragment = document.createDocumentFragment();
    var clientWidth = display.lineSpace.offsetWidth, pl = paddingLeft(cm.display);

    function add(left, top, width, bottom) {
      if (top < 0) top = 0;
      fragment.appendChild(elt("div", null, "CodeMirror-selected", "position: absolute; left: " + left +
                               "px; top: " + top + "px; width: " + (width == null ? clientWidth - left : width) +
                               "px; height: " + (bottom - top) + "px"));
    }

    function drawForLine(line, fromArg, toArg) {
      var lineObj = getLine(doc, line);
      var lineLen = lineObj.text.length;
      var start, end;
      function coords(ch, bias) {
        return charCoords(cm, Pos(line, ch), "div", lineObj, bias);
      }

      iterateBidiSections(getOrder(lineObj), fromArg || 0, toArg == null ? lineLen : toArg, function(from, to, dir) {
        var leftPos = coords(from, "left"), rightPos, left, right;
        if (from == to) {
          rightPos = leftPos;
          left = right = leftPos.left;
        } else {
          rightPos = coords(to - 1, "right");
          if (dir == "rtl") { var tmp = leftPos; leftPos = rightPos; rightPos = tmp; }
          left = leftPos.left;
          right = rightPos.right;
        }
        if (fromArg == null && from == 0) left = pl;
        if (rightPos.top - leftPos.top > 3) { // Different lines, draw top part
          add(left, leftPos.top, null, leftPos.bottom);
          left = pl;
          if (leftPos.bottom < rightPos.top) add(left, leftPos.bottom, null, rightPos.top);
        }
        if (toArg == null && to == lineLen) right = clientWidth;
        if (!start || leftPos.top < start.top || leftPos.top == start.top && leftPos.left < start.left)
          start = leftPos;
        if (!end || rightPos.bottom > end.bottom || rightPos.bottom == end.bottom && rightPos.right > end.right)
          end = rightPos;
        if (left < pl + 1) left = pl;
        add(left, rightPos.top, right - left, rightPos.bottom);
      });
      return {start: start, end: end};
    }

    if (sel.from.line == sel.to.line) {
      drawForLine(sel.from.line, sel.from.ch, sel.to.ch);
    } else {
      var fromLine = getLine(doc, sel.from.line), toLine = getLine(doc, sel.to.line);
      var singleVLine = visualLine(doc, fromLine) == visualLine(doc, toLine);
      var leftEnd = drawForLine(sel.from.line, sel.from.ch, singleVLine ? fromLine.text.length : null).end;
      var rightStart = drawForLine(sel.to.line, singleVLine ? 0 : null, sel.to.ch).start;
      if (singleVLine) {
        if (leftEnd.top < rightStart.top - 2) {
          add(leftEnd.right, leftEnd.top, null, leftEnd.bottom);
          add(pl, rightStart.top, rightStart.left, rightStart.bottom);
        } else {
          add(leftEnd.right, leftEnd.top, rightStart.left - leftEnd.right, leftEnd.bottom);
        }
      }
      if (leftEnd.bottom < rightStart.top)
        add(pl, leftEnd.bottom, null, rightStart.top);
    }

    removeChildrenAndAdd(display.selectionDiv, fragment);
    display.selectionDiv.style.display = "";
  }

  // Cursor-blinking
  function restartBlink(cm) {
    if (!cm.state.focused) return;
    var display = cm.display;
    clearInterval(display.blinker);
    var on = true;
    display.cursor.style.visibility = display.otherCursor.style.visibility = "";
    display.blinker = setInterval(function() {
      display.cursor.style.visibility = display.otherCursor.style.visibility = (on = !on) ? "" : "hidden";
    }, cm.options.cursorBlinkRate);
  }

  // HIGHLIGHT WORKER

  function startWorker(cm, time) {
    if (cm.doc.mode.startState && cm.doc.frontier < cm.display.showingTo)
      cm.state.highlight.set(time, bind(highlightWorker, cm));
  }

  function highlightWorker(cm) {
    var doc = cm.doc;
    if (doc.frontier < doc.first) doc.frontier = doc.first;
    if (doc.frontier >= cm.display.showingTo) return;
    var end = +new Date + cm.options.workTime;
    var state = copyState(doc.mode, getStateBefore(cm, doc.frontier));
    var changed = [], prevChange;
    doc.iter(doc.frontier, Math.min(doc.first + doc.size, cm.display.showingTo + 500), function(line) {
      if (doc.frontier >= cm.display.showingFrom) { // Visible
        var oldStyles = line.styles;
        line.styles = highlightLine(cm, line, state);
        var ischange = !oldStyles || oldStyles.length != line.styles.length;
        for (var i = 0; !ischange && i < oldStyles.length; ++i) ischange = oldStyles[i] != line.styles[i];
        if (ischange) {
          if (prevChange && prevChange.end == doc.frontier) prevChange.end++;
          else changed.push(prevChange = {start: doc.frontier, end: doc.frontier + 1});
        }
        line.stateAfter = copyState(doc.mode, state);
      } else {
        processLine(cm, line, state);
        line.stateAfter = doc.frontier % 5 == 0 ? copyState(doc.mode, state) : null;
      }
      ++doc.frontier;
      if (+new Date > end) {
        startWorker(cm, cm.options.workDelay);
        return true;
      }
    });
    if (changed.length)
      operation(cm, function() {
        for (var i = 0; i < changed.length; ++i)
          regChange(this, changed[i].start, changed[i].end);
      })();
  }

  // Finds the line to start with when starting a parse. Tries to
  // find a line with a stateAfter, so that it can start with a
  // valid state. If that fails, it returns the line with the
  // smallest indentation, which tends to need the least context to
  // parse correctly.
  function findStartLine(cm, n, precise) {
    var minindent, minline, doc = cm.doc;
    for (var search = n, lim = n - 100; search > lim; --search) {
      if (search <= doc.first) return doc.first;
      var line = getLine(doc, search - 1);
      if (line.stateAfter && (!precise || search <= doc.frontier)) return search;
      var indented = countColumn(line.text, null, cm.options.tabSize);
      if (minline == null || minindent > indented) {
        minline = search - 1;
        minindent = indented;
      }
    }
    return minline;
  }

  function getStateBefore(cm, n, precise) {
    var doc = cm.doc, display = cm.display;
      if (!doc.mode.startState) return true;
    var pos = findStartLine(cm, n, precise), state = pos > doc.first && getLine(doc, pos-1).stateAfter;
    if (!state) state = startState(doc.mode);
    else state = copyState(doc.mode, state);
    doc.iter(pos, n, function(line) {
      processLine(cm, line, state);
      var save = pos == n - 1 || pos % 5 == 0 || pos >= display.showingFrom && pos < display.showingTo;
      line.stateAfter = save ? copyState(doc.mode, state) : null;
      ++pos;
    });
    return state;
  }

  // POSITION MEASUREMENT

  function paddingTop(display) {return display.lineSpace.offsetTop;}
  function paddingVert(display) {return display.mover.offsetHeight - display.lineSpace.offsetHeight;}
  function paddingLeft(display) {
    var e = removeChildrenAndAdd(display.measure, elt("pre", null, null, "text-align: left")).appendChild(elt("span", "x"));
    return e.offsetLeft;
  }

  function measureChar(cm, line, ch, data, bias) {
    var dir = -1;
    data = data || measureLine(cm, line);

    for (var pos = ch;; pos += dir) {
      var r = data[pos];
      if (r) break;
      if (dir < 0 && pos == 0) dir = 1;
    }
    bias = pos > ch ? "left" : pos < ch ? "right" : bias;
    if (bias == "left" && r.leftSide) r = r.leftSide;
    else if (bias == "right" && r.rightSide) r = r.rightSide;
    return {left: pos < ch ? r.right : r.left,
            right: pos > ch ? r.left : r.right,
            top: r.top,
            bottom: r.bottom};
  }

  function findCachedMeasurement(cm, line) {
    var cache = cm.display.measureLineCache;
    for (var i = 0; i < cache.length; ++i) {
      var memo = cache[i];
      if (memo.text == line.text && memo.markedSpans == line.markedSpans &&
          cm.display.scroller.clientWidth == memo.width &&
          memo.classes == line.textClass + "|" + line.bgClass + "|" + line.wrapClass)
        return memo;
    }
  }

  function clearCachedMeasurement(cm, line) {
    var exists = findCachedMeasurement(cm, line);
    if (exists) exists.text = exists.measure = exists.markedSpans = null;
  }

  function measureLine(cm, line) {
    // First look in the cache
    var cached = findCachedMeasurement(cm, line);
    if (cached) return cached.measure;

    // Failing that, recompute and store result in cache
    var measure = measureLineInner(cm, line);
    var cache = cm.display.measureLineCache;
    var memo = {text: line.text, width: cm.display.scroller.clientWidth,
                markedSpans: line.markedSpans, measure: measure,
                classes: line.textClass + "|" + line.bgClass + "|" + line.wrapClass};
    if (cache.length == 16) cache[++cm.display.measureLineCachePos % 16] = memo;
    else cache.push(memo);
    return measure;
  }

  function measureLineInner(cm, line) {
    var display = cm.display, measure = emptyArray(line.text.length);
    var pre = lineContent(cm, line, measure, true);

    // IE does not cache element positions of inline elements between
    // calls to getBoundingClientRect. This makes the loop below,
    // which gathers the positions of all the characters on the line,
    // do an amount of layout work quadratic to the number of
    // characters. When line wrapping is off, we try to improve things
    // by first subdividing the line into a bunch of inline blocks, so
    // that IE can reuse most of the layout information from caches
    // for those blocks. This does interfere with line wrapping, so it
    // doesn't work when wrapping is on, but in that case the
    // situation is slightly better, since IE does cache line-wrapping
    // information and only recomputes per-line.
    if (ie && !ie_lt8 && !cm.options.lineWrapping && pre.childNodes.length > 100) {
      var fragment = document.createDocumentFragment();
      var chunk = 10, n = pre.childNodes.length;
      for (var i = 0, chunks = Math.ceil(n / chunk); i < chunks; ++i) {
        var wrap = elt("div", null, null, "display: inline-block");
        for (var j = 0; j < chunk && n; ++j) {
          wrap.appendChild(pre.firstChild);
          --n;
        }
        fragment.appendChild(wrap);
      }
      pre.appendChild(fragment);
    }

    removeChildrenAndAdd(display.measure, pre);

    var outer = getRect(display.lineDiv);
    var vranges = [], data = emptyArray(line.text.length), maxBot = pre.offsetHeight;
    // Work around an IE7/8 bug where it will sometimes have randomly
    // replaced our pre with a clone at this point.
    if (ie_lt9 && display.measure.first != pre)
      removeChildrenAndAdd(display.measure, pre);

    function measureRect(rect) {
      var top = rect.top - outer.top, bot = rect.bottom - outer.top;
      if (bot > maxBot) bot = maxBot;
      if (top < 0) top = 0;
      for (var i = vranges.length - 2; i >= 0; i -= 2) {
        var rtop = vranges[i], rbot = vranges[i+1];
        if (rtop > bot || rbot < top) continue;
        if (rtop <= top && rbot >= bot ||
            top <= rtop && bot >= rbot ||
            Math.min(bot, rbot) - Math.max(top, rtop) >= (bot - top) >> 1) {
          vranges[i] = Math.min(top, rtop);
          vranges[i+1] = Math.max(bot, rbot);
          break;
        }
      }
      if (i < 0) { i = vranges.length; vranges.push(top, bot); }
      return {left: rect.left - outer.left,
              right: rect.right - outer.left,
              top: i, bottom: null};
    }
    function finishRect(rect) {
      rect.bottom = vranges[rect.top+1];
      rect.top = vranges[rect.top];
    }

    for (var i = 0, cur; i < measure.length; ++i) if (cur = measure[i]) {
      var node = cur, rect = null;
      // A widget might wrap, needs special care
      if (/\bCodeMirror-widget\b/.test(cur.className) && cur.getClientRects) {
        if (cur.firstChild.nodeType == 1) node = cur.firstChild;
        var rects = node.getClientRects();
        if (rects.length > 1) {
          rect = data[i] = measureRect(rects[0]);
          rect.rightSide = measureRect(rects[rects.length - 1]);
        }
      }
      if (!rect) rect = data[i] = measureRect(getRect(node));
      if (cur.measureRight) rect.right = getRect(cur.measureRight).left;
      if (cur.leftSide) rect.leftSide = measureRect(getRect(cur.leftSide));
    }
    for (var i = 0, cur; i < data.length; ++i) if (cur = data[i]) {
      finishRect(cur);
      if (cur.leftSide) finishRect(cur.leftSide);
      if (cur.rightSide) finishRect(cur.rightSide);
    }
    return data;
  }

  function measureLineWidth(cm, line) {
    var hasBadSpan = false;
    if (line.markedSpans) for (var i = 0; i < line.markedSpans; ++i) {
      var sp = line.markedSpans[i];
      if (sp.collapsed && (sp.to == null || sp.to == line.text.length)) hasBadSpan = true;
    }
    var cached = !hasBadSpan && findCachedMeasurement(cm, line);
    if (cached) return measureChar(cm, line, line.text.length, cached.measure, "right").right;

    var pre = lineContent(cm, line, null, true);
    var end = pre.appendChild(zeroWidthElement(cm.display.measure));
    removeChildrenAndAdd(cm.display.measure, pre);
    return getRect(end).right - getRect(cm.display.lineDiv).left;
  }

  function clearCaches(cm) {
    cm.display.measureLineCache.length = cm.display.measureLineCachePos = 0;
    cm.display.cachedCharWidth = cm.display.cachedTextHeight = null;
    if (!cm.options.lineWrapping) cm.display.maxLineChanged = true;
    cm.display.lineNumChars = null;
  }

  function pageScrollX() { return window.pageXOffset || (document.documentElement || document.body).scrollLeft; }
  function pageScrollY() { return window.pageYOffset || (document.documentElement || document.body).scrollTop; }

  // Context is one of "line", "div" (display.lineDiv), "local"/null (editor), or "page"
  function intoCoordSystem(cm, lineObj, rect, context) {
    if (lineObj.widgets) for (var i = 0; i < lineObj.widgets.length; ++i) if (lineObj.widgets[i].above) {
      var size = widgetHeight(lineObj.widgets[i]);
      rect.top += size; rect.bottom += size;
    }
    if (context == "line") return rect;
    if (!context) context = "local";
    var yOff = heightAtLine(cm, lineObj);
    if (context == "local") yOff += paddingTop(cm.display);
    else yOff -= cm.display.viewOffset;
    if (context == "page" || context == "window") {
      var lOff = getRect(cm.display.lineSpace);
      yOff += lOff.top + (context == "window" ? 0 : pageScrollY());
      var xOff = lOff.left + (context == "window" ? 0 : pageScrollX());
      rect.left += xOff; rect.right += xOff;
    }
    rect.top += yOff; rect.bottom += yOff;
    return rect;
  }

  // Context may be "window", "page", "div", or "local"/null
  // Result is in "div" coords
  function fromCoordSystem(cm, coords, context) {
    if (context == "div") return coords;
    var left = coords.left, top = coords.top;
    // First move into "page" coordinate system
    if (context == "page") {
      left -= pageScrollX();
      top -= pageScrollY();
    } else if (context == "local" || !context) {
      var localBox = getRect(cm.display.sizer);
      left += localBox.left;
      top += localBox.top;
    }

    var lineSpaceBox = getRect(cm.display.lineSpace);
    return {left: left - lineSpaceBox.left, top: top - lineSpaceBox.top};
  }

  function charCoords(cm, pos, context, lineObj, bias) {
    if (!lineObj) lineObj = getLine(cm.doc, pos.line);
    return intoCoordSystem(cm, lineObj, measureChar(cm, lineObj, pos.ch, null, bias), context);
  }

  function cursorCoords(cm, pos, context, lineObj, measurement) {
    lineObj = lineObj || getLine(cm.doc, pos.line);
    if (!measurement) measurement = measureLine(cm, lineObj);
    function get(ch, right) {
      var m = measureChar(cm, lineObj, ch, measurement, right ? "right" : "left");
      if (right) m.left = m.right; else m.right = m.left;
      return intoCoordSystem(cm, lineObj, m, context);
    }
    function getBidi(ch, partPos) {
      var part = order[partPos], right = part.level % 2;
      if (ch == bidiLeft(part) && partPos && part.level < order[partPos - 1].level) {
        part = order[--partPos];
        ch = bidiRight(part) - (part.level % 2 ? 0 : 1);
        right = true;
      } else if (ch == bidiRight(part) && partPos < order.length - 1 && part.level < order[partPos + 1].level) {
        part = order[++partPos];
        ch = bidiLeft(part) - part.level % 2;
        right = false;
      }
      if (right && ch == part.to && ch > part.from) return get(ch - 1);
      return get(ch, right);
    }
    var order = getOrder(lineObj), ch = pos.ch;
    if (!order) return get(ch);
    var partPos = getBidiPartAt(order, ch);
    var val = getBidi(ch, partPos);
    if (bidiOther != null) val.other = getBidi(ch, bidiOther);
    return val;
  }

  function PosWithInfo(line, ch, outside, xRel) {
    var pos = new Pos(line, ch);
    pos.xRel = xRel;
    if (outside) pos.outside = true;
    return pos;
  }

  // Coords must be lineSpace-local
  function coordsChar(cm, x, y) {
    var doc = cm.doc;
    y += cm.display.viewOffset;
    if (y < 0) return PosWithInfo(doc.first, 0, true, -1);
    var lineNo = lineAtHeight(doc, y), last = doc.first + doc.size - 1;
    if (lineNo > last)
      return PosWithInfo(doc.first + doc.size - 1, getLine(doc, last).text.length, true, 1);
    if (x < 0) x = 0;

    for (;;) {
      var lineObj = getLine(doc, lineNo);
      var found = coordsCharInner(cm, lineObj, lineNo, x, y);
      var merged = collapsedSpanAtEnd(lineObj);
      var mergedPos = merged && merged.find();
      if (merged && (found.ch > mergedPos.from.ch || found.ch == mergedPos.from.ch && found.xRel > 0))
        lineNo = mergedPos.to.line;
      else
        return found;
    }
  }

  function coordsCharInner(cm, lineObj, lineNo, x, y) {
    var innerOff = y - heightAtLine(cm, lineObj);
    var wrongLine = false, adjust = 2 * cm.display.wrapper.clientWidth;
    var measurement = measureLine(cm, lineObj);

    function getX(ch) {
      var sp = cursorCoords(cm, Pos(lineNo, ch), "line",
                            lineObj, measurement);
      wrongLine = true;
      if (innerOff > sp.bottom) return sp.left - adjust;
      else if (innerOff < sp.top) return sp.left + adjust;
      else wrongLine = false;
      return sp.left;
    }

    var bidi = getOrder(lineObj), dist = lineObj.text.length;
    var from = lineLeft(lineObj), to = lineRight(lineObj);
    var fromX = getX(from), fromOutside = wrongLine, toX = getX(to), toOutside = wrongLine;

    if (x > toX) return PosWithInfo(lineNo, to, toOutside, 1);
    // Do a binary search between these bounds.
    for (;;) {
      if (bidi ? to == from || to == moveVisually(lineObj, from, 1) : to - from <= 1) {
        var ch = x < fromX || x - fromX <= toX - x ? from : to;
        var xDiff = x - (ch == from ? fromX : toX);
        while (isExtendingChar.test(lineObj.text.charAt(ch))) ++ch;
        var pos = PosWithInfo(lineNo, ch, ch == from ? fromOutside : toOutside,
                              xDiff < 0 ? -1 : xDiff ? 1 : 0);
        return pos;
      }
      var step = Math.ceil(dist / 2), middle = from + step;
      if (bidi) {
        middle = from;
        for (var i = 0; i < step; ++i) middle = moveVisually(lineObj, middle, 1);
      }
      var middleX = getX(middle);
      if (middleX > x) {to = middle; toX = middleX; if (toOutside = wrongLine) toX += 1000; dist = step;}
      else {from = middle; fromX = middleX; fromOutside = wrongLine; dist -= step;}
    }
  }

  var measureText;
  function textHeight(display) {
    if (display.cachedTextHeight != null) return display.cachedTextHeight;
    if (measureText == null) {
      measureText = elt("pre");
      // Measure a bunch of lines, for browsers that compute
      // fractional heights.
      for (var i = 0; i < 49; ++i) {
        measureText.appendChild(document.createTextNode("x"));
        measureText.appendChild(elt("br"));
      }
      measureText.appendChild(document.createTextNode("x"));
    }
    removeChildrenAndAdd(display.measure, measureText);
    var height = measureText.offsetHeight / 50;
    if (height > 3) display.cachedTextHeight = height;
    removeChildren(display.measure);
    return height || 1;
  }

  function charWidth(display) {
    if (display.cachedCharWidth != null) return display.cachedCharWidth;
    var anchor = elt("span", "x");
    var pre = elt("pre", [anchor]);
    removeChildrenAndAdd(display.measure, pre);
    var width = anchor.offsetWidth;
    if (width > 2) display.cachedCharWidth = width;
    return width || 10;
  }

  // OPERATIONS

  // Operations are used to wrap changes in such a way that each
  // change won't have to update the cursor and display (which would
  // be awkward, slow, and error-prone), but instead updates are
  // batched and then all combined and executed at once.

  var nextOpId = 0;
  function startOperation(cm) {
    cm.curOp = {
      // An array of ranges of lines that have to be updated. See
      // updateDisplay.
      changes: [],
      forceUpdate: false,
      updateInput: null,
      userSelChange: null,
      textChanged: null,
      selectionChanged: false,
      cursorActivity: false,
      updateMaxLine: false,
      updateScrollPos: false,
      id: ++nextOpId
    };
    if (!delayedCallbackDepth++) delayedCallbacks = [];
  }

  function endOperation(cm) {
    var op = cm.curOp, doc = cm.doc, display = cm.display;
    cm.curOp = null;

    if (op.updateMaxLine) computeMaxLength(cm);
    if (display.maxLineChanged && !cm.options.lineWrapping && display.maxLine) {
      var width = measureLineWidth(cm, display.maxLine);
      display.sizer.style.minWidth = Math.max(0, width + 3 + scrollerCutOff) + "px";
      display.maxLineChanged = false;
      var maxScrollLeft = Math.max(0, display.sizer.offsetLeft + display.sizer.offsetWidth - display.scroller.clientWidth);
      if (maxScrollLeft < doc.scrollLeft && !op.updateScrollPos)
        setScrollLeft(cm, Math.min(display.scroller.scrollLeft, maxScrollLeft), true);
    }
    var newScrollPos, updated;
    if (op.updateScrollPos) {
      newScrollPos = op.updateScrollPos;
    } else if (op.selectionChanged && display.scroller.clientHeight) { // don't rescroll if not visible
      var coords = cursorCoords(cm, doc.sel.head);
      newScrollPos = calculateScrollPos(cm, coords.left, coords.top, coords.left, coords.bottom);
    }
    if (op.changes.length || op.forceUpdate || newScrollPos && newScrollPos.scrollTop != null) {
      updated = updateDisplay(cm, op.changes, newScrollPos && newScrollPos.scrollTop, op.forceUpdate);
      if (cm.display.scroller.offsetHeight) cm.doc.scrollTop = cm.display.scroller.scrollTop;
    }
    if (!updated && op.selectionChanged) updateSelection(cm);
    if (op.updateScrollPos) {
      display.scroller.scrollTop = display.scrollbarV.scrollTop = doc.scrollTop = newScrollPos.scrollTop;
      display.scroller.scrollLeft = display.scrollbarH.scrollLeft = doc.scrollLeft = newScrollPos.scrollLeft;
      alignHorizontally(cm);
      if (op.scrollToPos)
        scrollPosIntoView(cm, clipPos(cm.doc, op.scrollToPos), op.scrollToPosMargin);
    } else if (newScrollPos) {
      scrollCursorIntoView(cm);
    }
    if (op.selectionChanged) restartBlink(cm);

    if (cm.state.focused && op.updateInput)
      resetInput(cm, op.userSelChange);

    var hidden = op.maybeHiddenMarkers, unhidden = op.maybeUnhiddenMarkers;
    if (hidden) for (var i = 0; i < hidden.length; ++i)
      if (!hidden[i].lines.length) signal(hidden[i], "hide");
    if (unhidden) for (var i = 0; i < unhidden.length; ++i)
      if (unhidden[i].lines.length) signal(unhidden[i], "unhide");

    var delayed;
    if (!--delayedCallbackDepth) {
      delayed = delayedCallbacks;
      delayedCallbacks = null;
    }
    if (op.textChanged)
      signal(cm, "change", cm, op.textChanged);
    if (op.cursorActivity) signal(cm, "cursorActivity", cm);
    if (delayed) for (var i = 0; i < delayed.length; ++i) delayed[i]();
  }

  // Wraps a function in an operation. Returns the wrapped function.
  function operation(cm1, f) {
    return function() {
      var cm = cm1 || this, withOp = !cm.curOp;
      if (withOp) startOperation(cm);
      try { var result = f.apply(cm, arguments); }
      finally { if (withOp) endOperation(cm); }
      return result;
    };
  }
  function docOperation(f) {
    return function() {
      var withOp = this.cm && !this.cm.curOp, result;
      if (withOp) startOperation(this.cm);
      try { result = f.apply(this, arguments); }
      finally { if (withOp) endOperation(this.cm); }
      return result;
    };
  }
  function runInOp(cm, f) {
    var withOp = !cm.curOp, result;
    if (withOp) startOperation(cm);
    try { result = f(); }
    finally { if (withOp) endOperation(cm); }
    return result;
  }

  function regChange(cm, from, to, lendiff) {
    if (from == null) from = cm.doc.first;
    if (to == null) to = cm.doc.first + cm.doc.size;
    cm.curOp.changes.push({from: from, to: to, diff: lendiff});
  }

  // INPUT HANDLING

  function slowPoll(cm) {
    if (cm.display.pollingFast) return;
    cm.display.poll.set(cm.options.pollInterval, function() {
      readInput(cm);
      if (cm.state.focused) slowPoll(cm);
    });
  }

  function fastPoll(cm) {
    var missed = false;
    cm.display.pollingFast = true;
    function p() {
      var changed = readInput(cm);
      if (!changed && !missed) {missed = true; cm.display.poll.set(60, p);}
      else {cm.display.pollingFast = false; slowPoll(cm);}
    }
    cm.display.poll.set(20, p);
  }

  // prevInput is a hack to work with IME. If we reset the textarea
  // on every change, that breaks IME. So we look for changes
  // compared to the previous content instead. (Modern browsers have
  // events that indicate IME taking place, but these are not widely
  // supported or compatible enough yet to rely on.)
  function readInput(cm) {
    var input = cm.display.input, prevInput = cm.display.prevInput, doc = cm.doc, sel = doc.sel;
    if (!cm.state.focused || hasSelection(input) || isReadOnly(cm) || cm.state.disableInput) return false;
    var text = input.value;
    if (text == prevInput && posEq(sel.from, sel.to)) return false;
    if (ie && !ie_lt9 && cm.display.inputHasSelection === text) {
      resetInput(cm, true);
      return false;
    }

    var withOp = !cm.curOp;
    if (withOp) startOperation(cm);
    sel.shift = false;
    var same = 0, l = Math.min(prevInput.length, text.length);
    while (same < l && prevInput.charCodeAt(same) == text.charCodeAt(same)) ++same;
    var from = sel.from, to = sel.to;
    if (same < prevInput.length)
      from = Pos(from.line, from.ch - (prevInput.length - same));
    else if (cm.state.overwrite && posEq(from, to) && !cm.state.pasteIncoming)
      to = Pos(to.line, Math.min(getLine(doc, to.line).text.length, to.ch + (text.length - same)));

    var updateInput = cm.curOp.updateInput;
    var changeEvent = {from: from, to: to, text: splitLines(text.slice(same)),
                       origin: cm.state.pasteIncoming ? "paste" : "+input"};
    makeChange(cm.doc, changeEvent, "end");
    cm.curOp.updateInput = updateInput;
    signalLater(cm, "inputRead", cm, changeEvent);

    if (text.length > 1000 || text.indexOf("\n") > -1) input.value = cm.display.prevInput = "";
    else cm.display.prevInput = text;
    if (withOp) endOperation(cm);
    cm.state.pasteIncoming = false;
    return true;
  }

  function resetInput(cm, user) {
    var minimal, selected, doc = cm.doc;
    if (!posEq(doc.sel.from, doc.sel.to)) {
      cm.display.prevInput = "";
      minimal = hasCopyEvent &&
        (doc.sel.to.line - doc.sel.from.line > 100 || (selected = cm.getSelection()).length > 1000);
      var content = minimal ? "-" : selected || cm.getSelection();
      cm.display.input.value = content;
      if (cm.state.focused) selectInput(cm.display.input);
      if (ie && !ie_lt9) cm.display.inputHasSelection = content;
    } else if (user) {
      cm.display.prevInput = cm.display.input.value = "";
      if (ie && !ie_lt9) cm.display.inputHasSelection = null;
    }
    cm.display.inaccurateSelection = minimal;
  }

  function focusInput(cm) {
    if (cm.options.readOnly != "nocursor" && (!mobile || document.activeElement != cm.display.input))
      cm.display.input.focus();
  }

  function isReadOnly(cm) {
    return cm.options.readOnly || cm.doc.cantEdit;
  }

  // EVENT HANDLERS

  function registerEventHandlers(cm) {
    var d = cm.display;
    on(d.scroller, "mousedown", operation(cm, onMouseDown));
    if (ie)
      on(d.scroller, "dblclick", operation(cm, function(e) {
        if (signalDOMEvent(cm, e)) return;
        var pos = posFromMouse(cm, e);
        if (!pos || clickInGutter(cm, e) || eventInWidget(cm.display, e)) return;
        e_preventDefault(e);
        var word = findWordAt(getLine(cm.doc, pos.line).text, pos);
        extendSelection(cm.doc, word.from, word.to);
      }));
    else
      on(d.scroller, "dblclick", function(e) { signalDOMEvent(cm, e) || e_preventDefault(e); });
    on(d.lineSpace, "selectstart", function(e) {
      if (!eventInWidget(d, e)) e_preventDefault(e);
    });
    // Gecko browsers fire contextmenu *after* opening the menu, at
    // which point we can't mess with it anymore. Context menu is
    // handled in onMouseDown for Gecko.
    if (!captureMiddleClick) on(d.scroller, "contextmenu", function(e) {onContextMenu(cm, e);});

    on(d.scroller, "scroll", function() {
      if (d.scroller.clientHeight) {
        setScrollTop(cm, d.scroller.scrollTop);
        setScrollLeft(cm, d.scroller.scrollLeft, true);
        signal(cm, "scroll", cm);
      }
    });
    on(d.scrollbarV, "scroll", function() {
      if (d.scroller.clientHeight) setScrollTop(cm, d.scrollbarV.scrollTop);
    });
    on(d.scrollbarH, "scroll", function() {
      if (d.scroller.clientHeight) setScrollLeft(cm, d.scrollbarH.scrollLeft);
    });

    on(d.scroller, "mousewheel", function(e){onScrollWheel(cm, e);});
    on(d.scroller, "DOMMouseScroll", function(e){onScrollWheel(cm, e);});

    function reFocus() { if (cm.state.focused) setTimeout(bind(focusInput, cm), 0); }
    on(d.scrollbarH, "mousedown", reFocus);
    on(d.scrollbarV, "mousedown", reFocus);
    // Prevent wrapper from ever scrolling
    on(d.wrapper, "scroll", function() { d.wrapper.scrollTop = d.wrapper.scrollLeft = 0; });

    var resizeTimer;
    function onResize() {
      if (resizeTimer == null) resizeTimer = setTimeout(function() {
        resizeTimer = null;
        // Might be a text scaling operation, clear size caches.
        d.cachedCharWidth = d.cachedTextHeight = knownScrollbarWidth = null;
        clearCaches(cm);
        runInOp(cm, bind(regChange, cm));
      }, 100);
    }
    on(window, "resize", onResize);
    // Above handler holds on to the editor and its data structures.
    // Here we poll to unregister it when the editor is no longer in
    // the document, so that it can be garbage-collected.
    function unregister() {
      for (var p = d.wrapper.parentNode; p && p != document.body; p = p.parentNode) {}
      if (p) setTimeout(unregister, 5000);
      else off(window, "resize", onResize);
    }
    setTimeout(unregister, 5000);

    on(d.input, "keyup", operation(cm, function(e) {
      if (signalDOMEvent(cm, e) || cm.options.onKeyEvent && cm.options.onKeyEvent(cm, addStop(e))) return;
      if (e.keyCode == 16) cm.doc.sel.shift = false;
    }));
    on(d.input, "input", bind(fastPoll, cm));
    on(d.input, "keydown", operation(cm, onKeyDown));
    on(d.input, "keypress", operation(cm, onKeyPress));
    on(d.input, "focus", bind(onFocus, cm));
    on(d.input, "blur", bind(onBlur, cm));

    function drag_(e) {
      if (signalDOMEvent(cm, e) || cm.options.onDragEvent && cm.options.onDragEvent(cm, addStop(e))) return;
      e_stop(e);
    }
    if (cm.options.dragDrop) {
      on(d.scroller, "dragstart", function(e){onDragStart(cm, e);});
      on(d.scroller, "dragenter", drag_);
      on(d.scroller, "dragover", drag_);
      on(d.scroller, "drop", operation(cm, onDrop));
    }
    on(d.scroller, "paste", function(e){
      if (eventInWidget(d, e)) return;
      focusInput(cm);
      fastPoll(cm);
    });
    on(d.input, "paste", function() {
      cm.state.pasteIncoming = true;
      fastPoll(cm);
    });

    function prepareCopy() {
      if (d.inaccurateSelection) {
        d.prevInput = "";
        d.inaccurateSelection = false;
        d.input.value = cm.getSelection();
        selectInput(d.input);
      }
    }
    on(d.input, "cut", prepareCopy);
    on(d.input, "copy", prepareCopy);

    // Needed to handle Tab key in KHTML
    if (khtml) on(d.sizer, "mouseup", function() {
        if (document.activeElement == d.input) d.input.blur();
        focusInput(cm);
    });
  }

  function eventInWidget(display, e) {
    for (var n = e_target(e); n != display.wrapper; n = n.parentNode) {
      if (!n || n.ignoreEvents || n.parentNode == display.sizer && n != display.mover) return true;
    }
  }

  function posFromMouse(cm, e, liberal) {
    var display = cm.display;
    if (!liberal) {
      var target = e_target(e);
      if (target == display.scrollbarH || target == display.scrollbarH.firstChild ||
          target == display.scrollbarV || target == display.scrollbarV.firstChild ||
          target == display.scrollbarFiller || target == display.gutterFiller) return null;
    }
    var x, y, space = getRect(display.lineSpace);
    // Fails unpredictably on IE[67] when mouse is dragged around quickly.
    try { x = e.clientX; y = e.clientY; } catch (e) { return null; }
    return coordsChar(cm, x - space.left, y - space.top);
  }

  var lastClick, lastDoubleClick;
  function onMouseDown(e) {
    if (signalDOMEvent(this, e)) return;
    var cm = this, display = cm.display, doc = cm.doc, sel = doc.sel;
    sel.shift = e.shiftKey;

    if (eventInWidget(display, e)) {
      if (!webkit) {
        display.scroller.draggable = false;
        setTimeout(function(){display.scroller.draggable = true;}, 100);
      }
      return;
    }
    if (clickInGutter(cm, e)) return;
    var start = posFromMouse(cm, e);

    switch (e_button(e)) {
    case 3:
      if (captureMiddleClick) onContextMenu.call(cm, cm, e);
      return;
    case 2:
      if (start) extendSelection(cm.doc, start);
      setTimeout(bind(focusInput, cm), 20);
      e_preventDefault(e);
      return;
    }
    // For button 1, if it was clicked inside the editor
    // (posFromMouse returning non-null), we have to adjust the
    // selection.
    if (!start) {if (e_target(e) == display.scroller) e_preventDefault(e); return;}

    if (!cm.state.focused) onFocus(cm);

    var now = +new Date, type = "single";
    if (lastDoubleClick && lastDoubleClick.time > now - 400 && posEq(lastDoubleClick.pos, start)) {
      type = "triple";
      e_preventDefault(e);
      setTimeout(bind(focusInput, cm), 20);
      selectLine(cm, start.line);
    } else if (lastClick && lastClick.time > now - 400 && posEq(lastClick.pos, start)) {
      type = "double";
      lastDoubleClick = {time: now, pos: start};
      e_preventDefault(e);
      var word = findWordAt(getLine(doc, start.line).text, start);
      extendSelection(cm.doc, word.from, word.to);
    } else { lastClick = {time: now, pos: start}; }

    var last = start;
    if (cm.options.dragDrop && dragAndDrop && !isReadOnly(cm) && !posEq(sel.from, sel.to) &&
        !posLess(start, sel.from) && !posLess(sel.to, start) && type == "single") {
      var dragEnd = operation(cm, function(e2) {
        if (webkit) display.scroller.draggable = false;
        cm.state.draggingText = false;
        off(document, "mouseup", dragEnd);
        off(display.scroller, "drop", dragEnd);
        if (Math.abs(e.clientX - e2.clientX) + Math.abs(e.clientY - e2.clientY) < 10) {
          e_preventDefault(e2);
          extendSelection(cm.doc, start);
          focusInput(cm);
        }
      });
      // Let the drag handler handle this.
      if (webkit) display.scroller.draggable = true;
      cm.state.draggingText = dragEnd;
      // IE's approach to draggable
      if (display.scroller.dragDrop) display.scroller.dragDrop();
      on(document, "mouseup", dragEnd);
      on(display.scroller, "drop", dragEnd);
      return;
    }
    e_preventDefault(e);
    if (type == "single") extendSelection(cm.doc, clipPos(doc, start));

    var startstart = sel.from, startend = sel.to, lastPos = start;

    function doSelect(cur) {
      if (posEq(lastPos, cur)) return;
      lastPos = cur;

      if (type == "single") {
        extendSelection(cm.doc, clipPos(doc, start), cur);
        return;
      }

      startstart = clipPos(doc, startstart);
      startend = clipPos(doc, startend);
      if (type == "double") {
        var word = findWordAt(getLine(doc, cur.line).text, cur);
        if (posLess(cur, startstart)) extendSelection(cm.doc, word.from, startend);
        else extendSelection(cm.doc, startstart, word.to);
      } else if (type == "triple") {
        if (posLess(cur, startstart)) extendSelection(cm.doc, startend, clipPos(doc, Pos(cur.line, 0)));
        else extendSelection(cm.doc, startstart, clipPos(doc, Pos(cur.line + 1, 0)));
      }
    }

    var editorSize = getRect(display.wrapper);
    // Used to ensure timeout re-tries don't fire when another extend
    // happened in the meantime (clearTimeout isn't reliable -- at
    // least on Chrome, the timeouts still happen even when cleared,
    // if the clear happens after their scheduled firing time).
    var counter = 0;

    function extend(e) {
      var curCount = ++counter;
      var cur = posFromMouse(cm, e, true);
      if (!cur) return;
      if (!posEq(cur, last)) {
        if (!cm.state.focused) onFocus(cm);
        last = cur;
        doSelect(cur);
        var visible = visibleLines(display, doc);
        if (cur.line >= visible.to || cur.line < visible.from)
          setTimeout(operation(cm, function(){if (counter == curCount) extend(e);}), 150);
      } else {
        var outside = e.clientY < editorSize.top ? -20 : e.clientY > editorSize.bottom ? 20 : 0;
        if (outside) setTimeout(operation(cm, function() {
          if (counter != curCount) return;
          display.scroller.scrollTop += outside;
          extend(e);
        }), 50);
      }
    }

    function done(e) {
      counter = Infinity;
      e_preventDefault(e);
      focusInput(cm);
      off(document, "mousemove", move);
      off(document, "mouseup", up);
    }

    var move = operation(cm, function(e) {
      if (!ie && !e_button(e)) done(e);
      else extend(e);
    });
    var up = operation(cm, done);
    on(document, "mousemove", move);
    on(document, "mouseup", up);
  }

  function clickInGutter(cm, e) {
    var display = cm.display;
    try { var mX = e.clientX, mY = e.clientY; }
    catch(e) { return false; }

    if (mX >= Math.floor(getRect(display.gutters).right)) return false;
    e_preventDefault(e);
    if (!hasHandler(cm, "gutterClick")) return true;

    var lineBox = getRect(display.lineDiv);
    if (mY > lineBox.bottom) return true;
    mY -= lineBox.top - display.viewOffset;

    for (var i = 0; i < cm.options.gutters.length; ++i) {
      var g = display.gutters.childNodes[i];
      if (g && getRect(g).right >= mX) {
        var line = lineAtHeight(cm.doc, mY);
        var gutter = cm.options.gutters[i];
        signalLater(cm, "gutterClick", cm, line, gutter, e);
        break;
      }
    }
    return true;
  }

  // Kludge to work around strange IE behavior where it'll sometimes
  // re-fire a series of drag-related events right after the drop (#1551)
  var lastDrop = 0;

  function onDrop(e) {
    var cm = this;
    if (signalDOMEvent(cm, e) || eventInWidget(cm.display, e) || (cm.options.onDragEvent && cm.options.onDragEvent(cm, addStop(e))))
      return;
    e_preventDefault(e);
    if (ie) lastDrop = +new Date;
    var pos = posFromMouse(cm, e, true), files = e.dataTransfer.files;
    if (!pos || isReadOnly(cm)) return;
    if (files && files.length && window.FileReader && window.File) {
      var n = files.length, text = Array(n), read = 0;
      var loadFile = function(file, i) {
        var reader = new FileReader;
        reader.onload = function() {
          text[i] = reader.result;
          if (++read == n) {
            pos = clipPos(cm.doc, pos);
            makeChange(cm.doc, {from: pos, to: pos, text: splitLines(text.join("\n")), origin: "paste"}, "around");
          }
        };
        reader.readAsText(file);
      };
      for (var i = 0; i < n; ++i) loadFile(files[i], i);
    } else {
      // Don't do a replace if the drop happened inside of the selected text.
      if (cm.state.draggingText && !(posLess(pos, cm.doc.sel.from) || posLess(cm.doc.sel.to, pos))) {
        cm.state.draggingText(e);
        // Ensure the editor is re-focused
        setTimeout(bind(focusInput, cm), 20);
        return;
      }
      try {
        var text = e.dataTransfer.getData("Text");
        if (text) {
          var curFrom = cm.doc.sel.from, curTo = cm.doc.sel.to;
          setSelection(cm.doc, pos, pos);
          if (cm.state.draggingText) replaceRange(cm.doc, "", curFrom, curTo, "paste");
          cm.replaceSelection(text, null, "paste");
          focusInput(cm);
          onFocus(cm);
        }
      }
      catch(e){}
    }
  }

  function onDragStart(cm, e) {
    if (ie && (!cm.state.draggingText || +new Date - lastDrop < 100)) { e_stop(e); return; }
    if (signalDOMEvent(cm, e) || eventInWidget(cm.display, e)) return;

    var txt = cm.getSelection();
    e.dataTransfer.setData("Text", txt);

    // Use dummy image instead of default browsers image.
    // Recent Safari (~6.0.2) have a tendency to segfault when this happens, so we don't do it there.
    if (e.dataTransfer.setDragImage && !safari) {
      var img = elt("img", null, null, "position: fixed; left: 0; top: 0;");
      if (opera) {
        img.width = img.height = 1;
        cm.display.wrapper.appendChild(img);
        // Force a relayout, or Opera won't use our image for some obscure reason
        img._top = img.offsetTop;
      }
      e.dataTransfer.setDragImage(img, 0, 0);
      if (opera) img.parentNode.removeChild(img);
    }
  }

  function setScrollTop(cm, val) {
    if (Math.abs(cm.doc.scrollTop - val) < 2) return;
    cm.doc.scrollTop = val;
    if (!gecko) updateDisplay(cm, [], val);
    if (cm.display.scroller.scrollTop != val) cm.display.scroller.scrollTop = val;
    if (cm.display.scrollbarV.scrollTop != val) cm.display.scrollbarV.scrollTop = val;
    if (gecko) updateDisplay(cm, []);
    startWorker(cm, 100);
  }
  function setScrollLeft(cm, val, isScroller) {
    if (isScroller ? val == cm.doc.scrollLeft : Math.abs(cm.doc.scrollLeft - val) < 2) return;
    val = Math.min(val, cm.display.scroller.scrollWidth - cm.display.scroller.clientWidth);
    cm.doc.scrollLeft = val;
    alignHorizontally(cm);
    if (cm.display.scroller.scrollLeft != val) cm.display.scroller.scrollLeft = val;
    if (cm.display.scrollbarH.scrollLeft != val) cm.display.scrollbarH.scrollLeft = val;
  }

  // Since the delta values reported on mouse wheel events are
  // unstandardized between browsers and even browser versions, and
  // generally horribly unpredictable, this code starts by measuring
  // the scroll effect that the first few mouse wheel events have,
  // and, from that, detects the way it can convert deltas to pixel
  // offsets afterwards.
  //
  // The reason we want to know the amount a wheel event will scroll
  // is that it gives us a chance to update the display before the
  // actual scrolling happens, reducing flickering.

  var wheelSamples = 0, wheelPixelsPerUnit = null;
  // Fill in a browser-detected starting value on browsers where we
  // know one. These don't have to be accurate -- the result of them
  // being wrong would just be a slight flicker on the first wheel
  // scroll (if it is large enough).
  if (ie) wheelPixelsPerUnit = -.53;
  else if (gecko) wheelPixelsPerUnit = 15;
  else if (chrome) wheelPixelsPerUnit = -.7;
  else if (safari) wheelPixelsPerUnit = -1/3;

  function onScrollWheel(cm, e) {
    var dx = e.wheelDeltaX, dy = e.wheelDeltaY;
    if (dx == null && e.detail && e.axis == e.HORIZONTAL_AXIS) dx = e.detail;
    if (dy == null && e.detail && e.axis == e.VERTICAL_AXIS) dy = e.detail;
    else if (dy == null) dy = e.wheelDelta;

    var display = cm.display, scroll = display.scroller;
    // Quit if there's nothing to scroll here
    if (!(dx && scroll.scrollWidth > scroll.clientWidth ||
          dy && scroll.scrollHeight > scroll.clientHeight)) return;

    // Webkit browsers on OS X abort momentum scrolls when the target
    // of the scroll event is removed from the scrollable element.
    // This hack (see related code in patchDisplay) makes sure the
    // element is kept around.
    if (dy && mac && webkit) {
      for (var cur = e.target; cur != scroll; cur = cur.parentNode) {
        if (cur.lineObj) {
          cm.display.currentWheelTarget = cur;
          break;
        }
      }
    }

    // On some browsers, horizontal scrolling will cause redraws to
    // happen before the gutter has been realigned, causing it to
    // wriggle around in a most unseemly way. When we have an
    // estimated pixels/delta value, we just handle horizontal
    // scrolling entirely here. It'll be slightly off from native, but
    // better than glitching out.
    if (dx && !gecko && !opera && wheelPixelsPerUnit != null) {
      if (dy)
        setScrollTop(cm, Math.max(0, Math.min(scroll.scrollTop + dy * wheelPixelsPerUnit, scroll.scrollHeight - scroll.clientHeight)));
      setScrollLeft(cm, Math.max(0, Math.min(scroll.scrollLeft + dx * wheelPixelsPerUnit, scroll.scrollWidth - scroll.clientWidth)));
      e_preventDefault(e);
      display.wheelStartX = null; // Abort measurement, if in progress
      return;
    }

    if (dy && wheelPixelsPerUnit != null) {
      var pixels = dy * wheelPixelsPerUnit;
      var top = cm.doc.scrollTop, bot = top + display.wrapper.clientHeight;
      if (pixels < 0) top = Math.max(0, top + pixels - 50);
      else bot = Math.min(cm.doc.height, bot + pixels + 50);
      updateDisplay(cm, [], {top: top, bottom: bot});
    }

    if (wheelSamples < 20) {
      if (display.wheelStartX == null) {
        display.wheelStartX = scroll.scrollLeft; display.wheelStartY = scroll.scrollTop;
        display.wheelDX = dx; display.wheelDY = dy;
        setTimeout(function() {
          if (display.wheelStartX == null) return;
          var movedX = scroll.scrollLeft - display.wheelStartX;
          var movedY = scroll.scrollTop - display.wheelStartY;
          var sample = (movedY && display.wheelDY && movedY / display.wheelDY) ||
            (movedX && display.wheelDX && movedX / display.wheelDX);
          display.wheelStartX = display.wheelStartY = null;
          if (!sample) return;
          wheelPixelsPerUnit = (wheelPixelsPerUnit * wheelSamples + sample) / (wheelSamples + 1);
          ++wheelSamples;
        }, 200);
      } else {
        display.wheelDX += dx; display.wheelDY += dy;
      }
    }
  }

  function doHandleBinding(cm, bound, dropShift) {
    if (typeof bound == "string") {
      bound = commands[bound];
      if (!bound) return false;
    }
    // Ensure previous input has been read, so that the handler sees a
    // consistent view of the document
    if (cm.display.pollingFast && readInput(cm)) cm.display.pollingFast = false;
    var doc = cm.doc, prevShift = doc.sel.shift, done = false;
    try {
      if (isReadOnly(cm)) cm.state.suppressEdits = true;
      if (dropShift) doc.sel.shift = false;
      done = bound(cm) != Pass;
    } finally {
      doc.sel.shift = prevShift;
      cm.state.suppressEdits = false;
    }
    return done;
  }

  function allKeyMaps(cm) {
    var maps = cm.state.keyMaps.slice(0);
    if (cm.options.extraKeys) maps.push(cm.options.extraKeys);
    maps.push(cm.options.keyMap);
    return maps;
  }

  var maybeTransition;
  function handleKeyBinding(cm, e) {
    // Handle auto keymap transitions
    var startMap = getKeyMap(cm.options.keyMap), next = startMap.auto;
    clearTimeout(maybeTransition);
    if (next && !isModifierKey(e)) maybeTransition = setTimeout(function() {
      if (getKeyMap(cm.options.keyMap) == startMap) {
        cm.options.keyMap = (next.call ? next.call(null, cm) : next);
        keyMapChanged(cm);
      }
    }, 50);

    var name = keyName(e, true), handled = false;
    if (!name) return false;
    var keymaps = allKeyMaps(cm);

    if (e.shiftKey) {
      // First try to resolve full name (including 'Shift-'). Failing
      // that, see if there is a cursor-motion command (starting with
      // 'go') bound to the keyname without 'Shift-'.
      handled = lookupKey("Shift-" + name, keymaps, function(b) {return doHandleBinding(cm, b, true);})
             || lookupKey(name, keymaps, function(b) {
                  if (typeof b == "string" ? /^go[A-Z]/.test(b) : b.motion)
                    return doHandleBinding(cm, b);
                });
    } else {
      handled = lookupKey(name, keymaps, function(b) { return doHandleBinding(cm, b); });
    }

    if (handled) {
      e_preventDefault(e);
      restartBlink(cm);
      if (ie_lt9) { e.oldKeyCode = e.keyCode; e.keyCode = 0; }
      signalLater(cm, "keyHandled", cm, name, e);
    }
    return handled;
  }

  function handleCharBinding(cm, e, ch) {
    var handled = lookupKey("'" + ch + "'", allKeyMaps(cm),
                            function(b) { return doHandleBinding(cm, b, true); });
    if (handled) {
      e_preventDefault(e);
      restartBlink(cm);
      signalLater(cm, "keyHandled", cm, "'" + ch + "'", e);
    }
    return handled;
  }

  var lastStoppedKey = null;
  function onKeyDown(e) {
    var cm = this;
    if (!cm.state.focused) onFocus(cm);
    if (ie && e.keyCode == 27) { e.returnValue = false; }
    if (signalDOMEvent(cm, e) || cm.options.onKeyEvent && cm.options.onKeyEvent(cm, addStop(e))) return;
    var code = e.keyCode;
    // IE does strange things with escape.
    cm.doc.sel.shift = code == 16 || e.shiftKey;
    // First give onKeyEvent option a chance to handle this.
    var handled = handleKeyBinding(cm, e);
    if (opera) {
      lastStoppedKey = handled ? code : null;
      // Opera has no cut event... we try to at least catch the key combo
      if (!handled && code == 88 && !hasCopyEvent && (mac ? e.metaKey : e.ctrlKey))
        cm.replaceSelection("");
    }
  }

  function onKeyPress(e) {
    var cm = this;
    if (signalDOMEvent(cm, e) || cm.options.onKeyEvent && cm.options.onKeyEvent(cm, addStop(e))) return;
    var keyCode = e.keyCode, charCode = e.charCode;
    if (opera && keyCode == lastStoppedKey) {lastStoppedKey = null; e_preventDefault(e); return;}
    if (((opera && (!e.which || e.which < 10)) || khtml) && handleKeyBinding(cm, e)) return;
    var ch = String.fromCharCode(charCode == null ? keyCode : charCode);
    if (this.options.electricChars && this.doc.mode.electricChars &&
        this.options.smartIndent && !isReadOnly(this) &&
        this.doc.mode.electricChars.indexOf(ch) > -1)
      setTimeout(operation(cm, function() {indentLine(cm, cm.doc.sel.to.line, "smart");}), 75);
    if (handleCharBinding(cm, e, ch)) return;
    if (ie && !ie_lt9) cm.display.inputHasSelection = null;
    fastPoll(cm);
  }

  function onFocus(cm) {
    if (cm.options.readOnly == "nocursor") return;
    if (!cm.state.focused) {
      signal(cm, "focus", cm);
      cm.state.focused = true;
      if (cm.display.wrapper.className.search(/\bCodeMirror-focused\b/) == -1)
        cm.display.wrapper.className += " CodeMirror-focused";
      resetInput(cm, true);
    }
    slowPoll(cm);
    restartBlink(cm);
  }
  function onBlur(cm) {
    if (cm.state.focused) {
      signal(cm, "blur", cm);
      cm.state.focused = false;
      cm.display.wrapper.className = cm.display.wrapper.className.replace(" CodeMirror-focused", "");
    }
    clearInterval(cm.display.blinker);
    setTimeout(function() {if (!cm.state.focused) cm.doc.sel.shift = false;}, 150);
  }

  var detectingSelectAll;
  function onContextMenu(cm, e) {
    if (signalDOMEvent(cm, e, "contextmenu")) return;
    var display = cm.display, sel = cm.doc.sel;
    if (eventInWidget(display, e)) return;

    var pos = posFromMouse(cm, e), scrollPos = display.scroller.scrollTop;
    if (!pos || opera) return; // Opera is difficult.
    if (posEq(sel.from, sel.to) || posLess(pos, sel.from) || !posLess(pos, sel.to))
      operation(cm, setSelection)(cm.doc, pos, pos);

    var oldCSS = display.input.style.cssText;
    display.inputDiv.style.position = "absolute";
    display.input.style.cssText = "position: fixed; width: 30px; height: 30px; top: " + (e.clientY - 5) +
      "px; left: " + (e.clientX - 5) + "px; z-index: 1000; background: white; outline: none;" +
      "border-width: 0; outline: none; overflow: hidden; opacity: .05; -ms-opacity: .05; filter: alpha(opacity=5);";
    focusInput(cm);
    resetInput(cm, true);
    // Adds "Select all" to context menu in FF
    if (posEq(sel.from, sel.to)) display.input.value = display.prevInput = " ";

    function prepareSelectAllHack() {
      if (display.input.selectionStart != null) {
        var extval = display.input.value = " " + (posEq(sel.from, sel.to) ? "" : display.input.value);
        display.prevInput = " ";
        display.input.selectionStart = 1; display.input.selectionEnd = extval.length;
      }
    }
    function rehide() {
      display.inputDiv.style.position = "relative";
      display.input.style.cssText = oldCSS;
      if (ie_lt9) display.scrollbarV.scrollTop = display.scroller.scrollTop = scrollPos;
      slowPoll(cm);

      // Try to detect the user choosing select-all
      if (display.input.selectionStart != null) {
        if (!ie || ie_lt9) prepareSelectAllHack();
        clearTimeout(detectingSelectAll);
        var i = 0, poll = function(){
          if (display.prevInput == " " && display.input.selectionStart == 0)
            operation(cm, commands.selectAll)(cm);
          else if (i++ < 10) detectingSelectAll = setTimeout(poll, 500);
          else resetInput(cm);
        };
        detectingSelectAll = setTimeout(poll, 200);
      }
    }

    if (ie && !ie_lt9) prepareSelectAllHack();
    if (captureMiddleClick) {
      e_stop(e);
      var mouseup = function() {
        off(window, "mouseup", mouseup);
        setTimeout(rehide, 20);
      };
      on(window, "mouseup", mouseup);
    } else {
      setTimeout(rehide, 50);
    }
  }

  // UPDATING

  var changeEnd = CodeMirror.changeEnd = function(change) {
    if (!change.text) return change.to;
    return Pos(change.from.line + change.text.length - 1,
               lst(change.text).length + (change.text.length == 1 ? change.from.ch : 0));
  };

  // Make sure a position will be valid after the given change.
  function clipPostChange(doc, change, pos) {
    if (!posLess(change.from, pos)) return clipPos(doc, pos);
    var diff = (change.text.length - 1) - (change.to.line - change.from.line);
    if (pos.line > change.to.line + diff) {
      var preLine = pos.line - diff, lastLine = doc.first + doc.size - 1;
      if (preLine > lastLine) return Pos(lastLine, getLine(doc, lastLine).text.length);
      return clipToLen(pos, getLine(doc, preLine).text.length);
    }
    if (pos.line == change.to.line + diff)
      return clipToLen(pos, lst(change.text).length + (change.text.length == 1 ? change.from.ch : 0) +
                       getLine(doc, change.to.line).text.length - change.to.ch);
    var inside = pos.line - change.from.line;
    return clipToLen(pos, change.text[inside].length + (inside ? 0 : change.from.ch));
  }

  // Hint can be null|"end"|"start"|"around"|{anchor,head}
  function computeSelAfterChange(doc, change, hint) {
    if (hint && typeof hint == "object") // Assumed to be {anchor, head} object
      return {anchor: clipPostChange(doc, change, hint.anchor),
              head: clipPostChange(doc, change, hint.head)};

    if (hint == "start") return {anchor: change.from, head: change.from};

    var end = changeEnd(change);
    if (hint == "around") return {anchor: change.from, head: end};
    if (hint == "end") return {anchor: end, head: end};

    // hint is null, leave the selection alone as much as possible
    var adjustPos = function(pos) {
      if (posLess(pos, change.from)) return pos;
      if (!posLess(change.to, pos)) return end;

      var line = pos.line + change.text.length - (change.to.line - change.from.line) - 1, ch = pos.ch;
      if (pos.line == change.to.line) ch += end.ch - change.to.ch;
      return Pos(line, ch);
    };
    return {anchor: adjustPos(doc.sel.anchor), head: adjustPos(doc.sel.head)};
  }

  function filterChange(doc, change, update) {
    var obj = {
      canceled: false,
      from: change.from,
      to: change.to,
      text: change.text,
      origin: change.origin,
      cancel: function() { this.canceled = true; }
    };
    if (update) obj.update = function(from, to, text, origin) {
      if (from) this.from = clipPos(doc, from);
      if (to) this.to = clipPos(doc, to);
      if (text) this.text = text;
      if (origin !== undefined) this.origin = origin;
    };
    signal(doc, "beforeChange", doc, obj);
    if (doc.cm) signal(doc.cm, "beforeChange", doc.cm, obj);

    if (obj.canceled) return null;
    return {from: obj.from, to: obj.to, text: obj.text, origin: obj.origin};
  }

  // Replace the range from from to to by the strings in replacement.
  // change is a {from, to, text [, origin]} object
  function makeChange(doc, change, selUpdate, ignoreReadOnly) {
    if (doc.cm) {
      if (!doc.cm.curOp) return operation(doc.cm, makeChange)(doc, change, selUpdate, ignoreReadOnly);
      if (doc.cm.state.suppressEdits) return;
    }

    if (hasHandler(doc, "beforeChange") || doc.cm && hasHandler(doc.cm, "beforeChange")) {
      change = filterChange(doc, change, true);
      if (!change) return;
    }

    // Possibly split or suppress the update based on the presence
    // of read-only spans in its range.
    var split = sawReadOnlySpans && !ignoreReadOnly && removeReadOnlyRanges(doc, change.from, change.to);
    if (split) {
      for (var i = split.length - 1; i >= 1; --i)
        makeChangeNoReadonly(doc, {from: split[i].from, to: split[i].to, text: [""]});
      if (split.length)
        makeChangeNoReadonly(doc, {from: split[0].from, to: split[0].to, text: change.text}, selUpdate);
    } else {
      makeChangeNoReadonly(doc, change, selUpdate);
    }
  }

  function makeChangeNoReadonly(doc, change, selUpdate) {
    var selAfter = computeSelAfterChange(doc, change, selUpdate);
    addToHistory(doc, change, selAfter, doc.cm ? doc.cm.curOp.id : NaN);

    makeChangeSingleDoc(doc, change, selAfter, stretchSpansOverChange(doc, change));
    var rebased = [];

    linkedDocs(doc, function(doc, sharedHist) {
      if (!sharedHist && indexOf(rebased, doc.history) == -1) {
        rebaseHist(doc.history, change);
        rebased.push(doc.history);
      }
      makeChangeSingleDoc(doc, change, null, stretchSpansOverChange(doc, change));
    });
  }

  function makeChangeFromHistory(doc, type) {
    if (doc.cm && doc.cm.state.suppressEdits) return;

    var hist = doc.history;
    var event = (type == "undo" ? hist.done : hist.undone).pop();
    if (!event) return;

    var anti = {changes: [], anchorBefore: event.anchorAfter, headBefore: event.headAfter,
                anchorAfter: event.anchorBefore, headAfter: event.headBefore,
                generation: hist.generation};
    (type == "undo" ? hist.undone : hist.done).push(anti);
    hist.generation = event.generation || ++hist.maxGeneration;

    var filter = hasHandler(doc, "beforeChange") || doc.cm && hasHandler(doc.cm, "beforeChange");

    for (var i = event.changes.length - 1; i >= 0; --i) {
      var change = event.changes[i];
      change.origin = type;
      if (filter && !filterChange(doc, change, false)) {
        (type == "undo" ? hist.done : hist.undone).length = 0;
        return;
      }

      anti.changes.push(historyChangeFromChange(doc, change));

      var after = i ? computeSelAfterChange(doc, change, null)
                    : {anchor: event.anchorBefore, head: event.headBefore};
      makeChangeSingleDoc(doc, change, after, mergeOldSpans(doc, change));
      var rebased = [];

      linkedDocs(doc, function(doc, sharedHist) {
        if (!sharedHist && indexOf(rebased, doc.history) == -1) {
          rebaseHist(doc.history, change);
          rebased.push(doc.history);
        }
        makeChangeSingleDoc(doc, change, null, mergeOldSpans(doc, change));
      });
    }
  }

  function shiftDoc(doc, distance) {
    function shiftPos(pos) {return Pos(pos.line + distance, pos.ch);}
    doc.first += distance;
    if (doc.cm) regChange(doc.cm, doc.first, doc.first, distance);
    doc.sel.head = shiftPos(doc.sel.head); doc.sel.anchor = shiftPos(doc.sel.anchor);
    doc.sel.from = shiftPos(doc.sel.from); doc.sel.to = shiftPos(doc.sel.to);
  }

  function makeChangeSingleDoc(doc, change, selAfter, spans) {
    if (doc.cm && !doc.cm.curOp)
      return operation(doc.cm, makeChangeSingleDoc)(doc, change, selAfter, spans);

    if (change.to.line < doc.first) {
      shiftDoc(doc, change.text.length - 1 - (change.to.line - change.from.line));
      return;
    }
    if (change.from.line > doc.lastLine()) return;

    // Clip the change to the size of this doc
    if (change.from.line < doc.first) {
      var shift = change.text.length - 1 - (doc.first - change.from.line);
      shiftDoc(doc, shift);
      change = {from: Pos(doc.first, 0), to: Pos(change.to.line + shift, change.to.ch),
                text: [lst(change.text)], origin: change.origin};
    }
    var last = doc.lastLine();
    if (change.to.line > last) {
      change = {from: change.from, to: Pos(last, getLine(doc, last).text.length),
                text: [change.text[0]], origin: change.origin};
    }

    change.removed = getBetween(doc, change.from, change.to);

    if (!selAfter) selAfter = computeSelAfterChange(doc, change, null);
    if (doc.cm) makeChangeSingleDocInEditor(doc.cm, change, spans, selAfter);
    else updateDoc(doc, change, spans, selAfter);
  }

  function makeChangeSingleDocInEditor(cm, change, spans, selAfter) {
    var doc = cm.doc, display = cm.display, from = change.from, to = change.to;

    var recomputeMaxLength = false, checkWidthStart = from.line;
    if (!cm.options.lineWrapping) {
      checkWidthStart = lineNo(visualLine(doc, getLine(doc, from.line)));
      doc.iter(checkWidthStart, to.line + 1, function(line) {
        if (line == display.maxLine) {
          recomputeMaxLength = true;
          return true;
        }
      });
    }

    if (!posLess(doc.sel.head, change.from) && !posLess(change.to, doc.sel.head))
      cm.curOp.cursorActivity = true;

    updateDoc(doc, change, spans, selAfter, estimateHeight(cm));

    if (!cm.options.lineWrapping) {
      doc.iter(checkWidthStart, from.line + change.text.length, function(line) {
        var len = lineLength(doc, line);
        if (len > display.maxLineLength) {
          display.maxLine = line;
          display.maxLineLength = len;
          display.maxLineChanged = true;
          recomputeMaxLength = false;
        }
      });
      if (recomputeMaxLength) cm.curOp.updateMaxLine = true;
    }

    // Adjust frontier, schedule worker
    doc.frontier = Math.min(doc.frontier, from.line);
    startWorker(cm, 400);

    var lendiff = change.text.length - (to.line - from.line) - 1;
    // Remember that these lines changed, for updating the display
    regChange(cm, from.line, to.line + 1, lendiff);

    if (hasHandler(cm, "change")) {
      var changeObj = {from: from, to: to,
                       text: change.text,
                       removed: change.removed,
                       origin: change.origin};
      if (cm.curOp.textChanged) {
        for (var cur = cm.curOp.textChanged; cur.next; cur = cur.next) {}
        cur.next = changeObj;
      } else cm.curOp.textChanged = changeObj;
    }
  }

  function replaceRange(doc, code, from, to, origin) {
    if (!to) to = from;
    if (posLess(to, from)) { var tmp = to; to = from; from = tmp; }
    if (typeof code == "string") code = splitLines(code);
    makeChange(doc, {from: from, to: to, text: code, origin: origin}, null);
  }

  // POSITION OBJECT

  function Pos(line, ch) {
    if (!(this instanceof Pos)) return new Pos(line, ch);
    this.line = line; this.ch = ch;
  }
  CodeMirror.Pos = Pos;

  function posEq(a, b) {return a.line == b.line && a.ch == b.ch;}
  function posLess(a, b) {return a.line < b.line || (a.line == b.line && a.ch < b.ch);}
  function copyPos(x) {return Pos(x.line, x.ch);}

  // SELECTION

  function clipLine(doc, n) {return Math.max(doc.first, Math.min(n, doc.first + doc.size - 1));}
  function clipPos(doc, pos) {
    if (pos.line < doc.first) return Pos(doc.first, 0);
    var last = doc.first + doc.size - 1;
    if (pos.line > last) return Pos(last, getLine(doc, last).text.length);
    return clipToLen(pos, getLine(doc, pos.line).text.length);
  }
  function clipToLen(pos, linelen) {
    var ch = pos.ch;
    if (ch == null || ch > linelen) return Pos(pos.line, linelen);
    else if (ch < 0) return Pos(pos.line, 0);
    else return pos;
  }
  function isLine(doc, l) {return l >= doc.first && l < doc.first + doc.size;}

  // If shift is held, this will move the selection anchor. Otherwise,
  // it'll set the whole selection.
  function extendSelection(doc, pos, other, bias) {
    if (doc.sel.shift || doc.sel.extend) {
      var anchor = doc.sel.anchor;
      if (other) {
        var posBefore = posLess(pos, anchor);
        if (posBefore != posLess(other, anchor)) {
          anchor = pos;
          pos = other;
        } else if (posBefore != posLess(pos, other)) {
          pos = other;
        }
      }
      setSelection(doc, anchor, pos, bias);
    } else {
      setSelection(doc, pos, other || pos, bias);
    }
    if (doc.cm) doc.cm.curOp.userSelChange = true;
  }

  function filterSelectionChange(doc, anchor, head) {
    var obj = {anchor: anchor, head: head};
    signal(doc, "beforeSelectionChange", doc, obj);
    if (doc.cm) signal(doc.cm, "beforeSelectionChange", doc.cm, obj);
    obj.anchor = clipPos(doc, obj.anchor); obj.head = clipPos(doc, obj.head);
    return obj;
  }

  // Update the selection. Last two args are only used by
  // updateDoc, since they have to be expressed in the line
  // numbers before the update.
  function setSelection(doc, anchor, head, bias, checkAtomic) {
    if (!checkAtomic && hasHandler(doc, "beforeSelectionChange") || doc.cm && hasHandler(doc.cm, "beforeSelectionChange")) {
      var filtered = filterSelectionChange(doc, anchor, head);
      head = filtered.head;
      anchor = filtered.anchor;
    }

    var sel = doc.sel;
    sel.goalColumn = null;
    // Skip over atomic spans.
    if (checkAtomic || !posEq(anchor, sel.anchor))
      anchor = skipAtomic(doc, anchor, bias, checkAtomic != "push");
    if (checkAtomic || !posEq(head, sel.head))
      head = skipAtomic(doc, head, bias, checkAtomic != "push");

    if (posEq(sel.anchor, anchor) && posEq(sel.head, head)) return;

    sel.anchor = anchor; sel.head = head;
    var inv = posLess(head, anchor);
    sel.from = inv ? head : anchor;
    sel.to = inv ? anchor : head;

    if (doc.cm)
      doc.cm.curOp.updateInput = doc.cm.curOp.selectionChanged =
        doc.cm.curOp.cursorActivity = true;

    signalLater(doc, "cursorActivity", doc);
  }

  function reCheckSelection(cm) {
    setSelection(cm.doc, cm.doc.sel.from, cm.doc.sel.to, null, "push");
  }

  function skipAtomic(doc, pos, bias, mayClear) {
    var flipped = false, curPos = pos;
    var dir = bias || 1;
    doc.cantEdit = false;
    search: for (;;) {
      var line = getLine(doc, curPos.line);
      if (line.markedSpans) {
        for (var i = 0; i < line.markedSpans.length; ++i) {
          var sp = line.markedSpans[i], m = sp.marker;
          if ((sp.from == null || (m.inclusiveLeft ? sp.from <= curPos.ch : sp.from < curPos.ch)) &&
              (sp.to == null || (m.inclusiveRight ? sp.to >= curPos.ch : sp.to > curPos.ch))) {
            if (mayClear) {
              signal(m, "beforeCursorEnter");
              if (m.explicitlyCleared) {
                if (!line.markedSpans) break;
                else {--i; continue;}
              }
            }
            if (!m.atomic) continue;
            var newPos = m.find()[dir < 0 ? "from" : "to"];
            if (posEq(newPos, curPos)) {
              newPos.ch += dir;
              if (newPos.ch < 0) {
                if (newPos.line > doc.first) newPos = clipPos(doc, Pos(newPos.line - 1));
                else newPos = null;
              } else if (newPos.ch > line.text.length) {
                if (newPos.line < doc.first + doc.size - 1) newPos = Pos(newPos.line + 1, 0);
                else newPos = null;
              }
              if (!newPos) {
                if (flipped) {
                  // Driven in a corner -- no valid cursor position found at all
                  // -- try again *with* clearing, if we didn't already
                  if (!mayClear) return skipAtomic(doc, pos, bias, true);
                  // Otherwise, turn off editing until further notice, and return the start of the doc
                  doc.cantEdit = true;
                  return Pos(doc.first, 0);
                }
                flipped = true; newPos = pos; dir = -dir;
              }
            }
            curPos = newPos;
            continue search;
          }
        }
      }
      return curPos;
    }
  }

  // SCROLLING

  function scrollCursorIntoView(cm) {
    var coords = scrollPosIntoView(cm, cm.doc.sel.head, cm.options.cursorScrollMargin);
    if (!cm.state.focused) return;
    var display = cm.display, box = getRect(display.sizer), doScroll = null;
    if (coords.top + box.top < 0) doScroll = true;
    else if (coords.bottom + box.top > (window.innerHeight || document.documentElement.clientHeight)) doScroll = false;
    if (doScroll != null && !phantom) {
      var hidden = display.cursor.style.display == "none";
      if (hidden) {
        display.cursor.style.display = "";
        display.cursor.style.left = coords.left + "px";
        display.cursor.style.top = (coords.top - display.viewOffset) + "px";
      }
      display.cursor.scrollIntoView(doScroll);
      if (hidden) display.cursor.style.display = "none";
    }
  }

  function scrollPosIntoView(cm, pos, margin) {
    if (margin == null) margin = 0;
    for (;;) {
      var changed = false, coords = cursorCoords(cm, pos);
      var scrollPos = calculateScrollPos(cm, coords.left, coords.top - margin, coords.left, coords.bottom + margin);
      var startTop = cm.doc.scrollTop, startLeft = cm.doc.scrollLeft;
      if (scrollPos.scrollTop != null) {
        setScrollTop(cm, scrollPos.scrollTop);
        if (Math.abs(cm.doc.scrollTop - startTop) > 1) changed = true;
      }
      if (scrollPos.scrollLeft != null) {
        setScrollLeft(cm, scrollPos.scrollLeft);
        if (Math.abs(cm.doc.scrollLeft - startLeft) > 1) changed = true;
      }
      if (!changed) return coords;
    }
  }

  function scrollIntoView(cm, x1, y1, x2, y2) {
    var scrollPos = calculateScrollPos(cm, x1, y1, x2, y2);
    if (scrollPos.scrollTop != null) setScrollTop(cm, scrollPos.scrollTop);
    if (scrollPos.scrollLeft != null) setScrollLeft(cm, scrollPos.scrollLeft);
  }

  function calculateScrollPos(cm, x1, y1, x2, y2) {
    var display = cm.display, snapMargin = textHeight(cm.display);
    if (y1 < 0) y1 = 0;
    var screen = display.scroller.clientHeight - scrollerCutOff, screentop = display.scroller.scrollTop, result = {};
    var docBottom = cm.doc.height + paddingVert(display);
    var atTop = y1 < snapMargin, atBottom = y2 > docBottom - snapMargin;
    if (y1 < screentop) {
      result.scrollTop = atTop ? 0 : y1;
    } else if (y2 > screentop + screen) {
      var newTop = Math.min(y1, (atBottom ? docBottom : y2) - screen);
      if (newTop != screentop) result.scrollTop = newTop;
    }

    var screenw = display.scroller.clientWidth - scrollerCutOff, screenleft = display.scroller.scrollLeft;
    x1 += display.gutters.offsetWidth; x2 += display.gutters.offsetWidth;
    var gutterw = display.gutters.offsetWidth;
    var atLeft = x1 < gutterw + 10;
    if (x1 < screenleft + gutterw || atLeft) {
      if (atLeft) x1 = 0;
      result.scrollLeft = Math.max(0, x1 - 10 - gutterw);
    } else if (x2 > screenw + screenleft - 3) {
      result.scrollLeft = x2 + 10 - screenw;
    }
    return result;
  }

  function updateScrollPos(cm, left, top) {
    cm.curOp.updateScrollPos = {scrollLeft: left == null ? cm.doc.scrollLeft : left,
                                scrollTop: top == null ? cm.doc.scrollTop : top};
  }

  function addToScrollPos(cm, left, top) {
    var pos = cm.curOp.updateScrollPos || (cm.curOp.updateScrollPos = {scrollLeft: cm.doc.scrollLeft, scrollTop: cm.doc.scrollTop});
    var scroll = cm.display.scroller;
    pos.scrollTop = Math.max(0, Math.min(scroll.scrollHeight - scroll.clientHeight, pos.scrollTop + top));
    pos.scrollLeft = Math.max(0, Math.min(scroll.scrollWidth - scroll.clientWidth, pos.scrollLeft + left));
  }

  // API UTILITIES

  function indentLine(cm, n, how, aggressive) {
    var doc = cm.doc;
    if (how == null) how = "add";
    if (how == "smart") {
      if (!cm.doc.mode.indent) how = "prev";
      else var state = getStateBefore(cm, n);
    }

    var tabSize = cm.options.tabSize;
    var line = getLine(doc, n), curSpace = countColumn(line.text, null, tabSize);
    var curSpaceString = line.text.match(/^\s*/)[0], indentation;
    if (how == "smart") {
      indentation = cm.doc.mode.indent(state, line.text.slice(curSpaceString.length), line.text);
      if (indentation == Pass) {
        if (!aggressive) return;
        how = "prev";
      }
    }
    if (how == "prev") {
      if (n > doc.first) indentation = countColumn(getLine(doc, n-1).text, null, tabSize);
      else indentation = 0;
    } else if (how == "add") {
      indentation = curSpace + cm.options.indentUnit;
    } else if (how == "subtract") {
      indentation = curSpace - cm.options.indentUnit;
    } else if (typeof how == "number") {
      indentation = curSpace + how;
    }
    indentation = Math.max(0, indentation);

    var indentString = "", pos = 0;
    if (cm.options.indentWithTabs)
      for (var i = Math.floor(indentation / tabSize); i; --i) {pos += tabSize; indentString += "\t";}
    if (pos < indentation) indentString += spaceStr(indentation - pos);

    if (indentString != curSpaceString)
      replaceRange(cm.doc, indentString, Pos(n, 0), Pos(n, curSpaceString.length), "+input");
    line.stateAfter = null;
  }

  function changeLine(cm, handle, op) {
    var no = handle, line = handle, doc = cm.doc;
    if (typeof handle == "number") line = getLine(doc, clipLine(doc, handle));
    else no = lineNo(handle);
    if (no == null) return null;
    if (op(line, no)) regChange(cm, no, no + 1);
    else return null;
    return line;
  }

  function findPosH(doc, pos, dir, unit, visually) {
    var line = pos.line, ch = pos.ch, origDir = dir;
    var lineObj = getLine(doc, line);
    var possible = true;
    function findNextLine() {
      var l = line + dir;
      if (l < doc.first || l >= doc.first + doc.size) return (possible = false);
      line = l;
      return lineObj = getLine(doc, l);
    }
    function moveOnce(boundToLine) {
      var next = (visually ? moveVisually : moveLogically)(lineObj, ch, dir, true);
      if (next == null) {
        if (!boundToLine && findNextLine()) {
          if (visually) ch = (dir < 0 ? lineRight : lineLeft)(lineObj);
          else ch = dir < 0 ? lineObj.text.length : 0;
        } else return (possible = false);
      } else ch = next;
      return true;
    }

    if (unit == "char") moveOnce();
    else if (unit == "column") moveOnce(true);
    else if (unit == "word" || unit == "group") {
      var sawType = null, group = unit == "group";
      for (var first = true;; first = false) {
        if (dir < 0 && !moveOnce(!first)) break;
        var cur = lineObj.text.charAt(ch) || "\n";
        var type = isWordChar(cur) ? "w"
          : !group ? null
          : /\s/.test(cur) ? null
          : "p";
        if (sawType && sawType != type) {
          if (dir < 0) {dir = 1; moveOnce();}
          break;
        }
        if (type) sawType = type;
        if (dir > 0 && !moveOnce(!first)) break;
      }
    }
    var result = skipAtomic(doc, Pos(line, ch), origDir, true);
    if (!possible) result.hitSide = true;
    return result;
  }

  function findPosV(cm, pos, dir, unit) {
    var doc = cm.doc, x = pos.left, y;
    if (unit == "page") {
      var pageSize = Math.min(cm.display.wrapper.clientHeight, window.innerHeight || document.documentElement.clientHeight);
      y = pos.top + dir * (pageSize - (dir < 0 ? 1.5 : .5) * textHeight(cm.display));
    } else if (unit == "line") {
      y = dir > 0 ? pos.bottom + 3 : pos.top - 3;
    }
    for (;;) {
      var target = coordsChar(cm, x, y);
      if (!target.outside) break;
      if (dir < 0 ? y <= 0 : y >= doc.height) { target.hitSide = true; break; }
      y += dir * 5;
    }
    return target;
  }

  function findWordAt(line, pos) {
    var start = pos.ch, end = pos.ch;
    if (line) {
      if ((pos.xRel < 0 || end == line.length) && start) --start; else ++end;
      var startChar = line.charAt(start);
      var check = isWordChar(startChar) ? isWordChar
        : /\s/.test(startChar) ? function(ch) {return /\s/.test(ch);}
        : function(ch) {return !/\s/.test(ch) && !isWordChar(ch);};
      while (start > 0 && check(line.charAt(start - 1))) --start;
      while (end < line.length && check(line.charAt(end))) ++end;
    }
    return {from: Pos(pos.line, start), to: Pos(pos.line, end)};
  }

  function selectLine(cm, line) {
    extendSelection(cm.doc, Pos(line, 0), clipPos(cm.doc, Pos(line + 1, 0)));
  }

  // PROTOTYPE

  // The publicly visible API. Note that operation(null, f) means
  // 'wrap f in an operation, performed on its `this` parameter'

  CodeMirror.prototype = {
    constructor: CodeMirror,
    focus: function(){window.focus(); focusInput(this); onFocus(this); fastPoll(this);},

    setOption: function(option, value) {
      var options = this.options, old = options[option];
      if (options[option] == value && option != "mode") return;
      options[option] = value;
      if (optionHandlers.hasOwnProperty(option))
        operation(this, optionHandlers[option])(this, value, old);
    },

    getOption: function(option) {return this.options[option];},
    getDoc: function() {return this.doc;},

    addKeyMap: function(map, bottom) {
      this.state.keyMaps[bottom ? "push" : "unshift"](map);
    },
    removeKeyMap: function(map) {
      var maps = this.state.keyMaps;
      for (var i = 0; i < maps.length; ++i)
        if (maps[i] == map || (typeof maps[i] != "string" && maps[i].name == map)) {
          maps.splice(i, 1);
          return true;
        }
    },

    addOverlay: operation(null, function(spec, options) {
      var mode = spec.token ? spec : CodeMirror.getMode(this.options, spec);
      if (mode.startState) throw new Error("Overlays may not be stateful.");
      this.state.overlays.push({mode: mode, modeSpec: spec, opaque: options && options.opaque});
      this.state.modeGen++;
      regChange(this);
    }),
    removeOverlay: operation(null, function(spec) {
      var overlays = this.state.overlays;
      for (var i = 0; i < overlays.length; ++i) {
        var cur = overlays[i].modeSpec;
        if (cur == spec || typeof spec == "string" && cur.name == spec) {
          overlays.splice(i, 1);
          this.state.modeGen++;
          regChange(this);
          return;
        }
      }
    }),

    indentLine: operation(null, function(n, dir, aggressive) {
      if (typeof dir != "string" && typeof dir != "number") {
        if (dir == null) dir = this.options.smartIndent ? "smart" : "prev";
        else dir = dir ? "add" : "subtract";
      }
      if (isLine(this.doc, n)) indentLine(this, n, dir, aggressive);
    }),
    indentSelection: operation(null, function(how) {
      var sel = this.doc.sel;
      if (posEq(sel.from, sel.to)) return indentLine(this, sel.from.line, how);
      var e = sel.to.line - (sel.to.ch ? 0 : 1);
      for (var i = sel.from.line; i <= e; ++i) indentLine(this, i, how);
    }),

    // Fetch the parser token for a given character. Useful for hacks
    // that want to inspect the mode state (say, for completion).
    getTokenAt: function(pos, precise) {
      var doc = this.doc;
      pos = clipPos(doc, pos);
      var state = getStateBefore(this, pos.line, precise), mode = this.doc.mode;
      var line = getLine(doc, pos.line);
      var stream = new StringStream(line.text, this.options.tabSize);
      while (stream.pos < pos.ch && !stream.eol()) {
        stream.start = stream.pos;
        var style = mode.token(stream, state);
      }
      return {start: stream.start,
              end: stream.pos,
              string: stream.current(),
              className: style || null, // Deprecated, use 'type' instead
              type: style || null,
              state: state};
    },

    getTokenTypeAt: function(pos) {
      pos = clipPos(this.doc, pos);
      var styles = getLineStyles(this, getLine(this.doc, pos.line));
      var before = 0, after = (styles.length - 1) / 2, ch = pos.ch;
      if (ch == 0) return styles[2];
      for (;;) {
        var mid = (before + after) >> 1;
        if ((mid ? styles[mid * 2 - 1] : 0) >= ch) after = mid;
        else if (styles[mid * 2 + 1] < ch) before = mid + 1;
        else return styles[mid * 2 + 2];
      }
    },

    getModeAt: function(pos) {
      var mode = this.doc.mode;
      if (!mode.innerMode) return mode;
      return CodeMirror.innerMode(mode, this.getTokenAt(pos).state).mode;
    },

    getHelper: function(pos, type) {
      if (!helpers.hasOwnProperty(type)) return;
      var help = helpers[type], mode = this.getModeAt(pos);
      return mode[type] && help[mode[type]] ||
        mode.helperType && help[mode.helperType] ||
        help[mode.name];
    },

    getStateAfter: function(line, precise) {
      var doc = this.doc;
      line = clipLine(doc, line == null ? doc.first + doc.size - 1: line);
      return getStateBefore(this, line + 1, precise);
    },

    cursorCoords: function(start, mode) {
      var pos, sel = this.doc.sel;
      if (start == null) pos = sel.head;
      else if (typeof start == "object") pos = clipPos(this.doc, start);
      else pos = start ? sel.from : sel.to;
      return cursorCoords(this, pos, mode || "page");
    },

    charCoords: function(pos, mode) {
      return charCoords(this, clipPos(this.doc, pos), mode || "page");
    },

    coordsChar: function(coords, mode) {
      coords = fromCoordSystem(this, coords, mode || "page");
      return coordsChar(this, coords.left, coords.top);
    },

    lineAtHeight: function(height, mode) {
      height = fromCoordSystem(this, {top: height, left: 0}, mode || "page").top;
      return lineAtHeight(this.doc, height + this.display.viewOffset);
    },
    heightAtLine: function(line, mode) {
      var end = false, last = this.doc.first + this.doc.size - 1;
      if (line < this.doc.first) line = this.doc.first;
      else if (line > last) { line = last; end = true; }
      var lineObj = getLine(this.doc, line);
      return intoCoordSystem(this, getLine(this.doc, line), {top: 0, left: 0}, mode || "page").top +
        (end ? lineObj.height : 0);
    },

    defaultTextHeight: function() { return textHeight(this.display); },
    defaultCharWidth: function() { return charWidth(this.display); },

    setGutterMarker: operation(null, function(line, gutterID, value) {
      return changeLine(this, line, function(line) {
        var markers = line.gutterMarkers || (line.gutterMarkers = {});
        markers[gutterID] = value;
        if (!value && isEmpty(markers)) line.gutterMarkers = null;
        return true;
      });
    }),

    clearGutter: operation(null, function(gutterID) {
      var cm = this, doc = cm.doc, i = doc.first;
      doc.iter(function(line) {
        if (line.gutterMarkers && line.gutterMarkers[gutterID]) {
          line.gutterMarkers[gutterID] = null;
          regChange(cm, i, i + 1);
          if (isEmpty(line.gutterMarkers)) line.gutterMarkers = null;
        }
        ++i;
      });
    }),

    addLineClass: operation(null, function(handle, where, cls) {
      return changeLine(this, handle, function(line) {
        var prop = where == "text" ? "textClass" : where == "background" ? "bgClass" : "wrapClass";
        if (!line[prop]) line[prop] = cls;
        else if (new RegExp("(?:^|\\s)" + cls + "(?:$|\\s)").test(line[prop])) return false;
        else line[prop] += " " + cls;
        return true;
      });
    }),

    removeLineClass: operation(null, function(handle, where, cls) {
      return changeLine(this, handle, function(line) {
        var prop = where == "text" ? "textClass" : where == "background" ? "bgClass" : "wrapClass";
        var cur = line[prop];
        if (!cur) return false;
        else if (cls == null) line[prop] = null;
        else {
          var found = cur.match(new RegExp("(?:^|\\s+)" + cls + "(?:$|\\s+)"));
          if (!found) return false;
          var end = found.index + found[0].length;
          line[prop] = cur.slice(0, found.index) + (!found.index || end == cur.length ? "" : " ") + cur.slice(end) || null;
        }
        return true;
      });
    }),

    addLineWidget: operation(null, function(handle, node, options) {
      return addLineWidget(this, handle, node, options);
    }),

    removeLineWidget: function(widget) { widget.clear(); },

    lineInfo: function(line) {
      if (typeof line == "number") {
        if (!isLine(this.doc, line)) return null;
        var n = line;
        line = getLine(this.doc, line);
        if (!line) return null;
      } else {
        var n = lineNo(line);
        if (n == null) return null;
      }
      return {line: n, handle: line, text: line.text, gutterMarkers: line.gutterMarkers,
              textClass: line.textClass, bgClass: line.bgClass, wrapClass: line.wrapClass,
              widgets: line.widgets};
    },

    getViewport: function() { return {from: this.display.showingFrom, to: this.display.showingTo};},

    addWidget: function(pos, node, scroll, vert, horiz) {
      var display = this.display;
      pos = cursorCoords(this, clipPos(this.doc, pos));
      var top = pos.bottom, left = pos.left;
      node.style.position = "absolute";
      display.sizer.appendChild(node);
      if (vert == "over") {
        top = pos.top;
      } else if (vert == "above" || vert == "near") {
        var vspace = Math.max(display.wrapper.clientHeight, this.doc.height),
        hspace = Math.max(display.sizer.clientWidth, display.lineSpace.clientWidth);
        // Default to positioning above (if specified and possible); otherwise default to positioning below
        if ((vert == 'above' || pos.bottom + node.offsetHeight > vspace) && pos.top > node.offsetHeight)
          top = pos.top - node.offsetHeight;
        else if (pos.bottom + node.offsetHeight <= vspace)
          top = pos.bottom;
        if (left + node.offsetWidth > hspace)
          left = hspace - node.offsetWidth;
      }
      node.style.top = top + "px";
      node.style.left = node.style.right = "";
      if (horiz == "right") {
        left = display.sizer.clientWidth - node.offsetWidth;
        node.style.right = "0px";
      } else {
        if (horiz == "left") left = 0;
        else if (horiz == "middle") left = (display.sizer.clientWidth - node.offsetWidth) / 2;
        node.style.left = left + "px";
      }
      if (scroll)
        scrollIntoView(this, left, top, left + node.offsetWidth, top + node.offsetHeight);
    },

    triggerOnKeyDown: operation(null, onKeyDown),

    execCommand: function(cmd) {return commands[cmd](this);},

    findPosH: function(from, amount, unit, visually) {
      var dir = 1;
      if (amount < 0) { dir = -1; amount = -amount; }
      for (var i = 0, cur = clipPos(this.doc, from); i < amount; ++i) {
        cur = findPosH(this.doc, cur, dir, unit, visually);
        if (cur.hitSide) break;
      }
      return cur;
    },

    moveH: operation(null, function(dir, unit) {
      var sel = this.doc.sel, pos;
      if (sel.shift || sel.extend || posEq(sel.from, sel.to))
        pos = findPosH(this.doc, sel.head, dir, unit, this.options.rtlMoveVisually);
      else
        pos = dir < 0 ? sel.from : sel.to;
      extendSelection(this.doc, pos, pos, dir);
    }),

    deleteH: operation(null, function(dir, unit) {
      var sel = this.doc.sel;
      if (!posEq(sel.from, sel.to)) replaceRange(this.doc, "", sel.from, sel.to, "+delete");
      else replaceRange(this.doc, "", sel.from, findPosH(this.doc, sel.head, dir, unit, false), "+delete");
      this.curOp.userSelChange = true;
    }),

    findPosV: function(from, amount, unit, goalColumn) {
      var dir = 1, x = goalColumn;
      if (amount < 0) { dir = -1; amount = -amount; }
      for (var i = 0, cur = clipPos(this.doc, from); i < amount; ++i) {
        var coords = cursorCoords(this, cur, "div");
        if (x == null) x = coords.left;
        else coords.left = x;
        cur = findPosV(this, coords, dir, unit);
        if (cur.hitSide) break;
      }
      return cur;
    },

    moveV: operation(null, function(dir, unit) {
      var sel = this.doc.sel;
      var pos = cursorCoords(this, sel.head, "div");
      if (sel.goalColumn != null) pos.left = sel.goalColumn;
      var target = findPosV(this, pos, dir, unit);

      if (unit == "page") addToScrollPos(this, 0, charCoords(this, target, "div").top - pos.top);
      extendSelection(this.doc, target, target, dir);
      sel.goalColumn = pos.left;
    }),

    toggleOverwrite: function(value) {
      if (value != null && value == this.state.overwrite) return;
      if (this.state.overwrite = !this.state.overwrite)
        this.display.cursor.className += " CodeMirror-overwrite";
      else
        this.display.cursor.className = this.display.cursor.className.replace(" CodeMirror-overwrite", "");
    },
    hasFocus: function() { return this.state.focused; },

    scrollTo: operation(null, function(x, y) {
      updateScrollPos(this, x, y);
    }),
    getScrollInfo: function() {
      var scroller = this.display.scroller, co = scrollerCutOff;
      return {left: scroller.scrollLeft, top: scroller.scrollTop,
              height: scroller.scrollHeight - co, width: scroller.scrollWidth - co,
              clientHeight: scroller.clientHeight - co, clientWidth: scroller.clientWidth - co};
    },

    scrollIntoView: operation(null, function(pos, margin) {
      if (typeof pos == "number") pos = Pos(pos, 0);
      if (!margin) margin = 0;
      var coords = pos;

      if (!pos || pos.line != null) {
        this.curOp.scrollToPos = pos ? clipPos(this.doc, pos) : this.doc.sel.head;
        this.curOp.scrollToPosMargin = margin;
        coords = cursorCoords(this, this.curOp.scrollToPos);
      }
      var sPos = calculateScrollPos(this, coords.left, coords.top - margin, coords.right, coords.bottom + margin);
      updateScrollPos(this, sPos.scrollLeft, sPos.scrollTop);
    }),

    setSize: operation(null, function(width, height) {
      function interpret(val) {
        return typeof val == "number" || /^\d+$/.test(String(val)) ? val + "px" : val;
      }
      if (width != null) this.display.wrapper.style.width = interpret(width);
      if (height != null) this.display.wrapper.style.height = interpret(height);
      if (this.options.lineWrapping)
        this.display.measureLineCache.length = this.display.measureLineCachePos = 0;
      this.curOp.forceUpdate = true;
    }),

    operation: function(f){return runInOp(this, f);},

    refresh: operation(null, function() {
      clearCaches(this);
      updateScrollPos(this, this.doc.scrollLeft, this.doc.scrollTop);
      regChange(this);
    }),

    swapDoc: operation(null, function(doc) {
      var old = this.doc;
      old.cm = null;
      attachDoc(this, doc);
      clearCaches(this);
      resetInput(this, true);
      updateScrollPos(this, doc.scrollLeft, doc.scrollTop);
      return old;
    }),

    getInputField: function(){return this.display.input;},
    getWrapperElement: function(){return this.display.wrapper;},
    getScrollerElement: function(){return this.display.scroller;},
    getGutterElement: function(){return this.display.gutters;}
  };
  eventMixin(CodeMirror);

  // OPTION DEFAULTS

  var optionHandlers = CodeMirror.optionHandlers = {};

  // The default configuration options.
  var defaults = CodeMirror.defaults = {};

  function option(name, deflt, handle, notOnInit) {
    CodeMirror.defaults[name] = deflt;
    if (handle) optionHandlers[name] =
      notOnInit ? function(cm, val, old) {if (old != Init) handle(cm, val, old);} : handle;
  }

  var Init = CodeMirror.Init = {toString: function(){return "CodeMirror.Init";}};

  // These two are, on init, called from the constructor because they
  // have to be initialized before the editor can start at all.
  option("value", "", function(cm, val) {
    cm.setValue(val);
  }, true);
  option("mode", null, function(cm, val) {
    cm.doc.modeOption = val;
    loadMode(cm);
  }, true);

  option("indentUnit", 2, loadMode, true);
  option("indentWithTabs", false);
  option("smartIndent", true);
  option("tabSize", 4, function(cm) {
    loadMode(cm);
    clearCaches(cm);
    regChange(cm);
  }, true);
  option("electricChars", true);
  option("rtlMoveVisually", !windows);

  option("theme", "default", function(cm) {
    themeChanged(cm);
    guttersChanged(cm);
  }, true);
  option("keyMap", "default", keyMapChanged);
  option("extraKeys", null);

  option("onKeyEvent", null);
  option("onDragEvent", null);

  option("lineWrapping", false, wrappingChanged, true);
  option("gutters", [], function(cm) {
    setGuttersForLineNumbers(cm.options);
    guttersChanged(cm);
  }, true);
  option("fixedGutter", true, function(cm, val) {
    cm.display.gutters.style.left = val ? compensateForHScroll(cm.display) + "px" : "0";
    cm.refresh();
  }, true);
  option("coverGutterNextToScrollbar", false, updateScrollbars, true);
  option("lineNumbers", false, function(cm) {
    setGuttersForLineNumbers(cm.options);
    guttersChanged(cm);
  }, true);
  option("firstLineNumber", 1, guttersChanged, true);
  option("lineNumberFormatter", function(integer) {return integer;}, guttersChanged, true);
  option("showCursorWhenSelecting", false, updateSelection, true);

  option("readOnly", false, function(cm, val) {
    if (val == "nocursor") {onBlur(cm); cm.display.input.blur();}
    else if (!val) resetInput(cm, true);
  });
  option("dragDrop", true);

  option("cursorBlinkRate", 530);
  option("cursorScrollMargin", 0);
  option("cursorHeight", 1);
  option("workTime", 100);
  option("workDelay", 100);
  option("flattenSpans", true);
  option("pollInterval", 100);
  option("undoDepth", 40, function(cm, val){cm.doc.history.undoDepth = val;});
  option("historyEventDelay", 500);
  option("viewportMargin", 10, function(cm){cm.refresh();}, true);
  option("maxHighlightLength", 10000, function(cm){loadMode(cm); cm.refresh();}, true);
  option("moveInputWithCursor", true, function(cm, val) {
    if (!val) cm.display.inputDiv.style.top = cm.display.inputDiv.style.left = 0;
  });

  option("tabindex", null, function(cm, val) {
    cm.display.input.tabIndex = val || "";
  });
  option("autofocus", null);

  // MODE DEFINITION AND QUERYING

  // Known modes, by name and by MIME
  var modes = CodeMirror.modes = {}, mimeModes = CodeMirror.mimeModes = {};

  CodeMirror.defineMode = function(name, mode) {
    if (!CodeMirror.defaults.mode && name != "null") CodeMirror.defaults.mode = name;
    if (arguments.length > 2) {
      mode.dependencies = [];
      for (var i = 2; i < arguments.length; ++i) mode.dependencies.push(arguments[i]);
    }
    modes[name] = mode;
  };

  CodeMirror.defineMIME = function(mime, spec) {
    mimeModes[mime] = spec;
  };

  CodeMirror.resolveMode = function(spec) {
    if (typeof spec == "string" && mimeModes.hasOwnProperty(spec)) {
      spec = mimeModes[spec];
    } else if (spec && typeof spec.name == "string" && mimeModes.hasOwnProperty(spec.name)) {
      var found = mimeModes[spec.name];
      spec = createObj(found, spec);
      spec.name = found.name;
    } else if (typeof spec == "string" && /^[\w\-]+\/[\w\-]+\+xml$/.test(spec)) {
      return CodeMirror.resolveMode("application/xml");
    }
    if (typeof spec == "string") return {name: spec};
    else return spec || {name: "null"};
  };

  CodeMirror.getMode = function(options, spec) {
    var spec = CodeMirror.resolveMode(spec);
    var mfactory = modes[spec.name];
    if (!mfactory) return CodeMirror.getMode(options, "text/plain");
    var modeObj = mfactory(options, spec);
    if (modeExtensions.hasOwnProperty(spec.name)) {
      var exts = modeExtensions[spec.name];
      for (var prop in exts) {
        if (!exts.hasOwnProperty(prop)) continue;
        if (modeObj.hasOwnProperty(prop)) modeObj["_" + prop] = modeObj[prop];
        modeObj[prop] = exts[prop];
      }
    }
    modeObj.name = spec.name;

    return modeObj;
  };

  CodeMirror.defineMode("null", function() {
    return {token: function(stream) {stream.skipToEnd();}};
  });
  CodeMirror.defineMIME("text/plain", "null");

  var modeExtensions = CodeMirror.modeExtensions = {};
  CodeMirror.extendMode = function(mode, properties) {
    var exts = modeExtensions.hasOwnProperty(mode) ? modeExtensions[mode] : (modeExtensions[mode] = {});
    copyObj(properties, exts);
  };

  // EXTENSIONS

  CodeMirror.defineExtension = function(name, func) {
    CodeMirror.prototype[name] = func;
  };
  CodeMirror.defineDocExtension = function(name, func) {
    Doc.prototype[name] = func;
  };
  CodeMirror.defineOption = option;

  var initHooks = [];
  CodeMirror.defineInitHook = function(f) {initHooks.push(f);};

  var helpers = CodeMirror.helpers = {};
  CodeMirror.registerHelper = function(type, name, value) {
    if (!helpers.hasOwnProperty(type)) helpers[type] = CodeMirror[type] = {};
    helpers[type][name] = value;
  };

  // UTILITIES

  CodeMirror.isWordChar = isWordChar;

  // MODE STATE HANDLING

  // Utility functions for working with state. Exported because modes
  // sometimes need to do this.
  function copyState(mode, state) {
    if (state === true) return state;
    if (mode.copyState) return mode.copyState(state);
    var nstate = {};
    for (var n in state) {
      var val = state[n];
      if (val instanceof Array) val = val.concat([]);
      nstate[n] = val;
    }
    return nstate;
  }
  CodeMirror.copyState = copyState;

  function startState(mode, a1, a2) {
    return mode.startState ? mode.startState(a1, a2) : true;
  }
  CodeMirror.startState = startState;

  CodeMirror.innerMode = function(mode, state) {
    while (mode.innerMode) {
      var info = mode.innerMode(state);
      if (!info || info.mode == mode) break;
      state = info.state;
      mode = info.mode;
    }
    return info || {mode: mode, state: state};
  };

  // STANDARD COMMANDS

  var commands = CodeMirror.commands = {
    selectAll: function(cm) {cm.setSelection(Pos(cm.firstLine(), 0), Pos(cm.lastLine()));},
    killLine: function(cm) {
      var from = cm.getCursor(true), to = cm.getCursor(false), sel = !posEq(from, to);
      if (!sel && cm.getLine(from.line).length == from.ch)
        cm.replaceRange("", from, Pos(from.line + 1, 0), "+delete");
      else cm.replaceRange("", from, sel ? to : Pos(from.line), "+delete");
    },
    deleteLine: function(cm) {
      var l = cm.getCursor().line;
      cm.replaceRange("", Pos(l, 0), Pos(l), "+delete");
    },
    delLineLeft: function(cm) {
      var cur = cm.getCursor();
      cm.replaceRange("", Pos(cur.line, 0), cur, "+delete");
    },
    undo: function(cm) {cm.undo();},
    redo: function(cm) {cm.redo();},
    goDocStart: function(cm) {cm.extendSelection(Pos(cm.firstLine(), 0));},
    goDocEnd: function(cm) {cm.extendSelection(Pos(cm.lastLine()));},
    goLineStart: function(cm) {
      cm.extendSelection(lineStart(cm, cm.getCursor().line));
    },
    goLineStartSmart: function(cm) {
      var cur = cm.getCursor(), start = lineStart(cm, cur.line);
      var line = cm.getLineHandle(start.line);
      var order = getOrder(line);
      if (!order || order[0].level == 0) {
        var firstNonWS = Math.max(0, line.text.search(/\S/));
        var inWS = cur.line == start.line && cur.ch <= firstNonWS && cur.ch;
        cm.extendSelection(Pos(start.line, inWS ? 0 : firstNonWS));
      } else cm.extendSelection(start);
    },
    goLineEnd: function(cm) {
      cm.extendSelection(lineEnd(cm, cm.getCursor().line));
    },
    goLineRight: function(cm) {
      var top = cm.charCoords(cm.getCursor(), "div").top + 5;
      cm.extendSelection(cm.coordsChar({left: cm.display.lineDiv.offsetWidth + 100, top: top}, "div"));
    },
    goLineLeft: function(cm) {
      var top = cm.charCoords(cm.getCursor(), "div").top + 5;
      cm.extendSelection(cm.coordsChar({left: 0, top: top}, "div"));
    },
    goLineUp: function(cm) {cm.moveV(-1, "line");},
    goLineDown: function(cm) {cm.moveV(1, "line");},
    goPageUp: function(cm) {cm.moveV(-1, "page");},
    goPageDown: function(cm) {cm.moveV(1, "page");},
    goCharLeft: function(cm) {cm.moveH(-1, "char");},
    goCharRight: function(cm) {cm.moveH(1, "char");},
    goColumnLeft: function(cm) {cm.moveH(-1, "column");},
    goColumnRight: function(cm) {cm.moveH(1, "column");},
    goWordLeft: function(cm) {cm.moveH(-1, "word");},
    goGroupRight: function(cm) {cm.moveH(1, "group");},
    goGroupLeft: function(cm) {cm.moveH(-1, "group");},
    goWordRight: function(cm) {cm.moveH(1, "word");},
    delCharBefore: function(cm) {cm.deleteH(-1, "char");},
    delCharAfter: function(cm) {cm.deleteH(1, "char");},
    delWordBefore: function(cm) {cm.deleteH(-1, "word");},
    delWordAfter: function(cm) {cm.deleteH(1, "word");},
    delGroupBefore: function(cm) {cm.deleteH(-1, "group");},
    delGroupAfter: function(cm) {cm.deleteH(1, "group");},
    indentAuto: function(cm) {cm.indentSelection("smart");},
    indentMore: function(cm) {cm.indentSelection("add");},
    indentLess: function(cm) {cm.indentSelection("subtract");},
    insertTab: function(cm) {cm.replaceSelection("\t", "end", "+input");},
    defaultTab: function(cm) {
      if (cm.somethingSelected()) cm.indentSelection("add");
      else cm.replaceSelection("\t", "end", "+input");
    },
    transposeChars: function(cm) {
      var cur = cm.getCursor(), line = cm.getLine(cur.line);
      if (cur.ch > 0 && cur.ch < line.length - 1)
        cm.replaceRange(line.charAt(cur.ch) + line.charAt(cur.ch - 1),
                        Pos(cur.line, cur.ch - 1), Pos(cur.line, cur.ch + 1));
    },
    newlineAndIndent: function(cm) {
      operation(cm, function() {
        cm.replaceSelection("\n", "end", "+input");
        cm.indentLine(cm.getCursor().line, null, true);
      })();
    },
    toggleOverwrite: function(cm) {cm.toggleOverwrite();}
  };

  // STANDARD KEYMAPS

  var keyMap = CodeMirror.keyMap = {};
  keyMap.basic = {
    "Left": "goCharLeft", "Right": "goCharRight", "Up": "goLineUp", "Down": "goLineDown",
    "End": "goLineEnd", "Home": "goLineStartSmart", "PageUp": "goPageUp", "PageDown": "goPageDown",
    "Delete": "delCharAfter", "Backspace": "delCharBefore", "Tab": "defaultTab", "Shift-Tab": "indentAuto",
    "Enter": "newlineAndIndent", "Insert": "toggleOverwrite"
  };
  // Note that the save and find-related commands aren't defined by
  // default. Unknown commands are simply ignored.
  keyMap.pcDefault = {
    "Ctrl-A": "selectAll", "Ctrl-D": "deleteLine", "Ctrl-Z": "undo", "Shift-Ctrl-Z": "redo", "Ctrl-Y": "redo",
    "Ctrl-Home": "goDocStart", "Alt-Up": "goDocStart", "Ctrl-End": "goDocEnd", "Ctrl-Down": "goDocEnd",
    "Ctrl-Left": "goGroupLeft", "Ctrl-Right": "goGroupRight", "Alt-Left": "goLineStart", "Alt-Right": "goLineEnd",
    "Ctrl-Backspace": "delGroupBefore", "Ctrl-Delete": "delGroupAfter", "Ctrl-S": "save", "Ctrl-F": "find",
    "Ctrl-G": "findNext", "Shift-Ctrl-G": "findPrev", "Shift-Ctrl-F": "replace", "Shift-Ctrl-R": "replaceAll",
    "Ctrl-[": "indentLess", "Ctrl-]": "indentMore",
    fallthrough: "basic"
  };
  keyMap.macDefault = {
    "Cmd-A": "selectAll", "Cmd-D": "deleteLine", "Cmd-Z": "undo", "Shift-Cmd-Z": "redo", "Cmd-Y": "redo",
    "Cmd-Up": "goDocStart", "Cmd-End": "goDocEnd", "Cmd-Down": "goDocEnd", "Alt-Left": "goGroupLeft",
    "Alt-Right": "goGroupRight", "Cmd-Left": "goLineStart", "Cmd-Right": "goLineEnd", "Alt-Backspace": "delGroupBefore",
    "Ctrl-Alt-Backspace": "delGroupAfter", "Alt-Delete": "delGroupAfter", "Cmd-S": "save", "Cmd-F": "find",
    "Cmd-G": "findNext", "Shift-Cmd-G": "findPrev", "Cmd-Alt-F": "replace", "Shift-Cmd-Alt-F": "replaceAll",
    "Cmd-[": "indentLess", "Cmd-]": "indentMore", "Cmd-Backspace": "delLineLeft",
    fallthrough: ["basic", "emacsy"]
  };
  keyMap["default"] = mac ? keyMap.macDefault : keyMap.pcDefault;
  keyMap.emacsy = {
    "Ctrl-F": "goCharRight", "Ctrl-B": "goCharLeft", "Ctrl-P": "goLineUp", "Ctrl-N": "goLineDown",
    "Alt-F": "goWordRight", "Alt-B": "goWordLeft", "Ctrl-A": "goLineStart", "Ctrl-E": "goLineEnd",
    "Ctrl-V": "goPageDown", "Shift-Ctrl-V": "goPageUp", "Ctrl-D": "delCharAfter", "Ctrl-H": "delCharBefore",
    "Alt-D": "delWordAfter", "Alt-Backspace": "delWordBefore", "Ctrl-K": "killLine", "Ctrl-T": "transposeChars"
  };

  // KEYMAP DISPATCH

  function getKeyMap(val) {
    if (typeof val == "string") return keyMap[val];
    else return val;
  }

  function lookupKey(name, maps, handle) {
    function lookup(map) {
      map = getKeyMap(map);
      var found = map[name];
      if (found === false) return "stop";
      if (found != null && handle(found)) return true;
      if (map.nofallthrough) return "stop";

      var fallthrough = map.fallthrough;
      if (fallthrough == null) return false;
      if (Object.prototype.toString.call(fallthrough) != "[object Array]")
        return lookup(fallthrough);
      for (var i = 0, e = fallthrough.length; i < e; ++i) {
        var done = lookup(fallthrough[i]);
        if (done) return done;
      }
      return false;
    }

    for (var i = 0; i < maps.length; ++i) {
      var done = lookup(maps[i]);
      if (done) return done != "stop";
    }
  }
  function isModifierKey(event) {
    var name = keyNames[event.keyCode];
    return name == "Ctrl" || name == "Alt" || name == "Shift" || name == "Mod";
  }
  function keyName(event, noShift) {
    if (opera && event.keyCode == 34 && event["char"]) return false;
    var name = keyNames[event.keyCode];
    if (name == null || event.altGraphKey) return false;
    if (event.altKey) name = "Alt-" + name;
    if (flipCtrlCmd ? event.metaKey : event.ctrlKey) name = "Ctrl-" + name;
    if (flipCtrlCmd ? event.ctrlKey : event.metaKey) name = "Cmd-" + name;
    if (!noShift && event.shiftKey) name = "Shift-" + name;
    return name;
  }
  CodeMirror.lookupKey = lookupKey;
  CodeMirror.isModifierKey = isModifierKey;
  CodeMirror.keyName = keyName;

  // FROMTEXTAREA

  CodeMirror.fromTextArea = function(textarea, options) {
    if (!options) options = {};
    options.value = textarea.value;
    if (!options.tabindex && textarea.tabindex)
      options.tabindex = textarea.tabindex;
    if (!options.placeholder && textarea.placeholder)
      options.placeholder = textarea.placeholder;
    // Set autofocus to true if this textarea is focused, or if it has
    // autofocus and no other element is focused.
    if (options.autofocus == null) {
      var hasFocus = document.body;
      // doc.activeElement occasionally throws on IE
      try { hasFocus = document.activeElement; } catch(e) {}
      options.autofocus = hasFocus == textarea ||
        textarea.getAttribute("autofocus") != null && hasFocus == document.body;
    }

    function save() {textarea.value = cm.getValue();}
    if (textarea.form) {
      on(textarea.form, "submit", save);
      // Deplorable hack to make the submit method do the right thing.
      if (!options.leaveSubmitMethodAlone) {
        var form = textarea.form, realSubmit = form.submit;
        try {
          var wrappedSubmit = form.submit = function() {
            save();
            form.submit = realSubmit;
            form.submit();
            form.submit = wrappedSubmit;
          };
        } catch(e) {}
      }
    }

    textarea.style.display = "none";
    var cm = CodeMirror(function(node) {
      textarea.parentNode.insertBefore(node, textarea.nextSibling);
    }, options);
    cm.save = save;
    cm.getTextArea = function() { return textarea; };
    cm.toTextArea = function() {
      save();
      textarea.parentNode.removeChild(cm.getWrapperElement());
      textarea.style.display = "";
      if (textarea.form) {
        off(textarea.form, "submit", save);
        if (typeof textarea.form.submit == "function")
          textarea.form.submit = realSubmit;
      }
    };
    return cm;
  };

  // STRING STREAM

  // Fed to the mode parsers, provides helper functions to make
  // parsers more succinct.

  // The character stream used by a mode's parser.
  function StringStream(string, tabSize) {
    this.pos = this.start = 0;
    this.string = string;
    this.tabSize = tabSize || 8;
    this.lastColumnPos = this.lastColumnValue = 0;
  }

  StringStream.prototype = {
    eol: function() {return this.pos >= this.string.length;},
    sol: function() {return this.pos == 0;},
    peek: function() {return this.string.charAt(this.pos) || undefined;},
    next: function() {
      if (this.pos < this.string.length)
        return this.string.charAt(this.pos++);
    },
    eat: function(match) {
      var ch = this.string.charAt(this.pos);
      if (typeof match == "string") var ok = ch == match;
      else var ok = ch && (match.test ? match.test(ch) : match(ch));
      if (ok) {++this.pos; return ch;}
    },
    eatWhile: function(match) {
      var start = this.pos;
      while (this.eat(match)){}
      return this.pos > start;
    },
    eatSpace: function() {
      var start = this.pos;
      while (/[\s\u00a0]/.test(this.string.charAt(this.pos))) ++this.pos;
      return this.pos > start;
    },
    skipToEnd: function() {this.pos = this.string.length;},
    skipTo: function(ch) {
      var found = this.string.indexOf(ch, this.pos);
      if (found > -1) {this.pos = found; return true;}
    },
    backUp: function(n) {this.pos -= n;},
    column: function() {
      if (this.lastColumnPos < this.start) {
        this.lastColumnValue = countColumn(this.string, this.start, this.tabSize, this.lastColumnPos, this.lastColumnValue);
        this.lastColumnPos = this.start;
      }
      return this.lastColumnValue;
    },
    indentation: function() {return countColumn(this.string, null, this.tabSize);},
    match: function(pattern, consume, caseInsensitive) {
      if (typeof pattern == "string") {
        var cased = function(str) {return caseInsensitive ? str.toLowerCase() : str;};
        var substr = this.string.substr(this.pos, pattern.length);
        if (cased(substr) == cased(pattern)) {
          if (consume !== false) this.pos += pattern.length;
          return true;
        }
      } else {
        var match = this.string.slice(this.pos).match(pattern);
        if (match && match.index > 0) return null;
        if (match && consume !== false) this.pos += match[0].length;
        return match;
      }
    },
    current: function(){return this.string.slice(this.start, this.pos);}
  };
  CodeMirror.StringStream = StringStream;

  // TEXTMARKERS

  function TextMarker(doc, type) {
    this.lines = [];
    this.type = type;
    this.doc = doc;
  }
  CodeMirror.TextMarker = TextMarker;
  eventMixin(TextMarker);

  TextMarker.prototype.clear = function() {
    if (this.explicitlyCleared) return;
    var cm = this.doc.cm, withOp = cm && !cm.curOp;
    if (withOp) startOperation(cm);
    if (hasHandler(this, "clear")) {
      var found = this.find();
      if (found) signalLater(this, "clear", found.from, found.to);
    }
    var min = null, max = null;
    for (var i = 0; i < this.lines.length; ++i) {
      var line = this.lines[i];
      var span = getMarkedSpanFor(line.markedSpans, this);
      if (span.to != null) max = lineNo(line);
      line.markedSpans = removeMarkedSpan(line.markedSpans, span);
      if (span.from != null)
        min = lineNo(line);
      else if (this.collapsed && !lineIsHidden(this.doc, line) && cm)
        updateLineHeight(line, textHeight(cm.display));
    }
    if (cm && this.collapsed && !cm.options.lineWrapping) for (var i = 0; i < this.lines.length; ++i) {
      var visual = visualLine(cm.doc, this.lines[i]), len = lineLength(cm.doc, visual);
      if (len > cm.display.maxLineLength) {
        cm.display.maxLine = visual;
        cm.display.maxLineLength = len;
        cm.display.maxLineChanged = true;
      }
    }

    if (min != null && cm) regChange(cm, min, max + 1);
    this.lines.length = 0;
    this.explicitlyCleared = true;
    if (this.atomic && this.doc.cantEdit) {
      this.doc.cantEdit = false;
      if (cm) reCheckSelection(cm);
    }
    if (withOp) endOperation(cm);
  };

  TextMarker.prototype.find = function() {
    var from, to;
    for (var i = 0; i < this.lines.length; ++i) {
      var line = this.lines[i];
      var span = getMarkedSpanFor(line.markedSpans, this);
      if (span.from != null || span.to != null) {
        var found = lineNo(line);
        if (span.from != null) from = Pos(found, span.from);
        if (span.to != null) to = Pos(found, span.to);
      }
    }
    if (this.type == "bookmark") return from;
    return from && {from: from, to: to};
  };

  TextMarker.prototype.changed = function() {
    var pos = this.find(), cm = this.doc.cm;
    if (!pos || !cm) return;
    var line = getLine(this.doc, pos.from.line);
    clearCachedMeasurement(cm, line);
    if (pos.from.line >= cm.display.showingFrom && pos.from.line < cm.display.showingTo) {
      for (var node = cm.display.lineDiv.firstChild; node; node = node.nextSibling) if (node.lineObj == line) {
        if (node.offsetHeight != line.height) updateLineHeight(line, node.offsetHeight);
        break;
      }
      runInOp(cm, function() {
        cm.curOp.selectionChanged = cm.curOp.forceUpdate = cm.curOp.updateMaxLine = true;
      });
    }
  };

  TextMarker.prototype.attachLine = function(line) {
    if (!this.lines.length && this.doc.cm) {
      var op = this.doc.cm.curOp;
      if (!op.maybeHiddenMarkers || indexOf(op.maybeHiddenMarkers, this) == -1)
        (op.maybeUnhiddenMarkers || (op.maybeUnhiddenMarkers = [])).push(this);
    }
    this.lines.push(line);
  };
  TextMarker.prototype.detachLine = function(line) {
    this.lines.splice(indexOf(this.lines, line), 1);
    if (!this.lines.length && this.doc.cm) {
      var op = this.doc.cm.curOp;
      (op.maybeHiddenMarkers || (op.maybeHiddenMarkers = [])).push(this);
    }
  };

  function markText(doc, from, to, options, type) {
    if (options && options.shared) return markTextShared(doc, from, to, options, type);
    if (doc.cm && !doc.cm.curOp) return operation(doc.cm, markText)(doc, from, to, options, type);

    var marker = new TextMarker(doc, type);
    if (type == "range" && !posLess(from, to)) return marker;
    if (options) copyObj(options, marker);
    if (marker.replacedWith) {
      marker.collapsed = true;
      marker.replacedWith = elt("span", [marker.replacedWith], "CodeMirror-widget");
      if (!options.handleMouseEvents) marker.replacedWith.ignoreEvents = true;
    }
    if (marker.collapsed) sawCollapsedSpans = true;

    if (marker.addToHistory)
      addToHistory(doc, {from: from, to: to, origin: "markText"},
                   {head: doc.sel.head, anchor: doc.sel.anchor}, NaN);

    var curLine = from.line, size = 0, collapsedAtStart, collapsedAtEnd, cm = doc.cm, updateMaxLine;
    doc.iter(curLine, to.line + 1, function(line) {
      if (cm && marker.collapsed && !cm.options.lineWrapping && visualLine(doc, line) == cm.display.maxLine)
        updateMaxLine = true;
      var span = {from: null, to: null, marker: marker};
      size += line.text.length;
      if (curLine == from.line) {span.from = from.ch; size -= from.ch;}
      if (curLine == to.line) {span.to = to.ch; size -= line.text.length - to.ch;}
      if (marker.collapsed) {
        if (curLine == to.line) collapsedAtEnd = collapsedSpanAt(line, to.ch);
        if (curLine == from.line) collapsedAtStart = collapsedSpanAt(line, from.ch);
        else updateLineHeight(line, 0);
      }
      addMarkedSpan(line, span);
      ++curLine;
    });
    if (marker.collapsed) doc.iter(from.line, to.line + 1, function(line) {
      if (lineIsHidden(doc, line)) updateLineHeight(line, 0);
    });

    if (marker.clearOnEnter) on(marker, "beforeCursorEnter", function() { marker.clear(); });

    if (marker.readOnly) {
      sawReadOnlySpans = true;
      if (doc.history.done.length || doc.history.undone.length)
        doc.clearHistory();
    }
    if (marker.collapsed) {
      if (collapsedAtStart != collapsedAtEnd)
        throw new Error("Inserting collapsed marker overlapping an existing one");
      marker.size = size;
      marker.atomic = true;
    }
    if (cm) {
      if (updateMaxLine) cm.curOp.updateMaxLine = true;
      if (marker.className || marker.title || marker.startStyle || marker.endStyle || marker.collapsed)
        regChange(cm, from.line, to.line + 1);
      if (marker.atomic) reCheckSelection(cm);
    }
    return marker;
  }

  // SHARED TEXTMARKERS

  function SharedTextMarker(markers, primary) {
    this.markers = markers;
    this.primary = primary;
    for (var i = 0, me = this; i < markers.length; ++i) {
      markers[i].parent = this;
      on(markers[i], "clear", function(){me.clear();});
    }
  }
  CodeMirror.SharedTextMarker = SharedTextMarker;
  eventMixin(SharedTextMarker);

  SharedTextMarker.prototype.clear = function() {
    if (this.explicitlyCleared) return;
    this.explicitlyCleared = true;
    for (var i = 0; i < this.markers.length; ++i)
      this.markers[i].clear();
    signalLater(this, "clear");
  };
  SharedTextMarker.prototype.find = function() {
    return this.primary.find();
  };

  function markTextShared(doc, from, to, options, type) {
    options = copyObj(options);
    options.shared = false;
    var markers = [markText(doc, from, to, options, type)], primary = markers[0];
    var widget = options.replacedWith;
    linkedDocs(doc, function(doc) {
      if (widget) options.replacedWith = widget.cloneNode(true);
      markers.push(markText(doc, clipPos(doc, from), clipPos(doc, to), options, type));
      for (var i = 0; i < doc.linked.length; ++i)
        if (doc.linked[i].isParent) return;
      primary = lst(markers);
    });
    return new SharedTextMarker(markers, primary);
  }

  // TEXTMARKER SPANS

  function getMarkedSpanFor(spans, marker) {
    if (spans) for (var i = 0; i < spans.length; ++i) {
      var span = spans[i];
      if (span.marker == marker) return span;
    }
  }
  function removeMarkedSpan(spans, span) {
    for (var r, i = 0; i < spans.length; ++i)
      if (spans[i] != span) (r || (r = [])).push(spans[i]);
    return r;
  }
  function addMarkedSpan(line, span) {
    line.markedSpans = line.markedSpans ? line.markedSpans.concat([span]) : [span];
    span.marker.attachLine(line);
  }

  function markedSpansBefore(old, startCh, isInsert) {
    if (old) for (var i = 0, nw; i < old.length; ++i) {
      var span = old[i], marker = span.marker;
      var startsBefore = span.from == null || (marker.inclusiveLeft ? span.from <= startCh : span.from < startCh);
      if (startsBefore || marker.type == "bookmark" && span.from == startCh && (!isInsert || !span.marker.insertLeft)) {
        var endsAfter = span.to == null || (marker.inclusiveRight ? span.to >= startCh : span.to > startCh);
        (nw || (nw = [])).push({from: span.from,
                                to: endsAfter ? null : span.to,
                                marker: marker});
      }
    }
    return nw;
  }

  function markedSpansAfter(old, endCh, isInsert) {
    if (old) for (var i = 0, nw; i < old.length; ++i) {
      var span = old[i], marker = span.marker;
      var endsAfter = span.to == null || (marker.inclusiveRight ? span.to >= endCh : span.to > endCh);
      if (endsAfter || marker.type == "bookmark" && span.from == endCh && (!isInsert || span.marker.insertLeft)) {
        var startsBefore = span.from == null || (marker.inclusiveLeft ? span.from <= endCh : span.from < endCh);
        (nw || (nw = [])).push({from: startsBefore ? null : span.from - endCh,
                                to: span.to == null ? null : span.to - endCh,
                                marker: marker});
      }
    }
    return nw;
  }

  function stretchSpansOverChange(doc, change) {
    var oldFirst = isLine(doc, change.from.line) && getLine(doc, change.from.line).markedSpans;
    var oldLast = isLine(doc, change.to.line) && getLine(doc, change.to.line).markedSpans;
    if (!oldFirst && !oldLast) return null;

    var startCh = change.from.ch, endCh = change.to.ch, isInsert = posEq(change.from, change.to);
    // Get the spans that 'stick out' on both sides
    var first = markedSpansBefore(oldFirst, startCh, isInsert);
    var last = markedSpansAfter(oldLast, endCh, isInsert);

    // Next, merge those two ends
    var sameLine = change.text.length == 1, offset = lst(change.text).length + (sameLine ? startCh : 0);
    if (first) {
      // Fix up .to properties of first
      for (var i = 0; i < first.length; ++i) {
        var span = first[i];
        if (span.to == null) {
          var found = getMarkedSpanFor(last, span.marker);
          if (!found) span.to = startCh;
          else if (sameLine) span.to = found.to == null ? null : found.to + offset;
        }
      }
    }
    if (last) {
      // Fix up .from in last (or move them into first in case of sameLine)
      for (var i = 0; i < last.length; ++i) {
        var span = last[i];
        if (span.to != null) span.to += offset;
        if (span.from == null) {
          var found = getMarkedSpanFor(first, span.marker);
          if (!found) {
            span.from = offset;
            if (sameLine) (first || (first = [])).push(span);
          }
        } else {
          span.from += offset;
          if (sameLine) (first || (first = [])).push(span);
        }
      }
    }
    if (sameLine && first) {
      // Make sure we didn't create any zero-length spans
      for (var i = 0; i < first.length; ++i)
        if (first[i].from != null && first[i].from == first[i].to && first[i].marker.type != "bookmark")
          first.splice(i--, 1);
      if (!first.length) first = null;
    }

    var newMarkers = [first];
    if (!sameLine) {
      // Fill gap with whole-line-spans
      var gap = change.text.length - 2, gapMarkers;
      if (gap > 0 && first)
        for (var i = 0; i < first.length; ++i)
          if (first[i].to == null)
            (gapMarkers || (gapMarkers = [])).push({from: null, to: null, marker: first[i].marker});
      for (var i = 0; i < gap; ++i)
        newMarkers.push(gapMarkers);
      newMarkers.push(last);
    }
    return newMarkers;
  }

  function mergeOldSpans(doc, change) {
    var old = getOldSpans(doc, change);
    var stretched = stretchSpansOverChange(doc, change);
    if (!old) return stretched;
    if (!stretched) return old;

    for (var i = 0; i < old.length; ++i) {
      var oldCur = old[i], stretchCur = stretched[i];
      if (oldCur && stretchCur) {
        spans: for (var j = 0; j < stretchCur.length; ++j) {
          var span = stretchCur[j];
          for (var k = 0; k < oldCur.length; ++k)
            if (oldCur[k].marker == span.marker) continue spans;
          oldCur.push(span);
        }
      } else if (stretchCur) {
        old[i] = stretchCur;
      }
    }
    return old;
  }

  function removeReadOnlyRanges(doc, from, to) {
    var markers = null;
    doc.iter(from.line, to.line + 1, function(line) {
      if (line.markedSpans) for (var i = 0; i < line.markedSpans.length; ++i) {
        var mark = line.markedSpans[i].marker;
        if (mark.readOnly && (!markers || indexOf(markers, mark) == -1))
          (markers || (markers = [])).push(mark);
      }
    });
    if (!markers) return null;
    var parts = [{from: from, to: to}];
    for (var i = 0; i < markers.length; ++i) {
      var mk = markers[i], m = mk.find();
      for (var j = 0; j < parts.length; ++j) {
        var p = parts[j];
        if (posLess(p.to, m.from) || posLess(m.to, p.from)) continue;
        var newParts = [j, 1];
        if (posLess(p.from, m.from) || !mk.inclusiveLeft && posEq(p.from, m.from))
          newParts.push({from: p.from, to: m.from});
        if (posLess(m.to, p.to) || !mk.inclusiveRight && posEq(p.to, m.to))
          newParts.push({from: m.to, to: p.to});
        parts.splice.apply(parts, newParts);
        j += newParts.length - 1;
      }
    }
    return parts;
  }

  function collapsedSpanAt(line, ch) {
    var sps = sawCollapsedSpans && line.markedSpans, found;
    if (sps) for (var sp, i = 0; i < sps.length; ++i) {
      sp = sps[i];
      if (!sp.marker.collapsed) continue;
      if ((sp.from == null || sp.from < ch) &&
          (sp.to == null || sp.to > ch) &&
          (!found || found.width < sp.marker.width))
        found = sp.marker;
    }
    return found;
  }
  function collapsedSpanAtStart(line) { return collapsedSpanAt(line, -1); }
  function collapsedSpanAtEnd(line) { return collapsedSpanAt(line, line.text.length + 1); }

  function visualLine(doc, line) {
    var merged;
    while (merged = collapsedSpanAtStart(line))
      line = getLine(doc, merged.find().from.line);
    return line;
  }

  function lineIsHidden(doc, line) {
    var sps = sawCollapsedSpans && line.markedSpans;
    if (sps) for (var sp, i = 0; i < sps.length; ++i) {
      sp = sps[i];
      if (!sp.marker.collapsed) continue;
      if (sp.from == null) return true;
      if (sp.marker.replacedWith) continue;
      if (sp.from == 0 && sp.marker.inclusiveLeft && lineIsHiddenInner(doc, line, sp))
        return true;
    }
  }
  function lineIsHiddenInner(doc, line, span) {
    if (span.to == null) {
      var end = span.marker.find().to, endLine = getLine(doc, end.line);
      return lineIsHiddenInner(doc, endLine, getMarkedSpanFor(endLine.markedSpans, span.marker));
    }
    if (span.marker.inclusiveRight && span.to == line.text.length)
      return true;
    for (var sp, i = 0; i < line.markedSpans.length; ++i) {
      sp = line.markedSpans[i];
      if (sp.marker.collapsed && !sp.marker.replacedWith && sp.from == span.to &&
          (sp.marker.inclusiveLeft || span.marker.inclusiveRight) &&
          lineIsHiddenInner(doc, line, sp)) return true;
    }
  }

  function detachMarkedSpans(line) {
    var spans = line.markedSpans;
    if (!spans) return;
    for (var i = 0; i < spans.length; ++i)
      spans[i].marker.detachLine(line);
    line.markedSpans = null;
  }

  function attachMarkedSpans(line, spans) {
    if (!spans) return;
    for (var i = 0; i < spans.length; ++i)
      spans[i].marker.attachLine(line);
    line.markedSpans = spans;
  }

  // LINE WIDGETS

  var LineWidget = CodeMirror.LineWidget = function(cm, node, options) {
    if (options) for (var opt in options) if (options.hasOwnProperty(opt))
      this[opt] = options[opt];
    this.cm = cm;
    this.node = node;
  };
  eventMixin(LineWidget);
  function widgetOperation(f) {
    return function() {
      var withOp = !this.cm.curOp;
      if (withOp) startOperation(this.cm);
      try {var result = f.apply(this, arguments);}
      finally {if (withOp) endOperation(this.cm);}
      return result;
    };
  }
  LineWidget.prototype.clear = widgetOperation(function() {
    var ws = this.line.widgets, no = lineNo(this.line);
    if (no == null || !ws) return;
    for (var i = 0; i < ws.length; ++i) if (ws[i] == this) ws.splice(i--, 1);
    if (!ws.length) this.line.widgets = null;
    var aboveVisible = heightAtLine(this.cm, this.line) < this.cm.doc.scrollTop;
    updateLineHeight(this.line, Math.max(0, this.line.height - widgetHeight(this)));
    if (aboveVisible) addToScrollPos(this.cm, 0, -this.height);
    regChange(this.cm, no, no + 1);
  });
  LineWidget.prototype.changed = widgetOperation(function() {
    var oldH = this.height;
    this.height = null;
    var diff = widgetHeight(this) - oldH;
    if (!diff) return;
    updateLineHeight(this.line, this.line.height + diff);
    var no = lineNo(this.line);
    regChange(this.cm, no, no + 1);
  });

  function widgetHeight(widget) {
    if (widget.height != null) return widget.height;
    if (!widget.node.parentNode || widget.node.parentNode.nodeType != 1)
      removeChildrenAndAdd(widget.cm.display.measure, elt("div", [widget.node], null, "position: relative"));
    return widget.height = widget.node.offsetHeight;
  }

  function addLineWidget(cm, handle, node, options) {
    var widget = new LineWidget(cm, node, options);
    if (widget.noHScroll) cm.display.alignWidgets = true;
    changeLine(cm, handle, function(line) {
      var widgets = line.widgets || (line.widgets = []);
      if (widget.insertAt == null) widgets.push(widget);
      else widgets.splice(Math.min(widgets.length - 1, Math.max(0, widget.insertAt)), 0, widget);
      widget.line = line;
      if (!lineIsHidden(cm.doc, line) || widget.showIfHidden) {
        var aboveVisible = heightAtLine(cm, line) < cm.doc.scrollTop;
        updateLineHeight(line, line.height + widgetHeight(widget));
        if (aboveVisible) addToScrollPos(cm, 0, widget.height);
      }
      return true;
    });
    return widget;
  }

  // LINE DATA STRUCTURE

  // Line objects. These hold state related to a line, including
  // highlighting info (the styles array).
  var Line = CodeMirror.Line = function(text, markedSpans, estimateHeight) {
    this.text = text;
    attachMarkedSpans(this, markedSpans);
    this.height = estimateHeight ? estimateHeight(this) : 1;
  };
  eventMixin(Line);

  function updateLine(line, text, markedSpans, estimateHeight) {
    line.text = text;
    if (line.stateAfter) line.stateAfter = null;
    if (line.styles) line.styles = null;
    if (line.order != null) line.order = null;
    detachMarkedSpans(line);
    attachMarkedSpans(line, markedSpans);
    var estHeight = estimateHeight ? estimateHeight(line) : 1;
    if (estHeight != line.height) updateLineHeight(line, estHeight);
  }

  function cleanUpLine(line) {
    line.parent = null;
    detachMarkedSpans(line);
  }

  // Run the given mode's parser over a line, update the styles
  // array, which contains alternating fragments of text and CSS
  // classes.
  function runMode(cm, text, mode, state, f) {
    var flattenSpans = mode.flattenSpans;
    if (flattenSpans == null) flattenSpans = cm.options.flattenSpans;
    var curStart = 0, curStyle = null;
    var stream = new StringStream(text, cm.options.tabSize), style;
    if (text == "" && mode.blankLine) mode.blankLine(state);
    while (!stream.eol()) {
      if (stream.pos > cm.options.maxHighlightLength) {
        flattenSpans = false;
        // Webkit seems to refuse to render text nodes longer than 57444 characters
        stream.pos = Math.min(text.length, stream.start + 50000);
        style = null;
      } else {
        style = mode.token(stream, state);
      }
      if (!flattenSpans || curStyle != style) {
        if (curStart < stream.start) f(stream.start, curStyle);
        curStart = stream.start; curStyle = style;
      }
      stream.start = stream.pos;
    }
    if (curStart < stream.pos) f(stream.pos, curStyle);
  }

  function highlightLine(cm, line, state) {
    // A styles array always starts with a number identifying the
    // mode/overlays that it is based on (for easy invalidation).
    var st = [cm.state.modeGen];
    // Compute the base array of styles
    runMode(cm, line.text, cm.doc.mode, state, function(end, style) {st.push(end, style);});

    // Run overlays, adjust style array.
    for (var o = 0; o < cm.state.overlays.length; ++o) {
      var overlay = cm.state.overlays[o], i = 1, at = 0;
      runMode(cm, line.text, overlay.mode, true, function(end, style) {
        var start = i;
        // Ensure there's a token end at the current position, and that i points at it
        while (at < end) {
          var i_end = st[i];
          if (i_end > end)
            st.splice(i, 1, end, st[i+1], i_end);
          i += 2;
          at = Math.min(end, i_end);
        }
        if (!style) return;
        if (overlay.opaque) {
          st.splice(start, i - start, end, style);
          i = start + 2;
        } else {
          for (; start < i; start += 2) {
            var cur = st[start+1];
            st[start+1] = cur ? cur + " " + style : style;
          }
        }
      });
    }

    return st;
  }

  function getLineStyles(cm, line) {
    if (!line.styles || line.styles[0] != cm.state.modeGen)
      line.styles = highlightLine(cm, line, line.stateAfter = getStateBefore(cm, lineNo(line)));
    return line.styles;
  }

  // Lightweight form of highlight -- proceed over this line and
  // update state, but don't save a style array.
  function processLine(cm, line, state) {
    var mode = cm.doc.mode;
    var stream = new StringStream(line.text, cm.options.tabSize);
    if (line.text == "" && mode.blankLine) mode.blankLine(state);
    while (!stream.eol() && stream.pos <= cm.options.maxHighlightLength) {
      mode.token(stream, state);
      stream.start = stream.pos;
    }
  }

  var styleToClassCache = {};
  function styleToClass(style) {
    if (!style) return null;
    return styleToClassCache[style] ||
      (styleToClassCache[style] = "cm-" + style.replace(/ +/g, " cm-"));
  }

  function lineContent(cm, realLine, measure, copyWidgets) {
    var merged, line = realLine, empty = true;
    while (merged = collapsedSpanAtStart(line))
      line = getLine(cm.doc, merged.find().from.line);

    var builder = {pre: elt("pre"), col: 0, pos: 0,
                   measure: null, measuredSomething: false, cm: cm,
                   copyWidgets: copyWidgets};
    if (line.textClass) builder.pre.className = line.textClass;

    do {
      if (line.text) empty = false;
      builder.measure = line == realLine && measure;
      builder.pos = 0;
      builder.addToken = builder.measure ? buildTokenMeasure : buildToken;
      if ((ie || webkit) && cm.getOption("lineWrapping"))
        builder.addToken = buildTokenSplitSpaces(builder.addToken);
      var next = insertLineContent(line, builder, getLineStyles(cm, line));
      if (measure && line == realLine && !builder.measuredSomething) {
        measure[0] = builder.pre.appendChild(zeroWidthElement(cm.display.measure));
        builder.measuredSomething = true;
      }
      if (next) line = getLine(cm.doc, next.to.line);
    } while (next);

    if (measure && !builder.measuredSomething && !measure[0])
      measure[0] = builder.pre.appendChild(empty ? elt("span", "\u00a0") : zeroWidthElement(cm.display.measure));
    if (!builder.pre.firstChild && !lineIsHidden(cm.doc, realLine))
      builder.pre.appendChild(document.createTextNode("\u00a0"));

    var order;
    // Work around problem with the reported dimensions of single-char
    // direction spans on IE (issue #1129). See also the comment in
    // cursorCoords.
    if (measure && ie && (order = getOrder(line))) {
      var l = order.length - 1;
      if (order[l].from == order[l].to) --l;
      var last = order[l], prev = order[l - 1];
      if (last.from + 1 == last.to && prev && last.level < prev.level) {
        var span = measure[builder.pos - 1];
        if (span) span.parentNode.insertBefore(span.measureRight = zeroWidthElement(cm.display.measure),
                                               span.nextSibling);
      }
    }

    signal(cm, "renderLine", cm, realLine, builder.pre);
    return builder.pre;
  }

  var tokenSpecialChars = /[\t\u0000-\u0019\u00ad\u200b\u2028\u2029\uFEFF]/g;
  function buildToken(builder, text, style, startStyle, endStyle, title) {
    if (!text) return;
    if (!tokenSpecialChars.test(text)) {
      builder.col += text.length;
      var content = document.createTextNode(text);
    } else {
      var content = document.createDocumentFragment(), pos = 0;
      while (true) {
        tokenSpecialChars.lastIndex = pos;
        var m = tokenSpecialChars.exec(text);
        var skipped = m ? m.index - pos : text.length - pos;
        if (skipped) {
          content.appendChild(document.createTextNode(text.slice(pos, pos + skipped)));
          builder.col += skipped;
        }
        if (!m) break;
        pos += skipped + 1;
        if (m[0] == "\t") {
          var tabSize = builder.cm.options.tabSize, tabWidth = tabSize - builder.col % tabSize;
          content.appendChild(elt("span", spaceStr(tabWidth), "cm-tab"));
          builder.col += tabWidth;
        } else {
          var token = elt("span", "\u2022", "cm-invalidchar");
          token.title = "\\u" + m[0].charCodeAt(0).toString(16);
          content.appendChild(token);
          builder.col += 1;
        }
      }
    }
    if (style || startStyle || endStyle || builder.measure) {
      var fullStyle = style || "";
      if (startStyle) fullStyle += startStyle;
      if (endStyle) fullStyle += endStyle;
      var token = elt("span", [content], fullStyle);
      if (title) token.title = title;
      return builder.pre.appendChild(token);
    }
    builder.pre.appendChild(content);
  }

  function buildTokenMeasure(builder, text, style, startStyle, endStyle) {
    var wrapping = builder.cm.options.lineWrapping;
    for (var i = 0; i < text.length; ++i) {
      var ch = text.charAt(i), start = i == 0;
      if (ch >= "\ud800" && ch < "\udbff" && i < text.length - 1) {
        ch = text.slice(i, i + 2);
        ++i;
      } else if (i && wrapping && spanAffectsWrapping(text, i)) {
        builder.pre.appendChild(elt("wbr"));
      }
      var old = builder.measure[builder.pos];
      var span = builder.measure[builder.pos] =
        buildToken(builder, ch, style,
                   start && startStyle, i == text.length - 1 && endStyle);
      if (old) span.leftSide = old.leftSide || old;
      // In IE single-space nodes wrap differently than spaces
      // embedded in larger text nodes, except when set to
      // white-space: normal (issue #1268).
      if (ie && wrapping && ch == " " && i && !/\s/.test(text.charAt(i - 1)) &&
          i < text.length - 1 && !/\s/.test(text.charAt(i + 1)))
        span.style.whiteSpace = "normal";
      builder.pos += ch.length;
    }
    if (text.length) builder.measuredSomething = true;
  }

  function buildTokenSplitSpaces(inner) {
    function split(old) {
      var out = " ";
      for (var i = 0; i < old.length - 2; ++i) out += i % 2 ? " " : "\u00a0";
      out += " ";
      return out;
    }
    return function(builder, text, style, startStyle, endStyle, title) {
      return inner(builder, text.replace(/ {3,}/, split), style, startStyle, endStyle, title);
    };
  }

  function buildCollapsedSpan(builder, size, marker, ignoreWidget) {
    var widget = !ignoreWidget && marker.replacedWith;
    if (widget) {
      if (builder.copyWidgets) widget = widget.cloneNode(true);
      builder.pre.appendChild(widget);
      if (builder.measure) {
        if (size) {
          builder.measure[builder.pos] = widget;
        } else {
          var elt = builder.measure[builder.pos] = zeroWidthElement(builder.cm.display.measure);
          if (marker.type != "bookmark" || marker.insertLeft)
            builder.pre.insertBefore(elt, widget);
          else
            builder.pre.appendChild(elt);
        }
        builder.measuredSomething = true;
      }
    }
    builder.pos += size;
  }

  // Outputs a number of spans to make up a line, taking highlighting
  // and marked text into account.
  function insertLineContent(line, builder, styles) {
    var spans = line.markedSpans, allText = line.text, at = 0;
    if (!spans) {
      for (var i = 1; i < styles.length; i+=2)
        builder.addToken(builder, allText.slice(at, at = styles[i]), styleToClass(styles[i+1]));
      return;
    }

    var len = allText.length, pos = 0, i = 1, text = "", style;
    var nextChange = 0, spanStyle, spanEndStyle, spanStartStyle, title, collapsed;
    for (;;) {
      if (nextChange == pos) { // Update current marker set
        spanStyle = spanEndStyle = spanStartStyle = title = "";
        collapsed = null; nextChange = Infinity;
        var foundBookmark = null;
        for (var j = 0; j < spans.length; ++j) {
          var sp = spans[j], m = sp.marker;
          if (sp.from <= pos && (sp.to == null || sp.to > pos)) {
            if (sp.to != null && nextChange > sp.to) { nextChange = sp.to; spanEndStyle = ""; }
            if (m.className) spanStyle += " " + m.className;
            if (m.startStyle && sp.from == pos) spanStartStyle += " " + m.startStyle;
            if (m.endStyle && sp.to == nextChange) spanEndStyle += " " + m.endStyle;
            if (m.title && !title) title = m.title;
            if (m.collapsed && (!collapsed || collapsed.marker.size < m.size))
              collapsed = sp;
          } else if (sp.from > pos && nextChange > sp.from) {
            nextChange = sp.from;
          }
          if (m.type == "bookmark" && sp.from == pos && m.replacedWith) foundBookmark = m;
        }
        if (collapsed && (collapsed.from || 0) == pos) {
          buildCollapsedSpan(builder, (collapsed.to == null ? len : collapsed.to) - pos,
                             collapsed.marker, collapsed.from == null);
          if (collapsed.to == null) return collapsed.marker.find();
        }
        if (foundBookmark && !collapsed) buildCollapsedSpan(builder, 0, foundBookmark);
      }
      if (pos >= len) break;

      var upto = Math.min(len, nextChange);
      while (true) {
        if (text) {
          var end = pos + text.length;
          if (!collapsed) {
            var tokenText = end > upto ? text.slice(0, upto - pos) : text;
            builder.addToken(builder, tokenText, style ? style + spanStyle : spanStyle,
                             spanStartStyle, pos + tokenText.length == nextChange ? spanEndStyle : "", title);
          }
          if (end >= upto) {text = text.slice(upto - pos); pos = upto; break;}
          pos = end;
          spanStartStyle = "";
        }
        text = allText.slice(at, at = styles[i++]);
        style = styleToClass(styles[i++]);
      }
    }
  }

  // DOCUMENT DATA STRUCTURE

  function updateDoc(doc, change, markedSpans, selAfter, estimateHeight) {
    function spansFor(n) {return markedSpans ? markedSpans[n] : null;}
    function update(line, text, spans) {
      updateLine(line, text, spans, estimateHeight);
      signalLater(line, "change", line, change);
    }

    var from = change.from, to = change.to, text = change.text;
    var firstLine = getLine(doc, from.line), lastLine = getLine(doc, to.line);
    var lastText = lst(text), lastSpans = spansFor(text.length - 1), nlines = to.line - from.line;

    // First adjust the line structure
    if (from.ch == 0 && to.ch == 0 && lastText == "") {
      // This is a whole-line replace. Treated specially to make
      // sure line objects move the way they are supposed to.
      for (var i = 0, e = text.length - 1, added = []; i < e; ++i)
        added.push(new Line(text[i], spansFor(i), estimateHeight));
      update(lastLine, lastLine.text, lastSpans);
      if (nlines) doc.remove(from.line, nlines);
      if (added.length) doc.insert(from.line, added);
    } else if (firstLine == lastLine) {
      if (text.length == 1) {
        update(firstLine, firstLine.text.slice(0, from.ch) + lastText + firstLine.text.slice(to.ch), lastSpans);
      } else {
        for (var added = [], i = 1, e = text.length - 1; i < e; ++i)
          added.push(new Line(text[i], spansFor(i), estimateHeight));
        added.push(new Line(lastText + firstLine.text.slice(to.ch), lastSpans, estimateHeight));
        update(firstLine, firstLine.text.slice(0, from.ch) + text[0], spansFor(0));
        doc.insert(from.line + 1, added);
      }
    } else if (text.length == 1) {
      update(firstLine, firstLine.text.slice(0, from.ch) + text[0] + lastLine.text.slice(to.ch), spansFor(0));
      doc.remove(from.line + 1, nlines);
    } else {
      update(firstLine, firstLine.text.slice(0, from.ch) + text[0], spansFor(0));
      update(lastLine, lastText + lastLine.text.slice(to.ch), lastSpans);
      for (var i = 1, e = text.length - 1, added = []; i < e; ++i)
        added.push(new Line(text[i], spansFor(i), estimateHeight));
      if (nlines > 1) doc.remove(from.line + 1, nlines - 1);
      doc.insert(from.line + 1, added);
    }

    signalLater(doc, "change", doc, change);
    setSelection(doc, selAfter.anchor, selAfter.head, null, true);
  }

  function LeafChunk(lines) {
    this.lines = lines;
    this.parent = null;
    for (var i = 0, e = lines.length, height = 0; i < e; ++i) {
      lines[i].parent = this;
      height += lines[i].height;
    }
    this.height = height;
  }

  LeafChunk.prototype = {
    chunkSize: function() { return this.lines.length; },
    removeInner: function(at, n) {
      for (var i = at, e = at + n; i < e; ++i) {
        var line = this.lines[i];
        this.height -= line.height;
        cleanUpLine(line);
        signalLater(line, "delete");
      }
      this.lines.splice(at, n);
    },
    collapse: function(lines) {
      lines.splice.apply(lines, [lines.length, 0].concat(this.lines));
    },
    insertInner: function(at, lines, height) {
      this.height += height;
      this.lines = this.lines.slice(0, at).concat(lines).concat(this.lines.slice(at));
      for (var i = 0, e = lines.length; i < e; ++i) lines[i].parent = this;
    },
    iterN: function(at, n, op) {
      for (var e = at + n; at < e; ++at)
        if (op(this.lines[at])) return true;
    }
  };

  function BranchChunk(children) {
    this.children = children;
    var size = 0, height = 0;
    for (var i = 0, e = children.length; i < e; ++i) {
      var ch = children[i];
      size += ch.chunkSize(); height += ch.height;
      ch.parent = this;
    }
    this.size = size;
    this.height = height;
    this.parent = null;
  }

  BranchChunk.prototype = {
    chunkSize: function() { return this.size; },
    removeInner: function(at, n) {
      this.size -= n;
      for (var i = 0; i < this.children.length; ++i) {
        var child = this.children[i], sz = child.chunkSize();
        if (at < sz) {
          var rm = Math.min(n, sz - at), oldHeight = child.height;
          child.removeInner(at, rm);
          this.height -= oldHeight - child.height;
          if (sz == rm) { this.children.splice(i--, 1); child.parent = null; }
          if ((n -= rm) == 0) break;
          at = 0;
        } else at -= sz;
      }
      if (this.size - n < 25) {
        var lines = [];
        this.collapse(lines);
        this.children = [new LeafChunk(lines)];
        this.children[0].parent = this;
      }
    },
    collapse: function(lines) {
      for (var i = 0, e = this.children.length; i < e; ++i) this.children[i].collapse(lines);
    },
    insertInner: function(at, lines, height) {
      this.size += lines.length;
      this.height += height;
      for (var i = 0, e = this.children.length; i < e; ++i) {
        var child = this.children[i], sz = child.chunkSize();
        if (at <= sz) {
          child.insertInner(at, lines, height);
          if (child.lines && child.lines.length > 50) {
            while (child.lines.length > 50) {
              var spilled = child.lines.splice(child.lines.length - 25, 25);
              var newleaf = new LeafChunk(spilled);
              child.height -= newleaf.height;
              this.children.splice(i + 1, 0, newleaf);
              newleaf.parent = this;
            }
            this.maybeSpill();
          }
          break;
        }
        at -= sz;
      }
    },
    maybeSpill: function() {
      if (this.children.length <= 10) return;
      var me = this;
      do {
        var spilled = me.children.splice(me.children.length - 5, 5);
        var sibling = new BranchChunk(spilled);
        if (!me.parent) { // Become the parent node
          var copy = new BranchChunk(me.children);
          copy.parent = me;
          me.children = [copy, sibling];
          me = copy;
        } else {
          me.size -= sibling.size;
          me.height -= sibling.height;
          var myIndex = indexOf(me.parent.children, me);
          me.parent.children.splice(myIndex + 1, 0, sibling);
        }
        sibling.parent = me.parent;
      } while (me.children.length > 10);
      me.parent.maybeSpill();
    },
    iterN: function(at, n, op) {
      for (var i = 0, e = this.children.length; i < e; ++i) {
        var child = this.children[i], sz = child.chunkSize();
        if (at < sz) {
          var used = Math.min(n, sz - at);
          if (child.iterN(at, used, op)) return true;
          if ((n -= used) == 0) break;
          at = 0;
        } else at -= sz;
      }
    }
  };

  var nextDocId = 0;
  var Doc = CodeMirror.Doc = function(text, mode, firstLine) {
    if (!(this instanceof Doc)) return new Doc(text, mode, firstLine);
    if (firstLine == null) firstLine = 0;

    BranchChunk.call(this, [new LeafChunk([new Line("", null)])]);
    this.first = firstLine;
    this.scrollTop = this.scrollLeft = 0;
    this.cantEdit = false;
    this.history = makeHistory();
    this.cleanGeneration = 1;
    this.frontier = firstLine;
    var start = Pos(firstLine, 0);
    this.sel = {from: start, to: start, head: start, anchor: start, shift: false, extend: false, goalColumn: null};
    this.id = ++nextDocId;
    this.modeOption = mode;

    if (typeof text == "string") text = splitLines(text);
    updateDoc(this, {from: start, to: start, text: text}, null, {head: start, anchor: start});
  };

  Doc.prototype = createObj(BranchChunk.prototype, {
    constructor: Doc,
    iter: function(from, to, op) {
      if (op) this.iterN(from - this.first, to - from, op);
      else this.iterN(this.first, this.first + this.size, from);
    },

    insert: function(at, lines) {
      var height = 0;
      for (var i = 0, e = lines.length; i < e; ++i) height += lines[i].height;
      this.insertInner(at - this.first, lines, height);
    },
    remove: function(at, n) { this.removeInner(at - this.first, n); },

    getValue: function(lineSep) {
      var lines = getLines(this, this.first, this.first + this.size);
      if (lineSep === false) return lines;
      return lines.join(lineSep || "\n");
    },
    setValue: function(code) {
      var top = Pos(this.first, 0), last = this.first + this.size - 1;
      makeChange(this, {from: top, to: Pos(last, getLine(this, last).text.length),
                        text: splitLines(code), origin: "setValue"},
                 {head: top, anchor: top}, true);
    },
    replaceRange: function(code, from, to, origin) {
      from = clipPos(this, from);
      to = to ? clipPos(this, to) : from;
      replaceRange(this, code, from, to, origin);
    },
    getRange: function(from, to, lineSep) {
      var lines = getBetween(this, clipPos(this, from), clipPos(this, to));
      if (lineSep === false) return lines;
      return lines.join(lineSep || "\n");
    },

    getLine: function(line) {var l = this.getLineHandle(line); return l && l.text;},
    setLine: function(line, text) {
      if (isLine(this, line))
        replaceRange(this, text, Pos(line, 0), clipPos(this, Pos(line)));
    },
    removeLine: function(line) {
      if (line) replaceRange(this, "", clipPos(this, Pos(line - 1)), clipPos(this, Pos(line)));
      else replaceRange(this, "", Pos(0, 0), clipPos(this, Pos(1, 0)));
    },

    getLineHandle: function(line) {if (isLine(this, line)) return getLine(this, line);},
    getLineNumber: function(line) {return lineNo(line);},

    getLineHandleVisualStart: function(line) {
      if (typeof line == "number") line = getLine(this, line);
      return visualLine(this, line);
    },

    lineCount: function() {return this.size;},
    firstLine: function() {return this.first;},
    lastLine: function() {return this.first + this.size - 1;},

    clipPos: function(pos) {return clipPos(this, pos);},

    getCursor: function(start) {
      var sel = this.sel, pos;
      if (start == null || start == "head") pos = sel.head;
      else if (start == "anchor") pos = sel.anchor;
      else if (start == "end" || start === false) pos = sel.to;
      else pos = sel.from;
      return copyPos(pos);
    },
    somethingSelected: function() {return !posEq(this.sel.head, this.sel.anchor);},

    setCursor: docOperation(function(line, ch, extend) {
      var pos = clipPos(this, typeof line == "number" ? Pos(line, ch || 0) : line);
      if (extend) extendSelection(this, pos);
      else setSelection(this, pos, pos);
    }),
    setSelection: docOperation(function(anchor, head) {
      setSelection(this, clipPos(this, anchor), clipPos(this, head || anchor));
    }),
    extendSelection: docOperation(function(from, to) {
      extendSelection(this, clipPos(this, from), to && clipPos(this, to));
    }),

    getSelection: function(lineSep) {return this.getRange(this.sel.from, this.sel.to, lineSep);},
    replaceSelection: function(code, collapse, origin) {
      makeChange(this, {from: this.sel.from, to: this.sel.to, text: splitLines(code), origin: origin}, collapse || "around");
    },
    undo: docOperation(function() {makeChangeFromHistory(this, "undo");}),
    redo: docOperation(function() {makeChangeFromHistory(this, "redo");}),

    setExtending: function(val) {this.sel.extend = val;},

    historySize: function() {
      var hist = this.history;
      return {undo: hist.done.length, redo: hist.undone.length};
    },
    clearHistory: function() {this.history = makeHistory(this.history.maxGeneration);},

    markClean: function() {
      this.cleanGeneration = this.changeGeneration();
    },
    changeGeneration: function() {
      this.history.lastOp = this.history.lastOrigin = null;
      return this.history.generation;
    },
    isClean: function (gen) {
      return this.history.generation == (gen || this.cleanGeneration);
    },

    getHistory: function() {
      return {done: copyHistoryArray(this.history.done),
              undone: copyHistoryArray(this.history.undone)};
    },
    setHistory: function(histData) {
      var hist = this.history = makeHistory(this.history.maxGeneration);
      hist.done = histData.done.slice(0);
      hist.undone = histData.undone.slice(0);
    },

    markText: function(from, to, options) {
      return markText(this, clipPos(this, from), clipPos(this, to), options, "range");
    },
    setBookmark: function(pos, options) {
      var realOpts = {replacedWith: options && (options.nodeType == null ? options.widget : options),
                      insertLeft: options && options.insertLeft};
      pos = clipPos(this, pos);
      return markText(this, pos, pos, realOpts, "bookmark");
    },
    findMarksAt: function(pos) {
      pos = clipPos(this, pos);
      var markers = [], spans = getLine(this, pos.line).markedSpans;
      if (spans) for (var i = 0; i < spans.length; ++i) {
        var span = spans[i];
        if ((span.from == null || span.from <= pos.ch) &&
            (span.to == null || span.to >= pos.ch))
          markers.push(span.marker.parent || span.marker);
      }
      return markers;
    },
    getAllMarks: function() {
      var markers = [];
      this.iter(function(line) {
        var sps = line.markedSpans;
        if (sps) for (var i = 0; i < sps.length; ++i)
          if (sps[i].from != null) markers.push(sps[i].marker);
      });
      return markers;
    },

    posFromIndex: function(off) {
      var ch, lineNo = this.first;
      this.iter(function(line) {
        var sz = line.text.length + 1;
        if (sz > off) { ch = off; return true; }
        off -= sz;
        ++lineNo;
      });
      return clipPos(this, Pos(lineNo, ch));
    },
    indexFromPos: function (coords) {
      coords = clipPos(this, coords);
      var index = coords.ch;
      if (coords.line < this.first || coords.ch < 0) return 0;
      this.iter(this.first, coords.line, function (line) {
        index += line.text.length + 1;
      });
      return index;
    },

    copy: function(copyHistory) {
      var doc = new Doc(getLines(this, this.first, this.first + this.size), this.modeOption, this.first);
      doc.scrollTop = this.scrollTop; doc.scrollLeft = this.scrollLeft;
      doc.sel = {from: this.sel.from, to: this.sel.to, head: this.sel.head, anchor: this.sel.anchor,
                 shift: this.sel.shift, extend: false, goalColumn: this.sel.goalColumn};
      if (copyHistory) {
        doc.history.undoDepth = this.history.undoDepth;
        doc.setHistory(this.getHistory());
      }
      return doc;
    },

    linkedDoc: function(options) {
      if (!options) options = {};
      var from = this.first, to = this.first + this.size;
      if (options.from != null && options.from > from) from = options.from;
      if (options.to != null && options.to < to) to = options.to;
      var copy = new Doc(getLines(this, from, to), options.mode || this.modeOption, from);
      if (options.sharedHist) copy.history = this.history;
      (this.linked || (this.linked = [])).push({doc: copy, sharedHist: options.sharedHist});
      copy.linked = [{doc: this, isParent: true, sharedHist: options.sharedHist}];
      return copy;
    },
    unlinkDoc: function(other) {
      if (other instanceof CodeMirror) other = other.doc;
      if (this.linked) for (var i = 0; i < this.linked.length; ++i) {
        var link = this.linked[i];
        if (link.doc != other) continue;
        this.linked.splice(i, 1);
        other.unlinkDoc(this);
        break;
      }
      // If the histories were shared, split them again
      if (other.history == this.history) {
        var splitIds = [other.id];
        linkedDocs(other, function(doc) {splitIds.push(doc.id);}, true);
        other.history = makeHistory();
        other.history.done = copyHistoryArray(this.history.done, splitIds);
        other.history.undone = copyHistoryArray(this.history.undone, splitIds);
      }
    },
    iterLinkedDocs: function(f) {linkedDocs(this, f);},

    getMode: function() {return this.mode;},
    getEditor: function() {return this.cm;}
  });

  Doc.prototype.eachLine = Doc.prototype.iter;

  // The Doc methods that should be available on CodeMirror instances
  var dontDelegate = "iter insert remove copy getEditor".split(" ");
  for (var prop in Doc.prototype) if (Doc.prototype.hasOwnProperty(prop) && indexOf(dontDelegate, prop) < 0)
    CodeMirror.prototype[prop] = (function(method) {
      return function() {return method.apply(this.doc, arguments);};
    })(Doc.prototype[prop]);

  eventMixin(Doc);

  function linkedDocs(doc, f, sharedHistOnly) {
    function propagate(doc, skip, sharedHist) {
      if (doc.linked) for (var i = 0; i < doc.linked.length; ++i) {
        var rel = doc.linked[i];
        if (rel.doc == skip) continue;
        var shared = sharedHist && rel.sharedHist;
        if (sharedHistOnly && !shared) continue;
        f(rel.doc, shared);
        propagate(rel.doc, doc, shared);
      }
    }
    propagate(doc, null, true);
  }

  function attachDoc(cm, doc) {
    if (doc.cm) throw new Error("This document is already in use.");
    cm.doc = doc;
    doc.cm = cm;
    estimateLineHeights(cm);
    loadMode(cm);
    if (!cm.options.lineWrapping) computeMaxLength(cm);
    cm.options.mode = doc.modeOption;
    regChange(cm);
  }

  // LINE UTILITIES

  function getLine(chunk, n) {
    n -= chunk.first;
    while (!chunk.lines) {
      for (var i = 0;; ++i) {
        var child = chunk.children[i], sz = child.chunkSize();
        if (n < sz) { chunk = child; break; }
        n -= sz;
      }
    }
    return chunk.lines[n];
  }

  function getBetween(doc, start, end) {
    var out = [], n = start.line;
    doc.iter(start.line, end.line + 1, function(line) {
      var text = line.text;
      if (n == end.line) text = text.slice(0, end.ch);
      if (n == start.line) text = text.slice(start.ch);
      out.push(text);
      ++n;
    });
    return out;
  }
  function getLines(doc, from, to) {
    var out = [];
    doc.iter(from, to, function(line) { out.push(line.text); });
    return out;
  }

  function updateLineHeight(line, height) {
    var diff = height - line.height;
    for (var n = line; n; n = n.parent) n.height += diff;
  }

  function lineNo(line) {
    if (line.parent == null) return null;
    var cur = line.parent, no = indexOf(cur.lines, line);
    for (var chunk = cur.parent; chunk; cur = chunk, chunk = chunk.parent) {
      for (var i = 0;; ++i) {
        if (chunk.children[i] == cur) break;
        no += chunk.children[i].chunkSize();
      }
    }
    return no + cur.first;
  }

  function lineAtHeight(chunk, h) {
    var n = chunk.first;
    outer: do {
      for (var i = 0, e = chunk.children.length; i < e; ++i) {
        var child = chunk.children[i], ch = child.height;
        if (h < ch) { chunk = child; continue outer; }
        h -= ch;
        n += child.chunkSize();
      }
      return n;
    } while (!chunk.lines);
    for (var i = 0, e = chunk.lines.length; i < e; ++i) {
      var line = chunk.lines[i], lh = line.height;
      if (h < lh) break;
      h -= lh;
    }
    return n + i;
  }

  function heightAtLine(cm, lineObj) {
    lineObj = visualLine(cm.doc, lineObj);

    var h = 0, chunk = lineObj.parent;
    for (var i = 0; i < chunk.lines.length; ++i) {
      var line = chunk.lines[i];
      if (line == lineObj) break;
      else h += line.height;
    }
    for (var p = chunk.parent; p; chunk = p, p = chunk.parent) {
      for (var i = 0; i < p.children.length; ++i) {
        var cur = p.children[i];
        if (cur == chunk) break;
        else h += cur.height;
      }
    }
    return h;
  }

  function getOrder(line) {
    var order = line.order;
    if (order == null) order = line.order = bidiOrdering(line.text);
    return order;
  }

  // HISTORY

  function makeHistory(startGen) {
    return {
      // Arrays of history events. Doing something adds an event to
      // done and clears undo. Undoing moves events from done to
      // undone, redoing moves them in the other direction.
      done: [], undone: [], undoDepth: Infinity,
      // Used to track when changes can be merged into a single undo
      // event
      lastTime: 0, lastOp: null, lastOrigin: null,
      // Used by the isClean() method
      generation: startGen || 1, maxGeneration: startGen || 1
    };
  }

  function attachLocalSpans(doc, change, from, to) {
    var existing = change["spans_" + doc.id], n = 0;
    doc.iter(Math.max(doc.first, from), Math.min(doc.first + doc.size, to), function(line) {
      if (line.markedSpans)
        (existing || (existing = change["spans_" + doc.id] = {}))[n] = line.markedSpans;
      ++n;
    });
  }

  function historyChangeFromChange(doc, change) {
    var from = { line: change.from.line, ch: change.from.ch };
    var histChange = {from: from, to: changeEnd(change), text: getBetween(doc, change.from, change.to)};
    attachLocalSpans(doc, histChange, change.from.line, change.to.line + 1);
    linkedDocs(doc, function(doc) {attachLocalSpans(doc, histChange, change.from.line, change.to.line + 1);}, true);
    return histChange;
  }

  function addToHistory(doc, change, selAfter, opId) {
    var hist = doc.history;
    hist.undone.length = 0;
    var time = +new Date, cur = lst(hist.done);

    if (cur &&
        (hist.lastOp == opId ||
         hist.lastOrigin == change.origin && change.origin &&
         ((change.origin.charAt(0) == "+" && doc.cm && hist.lastTime > time - doc.cm.options.historyEventDelay) ||
          change.origin.charAt(0) == "*"))) {
      // Merge this change into the last event
      var last = lst(cur.changes);
      if (posEq(change.from, change.to) && posEq(change.from, last.to)) {
        // Optimized case for simple insertion -- don't want to add
        // new changesets for every character typed
        last.to = changeEnd(change);
      } else {
        // Add new sub-event
        cur.changes.push(historyChangeFromChange(doc, change));
      }
      cur.anchorAfter = selAfter.anchor; cur.headAfter = selAfter.head;
    } else {
      // Can not be merged, start a new event.
      cur = {changes: [historyChangeFromChange(doc, change)],
             generation: hist.generation,
             anchorBefore: doc.sel.anchor, headBefore: doc.sel.head,
             anchorAfter: selAfter.anchor, headAfter: selAfter.head};
      hist.done.push(cur);
      hist.generation = ++hist.maxGeneration;
      while (hist.done.length > hist.undoDepth)
        hist.done.shift();
    }
    hist.lastTime = time;
    hist.lastOp = opId;
    hist.lastOrigin = change.origin;
  }

  function removeClearedSpans(spans) {
    if (!spans) return null;
    for (var i = 0, out; i < spans.length; ++i) {
      if (spans[i].marker.explicitlyCleared) { if (!out) out = spans.slice(0, i); }
      else if (out) out.push(spans[i]);
    }
    return !out ? spans : out.length ? out : null;
  }

  function getOldSpans(doc, change) {
    var found = change["spans_" + doc.id];
    if (!found) return null;
    for (var i = 0, nw = []; i < change.text.length; ++i)
      nw.push(removeClearedSpans(found[i]));
    return nw;
  }

  // Used both to provide a JSON-safe object in .getHistory, and, when
  // detaching a document, to split the history in two
  function copyHistoryArray(events, newGroup) {
    for (var i = 0, copy = []; i < events.length; ++i) {
      var event = events[i], changes = event.changes, newChanges = [];
      copy.push({changes: newChanges, anchorBefore: event.anchorBefore, headBefore: event.headBefore,
                 anchorAfter: event.anchorAfter, headAfter: event.headAfter});
      for (var j = 0; j < changes.length; ++j) {
        var change = changes[j], m;
        newChanges.push({from: change.from, to: change.to, text: change.text});
        if (newGroup) for (var prop in change) if (m = prop.match(/^spans_(\d+)$/)) {
          if (indexOf(newGroup, Number(m[1])) > -1) {
            lst(newChanges)[prop] = change[prop];
            delete change[prop];
          }
        }
      }
    }
    return copy;
  }

  // Rebasing/resetting history to deal with externally-sourced changes

  function rebaseHistSel(pos, from, to, diff) {
    if (to < pos.line) {
      pos.line += diff;
    } else if (from < pos.line) {
      pos.line = from;
      pos.ch = 0;
    }
  }

  // Tries to rebase an array of history events given a change in the
  // document. If the change touches the same lines as the event, the
  // event, and everything 'behind' it, is discarded. If the change is
  // before the event, the event's positions are updated. Uses a
  // copy-on-write scheme for the positions, to avoid having to
  // reallocate them all on every rebase, but also avoid problems with
  // shared position objects being unsafely updated.
  function rebaseHistArray(array, from, to, diff) {
    for (var i = 0; i < array.length; ++i) {
      var sub = array[i], ok = true;
      for (var j = 0; j < sub.changes.length; ++j) {
        var cur = sub.changes[j];
        if (!sub.copied) { cur.from = copyPos(cur.from); cur.to = copyPos(cur.to); }
        if (to < cur.from.line) {
          cur.from.line += diff;
          cur.to.line += diff;
        } else if (from <= cur.to.line) {
          ok = false;
          break;
        }
      }
      if (!sub.copied) {
        sub.anchorBefore = copyPos(sub.anchorBefore); sub.headBefore = copyPos(sub.headBefore);
        sub.anchorAfter = copyPos(sub.anchorAfter); sub.readAfter = copyPos(sub.headAfter);
        sub.copied = true;
      }
      if (!ok) {
        array.splice(0, i + 1);
        i = 0;
      } else {
        rebaseHistSel(sub.anchorBefore); rebaseHistSel(sub.headBefore);
        rebaseHistSel(sub.anchorAfter); rebaseHistSel(sub.headAfter);
      }
    }
  }

  function rebaseHist(hist, change) {
    var from = change.from.line, to = change.to.line, diff = change.text.length - (to - from) - 1;
    rebaseHistArray(hist.done, from, to, diff);
    rebaseHistArray(hist.undone, from, to, diff);
  }

  // EVENT OPERATORS

  function stopMethod() {e_stop(this);}
  // Ensure an event has a stop method.
  function addStop(event) {
    if (!event.stop) event.stop = stopMethod;
    return event;
  }

  function e_preventDefault(e) {
    if (e.preventDefault) e.preventDefault();
    else e.returnValue = false;
  }
  function e_stopPropagation(e) {
    if (e.stopPropagation) e.stopPropagation();
    else e.cancelBubble = true;
  }
  function e_defaultPrevented(e) {
    return e.defaultPrevented != null ? e.defaultPrevented : e.returnValue == false;
  }
  function e_stop(e) {e_preventDefault(e); e_stopPropagation(e);}
  CodeMirror.e_stop = e_stop;
  CodeMirror.e_preventDefault = e_preventDefault;
  CodeMirror.e_stopPropagation = e_stopPropagation;

  function e_target(e) {return e.target || e.srcElement;}
  function e_button(e) {
    var b = e.which;
    if (b == null) {
      if (e.button & 1) b = 1;
      else if (e.button & 2) b = 3;
      else if (e.button & 4) b = 2;
    }
    if (mac && e.ctrlKey && b == 1) b = 3;
    return b;
  }

  // EVENT HANDLING

  function on(emitter, type, f) {
    if (emitter.addEventListener)
      emitter.addEventListener(type, f, false);
    else if (emitter.attachEvent)
      emitter.attachEvent("on" + type, f);
    else {
      var map = emitter._handlers || (emitter._handlers = {});
      var arr = map[type] || (map[type] = []);
      arr.push(f);
    }
  }

  function off(emitter, type, f) {
    if (emitter.removeEventListener)
      emitter.removeEventListener(type, f, false);
    else if (emitter.detachEvent)
      emitter.detachEvent("on" + type, f);
    else {
      var arr = emitter._handlers && emitter._handlers[type];
      if (!arr) return;
      for (var i = 0; i < arr.length; ++i)
        if (arr[i] == f) { arr.splice(i, 1); break; }
    }
  }

  function signal(emitter, type /*, values...*/) {
    var arr = emitter._handlers && emitter._handlers[type];
    if (!arr) return;
    var args = Array.prototype.slice.call(arguments, 2);
    for (var i = 0; i < arr.length; ++i) arr[i].apply(null, args);
  }

  var delayedCallbacks, delayedCallbackDepth = 0;
  function signalLater(emitter, type /*, values...*/) {
    var arr = emitter._handlers && emitter._handlers[type];
    if (!arr) return;
    var args = Array.prototype.slice.call(arguments, 2);
    if (!delayedCallbacks) {
      ++delayedCallbackDepth;
      delayedCallbacks = [];
      setTimeout(fireDelayed, 0);
    }
    function bnd(f) {return function(){f.apply(null, args);};};
    for (var i = 0; i < arr.length; ++i)
      delayedCallbacks.push(bnd(arr[i]));
  }

  function signalDOMEvent(cm, e, override) {
    signal(cm, override || e.type, cm, e);
    return e_defaultPrevented(e) || e.codemirrorIgnore;
  }

  function fireDelayed() {
    --delayedCallbackDepth;
    var delayed = delayedCallbacks;
    delayedCallbacks = null;
    for (var i = 0; i < delayed.length; ++i) delayed[i]();
  }

  function hasHandler(emitter, type) {
    var arr = emitter._handlers && emitter._handlers[type];
    return arr && arr.length > 0;
  }

  CodeMirror.on = on; CodeMirror.off = off; CodeMirror.signal = signal;

  function eventMixin(ctor) {
    ctor.prototype.on = function(type, f) {on(this, type, f);};
    ctor.prototype.off = function(type, f) {off(this, type, f);};
  }

  // MISC UTILITIES

  // Number of pixels added to scroller and sizer to hide scrollbar
  var scrollerCutOff = 30;

  // Returned or thrown by various protocols to signal 'I'm not
  // handling this'.
  var Pass = CodeMirror.Pass = {toString: function(){return "CodeMirror.Pass";}};

  function Delayed() {this.id = null;}
  Delayed.prototype = {set: function(ms, f) {clearTimeout(this.id); this.id = setTimeout(f, ms);}};

  // Counts the column offset in a string, taking tabs into account.
  // Used mostly to find indentation.
  function countColumn(string, end, tabSize, startIndex, startValue) {
    if (end == null) {
      end = string.search(/[^\s\u00a0]/);
      if (end == -1) end = string.length;
    }
    for (var i = startIndex || 0, n = startValue || 0; i < end; ++i) {
      if (string.charAt(i) == "\t") n += tabSize - (n % tabSize);
      else ++n;
    }
    return n;
  }
  CodeMirror.countColumn = countColumn;

  var spaceStrs = [""];
  function spaceStr(n) {
    while (spaceStrs.length <= n)
      spaceStrs.push(lst(spaceStrs) + " ");
    return spaceStrs[n];
  }

  function lst(arr) { return arr[arr.length-1]; }

  function selectInput(node) {
    if (ios) { // Mobile Safari apparently has a bug where select() is broken.
      node.selectionStart = 0;
      node.selectionEnd = node.value.length;
    } else {
      // Suppress mysterious IE10 errors
      try { node.select(); }
      catch(_e) {}
    }
  }

  function indexOf(collection, elt) {
    if (collection.indexOf) return collection.indexOf(elt);
    for (var i = 0, e = collection.length; i < e; ++i)
      if (collection[i] == elt) return i;
    return -1;
  }

  function createObj(base, props) {
    function Obj() {}
    Obj.prototype = base;
    var inst = new Obj();
    if (props) copyObj(props, inst);
    return inst;
  }

  function copyObj(obj, target) {
    if (!target) target = {};
    for (var prop in obj) if (obj.hasOwnProperty(prop)) target[prop] = obj[prop];
    return target;
  }

  function emptyArray(size) {
    for (var a = [], i = 0; i < size; ++i) a.push(undefined);
    return a;
  }

  function bind(f) {
    var args = Array.prototype.slice.call(arguments, 1);
    return function(){return f.apply(null, args);};
  }

  var nonASCIISingleCaseWordChar = /[\u3040-\u309f\u30a0-\u30ff\u3400-\u4db5\u4e00-\u9fcc\uac00-\ud7af]/;
  function isWordChar(ch) {
    return /\w/.test(ch) || ch > "\x80" &&
      (ch.toUpperCase() != ch.toLowerCase() || nonASCIISingleCaseWordChar.test(ch));
  }

  function isEmpty(obj) {
    for (var n in obj) if (obj.hasOwnProperty(n) && obj[n]) return false;
    return true;
  }

  var isExtendingChar = /[\u0300-\u036F\u0483-\u0487\u0488-\u0489\u0591-\u05BD\u05BF\u05C1-\u05C2\u05C4-\u05C5\u05C7\u0610-\u061A\u064B-\u065F\u0670\u06D6-\u06DC\u06DF-\u06E4\u06E7-\u06E8\u06EA-\u06ED\uA66F\uA670-\uA672\uA674-\uA67D\uA69F\udc00-\udfff]/;

  // DOM UTILITIES

  function elt(tag, content, className, style) {
    var e = document.createElement(tag);
    if (className) e.className = className;
    if (style) e.style.cssText = style;
    if (typeof content == "string") setTextContent(e, content);
    else if (content) for (var i = 0; i < content.length; ++i) e.appendChild(content[i]);
    return e;
  }

  function removeChildren(e) {
    for (var count = e.childNodes.length; count > 0; --count)
      e.removeChild(e.firstChild);
    return e;
  }

  function removeChildrenAndAdd(parent, e) {
    return removeChildren(parent).appendChild(e);
  }

  function setTextContent(e, str) {
    if (ie_lt9) {
      e.innerHTML = "";
      e.appendChild(document.createTextNode(str));
    } else e.textContent = str;
  }

  function getRect(node) {
    return node.getBoundingClientRect();
  }
  CodeMirror.replaceGetRect = function(f) { getRect = f; };

  // FEATURE DETECTION

  // Detect drag-and-drop
  var dragAndDrop = function() {
    // There is *some* kind of drag-and-drop support in IE6-8, but I
    // couldn't get it to work yet.
    if (ie_lt9) return false;
    var div = elt('div');
    return "draggable" in div || "dragDrop" in div;
  }();

  // For a reason I have yet to figure out, some browsers disallow
  // word wrapping between certain characters *only* if a new inline
  // element is started between them. This makes it hard to reliably
  // measure the position of things, since that requires inserting an
  // extra span. This terribly fragile set of tests matches the
  // character combinations that suffer from this phenomenon on the
  // various browsers.
  function spanAffectsWrapping() { return false; }
  if (gecko) // Only for "$'"
    spanAffectsWrapping = function(str, i) {
      return str.charCodeAt(i - 1) == 36 && str.charCodeAt(i) == 39;
    };
  else if (safari && !/Version\/([6-9]|\d\d)\b/.test(navigator.userAgent))
    spanAffectsWrapping = function(str, i) {
      return /\-[^ \-?]|\?[^ !\'\"\),.\-\/:;\?\]\}]/.test(str.slice(i - 1, i + 1));
    };
  else if (webkit && !/Chrome\/(?:29|[3-9]\d|\d\d\d)\./.test(navigator.userAgent))
    spanAffectsWrapping = function(str, i) {
      if (i > 1 && str.charCodeAt(i - 1) == 45) {
        if (/\w/.test(str.charAt(i - 2)) && /[^\-?\.]/.test(str.charAt(i))) return true;
        if (i > 2 && /[\d\.,]/.test(str.charAt(i - 2)) && /[\d\.,]/.test(str.charAt(i))) return false;
      }
      return /[~!#%&*)=+}\]|\"\.>,:;][({[<]|-[^\-?\.\u2010-\u201f\u2026]|\?[\w~`@#$%\^&*(_=+{[|><]|…[\w~`@#$%\^&*(_=+{[><]/.test(str.slice(i - 1, i + 1));
    };

  var knownScrollbarWidth;
  function scrollbarWidth(measure) {
    if (knownScrollbarWidth != null) return knownScrollbarWidth;
    var test = elt("div", null, null, "width: 50px; height: 50px; overflow-x: scroll");
    removeChildrenAndAdd(measure, test);
    if (test.offsetWidth)
      knownScrollbarWidth = test.offsetHeight - test.clientHeight;
    return knownScrollbarWidth || 0;
  }

  var zwspSupported;
  function zeroWidthElement(measure) {
    if (zwspSupported == null) {
      var test = elt("span", "\u200b");
      removeChildrenAndAdd(measure, elt("span", [test, document.createTextNode("x")]));
      if (measure.firstChild.offsetHeight != 0)
        zwspSupported = test.offsetWidth <= 1 && test.offsetHeight > 2 && !ie_lt8;
    }
    if (zwspSupported) return elt("span", "\u200b");
    else return elt("span", "\u00a0", null, "display: inline-block; width: 1px; margin-right: -1px");
  }

  // See if "".split is the broken IE version, if so, provide an
  // alternative way to split lines.
  var splitLines = "\n\nb".split(/\n/).length != 3 ? function(string) {
    var pos = 0, result = [], l = string.length;
    while (pos <= l) {
      var nl = string.indexOf("\n", pos);
      if (nl == -1) nl = string.length;
      var line = string.slice(pos, string.charAt(nl - 1) == "\r" ? nl - 1 : nl);
      var rt = line.indexOf("\r");
      if (rt != -1) {
        result.push(line.slice(0, rt));
        pos += rt + 1;
      } else {
        result.push(line);
        pos = nl + 1;
      }
    }
    return result;
  } : function(string){return string.split(/\r\n?|\n/);};
  CodeMirror.splitLines = splitLines;

  var hasSelection = window.getSelection ? function(te) {
    try { return te.selectionStart != te.selectionEnd; }
    catch(e) { return false; }
  } : function(te) {
    try {var range = te.ownerDocument.selection.createRange();}
    catch(e) {}
    if (!range || range.parentElement() != te) return false;
    return range.compareEndPoints("StartToEnd", range) != 0;
  };

  var hasCopyEvent = (function() {
    var e = elt("div");
    if ("oncopy" in e) return true;
    e.setAttribute("oncopy", "return;");
    return typeof e.oncopy == 'function';
  })();

  // KEY NAMING

  var keyNames = {3: "Enter", 8: "Backspace", 9: "Tab", 13: "Enter", 16: "Shift", 17: "Ctrl", 18: "Alt",
                  19: "Pause", 20: "CapsLock", 27: "Esc", 32: "Space", 33: "PageUp", 34: "PageDown", 35: "End",
                  36: "Home", 37: "Left", 38: "Up", 39: "Right", 40: "Down", 44: "PrintScrn", 45: "Insert",
                  46: "Delete", 59: ";", 91: "Mod", 92: "Mod", 93: "Mod", 109: "-", 107: "=", 127: "Delete",
                  186: ";", 187: "=", 188: ",", 189: "-", 190: ".", 191: "/", 192: "`", 219: "[", 220: "\\",
                  221: "]", 222: "'", 63276: "PageUp", 63277: "PageDown", 63275: "End", 63273: "Home",
                  63234: "Left", 63232: "Up", 63235: "Right", 63233: "Down", 63302: "Insert", 63272: "Delete"};
  CodeMirror.keyNames = keyNames;
  (function() {
    // Number keys
    for (var i = 0; i < 10; i++) keyNames[i + 48] = String(i);
    // Alphabetic keys
    for (var i = 65; i <= 90; i++) keyNames[i] = String.fromCharCode(i);
    // Function keys
    for (var i = 1; i <= 12; i++) keyNames[i + 111] = keyNames[i + 63235] = "F" + i;
  })();

  // BIDI HELPERS

  function iterateBidiSections(order, from, to, f) {
    if (!order) return f(from, to, "ltr");
    var found = false;
    for (var i = 0; i < order.length; ++i) {
      var part = order[i];
      if (part.from < to && part.to > from || from == to && part.to == from) {
        f(Math.max(part.from, from), Math.min(part.to, to), part.level == 1 ? "rtl" : "ltr");
        found = true;
      }
    }
    if (!found) f(from, to, "ltr");
  }

  function bidiLeft(part) { return part.level % 2 ? part.to : part.from; }
  function bidiRight(part) { return part.level % 2 ? part.from : part.to; }

  function lineLeft(line) { var order = getOrder(line); return order ? bidiLeft(order[0]) : 0; }
  function lineRight(line) {
    var order = getOrder(line);
    if (!order) return line.text.length;
    return bidiRight(lst(order));
  }

  function lineStart(cm, lineN) {
    var line = getLine(cm.doc, lineN);
    var visual = visualLine(cm.doc, line);
    if (visual != line) lineN = lineNo(visual);
    var order = getOrder(visual);
    var ch = !order ? 0 : order[0].level % 2 ? lineRight(visual) : lineLeft(visual);
    return Pos(lineN, ch);
  }
  function lineEnd(cm, lineN) {
    var merged, line;
    while (merged = collapsedSpanAtEnd(line = getLine(cm.doc, lineN)))
      lineN = merged.find().to.line;
    var order = getOrder(line);
    var ch = !order ? line.text.length : order[0].level % 2 ? lineLeft(line) : lineRight(line);
    return Pos(lineN, ch);
  }

  function compareBidiLevel(order, a, b) {
    var linedir = order[0].level;
    if (a == linedir) return true;
    if (b == linedir) return false;
    return a < b;
  }
  var bidiOther;
  function getBidiPartAt(order, pos) {
    for (var i = 0, found; i < order.length; ++i) {
      var cur = order[i];
      if (cur.from < pos && cur.to > pos) { bidiOther = null; return i; }
      if (cur.from == pos || cur.to == pos) {
        if (found == null) {
          found = i;
        } else if (compareBidiLevel(order, cur.level, order[found].level)) {
          bidiOther = found;
          return i;
        } else {
          bidiOther = i;
          return found;
        }
      }
    }
    bidiOther = null;
    return found;
  }

  function moveInLine(line, pos, dir, byUnit) {
    if (!byUnit) return pos + dir;
    do pos += dir;
    while (pos > 0 && isExtendingChar.test(line.text.charAt(pos)));
    return pos;
  }

  // This is somewhat involved. It is needed in order to move
  // 'visually' through bi-directional text -- i.e., pressing left
  // should make the cursor go left, even when in RTL text. The
  // tricky part is the 'jumps', where RTL and LTR text touch each
  // other. This often requires the cursor offset to move more than
  // one unit, in order to visually move one unit.
  function moveVisually(line, start, dir, byUnit) {
    var bidi = getOrder(line);
    if (!bidi) return moveLogically(line, start, dir, byUnit);
    var pos = getBidiPartAt(bidi, start), part = bidi[pos];
    var target = moveInLine(line, start, part.level % 2 ? -dir : dir, byUnit);

    for (;;) {
      if (target > part.from && target < part.to) return target;
      if (target == part.from || target == part.to) {
        if (getBidiPartAt(bidi, target) == pos) return target;
        part = bidi[pos += dir];
        return (dir > 0) == part.level % 2 ? part.to : part.from;
      } else {
        part = bidi[pos += dir];
        if (!part) return null;
        if ((dir > 0) == part.level % 2)
          target = moveInLine(line, part.to, -1, byUnit);
        else
          target = moveInLine(line, part.from, 1, byUnit);
      }
    }
  }

  function moveLogically(line, start, dir, byUnit) {
    var target = start + dir;
    if (byUnit) while (target > 0 && isExtendingChar.test(line.text.charAt(target))) target += dir;
    return target < 0 || target > line.text.length ? null : target;
  }

  // Bidirectional ordering algorithm
  // See http://unicode.org/reports/tr9/tr9-13.html for the algorithm
  // that this (partially) implements.

  // One-char codes used for character types:
  // L (L):   Left-to-Right
  // R (R):   Right-to-Left
  // r (AL):  Right-to-Left Arabic
  // 1 (EN):  European Number
  // + (ES):  European Number Separator
  // % (ET):  European Number Terminator
  // n (AN):  Arabic Number
  // , (CS):  Common Number Separator
  // m (NSM): Non-Spacing Mark
  // b (BN):  Boundary Neutral
  // s (B):   Paragraph Separator
  // t (S):   Segment Separator
  // w (WS):  Whitespace
  // N (ON):  Other Neutrals

  // Returns null if characters are ordered as they appear
  // (left-to-right), or an array of sections ({from, to, level}
  // objects) in the order in which they occur visually.
  var bidiOrdering = (function() {
    // Character types for codepoints 0 to 0xff
    var lowTypes = "bbbbbbbbbtstwsbbbbbbbbbbbbbbssstwNN%%%NNNNNN,N,N1111111111NNNNNNNLLLLLLLLLLLLLLLLLLLLLLLLLLNNNNNNLLLLLLLLLLLLLLLLLLLLLLLLLLNNNNbbbbbbsbbbbbbbbbbbbbbbbbbbbbbbbbb,N%%%%NNNNLNNNNN%%11NLNNN1LNNNNNLLLLLLLLLLLLLLLLLLLLLLLNLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLNLLLLLLLL";
    // Character types for codepoints 0x600 to 0x6ff
    var arabicTypes = "rrrrrrrrrrrr,rNNmmmmmmrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrmmmmmmmmmmmmmmrrrrrrrnnnnnnnnnn%nnrrrmrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrmmmmmmmmmmmmmmmmmmmNmmmmrrrrrrrrrrrrrrrrrr";
    function charType(code) {
      if (code <= 0xff) return lowTypes.charAt(code);
      else if (0x590 <= code && code <= 0x5f4) return "R";
      else if (0x600 <= code && code <= 0x6ff) return arabicTypes.charAt(code - 0x600);
      else if (0x700 <= code && code <= 0x8ac) return "r";
      else return "L";
    }

    var bidiRE = /[\u0590-\u05f4\u0600-\u06ff\u0700-\u08ac]/;
    var isNeutral = /[stwN]/, isStrong = /[LRr]/, countsAsLeft = /[Lb1n]/, countsAsNum = /[1n]/;
    // Browsers seem to always treat the boundaries of block elements as being L.
    var outerType = "L";

    return function(str) {
      if (!bidiRE.test(str)) return false;
      var len = str.length, types = [];
      for (var i = 0, type; i < len; ++i)
        types.push(type = charType(str.charCodeAt(i)));

      // W1. Examine each non-spacing mark (NSM) in the level run, and
      // change the type of the NSM to the type of the previous
      // character. If the NSM is at the start of the level run, it will
      // get the type of sor.
      for (var i = 0, prev = outerType; i < len; ++i) {
        var type = types[i];
        if (type == "m") types[i] = prev;
        else prev = type;
      }

      // W2. Search backwards from each instance of a European number
      // until the first strong type (R, L, AL, or sor) is found. If an
      // AL is found, change the type of the European number to Arabic
      // number.
      // W3. Change all ALs to R.
      for (var i = 0, cur = outerType; i < len; ++i) {
        var type = types[i];
        if (type == "1" && cur == "r") types[i] = "n";
        else if (isStrong.test(type)) { cur = type; if (type == "r") types[i] = "R"; }
      }

      // W4. A single European separator between two European numbers
      // changes to a European number. A single common separator between
      // two numbers of the same type changes to that type.
      for (var i = 1, prev = types[0]; i < len - 1; ++i) {
        var type = types[i];
        if (type == "+" && prev == "1" && types[i+1] == "1") types[i] = "1";
        else if (type == "," && prev == types[i+1] &&
                 (prev == "1" || prev == "n")) types[i] = prev;
        prev = type;
      }

      // W5. A sequence of European terminators adjacent to European
      // numbers changes to all European numbers.
      // W6. Otherwise, separators and terminators change to Other
      // Neutral.
      for (var i = 0; i < len; ++i) {
        var type = types[i];
        if (type == ",") types[i] = "N";
        else if (type == "%") {
          for (var end = i + 1; end < len && types[end] == "%"; ++end) {}
          var replace = (i && types[i-1] == "!") || (end < len - 1 && types[end] == "1") ? "1" : "N";
          for (var j = i; j < end; ++j) types[j] = replace;
          i = end - 1;
        }
      }

      // W7. Search backwards from each instance of a European number
      // until the first strong type (R, L, or sor) is found. If an L is
      // found, then change the type of the European number to L.
      for (var i = 0, cur = outerType; i < len; ++i) {
        var type = types[i];
        if (cur == "L" && type == "1") types[i] = "L";
        else if (isStrong.test(type)) cur = type;
      }

      // N1. A sequence of neutrals takes the direction of the
      // surrounding strong text if the text on both sides has the same
      // direction. European and Arabic numbers act as if they were R in
      // terms of their influence on neutrals. Start-of-level-run (sor)
      // and end-of-level-run (eor) are used at level run boundaries.
      // N2. Any remaining neutrals take the embedding direction.
      for (var i = 0; i < len; ++i) {
        if (isNeutral.test(types[i])) {
          for (var end = i + 1; end < len && isNeutral.test(types[end]); ++end) {}
          var before = (i ? types[i-1] : outerType) == "L";
          var after = (end < len - 1 ? types[end] : outerType) == "L";
          var replace = before || after ? "L" : "R";
          for (var j = i; j < end; ++j) types[j] = replace;
          i = end - 1;
        }
      }

      // Here we depart from the documented algorithm, in order to avoid
      // building up an actual levels array. Since there are only three
      // levels (0, 1, 2) in an implementation that doesn't take
      // explicit embedding into account, we can build up the order on
      // the fly, without following the level-based algorithm.
      var order = [], m;
      for (var i = 0; i < len;) {
        if (countsAsLeft.test(types[i])) {
          var start = i;
          for (++i; i < len && countsAsLeft.test(types[i]); ++i) {}
          order.push({from: start, to: i, level: 0});
        } else {
          var pos = i, at = order.length;
          for (++i; i < len && types[i] != "L"; ++i) {}
          for (var j = pos; j < i;) {
            if (countsAsNum.test(types[j])) {
              if (pos < j) order.splice(at, 0, {from: pos, to: j, level: 1});
              var nstart = j;
              for (++j; j < i && countsAsNum.test(types[j]); ++j) {}
              order.splice(at, 0, {from: nstart, to: j, level: 2});
              pos = j;
            } else ++j;
          }
          if (pos < i) order.splice(at, 0, {from: pos, to: i, level: 1});
        }
      }
      if (order[0].level == 1 && (m = str.match(/^\s+/))) {
        order[0].from = m[0].length;
        order.unshift({from: 0, to: m[0].length, level: 0});
      }
      if (lst(order).level == 1 && (m = str.match(/\s+$/))) {
        lst(order).to -= m[0].length;
        order.push({from: len - m[0].length, to: len, level: 0});
      }
      if (order[0].level != lst(order).level)
        order.push({from: len, to: len, level: order[0].level});

      return order;
    };
  })();

  // THE END

  CodeMirror.version = "3.15.0";

  return CodeMirror;
})();

// TODO actually recognize syntax of TypeScript constructs

CodeMirror.defineMode("javascript", function(config, parserConfig) {
  var indentUnit = config.indentUnit;
  var statementIndent = parserConfig.statementIndent;
  var jsonMode = parserConfig.json;
  var isTS = parserConfig.typescript;

  // Tokenizer

  var keywords = function(){
    function kw(type) {return {type: type, style: "keyword"};}
    var A = kw("keyword a"), B = kw("keyword b"), C = kw("keyword c");
    var operator = kw("operator"), atom = {type: "atom", style: "atom"};

    var jsKeywords = {
      "if": kw("if"), "while": A, "with": A, "else": B, "do": B, "try": B, "finally": B,
      "return": C, "break": C, "continue": C, "new": C, "delete": C, "throw": C,
      "var": kw("var"), "const": kw("var"), "let": kw("var"),
      "function": kw("function"), "catch": kw("catch"),
      "for": kw("for"), "switch": kw("switch"), "case": kw("case"), "default": kw("default"),
      "in": operator, "typeof": operator, "instanceof": operator,
      "true": atom, "false": atom, "null": atom, "undefined": atom, "NaN": atom, "Infinity": atom,
      "this": kw("this")
    };

    // Extend the 'normal' keywords with the TypeScript language extensions
    if (isTS) {
      var type = {type: "variable", style: "variable-3"};
      var tsKeywords = {
        // object-like things
        "interface": kw("interface"),
        "class": kw("class"),
        "extends": kw("extends"),
        "constructor": kw("constructor"),

        // scope modifiers
        "public": kw("public"),
        "private": kw("private"),
        "protected": kw("protected"),
        "static": kw("static"),

        "super": kw("super"),

        // types
        "string": type, "number": type, "bool": type, "any": type
      };

      for (var attr in tsKeywords) {
        jsKeywords[attr] = tsKeywords[attr];
      }
    }

    return jsKeywords;
  }();

  var isOperatorChar = /[+\-*&%=<>!?|~^]/;

  function chain(stream, state, f) {
    state.tokenize = f;
    return f(stream, state);
  }

  function nextUntilUnescaped(stream, end) {
    var escaped = false, next;
    while ((next = stream.next()) != null) {
      if (next == end && !escaped)
        return false;
      escaped = !escaped && next == "\\";
    }
    return escaped;
  }

  // Used as scratch variables to communicate multiple values without
  // consing up tons of objects.
  var type, content;
  function ret(tp, style, cont) {
    type = tp; content = cont;
    return style;
  }

  function jsTokenBase(stream, state) {
    var ch = stream.next();
    if (ch == '"' || ch == "'")
      return chain(stream, state, jsTokenString(ch));
    else if (/[\[\]{}\(\),;\:\.]/.test(ch))
      return ret(ch);
    else if (ch == "0" && stream.eat(/x/i)) {
      stream.eatWhile(/[\da-f]/i);
      return ret("number", "number");
    }
    else if (/\d/.test(ch) || ch == "-" && stream.eat(/\d/)) {
      stream.match(/^\d*(?:\.\d*)?(?:[eE][+\-]?\d+)?/);
      return ret("number", "number");
    }
    else if (ch == "/") {
      if (stream.eat("*")) {
        return chain(stream, state, jsTokenComment);
      }
      else if (stream.eat("/")) {
        stream.skipToEnd();
        return ret("comment", "comment");
      }
      else if (state.lastType == "operator" || state.lastType == "keyword c" ||
               /^[\[{}\(,;:]$/.test(state.lastType)) {
        nextUntilUnescaped(stream, "/");
        stream.eatWhile(/[gimy]/); // 'y' is "sticky" option in Mozilla
        return ret("regexp", "string-2");
      }
      else {
        stream.eatWhile(isOperatorChar);
        return ret("operator", null, stream.current());
      }
    }
    else if (ch == "#") {
      stream.skipToEnd();
      return ret("error", "error");
    }
    else if (isOperatorChar.test(ch)) {
      stream.eatWhile(isOperatorChar);
      return ret("operator", null, stream.current());
    }
    else {
      stream.eatWhile(/[\w\$_]/);
      var word = stream.current(), known = keywords.propertyIsEnumerable(word) && keywords[word];
      return (known && state.lastType != ".") ? ret(known.type, known.style, word) :
                     ret("variable", "variable", word);
    }
  }

  function jsTokenString(quote) {
    return function(stream, state) {
      if (!nextUntilUnescaped(stream, quote))
        state.tokenize = jsTokenBase;
      return ret("string", "string");
    };
  }

  function jsTokenComment(stream, state) {
    var maybeEnd = false, ch;
    while (ch = stream.next()) {
      if (ch == "/" && maybeEnd) {
        state.tokenize = jsTokenBase;
        break;
      }
      maybeEnd = (ch == "*");
    }
    return ret("comment", "comment");
  }

  // Parser

  var atomicTypes = {"atom": true, "number": true, "variable": true, "string": true, "regexp": true, "this": true};

  function JSLexical(indented, column, type, align, prev, info) {
    this.indented = indented;
    this.column = column;
    this.type = type;
    this.prev = prev;
    this.info = info;
    if (align != null) this.align = align;
  }

  function inScope(state, varname) {
    for (var v = state.localVars; v; v = v.next)
      if (v.name == varname) return true;
  }

  function parseJS(state, style, type, content, stream) {
    var cc = state.cc;
    // Communicate our context to the combinators.
    // (Less wasteful than consing up a hundred closures on every call.)
    cx.state = state; cx.stream = stream; cx.marked = null, cx.cc = cc;

    if (!state.lexical.hasOwnProperty("align"))
      state.lexical.align = true;

    while(true) {
      var combinator = cc.length ? cc.pop() : jsonMode ? expression : statement;
      if (combinator(type, content)) {
        while(cc.length && cc[cc.length - 1].lex)
          cc.pop()();
        if (cx.marked) return cx.marked;
        if (type == "variable" && inScope(state, content)) return "variable-2";
        return style;
      }
    }
  }

  // Combinator utils

  var cx = {state: null, column: null, marked: null, cc: null};
  function pass() {
    for (var i = arguments.length - 1; i >= 0; i--) cx.cc.push(arguments[i]);
  }
  function cont() {
    pass.apply(null, arguments);
    return true;
  }
  function register(varname) {
    function inList(list) {
      for (var v = list; v; v = v.next)
        if (v.name == varname) return true;
      return false;
    }
    var state = cx.state;
    if (state.context) {
      cx.marked = "def";
      if (inList(state.localVars)) return;
      state.localVars = {name: varname, next: state.localVars};
    } else {
      if (inList(state.globalVars)) return;
      state.globalVars = {name: varname, next: state.globalVars};
    }
  }

  // Combinators

  var defaultVars = {name: "this", next: {name: "arguments"}};
  function pushcontext() {
    cx.state.context = {prev: cx.state.context, vars: cx.state.localVars};
    cx.state.localVars = defaultVars;
  }
  function popcontext() {
    cx.state.localVars = cx.state.context.vars;
    cx.state.context = cx.state.context.prev;
  }
  function pushlex(type, info) {
    var result = function() {
      var state = cx.state, indent = state.indented;
      if (state.lexical.type == "stat") indent = state.lexical.indented;
      state.lexical = new JSLexical(indent, cx.stream.column(), type, null, state.lexical, info);
    };
    result.lex = true;
    return result;
  }
  function poplex() {
    var state = cx.state;
    if (state.lexical.prev) {
      if (state.lexical.type == ")")
        state.indented = state.lexical.indented;
      state.lexical = state.lexical.prev;
    }
  }
  poplex.lex = true;

  function expect(wanted) {
    return function(type) {
      if (type == wanted) return cont();
      else if (wanted == ";") return pass();
      else return cont(arguments.callee);
    };
  }

  function statement(type) {
    if (type == "var") return cont(pushlex("vardef"), vardef1, expect(";"), poplex);
    if (type == "keyword a") return cont(pushlex("form"), expression, statement, poplex);
    if (type == "keyword b") return cont(pushlex("form"), statement, poplex);
    if (type == "{") return cont(pushlex("}"), block, poplex);
    if (type == ";") return cont();
    if (type == "if") return cont(pushlex("form"), expression, statement, poplex, maybeelse);
    if (type == "function") return cont(functiondef);
    if (type == "for") return cont(pushlex("form"), expect("("), pushlex(")"), forspec1, expect(")"),
                                   poplex, statement, poplex);
    if (type == "variable") return cont(pushlex("stat"), maybelabel);
    if (type == "switch") return cont(pushlex("form"), expression, pushlex("}", "switch"), expect("{"),
                                      block, poplex, poplex);
    if (type == "case") return cont(expression, expect(":"));
    if (type == "default") return cont(expect(":"));
    if (type == "catch") return cont(pushlex("form"), pushcontext, expect("("), funarg, expect(")"),
                                     statement, poplex, popcontext);
    return pass(pushlex("stat"), expression, expect(";"), poplex);
  }
  function expression(type) {
    return expressionInner(type, false);
  }
  function expressionNoComma(type) {
    return expressionInner(type, true);
  }
  function expressionInner(type, noComma) {
    var maybeop = noComma ? maybeoperatorNoComma : maybeoperatorComma;
    if (atomicTypes.hasOwnProperty(type)) return cont(maybeop);
    if (type == "function") return cont(functiondef);
    if (type == "keyword c") return cont(noComma ? maybeexpressionNoComma : maybeexpression);
    if (type == "(") return cont(pushlex(")"), maybeexpression, expect(")"), poplex, maybeop);
    if (type == "operator") return cont(noComma ? expressionNoComma : expression);
    if (type == "[") return cont(pushlex("]"), commasep(expressionNoComma, "]"), poplex, maybeop);
    if (type == "{") return cont(pushlex("}"), commasep(objprop, "}"), poplex, maybeop);
    return cont();
  }
  function maybeexpression(type) {
    if (type.match(/[;\}\)\],]/)) return pass();
    return pass(expression);
  }
  function maybeexpressionNoComma(type) {
    if (type.match(/[;\}\)\],]/)) return pass();
    return pass(expressionNoComma);
  }

  function maybeoperatorComma(type, value) {
    if (type == ",") return cont(expression);
    return maybeoperatorNoComma(type, value, false);
  }
  function maybeoperatorNoComma(type, value, noComma) {
    var me = noComma == false ? maybeoperatorComma : maybeoperatorNoComma;
    var expr = noComma == false ? expression : expressionNoComma;
    if (type == "operator") {
      if (/\+\+|--/.test(value)) return cont(me);
      if (value == "?") return cont(expression, expect(":"), expr);
      return cont(expr);
    }
    if (type == ";") return;
    if (type == "(") return cont(pushlex(")", "call"), commasep(expressionNoComma, ")"), poplex, me);
    if (type == ".") return cont(property, me);
    if (type == "[") return cont(pushlex("]"), maybeexpression, expect("]"), poplex, me);
  }
  function maybelabel(type) {
    if (type == ":") return cont(poplex, statement);
    return pass(maybeoperatorComma, expect(";"), poplex);
  }
  function property(type) {
    if (type == "variable") {cx.marked = "property"; return cont();}
  }
  function objprop(type, value) {
    if (type == "variable") {
      cx.marked = "property";
      if (value == "get" || value == "set") return cont(getterSetter);
    } else if (type == "number" || type == "string") {
      cx.marked = type + " property";
    }
    if (atomicTypes.hasOwnProperty(type)) return cont(expect(":"), expressionNoComma);
  }
  function getterSetter(type) {
    if (type == ":") return cont(expression);
    if (type != "variable") return cont(expect(":"), expression);
    cx.marked = "property";
    return cont(functiondef);
  }
  function commasep(what, end) {
    function proceed(type) {
      if (type == ",") {
        var lex = cx.state.lexical;
        if (lex.info == "call") lex.pos = (lex.pos || 0) + 1;
        return cont(what, proceed);
      }
      if (type == end) return cont();
      return cont(expect(end));
    }
    return function(type) {
      if (type == end) return cont();
      else return pass(what, proceed);
    };
  }
  function block(type) {
    if (type == "}") return cont();
    return pass(statement, block);
  }
  function maybetype(type) {
    if (type == ":") return cont(typedef);
    return pass();
  }
  function typedef(type) {
    if (type == "variable"){cx.marked = "variable-3"; return cont();}
    return pass();
  }
  function vardef1(type, value) {
    if (type == "variable") {
      register(value);
      return isTS ? cont(maybetype, vardef2) : cont(vardef2);
    }
    return pass();
  }
  function vardef2(type, value) {
    if (value == "=") return cont(expressionNoComma, vardef2);
    if (type == ",") return cont(vardef1);
  }
  function maybeelse(type, value) {
    if (type == "keyword b" && value == "else") return cont(pushlex("form"), statement, poplex);
  }
  function forspec1(type) {
    if (type == "var") return cont(vardef1, expect(";"), forspec2);
    if (type == ";") return cont(forspec2);
    if (type == "variable") return cont(formaybein);
    return pass(expression, expect(";"), forspec2);
  }
  function formaybein(_type, value) {
    if (value == "in") return cont(expression);
    return cont(maybeoperatorComma, forspec2);
  }
  function forspec2(type, value) {
    if (type == ";") return cont(forspec3);
    if (value == "in") return cont(expression);
    return pass(expression, expect(";"), forspec3);
  }
  function forspec3(type) {
    if (type != ")") cont(expression);
  }
  function functiondef(type, value) {
    if (type == "variable") {register(value); return cont(functiondef);}
    if (type == "(") return cont(pushlex(")"), pushcontext, commasep(funarg, ")"), poplex, statement, popcontext);
  }
  function funarg(type, value) {
    if (type == "variable") {register(value); return isTS ? cont(maybetype) : cont();}
  }

  // Interface

  return {
    startState: function(basecolumn) {
      return {
        tokenize: jsTokenBase,
        lastType: null,
        cc: [],
        lexical: new JSLexical((basecolumn || 0) - indentUnit, 0, "block", false),
        localVars: parserConfig.localVars,
        globalVars: parserConfig.globalVars,
        context: parserConfig.localVars && {vars: parserConfig.localVars},
        indented: 0
      };
    },

    token: function(stream, state) {
      if (stream.sol()) {
        if (!state.lexical.hasOwnProperty("align"))
          state.lexical.align = false;
        state.indented = stream.indentation();
      }
      if (state.tokenize != jsTokenComment && stream.eatSpace()) return null;
      var style = state.tokenize(stream, state);
      if (type == "comment") return style;
      state.lastType = type == "operator" && (content == "++" || content == "--") ? "incdec" : type;
      return parseJS(state, style, type, content, stream);
    },

    indent: function(state, textAfter) {
      if (state.tokenize == jsTokenComment) return CodeMirror.Pass;
      if (state.tokenize != jsTokenBase) return 0;
      var firstChar = textAfter && textAfter.charAt(0), lexical = state.lexical;
      // Kludge to prevent 'maybelse' from blocking lexical scope pops
      for (var i = state.cc.length - 1; i >= 0; --i) {
        var c = state.cc[i];
        if (c == poplex) lexical = lexical.prev;
        else if (c != maybeelse || /^else\b/.test(textAfter)) break;
      }
      if (lexical.type == "stat" && firstChar == "}") lexical = lexical.prev;
      if (statementIndent && lexical.type == ")" && lexical.prev.type == "stat")
        lexical = lexical.prev;
      var type = lexical.type, closing = firstChar == type;

      if (type == "vardef") return lexical.indented + (state.lastType == "operator" || state.lastType == "," ? 4 : 0);
      else if (type == "form" && firstChar == "{") return lexical.indented;
      else if (type == "form") return lexical.indented + indentUnit;
      else if (type == "stat")
        return lexical.indented + (state.lastType == "operator" || state.lastType == "," ? statementIndent || indentUnit : 0);
      else if (lexical.info == "switch" && !closing && parserConfig.doubleIndentSwitch != false)
        return lexical.indented + (/^(?:case|default)\b/.test(textAfter) ? indentUnit : 2 * indentUnit);
      else if (lexical.align) return lexical.column + (closing ? 0 : 1);
      else return lexical.indented + (closing ? 0 : indentUnit);
    },

    electricChars: ":{}",
    blockCommentStart: jsonMode ? null : "/*",
    blockCommentEnd: jsonMode ? null : "*/",
    lineComment: jsonMode ? null : "//",
    fold: "brace",

    helperType: jsonMode ? "json" : "javascript",
    jsonMode: jsonMode
  };
});

CodeMirror.defineMIME("text/javascript", "javascript");
CodeMirror.defineMIME("text/ecmascript", "javascript");
CodeMirror.defineMIME("application/javascript", "javascript");
CodeMirror.defineMIME("application/ecmascript", "javascript");
CodeMirror.defineMIME("application/json", {name: "javascript", json: true});
CodeMirror.defineMIME("application/x-json", {name: "javascript", json: true});
CodeMirror.defineMIME("text/typescript", { name: "javascript", typescript: true });
CodeMirror.defineMIME("application/typescript", { name: "javascript", typescript: true });

CodeMirror.defineMode("xml", function(config, parserConfig) {
  var indentUnit = config.indentUnit;
  var multilineTagIndentFactor = parserConfig.multilineTagIndentFactor || 1;
  var multilineTagIndentPastTag = parserConfig.multilineTagIndentPastTag || true;

  var Kludges = parserConfig.htmlMode ? {
    autoSelfClosers: {'area': true, 'base': true, 'br': true, 'col': true, 'command': true,
                      'embed': true, 'frame': true, 'hr': true, 'img': true, 'input': true,
                      'keygen': true, 'link': true, 'meta': true, 'param': true, 'source': true,
                      'track': true, 'wbr': true},
    implicitlyClosed: {'dd': true, 'li': true, 'optgroup': true, 'option': true, 'p': true,
                       'rp': true, 'rt': true, 'tbody': true, 'td': true, 'tfoot': true,
                       'th': true, 'tr': true},
    contextGrabbers: {
      'dd': {'dd': true, 'dt': true},
      'dt': {'dd': true, 'dt': true},
      'li': {'li': true},
      'option': {'option': true, 'optgroup': true},
      'optgroup': {'optgroup': true},
      'p': {'address': true, 'article': true, 'aside': true, 'blockquote': true, 'dir': true,
            'div': true, 'dl': true, 'fieldset': true, 'footer': true, 'form': true,
            'h1': true, 'h2': true, 'h3': true, 'h4': true, 'h5': true, 'h6': true,
            'header': true, 'hgroup': true, 'hr': true, 'menu': true, 'nav': true, 'ol': true,
            'p': true, 'pre': true, 'section': true, 'table': true, 'ul': true},
      'rp': {'rp': true, 'rt': true},
      'rt': {'rp': true, 'rt': true},
      'tbody': {'tbody': true, 'tfoot': true},
      'td': {'td': true, 'th': true},
      'tfoot': {'tbody': true},
      'th': {'td': true, 'th': true},
      'thead': {'tbody': true, 'tfoot': true},
      'tr': {'tr': true}
    },
    doNotIndent: {"pre": true},
    allowUnquoted: true,
    allowMissing: true
  } : {
    autoSelfClosers: {},
    implicitlyClosed: {},
    contextGrabbers: {},
    doNotIndent: {},
    allowUnquoted: false,
    allowMissing: false
  };
  var alignCDATA = parserConfig.alignCDATA;

  // Return variables for tokenizers
  var tagName, type;

  function inText(stream, state) {
    function chain(parser) {
      state.tokenize = parser;
      return parser(stream, state);
    }

    var ch = stream.next();
    if (ch == "<") {
      if (stream.eat("!")) {
        if (stream.eat("[")) {
          if (stream.match("CDATA[")) return chain(inBlock("atom", "]]>"));
          else return null;
        } else if (stream.match("--")) {
          return chain(inBlock("comment", "-->"));
        } else if (stream.match("DOCTYPE", true, true)) {
          stream.eatWhile(/[\w\._\-]/);
          return chain(doctype(1));
        } else {
          return null;
        }
      } else if (stream.eat("?")) {
        stream.eatWhile(/[\w\._\-]/);
        state.tokenize = inBlock("meta", "?>");
        return "meta";
      } else {
        var isClose = stream.eat("/");
        tagName = "";
        var c;
        while ((c = stream.eat(/[^\s\u00a0=<>\"\'\/?]/))) tagName += c;
        if (!tagName) return "error";
        type = isClose ? "closeTag" : "openTag";
        state.tokenize = inTag;
        return "tag";
      }
    } else if (ch == "&") {
      var ok;
      if (stream.eat("#")) {
        if (stream.eat("x")) {
          ok = stream.eatWhile(/[a-fA-F\d]/) && stream.eat(";");
        } else {
          ok = stream.eatWhile(/[\d]/) && stream.eat(";");
        }
      } else {
        ok = stream.eatWhile(/[\w\.\-:]/) && stream.eat(";");
      }
      return ok ? "atom" : "error";
    } else {
      stream.eatWhile(/[^&<]/);
      return null;
    }
  }

  function inTag(stream, state) {
    var ch = stream.next();
    if (ch == ">" || (ch == "/" && stream.eat(">"))) {
      state.tokenize = inText;
      type = ch == ">" ? "endTag" : "selfcloseTag";
      return "tag";
    } else if (ch == "=") {
      type = "equals";
      return null;
    } else if (ch == "<") {
      return "error";
    } else if (/[\'\"]/.test(ch)) {
      state.tokenize = inAttribute(ch);
      state.stringStartCol = stream.column();
      return state.tokenize(stream, state);
    } else {
      stream.eatWhile(/[^\s\u00a0=<>\"\']/);
      return "word";
    }
  }

  function inAttribute(quote) {
    var closure = function(stream, state) {
      while (!stream.eol()) {
        if (stream.next() == quote) {
          state.tokenize = inTag;
          break;
        }
      }
      return "string";
    };
    closure.isInAttribute = true;
    return closure;
  }

  function inBlock(style, terminator) {
    return function(stream, state) {
      while (!stream.eol()) {
        if (stream.match(terminator)) {
          state.tokenize = inText;
          break;
        }
        stream.next();
      }
      return style;
    };
  }
  function doctype(depth) {
    return function(stream, state) {
      var ch;
      while ((ch = stream.next()) != null) {
        if (ch == "<") {
          state.tokenize = doctype(depth + 1);
          return state.tokenize(stream, state);
        } else if (ch == ">") {
          if (depth == 1) {
            state.tokenize = inText;
            break;
          } else {
            state.tokenize = doctype(depth - 1);
            return state.tokenize(stream, state);
          }
        }
      }
      return "meta";
    };
  }

  var curState, curStream, setStyle;
  function pass() {
    for (var i = arguments.length - 1; i >= 0; i--) curState.cc.push(arguments[i]);
  }
  function cont() {
    pass.apply(null, arguments);
    return true;
  }

  function pushContext(tagName, startOfLine) {
    var noIndent = Kludges.doNotIndent.hasOwnProperty(tagName) || (curState.context && curState.context.noIndent);
    curState.context = {
      prev: curState.context,
      tagName: tagName,
      indent: curState.indented,
      startOfLine: startOfLine,
      noIndent: noIndent
    };
  }
  function popContext() {
    if (curState.context) curState.context = curState.context.prev;
  }

  function element(type) {
    if (type == "openTag") {
      curState.tagName = tagName;
      curState.tagStart = curStream.column();
      return cont(attributes, endtag(curState.startOfLine));
    } else if (type == "closeTag") {
      var err = false;
      if (curState.context) {
        if (curState.context.tagName != tagName) {
          if (Kludges.implicitlyClosed.hasOwnProperty(curState.context.tagName.toLowerCase())) {
            popContext();
          }
          err = !curState.context || curState.context.tagName != tagName;
        }
      } else {
        err = true;
      }
      if (err) setStyle = "error";
      return cont(endclosetag(err));
    }
    return cont();
  }
  function endtag(startOfLine) {
    return function(type) {
      var tagName = curState.tagName;
      curState.tagName = curState.tagStart = null;
      if (type == "selfcloseTag" ||
          (type == "endTag" && Kludges.autoSelfClosers.hasOwnProperty(tagName.toLowerCase()))) {
        maybePopContext(tagName.toLowerCase());
        return cont();
      }
      if (type == "endTag") {
        maybePopContext(tagName.toLowerCase());
        pushContext(tagName, startOfLine);
        return cont();
      }
      return cont();
    };
  }
  function endclosetag(err) {
    return function(type) {
      if (err) setStyle = "error";
      if (type == "endTag") { popContext(); return cont(); }
      setStyle = "error";
      return cont(arguments.callee);
    };
  }
  function maybePopContext(nextTagName) {
    var parentTagName;
    while (true) {
      if (!curState.context) {
        return;
      }
      parentTagName = curState.context.tagName.toLowerCase();
      if (!Kludges.contextGrabbers.hasOwnProperty(parentTagName) ||
          !Kludges.contextGrabbers[parentTagName].hasOwnProperty(nextTagName)) {
        return;
      }
      popContext();
    }
  }

  function attributes(type) {
    if (type == "word") {setStyle = "attribute"; return cont(attribute, attributes);}
    if (type == "endTag" || type == "selfcloseTag") return pass();
    setStyle = "error";
    return cont(attributes);
  }
  function attribute(type) {
    if (type == "equals") return cont(attvalue, attributes);
    if (!Kludges.allowMissing) setStyle = "error";
    else if (type == "word") setStyle = "attribute";
    return (type == "endTag" || type == "selfcloseTag") ? pass() : cont();
  }
  function attvalue(type) {
    if (type == "string") return cont(attvaluemaybe);
    if (type == "word" && Kludges.allowUnquoted) {setStyle = "string"; return cont();}
    setStyle = "error";
    return (type == "endTag" || type == "selfCloseTag") ? pass() : cont();
  }
  function attvaluemaybe(type) {
    if (type == "string") return cont(attvaluemaybe);
    else return pass();
  }

  return {
    startState: function() {
      return {tokenize: inText, cc: [], indented: 0, startOfLine: true, tagName: null, tagStart: null, context: null};
    },

    token: function(stream, state) {
      if (!state.tagName && stream.sol()) {
        state.startOfLine = true;
        state.indented = stream.indentation();
      }
      if (stream.eatSpace()) return null;

      setStyle = type = tagName = null;
      var style = state.tokenize(stream, state);
      state.type = type;
      if ((style || type) && style != "comment") {
        curState = state; curStream = stream;
        while (true) {
          var comb = state.cc.pop() || element;
          if (comb(type || style)) break;
        }
      }
      state.startOfLine = false;
      return setStyle || style;
    },

    indent: function(state, textAfter, fullLine) {
      var context = state.context;
      // Indent multi-line strings (e.g. css).
      if (state.tokenize.isInAttribute) {
        return state.stringStartCol + 1;
      }
      if ((state.tokenize != inTag && state.tokenize != inText) ||
          context && context.noIndent)
        return fullLine ? fullLine.match(/^(\s*)/)[0].length : 0;
      // Indent the starts of attribute names.
      if (state.tagName) {
        if (multilineTagIndentPastTag)
          return state.tagStart + state.tagName.length + 2;
        else
          return state.tagStart + indentUnit * multilineTagIndentFactor;
      }
      if (alignCDATA && /<!\[CDATA\[/.test(textAfter)) return 0;
      if (context && /^<\//.test(textAfter))
        context = context.prev;
      while (context && !context.startOfLine)
        context = context.prev;
      if (context) return context.indent + indentUnit;
      else return 0;
    },

    electricChars: "/",
    blockCommentStart: "<!--",
    blockCommentEnd: "-->",

    configuration: parserConfig.htmlMode ? "html" : "xml",
    helperType: parserConfig.htmlMode ? "html" : "xml"
  };
});

CodeMirror.defineMIME("text/xml", "xml");
CodeMirror.defineMIME("application/xml", "xml");
if (!CodeMirror.mimeModes.hasOwnProperty("text/html"))
  CodeMirror.defineMIME("text/html", {name: "xml", htmlMode: true});

CodeMirror.defineMode("yaml", function() {

  var cons = ['true', 'false', 'on', 'off', 'yes', 'no'];
  var keywordRegex = new RegExp("\\b(("+cons.join(")|(")+"))$", 'i');

  return {
    token: function(stream, state) {
      var ch = stream.peek();
      var esc = state.escaped;
      state.escaped = false;
      /* comments */
      if (ch == "#" && (stream.pos == 0 || /\s/.test(stream.string.charAt(stream.pos - 1)))) {
        stream.skipToEnd(); return "comment";
      }
      if (state.literal && stream.indentation() > state.keyCol) {
        stream.skipToEnd(); return "string";
      } else if (state.literal) { state.literal = false; }
      if (stream.sol()) {
        state.keyCol = 0;
        state.pair = false;
        state.pairStart = false;
        /* document start */
        if(stream.match(/---/)) { return "def"; }
        /* document end */
        if (stream.match(/\.\.\./)) { return "def"; }
        /* array list item */
        if (stream.match(/\s*-\s+/)) { return 'meta'; }
      }
      /* pairs (associative arrays) -> key */
      if (!state.pair && stream.match(/^\s*([a-z0-9\._-])+(?=\s*:)/i)) {
        state.pair = true;
        state.keyCol = stream.indentation();
        return "atom";
      }
      if (state.pair && stream.match(/^:\s*/)) { state.pairStart = true; return 'meta'; }

      /* inline pairs/lists */
      if (stream.match(/^(\{|\}|\[|\])/)) {
        if (ch == '{')
          state.inlinePairs++;
        else if (ch == '}')
          state.inlinePairs--;
        else if (ch == '[')
          state.inlineList++;
        else
          state.inlineList--;
        return 'meta';
      }

      /* list seperator */
      if (state.inlineList > 0 && !esc && ch == ',') {
        stream.next();
        return 'meta';
      }
      /* pairs seperator */
      if (state.inlinePairs > 0 && !esc && ch == ',') {
        state.keyCol = 0;
        state.pair = false;
        state.pairStart = false;
        stream.next();
        return 'meta';
      }

      /* start of value of a pair */
      if (state.pairStart) {
        /* block literals */
        if (stream.match(/^\s*(\||\>)\s*/)) { state.literal = true; return 'meta'; };
        /* references */
        if (stream.match(/^\s*(\&|\*)[a-z0-9\._-]+\b/i)) { return 'variable-2'; }
        /* numbers */
        if (state.inlinePairs == 0 && stream.match(/^\s*-?[0-9\.\,]+\s?$/)) { return 'number'; }
        if (state.inlinePairs > 0 && stream.match(/^\s*-?[0-9\.\,]+\s?(?=(,|}))/)) { return 'number'; }
        /* keywords */
        if (stream.match(keywordRegex)) { return 'keyword'; }
      }

      /* nothing found, continue */
      state.pairStart = false;
      state.escaped = (ch == '\\');
      stream.next();
      return null;
    },
    startState: function() {
      return {
        pair: false,
        pairStart: false,
        keyCol: 0,
        inlinePairs: 0,
        inlineList: 0,
        literal: false,
        escaped: false
      };
    }
  };
});

CodeMirror.defineMIME("text/x-yaml", "yaml");

// Open simple dialogs on top of an editor. Relies on dialog.css.

(function() {
  function dialogDiv(cm, template, bottom) {
    var wrap = cm.getWrapperElement();
    var dialog;
    dialog = wrap.appendChild(document.createElement("div"));
    if (bottom) {
      dialog.className = "CodeMirror-dialog CodeMirror-dialog-bottom";
    } else {
      dialog.className = "CodeMirror-dialog CodeMirror-dialog-top";
    }
    dialog.innerHTML = template;
    return dialog;
  }

  CodeMirror.defineExtension("openDialog", function(template, callback, options) {
    var dialog = dialogDiv(this, template, options && options.bottom);
    var closed = false, me = this;
    function close() {
      if (closed) return;
      closed = true;
      dialog.parentNode.removeChild(dialog);
    }
    var inp = dialog.getElementsByTagName("input")[0], button;
    if (inp) {
      CodeMirror.on(inp, "keydown", function(e) {
        if (options && options.onKeyDown && options.onKeyDown(e, inp.value, close)) { return; }
        if (e.keyCode == 13 || e.keyCode == 27) {
          CodeMirror.e_stop(e);
          close();
          me.focus();
          if (e.keyCode == 13) callback(inp.value);
        }
      });
      if (options && options.onKeyUp) {
        CodeMirror.on(inp, "keyup", function(e) {options.onKeyUp(e, inp.value, close);});
      }
      if (options && options.value) inp.value = options.value;
      inp.focus();
      CodeMirror.on(inp, "blur", close);
    } else if (button = dialog.getElementsByTagName("button")[0]) {
      CodeMirror.on(button, "click", function() {
        close();
        me.focus();
      });
      button.focus();
      CodeMirror.on(button, "blur", close);
    }
    return close;
  });

  CodeMirror.defineExtension("openConfirm", function(template, callbacks, options) {
    var dialog = dialogDiv(this, template, options && options.bottom);
    var buttons = dialog.getElementsByTagName("button");
    var closed = false, me = this, blurring = 1;
    function close() {
      if (closed) return;
      closed = true;
      dialog.parentNode.removeChild(dialog);
      me.focus();
    }
    buttons[0].focus();
    for (var i = 0; i < buttons.length; ++i) {
      var b = buttons[i];
      (function(callback) {
        CodeMirror.on(b, "click", function(e) {
          CodeMirror.e_preventDefault(e);
          close();
          if (callback) callback(me);
        });
      })(callbacks[i]);
      CodeMirror.on(b, "blur", function() {
        --blurring;
        setTimeout(function() { if (blurring <= 0) close(); }, 200);
      });
      CodeMirror.on(b, "focus", function() { ++blurring; });
    }
  });
})();

// Define search commands. Depends on dialog.js or another
// implementation of the openDialog method.

// Replace works a little oddly -- it will do the replace on the next
// Ctrl-G (or whatever is bound to findNext) press. You prevent a
// replace by making sure the match is no longer selected when hitting
// Ctrl-G.

(function() {
  function searchOverlay(query) {
    if (typeof query == "string") return {token: function(stream) {
      if (stream.match(query)) return "searching";
      stream.next();
      stream.skipTo(query.charAt(0)) || stream.skipToEnd();
    }};
    return {token: function(stream) {
      if (stream.match(query)) return "searching";
      while (!stream.eol()) {
        stream.next();
        if (stream.match(query, false)) break;
      }
    }};
  }

  function SearchState() {
    this.posFrom = this.posTo = this.query = null;
    this.overlay = null;
  }
  function getSearchState(cm) {
    return cm.state.search || (cm.state.search = new SearchState());
  }
  function getSearchCursor(cm, query, pos) {
    // Heuristic: if the query string is all lowercase, do a case insensitive search.
    return cm.getSearchCursor(query, pos, typeof query == "string" && query == query.toLowerCase());
  }
  function dialog(cm, text, shortText, f) {
    if (cm.openDialog) cm.openDialog(text, f);
    else f(prompt(shortText, ""));
  }
  function confirmDialog(cm, text, shortText, fs) {
    if (cm.openConfirm) cm.openConfirm(text, fs);
    else if (confirm(shortText)) fs[0]();
  }
  function parseQuery(query) {
    var isRE = query.match(/^\/(.*)\/([a-z]*)$/);
    return isRE ? new RegExp(isRE[1], isRE[2].indexOf("i") == -1 ? "" : "i") : query;
  }
  var queryDialog =
    'Search: <input type="text" style="width: 10em"/> <span style="color: #888">(Use /re/ syntax for regexp search)</span>';
  function doSearch(cm, rev) {
    var state = getSearchState(cm);
    if (state.query) return findNext(cm, rev);
    dialog(cm, queryDialog, "Search for:", function(query) {
      cm.operation(function() {
        if (!query || state.query) return;
        state.query = parseQuery(query);
        cm.removeOverlay(state.overlay);
        state.overlay = searchOverlay(state.query);
        cm.addOverlay(state.overlay);
        state.posFrom = state.posTo = cm.getCursor();
        findNext(cm, rev);
      });
    });
  }
  function findNext(cm, rev) {cm.operation(function() {
    var state = getSearchState(cm);
    var cursor = getSearchCursor(cm, state.query, rev ? state.posFrom : state.posTo);
    if (!cursor.find(rev)) {
      cursor = getSearchCursor(cm, state.query, rev ? CodeMirror.Pos(cm.lastLine()) : CodeMirror.Pos(cm.firstLine(), 0));
      if (!cursor.find(rev)) return;
    }
    cm.setSelection(cursor.from(), cursor.to());
    state.posFrom = cursor.from(); state.posTo = cursor.to();
  });}
  function clearSearch(cm) {cm.operation(function() {
    var state = getSearchState(cm);
    if (!state.query) return;
    state.query = null;
    cm.removeOverlay(state.overlay);
  });}

  var replaceQueryDialog =
    'Replace: <input type="text" style="width: 10em"/> <span style="color: #888">(Use /re/ syntax for regexp search)</span>';
  var replacementQueryDialog = 'With: <input type="text" style="width: 10em"/>';
  var doReplaceConfirm = "Replace? <button>Yes</button> <button>No</button> <button>Stop</button>";
  function replace(cm, all) {
    dialog(cm, replaceQueryDialog, "Replace:", function(query) {
      if (!query) return;
      query = parseQuery(query);
      dialog(cm, replacementQueryDialog, "Replace with:", function(text) {
        if (all) {
          cm.operation(function() {
            for (var cursor = getSearchCursor(cm, query); cursor.findNext();) {
              if (typeof query != "string") {
                var match = cm.getRange(cursor.from(), cursor.to()).match(query);
                cursor.replace(text.replace(/\$(\d)/, function(_, i) {return match[i];}));
              } else cursor.replace(text);
            }
          });
        } else {
          clearSearch(cm);
          var cursor = getSearchCursor(cm, query, cm.getCursor());
          var advance = function() {
            var start = cursor.from(), match;
            if (!(match = cursor.findNext())) {
              cursor = getSearchCursor(cm, query);
              if (!(match = cursor.findNext()) ||
                  (start && cursor.from().line == start.line && cursor.from().ch == start.ch)) return;
            }
            cm.setSelection(cursor.from(), cursor.to());
            confirmDialog(cm, doReplaceConfirm, "Replace?",
                          [function() {doReplace(match);}, advance]);
          };
          var doReplace = function(match) {
            cursor.replace(typeof query == "string" ? text :
                           text.replace(/\$(\d)/, function(_, i) {return match[i];}));
            advance();
          };
          advance();
        }
      });
    });
  }

  CodeMirror.commands.find = function(cm) {clearSearch(cm); doSearch(cm);};
  CodeMirror.commands.findNext = doSearch;
  CodeMirror.commands.findPrev = function(cm) {doSearch(cm, true);};
  CodeMirror.commands.clearSearch = clearSearch;
  CodeMirror.commands.replace = replace;
  CodeMirror.commands.replaceAll = function(cm) {replace(cm, true);};
})();

(function(){
  var Pos = CodeMirror.Pos;

  function SearchCursor(doc, query, pos, caseFold) {
    this.atOccurrence = false; this.doc = doc;
    if (caseFold == null && typeof query == "string") caseFold = false;

    pos = pos ? doc.clipPos(pos) : Pos(0, 0);
    this.pos = {from: pos, to: pos};

    // The matches method is filled in based on the type of query.
    // It takes a position and a direction, and returns an object
    // describing the next occurrence of the query, or null if no
    // more matches were found.
    if (typeof query != "string") { // Regexp match
      if (!query.global) query = new RegExp(query.source, query.ignoreCase ? "ig" : "g");
      this.matches = function(reverse, pos) {
        if (reverse) {
          query.lastIndex = 0;
          var line = doc.getLine(pos.line).slice(0, pos.ch), cutOff = 0, match, start;
          for (;;) {
            query.lastIndex = cutOff;
            var newMatch = query.exec(line);
            if (!newMatch) break;
            match = newMatch;
            start = match.index;
            cutOff = match.index + (match[0].length || 1);
            if (cutOff == line.length) break;
          }
          var matchLen = (match && match[0].length) || 0;
          if (!matchLen) {
            if (start == 0 && line.length == 0) {match = undefined;}
            else if (start != doc.getLine(pos.line).length) {
              matchLen++;
            }
          }
        } else {
          query.lastIndex = pos.ch;
          var line = doc.getLine(pos.line), match = query.exec(line);
          var matchLen = (match && match[0].length) || 0;
          var start = match && match.index;
          if (start + matchLen != line.length && !matchLen) matchLen = 1;
        }
        if (match && matchLen)
          return {from: Pos(pos.line, start),
                  to: Pos(pos.line, start + matchLen),
                  match: match};
      };
    } else { // String query
      if (caseFold) query = query.toLowerCase();
      var fold = caseFold ? function(str){return str.toLowerCase();} : function(str){return str;};
      var target = query.split("\n");
      // Different methods for single-line and multi-line queries
      if (target.length == 1) {
        if (!query.length) {
          // Empty string would match anything and never progress, so
          // we define it to match nothing instead.
          this.matches = function() {};
        } else {
          this.matches = function(reverse, pos) {
            var line = fold(doc.getLine(pos.line)), len = query.length, match;
            if (reverse ? (pos.ch >= len && (match = line.lastIndexOf(query, pos.ch - len)) != -1)
                        : (match = line.indexOf(query, pos.ch)) != -1)
              return {from: Pos(pos.line, match),
                      to: Pos(pos.line, match + len)};
          };
        }
      } else {
        this.matches = function(reverse, pos) {
          var ln = pos.line, idx = (reverse ? target.length - 1 : 0), match = target[idx], line = fold(doc.getLine(ln));
          var offsetA = (reverse ? line.indexOf(match) + match.length : line.lastIndexOf(match));
          if (reverse ? offsetA >= pos.ch || offsetA != match.length
              : offsetA <= pos.ch || offsetA != line.length - match.length)
            return;
          for (;;) {
            if (reverse ? !ln : ln == doc.lineCount() - 1) return;
            line = fold(doc.getLine(ln += reverse ? -1 : 1));
            match = target[reverse ? --idx : ++idx];
            if (idx > 0 && idx < target.length - 1) {
              if (line != match) return;
              else continue;
            }
            var offsetB = (reverse ? line.lastIndexOf(match) : line.indexOf(match) + match.length);
            if (reverse ? offsetB != line.length - match.length : offsetB != match.length)
              return;
            var start = Pos(pos.line, offsetA), end = Pos(ln, offsetB);
            return {from: reverse ? end : start, to: reverse ? start : end};
          }
        };
      }
    }
  }

  SearchCursor.prototype = {
    findNext: function() {return this.find(false);},
    findPrevious: function() {return this.find(true);},

    find: function(reverse) {
      var self = this, pos = this.doc.clipPos(reverse ? this.pos.from : this.pos.to);
      function savePosAndFail(line) {
        var pos = Pos(line, 0);
        self.pos = {from: pos, to: pos};
        self.atOccurrence = false;
        return false;
      }

      for (;;) {
        if (this.pos = this.matches(reverse, pos)) {
          if (!this.pos.from || !this.pos.to) { console.log(this.matches, this.pos); }
          this.atOccurrence = true;
          return this.pos.match || true;
        }
        if (reverse) {
          if (!pos.line) return savePosAndFail(0);
          pos = Pos(pos.line-1, this.doc.getLine(pos.line-1).length);
        }
        else {
          var maxLine = this.doc.lineCount();
          if (pos.line == maxLine - 1) return savePosAndFail(maxLine);
          pos = Pos(pos.line + 1, 0);
        }
      }
    },

    from: function() {if (this.atOccurrence) return this.pos.from;},
    to: function() {if (this.atOccurrence) return this.pos.to;},

    replace: function(newText) {
      if (!this.atOccurrence) return;
      var lines = CodeMirror.splitLines(newText);
      this.doc.replaceRange(lines, this.pos.from, this.pos.to);
      this.pos.to = Pos(this.pos.from.line + lines.length - 1,
                        lines[lines.length - 1].length + (lines.length == 1 ? this.pos.from.ch : 0));
    }
  };

  CodeMirror.defineExtension("getSearchCursor", function(query, pos, caseFold) {
    return new SearchCursor(this.doc, query, pos, caseFold);
  });
  CodeMirror.defineDocExtension("getSearchCursor", function(query, pos, caseFold) {
    return new SearchCursor(this, query, pos, caseFold);
  });
})();

(function() {
  "use strict";
  var GUTTER_ID = "CodeMirror-lint-markers";
  var SEVERITIES = /^(?:error|warning)$/;

  function showTooltip(e, content) {
    var tt = document.createElement("div");
    tt.className = "CodeMirror-lint-tooltip";
    tt.appendChild(content.cloneNode(true));
    document.body.appendChild(tt);

    function position(e) {
      if (!tt.parentNode) return CodeMirror.off(document, "mousemove", position);
      tt.style.top = Math.max(0, e.clientY - tt.offsetHeight - 5) + "px";
      tt.style.left = (e.clientX + 5) + "px";
    }
    CodeMirror.on(document, "mousemove", position);
    position(e);
    if (tt.style.opacity != null) tt.style.opacity = 1;
    return tt;
  }
  function rm(elt) {
    if (elt.parentNode) elt.parentNode.removeChild(elt);
  }
  function hideTooltip(tt) {
    if (!tt.parentNode) return;
    if (tt.style.opacity == null) rm(tt);
    tt.style.opacity = 0;
    setTimeout(function() { rm(tt); }, 600);
  }

  function showTooltipFor(e, content, node) {
    var tooltip = showTooltip(e, content);
    function hide() {
      CodeMirror.off(node, "mouseout", hide);
      if (tooltip) { hideTooltip(tooltip); tooltip = null; }
    }
    var poll = setInterval(function() {
      if (tooltip) for (var n = node;; n = n.parentNode) {
        if (n == document.body) return;
        if (!n) { hide(); break; }
      }
      if (!tooltip) return clearInterval(poll);
    }, 400);
    CodeMirror.on(node, "mouseout", hide);
  }

  function LintState(cm, options, hasGutter) {
    this.marked = [];
    this.options = options;
    this.timeout = null;
    this.hasGutter = hasGutter;
    this.onMouseOver = function(e) { onMouseOver(cm, e); };
  }

  function parseOptions(cm, options) {
    if (options instanceof Function) return {getAnnotations: options};
    if (!options || options === true) options = {};
    if (!options.getAnnotations) options.getAnnotations = cm.getHelper(CodeMirror.Pos(0, 0), "lint");
    if (!options.getAnnotations) throw new Error("Required option 'getAnnotations' missing (lint addon)");
    return options;
  }

  function clearMarks(cm) {
    var state = cm.state.lint;
    if (state.hasGutter) cm.clearGutter(GUTTER_ID);
    for (var i = 0; i < state.marked.length; ++i)
      state.marked[i].clear();
    state.marked.length = 0;
  }

  function makeMarker(labels, severity, multiple, tooltips) {
    var marker = document.createElement("div"), inner = marker;
    marker.className = "CodeMirror-lint-marker-" + severity;
    if (multiple) {
      inner = marker.appendChild(document.createElement("div"));
      inner.className = "CodeMirror-lint-marker-multiple";
    }

    if (tooltips != false) CodeMirror.on(inner, "mouseover", function(e) {
      showTooltipFor(e, labels, inner);
    });

    return marker;
  }

  function getMaxSeverity(a, b) {
    if (a == "error") return a;
    else return b;
  }

  function groupByLine(annotations) {
    var lines = [];
    for (var i = 0; i < annotations.length; ++i) {
      var ann = annotations[i], line = ann.from.line;
      (lines[line] || (lines[line] = [])).push(ann);
    }
    return lines;
  }

  function annotationTooltip(ann) {
    var severity = ann.severity;
    if (!SEVERITIES.test(severity)) severity = "error";
    var tip = document.createElement("div");
    tip.className = "CodeMirror-lint-message-" + severity;
    tip.appendChild(document.createTextNode(ann.message));
    return tip;
  }

  function startLinting(cm) {
    var state = cm.state.lint, options = state.options;
    if (options.async)
      options.getAnnotations(cm, updateLinting, options);
    else
      updateLinting(cm, options.getAnnotations(cm.getValue()));
  }

  function updateLinting(cm, annotationsNotSorted) {
    clearMarks(cm);
    var state = cm.state.lint, options = state.options;

    var annotations = groupByLine(annotationsNotSorted);

    for (var line = 0; line < annotations.length; ++line) {
      var anns = annotations[line];
      if (!anns) continue;

      var maxSeverity = null;
      var tipLabel = state.hasGutter && document.createDocumentFragment();

      for (var i = 0; i < anns.length; ++i) {
        var ann = anns[i];
        var severity = ann.severity;
        if (!SEVERITIES.test(severity)) severity = "error";
        maxSeverity = getMaxSeverity(maxSeverity, severity);

        if (options.formatAnnotation) ann = options.formatAnnotation(ann);
        if (state.hasGutter) tipLabel.appendChild(annotationTooltip(ann));

        if (ann.to) state.marked.push(cm.markText(ann.from, ann.to, {
          className: "CodeMirror-lint-mark-" + severity,
          __annotation: ann
        }));
      }

      if (state.hasGutter)
        cm.setGutterMarker(line, GUTTER_ID, makeMarker(tipLabel, maxSeverity, anns.length > 1,
                                                       state.options.tooltips));
    }
    if (options.onUpdateLinting) options.onUpdateLinting(annotationsNotSorted, annotations, cm);
  }

  function onChange(cm) {
    var state = cm.state.lint;
    clearTimeout(state.timeout);
    state.timeout = setTimeout(function(){startLinting(cm);}, state.options.delay || 500);
  }

  function popupSpanTooltip(ann, e) {
    var target = e.target || e.srcElement;
    showTooltipFor(e, annotationTooltip(ann), target);
  }

  // When the mouseover fires, the cursor might not actually be over
  // the character itself yet. These pairs of x,y offsets are used to
  // probe a few nearby points when no suitable marked range is found.
  var nearby = [0, 0, 0, 5, 0, -5, 5, 0, -5, 0];

  function onMouseOver(cm, e) {
    if (!/\bCodeMirror-lint-mark-/.test((e.target || e.srcElement).className)) return;
    for (var i = 0; i < nearby.length; i += 2) {
      var spans = cm.findMarksAt(cm.coordsChar({left: e.clientX + nearby[i],
                                                top: e.clientY + nearby[i + 1]}));
      for (var j = 0; j < spans.length; ++j) {
        var span = spans[j], ann = span.__annotation;
        if (ann) return popupSpanTooltip(ann, e);
      }
    }
  }

  function optionHandler(cm, val, old) {
    if (old && old != CodeMirror.Init) {
      clearMarks(cm);
      cm.off("change", onChange);
      CodeMirror.off(cm.getWrapperElement(), "mouseover", cm.state.lint.onMouseOver);
      delete cm.state.lint;
    }

    if (val) {
      var gutters = cm.getOption("gutters"), hasLintGutter = false;
      for (var i = 0; i < gutters.length; ++i) if (gutters[i] == GUTTER_ID) hasLintGutter = true;
      var state = cm.state.lint = new LintState(cm, parseOptions(cm, val), hasLintGutter);
      cm.on("change", onChange);
      if (state.options.tooltips != false)
        CodeMirror.on(cm.getWrapperElement(), "mouseover", state.onMouseOver);

      startLinting(cm);
    }
  }

  CodeMirror.defineOption("lintWith", false, optionHandler); // deprecated
  CodeMirror.defineOption("lint", false, optionHandler); // deprecated
})();

'use strict';
/**
 * Binds a CodeMirror widget to a <textarea> element.
 */
angular.module('ui.codemirror', []).constant('uiCodemirrorConfig', {}).directive('uiCodemirror', [
  'uiCodemirrorConfig',
  function (uiCodemirrorConfig) {
    return {
      restrict: 'EA',
      require: '?ngModel',
      priority: 1,
      compile: function compile() {
        // Require CodeMirror
        if (angular.isUndefined(window.CodeMirror)) {
          throw new Error('ui-codemirror need CodeMirror to work... (o rly?)');
        }
        return function postLink(scope, iElement, iAttrs, ngModel) {
          var options, opts, codeMirror, initialTextValue;
          initialTextValue = iElement.text();
          options = uiCodemirrorConfig.codemirror || {};
          opts = angular.extend({ value: initialTextValue }, options, scope.$eval(iAttrs.uiCodemirror), scope.$eval(iAttrs.uiCodemirrorOpts));
          if (iElement[0].tagName === 'TEXTAREA') {
            // Might bug but still ...
            codeMirror = window.CodeMirror.fromTextArea(iElement[0], opts);
          } else {
            iElement.html('');
            codeMirror = new window.CodeMirror(function (cm_el) {
              iElement.append(cm_el);
            }, opts);
          }
          if (iAttrs.uiCodemirror || iAttrs.uiCodemirrorOpts) {
            var codemirrorDefaultsKeys = Object.keys(window.CodeMirror.defaults);
            scope.$watch(iAttrs.uiCodemirror || iAttrs.uiCodemirrorOpts, function updateOptions(newValues, oldValue) {
              if (!angular.isObject(newValues)) {
                return;
              }
              codemirrorDefaultsKeys.forEach(function (key) {
                if (newValues.hasOwnProperty(key)) {
                  if (oldValue && newValues[key] === oldValue[key]) {
                    return;
                  }
                  codeMirror.setOption(key, newValues[key]);
                }
              });
            }, true);
          }
          if (ngModel) {
            // CodeMirror expects a string, so make sure it gets one.
            // This does not change the model.
            ngModel.$formatters.push(function (value) {
              if (angular.isUndefined(value) || value === null) {
                return '';
              } else if (angular.isObject(value) || angular.isArray(value)) {
                throw new Error('ui-codemirror cannot use an object or an array as a model');
              }
              return value;
            });
            // Override the ngModelController $render method, which is what gets called when the model is updated.
            // This takes care of the synchronizing the codeMirror element with the underlying model, in the case that it is changed by something else.
            ngModel.$render = function () {
              //Code mirror expects a string so make sure it gets one
              //Although the formatter have already done this, it can be possible that another formatter returns undefined (for example the required directive)
              var safeViewValue = ngModel.$viewValue || '';
              codeMirror.setValue(safeViewValue);
            };
            // Keep the ngModel in sync with changes from CodeMirror
            codeMirror.on('change', function (instance) {
              var newValue = instance.getValue();
              if (newValue !== ngModel.$viewValue) {
                // Changes to the model from a callback need to be wrapped in $apply or angular will not notice them
                scope.$apply(function () {
                  ngModel.$setViewValue(newValue);
                });
              }
            });
          }
          // Watch ui-refresh and refresh the directive
          if (iAttrs.uiRefresh) {
            scope.$watch(iAttrs.uiRefresh, function (newVal, oldVal) {
              // Skip the initial watch firing
              if (newVal !== oldVal) {
                codeMirror.refresh();
              }
            });
          }
          // Allow access to the CodeMirror instance through a broadcasted event
          // eg: $broadcast('CodeMirror', function(cm){...});
          scope.$on('CodeMirror', function (event, callback) {
            if (angular.isFunction(callback)) {
              callback(codeMirror);
            } else {
              throw new Error('the CodeMirror event requires a callback function');
            }
          });
          // onLoad callback
          if (angular.isFunction(opts.onLoad)) {
            opts.onLoad(codeMirror);
          }
        };
      }
    };
  }
]);
/*
 * angular-marked
 * (c) 2014 J. Harshbarger
 * Licensed MIT
 */

/* jshint undef: true, unused: true */
/* global angular:true */
/* global marked:true */
/* global module */
/* global require */

(function () {
  'use strict';

  /**
   * @ngdoc overview
   * @name index
   *
   * @description
   * AngularJS Markdown using [marked](https://github.com/chjj/marked).
   *
   * ## Why?
   *
   * I wanted to use [marked](https://github.com/chjj/marked) instead of [showdown](https://github.com/coreyti/showdown) as used in [angular-markdown-directive](https://github.com/btford/angular-markdown-directive) as well as expose the option to globally set defaults.
   *
   * ## How?
   *
   * - {@link hc.marked.directive:marked As a directive}
   * - {@link hc.marked.service:marked As a service}
   * - {@link hc.marked.service:markedProvider Set default options}
   *
   * @example

      Convert markdown to html at run time.  For example:

      <example module="hc.marked">
        <file name=".html">
          <form ng-controller="MainController">
            Markdown:<br />
            <textarea ng-model="my_markdown" cols="60" rows="5" class="span8" /><br />
            Output:<br />
            <div marked="my_markdown" />
          </form>
        </file>
        <file  name=".js">
          function MainController($scope) {
            $scope.my_markdown = "*This* **is** [markdown](https://daringfireball.net/projects/markdown/)";
          }
        </file>
      </example>

    *
    */

    /**
     * @ngdoc overview
     * @name hc.marked
     * @description # angular-marked (core module)
       # Installation
      First include angular-marked.js in your HTML:

      ```js
        <script src="angular-marked.js">
      ```

      Then load the module in your application by adding it as a dependency:

      ```js
      angular.module('yourApp', ['hc.marked']);
      ```

      With that you're ready to get started!
     */

  if (typeof module !== 'undefined' && typeof exports === 'object') {
    module.exports = 'hc.marked';
  }

  angular.module('hc.marked', [])

    /**
    * @ngdoc service
    * @name hc.marked.service:marked
    * @requires $window
    * @description
    * A reference to the [marked](https://github.com/chjj/marked) parser.
    *
    * @example
    <example module="hc.marked">
      <file name=".html">
        <div ng-controller="MainController">
          html: {{html}}
        </div>
      </file>
      <file  name=".js">
        function MainController($scope, marked) {
          $scope.html = marked('#TEST');
        }
      </file>
    </example>
   **/

   /**
   * @ngdoc service
   * @name hc.marked.service:markedProvider
   * @description
   * Use `markedProvider` to change the default behavior of the {@link hc.marked.service:marked marked} service.
   *
   * @example

    ## Example using [google-code-prettify syntax highlighter](https://code.google.com/p/google-code-prettify/) (must include google-code-prettify.js script).  Also works with [highlight.js Javascript syntax highlighter](http://highlightjs.org/).

    <example module="myApp">
    <file name=".js">
    angular.module('myApp', ['hc.marked'])
      .config(['markedProvider', function(markedProvider) {
        markedProvider.setOptions({
          gfm: true,
          tables: true,
          highlight: function (code) {
            return prettyPrintOne(code);
          }
        });
      }]);
    </file>
    <file name=".html">
      <marked>
      ```js
      angular.module('myApp', ['hc.marked'])
        .config(['markedProvider', function(markedProvider) {
          markedProvider.setOptions({
            gfm: true,
            tables: true,
            highlight: function (code) {
              return prettyPrintOne(code);
            }
          });
        }]);
      ```
      </marked>
    </file>
    </example>
  **/

  .provider('marked', function () {

    var self = this;

    /**
     * @ngdoc method
     * @name markedProvider#setOptions
     * @methodOf hc.marked.service:markedProvider
     *
     * @param {object} opts Default options for [marked](https://github.com/chjj/marked#options-1).
     */

    self.setRenderer = function (opts) {
      this.renderer = opts;
    };

    self.setOptions = function(opts) {  // Store options for later
      this.defaults = opts;
    };

    self.$get = ['$window', '$log', function ($window, $log) {

      var m =  (function() {

        if (typeof module !== 'undefined' && typeof exports === 'object') {
          return require('marked');
        } else {
          return $window.marked || marked;
        }

      })();

      if (angular.isUndefined(m)) {
        $log.error('angular-marked Error: marked not loaded.  See installation instructions.');
        return;
      }

      // override rendered markdown html
      // with custom definitions if defined
      if (self.renderer) {
        var r = new m.Renderer();
        var o = Object.keys(self.renderer),
            l = o.length;

        while (l--) {
          r[o[l]] = self.renderer[o[l]];
        }

        // add the new renderer to the options if need be
        self.defaults = self.defaults || {};
        self.defaults.renderer = r;
      }

      m.setOptions(self.defaults);

      return m;
    }];

  })

  // TODO: filter tests */
  //app.filter('marked', ['marked', function(marked) {
  //  return marked;
  //}]);

  /**
   * @ngdoc directive
   * @name hc.marked.directive:marked
   * @restrict AE
   * @element any
   *
   * @description
   * Compiles source test into HTML.
   *
   * @param {expression} marked The source text to be compiled.  If blank uses content as the source.
   * @param {expression=} opts Hash of options that override defaults.
   *
   * @example

     ## A simple block of text

      <example module="hc.marked">
        <file name="exampleA.html">
         * <marked>
         * ### Markdown directive
         *
         * *It works!*
         *
         * *This* **is** [markdown](https://daringfireball.net/projects/markdown/) in the view.
         * </marked>
        </file>
      </example>

     ## Bind to a scope variable

      <example module="hc.marked">
        <file name="exampleB.html">
          <form ng-controller="MainController">
            Markdown:<br />
            <textarea ng-model="my_markdown" class="span8" cols="60" rows="5"></textarea><br />
            Output:<br />
            <blockquote marked="my_markdown"></blockquote>
          </form>
        </file>
        <file  name="exampleB.js">
          * function MainController($scope) {
          *   $scope.my_markdown = '*This* **is** [markdown](https://daringfireball.net/projects/markdown/)';
          *   $scope.my_markdown += ' in a scope variable';
          * }
        </file>
      </example>

      ## Include a markdown file:

       <example module="hc.marked">
         <file name="exampleC.html">
           <div marked ng-include="'include.html'" />
         </file>
         * <file name="include.html">
         * *This* **is** [markdown](https://daringfireball.net/projects/markdown/) in a include file.
         * </file>
       </example>
   */

  .directive('marked', ['marked', function (marked) {
    return {
      restrict: 'AE',
      replace: true,
      scope: {
        opts: '=',
        marked: '='
      },
      link: function (scope, element, attrs) {
        set(scope.marked || element.text() || '');

        function unindent(text) {
          if (!text) return text;

          var lines  = text
            .replace(/\t/g, '  ')
            .split(/\r?\n/);

          var i, l, min = null, line, len = lines.length;
          for (i = 0; i < len; i++) {
            line = lines[i];
            l = line.match(/^(\s*)/)[0].length;
            if (l === line.length) { continue; }
            min = (l < min || min === null) ? l : min;
          }

          if (min !== null && min > 0) {
            for (i = 0; i < len; i++) {
              lines[i] = lines[i].substr(min);
            }
          }
          return lines.join('\n');
        }

        function set(text) {
          text = unindent(text || '');
          element.html(marked(text, scope.opts || null));
        }

        if (attrs.marked) {
          scope.$watch('marked', set);
        }

      }
    };
  }]);

}());

/*global angular*/
(function (module) {

var dirHljs, dirLanguageFactory, dirSourceFactory, dirIncludeFactory;

function shouldHighlightStatics(attrs) {
  var should = true;
  angular.forEach([
    'source', 'include'
  ], function (name) {
    if (attrs[name]) {
      should = false;
    }
  });
  return should;
}

module

/**
 * hljsService service
 */
.provider('hljsService', function () {
  var _hljsOptions = {};

  return {
    setOptions: function (options) {
      angular.extend(_hljsOptions, options);
    },
    getOptions: function () {
      return angular.copy(_hljsOptions);
    },
    $get: ['$window', function ($window) {
      ($window.hljs.configure || angular.noop)(_hljsOptions);
      return $window.hljs;
    }]
  };
})

/**
 * hljsCache service
 */
.factory('hljsCache', [
         '$cacheFactory',
function ($cacheFactory) {
  return $cacheFactory('hljsCache');
}])

/**
 * HljsCtrl controller
 */
.controller('HljsCtrl', [
                  'hljsCache', 'hljsService',
function HljsCtrl (hljsCache,   hljsService) {
  var ctrl = this;

  var _elm = null,
      _lang = null,
      _code = null,
      _hlCb = null;

  ctrl.init = function (codeElm) {
    _elm = codeElm;
  };

  ctrl.setLanguage = function (lang) {
    _lang = lang;

    if (_code) {
      ctrl.highlight(_code);
    }
  };

  ctrl.highlightCallback = function (cb) {
    _hlCb = cb;
  };

  ctrl.highlight = function (code) {
    if (!_elm) {
      return;
    }

    var res, cacheKey;

    _code = code;

    if (_lang) {
      // language specified
      cacheKey = ctrl._cacheKey(_lang, _code);
      res = hljsCache.get(cacheKey);

      if (!res) {
        res = hljsService.highlight(_lang, hljsService.fixMarkup(_code), true);
        hljsCache.put(cacheKey, res);
      }
    }
    else {
      // language auto-detect
      cacheKey = ctrl._cacheKey(_code);
      res = hljsCache.get(cacheKey);

      if (!res) {
        res = hljsService.highlightAuto(hljsService.fixMarkup(_code));
        hljsCache.put(cacheKey, res);
      }
    }

    _elm.html(res.value);
    // language as class on the <code> tag
    _elm.addClass(res.language);

    if (_hlCb !== null && angular.isFunction(_hlCb)) {
      _hlCb();
    }
  };

  ctrl.clear = function () {
    if (!_elm) {
      return;
    }
    _code = null;
    _elm.text('');
  };

  ctrl.release = function () {
    _elm = null;
  };

  ctrl._cacheKey = function () {
    var args = Array.prototype.slice.call(arguments),
        glue = "!angular-highlightjs!";
    return args.join(glue);
  };
}]);

/**
 * hljs directive
 */
dirHljs = ['$compile', '$parse', function ($compile, $parse) {
  return {
    restrict: 'EA',
    controller: 'HljsCtrl',
    compile: function(tElm, tAttrs, transclude) {
      // get static code
      // strip the starting "new line" character
      var staticHTML = tElm[0].innerHTML.replace(/^(\r\n|\r|\n)/m, ''),
          staticText = tElm[0].textContent.replace(/^(\r\n|\r|\n)/m, '');

      // put template
      tElm.html('<pre><code class="hljs"></code></pre>');

      return function postLink(scope, iElm, iAttrs, ctrl) {
        var compileCheck, escapeCheck;

        if (angular.isDefined(iAttrs.compile)) {
          compileCheck = $parse(iAttrs.compile);
        }

        if (angular.isDefined(iAttrs.escape)) {
          escapeCheck = $parse(iAttrs.escape);
        } else if (angular.isDefined(iAttrs.noEscape)) {
          escapeCheck = $parse('false');
        }

        ctrl.init(iElm.find('code'));

        if (iAttrs.onhighlight) {
          ctrl.highlightCallback(function () {
            scope.$eval(iAttrs.onhighlight);
          });
        }

        if ((staticHTML || staticText) && shouldHighlightStatics(iAttrs)) {

          var code;

          // Auto-escape check
          // default to "true"
          if (escapeCheck && !escapeCheck(scope)) {
            code = staticText;
          }
          else {
            code = staticHTML;
          }

          ctrl.highlight(code);

          // Check if the highlight result needs to be compiled
          if (compileCheck && compileCheck(scope)) {
            // compile the new DOM and link it to the current scope.
            // NOTE: we only compile .childNodes so that
            // we don't get into infinite loop compiling ourselves
            $compile(iElm.find('code').contents())(scope);
          }
        }

        scope.$on('$destroy', function () {
          ctrl.release();
        });
      };
    }
  };
}];

/**
 * language directive
 */
dirLanguageFactory = function (dirName) {
  return [function () {
    return {
      require: '?hljs',
      restrict: 'A',
      link: function (scope, iElm, iAttrs, ctrl) {
        if (!ctrl) {
          return;
        }      
        iAttrs.$observe(dirName, function (lang) {
          if (angular.isDefined(lang)) {
            ctrl.setLanguage(lang);
          }
        });
      }
    };
  }];
};

/**
 * source directive
 */
dirSourceFactory = function (dirName) {
  return ['$compile', '$parse', function ($compile, $parse) {
    return {
      require: '?hljs',
      restrict: 'A',
      link: function(scope, iElm, iAttrs, ctrl) {
        var compileCheck;

        if (!ctrl) {
          return;
        }

        if (angular.isDefined(iAttrs.compile)) {
          compileCheck = $parse(iAttrs.compile);
        }

        scope.$watch(iAttrs[dirName], function (newCode, oldCode) {
          if (newCode) {
            ctrl.highlight(newCode);

            // Check if the highlight result needs to be compiled
            if (compileCheck && compileCheck(scope)) {
              // compile the new DOM and link it to the current scope.
              // NOTE: we only compile .childNodes so that
              // we don't get into infinite loop compiling ourselves
              $compile(iElm.find('code').contents())(scope);
            }
          }
          else {
            ctrl.clear();
          }
        });
      }
    };
  }];
};

/**
 * include directive
 */
dirIncludeFactory = function (dirName) {
  return [
             '$http', '$templateCache', '$q', '$compile', '$parse',
    function ($http,   $templateCache,   $q,   $compile,   $parse) {
      return {
        require: '?hljs',
        restrict: 'A',
        compile: function(tElm, tAttrs, transclude) {
          var srcExpr = tAttrs[dirName];

          return function postLink(scope, iElm, iAttrs, ctrl) {
            var changeCounter = 0, compileCheck;

            if (!ctrl) {
              return;
            }

            if (angular.isDefined(iAttrs.compile)) {
              compileCheck = $parse(iAttrs.compile);
            }

            scope.$watch(srcExpr, function (src) {
              var thisChangeId = ++changeCounter;

              if (src && angular.isString(src)) {
                var templateCachePromise, dfd;

                templateCachePromise = $templateCache.get(src);
                if (!templateCachePromise) {
                  dfd = $q.defer();
                  $http.get(src, {
                    cache: $templateCache,
                    transformResponse: function(data, headersGetter) {
                      // Return the raw string, so $http doesn't parse it
                      // if it's json.
                      return data;
                    }
                  }).success(function (code) {
                    if (thisChangeId !== changeCounter) {
                      return;
                    }
                    dfd.resolve(code);
                  }).error(function() {
                    if (thisChangeId === changeCounter) {
                      ctrl.clear();
                    }
                    dfd.resolve();
                  });
                  templateCachePromise = dfd.promise;
                }

                $q.when(templateCachePromise)
                .then(function (code) {
                  if (!code) {
                    return;
                  }

                  // $templateCache from $http
                  if (angular.isArray(code)) {
                    // 1.1.5
                    code = code[1];
                  }
                  else if (angular.isObject(code)) {
                    // 1.0.7
                    code = code.data;
                  }

                  code = code.replace(/^(\r\n|\r|\n)/m, '');
                  ctrl.highlight(code);

                  // Check if the highlight result needs to be compiled
                  if (compileCheck && compileCheck(scope)) {
                    // compile the new DOM and link it to the current scope.
                    // NOTE: we only compile .childNodes so that
                    // we don't get into infinite loop compiling ourselves
                    $compile(iElm.find('code').contents())(scope);
                  }
                });
              }
              else {
                ctrl.clear();
              }
            });
          };
        }
      };
  }];
};

module
.directive('hljs', dirHljs)
.directive('language', dirLanguageFactory('language'))
.directive('source', dirSourceFactory('source'))
.directive('include', dirIncludeFactory('include'));

})(angular.module('hljs', []));
(function (root) {
// lazy require symbols table
var _symbols, removelist;
function symbols(code) {
    if (_symbols) return _symbols[code];
    _symbols = require('unicode/category/So');
    removelist = ['sign','cross','of','symbol','staff','hand','black','white']
        .map(function (word) {return new RegExp(word, 'gi')});
    return _symbols[code];
}

function slug(string, opts) {
    opts = opts || {};
    string = string.toString();
    if ('string' === typeof opts)
        opts = {replacement:opts};
    opts.mode = opts.mode || slug.defaults.mode;
    var defaults = slug.defaults.modes[opts.mode];
    ['replacement','multicharmap','charmap','remove'].forEach(function (key) {
        opts[key] = opts[key] || defaults[key];
    });
    if ('undefined' === typeof opts.symbols)
        opts.symbols = defaults.symbols;
    var lengths = [];
    Object.keys(opts.multicharmap).forEach(function (key) {
        var len = key.length;
        if (lengths.indexOf(len) === -1)
            lengths.push(len);
    });
    var code, unicode, result = "";
    for (var char, i = 0, l = string.length; i < l; i++) { char = string[i];
        if (!lengths.some(function (len) {
            var str = string.substr(i, len);
            if (opts.multicharmap[str]) {
                i += len - 1;
                char = opts.multicharmap[str];
                return true;
            } else return false;
        })) {
            if (opts.charmap[char]) {
                char = opts.charmap[char];
                code = char.charCodeAt(0);
            } else {
                code = string.charCodeAt(i);
            }
            if (opts.symbols && (unicode = symbols(code))) {
                char = unicode.name.toLowerCase();
                for(var j = 0, rl = removelist.length; j < rl; j++) {
                    char = char.replace(removelist[j], '');
                }
                char = char.replace(/^\s+|\s+$/g, '');
            }
        }
        char = char.replace(/[^\w\s\-\.\_~]/g, ''); // allowed
        if (opts.remove) char = char.replace(opts.remove, ''); // add flavour
        result += char;
    }
    result = result.replace(/^\s+|\s+$/g, ''); // trim leading/trailing spaces
    result = result.replace(/[-\s]+/g, opts.replacement); // convert spaces
    return result.replace(opts.replacement+"$",''); // remove trailing separator
};

slug.defaults = {
    mode: 'pretty',
};

slug.multicharmap = slug.defaults.multicharmap = {
    '<3': 'love', '&&': 'and', '||': 'or', 'w/': 'with',
};

// https://code.djangoproject.com/browser/django/trunk/django/contrib/admin/media/js/urlify.js
slug.charmap  = slug.defaults.charmap = {
    // latin
    'À': 'A', 'Á': 'A', 'Â': 'A', 'Ã': 'A', 'Ä': 'A', 'Å': 'A', 'Æ': 'AE',
    'Ç': 'C', 'È': 'E', 'É': 'E', 'Ê': 'E', 'Ë': 'E', 'Ì': 'I', 'Í': 'I',
    'Î': 'I', 'Ï': 'I', 'Ð': 'D', 'Ñ': 'N', 'Ò': 'O', 'Ó': 'O', 'Ô': 'O',
    'Õ': 'O', 'Ö': 'O', 'Ő': 'O', 'Ø': 'O', 'Ù': 'U', 'Ú': 'U', 'Û': 'U',
    'Ü': 'U', 'Ű': 'U', 'Ý': 'Y', 'Þ': 'TH', 'ß': 'ss', 'à':'a', 'á':'a',
    'â': 'a', 'ã': 'a', 'ä': 'a', 'å': 'a', 'æ': 'ae', 'ç': 'c', 'è': 'e',
    'é': 'e', 'ê': 'e', 'ë': 'e', 'ì': 'i', 'í': 'i', 'î': 'i', 'ï': 'i',
    'ð': 'd', 'ñ': 'n', 'ò': 'o', 'ó': 'o', 'ô': 'o', 'õ': 'o', 'ö': 'o',
    'ő': 'o', 'ø': 'o', 'ù': 'u', 'ú': 'u', 'û': 'u', 'ü': 'u', 'ű': 'u',
    'ý': 'y', 'þ': 'th', 'ÿ': 'y', 'ẞ': 'SS',
    // greek
    'α':'a', 'β':'b', 'γ':'g', 'δ':'d', 'ε':'e', 'ζ':'z', 'η':'h', 'θ':'8',
    'ι':'i', 'κ':'k', 'λ':'l', 'μ':'m', 'ν':'n', 'ξ':'3', 'ο':'o', 'π':'p',
    'ρ':'r', 'σ':'s', 'τ':'t', 'υ':'y', 'φ':'f', 'χ':'x', 'ψ':'ps', 'ω':'w',
    'ά':'a', 'έ':'e', 'ί':'i', 'ό':'o', 'ύ':'y', 'ή':'h', 'ώ':'w', 'ς':'s',
    'ϊ':'i', 'ΰ':'y', 'ϋ':'y', 'ΐ':'i',
    'Α':'A', 'Β':'B', 'Γ':'G', 'Δ':'D', 'Ε':'E', 'Ζ':'Z', 'Η':'H', 'Θ':'8',
    'Ι':'I', 'Κ':'K', 'Λ':'L', 'Μ':'M', 'Ν':'N', 'Ξ':'3', 'Ο':'O', 'Π':'P',
    'Ρ':'R', 'Σ':'S', 'Τ':'T', 'Υ':'Y', 'Φ':'F', 'Χ':'X', 'Ψ':'PS', 'Ω':'W',
    'Ά':'A', 'Έ':'E', 'Ί':'I', 'Ό':'O', 'Ύ':'Y', 'Ή':'H', 'Ώ':'W', 'Ϊ':'I',
    'Ϋ':'Y',
    // turkish
    'ş':'s', 'Ş':'S', 'ı':'i', 'İ':'I',
    'ğ':'g', 'Ğ':'G',
    // russian
    'а':'a', 'б':'b', 'в':'v', 'г':'g', 'д':'d', 'е':'e', 'ё':'yo', 'ж':'zh',
    'з':'z', 'и':'i', 'й':'j', 'к':'k', 'л':'l', 'м':'m', 'н':'n', 'о':'o',
    'п':'p', 'р':'r', 'с':'s', 'т':'t', 'у':'u', 'ф':'f', 'х':'h', 'ц':'c',
    'ч':'ch', 'ш':'sh', 'щ':'sh', 'ъ':'u', 'ы':'y', 'ь':'', 'э':'e', 'ю':'yu',
    'я':'ya',
    'А':'A', 'Б':'B', 'В':'V', 'Г':'G', 'Д':'D', 'Е':'E', 'Ё':'Yo', 'Ж':'Zh',
    'З':'Z', 'И':'I', 'Й':'J', 'К':'K', 'Л':'L', 'М':'M', 'Н':'N', 'О':'O',
    'П':'P', 'Р':'R', 'С':'S', 'Т':'T', 'У':'U', 'Ф':'F', 'Х':'H', 'Ц':'C',
    'Ч':'Ch', 'Ш':'Sh', 'Щ':'Sh', 'Ъ':'U', 'Ы':'Y', 'Ь':'', 'Э':'E', 'Ю':'Yu',
    'Я':'Ya',
    // ukranian
    'Є':'Ye', 'І':'I', 'Ї':'Yi', 'Ґ':'G', 'є':'ye', 'і':'i', 'ї':'yi', 'ґ':'g',
    // czech
    'č':'c', 'ď':'d', 'ě':'e', 'ň': 'n', 'ř':'r', 'š':'s', 'ť':'t', 'ů':'u',
    'ž':'z', 'Č':'C', 'Ď':'D', 'Ě':'E', 'Ň': 'N', 'Ř':'R', 'Š':'S', 'Ť':'T',
    'Ů':'U', 'Ž':'Z',
    // polish
    'ą':'a', 'ć':'c', 'ę':'e', 'ł':'l', 'ń':'n', 'ś':'s', 'ź':'z',
    'ż':'z', 'Ą':'A', 'Ć':'C', 'Ę':'E', 'Ł':'L', 'Ń':'N', 'Ś':'S',
    'Ź':'Z', 'Ż':'Z',
    // latvian
    'ā':'a', 'ē':'e', 'ģ':'g', 'ī':'i', 'ķ':'k', 'ļ':'l', 'ņ':'n',
    'ū':'u', 'Ā':'A', 'Ē':'E', 'Ģ':'G', 'Ī':'I',
    'Ķ':'K', 'Ļ':'L', 'Ņ':'N', 'Ū':'U',
    // lithuanian
    'ė':'e', 'į':'i', 'ų':'u', 'Ė': 'E', 'Į': 'I', 'Ų':'U',
    // romanian
    'ț':'t', 'Ț':'T', 'ţ':'t', 'Ţ':'T', 'ș':'s', 'Ș':'S', 'ă':'a', 'Ă':'A',
    // currency
    '€': 'euro', '₢': 'cruzeiro', '₣': 'french franc', '£': 'pound',
    '₤': 'lira', '₥': 'mill', '₦': 'naira', '₧': 'peseta', '₨': 'rupee',
    '₩': 'won', '₪': 'new shequel', '₫': 'dong', '₭': 'kip', '₮': 'tugrik',
    '₯': 'drachma', '₰': 'penny', '₱': 'peso', '₲': 'guarani', '₳': 'austral',
    '₴': 'hryvnia', '₵': 'cedi', '¢': 'cent', '¥': 'yen', '元': 'yuan',
    '円': 'yen', '﷼': 'rial', '₠': 'ecu', '¤': 'currency', '฿': 'baht',
    "$": 'dollar', '₹': 'indian rupee',
    // symbols
    '©':'(c)', 'œ': 'oe', 'Œ': 'OE', '∑': 'sum', '®': '(r)', '†': '+',
    '“': '"', '”': '"', '‘': "'", '’': "'", '∂': 'd', 'ƒ': 'f', '™': 'tm',
    '℠': 'sm', '…': '...', '˚': 'o', 'º': 'o', 'ª': 'a', '•': '*',
    '∆': 'delta', '∞': 'infinity', '♥': 'love', '&': 'and', '|': 'or',
    '<': 'less', '>': 'greater',
};

slug.defaults.modes = {
    rfc3986: {
        replacement: '-',
        symbols: true,
        remove: null,
        charmap: slug.defaults.charmap,
        multicharmap: slug.defaults.multicharmap,
    },
    pretty: {
        replacement: '-',
        symbols: true,
        remove: /[.]/g,
        charmap: slug.defaults.charmap,
        multicharmap: slug.defaults.multicharmap,
    },
};

// Be compatible with different module systems

if (typeof define !== 'undefined' && define.amd) { // AMD
    // dont load symbols table in the browser
    Object.keys(slug.defaults.modes).forEach(function (key) {
        slug.defaults.modes[key].symbols = false;
    });
    define([], function () {return slug});
} else if (typeof module !== 'undefined' && module.exports) { // CommonJS
    symbols(); // preload symbols table
    module.exports = slug;
} else { // Script tag
    // dont load symbols table in the browser
    Object.keys(slug.defaults.modes).forEach(function (key) {
        slug.defaults.modes[key].symbols = false;
    });
    root.slug = slug;
}

}(this));

/* FileSaver.js
 * A saveAs() FileSaver implementation.
 * 1.1.20160328
 *
 * By Eli Grey, http://eligrey.com
 * License: MIT
 *   See https://github.com/eligrey/FileSaver.js/blob/master/LICENSE.md
 */

/*global self */
/*jslint bitwise: true, indent: 4, laxbreak: true, laxcomma: true, smarttabs: true, plusplus: true */

/*! @source http://purl.eligrey.com/github/FileSaver.js/blob/master/FileSaver.js */

var saveAs = saveAs || (function(view) {
	"use strict";
	// IE <10 is explicitly unsupported
	if (typeof navigator !== "undefined" && /MSIE [1-9]\./.test(navigator.userAgent)) {
		return;
	}
	var
		  doc = view.document
		  // only get URL when necessary in case Blob.js hasn't overridden it yet
		, get_URL = function() {
			return view.URL || view.webkitURL || view;
		}
		, save_link = doc.createElementNS("http://www.w3.org/1999/xhtml", "a")
		, can_use_save_link = "download" in save_link
		, click = function(node) {
			var event = new MouseEvent("click");
			node.dispatchEvent(event);
		}
		, is_safari = /Version\/[\d\.]+.*Safari/.test(navigator.userAgent)
		, webkit_req_fs = view.webkitRequestFileSystem
		, req_fs = view.requestFileSystem || webkit_req_fs || view.mozRequestFileSystem
		, throw_outside = function(ex) {
			(view.setImmediate || view.setTimeout)(function() {
				throw ex;
			}, 0);
		}
		, force_saveable_type = "application/octet-stream"
		, fs_min_size = 0
		// the Blob API is fundamentally broken as there is no "downloadfinished" event to subscribe to
		, arbitrary_revoke_timeout = 1000 * 40 // in ms
		, revoke = function(file) {
			var revoker = function() {
				if (typeof file === "string") { // file is an object URL
					get_URL().revokeObjectURL(file);
				} else { // file is a File
					file.remove();
				}
			};
			/* // Take note W3C:
			var
			  uri = typeof file === "string" ? file : file.toURL()
			, revoker = function(evt) {
				// idealy DownloadFinishedEvent.data would be the URL requested
				if (evt.data === uri) {
					if (typeof file === "string") { // file is an object URL
						get_URL().revokeObjectURL(file);
					} else { // file is a File
						file.remove();
					}
				}
			}
			;
			view.addEventListener("downloadfinished", revoker);
			*/
			setTimeout(revoker, arbitrary_revoke_timeout);
		}
		, dispatch = function(filesaver, event_types, event) {
			event_types = [].concat(event_types);
			var i = event_types.length;
			while (i--) {
				var listener = filesaver["on" + event_types[i]];
				if (typeof listener === "function") {
					try {
						listener.call(filesaver, event || filesaver);
					} catch (ex) {
						throw_outside(ex);
					}
				}
			}
		}
		, auto_bom = function(blob) {
			// prepend BOM for UTF-8 XML and text/* types (including HTML)
			if (/^\s*(?:text\/\S*|application\/xml|\S*\/\S*\+xml)\s*;.*charset\s*=\s*utf-8/i.test(blob.type)) {
				return new Blob(["\ufeff", blob], {type: blob.type});
			}
			return blob;
		}
		, FileSaver = function(blob, name, no_auto_bom) {
			if (!no_auto_bom) {
				blob = auto_bom(blob);
			}
			// First try a.download, then web filesystem, then object URLs
			var
				  filesaver = this
				, type = blob.type
				, blob_changed = false
				, object_url
				, target_view
				, dispatch_all = function() {
					dispatch(filesaver, "writestart progress write writeend".split(" "));
				}
				// on any filesys errors revert to saving with object URLs
				, fs_error = function() {
					if (target_view && is_safari && typeof FileReader !== "undefined") {
						// Safari doesn't allow downloading of blob urls
						var reader = new FileReader();
						reader.onloadend = function() {
							var base64Data = reader.result;
							target_view.location.href = "data:attachment/file" + base64Data.slice(base64Data.search(/[,;]/));
							filesaver.readyState = filesaver.DONE;
							dispatch_all();
						};
						reader.readAsDataURL(blob);
						filesaver.readyState = filesaver.INIT;
						return;
					}
					// don't create more object URLs than needed
					if (blob_changed || !object_url) {
						object_url = get_URL().createObjectURL(blob);
					}
					if (target_view) {
						target_view.location.href = object_url;
					} else {
						var new_tab = view.open(object_url, "_blank");
						if (new_tab === undefined && is_safari) {
							//Apple do not allow window.open, see http://bit.ly/1kZffRI
							view.location.href = object_url
						}
					}
					filesaver.readyState = filesaver.DONE;
					dispatch_all();
					revoke(object_url);
				}
				, abortable = function(func) {
					return function() {
						if (filesaver.readyState !== filesaver.DONE) {
							return func.apply(this, arguments);
						}
					};
				}
				, create_if_not_found = {create: true, exclusive: false}
				, slice
			;
			filesaver.readyState = filesaver.INIT;
			if (!name) {
				name = "download";
			}
			if (can_use_save_link) {
				object_url = get_URL().createObjectURL(blob);
				setTimeout(function() {
					save_link.href = object_url;
					save_link.download = name;
					click(save_link);
					dispatch_all();
					revoke(object_url);
					filesaver.readyState = filesaver.DONE;
				});
				return;
			}
			// Object and web filesystem URLs have a problem saving in Google Chrome when
			// viewed in a tab, so I force save with application/octet-stream
			// http://code.google.com/p/chromium/issues/detail?id=91158
			// Update: Google errantly closed 91158, I submitted it again:
			// https://code.google.com/p/chromium/issues/detail?id=389642
			if (view.chrome && type && type !== force_saveable_type) {
				slice = blob.slice || blob.webkitSlice;
				blob = slice.call(blob, 0, blob.size, force_saveable_type);
				blob_changed = true;
			}
			// Since I can't be sure that the guessed media type will trigger a download
			// in WebKit, I append .download to the filename.
			// https://bugs.webkit.org/show_bug.cgi?id=65440
			if (webkit_req_fs && name !== "download") {
				name += ".download";
			}
			if (type === force_saveable_type || webkit_req_fs) {
				target_view = view;
			}
			if (!req_fs) {
				fs_error();
				return;
			}
			fs_min_size += blob.size;
			req_fs(view.TEMPORARY, fs_min_size, abortable(function(fs) {
				fs.root.getDirectory("saved", create_if_not_found, abortable(function(dir) {
					var save = function() {
						dir.getFile(name, create_if_not_found, abortable(function(file) {
							file.createWriter(abortable(function(writer) {
								writer.onwriteend = function(event) {
									target_view.location.href = file.toURL();
									filesaver.readyState = filesaver.DONE;
									dispatch(filesaver, "writeend", event);
									revoke(file);
								};
								writer.onerror = function() {
									var error = writer.error;
									if (error.code !== error.ABORT_ERR) {
										fs_error();
									}
								};
								"writestart progress write abort".split(" ").forEach(function(event) {
									writer["on" + event] = filesaver["on" + event];
								});
								writer.write(blob);
								filesaver.abort = function() {
									writer.abort();
									filesaver.readyState = filesaver.DONE;
								};
								filesaver.readyState = filesaver.WRITING;
							}), fs_error);
						}), fs_error);
					};
					dir.getFile(name, {create: false}, abortable(function(file) {
						// delete file if it already exists
						file.remove();
						save();
					}), abortable(function(ex) {
						if (ex.code === ex.NOT_FOUND_ERR) {
							save();
						} else {
							fs_error();
						}
					}));
				}), fs_error);
			}), fs_error);
		}
		, FS_proto = FileSaver.prototype
		, saveAs = function(blob, name, no_auto_bom) {
			return new FileSaver(blob, name, no_auto_bom);
		}
	;
	// IE 10+ (native saveAs)
	if (typeof navigator !== "undefined" && navigator.msSaveOrOpenBlob) {
		return function(blob, name, no_auto_bom) {
			if (!no_auto_bom) {
				blob = auto_bom(blob);
			}
			return navigator.msSaveOrOpenBlob(blob, name || "download");
		};
	}

	FS_proto.abort = function() {
		var filesaver = this;
		filesaver.readyState = filesaver.DONE;
		dispatch(filesaver, "abort");
	};
	FS_proto.readyState = FS_proto.INIT = 0;
	FS_proto.WRITING = 1;
	FS_proto.DONE = 2;

	FS_proto.error =
	FS_proto.onwritestart =
	FS_proto.onprogress =
	FS_proto.onwrite =
	FS_proto.onabort =
	FS_proto.onerror =
	FS_proto.onwriteend =
		null;

	return saveAs;
}(
	   typeof self !== "undefined" && self
	|| typeof window !== "undefined" && window
	|| this.content
));
// `self` is undefined in Firefox for Android content script context
// while `this` is nsIContentFrameMessageManager
// with an attribute `content` that corresponds to the window

if (typeof module !== "undefined" && module.exports) {
  module.exports.saveAs = saveAs;
} else if ((typeof define !== "undefined" && define !== null) && (define.amd !== null)) {
  define([], function() {
    return saveAs;
  });
}

!function(e){if("object"==typeof exports&&"undefined"!=typeof module)module.exports=e();else if("function"==typeof define&&define.amd)define([],e);else{var n;"undefined"!=typeof window?n=window:"undefined"!=typeof global?n=global:"undefined"!=typeof self&&(n=self),n.ramlClientGenerator=e()}}(function(){var define,module,exports;return (function e(t,n,r){function s(o,u){if(!n[o]){if(!t[o]){var a=typeof require=="function"&&require;if(!u&&a)return a(o,!0);if(i)return i(o,!0);var f=new Error("Cannot find module '"+o+"'");throw f.code="MODULE_NOT_FOUND",f}var l=n[o]={exports:{}};t[o][0].call(l.exports,function(e){var n=t[o][1][e];return s(n?n:e)},l,l.exports,e,t,n,r)}return n[o].exports}var i=typeof require=="function"&&require;for(var o=0;o<r.length;o++)s(r[o]);return s})({1:[function(require,module,exports){
/**
 * Map dependencies to their environment.
 *
 * @type {Object}
 */
var DEPS_MAP = {
  node: {
    popsicle:     'require(\'popsicle\')',
    ClientOAuth2: 'require(\'client-oauth2\')'
  },
  amd: {
    popsicle:     '\'popsicle\'',
    ClientOAuth2: '\'ClientOAuth2\''
  },
  browser: {
    popsicle:     'root.popsicle',
    ClientOAuth2: 'root.ClientOAuth2'
  }
};

/**
 * Map an array of dependency names to values.
 *
 * @param  {Array}  deps
 * @param  {String} env
 * @return {Array}
 */
function mapDeps (deps, env) {
  if (!env) {
    return deps;
  }

  return deps.map(function (dep) {
    return DEPS_MAP[env][dep];
  });
}

/**
 * Create a dependencies string.
 *
 * @param  {Object} context
 * @param  {String} env
 * @return {String}
 */
module.exports = function (context, env) {
  var deps = ['popsicle'];

  // OAuth 2.0 depends on ClientOAuth2 to work.
  if (context.security['OAuth 2.0']) {
    deps.push('ClientOAuth2');
  }

  // Returns an array of strings for AMD.
  if (env === 'amd') {
    return '[' + mapDeps(deps, env).join(', ') + ']';
  }

  return mapDeps(deps, env).join(', ');
};

},{}],2:[function(require,module,exports){
/**
 * Iterate over the parameters and turn into a string.
 *
 * @param  {Object} parameters
 * @return {String}
 */
module.exports = function (parameters) {
  return Object.keys(parameters).map(function (key) {
    var parameter = parameters[key];
    var title     = '* **' + parameter.displayName + '**';
    var options   = [];

    if (parameter.type) {
      options.push(parameter.type);
    }

    if (Array.isArray(parameter.enum) && parameter.enum.length) {
      options.push('one of (' + parameter.enum.join(', ') + ')');
    }

    if (parameter.default) {
      options.push('default: ' + parameter.default);
    }

    return title +
      (options.length ? ' _' + options.join(', ') + '_' : '') +
      (parameter.description ? '\n\n' + parameter.description : '');
  }).join('\n\n');
};

},{}],3:[function(require,module,exports){
/**
 * Pull out request parameters from the resource.
 *
 * @param  {Object} resource
 * @return {String}
 */
var params = function (resource) {
  return resource.uriParameters.map(function (param) {
    return param.displayName;
  }).join(', ');
};

/**
 * Stringify a resource into a request snippet.
 *
 * @param  {Object} resource
 * @return {String}
 */
module.exports = function (resource) {
  var parts = [];
  var part  = resource;

  while (part && part.parent) {
    var segment = part.key;

    // If uri parameters exist, push onto the stack.
    if (part.uriParameters.length) {
      segment += '(' + params(part) + ')';
    }

    parts.unshift(segment);

    part = part.parent;
  }

  return 'resources' + (parts.length ? '.' + parts.join('.') : '');
};

},{}],4:[function(require,module,exports){
var generator = require('../../lib/generator');

/**
 * Export a client generator instance.
 *
 * @type {Function}
 */
module.exports = generator({
  templates: {
    '.gitignore':   require('./templates/.gitignore.hbs'),
    'index.js':     require('./templates/index.js.hbs'),
    'README.md':    require('./templates/README.md.hbs'),
    'INSTALL.md':   require('./templates/INSTALL.md.hbs'),
    'package.json': require('./templates/package.json.hbs')
  },
  format: {
    variable: require('camel-case')
  },
  partials: {
    auth:      require('./partials/auth.js.hbs'),
    utils:     require('./partials/utils.js.hbs'),
    client:    require('./partials/client.js.hbs'),
    resources: require('./partials/resources.js.hbs')
  },
  helpers: {
    stringify:         require('javascript-stringify'),
    dependencies:      require('./helpers/dependencies'),
    requestSnippet:    require('./helpers/request-snippet'),
    parametersSnippet: require('./helpers/parameters-snippet')
  }
});

},{"../../lib/generator":20,"./helpers/dependencies":1,"./helpers/parameters-snippet":2,"./helpers/request-snippet":3,"./partials/auth.js.hbs":5,"./partials/client.js.hbs":6,"./partials/resources.js.hbs":7,"./partials/utils.js.hbs":8,"./templates/.gitignore.hbs":9,"./templates/INSTALL.md.hbs":10,"./templates/README.md.hbs":11,"./templates/index.js.hbs":12,"./templates/package.json.hbs":13,"camel-case":27,"javascript-stringify":45}],5:[function(require,module,exports){
// hbsfy compiled Handlebars template
var HandlebarsCompiler = require('hbsfy/runtime');
module.exports = HandlebarsCompiler.template({"1":function(depth0,helpers,partials,data) {
    var stack1;

  return "/**\n * @param {Object} options\n */\nfunction OAuth2 (options) {\n  ClientOAuth2.call(this, extend("
    + ((stack1 = (helpers.stringify || (depth0 && depth0.stringify) || helpers.helperMissing).call(depth0,((stack1 = ((stack1 = (depth0 != null ? depth0.security : depth0)) != null ? stack1['OAuth 2.0'] : stack1)) != null ? stack1.settings : stack1),{"name":"stringify","hash":{},"data":data})) != null ? stack1 : "")
    + ", options));\n}\n\nOAuth2.prototype = Object.create(ClientOAuth2.prototype);\nOAuth2.prototype.constructor = OAuth2;\nOAuth2.prototype.request = popsicle;\n\nClient.OAuth2 = OAuth2;\n";
},"compiler":[6,">= 2.0.0-beta.1"],"main":function(depth0,helpers,partials,data) {
    var stack1;

  return ((stack1 = helpers['if'].call(depth0,((stack1 = (depth0 != null ? depth0.security : depth0)) != null ? stack1['OAuth 2.0'] : stack1),{"name":"if","hash":{},"fn":this.program(1, data, 0),"inverse":this.noop,"data":data})) != null ? stack1 : "");
},"useData":true});

},{"hbsfy/runtime":41}],6:[function(require,module,exports){
// hbsfy compiled Handlebars template
var HandlebarsCompiler = require('hbsfy/runtime');
module.exports = HandlebarsCompiler.template({"compiler":[6,">= 2.0.0-beta.1"],"main":function(depth0,helpers,partials,data) {
    var stack1, alias1=helpers.helperMissing;

  return "function Client (options) {\n  this.options = extend({\n    baseUri: "
    + ((stack1 = (helpers.stringify || (depth0 && depth0.stringify) || alias1).call(depth0,(depth0 != null ? depth0.baseUri : depth0),{"name":"stringify","hash":{},"data":data})) != null ? stack1 : "")
    + ",\n    baseUriParameters: "
    + ((stack1 = (helpers.stringify || (depth0 && depth0.stringify) || alias1).call(depth0,(helpers.object || (depth0 && depth0.object) || alias1).call(depth0,(helpers.keys || (depth0 && depth0.keys) || alias1).call(depth0,(depth0 != null ? depth0.baseUriParameters : depth0),{"name":"keys","hash":{},"data":data}),(helpers.pluck || (depth0 && depth0.pluck) || alias1).call(depth0,(depth0 != null ? depth0.baseUriParameters : depth0),"default",{"name":"pluck","hash":{},"data":data}),{"name":"object","hash":{},"data":data}),{"name":"stringify","hash":{},"data":data})) != null ? stack1 : "")
    + "\n  }, options);\n\n  this.resources = new "
    + this.escapeExpression((helpers.pascalCase || (depth0 && depth0.pascalCase) || alias1).call(depth0,((stack1 = (depth0 != null ? depth0.resources : depth0)) != null ? stack1.id : stack1),{"name":"pascalCase","hash":{},"data":data}))
    + "('', this);\n};\n\nClient.prototype.resource = function (route, parameters) {\n  var path = '/' + template(route, parameters).replace(/^\\//, '');\n\n  return new CustomResource(path, this);\n};\n\nClient.prototype.request = popsicle;\nClient.prototype.form = Client.form = popsicle.form;\nClient.prototype.version  = "
    + ((stack1 = (helpers.stringify || (depth0 && depth0.stringify) || alias1).call(depth0,(depth0 != null ? depth0.version : depth0),{"name":"stringify","hash":{},"data":data})) != null ? stack1 : "")
    + ";\n";
},"useData":true});

},{"hbsfy/runtime":41}],7:[function(require,module,exports){
// hbsfy compiled Handlebars template
var HandlebarsCompiler = require('hbsfy/runtime');
module.exports = HandlebarsCompiler.template({"1":function(depth0,helpers,partials,data,blockParams,depths) {
    var stack1;

  return "function "
    + this.escapeExpression((helpers.pascalCase || (depth0 && depth0.pascalCase) || helpers.helperMissing).call(depth0,(depth0 != null ? depth0.id : depth0),{"name":"pascalCase","hash":{},"data":data}))
    + " (uri, client) {\n  this._uri    = uri;\n  this._client = client;\n\n"
    + ((stack1 = helpers.each.call(depth0,(depth0 != null ? depth0.children : depth0),{"name":"each","hash":{},"fn":this.program(2, data, 0, blockParams, depths),"inverse":this.noop,"data":data})) != null ? stack1 : "")
    + "};\n\n"
    + ((stack1 = helpers.each.call(depth0,(depth0 != null ? depth0.children : depth0),{"name":"each","hash":{},"fn":this.program(5, data, 0, blockParams, depths),"inverse":this.noop,"data":data})) != null ? stack1 : "")
    + "\n"
    + ((stack1 = helpers.each.call(depth0,(depth0 != null ? depth0.methods : depth0),{"name":"each","hash":{},"fn":this.program(8, data, 0, blockParams, depths),"inverse":this.noop,"data":data})) != null ? stack1 : "");
},"2":function(depth0,helpers,partials,data) {
    var stack1;

  return ((stack1 = helpers.unless.call(depth0,(depth0 != null ? depth0.uriParameters : depth0),{"name":"unless","hash":{},"fn":this.program(3, data, 0),"inverse":this.noop,"data":data})) != null ? stack1 : "");
},"3":function(depth0,helpers,partials,data) {
    var stack1, helper, alias1=helpers.helperMissing, alias2=this.escapeExpression;

  return "  this."
    + alias2(((helper = (helper = helpers.key || (data && data.key)) != null ? helper : alias1),(typeof helper === "function" ? helper.call(depth0,{"name":"key","hash":{},"data":data}) : helper)))
    + " = new "
    + alias2((helpers.pascalCase || (depth0 && depth0.pascalCase) || alias1).call(depth0,(depth0 != null ? depth0.id : depth0),{"name":"pascalCase","hash":{},"data":data}))
    + "(uri + "
    + ((stack1 = (helpers.stringify || (depth0 && depth0.stringify) || alias1).call(depth0,(depth0 != null ? depth0.relativeUri : depth0),{"name":"stringify","hash":{},"data":data})) != null ? stack1 : "")
    + ", client);\n";
},"5":function(depth0,helpers,partials,data,blockParams,depths) {
    var stack1;

  return ((stack1 = helpers['if'].call(depth0,(depth0 != null ? depth0.uriParameters : depth0),{"name":"if","hash":{},"fn":this.program(6, data, 0, blockParams, depths),"inverse":this.noop,"data":data})) != null ? stack1 : "");
},"6":function(depth0,helpers,partials,data,blockParams,depths) {
    var stack1, helper, alias1=helpers.helperMissing, alias2=this.escapeExpression;

  return alias2((helpers.pascalCase || (depth0 && depth0.pascalCase) || alias1).call(depth0,(depths[2] != null ? depths[2].id : depths[2]),{"name":"pascalCase","hash":{},"data":data}))
    + ".prototype."
    + alias2(((helper = (helper = helpers.key || (data && data.key)) != null ? helper : alias1),(typeof helper === "function" ? helper.call(depth0,{"name":"key","hash":{},"data":data}) : helper)))
    + " = function (/* ...args */) {\n  var uri = this._uri + template("
    + ((stack1 = (helpers.stringify || (depth0 && depth0.stringify) || alias1).call(depth0,(depth0 != null ? depth0.relativeUri : depth0),{"name":"stringify","hash":{},"data":data})) != null ? stack1 : "")
    + ", arguments, "
    + ((stack1 = (helpers.stringify || (depth0 && depth0.stringify) || alias1).call(depth0,(helpers.pluck || (depth0 && depth0.pluck) || alias1).call(depth0,(depth0 != null ? depth0.uriParameters : depth0),"default",{"name":"pluck","hash":{},"data":data}),{"name":"stringify","hash":{},"data":data})) != null ? stack1 : "")
    + ");\n\n  return new "
    + alias2((helpers.pascalCase || (depth0 && depth0.pascalCase) || alias1).call(depth0,(depth0 != null ? depth0.id : depth0),{"name":"pascalCase","hash":{},"data":data}))
    + "(uri, this._client);\n};\n";
},"8":function(depth0,helpers,partials,data,blockParams,depths) {
    var stack1, helper, alias1=helpers.helperMissing, alias2=this.escapeExpression;

  return alias2((helpers.pascalCase || (depth0 && depth0.pascalCase) || alias1).call(depth0,(depths[1] != null ? depths[1].id : depths[1]),{"name":"pascalCase","hash":{},"data":data}))
    + ".prototype."
    + alias2(((helper = (helper = helpers.key || (data && data.key)) != null ? helper : alias1),(typeof helper === "function" ? helper.call(depth0,{"name":"key","hash":{},"data":data}) : helper)))
    + " = function (body, options) {\n"
    + ((stack1 = helpers['if'].call(depth0,(helpers.keys || (depth0 && depth0.keys) || alias1).call(depth0,(depth0 != null ? depth0.headers : depth0),{"name":"keys","hash":{},"data":data}),{"name":"if","hash":{},"fn":this.program(9, data, 0, blockParams, depths),"inverse":this.noop,"data":data})) != null ? stack1 : "")
    + "  return handleRequest(this._client, this._uri, "
    + ((stack1 = (helpers.stringify || (depth0 && depth0.stringify) || alias1).call(depth0,(helpers.upperCase || (depth0 && depth0.upperCase) || alias1).call(depth0,(depth0 != null ? depth0.method : depth0),{"name":"upperCase","hash":{},"data":data}),{"name":"stringify","hash":{},"data":data})) != null ? stack1 : "")
    + ", body, options);\n};\n";
},"9":function(depth0,helpers,partials,data) {
    var stack1, alias1=helpers.helperMissing;

  return "  options = extend({}, options);\n  options.headers = extend("
    + ((stack1 = (helpers.stringify || (depth0 && depth0.stringify) || alias1).call(depth0,(helpers.object || (depth0 && depth0.object) || alias1).call(depth0,(helpers.keys || (depth0 && depth0.keys) || alias1).call(depth0,(depth0 != null ? depth0.headers : depth0),{"name":"keys","hash":{},"data":data}),(helpers.pluck || (depth0 && depth0.pluck) || alias1).call(depth0,(depth0 != null ? depth0.headers : depth0),"default",{"name":"pluck","hash":{},"data":data}),{"name":"object","hash":{},"data":data}),{"name":"stringify","hash":{},"data":data})) != null ? stack1 : "")
    + ", options.headers);\n\n";
},"11":function(depth0,helpers,partials,data) {
    var stack1, alias1=helpers.helperMissing;

  return "CustomResource.prototype."
    + this.escapeExpression((helpers.camelCase || (depth0 && depth0.camelCase) || alias1).call(depth0,depth0,{"name":"camelCase","hash":{},"data":data}))
    + " = function (body, options) {\n  return handleRequest(this._client, this._uri, "
    + ((stack1 = (helpers.stringify || (depth0 && depth0.stringify) || alias1).call(depth0,(helpers.upperCase || (depth0 && depth0.upperCase) || alias1).call(depth0,depth0,{"name":"upperCase","hash":{},"data":data}),{"name":"stringify","hash":{},"data":data})) != null ? stack1 : "")
    + ", body, options);\n};\n";
},"compiler":[6,">= 2.0.0-beta.1"],"main":function(depth0,helpers,partials,data,blockParams,depths) {
    var stack1;

  return "function handleRequest (client, path, method, body, options) {\n  options = extend({}, client.options, options);\n\n  var baseUri = template(options.baseUri, options.baseUriParameters);\n  var hasBody = method !== 'GET' && method !== 'HEAD';\n  var reqOpts = {};\n\n  var reqBody = hasBody && body != null ? body : options.body;\n  var reqQuery = !hasBody && body != null ? body : options.query;\n\n  var reqOpts = {\n    url: baseUri.replace(/\\/$/, '') + path,\n    method: method,\n    headers: extend({}, options.headers),\n    body: reqBody,\n    query: typeof reqQuery === 'object' ? extend({}, reqQuery) : reqQuery\n  };\n\n  if (options.user && typeof options.user.sign === 'function') {\n    options.user.sign(reqOpts);\n  }\n\n  return client.request(reqOpts);\n}\n\n"
    + ((stack1 = helpers.each.call(depth0,(depth0 != null ? depth0.allResources : depth0),{"name":"each","hash":{},"fn":this.program(1, data, 0, blockParams, depths),"inverse":this.noop,"data":data})) != null ? stack1 : "")
    + "\nfunction CustomResource (uri, client) {\n  this._uri    = uri;\n  this._client = client;\n}\n\n"
    + ((stack1 = helpers.each.call(depth0,(depth0 != null ? depth0.supportedMethods : depth0),{"name":"each","hash":{},"fn":this.program(11, data, 0, blockParams, depths),"inverse":this.noop,"data":data})) != null ? stack1 : "");
},"useData":true,"useDepths":true});

},{"hbsfy/runtime":41}],8:[function(require,module,exports){
// hbsfy compiled Handlebars template
var HandlebarsCompiler = require('hbsfy/runtime');
module.exports = HandlebarsCompiler.template({"compiler":[6,">= 2.0.0-beta.1"],"main":function(depth0,helpers,partials,data) {
    return "var TEMPLATE_REGEXP = /\\{([^\\{\\}]+)\\}/g;\n\n/**\n * @param  {String} string\n * @param  {Object} interpolate\n * @param  {Object} defaults\n * @return {String}\n */\nfunction template (string, interpolate, defaults) {\n  defaults    = defaults || {};\n  interpolate = interpolate || {};\n\n  return string.replace(TEMPLATE_REGEXP, function (match, key) {\n    if (interpolate[key] != null) {\n      return encodeURIComponent(interpolate[key]);\n    }\n\n    if (defaults[key] != null) {\n      return encodeURIComponent(defaults[key]);\n    }\n\n    return '';\n  });\n}\n\n/**\n * @param  {Object} dest\n * @param  {Object} ...source\n * @return {Object}\n */\nfunction extend (dest /*, ...source */) {\n  for (var i = 1; i < arguments.length; i++) {\n    for (var key in arguments[i]) {\n      dest[key] = arguments[i][key];\n    }\n  }\n\n  return dest;\n}\n";
},"useData":true});

},{"hbsfy/runtime":41}],9:[function(require,module,exports){
// hbsfy compiled Handlebars template
var HandlebarsCompiler = require('hbsfy/runtime');
module.exports = HandlebarsCompiler.template({"compiler":[6,">= 2.0.0-beta.1"],"main":function(depth0,helpers,partials,data) {
    return "node_modules\n";
},"useData":true});

},{"hbsfy/runtime":41}],10:[function(require,module,exports){
// hbsfy compiled Handlebars template
var HandlebarsCompiler = require('hbsfy/runtime');
module.exports = HandlebarsCompiler.template({"compiler":[6,">= 2.0.0-beta.1"],"main":function(depth0,helpers,partials,data) {
    var alias1=helpers.helperMissing, alias2=this.escapeExpression;

  return "# Installation\n\nFollow these instructions to publish and subsequently install the module in your project.\n\n## Git\n\n```\n# Initialize with git\ngit init\ngit add .\ngit commit -m \"initial commit\"\ngit push [git-url]\n\n# Install in project from git\nnpm install [git-url] --save\n```\n\n## Source Directory\n\n```\n# Link module globally\nnpm link\n\n# Link in project to local module\nnpm link "
    + alias2((helpers.paramCase || (depth0 && depth0.paramCase) || alias1).call(depth0,(depth0 != null ? depth0.title : depth0),{"name":"paramCase","hash":{},"data":data}))
    + "\n```\n\n**Note:** You should publish it before you use it publicly.\n\n## NPM\n\n```\n# Publish to npm\nnpm publish\n\n# Install from npm\nnpm install "
    + alias2((helpers.paramCase || (depth0 && depth0.paramCase) || alias1).call(depth0,(depth0 != null ? depth0.title : depth0),{"name":"paramCase","hash":{},"data":data}))
    + " --save\n```\n\n## Bower\n\n```\n# Register with bower\nbower register "
    + alias2((helpers.paramCase || (depth0 && depth0.paramCase) || alias1).call(depth0,(depth0 != null ? depth0.title : depth0),{"name":"paramCase","hash":{},"data":data}))
    + " [git-url]\n\n# Install from bower\nbower install "
    + alias2((helpers.paramCase || (depth0 && depth0.paramCase) || alias1).call(depth0,(depth0 != null ? depth0.title : depth0),{"name":"paramCase","hash":{},"data":data}))
    + " --save\n```\n";
},"useData":true});

},{"hbsfy/runtime":41}],11:[function(require,module,exports){
// hbsfy compiled Handlebars template
var HandlebarsCompiler = require('hbsfy/runtime');
module.exports = HandlebarsCompiler.template({"1":function(depth0,helpers,partials,data) {
    var stack1, alias1=helpers.helperMissing, alias2=this.escapeExpression;

  return "### Authentication\n\n#### OAuth 2.0\n\nThis API supports authentication with [OAuth 2.0](https://github.com/mulesoft/js-client-oauth2). Initialize the `OAuth2` instance with the application client id, client secret and a redirect uri to authenticate with users.\n\n```js\nvar auth = new "
    + alias2((helpers.pascalCase || (depth0 && depth0.pascalCase) || alias1).call(depth0,(depth0 != null ? depth0.title : depth0),{"name":"pascalCase","hash":{},"data":data}))
    + ".OAuth2({\n  clientId:     '123',\n  clientSecret: 'abc',\n  redirectUri:  'http://example.com/auth/callback'\n});\n```\n\n**All `getToken()` calls are asynchronous and return promise objects which resolve to an access token instance.**\n\n"
    + ((stack1 = helpers['if'].call(depth0,(helpers.contains || (depth0 && depth0.contains) || alias1).call(depth0,((stack1 = ((stack1 = ((stack1 = (depth0 != null ? depth0.security : depth0)) != null ? stack1['OAuth 2.0'] : stack1)) != null ? stack1.settings : stack1)) != null ? stack1.authorizationGrants : stack1),"code",{"name":"contains","hash":{},"data":data}),{"name":"if","hash":{},"fn":this.program(2, data, 0),"inverse":this.noop,"data":data})) != null ? stack1 : "")
    + ((stack1 = helpers['if'].call(depth0,(helpers.contains || (depth0 && depth0.contains) || alias1).call(depth0,((stack1 = ((stack1 = ((stack1 = (depth0 != null ? depth0.security : depth0)) != null ? stack1['OAuth 2.0'] : stack1)) != null ? stack1.settings : stack1)) != null ? stack1.authorizationGrants : stack1),"token",{"name":"contains","hash":{},"data":data}),{"name":"if","hash":{},"fn":this.program(4, data, 0),"inverse":this.noop,"data":data})) != null ? stack1 : "")
    + ((stack1 = helpers['if'].call(depth0,(helpers.contains || (depth0 && depth0.contains) || alias1).call(depth0,((stack1 = ((stack1 = ((stack1 = (depth0 != null ? depth0.security : depth0)) != null ? stack1['OAuth 2.0'] : stack1)) != null ? stack1.settings : stack1)) != null ? stack1.authorizationGrants : stack1),"owner",{"name":"contains","hash":{},"data":data}),{"name":"if","hash":{},"fn":this.program(6, data, 0),"inverse":this.noop,"data":data})) != null ? stack1 : "")
    + ((stack1 = helpers['if'].call(depth0,(helpers.contains || (depth0 && depth0.contains) || alias1).call(depth0,((stack1 = ((stack1 = ((stack1 = (depth0 != null ? depth0.security : depth0)) != null ? stack1['OAuth 2.0'] : stack1)) != null ? stack1.settings : stack1)) != null ? stack1.authorizationGrants : stack1),"credentials",{"name":"contains","hash":{},"data":data}),{"name":"if","hash":{},"fn":this.program(8, data, 0),"inverse":this.noop,"data":data})) != null ? stack1 : "")
    + "##### Access Tokens\n\nAccess token instances can be manually re-created. This is critical for access token reuse, such as saving credentials to a database for reusing later in the codebase.\n\n```js\nvar token = auth.createToken('access token', 'refresh token');\n```\n\nAn access token instance (manually created or automatically generated by a `getToken()` method) can be passed into any API request. This will sign the API request with the current users access token credentials.\n\n```js\n// Existing API client instance.\nclient.resource('/').get(null, {\n  user: token\n});\n\n// New API client instance.\nvar client = new "
    + alias2((helpers.pascalCase || (depth0 && depth0.pascalCase) || alias1).call(depth0,(depth0 != null ? depth0.title : depth0),{"name":"pascalCase","hash":{},"data":data}))
    + "({\n  user: token\n});\n```\n\n";
},"2":function(depth0,helpers,partials,data) {
    return "##### [Authorization Code Grant](https://github.com/mulesoft/js-client-oauth2#authorization-code-grant)\n\n1. Redirect user to `auth.code.getUri()`.\n2. Parse response uri and get an access token instance using `auth.code.getToken(uri)`.\n\n";
},"4":function(depth0,helpers,partials,data) {
    return "\n##### [Implicit Grant](https://github.com/mulesoft/js-client-oauth2#implicit-grant)\n\n1. Redirect user to `auth.token.getUri()` in a browser.\n2. Parse response uri and get an access token instance using `auth.token.getToken(uri)`.\n\n";
},"6":function(depth0,helpers,partials,data) {
    return "\n##### [Resource Owner Password Credentials Grant](https://github.com/mulesoft/js-client-oauth2#resource-owner-password-credentials-grant)\n\n1. Make a direct request for the access token on behalf of the user using `auth.owner.getToken(username, password)`.\n\n";
},"8":function(depth0,helpers,partials,data) {
    return "\n##### [Client Credentials Grant](https://github.com/mulesoft/js-client-oauth2#client-credentials-grant)\n\n1. Get the access token for the application by using `auth.credentials.getToken()`.\n\n";
},"10":function(depth0,helpers,partials,data) {
    var helper;

  return this.escapeExpression(((helper = (helper = helpers.version || (depth0 != null ? depth0.version : depth0)) != null ? helper : helpers.helperMissing),(typeof helper === "function" ? helper.call(depth0,{"name":"version","hash":{},"data":data}) : helper)));
},"12":function(depth0,helpers,partials,data) {
    return "v3";
},"14":function(depth0,helpers,partials,data) {
    var stack1;

  return ((stack1 = helpers['if'].call(depth0,(helpers.keys || (depth0 && depth0.keys) || helpers.helperMissing).call(depth0,(depth0 != null ? depth0.methods : depth0),{"name":"keys","hash":{},"data":data}),{"name":"if","hash":{},"fn":this.program(15, data, 0),"inverse":this.noop,"data":data})) != null ? stack1 : "");
},"15":function(depth0,helpers,partials,data) {
    var stack1, alias1=helpers.helperMissing;

  return "#### "
    + ((stack1 = (helpers.requestSnippet || (depth0 && depth0.requestSnippet) || alias1).call(depth0,depth0,{"name":"requestSnippet","hash":{},"data":data})) != null ? stack1 : "")
    + "\n\n"
    + ((stack1 = helpers['if'].call(depth0,(depth0 != null ? depth0.uriParameters : depth0),{"name":"if","hash":{},"fn":this.program(16, data, 0),"inverse":this.noop,"data":data})) != null ? stack1 : "")
    + ((stack1 = helpers['if'].call(depth0,(depth0 != null ? depth0.description : depth0),{"name":"if","hash":{},"fn":this.program(18, data, 0),"inverse":this.noop,"data":data})) != null ? stack1 : "")
    + "```js\nvar resource = client."
    + ((stack1 = (helpers.requestSnippet || (depth0 && depth0.requestSnippet) || alias1).call(depth0,depth0,{"name":"requestSnippet","hash":{},"data":data})) != null ? stack1 : "")
    + ";\n```\n\n"
    + ((stack1 = helpers.each.call(depth0,(depth0 != null ? depth0.methods : depth0),{"name":"each","hash":{},"fn":this.program(20, data, 0),"inverse":this.noop,"data":data})) != null ? stack1 : "");
},"16":function(depth0,helpers,partials,data) {
    var stack1;

  return ((stack1 = (helpers.parametersSnippet || (depth0 && depth0.parametersSnippet) || helpers.helperMissing).call(depth0,(depth0 != null ? depth0.uriParameters : depth0),{"name":"parametersSnippet","hash":{},"data":data})) != null ? stack1 : "")
    + "\n\n";
},"18":function(depth0,helpers,partials,data) {
    var stack1, helper;

  return ((stack1 = ((helper = (helper = helpers.description || (depth0 != null ? depth0.description : depth0)) != null ? helper : helpers.helperMissing),(typeof helper === "function" ? helper.call(depth0,{"name":"description","hash":{},"data":data}) : helper))) != null ? stack1 : "")
    + "\n\n";
},"20":function(depth0,helpers,partials,data) {
    var stack1, helper, alias1=helpers.helperMissing, alias2=this.escapeExpression;

  return "##### "
    + alias2((helpers.upperCase || (depth0 && depth0.upperCase) || alias1).call(depth0,(depth0 != null ? depth0.method : depth0),{"name":"upperCase","hash":{},"data":data}))
    + "\n\n"
    + ((stack1 = helpers['if'].call(depth0,(depth0 != null ? depth0.description : depth0),{"name":"if","hash":{},"fn":this.program(18, data, 0),"inverse":this.noop,"data":data})) != null ? stack1 : "")
    + "```js\nresource."
    + alias2(((helper = (helper = helpers.key || (depth0 != null ? depth0.key : depth0)) != null ? helper : alias1),(typeof helper === "function" ? helper.call(depth0,{"name":"key","hash":{},"data":data}) : helper)))
    + "().then(function (res) { ... });\n```\n\n"
    + ((stack1 = helpers['if'].call(depth0,(helpers.keys || (depth0 && depth0.keys) || alias1).call(depth0,(depth0 != null ? depth0.queryParameters : depth0),{"name":"keys","hash":{},"data":data}),{"name":"if","hash":{},"fn":this.program(21, data, 0),"inverse":this.noop,"data":data})) != null ? stack1 : "")
    + ((stack1 = helpers['if'].call(depth0,(helpers.keys || (depth0 && depth0.keys) || alias1).call(depth0,(depth0 != null ? depth0.headers : depth0),{"name":"keys","hash":{},"data":data}),{"name":"if","hash":{},"fn":this.program(26, data, 0),"inverse":this.noop,"data":data})) != null ? stack1 : "")
    + ((stack1 = helpers['if'].call(depth0,(helpers.keys || (depth0 && depth0.keys) || alias1).call(depth0,(depth0 != null ? depth0.body : depth0),{"name":"keys","hash":{},"data":data}),{"name":"if","hash":{},"fn":this.program(28, data, 0),"inverse":this.noop,"data":data})) != null ? stack1 : "");
},"21":function(depth0,helpers,partials,data) {
    var stack1, alias1=helpers.helperMissing;

  return "##### Query Parameters\n\n```javascript\n"
    + ((stack1 = helpers['if'].call(depth0,(helpers.equal || (depth0 && depth0.equal) || alias1).call(depth0,(depth0 != null ? depth0.method : depth0),"get",{"name":"equal","hash":{},"data":data}),{"name":"if","hash":{},"fn":this.program(22, data, 0),"inverse":this.program(24, data, 0),"data":data})) != null ? stack1 : "")
    + "```\n\n"
    + ((stack1 = (helpers.parametersSnippet || (depth0 && depth0.parametersSnippet) || alias1).call(depth0,(depth0 != null ? depth0.queryParameters : depth0),{"name":"parametersSnippet","hash":{},"data":data})) != null ? stack1 : "")
    + "\n\n";
},"22":function(depth0,helpers,partials,data) {
    var helper;

  return "resource."
    + this.escapeExpression(((helper = (helper = helpers.key || (depth0 != null ? depth0.key : depth0)) != null ? helper : helpers.helperMissing),(typeof helper === "function" ? helper.call(depth0,{"name":"key","hash":{},"data":data}) : helper)))
    + "({ ... });\n";
},"24":function(depth0,helpers,partials,data) {
    var helper;

  return "resource."
    + this.escapeExpression(((helper = (helper = helpers.key || (depth0 != null ? depth0.key : depth0)) != null ? helper : helpers.helperMissing),(typeof helper === "function" ? helper.call(depth0,{"name":"key","hash":{},"data":data}) : helper)))
    + "(null, { query: { ... } });\n";
},"26":function(depth0,helpers,partials,data) {
    var stack1, helper, alias1=helpers.helperMissing;

  return "##### Headers\n\n```javascript\nresource."
    + this.escapeExpression(((helper = (helper = helpers.key || (depth0 != null ? depth0.key : depth0)) != null ? helper : alias1),(typeof helper === "function" ? helper.call(depth0,{"name":"key","hash":{},"data":data}) : helper)))
    + "(null, {\n  headers: { ... }\n});\n```\n\n"
    + ((stack1 = (helpers.parametersSnippet || (depth0 && depth0.parametersSnippet) || alias1).call(depth0,(depth0 != null ? depth0.headers : depth0),{"name":"parametersSnippet","hash":{},"data":data})) != null ? stack1 : "")
    + "\n\n";
},"28":function(depth0,helpers,partials,data) {
    var stack1;

  return "##### Body\n\n"
    + ((stack1 = helpers.each.call(depth0,(depth0 != null ? depth0.body : depth0),{"name":"each","hash":{},"fn":this.program(29, data, 0),"inverse":this.noop,"data":data})) != null ? stack1 : "");
},"29":function(depth0,helpers,partials,data) {
    var stack1, helper;

  return "**"
    + this.escapeExpression(((helper = (helper = helpers.key || (data && data.key)) != null ? helper : helpers.helperMissing),(typeof helper === "function" ? helper.call(depth0,{"name":"key","hash":{},"data":data}) : helper)))
    + "**\n\n"
    + ((stack1 = helpers['if'].call(depth0,(depth0 != null ? depth0.schema : depth0),{"name":"if","hash":{},"fn":this.program(30, data, 0),"inverse":this.noop,"data":data})) != null ? stack1 : "")
    + ((stack1 = helpers['if'].call(depth0,(depth0 != null ? depth0.formParameters : depth0),{"name":"if","hash":{},"fn":this.program(32, data, 0),"inverse":this.noop,"data":data})) != null ? stack1 : "");
},"30":function(depth0,helpers,partials,data) {
    var stack1, helper;

  return "```\n"
    + ((stack1 = ((helper = (helper = helpers.schema || (depth0 != null ? depth0.schema : depth0)) != null ? helper : helpers.helperMissing),(typeof helper === "function" ? helper.call(depth0,{"name":"schema","hash":{},"data":data}) : helper))) != null ? stack1 : "")
    + "\n```\n\n";
},"32":function(depth0,helpers,partials,data) {
    var stack1;

  return ((stack1 = (helpers.json || (depth0 && depth0.json) || helpers.helperMissing).call(depth0,(depth0 != null ? depth0.formParameters : depth0),2,{"name":"json","hash":{},"data":data})) != null ? stack1 : "")
    + "\n\n";
},"compiler":[6,">= 2.0.0-beta.1"],"main":function(depth0,helpers,partials,data) {
    var stack1, helper, alias1=helpers.helperMissing, alias2="function", alias3=this.escapeExpression;

  return "# "
    + alias3(((helper = (helper = helpers.title || (depth0 != null ? depth0.title : depth0)) != null ? helper : alias1),(typeof helper === alias2 ? helper.call(depth0,{"name":"title","hash":{},"data":data}) : helper)))
    + "\n\nBrowser and node module for making API requests against ["
    + alias3(((helper = (helper = helpers.title || (depth0 != null ? depth0.title : depth0)) != null ? helper : alias1),(typeof helper === alias2 ? helper.call(depth0,{"name":"title","hash":{},"data":data}) : helper)))
    + "]("
    + alias3(((helper = (helper = helpers.baseUri || (depth0 != null ? depth0.baseUri : depth0)) != null ? helper : alias1),(typeof helper === alias2 ? helper.call(depth0,{"name":"baseUri","hash":{},"data":data}) : helper)))
    + ").\n\n**Please note: This module uses [Popsicle](https://github.com/blakeembrey/popsicle) to make API requests. Promises must be supported or polyfilled on all target environments.**\n\n## Installation\n\n```\nnpm install "
    + alias3((helpers.paramCase || (depth0 && depth0.paramCase) || alias1).call(depth0,(depth0 != null ? depth0.title : depth0),{"name":"paramCase","hash":{},"data":data}))
    + " --save\nbower install "
    + alias3((helpers.paramCase || (depth0 && depth0.paramCase) || alias1).call(depth0,(depth0 != null ? depth0.title : depth0),{"name":"paramCase","hash":{},"data":data}))
    + " --save\n```\n\n## Usage\n\n### Node\n\n```javascript\nvar "
    + alias3((helpers.pascalCase || (depth0 && depth0.pascalCase) || alias1).call(depth0,(depth0 != null ? depth0.title : depth0),{"name":"pascalCase","hash":{},"data":data}))
    + " = require('"
    + alias3((helpers.paramCase || (depth0 && depth0.paramCase) || alias1).call(depth0,(depth0 != null ? depth0.title : depth0),{"name":"paramCase","hash":{},"data":data}))
    + "');\n\nvar client = new "
    + alias3((helpers.pascalCase || (depth0 && depth0.pascalCase) || alias1).call(depth0,(depth0 != null ? depth0.title : depth0),{"name":"pascalCase","hash":{},"data":data}))
    + "();\n```\n\n### Browsers\n\n```html\n<script src=\""
    + alias3((helpers.paramCase || (depth0 && depth0.paramCase) || alias1).call(depth0,(depth0 != null ? depth0.title : depth0),{"name":"paramCase","hash":{},"data":data}))
    + "/index.js\">\n\n<script>\n  var client = new window."
    + alias3((helpers.pascalCase || (depth0 && depth0.pascalCase) || alias1).call(depth0,(depth0 != null ? depth0.title : depth0),{"name":"pascalCase","hash":{},"data":data}))
    + "();\n</script>\n```\n\n"
    + ((stack1 = helpers['if'].call(depth0,((stack1 = (depth0 != null ? depth0.security : depth0)) != null ? stack1['OAuth 2.0'] : stack1),{"name":"if","hash":{},"fn":this.program(1, data, 0),"inverse":this.noop,"data":data})) != null ? stack1 : "")
    + "### Options\n\nYou can set options when you initialize a client or at any time with the `options` property. You may also override options for a single request by passing an object as the second argument of any request method. For example:\n\n```javascript\nvar client = new "
    + alias3((helpers.pascalCase || (depth0 && depth0.pascalCase) || alias1).call(depth0,(depth0 != null ? depth0.title : depth0),{"name":"pascalCase","hash":{},"data":data}))
    + "({ ... });\n\nclient.options = { ... };\n\nclient.resource('/').get(null, {\n  baseUri: 'http://example.com',\n  headers: {\n    'Content-Type': 'application/json'\n  }\n});\n```\n\n#### Base URI\n\nYou can override the base URI by setting the `baseUri` property, or initializing a client with a base URI. For example:\n\n```javascript\nnew "
    + alias3((helpers.pascalCase || (depth0 && depth0.pascalCase) || alias1).call(depth0,(depth0 != null ? depth0.title : depth0),{"name":"pascalCase","hash":{},"data":data}))
    + "({\n  baseUri: 'https://example.com'\n});\n```\n\n#### Base URI Parameters\n\nIf the base URI has parameters inline, you can set them by updating the `baseUriParameters` property. For example:\n\n```javascript\nclient.options.baseUriParameters.version = '"
    + ((stack1 = helpers['if'].call(depth0,(depth0 != null ? depth0.version : depth0),{"name":"if","hash":{},"fn":this.program(10, data, 0),"inverse":this.program(12, data, 0),"data":data})) != null ? stack1 : "")
    + "';\n```\n\n### Resources\n\nAll methods return a HTTP request instance of [Popsicle](https://github.com/blakeembrey/popsicle), which allows the use of promises (and streaming in node).\n\n"
    + ((stack1 = helpers.each.call(depth0,(depth0 != null ? depth0.allResources : depth0),{"name":"each","hash":{},"fn":this.program(14, data, 0),"inverse":this.noop,"data":data})) != null ? stack1 : "")
    + "\n\n### Custom Resources\n\nYou can make requests to a custom path in the API using the `#resource(path)` method.\n\n```javascript\nclient.resource('/example/path').get();\n```\n\n## License\n\nApache 2.0\n";
},"useData":true});

},{"hbsfy/runtime":41}],12:[function(require,module,exports){
// hbsfy compiled Handlebars template
var HandlebarsCompiler = require('hbsfy/runtime');
module.exports = HandlebarsCompiler.template({"1":function(depth0,helpers,partials,data) {
    var stack1;

  return ((stack1 = this.invokePartial(partials.utils,depth0,{"name":"utils","data":data,"helpers":helpers,"partials":partials})) != null ? stack1 : "")
    + "\n"
    + ((stack1 = this.invokePartial(partials.resources,depth0,{"name":"resources","data":data,"helpers":helpers,"partials":partials})) != null ? stack1 : "")
    + "\n"
    + ((stack1 = this.invokePartial(partials.client,depth0,{"name":"client","data":data,"helpers":helpers,"partials":partials})) != null ? stack1 : "")
    + "\n"
    + ((stack1 = this.invokePartial(partials.auth,depth0,{"name":"auth","data":data,"helpers":helpers,"partials":partials})) != null ? stack1 : "")
    + "\nreturn Client;\n";
},"compiler":[6,">= 2.0.0-beta.1"],"main":function(depth0,helpers,partials,data) {
    var stack1, alias1=helpers.helperMissing;

  return "(function (root, client) {\n  if (typeof define === 'function' && define.amd) {\n    // AMD. Register as an anonymous module.\n    define("
    + ((stack1 = (helpers.dependencies || (depth0 && depth0.dependencies) || alias1).call(depth0,depth0,"amd",{"name":"dependencies","hash":{},"data":data})) != null ? stack1 : "")
    + ", client);\n  } else if (typeof exports === 'object') {\n    // Node. Does not work with strict CommonJS, but only CommonJS-like\n    // environments that support `module.exports`, like Node.\n    module.exports = client("
    + ((stack1 = (helpers.dependencies || (depth0 && depth0.dependencies) || alias1).call(depth0,depth0,"node",{"name":"dependencies","hash":{},"data":data})) != null ? stack1 : "")
    + ");\n  } else {\n    // Browser globals (root is window).\n    root."
    + this.escapeExpression((helpers.pascalCase || (depth0 && depth0.pascalCase) || alias1).call(depth0,(depth0 != null ? depth0.title : depth0),{"name":"pascalCase","hash":{},"data":data}))
    + " = client("
    + ((stack1 = (helpers.dependencies || (depth0 && depth0.dependencies) || alias1).call(depth0,depth0,"browser",{"name":"dependencies","hash":{},"data":data})) != null ? stack1 : "")
    + ");\n  }\n})(this, function ("
    + ((stack1 = (helpers.dependencies || (depth0 && depth0.dependencies) || alias1).call(depth0,depth0,false,{"name":"dependencies","hash":{},"data":data})) != null ? stack1 : "")
    + ") {\n"
    + ((stack1 = (helpers.indent || (depth0 && depth0.indent) || alias1).call(depth0,2,{"name":"indent","hash":{},"fn":this.program(1, data, 0),"inverse":this.noop,"data":data})) != null ? stack1 : "")
    + "});\n";
},"usePartial":true,"useData":true});

},{"hbsfy/runtime":41}],13:[function(require,module,exports){
// hbsfy compiled Handlebars template
var HandlebarsCompiler = require('hbsfy/runtime');
module.exports = HandlebarsCompiler.template({"1":function(depth0,helpers,partials,data) {
    return "\"client-oauth2\": \"^0.1.0\",\n    ";
},"compiler":[6,">= 2.0.0-beta.1"],"main":function(depth0,helpers,partials,data) {
    var stack1, helper, alias1=helpers.helperMissing, alias2=this.escapeExpression;

  return "{\n  \"name\": \""
    + alias2((helpers.paramCase || (depth0 && depth0.paramCase) || alias1).call(depth0,(depth0 != null ? depth0.title : depth0),{"name":"paramCase","hash":{},"data":data}))
    + "\",\n  \"version\": \"0.0.0\",\n  \"description\": \""
    + alias2(((helper = (helper = helpers.description || (depth0 != null ? depth0.description : depth0)) != null ? helper : alias1),(typeof helper === "function" ? helper.call(depth0,{"name":"description","hash":{},"data":data}) : helper)))
    + "\",\n  \"main\": \"index.js\",\n  \"files\": [\n    \"index.js\"\n  ],\n  \"repository\": {\n    \"type\": \"git\",\n    \"url\": \"git://github.com/mulesoft/raml-client-generator.git\"\n  },\n  \"keywords\": [\n    \"raml-api\"\n  ],\n  \"author\": \"MuleSoft, Inc.\",\n  \"license\": \"Apache 2.0\",\n  \"bugs\": {\n    \"url\": \"https://github.com/mulesoft/raml-client-generator/issues\"\n  },\n  \"homepage\": \"https://github.com/mulesoft/raml-client-generator\",\n  \"dependencies\": {\n    "
    + ((stack1 = helpers['if'].call(depth0,((stack1 = (depth0 != null ? depth0.security : depth0)) != null ? stack1['OAuth 2.0'] : stack1),{"name":"if","hash":{},"fn":this.program(1, data, 0),"inverse":this.noop,"data":data})) != null ? stack1 : "")
    + "\"popsicle\": \"^0.3.6\"\n  }\n}\n";
},"useData":true});

},{"hbsfy/runtime":41}],14:[function(require,module,exports){
var extend             = require('extend');
var sanitizeUri        = require('./uri');
var sanitizeSecurity   = require('./security');
var sanitizeResources  = require('./resources');
var sanitizeParameters = require('./parameters');

/**
 * Track indexes of each generated id.
 *
 * @type {Object}
 */
var PARAM_IDS;

/**
 * Default formatting options.
 *
 * @type {Object}
 */
var DEFAULT_FORMAT = {
  /**
   * Replace with your preferred uri templating language.
   *
   * @param  {String} uri
   * @return {String}
   */
  uri: function (uri) {
    return uri;
  },
  /**
   * Variable formatting support. By default, we'll just throw an error.
   */
  variable: function () {
    throw new Error('No variable format specified');
  },
  /**
   * Generate unique ids each spec iteration.
   */
  uniqueId: function (prefix) {
    var id = ++PARAM_IDS[prefix] || (PARAM_IDS[prefix] = 0);

    return prefix + id;
  }
};

/**
 * Validate (and sanitize) the passed in spec object.
 *
 * @param  {Obejct} spec
 * @return {Obejct}
 */
var validateSpec = function (spec) {
  // Reset the id generations.
  PARAM_IDS = {};

  spec.format = extend({}, DEFAULT_FORMAT, spec.format);

  return extend({}, spec);
};

/**
 * Flatten the resources object tree into an array.
 *
 * @param  {Object} resources
 * @return {Array}
 */
var flattenResources = function (resources) {
  var array = [];

  // Recursively push all resources into a single flattened array.
  (function recurse (resource) {
    array.push(resource);

    Object.keys(resource.children).forEach(function (key) {
      recurse(resource.children[key]);
    });
  })(resources);

  return array;
};

/**
 * Flatten the resources object into an array of methods.
 *
 * @param  {Object} resources
 * @return {Array}
 */
var flattenMethods = function (resources) {
  var array = [];

  // Recursively push all methods into a single flattened array.
  (function recurse (resource) {
    if (resource.methods) {
      Object.keys(resource.methods).forEach(function (key) {
        array.push(resource.methods[key]);
      });
    }

    Object.keys(resource.children).forEach(function (key) {
      recurse(resource.children[key]);
    });
  })(resources);

  return array;
};

/**
 * Create a context object for the templates to use during compilation.
 *
 * @param  {Object} ast
 * @param  {Object} spec
 * @return {Object}
 */
module.exports = function (ast, spec) {
  // Validate the spec before using.
  spec = validateSpec(spec);

  // Create an empty context object.
  var context = {
    id:                spec.format.uniqueId('client'),
    title:             ast.title || 'API Client',
    version:           ast.version,
    baseUri:           sanitizeUri(ast.baseUri, spec),
    security:          sanitizeSecurity(ast.securitySchemes, spec),
    resources:         sanitizeResources(ast.resources, spec),
    baseUriParameters: sanitizeParameters(ast.baseUriParameters, spec)
  };

  context.allMethods       = flattenMethods(context.resources);
  context.allResources     = flattenResources(context.resources);
  context.supportedMethods = require('methods');

  return context;
};

},{"./parameters":16,"./resources":17,"./security":18,"./uri":19,"extend":33,"methods":47}],15:[function(require,module,exports){
var pick               = require('object.pick');
var sanitizeParameters = require('./parameters');

/**
 * Sanitize a method into a flatter, more readable structure.
 *
 * @param  {Object} method
 * @param  {Object} resource
 * @param  {Object} spec
 * @return {Object}
 */
var sanitizeMethod = function (method, resource, spec) {
  // Pick only the usable properties.
  var obj = pick(method, [
    'method',
    'protocols',
    'responses',
    'body',
    'headers'
  ]);

  // Attach a unique id to every method.
  obj.id              = spec.format.uniqueId('method');
  obj.resource        = resource;
  obj.queryParameters = sanitizeParameters(method.queryParameters);
  obj.description     = (method.description || '').trim();

  // TODO: Add `securedBy` support.
  // TODO: Automatically infer content-type header from body.

  return obj;
};

/**
 * Sanitize a methods array into a more reusable object.
 *
 * @param  {Array}  methods
 * @param  {Object} resource
 * @param  {Object} spec
 * @return {Object}
 */
module.exports = function (methods, resource, spec) {
  var obj = {};

  if (!methods) {
    return obj;
  }

  methods.forEach(function (method) {
    var key             = spec.format.variable(method.method);
    var sanitizedMethod = sanitizeMethod(method, resource, spec);

    obj[key] = sanitizedMethod;
    sanitizedMethod.key = key;
  });

  return obj;
};

},{"./parameters":16,"object.pick":48}],16:[function(require,module,exports){
var pick = require('object.pick');

/**
 * Sanitize the parameter into a more reusable object.
 *
 * @param  {Object} parameter
 * @return {Object}
 */
var sanitizeParameter = function (parameter) {
  var obj = pick(parameter, [
    'displayName',
    'type',
    'enum',
    'pattern',
    'minLength',
    'maxLength',
    'minimum',
    'maximum',
    'example',
    'repeat',
    'required',
    'default'
  ]);

  obj.description = (parameter.description || '').trim();

  // Automatically set the default parameter from the enum value.
  if (obj.default == null && Array.isArray(obj.enum)) {
    obj.default = obj.enum[0];
  }

  return obj;
};

/**
 * Sanitize parameters into something more consumable.
 *
 * @param  {Object} parameters
 * @return {Object}
 */
module.exports = function (parameters) {
  var obj = {};

  if (!parameters) {
    return obj;
  }

  // Iterate over every parameter and generate a new parameters object.
  Object.keys(parameters).forEach(function (key) {
    obj[key] = sanitizeParameter(parameters[key]);
  });

  return obj;
};

},{"object.pick":48}],17:[function(require,module,exports){
var sanitizeUri        = require('./uri');
var sanitizeMethods    = require('./methods');
var sanitizeParameters = require('./parameters');

/**
 * Match template tags in a string.
 *
 * @type {RegExp}
 */
var TEMPLATE_REGEXP = /\{[^\{\}]+\}/g;

/**
 * Convert a URI parameter into a variable name.
 *
 * @param  {String} uri
 * @param  {Object} spec
 * @return {String}
 */
var toPropertyFormat = function (uri, spec) {
  // Replace the prefixed path segment.
  uri = uri.replace(/^[\.\/]/, '');

  // Handle a only a single parameter. E.g. "/{param}".
  if (/^\{[^\{\}]+\}$/.test(uri)) {
    return spec.format.variable(uri.slice(1, -1));
  }

  // Handle static text with trailing parameters. E.g. "/string{id}".
  if (/^[^\{\}]+(?:\{[^\{\}]+\})*$/.test(uri)) {
    return spec.format.variable(uri.replace(/\{.+\}$/, ''));
  }
};

/**
 * Convert the uri to the language replacement format.
 *
 * @param  {String} uri
 * @param  {Object} spec
 * @return {String}
 */
var toUriFormat = function (uri, spec) {
  var index = 0;

  // Index the template parameters instead of having unique names. This
  // saves a minor amount of space and makes processing *a lot* easier.
  var indexedUri = uri.replace(/\{[^\{\}]+\}/g, function () {
    return '{' + (index++) + '}';
  });

  return sanitizeUri(indexedUri, spec);
};

/**
 * Attach the current resource to the object structure.
 *
 * @param {Object} obj
 * @param {Object} resource
 * @param {Object} spec
 */
var attachResource = function (obj, resource, spec) {
  // Split the relative uri into the valid parts. This includes special-case
  // handling for the `mediaTypeExtension` parameter according to the spec.
  var uriParts = resource.relativeUri.split(
    /(?=\.|\/|\{mediaTypeExtension\}$)/
  );

  // Sanitize the uri parameters before extracting.
  var parameters = sanitizeParameters(resource.uriParameters);

  /**
   * Return the parameter from the parameters object based on the passed in tag.
   *
   * @param  {String} param
   * @return {Object}
   */
  var getParamTag = function (param) {
    return parameters[param.slice(1, -1)];
  };

  // Iterate over each of the uri parts and nest on the root object.
  (function recurse (obj, parts) {
    var part = parts[0];

    // Add a period to the beginning of the manual media type extension.
    if (part === '{mediaTypeExtension}' && parts.length === 1) {
      if (Array.isArray(parameters.mediaTypeExtension.enum)) {
        parameters.mediaTypeExtension.enum.forEach(function (extension) {
          extension = '.' + extension.replace(/^\./, '');

          return recurse(obj, [extension]);
        });
      }

      // Remove the media type enum from documentation purposes.
      delete parameters.mediaTypeExtension.enum;

      part = '.{mediaTypeExtension}';
    }

    // Recursively create (or select) the child resource. If the resource is
    // a single slash, it should be attached to the same object.
    if (part !== '/') {
      // Convert the uri part into a variable name.
      var key = toPropertyFormat(part, spec);

      // TODO: Handle duplicate variable names and missing variable names.
      if (!key || obj.children.hasOwnProperty(key)) {
        // Handle exact matching relative uris. If they don't match exactly,
        // it's impossible for us to handle generically.
        if (part === obj.children[key].relativeUri) {
          obj = obj.children[key];
        } else {
          return;
        }
      } else {
        var matches       = part.match(TEMPLATE_REGEXP) || [];
        var uriParameters = Array.prototype.map.call(matches, getParamTag);

        obj = obj.children[key] = {
          id:            spec.format.uniqueId('resource'),
          key:           key,
          parent:        obj,
          children:      {},
          relativeUri:   toUriFormat(part, spec),
          uriParameters: uriParameters
        };
      }
    }

    // Recursively append uri parts.
    if (parts.length > 1) {
      return recurse(obj, parts.slice(1));
    }

    obj.methods     = sanitizeMethods(resource.methods, obj, spec);
    obj.description = (resource.description || '').trim();

    if (resource.resources) {
      resource.resources.forEach(function (resource) {
        attachResource(obj, resource, spec);
      });
    }

    // TODO: Implement node backtracking when no methods are available.

    return obj;
  })(obj, uriParts);
};

/**
 * Sanitize resources into nested object form.
 *
 * @param  {Object} resources
 * @param  {Object} spec
 * @return {Object}
 */
module.exports = function (resources, spec) {
  // Create the root resource object for consistency of behaviour.
  var obj = {
    id:            spec.format.uniqueId('resource'),
    children:      {},
    relativeUri:   '',
    uriParameters: []
  };

  if (!resources) {
    return obj;
  }

  // Iterate over the resources array and attach each .
  resources.forEach(function (resource) {
    return attachResource(obj, resource, spec);
  });

  return obj;
};

},{"./methods":15,"./parameters":16,"./uri":19}],18:[function(require,module,exports){
/**
 * Sanitize resources into nested object form.
 *
 * @param  {Object} securitySchemes
 * @return {Object}
 */
module.exports = function (securitySchemes) {
  var obj = {};

  if (!Array.isArray(securitySchemes)) {
    return obj;
  }

  securitySchemes.forEach(function (schemes) {
    Object.keys(schemes).forEach(function (key) {
      var scheme = schemes[key];

      obj[scheme.type] = scheme;
    });
  });

  return obj;
};

},{}],19:[function(require,module,exports){
/**
 * Sanitize all uris.
 *
 * @param  {String} uri
 * @param  {Object} spec
 * @return {String}
 */
module.exports = function (uri, spec) {
  return spec.format.uri(uri || '').replace(/\/+$/, '');
};

},{}],20:[function(require,module,exports){
var extend        = require('extend');
var helpers       = require('./helpers');
var createContext = require('./context');

// Handlebars required in node to support `require('x.hbs')`.
require('handlebars');

/**
 * Compile an api client using a combination of the ast, spec and user data.
 *
 * @param  {Object} ast
 * @param  {Object} spec
 * @param  {Object} data
 * @return {Object}
 */
function generate (ast, spec, data) {
  // Handlebars compile options from the specification.
  var options = {
    data:     data,
    helpers:  extend({}, helpers, spec.helpers),
    partials: extend({}, spec.partials)
  };

  // Allow the language to override the file generator.
  var createFiles = spec.files || generateFiles;
  var context = createContext(ast, spec);
  var files = createFiles(spec.templates, context, options);

  // Create the compile object. We resolve this object instead of just the
  // files so that external utilities have access to the context object. For
  // example, the "API Notebook" project needs to add runtime documentation.
  return {
    files: files,
    context: context,
    options: options
  };
}

/**
 * Default file generator directly from templates.
 *
 * @param  {Object} templates
 * @param  {Object} context
 * @param  {Object} options
 * @return {Object}
 */
function generateFiles (templates, context, options) {
  var files = {};

  Object.keys(templates).forEach(function (key) {
    files[key] = templates[key](context, options);
  });

  return files;
}

/**
 * Generate a language specific client generator based on passed in spec.
 *
 * @param  {Object}   spec
 * @return {Function}
 */
module.exports = function (spec) {
  /**
   * Generate an API client by passed in an AST.
   *
   * @param  {Object} ast
   * @param  {Object} options
   * @return {Object}
   */
  return function (ast, options) {
    return generate(ast, spec, options);
  };
};

},{"./context":14,"./helpers":21,"extend":33,"handlebars":22}],21:[function(require,module,exports){
var indent = require('indent-string');
var trim   = String.prototype.trim;
var hasOwn = Object.prototype.hasOwnProperty;

/**
 * Case sanitization support.
 */
exports.camelCase    = require('camel-case');
exports.pascalCase   = require('pascal-case');
exports.constantCase = require('constant-case');
exports.paramCase    = require('param-case');
exports.lowerCase    = require('lower-case');
exports.upperCase    = require('upper-case');
exports.snakeCase    = require('snake-case');

/**
 * Formatting utilities.
 */
exports.indent = function (/* input, count, character, opts */) {
  var args      = Array.prototype.slice.call(arguments);
  var opts      = args.pop();
  var input     = (opts.fn ? opts.fn(this) : args[0]);
  var count     = (opts.fn ? args[0] : args[1]) || 2;
  var character = (opts.fn ? args[1] : args[2]) || ' ';

  return indent(input, character, count);
};

/**
 * The `||` conditional as a helper.
 *
 * @return {Boolean}
 */
exports.or = function (/* ...condition, opts */) {
  for (var i = 0; i < arguments.length - 1; i++) {
    if (arguments[i]) {
      return true;
    }
  }

  return false;
};

/**
 * The `&&` conditional as a helper.
 *
 * @return {Boolean}
 */
exports.and = function (/* ...condition, opts */) {
  for (var i = 0; i < arguments.length - 1; i++) {
    if (!arguments[i]) {
      return false;
    }
  }

  return true;
};

/**
 * The `!` conditional as a helper.
 *
 * @return {Boolean}
 */
exports.not = function (condition) {
  return !condition;
};

/**
 * Get the keys of an object.
 */
exports.keys = function (obj) {
  var keys = [];

  for (var prop in obj) {
    if (hasOwn.call(obj, prop)) {
      keys.push(prop);
    }
  }

  return keys;
};

/**
 * Return all the nested by the name.
 *
 * @param  {Object} obj
 * @param  {String} name
 * @return {Array}
 */
exports.pluck = function (obj, name) {
  return Object.keys(obj).map(function (key) {
    return obj[key] && obj[key][name];
  });
};

/**
 * Turn an array of keys into an object.
 *
 * @param  {Array}  keys
 * @param  {Array}  values
 * @return {Object}
 */
exports.object = function (keys, values) {
  var obj = {};

  for (var i = 0; i < keys.length; i++) {
    obj[keys[i]] = values[i];
  }

  return obj;
};

/**
 * Check whether a value is contained within an array.
 *
 * @param  {Array}   array
 * @param  {*}       value
 * @return {Boolean}
 */
exports.contains = function (array, value) {
  return array.indexOf(value) > -1;
};

/**
 * Debugging.
 */
exports.log = function () {
  var opts = arguments[arguments.length - 1];

  if (opts.fn) {
    console.log(opts.fn(this));
  } else {
    console.log.apply(console, Array.prototype.slice.call(arguments, 0, -1));
  }
};

/**
 * Trim a string.
 *
 * @return {String}
 */
exports.trim = function () {
  var opts = arguments[arguments.length - 1];

  if (arguments.length > 1) {
    return trim.call(arguments[0] == null ? '' : arguments[0]);
  }

  return trim.call(opts.fn(this));
};

/**
 * Check that a number of arguments are equal.
 *
 * @return {Boolean}
 */
exports.equal = function () {
  var args = Array.prototype.slice.call(arguments, 0, -1);
  var opts = arguments[arguments.length - 1];

  for (var i = 1; i < args.length; i++) {
    if (args[i - 1] !== args[i]) {
      return opts.fn ? opts.inverse(this) : false;
    }
  }

  return opts.fn ? opts.fn(this) : true;
};

/**
 * Serialize as a JSON string.
 *
 * @return {String}
 */
exports.json = function () {
  if (arguments.length > 2) {
    return JSON.stringify(arguments[0], null, arguments[1]);
  }

  if (arguments.length === 2) {
    return JSON.stringify(arguments[0]);
  }

  throw new Error('Unsupported usage of json helper');
};

/**
 * Join an array of values together.
 *
 * @param  {Array}  array
 * @param  {String} value
 * @return {String}
 */
exports.join = function (array, value) {
  return Array.isArray(array) ? array.join(value) : array;
};

},{"camel-case":27,"constant-case":32,"indent-string":42,"lower-case":46,"param-case":53,"pascal-case":55,"snake-case":60,"upper-case":61}],22:[function(require,module,exports){

},{}],23:[function(require,module,exports){
/*!
 * The buffer module from node.js, for the browser.
 *
 * @author   Feross Aboukhadijeh <feross@feross.org> <http://feross.org>
 * @license  MIT
 */

var base64 = require('base64-js')
var ieee754 = require('ieee754')
var isArray = require('is-array')

exports.Buffer = Buffer
exports.SlowBuffer = SlowBuffer
exports.INSPECT_MAX_BYTES = 50
Buffer.poolSize = 8192 // not used by this implementation

var kMaxLength = 0x3fffffff
var rootParent = {}

/**
 * If `Buffer.TYPED_ARRAY_SUPPORT`:
 *   === true    Use Uint8Array implementation (fastest)
 *   === false   Use Object implementation (most compatible, even IE6)
 *
 * Browsers that support typed arrays are IE 10+, Firefox 4+, Chrome 7+, Safari 5.1+,
 * Opera 11.6+, iOS 4.2+.
 *
 * Note:
 *
 * - Implementation must support adding new properties to `Uint8Array` instances.
 *   Firefox 4-29 lacked support, fixed in Firefox 30+.
 *   See: https://bugzilla.mozilla.org/show_bug.cgi?id=695438.
 *
 *  - Chrome 9-10 is missing the `TypedArray.prototype.subarray` function.
 *
 *  - IE10 has a broken `TypedArray.prototype.subarray` function which returns arrays of
 *    incorrect length in some situations.
 *
 * We detect these buggy browsers and set `Buffer.TYPED_ARRAY_SUPPORT` to `false` so they will
 * get the Object implementation, which is slower but will work correctly.
 */
Buffer.TYPED_ARRAY_SUPPORT = (function () {
  try {
    var buf = new ArrayBuffer(0)
    var arr = new Uint8Array(buf)
    arr.foo = function () { return 42 }
    return arr.foo() === 42 && // typed array instances can be augmented
        typeof arr.subarray === 'function' && // chrome 9-10 lack `subarray`
        new Uint8Array(1).subarray(1, 1).byteLength === 0 // ie10 has broken `subarray`
  } catch (e) {
    return false
  }
})()

/**
 * Class: Buffer
 * =============
 *
 * The Buffer constructor returns instances of `Uint8Array` that are augmented
 * with function properties for all the node `Buffer` API functions. We use
 * `Uint8Array` so that square bracket notation works as expected -- it returns
 * a single octet.
 *
 * By augmenting the instances, we can avoid modifying the `Uint8Array`
 * prototype.
 */
function Buffer (subject, encoding, noZero) {
  if (!(this instanceof Buffer))
    return new Buffer(subject, encoding, noZero)

  var type = typeof subject

  // Find the length
  var length
  if (type === 'number') {
    length = +subject
  } else if (type === 'string') {
    length = Buffer.byteLength(subject, encoding)
  } else if (type === 'object' && subject !== null) { // assume object is array-like
    if (subject.type === 'Buffer' && isArray(subject.data))
      subject = subject.data
    length = +subject.length
  } else {
    throw new TypeError('must start with number, buffer, array or string')
  }

  if (length > kMaxLength)
    throw new RangeError('Attempt to allocate Buffer larger than maximum ' +
      'size: 0x' + kMaxLength.toString(16) + ' bytes')

  if (length < 0)
    length = 0
  else
    length >>>= 0 // Coerce to uint32.

  var self = this
  if (Buffer.TYPED_ARRAY_SUPPORT) {
    // Preferred: Return an augmented `Uint8Array` instance for best performance
    /*eslint-disable consistent-this */
    self = Buffer._augment(new Uint8Array(length))
    /*eslint-enable consistent-this */
  } else {
    // Fallback: Return THIS instance of Buffer (created by `new`)
    self.length = length
    self._isBuffer = true
  }

  var i
  if (Buffer.TYPED_ARRAY_SUPPORT && typeof subject.byteLength === 'number') {
    // Speed optimization -- use set if we're copying from a typed array
    self._set(subject)
  } else if (isArrayish(subject)) {
    // Treat array-ish objects as a byte array
    if (Buffer.isBuffer(subject)) {
      for (i = 0; i < length; i++)
        self[i] = subject.readUInt8(i)
    } else {
      for (i = 0; i < length; i++)
        self[i] = ((subject[i] % 256) + 256) % 256
    }
  } else if (type === 'string') {
    self.write(subject, 0, encoding)
  } else if (type === 'number' && !Buffer.TYPED_ARRAY_SUPPORT && !noZero) {
    for (i = 0; i < length; i++) {
      self[i] = 0
    }
  }

  if (length > 0 && length <= Buffer.poolSize)
    self.parent = rootParent

  return self
}

function SlowBuffer (subject, encoding, noZero) {
  if (!(this instanceof SlowBuffer))
    return new SlowBuffer(subject, encoding, noZero)

  var buf = new Buffer(subject, encoding, noZero)
  delete buf.parent
  return buf
}

Buffer.isBuffer = function (b) {
  return !!(b != null && b._isBuffer)
}

Buffer.compare = function (a, b) {
  if (!Buffer.isBuffer(a) || !Buffer.isBuffer(b))
    throw new TypeError('Arguments must be Buffers')

  if (a === b) return 0

  var x = a.length
  var y = b.length
  for (var i = 0, len = Math.min(x, y); i < len && a[i] === b[i]; i++) {}
  if (i !== len) {
    x = a[i]
    y = b[i]
  }
  if (x < y) return -1
  if (y < x) return 1
  return 0
}

Buffer.isEncoding = function (encoding) {
  switch (String(encoding).toLowerCase()) {
    case 'hex':
    case 'utf8':
    case 'utf-8':
    case 'ascii':
    case 'binary':
    case 'base64':
    case 'raw':
    case 'ucs2':
    case 'ucs-2':
    case 'utf16le':
    case 'utf-16le':
      return true
    default:
      return false
  }
}

Buffer.concat = function (list, totalLength) {
  if (!isArray(list)) throw new TypeError('Usage: Buffer.concat(list[, length])')

  if (list.length === 0) {
    return new Buffer(0)
  } else if (list.length === 1) {
    return list[0]
  }

  var i
  if (totalLength === undefined) {
    totalLength = 0
    for (i = 0; i < list.length; i++) {
      totalLength += list[i].length
    }
  }

  var buf = new Buffer(totalLength)
  var pos = 0
  for (i = 0; i < list.length; i++) {
    var item = list[i]
    item.copy(buf, pos)
    pos += item.length
  }
  return buf
}

Buffer.byteLength = function (str, encoding) {
  var ret
  str = str + ''
  switch (encoding || 'utf8') {
    case 'ascii':
    case 'binary':
    case 'raw':
      ret = str.length
      break
    case 'ucs2':
    case 'ucs-2':
    case 'utf16le':
    case 'utf-16le':
      ret = str.length * 2
      break
    case 'hex':
      ret = str.length >>> 1
      break
    case 'utf8':
    case 'utf-8':
      ret = utf8ToBytes(str).length
      break
    case 'base64':
      ret = base64ToBytes(str).length
      break
    default:
      ret = str.length
  }
  return ret
}

// pre-set for values that may exist in the future
Buffer.prototype.length = undefined
Buffer.prototype.parent = undefined

// toString(encoding, start=0, end=buffer.length)
Buffer.prototype.toString = function (encoding, start, end) {
  var loweredCase = false

  start = start >>> 0
  end = end === undefined || end === Infinity ? this.length : end >>> 0

  if (!encoding) encoding = 'utf8'
  if (start < 0) start = 0
  if (end > this.length) end = this.length
  if (end <= start) return ''

  while (true) {
    switch (encoding) {
      case 'hex':
        return hexSlice(this, start, end)

      case 'utf8':
      case 'utf-8':
        return utf8Slice(this, start, end)

      case 'ascii':
        return asciiSlice(this, start, end)

      case 'binary':
        return binarySlice(this, start, end)

      case 'base64':
        return base64Slice(this, start, end)

      case 'ucs2':
      case 'ucs-2':
      case 'utf16le':
      case 'utf-16le':
        return utf16leSlice(this, start, end)

      default:
        if (loweredCase)
          throw new TypeError('Unknown encoding: ' + encoding)
        encoding = (encoding + '').toLowerCase()
        loweredCase = true
    }
  }
}

Buffer.prototype.equals = function (b) {
  if (!Buffer.isBuffer(b)) throw new TypeError('Argument must be a Buffer')
  if (this === b) return true
  return Buffer.compare(this, b) === 0
}

Buffer.prototype.inspect = function () {
  var str = ''
  var max = exports.INSPECT_MAX_BYTES
  if (this.length > 0) {
    str = this.toString('hex', 0, max).match(/.{2}/g).join(' ')
    if (this.length > max)
      str += ' ... '
  }
  return '<Buffer ' + str + '>'
}

Buffer.prototype.compare = function (b) {
  if (!Buffer.isBuffer(b)) throw new TypeError('Argument must be a Buffer')
  if (this === b) return 0
  return Buffer.compare(this, b)
}

// `get` will be removed in Node 0.13+
Buffer.prototype.get = function (offset) {
  console.log('.get() is deprecated. Access using array indexes instead.')
  return this.readUInt8(offset)
}

// `set` will be removed in Node 0.13+
Buffer.prototype.set = function (v, offset) {
  console.log('.set() is deprecated. Access using array indexes instead.')
  return this.writeUInt8(v, offset)
}

function hexWrite (buf, string, offset, length) {
  offset = Number(offset) || 0
  var remaining = buf.length - offset
  if (!length) {
    length = remaining
  } else {
    length = Number(length)
    if (length > remaining) {
      length = remaining
    }
  }

  // must be an even number of digits
  var strLen = string.length
  if (strLen % 2 !== 0) throw new Error('Invalid hex string')

  if (length > strLen / 2) {
    length = strLen / 2
  }
  for (var i = 0; i < length; i++) {
    var byte = parseInt(string.substr(i * 2, 2), 16)
    if (isNaN(byte)) throw new Error('Invalid hex string')
    buf[offset + i] = byte
  }
  return i
}

function utf8Write (buf, string, offset, length) {
  var charsWritten = blitBuffer(utf8ToBytes(string, buf.length - offset), buf, offset, length)
  return charsWritten
}

function asciiWrite (buf, string, offset, length) {
  var charsWritten = blitBuffer(asciiToBytes(string), buf, offset, length)
  return charsWritten
}

function binaryWrite (buf, string, offset, length) {
  return asciiWrite(buf, string, offset, length)
}

function base64Write (buf, string, offset, length) {
  var charsWritten = blitBuffer(base64ToBytes(string), buf, offset, length)
  return charsWritten
}

function utf16leWrite (buf, string, offset, length) {
  var charsWritten = blitBuffer(utf16leToBytes(string, buf.length - offset), buf, offset, length)
  return charsWritten
}

Buffer.prototype.write = function (string, offset, length, encoding) {
  // Support both (string, offset, length, encoding)
  // and the legacy (string, encoding, offset, length)
  if (isFinite(offset)) {
    if (!isFinite(length)) {
      encoding = length
      length = undefined
    }
  } else {  // legacy
    var swap = encoding
    encoding = offset
    offset = length
    length = swap
  }

  offset = Number(offset) || 0

  if (length < 0 || offset < 0 || offset > this.length)
    throw new RangeError('attempt to write outside buffer bounds')

  var remaining = this.length - offset
  if (!length) {
    length = remaining
  } else {
    length = Number(length)
    if (length > remaining) {
      length = remaining
    }
  }
  encoding = String(encoding || 'utf8').toLowerCase()

  var ret
  switch (encoding) {
    case 'hex':
      ret = hexWrite(this, string, offset, length)
      break
    case 'utf8':
    case 'utf-8':
      ret = utf8Write(this, string, offset, length)
      break
    case 'ascii':
      ret = asciiWrite(this, string, offset, length)
      break
    case 'binary':
      ret = binaryWrite(this, string, offset, length)
      break
    case 'base64':
      ret = base64Write(this, string, offset, length)
      break
    case 'ucs2':
    case 'ucs-2':
    case 'utf16le':
    case 'utf-16le':
      ret = utf16leWrite(this, string, offset, length)
      break
    default:
      throw new TypeError('Unknown encoding: ' + encoding)
  }
  return ret
}

Buffer.prototype.toJSON = function () {
  return {
    type: 'Buffer',
    data: Array.prototype.slice.call(this._arr || this, 0)
  }
}

function base64Slice (buf, start, end) {
  if (start === 0 && end === buf.length) {
    return base64.fromByteArray(buf)
  } else {
    return base64.fromByteArray(buf.slice(start, end))
  }
}

function utf8Slice (buf, start, end) {
  var res = ''
  var tmp = ''
  end = Math.min(buf.length, end)

  for (var i = start; i < end; i++) {
    if (buf[i] <= 0x7F) {
      res += decodeUtf8Char(tmp) + String.fromCharCode(buf[i])
      tmp = ''
    } else {
      tmp += '%' + buf[i].toString(16)
    }
  }

  return res + decodeUtf8Char(tmp)
}

function asciiSlice (buf, start, end) {
  var ret = ''
  end = Math.min(buf.length, end)

  for (var i = start; i < end; i++) {
    ret += String.fromCharCode(buf[i] & 0x7F)
  }
  return ret
}

function binarySlice (buf, start, end) {
  var ret = ''
  end = Math.min(buf.length, end)

  for (var i = start; i < end; i++) {
    ret += String.fromCharCode(buf[i])
  }
  return ret
}

function hexSlice (buf, start, end) {
  var len = buf.length

  if (!start || start < 0) start = 0
  if (!end || end < 0 || end > len) end = len

  var out = ''
  for (var i = start; i < end; i++) {
    out += toHex(buf[i])
  }
  return out
}

function utf16leSlice (buf, start, end) {
  var bytes = buf.slice(start, end)
  var res = ''
  for (var i = 0; i < bytes.length; i += 2) {
    res += String.fromCharCode(bytes[i] + bytes[i + 1] * 256)
  }
  return res
}

Buffer.prototype.slice = function (start, end) {
  var len = this.length
  start = ~~start
  end = end === undefined ? len : ~~end

  if (start < 0) {
    start += len
    if (start < 0)
      start = 0
  } else if (start > len) {
    start = len
  }

  if (end < 0) {
    end += len
    if (end < 0)
      end = 0
  } else if (end > len) {
    end = len
  }

  if (end < start)
    end = start

  var newBuf
  if (Buffer.TYPED_ARRAY_SUPPORT) {
    newBuf = Buffer._augment(this.subarray(start, end))
  } else {
    var sliceLen = end - start
    newBuf = new Buffer(sliceLen, undefined, true)
    for (var i = 0; i < sliceLen; i++) {
      newBuf[i] = this[i + start]
    }
  }

  if (newBuf.length)
    newBuf.parent = this.parent || this

  return newBuf
}

/*
 * Need to make sure that buffer isn't trying to write out of bounds.
 */
function checkOffset (offset, ext, length) {
  if ((offset % 1) !== 0 || offset < 0)
    throw new RangeError('offset is not uint')
  if (offset + ext > length)
    throw new RangeError('Trying to access beyond buffer length')
}

Buffer.prototype.readUIntLE = function (offset, byteLength, noAssert) {
  offset = offset >>> 0
  byteLength = byteLength >>> 0
  if (!noAssert)
    checkOffset(offset, byteLength, this.length)

  var val = this[offset]
  var mul = 1
  var i = 0
  while (++i < byteLength && (mul *= 0x100))
    val += this[offset + i] * mul

  return val
}

Buffer.prototype.readUIntBE = function (offset, byteLength, noAssert) {
  offset = offset >>> 0
  byteLength = byteLength >>> 0
  if (!noAssert)
    checkOffset(offset, byteLength, this.length)

  var val = this[offset + --byteLength]
  var mul = 1
  while (byteLength > 0 && (mul *= 0x100))
    val += this[offset + --byteLength] * mul

  return val
}

Buffer.prototype.readUInt8 = function (offset, noAssert) {
  if (!noAssert)
    checkOffset(offset, 1, this.length)
  return this[offset]
}

Buffer.prototype.readUInt16LE = function (offset, noAssert) {
  if (!noAssert)
    checkOffset(offset, 2, this.length)
  return this[offset] | (this[offset + 1] << 8)
}

Buffer.prototype.readUInt16BE = function (offset, noAssert) {
  if (!noAssert)
    checkOffset(offset, 2, this.length)
  return (this[offset] << 8) | this[offset + 1]
}

Buffer.prototype.readUInt32LE = function (offset, noAssert) {
  if (!noAssert)
    checkOffset(offset, 4, this.length)

  return ((this[offset]) |
      (this[offset + 1] << 8) |
      (this[offset + 2] << 16)) +
      (this[offset + 3] * 0x1000000)
}

Buffer.prototype.readUInt32BE = function (offset, noAssert) {
  if (!noAssert)
    checkOffset(offset, 4, this.length)

  return (this[offset] * 0x1000000) +
      ((this[offset + 1] << 16) |
      (this[offset + 2] << 8) |
      this[offset + 3])
}

Buffer.prototype.readIntLE = function (offset, byteLength, noAssert) {
  offset = offset >>> 0
  byteLength = byteLength >>> 0
  if (!noAssert)
    checkOffset(offset, byteLength, this.length)

  var val = this[offset]
  var mul = 1
  var i = 0
  while (++i < byteLength && (mul *= 0x100))
    val += this[offset + i] * mul
  mul *= 0x80

  if (val >= mul)
    val -= Math.pow(2, 8 * byteLength)

  return val
}

Buffer.prototype.readIntBE = function (offset, byteLength, noAssert) {
  offset = offset >>> 0
  byteLength = byteLength >>> 0
  if (!noAssert)
    checkOffset(offset, byteLength, this.length)

  var i = byteLength
  var mul = 1
  var val = this[offset + --i]
  while (i > 0 && (mul *= 0x100))
    val += this[offset + --i] * mul
  mul *= 0x80

  if (val >= mul)
    val -= Math.pow(2, 8 * byteLength)

  return val
}

Buffer.prototype.readInt8 = function (offset, noAssert) {
  if (!noAssert)
    checkOffset(offset, 1, this.length)
  if (!(this[offset] & 0x80))
    return (this[offset])
  return ((0xff - this[offset] + 1) * -1)
}

Buffer.prototype.readInt16LE = function (offset, noAssert) {
  if (!noAssert)
    checkOffset(offset, 2, this.length)
  var val = this[offset] | (this[offset + 1] << 8)
  return (val & 0x8000) ? val | 0xFFFF0000 : val
}

Buffer.prototype.readInt16BE = function (offset, noAssert) {
  if (!noAssert)
    checkOffset(offset, 2, this.length)
  var val = this[offset + 1] | (this[offset] << 8)
  return (val & 0x8000) ? val | 0xFFFF0000 : val
}

Buffer.prototype.readInt32LE = function (offset, noAssert) {
  if (!noAssert)
    checkOffset(offset, 4, this.length)

  return (this[offset]) |
      (this[offset + 1] << 8) |
      (this[offset + 2] << 16) |
      (this[offset + 3] << 24)
}

Buffer.prototype.readInt32BE = function (offset, noAssert) {
  if (!noAssert)
    checkOffset(offset, 4, this.length)

  return (this[offset] << 24) |
      (this[offset + 1] << 16) |
      (this[offset + 2] << 8) |
      (this[offset + 3])
}

Buffer.prototype.readFloatLE = function (offset, noAssert) {
  if (!noAssert)
    checkOffset(offset, 4, this.length)
  return ieee754.read(this, offset, true, 23, 4)
}

Buffer.prototype.readFloatBE = function (offset, noAssert) {
  if (!noAssert)
    checkOffset(offset, 4, this.length)
  return ieee754.read(this, offset, false, 23, 4)
}

Buffer.prototype.readDoubleLE = function (offset, noAssert) {
  if (!noAssert)
    checkOffset(offset, 8, this.length)
  return ieee754.read(this, offset, true, 52, 8)
}

Buffer.prototype.readDoubleBE = function (offset, noAssert) {
  if (!noAssert)
    checkOffset(offset, 8, this.length)
  return ieee754.read(this, offset, false, 52, 8)
}

function checkInt (buf, value, offset, ext, max, min) {
  if (!Buffer.isBuffer(buf)) throw new TypeError('buffer must be a Buffer instance')
  if (value > max || value < min) throw new RangeError('value is out of bounds')
  if (offset + ext > buf.length) throw new RangeError('index out of range')
}

Buffer.prototype.writeUIntLE = function (value, offset, byteLength, noAssert) {
  value = +value
  offset = offset >>> 0
  byteLength = byteLength >>> 0
  if (!noAssert)
    checkInt(this, value, offset, byteLength, Math.pow(2, 8 * byteLength), 0)

  var mul = 1
  var i = 0
  this[offset] = value & 0xFF
  while (++i < byteLength && (mul *= 0x100))
    this[offset + i] = (value / mul) >>> 0 & 0xFF

  return offset + byteLength
}

Buffer.prototype.writeUIntBE = function (value, offset, byteLength, noAssert) {
  value = +value
  offset = offset >>> 0
  byteLength = byteLength >>> 0
  if (!noAssert)
    checkInt(this, value, offset, byteLength, Math.pow(2, 8 * byteLength), 0)

  var i = byteLength - 1
  var mul = 1
  this[offset + i] = value & 0xFF
  while (--i >= 0 && (mul *= 0x100))
    this[offset + i] = (value / mul) >>> 0 & 0xFF

  return offset + byteLength
}

Buffer.prototype.writeUInt8 = function (value, offset, noAssert) {
  value = +value
  offset = offset >>> 0
  if (!noAssert)
    checkInt(this, value, offset, 1, 0xff, 0)
  if (!Buffer.TYPED_ARRAY_SUPPORT) value = Math.floor(value)
  this[offset] = value
  return offset + 1
}

function objectWriteUInt16 (buf, value, offset, littleEndian) {
  if (value < 0) value = 0xffff + value + 1
  for (var i = 0, j = Math.min(buf.length - offset, 2); i < j; i++) {
    buf[offset + i] = (value & (0xff << (8 * (littleEndian ? i : 1 - i)))) >>>
      (littleEndian ? i : 1 - i) * 8
  }
}

Buffer.prototype.writeUInt16LE = function (value, offset, noAssert) {
  value = +value
  offset = offset >>> 0
  if (!noAssert)
    checkInt(this, value, offset, 2, 0xffff, 0)
  if (Buffer.TYPED_ARRAY_SUPPORT) {
    this[offset] = value
    this[offset + 1] = (value >>> 8)
  } else objectWriteUInt16(this, value, offset, true)
  return offset + 2
}

Buffer.prototype.writeUInt16BE = function (value, offset, noAssert) {
  value = +value
  offset = offset >>> 0
  if (!noAssert)
    checkInt(this, value, offset, 2, 0xffff, 0)
  if (Buffer.TYPED_ARRAY_SUPPORT) {
    this[offset] = (value >>> 8)
    this[offset + 1] = value
  } else objectWriteUInt16(this, value, offset, false)
  return offset + 2
}

function objectWriteUInt32 (buf, value, offset, littleEndian) {
  if (value < 0) value = 0xffffffff + value + 1
  for (var i = 0, j = Math.min(buf.length - offset, 4); i < j; i++) {
    buf[offset + i] = (value >>> (littleEndian ? i : 3 - i) * 8) & 0xff
  }
}

Buffer.prototype.writeUInt32LE = function (value, offset, noAssert) {
  value = +value
  offset = offset >>> 0
  if (!noAssert)
    checkInt(this, value, offset, 4, 0xffffffff, 0)
  if (Buffer.TYPED_ARRAY_SUPPORT) {
    this[offset + 3] = (value >>> 24)
    this[offset + 2] = (value >>> 16)
    this[offset + 1] = (value >>> 8)
    this[offset] = value
  } else objectWriteUInt32(this, value, offset, true)
  return offset + 4
}

Buffer.prototype.writeUInt32BE = function (value, offset, noAssert) {
  value = +value
  offset = offset >>> 0
  if (!noAssert)
    checkInt(this, value, offset, 4, 0xffffffff, 0)
  if (Buffer.TYPED_ARRAY_SUPPORT) {
    this[offset] = (value >>> 24)
    this[offset + 1] = (value >>> 16)
    this[offset + 2] = (value >>> 8)
    this[offset + 3] = value
  } else objectWriteUInt32(this, value, offset, false)
  return offset + 4
}

Buffer.prototype.writeIntLE = function (value, offset, byteLength, noAssert) {
  value = +value
  offset = offset >>> 0
  if (!noAssert) {
    checkInt(this,
             value,
             offset,
             byteLength,
             Math.pow(2, 8 * byteLength - 1) - 1,
             -Math.pow(2, 8 * byteLength - 1))
  }

  var i = 0
  var mul = 1
  var sub = value < 0 ? 1 : 0
  this[offset] = value & 0xFF
  while (++i < byteLength && (mul *= 0x100))
    this[offset + i] = ((value / mul) >> 0) - sub & 0xFF

  return offset + byteLength
}

Buffer.prototype.writeIntBE = function (value, offset, byteLength, noAssert) {
  value = +value
  offset = offset >>> 0
  if (!noAssert) {
    checkInt(this,
             value,
             offset,
             byteLength,
             Math.pow(2, 8 * byteLength - 1) - 1,
             -Math.pow(2, 8 * byteLength - 1))
  }

  var i = byteLength - 1
  var mul = 1
  var sub = value < 0 ? 1 : 0
  this[offset + i] = value & 0xFF
  while (--i >= 0 && (mul *= 0x100))
    this[offset + i] = ((value / mul) >> 0) - sub & 0xFF

  return offset + byteLength
}

Buffer.prototype.writeInt8 = function (value, offset, noAssert) {
  value = +value
  offset = offset >>> 0
  if (!noAssert)
    checkInt(this, value, offset, 1, 0x7f, -0x80)
  if (!Buffer.TYPED_ARRAY_SUPPORT) value = Math.floor(value)
  if (value < 0) value = 0xff + value + 1
  this[offset] = value
  return offset + 1
}

Buffer.prototype.writeInt16LE = function (value, offset, noAssert) {
  value = +value
  offset = offset >>> 0
  if (!noAssert)
    checkInt(this, value, offset, 2, 0x7fff, -0x8000)
  if (Buffer.TYPED_ARRAY_SUPPORT) {
    this[offset] = value
    this[offset + 1] = (value >>> 8)
  } else objectWriteUInt16(this, value, offset, true)
  return offset + 2
}

Buffer.prototype.writeInt16BE = function (value, offset, noAssert) {
  value = +value
  offset = offset >>> 0
  if (!noAssert)
    checkInt(this, value, offset, 2, 0x7fff, -0x8000)
  if (Buffer.TYPED_ARRAY_SUPPORT) {
    this[offset] = (value >>> 8)
    this[offset + 1] = value
  } else objectWriteUInt16(this, value, offset, false)
  return offset + 2
}

Buffer.prototype.writeInt32LE = function (value, offset, noAssert) {
  value = +value
  offset = offset >>> 0
  if (!noAssert)
    checkInt(this, value, offset, 4, 0x7fffffff, -0x80000000)
  if (Buffer.TYPED_ARRAY_SUPPORT) {
    this[offset] = value
    this[offset + 1] = (value >>> 8)
    this[offset + 2] = (value >>> 16)
    this[offset + 3] = (value >>> 24)
  } else objectWriteUInt32(this, value, offset, true)
  return offset + 4
}

Buffer.prototype.writeInt32BE = function (value, offset, noAssert) {
  value = +value
  offset = offset >>> 0
  if (!noAssert)
    checkInt(this, value, offset, 4, 0x7fffffff, -0x80000000)
  if (value < 0) value = 0xffffffff + value + 1
  if (Buffer.TYPED_ARRAY_SUPPORT) {
    this[offset] = (value >>> 24)
    this[offset + 1] = (value >>> 16)
    this[offset + 2] = (value >>> 8)
    this[offset + 3] = value
  } else objectWriteUInt32(this, value, offset, false)
  return offset + 4
}

function checkIEEE754 (buf, value, offset, ext, max, min) {
  if (value > max || value < min) throw new RangeError('value is out of bounds')
  if (offset + ext > buf.length) throw new RangeError('index out of range')
  if (offset < 0) throw new RangeError('index out of range')
}

function writeFloat (buf, value, offset, littleEndian, noAssert) {
  if (!noAssert)
    checkIEEE754(buf, value, offset, 4, 3.4028234663852886e+38, -3.4028234663852886e+38)
  ieee754.write(buf, value, offset, littleEndian, 23, 4)
  return offset + 4
}

Buffer.prototype.writeFloatLE = function (value, offset, noAssert) {
  return writeFloat(this, value, offset, true, noAssert)
}

Buffer.prototype.writeFloatBE = function (value, offset, noAssert) {
  return writeFloat(this, value, offset, false, noAssert)
}

function writeDouble (buf, value, offset, littleEndian, noAssert) {
  if (!noAssert)
    checkIEEE754(buf, value, offset, 8, 1.7976931348623157E+308, -1.7976931348623157E+308)
  ieee754.write(buf, value, offset, littleEndian, 52, 8)
  return offset + 8
}

Buffer.prototype.writeDoubleLE = function (value, offset, noAssert) {
  return writeDouble(this, value, offset, true, noAssert)
}

Buffer.prototype.writeDoubleBE = function (value, offset, noAssert) {
  return writeDouble(this, value, offset, false, noAssert)
}

// copy(targetBuffer, targetStart=0, sourceStart=0, sourceEnd=buffer.length)
Buffer.prototype.copy = function (target, target_start, start, end) {
  var self = this // source

  if (!start) start = 0
  if (!end && end !== 0) end = this.length
  if (target_start >= target.length) target_start = target.length
  if (!target_start) target_start = 0
  if (end > 0 && end < start) end = start

  // Copy 0 bytes; we're done
  if (end === start) return 0
  if (target.length === 0 || self.length === 0) return 0

  // Fatal error conditions
  if (target_start < 0)
    throw new RangeError('targetStart out of bounds')
  if (start < 0 || start >= self.length) throw new RangeError('sourceStart out of bounds')
  if (end < 0) throw new RangeError('sourceEnd out of bounds')

  // Are we oob?
  if (end > this.length)
    end = this.length
  if (target.length - target_start < end - start)
    end = target.length - target_start + start

  var len = end - start

  if (len < 1000 || !Buffer.TYPED_ARRAY_SUPPORT) {
    for (var i = 0; i < len; i++) {
      target[i + target_start] = this[i + start]
    }
  } else {
    target._set(this.subarray(start, start + len), target_start)
  }

  return len
}

// fill(value, start=0, end=buffer.length)
Buffer.prototype.fill = function (value, start, end) {
  if (!value) value = 0
  if (!start) start = 0
  if (!end) end = this.length

  if (end < start) throw new RangeError('end < start')

  // Fill 0 bytes; we're done
  if (end === start) return
  if (this.length === 0) return

  if (start < 0 || start >= this.length) throw new RangeError('start out of bounds')
  if (end < 0 || end > this.length) throw new RangeError('end out of bounds')

  var i
  if (typeof value === 'number') {
    for (i = start; i < end; i++) {
      this[i] = value
    }
  } else {
    var bytes = utf8ToBytes(value.toString())
    var len = bytes.length
    for (i = start; i < end; i++) {
      this[i] = bytes[i % len]
    }
  }

  return this
}

/**
 * Creates a new `ArrayBuffer` with the *copied* memory of the buffer instance.
 * Added in Node 0.12. Only available in browsers that support ArrayBuffer.
 */
Buffer.prototype.toArrayBuffer = function () {
  if (typeof Uint8Array !== 'undefined') {
    if (Buffer.TYPED_ARRAY_SUPPORT) {
      return (new Buffer(this)).buffer
    } else {
      var buf = new Uint8Array(this.length)
      for (var i = 0, len = buf.length; i < len; i += 1) {
        buf[i] = this[i]
      }
      return buf.buffer
    }
  } else {
    throw new TypeError('Buffer.toArrayBuffer not supported in this browser')
  }
}

// HELPER FUNCTIONS
// ================

var BP = Buffer.prototype

/**
 * Augment a Uint8Array *instance* (not the Uint8Array class!) with Buffer methods
 */
Buffer._augment = function (arr) {
  arr.constructor = Buffer
  arr._isBuffer = true

  // save reference to original Uint8Array get/set methods before overwriting
  arr._get = arr.get
  arr._set = arr.set

  // deprecated, will be removed in node 0.13+
  arr.get = BP.get
  arr.set = BP.set

  arr.write = BP.write
  arr.toString = BP.toString
  arr.toLocaleString = BP.toString
  arr.toJSON = BP.toJSON
  arr.equals = BP.equals
  arr.compare = BP.compare
  arr.copy = BP.copy
  arr.slice = BP.slice
  arr.readUIntLE = BP.readUIntLE
  arr.readUIntBE = BP.readUIntBE
  arr.readUInt8 = BP.readUInt8
  arr.readUInt16LE = BP.readUInt16LE
  arr.readUInt16BE = BP.readUInt16BE
  arr.readUInt32LE = BP.readUInt32LE
  arr.readUInt32BE = BP.readUInt32BE
  arr.readIntLE = BP.readIntLE
  arr.readIntBE = BP.readIntBE
  arr.readInt8 = BP.readInt8
  arr.readInt16LE = BP.readInt16LE
  arr.readInt16BE = BP.readInt16BE
  arr.readInt32LE = BP.readInt32LE
  arr.readInt32BE = BP.readInt32BE
  arr.readFloatLE = BP.readFloatLE
  arr.readFloatBE = BP.readFloatBE
  arr.readDoubleLE = BP.readDoubleLE
  arr.readDoubleBE = BP.readDoubleBE
  arr.writeUInt8 = BP.writeUInt8
  arr.writeUIntLE = BP.writeUIntLE
  arr.writeUIntBE = BP.writeUIntBE
  arr.writeUInt16LE = BP.writeUInt16LE
  arr.writeUInt16BE = BP.writeUInt16BE
  arr.writeUInt32LE = BP.writeUInt32LE
  arr.writeUInt32BE = BP.writeUInt32BE
  arr.writeIntLE = BP.writeIntLE
  arr.writeIntBE = BP.writeIntBE
  arr.writeInt8 = BP.writeInt8
  arr.writeInt16LE = BP.writeInt16LE
  arr.writeInt16BE = BP.writeInt16BE
  arr.writeInt32LE = BP.writeInt32LE
  arr.writeInt32BE = BP.writeInt32BE
  arr.writeFloatLE = BP.writeFloatLE
  arr.writeFloatBE = BP.writeFloatBE
  arr.writeDoubleLE = BP.writeDoubleLE
  arr.writeDoubleBE = BP.writeDoubleBE
  arr.fill = BP.fill
  arr.inspect = BP.inspect
  arr.toArrayBuffer = BP.toArrayBuffer

  return arr
}

var INVALID_BASE64_RE = /[^+\/0-9A-z\-]/g

function base64clean (str) {
  // Node strips out invalid characters like \n and \t from the string, base64-js does not
  str = stringtrim(str).replace(INVALID_BASE64_RE, '')
  // Node converts strings with length < 2 to ''
  if (str.length < 2) return ''
  // Node allows for non-padded base64 strings (missing trailing ===), base64-js does not
  while (str.length % 4 !== 0) {
    str = str + '='
  }
  return str
}

function stringtrim (str) {
  if (str.trim) return str.trim()
  return str.replace(/^\s+|\s+$/g, '')
}

function isArrayish (subject) {
  return isArray(subject) || Buffer.isBuffer(subject) ||
      subject && typeof subject === 'object' &&
      typeof subject.length === 'number'
}

function toHex (n) {
  if (n < 16) return '0' + n.toString(16)
  return n.toString(16)
}

function utf8ToBytes (string, units) {
  units = units || Infinity
  var codePoint
  var length = string.length
  var leadSurrogate = null
  var bytes = []
  var i = 0

  for (; i < length; i++) {
    codePoint = string.charCodeAt(i)

    // is surrogate component
    if (codePoint > 0xD7FF && codePoint < 0xE000) {
      // last char was a lead
      if (leadSurrogate) {
        // 2 leads in a row
        if (codePoint < 0xDC00) {
          if ((units -= 3) > -1) bytes.push(0xEF, 0xBF, 0xBD)
          leadSurrogate = codePoint
          continue
        } else {
          // valid surrogate pair
          codePoint = leadSurrogate - 0xD800 << 10 | codePoint - 0xDC00 | 0x10000
          leadSurrogate = null
        }
      } else {
        // no lead yet

        if (codePoint > 0xDBFF) {
          // unexpected trail
          if ((units -= 3) > -1) bytes.push(0xEF, 0xBF, 0xBD)
          continue
        } else if (i + 1 === length) {
          // unpaired lead
          if ((units -= 3) > -1) bytes.push(0xEF, 0xBF, 0xBD)
          continue
        } else {
          // valid lead
          leadSurrogate = codePoint
          continue
        }
      }
    } else if (leadSurrogate) {
      // valid bmp char, but last char was a lead
      if ((units -= 3) > -1) bytes.push(0xEF, 0xBF, 0xBD)
      leadSurrogate = null
    }

    // encode utf8
    if (codePoint < 0x80) {
      if ((units -= 1) < 0) break
      bytes.push(codePoint)
    } else if (codePoint < 0x800) {
      if ((units -= 2) < 0) break
      bytes.push(
        codePoint >> 0x6 | 0xC0,
        codePoint & 0x3F | 0x80
      )
    } else if (codePoint < 0x10000) {
      if ((units -= 3) < 0) break
      bytes.push(
        codePoint >> 0xC | 0xE0,
        codePoint >> 0x6 & 0x3F | 0x80,
        codePoint & 0x3F | 0x80
      )
    } else if (codePoint < 0x200000) {
      if ((units -= 4) < 0) break
      bytes.push(
        codePoint >> 0x12 | 0xF0,
        codePoint >> 0xC & 0x3F | 0x80,
        codePoint >> 0x6 & 0x3F | 0x80,
        codePoint & 0x3F | 0x80
      )
    } else {
      throw new Error('Invalid code point')
    }
  }

  return bytes
}

function asciiToBytes (str) {
  var byteArray = []
  for (var i = 0; i < str.length; i++) {
    // Node's code seems to be doing this and not & 0x7F..
    byteArray.push(str.charCodeAt(i) & 0xFF)
  }
  return byteArray
}

function utf16leToBytes (str, units) {
  var c, hi, lo
  var byteArray = []
  for (var i = 0; i < str.length; i++) {
    if ((units -= 2) < 0) break

    c = str.charCodeAt(i)
    hi = c >> 8
    lo = c % 256
    byteArray.push(lo)
    byteArray.push(hi)
  }

  return byteArray
}

function base64ToBytes (str) {
  return base64.toByteArray(base64clean(str))
}

function blitBuffer (src, dst, offset, length) {
  for (var i = 0; i < length; i++) {
    if ((i + offset >= dst.length) || (i >= src.length))
      break
    dst[i + offset] = src[i]
  }
  return i
}

function decodeUtf8Char (str) {
  try {
    return decodeURIComponent(str)
  } catch (err) {
    return String.fromCharCode(0xFFFD) // UTF 8 invalid char
  }
}

},{"base64-js":24,"ieee754":25,"is-array":26}],24:[function(require,module,exports){
var lookup = 'ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/';

;(function (exports) {
	'use strict';

  var Arr = (typeof Uint8Array !== 'undefined')
    ? Uint8Array
    : Array

	var PLUS   = '+'.charCodeAt(0)
	var SLASH  = '/'.charCodeAt(0)
	var NUMBER = '0'.charCodeAt(0)
	var LOWER  = 'a'.charCodeAt(0)
	var UPPER  = 'A'.charCodeAt(0)
	var PLUS_URL_SAFE = '-'.charCodeAt(0)
	var SLASH_URL_SAFE = '_'.charCodeAt(0)

	function decode (elt) {
		var code = elt.charCodeAt(0)
		if (code === PLUS ||
		    code === PLUS_URL_SAFE)
			return 62 // '+'
		if (code === SLASH ||
		    code === SLASH_URL_SAFE)
			return 63 // '/'
		if (code < NUMBER)
			return -1 //no match
		if (code < NUMBER + 10)
			return code - NUMBER + 26 + 26
		if (code < UPPER + 26)
			return code - UPPER
		if (code < LOWER + 26)
			return code - LOWER + 26
	}

	function b64ToByteArray (b64) {
		var i, j, l, tmp, placeHolders, arr

		if (b64.length % 4 > 0) {
			throw new Error('Invalid string. Length must be a multiple of 4')
		}

		// the number of equal signs (place holders)
		// if there are two placeholders, than the two characters before it
		// represent one byte
		// if there is only one, then the three characters before it represent 2 bytes
		// this is just a cheap hack to not do indexOf twice
		var len = b64.length
		placeHolders = '=' === b64.charAt(len - 2) ? 2 : '=' === b64.charAt(len - 1) ? 1 : 0

		// base64 is 4/3 + up to two characters of the original data
		arr = new Arr(b64.length * 3 / 4 - placeHolders)

		// if there are placeholders, only get up to the last complete 4 chars
		l = placeHolders > 0 ? b64.length - 4 : b64.length

		var L = 0

		function push (v) {
			arr[L++] = v
		}

		for (i = 0, j = 0; i < l; i += 4, j += 3) {
			tmp = (decode(b64.charAt(i)) << 18) | (decode(b64.charAt(i + 1)) << 12) | (decode(b64.charAt(i + 2)) << 6) | decode(b64.charAt(i + 3))
			push((tmp & 0xFF0000) >> 16)
			push((tmp & 0xFF00) >> 8)
			push(tmp & 0xFF)
		}

		if (placeHolders === 2) {
			tmp = (decode(b64.charAt(i)) << 2) | (decode(b64.charAt(i + 1)) >> 4)
			push(tmp & 0xFF)
		} else if (placeHolders === 1) {
			tmp = (decode(b64.charAt(i)) << 10) | (decode(b64.charAt(i + 1)) << 4) | (decode(b64.charAt(i + 2)) >> 2)
			push((tmp >> 8) & 0xFF)
			push(tmp & 0xFF)
		}

		return arr
	}

	function uint8ToBase64 (uint8) {
		var i,
			extraBytes = uint8.length % 3, // if we have 1 byte left, pad 2 bytes
			output = "",
			temp, length

		function encode (num) {
			return lookup.charAt(num)
		}

		function tripletToBase64 (num) {
			return encode(num >> 18 & 0x3F) + encode(num >> 12 & 0x3F) + encode(num >> 6 & 0x3F) + encode(num & 0x3F)
		}

		// go through the array every three bytes, we'll deal with trailing stuff later
		for (i = 0, length = uint8.length - extraBytes; i < length; i += 3) {
			temp = (uint8[i] << 16) + (uint8[i + 1] << 8) + (uint8[i + 2])
			output += tripletToBase64(temp)
		}

		// pad the end with zeros, but make sure to not forget the extra bytes
		switch (extraBytes) {
			case 1:
				temp = uint8[uint8.length - 1]
				output += encode(temp >> 2)
				output += encode((temp << 4) & 0x3F)
				output += '=='
				break
			case 2:
				temp = (uint8[uint8.length - 2] << 8) + (uint8[uint8.length - 1])
				output += encode(temp >> 10)
				output += encode((temp >> 4) & 0x3F)
				output += encode((temp << 2) & 0x3F)
				output += '='
				break
		}

		return output
	}

	exports.toByteArray = b64ToByteArray
	exports.fromByteArray = uint8ToBase64
}(typeof exports === 'undefined' ? (this.base64js = {}) : exports))

},{}],25:[function(require,module,exports){
exports.read = function(buffer, offset, isLE, mLen, nBytes) {
  var e, m,
      eLen = nBytes * 8 - mLen - 1,
      eMax = (1 << eLen) - 1,
      eBias = eMax >> 1,
      nBits = -7,
      i = isLE ? (nBytes - 1) : 0,
      d = isLE ? -1 : 1,
      s = buffer[offset + i];

  i += d;

  e = s & ((1 << (-nBits)) - 1);
  s >>= (-nBits);
  nBits += eLen;
  for (; nBits > 0; e = e * 256 + buffer[offset + i], i += d, nBits -= 8);

  m = e & ((1 << (-nBits)) - 1);
  e >>= (-nBits);
  nBits += mLen;
  for (; nBits > 0; m = m * 256 + buffer[offset + i], i += d, nBits -= 8);

  if (e === 0) {
    e = 1 - eBias;
  } else if (e === eMax) {
    return m ? NaN : ((s ? -1 : 1) * Infinity);
  } else {
    m = m + Math.pow(2, mLen);
    e = e - eBias;
  }
  return (s ? -1 : 1) * m * Math.pow(2, e - mLen);
};

exports.write = function(buffer, value, offset, isLE, mLen, nBytes) {
  var e, m, c,
      eLen = nBytes * 8 - mLen - 1,
      eMax = (1 << eLen) - 1,
      eBias = eMax >> 1,
      rt = (mLen === 23 ? Math.pow(2, -24) - Math.pow(2, -77) : 0),
      i = isLE ? 0 : (nBytes - 1),
      d = isLE ? 1 : -1,
      s = value < 0 || (value === 0 && 1 / value < 0) ? 1 : 0;

  value = Math.abs(value);

  if (isNaN(value) || value === Infinity) {
    m = isNaN(value) ? 1 : 0;
    e = eMax;
  } else {
    e = Math.floor(Math.log(value) / Math.LN2);
    if (value * (c = Math.pow(2, -e)) < 1) {
      e--;
      c *= 2;
    }
    if (e + eBias >= 1) {
      value += rt / c;
    } else {
      value += rt * Math.pow(2, 1 - eBias);
    }
    if (value * c >= 2) {
      e++;
      c /= 2;
    }

    if (e + eBias >= eMax) {
      m = 0;
      e = eMax;
    } else if (e + eBias >= 1) {
      m = (value * c - 1) * Math.pow(2, mLen);
      e = e + eBias;
    } else {
      m = value * Math.pow(2, eBias - 1) * Math.pow(2, mLen);
      e = 0;
    }
  }

  for (; mLen >= 8; buffer[offset + i] = m & 0xff, i += d, m /= 256, mLen -= 8);

  e = (e << mLen) | m;
  eLen += mLen;
  for (; eLen > 0; buffer[offset + i] = e & 0xff, i += d, e /= 256, eLen -= 8);

  buffer[offset + i - d] |= s * 128;
};

},{}],26:[function(require,module,exports){

/**
 * isArray
 */

var isArray = Array.isArray;

/**
 * toString
 */

var str = Object.prototype.toString;

/**
 * Whether or not the given `val`
 * is an array.
 *
 * example:
 *
 *        isArray([]);
 *        // > true
 *        isArray(arguments);
 *        // > false
 *        isArray('');
 *        // > false
 *
 * @param {mixed} val
 * @return {bool}
 */

module.exports = isArray || function (val) {
  return !! val && '[object Array]' == str.call(val);
};

},{}],27:[function(require,module,exports){
var upperCase    = require('upper-case');
var sentenceCase = require('sentence-case');

/**
 * Camel case a string.
 *
 * @param  {String} string
 * @param  {String} [locale]
 * @return {String}
 */
module.exports = function (string, locale) {
  return sentenceCase(string, locale)
    // Replace periods between numeric entities with an underscore.
    .replace(/(\d) (?=\d)/g, '$1_')
    // Replace spaces between words with an upper cased character.
    .replace(/ (.)/g, function (m, $1) {
      return upperCase($1, locale);
    });
};

},{"sentence-case":28,"upper-case":61}],28:[function(require,module,exports){
var lowerCase = require('lower-case')

var NON_WORD_REGEXP = require('./vendor/non-word-regexp')
var CAMEL_CASE_REGEXP = require('./vendor/camel-case-regexp')
var TRAILING_DIGIT_REGEXP = require('./vendor/trailing-digit-regexp')

/**
 * Sentence case a string.
 *
 * @param  {String} str
 * @param  {String} locale
 * @param  {String} replacement
 * @return {String}
 */
module.exports = function (str, locale, replacement) {
  if (str == null) {
    return ''
  }

  replacement = replacement || ' '

  function replace (match, index, string) {
    if (index === 0 || index === (string.length - match.length)) {
      return ''
    }

    return replacement
  }

  str = String(str)
    // Support camel case ("camelCase" -> "camel Case").
    .replace(CAMEL_CASE_REGEXP, '$1 $2')
    // Support digit groups ("test2012" -> "test 2012").
    .replace(TRAILING_DIGIT_REGEXP, '$1 $2')
    // Remove all non-word characters and replace with a single space.
    .replace(NON_WORD_REGEXP, replace)

  // Lower case the entire string.
  return lowerCase(str, locale)
}

},{"./vendor/camel-case-regexp":29,"./vendor/non-word-regexp":30,"./vendor/trailing-digit-regexp":31,"lower-case":46}],29:[function(require,module,exports){
module.exports = /([\u0061-\u007A\u00B5\u00DF-\u00F6\u00F8-\u00FF\u0101\u0103\u0105\u0107\u0109\u010B\u010D\u010F\u0111\u0113\u0115\u0117\u0119\u011B\u011D\u011F\u0121\u0123\u0125\u0127\u0129\u012B\u012D\u012F\u0131\u0133\u0135\u0137\u0138\u013A\u013C\u013E\u0140\u0142\u0144\u0146\u0148\u0149\u014B\u014D\u014F\u0151\u0153\u0155\u0157\u0159\u015B\u015D\u015F\u0161\u0163\u0165\u0167\u0169\u016B\u016D\u016F\u0171\u0173\u0175\u0177\u017A\u017C\u017E-\u0180\u0183\u0185\u0188\u018C\u018D\u0192\u0195\u0199-\u019B\u019E\u01A1\u01A3\u01A5\u01A8\u01AA\u01AB\u01AD\u01B0\u01B4\u01B6\u01B9\u01BA\u01BD-\u01BF\u01C6\u01C9\u01CC\u01CE\u01D0\u01D2\u01D4\u01D6\u01D8\u01DA\u01DC\u01DD\u01DF\u01E1\u01E3\u01E5\u01E7\u01E9\u01EB\u01ED\u01EF\u01F0\u01F3\u01F5\u01F9\u01FB\u01FD\u01FF\u0201\u0203\u0205\u0207\u0209\u020B\u020D\u020F\u0211\u0213\u0215\u0217\u0219\u021B\u021D\u021F\u0221\u0223\u0225\u0227\u0229\u022B\u022D\u022F\u0231\u0233-\u0239\u023C\u023F\u0240\u0242\u0247\u0249\u024B\u024D\u024F-\u0293\u0295-\u02AF\u0371\u0373\u0377\u037B-\u037D\u0390\u03AC-\u03CE\u03D0\u03D1\u03D5-\u03D7\u03D9\u03DB\u03DD\u03DF\u03E1\u03E3\u03E5\u03E7\u03E9\u03EB\u03ED\u03EF-\u03F3\u03F5\u03F8\u03FB\u03FC\u0430-\u045F\u0461\u0463\u0465\u0467\u0469\u046B\u046D\u046F\u0471\u0473\u0475\u0477\u0479\u047B\u047D\u047F\u0481\u048B\u048D\u048F\u0491\u0493\u0495\u0497\u0499\u049B\u049D\u049F\u04A1\u04A3\u04A5\u04A7\u04A9\u04AB\u04AD\u04AF\u04B1\u04B3\u04B5\u04B7\u04B9\u04BB\u04BD\u04BF\u04C2\u04C4\u04C6\u04C8\u04CA\u04CC\u04CE\u04CF\u04D1\u04D3\u04D5\u04D7\u04D9\u04DB\u04DD\u04DF\u04E1\u04E3\u04E5\u04E7\u04E9\u04EB\u04ED\u04EF\u04F1\u04F3\u04F5\u04F7\u04F9\u04FB\u04FD\u04FF\u0501\u0503\u0505\u0507\u0509\u050B\u050D\u050F\u0511\u0513\u0515\u0517\u0519\u051B\u051D\u051F\u0521\u0523\u0525\u0527\u0561-\u0587\u1D00-\u1D2B\u1D6B-\u1D77\u1D79-\u1D9A\u1E01\u1E03\u1E05\u1E07\u1E09\u1E0B\u1E0D\u1E0F\u1E11\u1E13\u1E15\u1E17\u1E19\u1E1B\u1E1D\u1E1F\u1E21\u1E23\u1E25\u1E27\u1E29\u1E2B\u1E2D\u1E2F\u1E31\u1E33\u1E35\u1E37\u1E39\u1E3B\u1E3D\u1E3F\u1E41\u1E43\u1E45\u1E47\u1E49\u1E4B\u1E4D\u1E4F\u1E51\u1E53\u1E55\u1E57\u1E59\u1E5B\u1E5D\u1E5F\u1E61\u1E63\u1E65\u1E67\u1E69\u1E6B\u1E6D\u1E6F\u1E71\u1E73\u1E75\u1E77\u1E79\u1E7B\u1E7D\u1E7F\u1E81\u1E83\u1E85\u1E87\u1E89\u1E8B\u1E8D\u1E8F\u1E91\u1E93\u1E95-\u1E9D\u1E9F\u1EA1\u1EA3\u1EA5\u1EA7\u1EA9\u1EAB\u1EAD\u1EAF\u1EB1\u1EB3\u1EB5\u1EB7\u1EB9\u1EBB\u1EBD\u1EBF\u1EC1\u1EC3\u1EC5\u1EC7\u1EC9\u1ECB\u1ECD\u1ECF\u1ED1\u1ED3\u1ED5\u1ED7\u1ED9\u1EDB\u1EDD\u1EDF\u1EE1\u1EE3\u1EE5\u1EE7\u1EE9\u1EEB\u1EED\u1EEF\u1EF1\u1EF3\u1EF5\u1EF7\u1EF9\u1EFB\u1EFD\u1EFF-\u1F07\u1F10-\u1F15\u1F20-\u1F27\u1F30-\u1F37\u1F40-\u1F45\u1F50-\u1F57\u1F60-\u1F67\u1F70-\u1F7D\u1F80-\u1F87\u1F90-\u1F97\u1FA0-\u1FA7\u1FB0-\u1FB4\u1FB6\u1FB7\u1FBE\u1FC2-\u1FC4\u1FC6\u1FC7\u1FD0-\u1FD3\u1FD6\u1FD7\u1FE0-\u1FE7\u1FF2-\u1FF4\u1FF6\u1FF7\u210A\u210E\u210F\u2113\u212F\u2134\u2139\u213C\u213D\u2146-\u2149\u214E\u2184\u2C30-\u2C5E\u2C61\u2C65\u2C66\u2C68\u2C6A\u2C6C\u2C71\u2C73\u2C74\u2C76-\u2C7B\u2C81\u2C83\u2C85\u2C87\u2C89\u2C8B\u2C8D\u2C8F\u2C91\u2C93\u2C95\u2C97\u2C99\u2C9B\u2C9D\u2C9F\u2CA1\u2CA3\u2CA5\u2CA7\u2CA9\u2CAB\u2CAD\u2CAF\u2CB1\u2CB3\u2CB5\u2CB7\u2CB9\u2CBB\u2CBD\u2CBF\u2CC1\u2CC3\u2CC5\u2CC7\u2CC9\u2CCB\u2CCD\u2CCF\u2CD1\u2CD3\u2CD5\u2CD7\u2CD9\u2CDB\u2CDD\u2CDF\u2CE1\u2CE3\u2CE4\u2CEC\u2CEE\u2CF3\u2D00-\u2D25\u2D27\u2D2D\uA641\uA643\uA645\uA647\uA649\uA64B\uA64D\uA64F\uA651\uA653\uA655\uA657\uA659\uA65B\uA65D\uA65F\uA661\uA663\uA665\uA667\uA669\uA66B\uA66D\uA681\uA683\uA685\uA687\uA689\uA68B\uA68D\uA68F\uA691\uA693\uA695\uA697\uA723\uA725\uA727\uA729\uA72B\uA72D\uA72F-\uA731\uA733\uA735\uA737\uA739\uA73B\uA73D\uA73F\uA741\uA743\uA745\uA747\uA749\uA74B\uA74D\uA74F\uA751\uA753\uA755\uA757\uA759\uA75B\uA75D\uA75F\uA761\uA763\uA765\uA767\uA769\uA76B\uA76D\uA76F\uA771-\uA778\uA77A\uA77C\uA77F\uA781\uA783\uA785\uA787\uA78C\uA78E\uA791\uA793\uA7A1\uA7A3\uA7A5\uA7A7\uA7A9\uA7FA\uFB00-\uFB06\uFB13-\uFB17\uFF41-\uFF5A])([\u0041-\u005A\u00C0-\u00D6\u00D8-\u00DE\u0100\u0102\u0104\u0106\u0108\u010A\u010C\u010E\u0110\u0112\u0114\u0116\u0118\u011A\u011C\u011E\u0120\u0122\u0124\u0126\u0128\u012A\u012C\u012E\u0130\u0132\u0134\u0136\u0139\u013B\u013D\u013F\u0141\u0143\u0145\u0147\u014A\u014C\u014E\u0150\u0152\u0154\u0156\u0158\u015A\u015C\u015E\u0160\u0162\u0164\u0166\u0168\u016A\u016C\u016E\u0170\u0172\u0174\u0176\u0178\u0179\u017B\u017D\u0181\u0182\u0184\u0186\u0187\u0189-\u018B\u018E-\u0191\u0193\u0194\u0196-\u0198\u019C\u019D\u019F\u01A0\u01A2\u01A4\u01A6\u01A7\u01A9\u01AC\u01AE\u01AF\u01B1-\u01B3\u01B5\u01B7\u01B8\u01BC\u01C4\u01C7\u01CA\u01CD\u01CF\u01D1\u01D3\u01D5\u01D7\u01D9\u01DB\u01DE\u01E0\u01E2\u01E4\u01E6\u01E8\u01EA\u01EC\u01EE\u01F1\u01F4\u01F6-\u01F8\u01FA\u01FC\u01FE\u0200\u0202\u0204\u0206\u0208\u020A\u020C\u020E\u0210\u0212\u0214\u0216\u0218\u021A\u021C\u021E\u0220\u0222\u0224\u0226\u0228\u022A\u022C\u022E\u0230\u0232\u023A\u023B\u023D\u023E\u0241\u0243-\u0246\u0248\u024A\u024C\u024E\u0370\u0372\u0376\u0386\u0388-\u038A\u038C\u038E\u038F\u0391-\u03A1\u03A3-\u03AB\u03CF\u03D2-\u03D4\u03D8\u03DA\u03DC\u03DE\u03E0\u03E2\u03E4\u03E6\u03E8\u03EA\u03EC\u03EE\u03F4\u03F7\u03F9\u03FA\u03FD-\u042F\u0460\u0462\u0464\u0466\u0468\u046A\u046C\u046E\u0470\u0472\u0474\u0476\u0478\u047A\u047C\u047E\u0480\u048A\u048C\u048E\u0490\u0492\u0494\u0496\u0498\u049A\u049C\u049E\u04A0\u04A2\u04A4\u04A6\u04A8\u04AA\u04AC\u04AE\u04B0\u04B2\u04B4\u04B6\u04B8\u04BA\u04BC\u04BE\u04C0\u04C1\u04C3\u04C5\u04C7\u04C9\u04CB\u04CD\u04D0\u04D2\u04D4\u04D6\u04D8\u04DA\u04DC\u04DE\u04E0\u04E2\u04E4\u04E6\u04E8\u04EA\u04EC\u04EE\u04F0\u04F2\u04F4\u04F6\u04F8\u04FA\u04FC\u04FE\u0500\u0502\u0504\u0506\u0508\u050A\u050C\u050E\u0510\u0512\u0514\u0516\u0518\u051A\u051C\u051E\u0520\u0522\u0524\u0526\u0531-\u0556\u10A0-\u10C5\u10C7\u10CD\u1E00\u1E02\u1E04\u1E06\u1E08\u1E0A\u1E0C\u1E0E\u1E10\u1E12\u1E14\u1E16\u1E18\u1E1A\u1E1C\u1E1E\u1E20\u1E22\u1E24\u1E26\u1E28\u1E2A\u1E2C\u1E2E\u1E30\u1E32\u1E34\u1E36\u1E38\u1E3A\u1E3C\u1E3E\u1E40\u1E42\u1E44\u1E46\u1E48\u1E4A\u1E4C\u1E4E\u1E50\u1E52\u1E54\u1E56\u1E58\u1E5A\u1E5C\u1E5E\u1E60\u1E62\u1E64\u1E66\u1E68\u1E6A\u1E6C\u1E6E\u1E70\u1E72\u1E74\u1E76\u1E78\u1E7A\u1E7C\u1E7E\u1E80\u1E82\u1E84\u1E86\u1E88\u1E8A\u1E8C\u1E8E\u1E90\u1E92\u1E94\u1E9E\u1EA0\u1EA2\u1EA4\u1EA6\u1EA8\u1EAA\u1EAC\u1EAE\u1EB0\u1EB2\u1EB4\u1EB6\u1EB8\u1EBA\u1EBC\u1EBE\u1EC0\u1EC2\u1EC4\u1EC6\u1EC8\u1ECA\u1ECC\u1ECE\u1ED0\u1ED2\u1ED4\u1ED6\u1ED8\u1EDA\u1EDC\u1EDE\u1EE0\u1EE2\u1EE4\u1EE6\u1EE8\u1EEA\u1EEC\u1EEE\u1EF0\u1EF2\u1EF4\u1EF6\u1EF8\u1EFA\u1EFC\u1EFE\u1F08-\u1F0F\u1F18-\u1F1D\u1F28-\u1F2F\u1F38-\u1F3F\u1F48-\u1F4D\u1F59\u1F5B\u1F5D\u1F5F\u1F68-\u1F6F\u1FB8-\u1FBB\u1FC8-\u1FCB\u1FD8-\u1FDB\u1FE8-\u1FEC\u1FF8-\u1FFB\u2102\u2107\u210B-\u210D\u2110-\u2112\u2115\u2119-\u211D\u2124\u2126\u2128\u212A-\u212D\u2130-\u2133\u213E\u213F\u2145\u2183\u2C00-\u2C2E\u2C60\u2C62-\u2C64\u2C67\u2C69\u2C6B\u2C6D-\u2C70\u2C72\u2C75\u2C7E-\u2C80\u2C82\u2C84\u2C86\u2C88\u2C8A\u2C8C\u2C8E\u2C90\u2C92\u2C94\u2C96\u2C98\u2C9A\u2C9C\u2C9E\u2CA0\u2CA2\u2CA4\u2CA6\u2CA8\u2CAA\u2CAC\u2CAE\u2CB0\u2CB2\u2CB4\u2CB6\u2CB8\u2CBA\u2CBC\u2CBE\u2CC0\u2CC2\u2CC4\u2CC6\u2CC8\u2CCA\u2CCC\u2CCE\u2CD0\u2CD2\u2CD4\u2CD6\u2CD8\u2CDA\u2CDC\u2CDE\u2CE0\u2CE2\u2CEB\u2CED\u2CF2\uA640\uA642\uA644\uA646\uA648\uA64A\uA64C\uA64E\uA650\uA652\uA654\uA656\uA658\uA65A\uA65C\uA65E\uA660\uA662\uA664\uA666\uA668\uA66A\uA66C\uA680\uA682\uA684\uA686\uA688\uA68A\uA68C\uA68E\uA690\uA692\uA694\uA696\uA722\uA724\uA726\uA728\uA72A\uA72C\uA72E\uA732\uA734\uA736\uA738\uA73A\uA73C\uA73E\uA740\uA742\uA744\uA746\uA748\uA74A\uA74C\uA74E\uA750\uA752\uA754\uA756\uA758\uA75A\uA75C\uA75E\uA760\uA762\uA764\uA766\uA768\uA76A\uA76C\uA76E\uA779\uA77B\uA77D\uA77E\uA780\uA782\uA784\uA786\uA78B\uA78D\uA790\uA792\uA7A0\uA7A2\uA7A4\uA7A6\uA7A8\uA7AA\uFF21-\uFF3A\u0030-\u0039\u00B2\u00B3\u00B9\u00BC-\u00BE\u0660-\u0669\u06F0-\u06F9\u07C0-\u07C9\u0966-\u096F\u09E6-\u09EF\u09F4-\u09F9\u0A66-\u0A6F\u0AE6-\u0AEF\u0B66-\u0B6F\u0B72-\u0B77\u0BE6-\u0BF2\u0C66-\u0C6F\u0C78-\u0C7E\u0CE6-\u0CEF\u0D66-\u0D75\u0E50-\u0E59\u0ED0-\u0ED9\u0F20-\u0F33\u1040-\u1049\u1090-\u1099\u1369-\u137C\u16EE-\u16F0\u17E0-\u17E9\u17F0-\u17F9\u1810-\u1819\u1946-\u194F\u19D0-\u19DA\u1A80-\u1A89\u1A90-\u1A99\u1B50-\u1B59\u1BB0-\u1BB9\u1C40-\u1C49\u1C50-\u1C59\u2070\u2074-\u2079\u2080-\u2089\u2150-\u2182\u2185-\u2189\u2460-\u249B\u24EA-\u24FF\u2776-\u2793\u2CFD\u3007\u3021-\u3029\u3038-\u303A\u3192-\u3195\u3220-\u3229\u3248-\u324F\u3251-\u325F\u3280-\u3289\u32B1-\u32BF\uA620-\uA629\uA6E6-\uA6EF\uA830-\uA835\uA8D0-\uA8D9\uA900-\uA909\uA9D0-\uA9D9\uAA50-\uAA59\uABF0-\uABF9\uFF10-\uFF19])/g

},{}],30:[function(require,module,exports){
module.exports = /[^\u0041-\u005A\u0061-\u007A\u00AA\u00B5\u00BA\u00C0-\u00D6\u00D8-\u00F6\u00F8-\u02C1\u02C6-\u02D1\u02E0-\u02E4\u02EC\u02EE\u0370-\u0374\u0376\u0377\u037A-\u037D\u0386\u0388-\u038A\u038C\u038E-\u03A1\u03A3-\u03F5\u03F7-\u0481\u048A-\u0527\u0531-\u0556\u0559\u0561-\u0587\u05D0-\u05EA\u05F0-\u05F2\u0620-\u064A\u066E\u066F\u0671-\u06D3\u06D5\u06E5\u06E6\u06EE\u06EF\u06FA-\u06FC\u06FF\u0710\u0712-\u072F\u074D-\u07A5\u07B1\u07CA-\u07EA\u07F4\u07F5\u07FA\u0800-\u0815\u081A\u0824\u0828\u0840-\u0858\u08A0\u08A2-\u08AC\u0904-\u0939\u093D\u0950\u0958-\u0961\u0971-\u0977\u0979-\u097F\u0985-\u098C\u098F\u0990\u0993-\u09A8\u09AA-\u09B0\u09B2\u09B6-\u09B9\u09BD\u09CE\u09DC\u09DD\u09DF-\u09E1\u09F0\u09F1\u0A05-\u0A0A\u0A0F\u0A10\u0A13-\u0A28\u0A2A-\u0A30\u0A32\u0A33\u0A35\u0A36\u0A38\u0A39\u0A59-\u0A5C\u0A5E\u0A72-\u0A74\u0A85-\u0A8D\u0A8F-\u0A91\u0A93-\u0AA8\u0AAA-\u0AB0\u0AB2\u0AB3\u0AB5-\u0AB9\u0ABD\u0AD0\u0AE0\u0AE1\u0B05-\u0B0C\u0B0F\u0B10\u0B13-\u0B28\u0B2A-\u0B30\u0B32\u0B33\u0B35-\u0B39\u0B3D\u0B5C\u0B5D\u0B5F-\u0B61\u0B71\u0B83\u0B85-\u0B8A\u0B8E-\u0B90\u0B92-\u0B95\u0B99\u0B9A\u0B9C\u0B9E\u0B9F\u0BA3\u0BA4\u0BA8-\u0BAA\u0BAE-\u0BB9\u0BD0\u0C05-\u0C0C\u0C0E-\u0C10\u0C12-\u0C28\u0C2A-\u0C33\u0C35-\u0C39\u0C3D\u0C58\u0C59\u0C60\u0C61\u0C85-\u0C8C\u0C8E-\u0C90\u0C92-\u0CA8\u0CAA-\u0CB3\u0CB5-\u0CB9\u0CBD\u0CDE\u0CE0\u0CE1\u0CF1\u0CF2\u0D05-\u0D0C\u0D0E-\u0D10\u0D12-\u0D3A\u0D3D\u0D4E\u0D60\u0D61\u0D7A-\u0D7F\u0D85-\u0D96\u0D9A-\u0DB1\u0DB3-\u0DBB\u0DBD\u0DC0-\u0DC6\u0E01-\u0E30\u0E32\u0E33\u0E40-\u0E46\u0E81\u0E82\u0E84\u0E87\u0E88\u0E8A\u0E8D\u0E94-\u0E97\u0E99-\u0E9F\u0EA1-\u0EA3\u0EA5\u0EA7\u0EAA\u0EAB\u0EAD-\u0EB0\u0EB2\u0EB3\u0EBD\u0EC0-\u0EC4\u0EC6\u0EDC-\u0EDF\u0F00\u0F40-\u0F47\u0F49-\u0F6C\u0F88-\u0F8C\u1000-\u102A\u103F\u1050-\u1055\u105A-\u105D\u1061\u1065\u1066\u106E-\u1070\u1075-\u1081\u108E\u10A0-\u10C5\u10C7\u10CD\u10D0-\u10FA\u10FC-\u1248\u124A-\u124D\u1250-\u1256\u1258\u125A-\u125D\u1260-\u1288\u128A-\u128D\u1290-\u12B0\u12B2-\u12B5\u12B8-\u12BE\u12C0\u12C2-\u12C5\u12C8-\u12D6\u12D8-\u1310\u1312-\u1315\u1318-\u135A\u1380-\u138F\u13A0-\u13F4\u1401-\u166C\u166F-\u167F\u1681-\u169A\u16A0-\u16EA\u1700-\u170C\u170E-\u1711\u1720-\u1731\u1740-\u1751\u1760-\u176C\u176E-\u1770\u1780-\u17B3\u17D7\u17DC\u1820-\u1877\u1880-\u18A8\u18AA\u18B0-\u18F5\u1900-\u191C\u1950-\u196D\u1970-\u1974\u1980-\u19AB\u19C1-\u19C7\u1A00-\u1A16\u1A20-\u1A54\u1AA7\u1B05-\u1B33\u1B45-\u1B4B\u1B83-\u1BA0\u1BAE\u1BAF\u1BBA-\u1BE5\u1C00-\u1C23\u1C4D-\u1C4F\u1C5A-\u1C7D\u1CE9-\u1CEC\u1CEE-\u1CF1\u1CF5\u1CF6\u1D00-\u1DBF\u1E00-\u1F15\u1F18-\u1F1D\u1F20-\u1F45\u1F48-\u1F4D\u1F50-\u1F57\u1F59\u1F5B\u1F5D\u1F5F-\u1F7D\u1F80-\u1FB4\u1FB6-\u1FBC\u1FBE\u1FC2-\u1FC4\u1FC6-\u1FCC\u1FD0-\u1FD3\u1FD6-\u1FDB\u1FE0-\u1FEC\u1FF2-\u1FF4\u1FF6-\u1FFC\u2071\u207F\u2090-\u209C\u2102\u2107\u210A-\u2113\u2115\u2119-\u211D\u2124\u2126\u2128\u212A-\u212D\u212F-\u2139\u213C-\u213F\u2145-\u2149\u214E\u2183\u2184\u2C00-\u2C2E\u2C30-\u2C5E\u2C60-\u2CE4\u2CEB-\u2CEE\u2CF2\u2CF3\u2D00-\u2D25\u2D27\u2D2D\u2D30-\u2D67\u2D6F\u2D80-\u2D96\u2DA0-\u2DA6\u2DA8-\u2DAE\u2DB0-\u2DB6\u2DB8-\u2DBE\u2DC0-\u2DC6\u2DC8-\u2DCE\u2DD0-\u2DD6\u2DD8-\u2DDE\u2E2F\u3005\u3006\u3031-\u3035\u303B\u303C\u3041-\u3096\u309D-\u309F\u30A1-\u30FA\u30FC-\u30FF\u3105-\u312D\u3131-\u318E\u31A0-\u31BA\u31F0-\u31FF\u3400-\u4DB5\u4E00-\u9FCC\uA000-\uA48C\uA4D0-\uA4FD\uA500-\uA60C\uA610-\uA61F\uA62A\uA62B\uA640-\uA66E\uA67F-\uA697\uA6A0-\uA6E5\uA717-\uA71F\uA722-\uA788\uA78B-\uA78E\uA790-\uA793\uA7A0-\uA7AA\uA7F8-\uA801\uA803-\uA805\uA807-\uA80A\uA80C-\uA822\uA840-\uA873\uA882-\uA8B3\uA8F2-\uA8F7\uA8FB\uA90A-\uA925\uA930-\uA946\uA960-\uA97C\uA984-\uA9B2\uA9CF\uAA00-\uAA28\uAA40-\uAA42\uAA44-\uAA4B\uAA60-\uAA76\uAA7A\uAA80-\uAAAF\uAAB1\uAAB5\uAAB6\uAAB9-\uAABD\uAAC0\uAAC2\uAADB-\uAADD\uAAE0-\uAAEA\uAAF2-\uAAF4\uAB01-\uAB06\uAB09-\uAB0E\uAB11-\uAB16\uAB20-\uAB26\uAB28-\uAB2E\uABC0-\uABE2\uAC00-\uD7A3\uD7B0-\uD7C6\uD7CB-\uD7FB\uF900-\uFA6D\uFA70-\uFAD9\uFB00-\uFB06\uFB13-\uFB17\uFB1D\uFB1F-\uFB28\uFB2A-\uFB36\uFB38-\uFB3C\uFB3E\uFB40\uFB41\uFB43\uFB44\uFB46-\uFBB1\uFBD3-\uFD3D\uFD50-\uFD8F\uFD92-\uFDC7\uFDF0-\uFDFB\uFE70-\uFE74\uFE76-\uFEFC\uFF21-\uFF3A\uFF41-\uFF5A\uFF66-\uFFBE\uFFC2-\uFFC7\uFFCA-\uFFCF\uFFD2-\uFFD7\uFFDA-\uFFDC\u0030-\u0039\u00B2\u00B3\u00B9\u00BC-\u00BE\u0660-\u0669\u06F0-\u06F9\u07C0-\u07C9\u0966-\u096F\u09E6-\u09EF\u09F4-\u09F9\u0A66-\u0A6F\u0AE6-\u0AEF\u0B66-\u0B6F\u0B72-\u0B77\u0BE6-\u0BF2\u0C66-\u0C6F\u0C78-\u0C7E\u0CE6-\u0CEF\u0D66-\u0D75\u0E50-\u0E59\u0ED0-\u0ED9\u0F20-\u0F33\u1040-\u1049\u1090-\u1099\u1369-\u137C\u16EE-\u16F0\u17E0-\u17E9\u17F0-\u17F9\u1810-\u1819\u1946-\u194F\u19D0-\u19DA\u1A80-\u1A89\u1A90-\u1A99\u1B50-\u1B59\u1BB0-\u1BB9\u1C40-\u1C49\u1C50-\u1C59\u2070\u2074-\u2079\u2080-\u2089\u2150-\u2182\u2185-\u2189\u2460-\u249B\u24EA-\u24FF\u2776-\u2793\u2CFD\u3007\u3021-\u3029\u3038-\u303A\u3192-\u3195\u3220-\u3229\u3248-\u324F\u3251-\u325F\u3280-\u3289\u32B1-\u32BF\uA620-\uA629\uA6E6-\uA6EF\uA830-\uA835\uA8D0-\uA8D9\uA900-\uA909\uA9D0-\uA9D9\uAA50-\uAA59\uABF0-\uABF9\uFF10-\uFF19]+/g

},{}],31:[function(require,module,exports){
module.exports = /([\u0030-\u0039\u00B2\u00B3\u00B9\u00BC-\u00BE\u0660-\u0669\u06F0-\u06F9\u07C0-\u07C9\u0966-\u096F\u09E6-\u09EF\u09F4-\u09F9\u0A66-\u0A6F\u0AE6-\u0AEF\u0B66-\u0B6F\u0B72-\u0B77\u0BE6-\u0BF2\u0C66-\u0C6F\u0C78-\u0C7E\u0CE6-\u0CEF\u0D66-\u0D75\u0E50-\u0E59\u0ED0-\u0ED9\u0F20-\u0F33\u1040-\u1049\u1090-\u1099\u1369-\u137C\u16EE-\u16F0\u17E0-\u17E9\u17F0-\u17F9\u1810-\u1819\u1946-\u194F\u19D0-\u19DA\u1A80-\u1A89\u1A90-\u1A99\u1B50-\u1B59\u1BB0-\u1BB9\u1C40-\u1C49\u1C50-\u1C59\u2070\u2074-\u2079\u2080-\u2089\u2150-\u2182\u2185-\u2189\u2460-\u249B\u24EA-\u24FF\u2776-\u2793\u2CFD\u3007\u3021-\u3029\u3038-\u303A\u3192-\u3195\u3220-\u3229\u3248-\u324F\u3251-\u325F\u3280-\u3289\u32B1-\u32BF\uA620-\uA629\uA6E6-\uA6EF\uA830-\uA835\uA8D0-\uA8D9\uA900-\uA909\uA9D0-\uA9D9\uAA50-\uAA59\uABF0-\uABF9\uFF10-\uFF19])([^\u0030-\u0039\u00B2\u00B3\u00B9\u00BC-\u00BE\u0660-\u0669\u06F0-\u06F9\u07C0-\u07C9\u0966-\u096F\u09E6-\u09EF\u09F4-\u09F9\u0A66-\u0A6F\u0AE6-\u0AEF\u0B66-\u0B6F\u0B72-\u0B77\u0BE6-\u0BF2\u0C66-\u0C6F\u0C78-\u0C7E\u0CE6-\u0CEF\u0D66-\u0D75\u0E50-\u0E59\u0ED0-\u0ED9\u0F20-\u0F33\u1040-\u1049\u1090-\u1099\u1369-\u137C\u16EE-\u16F0\u17E0-\u17E9\u17F0-\u17F9\u1810-\u1819\u1946-\u194F\u19D0-\u19DA\u1A80-\u1A89\u1A90-\u1A99\u1B50-\u1B59\u1BB0-\u1BB9\u1C40-\u1C49\u1C50-\u1C59\u2070\u2074-\u2079\u2080-\u2089\u2150-\u2182\u2185-\u2189\u2460-\u249B\u24EA-\u24FF\u2776-\u2793\u2CFD\u3007\u3021-\u3029\u3038-\u303A\u3192-\u3195\u3220-\u3229\u3248-\u324F\u3251-\u325F\u3280-\u3289\u32B1-\u32BF\uA620-\uA629\uA6E6-\uA6EF\uA830-\uA835\uA8D0-\uA8D9\uA900-\uA909\uA9D0-\uA9D9\uAA50-\uAA59\uABF0-\uABF9\uFF10-\uFF19])/g

},{}],32:[function(require,module,exports){
var upperCase = require('upper-case');
var snakeCase = require('snake-case');

/**
 * Constant case a string.
 *
 * @param  {String} string
 * @param  {String} [locale]
 * @return {String}
 */
module.exports = function (string, locale) {
  return upperCase(snakeCase(string, locale), locale);
};

},{"snake-case":60,"upper-case":61}],33:[function(require,module,exports){
var hasOwn = Object.prototype.hasOwnProperty;
var toString = Object.prototype.toString;
var undefined;

var isPlainObject = function isPlainObject(obj) {
	'use strict';
	if (!obj || toString.call(obj) !== '[object Object]') {
		return false;
	}

	var has_own_constructor = hasOwn.call(obj, 'constructor');
	var has_is_property_of_method = obj.constructor && obj.constructor.prototype && hasOwn.call(obj.constructor.prototype, 'isPrototypeOf');
	// Not own constructor property must be Object
	if (obj.constructor && !has_own_constructor && !has_is_property_of_method) {
		return false;
	}

	// Own properties are enumerated firstly, so to speed up,
	// if last one is own, then all properties are own.
	var key;
	for (key in obj) {}

	return key === undefined || hasOwn.call(obj, key);
};

module.exports = function extend() {
	'use strict';
	var options, name, src, copy, copyIsArray, clone,
		target = arguments[0],
		i = 1,
		length = arguments.length,
		deep = false;

	// Handle a deep copy situation
	if (typeof target === 'boolean') {
		deep = target;
		target = arguments[1] || {};
		// skip the boolean and the target
		i = 2;
	} else if ((typeof target !== 'object' && typeof target !== 'function') || target == null) {
		target = {};
	}

	for (; i < length; ++i) {
		options = arguments[i];
		// Only deal with non-null/undefined values
		if (options != null) {
			// Extend the base object
			for (name in options) {
				src = target[name];
				copy = options[name];

				// Prevent never-ending loop
				if (target === copy) {
					continue;
				}

				// Recurse if we're merging plain objects or arrays
				if (deep && copy && (isPlainObject(copy) || (copyIsArray = Array.isArray(copy)))) {
					if (copyIsArray) {
						copyIsArray = false;
						clone = src && Array.isArray(src) ? src : [];
					} else {
						clone = src && isPlainObject(src) ? src : {};
					}

					// Never move original objects, clone them
					target[name] = extend(deep, clone, copy);

				// Don't bring in undefined values
				} else if (copy !== undefined) {
					target[name] = copy;
				}
			}
		}
	}

	// Return the modified object
	return target;
};


},{}],34:[function(require,module,exports){
(function (global){
"use strict";
/*globals Handlebars: true */
var base = require("./handlebars/base");

// Each of these augment the Handlebars object. No need to setup here.
// (This is done to easily share code between commonjs and browse envs)
var SafeString = require("./handlebars/safe-string")["default"];
var Exception = require("./handlebars/exception")["default"];
var Utils = require("./handlebars/utils");
var runtime = require("./handlebars/runtime");

// For compatibility and usage outside of module systems, make the Handlebars object a namespace
var create = function() {
  var hb = new base.HandlebarsEnvironment();

  Utils.extend(hb, base);
  hb.SafeString = SafeString;
  hb.Exception = Exception;
  hb.Utils = Utils;
  hb.escapeExpression = Utils.escapeExpression;

  hb.VM = runtime;
  hb.template = function(spec) {
    return runtime.template(spec, hb);
  };

  return hb;
};

var Handlebars = create();
Handlebars.create = create;

/*jshint -W040 */
/* istanbul ignore next */
var root = typeof global !== 'undefined' ? global : window,
    $Handlebars = root.Handlebars;
/* istanbul ignore next */
Handlebars.noConflict = function() {
  if (root.Handlebars === Handlebars) {
    root.Handlebars = $Handlebars;
  }
};

Handlebars['default'] = Handlebars;

exports["default"] = Handlebars;
}).call(this,typeof global !== "undefined" ? global : typeof self !== "undefined" ? self : typeof window !== "undefined" ? window : {})
},{"./handlebars/base":35,"./handlebars/exception":36,"./handlebars/runtime":37,"./handlebars/safe-string":38,"./handlebars/utils":39}],35:[function(require,module,exports){
"use strict";
var Utils = require("./utils");
var Exception = require("./exception")["default"];

var VERSION = "3.0.0";
exports.VERSION = VERSION;var COMPILER_REVISION = 6;
exports.COMPILER_REVISION = COMPILER_REVISION;
var REVISION_CHANGES = {
  1: '<= 1.0.rc.2', // 1.0.rc.2 is actually rev2 but doesn't report it
  2: '== 1.0.0-rc.3',
  3: '== 1.0.0-rc.4',
  4: '== 1.x.x',
  5: '== 2.0.0-alpha.x',
  6: '>= 2.0.0-beta.1'
};
exports.REVISION_CHANGES = REVISION_CHANGES;
var isArray = Utils.isArray,
    isFunction = Utils.isFunction,
    toString = Utils.toString,
    objectType = '[object Object]';

function HandlebarsEnvironment(helpers, partials) {
  this.helpers = helpers || {};
  this.partials = partials || {};

  registerDefaultHelpers(this);
}

exports.HandlebarsEnvironment = HandlebarsEnvironment;HandlebarsEnvironment.prototype = {
  constructor: HandlebarsEnvironment,

  logger: logger,
  log: log,

  registerHelper: function(name, fn) {
    if (toString.call(name) === objectType) {
      if (fn) { throw new Exception('Arg not supported with multiple helpers'); }
      Utils.extend(this.helpers, name);
    } else {
      this.helpers[name] = fn;
    }
  },
  unregisterHelper: function(name) {
    delete this.helpers[name];
  },

  registerPartial: function(name, partial) {
    if (toString.call(name) === objectType) {
      Utils.extend(this.partials,  name);
    } else {
      if (typeof partial === 'undefined') {
        throw new Exception('Attempting to register a partial as undefined');
      }
      this.partials[name] = partial;
    }
  },
  unregisterPartial: function(name) {
    delete this.partials[name];
  }
};

function registerDefaultHelpers(instance) {
  instance.registerHelper('helperMissing', function(/* [args, ]options */) {
    if(arguments.length === 1) {
      // A missing field in a {{foo}} constuct.
      return undefined;
    } else {
      // Someone is actually trying to call something, blow up.
      throw new Exception("Missing helper: '" + arguments[arguments.length-1].name + "'");
    }
  });

  instance.registerHelper('blockHelperMissing', function(context, options) {
    var inverse = options.inverse,
        fn = options.fn;

    if(context === true) {
      return fn(this);
    } else if(context === false || context == null) {
      return inverse(this);
    } else if (isArray(context)) {
      if(context.length > 0) {
        if (options.ids) {
          options.ids = [options.name];
        }

        return instance.helpers.each(context, options);
      } else {
        return inverse(this);
      }
    } else {
      if (options.data && options.ids) {
        var data = createFrame(options.data);
        data.contextPath = Utils.appendContextPath(options.data.contextPath, options.name);
        options = {data: data};
      }

      return fn(context, options);
    }
  });

  instance.registerHelper('each', function(context, options) {
    if (!options) {
      throw new Exception('Must pass iterator to #each');
    }

    var fn = options.fn, inverse = options.inverse;
    var i = 0, ret = "", data;

    var contextPath;
    if (options.data && options.ids) {
      contextPath = Utils.appendContextPath(options.data.contextPath, options.ids[0]) + '.';
    }

    if (isFunction(context)) { context = context.call(this); }

    if (options.data) {
      data = createFrame(options.data);
    }

    function execIteration(key, i, last) {
      if (data) {
        data.key = key;
        data.index = i;
        data.first = i === 0;
        data.last  = !!last;

        if (contextPath) {
          data.contextPath = contextPath + key;
        }
      }

      ret = ret + fn(context[key], {
        data: data,
        blockParams: Utils.blockParams([context[key], key], [contextPath + key, null])
      });
    }

    if(context && typeof context === 'object') {
      if (isArray(context)) {
        for(var j = context.length; i<j; i++) {
          execIteration(i, i, i === context.length-1);
        }
      } else {
        var priorKey;

        for(var key in context) {
          if(context.hasOwnProperty(key)) {
            // We're running the iterations one step out of sync so we can detect
            // the last iteration without have to scan the object twice and create
            // an itermediate keys array. 
            if (priorKey) {
              execIteration(priorKey, i-1);
            }
            priorKey = key;
            i++;
          }
        }
        if (priorKey) {
          execIteration(priorKey, i-1, true);
        }
      }
    }

    if(i === 0){
      ret = inverse(this);
    }

    return ret;
  });

  instance.registerHelper('if', function(conditional, options) {
    if (isFunction(conditional)) { conditional = conditional.call(this); }

    // Default behavior is to render the positive path if the value is truthy and not empty.
    // The `includeZero` option may be set to treat the condtional as purely not empty based on the
    // behavior of isEmpty. Effectively this determines if 0 is handled by the positive path or negative.
    if ((!options.hash.includeZero && !conditional) || Utils.isEmpty(conditional)) {
      return options.inverse(this);
    } else {
      return options.fn(this);
    }
  });

  instance.registerHelper('unless', function(conditional, options) {
    return instance.helpers['if'].call(this, conditional, {fn: options.inverse, inverse: options.fn, hash: options.hash});
  });

  instance.registerHelper('with', function(context, options) {
    if (isFunction(context)) { context = context.call(this); }

    var fn = options.fn;

    if (!Utils.isEmpty(context)) {
      if (options.data && options.ids) {
        var data = createFrame(options.data);
        data.contextPath = Utils.appendContextPath(options.data.contextPath, options.ids[0]);
        options = {data:data};
      }

      return fn(context, options);
    } else {
      return options.inverse(this);
    }
  });

  instance.registerHelper('log', function(message, options) {
    var level = options.data && options.data.level != null ? parseInt(options.data.level, 10) : 1;
    instance.log(level, message);
  });

  instance.registerHelper('lookup', function(obj, field) {
    return obj && obj[field];
  });
}

var logger = {
  methodMap: { 0: 'debug', 1: 'info', 2: 'warn', 3: 'error' },

  // State enum
  DEBUG: 0,
  INFO: 1,
  WARN: 2,
  ERROR: 3,
  level: 1,

  // Can be overridden in the host environment
  log: function(level, message) {
    if (typeof console !== 'undefined' && logger.level <= level) {
      var method = logger.methodMap[level];
      (console[method] || console.log).call(console, message);
    }
  }
};
exports.logger = logger;
var log = logger.log;
exports.log = log;
var createFrame = function(object) {
  var frame = Utils.extend({}, object);
  frame._parent = object;
  return frame;
};
exports.createFrame = createFrame;
},{"./exception":36,"./utils":39}],36:[function(require,module,exports){
"use strict";

var errorProps = ['description', 'fileName', 'lineNumber', 'message', 'name', 'number', 'stack'];

function Exception(message, node) {
  var loc = node && node.loc,
      line,
      column;
  if (loc) {
    line = loc.start.line;
    column = loc.start.column;

    message += ' - ' + line + ':' + column;
  }

  var tmp = Error.prototype.constructor.call(this, message);

  // Unfortunately errors are not enumerable in Chrome (at least), so `for prop in tmp` doesn't work.
  for (var idx = 0; idx < errorProps.length; idx++) {
    this[errorProps[idx]] = tmp[errorProps[idx]];
  }

  if (loc) {
    this.lineNumber = line;
    this.column = column;
  }
}

Exception.prototype = new Error();

exports["default"] = Exception;
},{}],37:[function(require,module,exports){
"use strict";
var Utils = require("./utils");
var Exception = require("./exception")["default"];
var COMPILER_REVISION = require("./base").COMPILER_REVISION;
var REVISION_CHANGES = require("./base").REVISION_CHANGES;
var createFrame = require("./base").createFrame;

function checkRevision(compilerInfo) {
  var compilerRevision = compilerInfo && compilerInfo[0] || 1,
      currentRevision = COMPILER_REVISION;

  if (compilerRevision !== currentRevision) {
    if (compilerRevision < currentRevision) {
      var runtimeVersions = REVISION_CHANGES[currentRevision],
          compilerVersions = REVISION_CHANGES[compilerRevision];
      throw new Exception("Template was precompiled with an older version of Handlebars than the current runtime. "+
            "Please update your precompiler to a newer version ("+runtimeVersions+") or downgrade your runtime to an older version ("+compilerVersions+").");
    } else {
      // Use the embedded version info since the runtime doesn't know about this revision yet
      throw new Exception("Template was precompiled with a newer version of Handlebars than the current runtime. "+
            "Please update your runtime to a newer version ("+compilerInfo[1]+").");
    }
  }
}

exports.checkRevision = checkRevision;// TODO: Remove this line and break up compilePartial

function template(templateSpec, env) {
  /* istanbul ignore next */
  if (!env) {
    throw new Exception("No environment passed to template");
  }
  if (!templateSpec || !templateSpec.main) {
    throw new Exception('Unknown template object: ' + typeof templateSpec);
  }

  // Note: Using env.VM references rather than local var references throughout this section to allow
  // for external users to override these as psuedo-supported APIs.
  env.VM.checkRevision(templateSpec.compiler);

  var invokePartialWrapper = function(partial, context, options) {
    if (options.hash) {
      context = Utils.extend({}, context, options.hash);
    }

    partial = env.VM.resolvePartial.call(this, partial, context, options);
    var result = env.VM.invokePartial.call(this, partial, context, options);

    if (result == null && env.compile) {
      options.partials[options.name] = env.compile(partial, templateSpec.compilerOptions, env);
      result = options.partials[options.name](context, options);
    }
    if (result != null) {
      if (options.indent) {
        var lines = result.split('\n');
        for (var i = 0, l = lines.length; i < l; i++) {
          if (!lines[i] && i + 1 === l) {
            break;
          }

          lines[i] = options.indent + lines[i];
        }
        result = lines.join('\n');
      }
      return result;
    } else {
      throw new Exception("The partial " + options.name + " could not be compiled when running in runtime-only mode");
    }
  };

  // Just add water
  var container = {
    strict: function(obj, name) {
      if (!(name in obj)) {
        throw new Exception('"' + name + '" not defined in ' + obj);
      }
      return obj[name];
    },
    lookup: function(depths, name) {
      var len = depths.length;
      for (var i = 0; i < len; i++) {
        if (depths[i] && depths[i][name] != null) {
          return depths[i][name];
        }
      }
    },
    lambda: function(current, context) {
      return typeof current === 'function' ? current.call(context) : current;
    },

    escapeExpression: Utils.escapeExpression,
    invokePartial: invokePartialWrapper,

    fn: function(i) {
      return templateSpec[i];
    },

    programs: [],
    program: function(i, data, declaredBlockParams, blockParams, depths) {
      var programWrapper = this.programs[i],
          fn = this.fn(i);
      if (data || depths || blockParams || declaredBlockParams) {
        programWrapper = program(this, i, fn, data, declaredBlockParams, blockParams, depths);
      } else if (!programWrapper) {
        programWrapper = this.programs[i] = program(this, i, fn);
      }
      return programWrapper;
    },

    data: function(data, depth) {
      while (data && depth--) {
        data = data._parent;
      }
      return data;
    },
    merge: function(param, common) {
      var ret = param || common;

      if (param && common && (param !== common)) {
        ret = Utils.extend({}, common, param);
      }

      return ret;
    },

    noop: env.VM.noop,
    compilerInfo: templateSpec.compiler
  };

  var ret = function(context, options) {
    options = options || {};
    var data = options.data;

    ret._setup(options);
    if (!options.partial && templateSpec.useData) {
      data = initData(context, data);
    }
    var depths,
        blockParams = templateSpec.useBlockParams ? [] : undefined;
    if (templateSpec.useDepths) {
      depths = options.depths ? [context].concat(options.depths) : [context];
    }

    return templateSpec.main.call(container, context, container.helpers, container.partials, data, blockParams, depths);
  };
  ret.isTop = true;

  ret._setup = function(options) {
    if (!options.partial) {
      container.helpers = container.merge(options.helpers, env.helpers);

      if (templateSpec.usePartial) {
        container.partials = container.merge(options.partials, env.partials);
      }
    } else {
      container.helpers = options.helpers;
      container.partials = options.partials;
    }
  };

  ret._child = function(i, data, blockParams, depths) {
    if (templateSpec.useBlockParams && !blockParams) {
      throw new Exception('must pass block params');
    }
    if (templateSpec.useDepths && !depths) {
      throw new Exception('must pass parent depths');
    }

    return program(container, i, templateSpec[i], data, 0, blockParams, depths);
  };
  return ret;
}

exports.template = template;function program(container, i, fn, data, declaredBlockParams, blockParams, depths) {
  var prog = function(context, options) {
    options = options || {};

    return fn.call(container,
        context,
        container.helpers, container.partials,
        options.data || data,
        blockParams && [options.blockParams].concat(blockParams),
        depths && [context].concat(depths));
  };
  prog.program = i;
  prog.depth = depths ? depths.length : 0;
  prog.blockParams = declaredBlockParams || 0;
  return prog;
}

exports.program = program;function resolvePartial(partial, context, options) {
  if (!partial) {
    partial = options.partials[options.name];
  } else if (!partial.call && !options.name) {
    // This is a dynamic partial that returned a string
    options.name = partial;
    partial = options.partials[partial];
  }
  return partial;
}

exports.resolvePartial = resolvePartial;function invokePartial(partial, context, options) {
  options.partial = true;

  if(partial === undefined) {
    throw new Exception("The partial " + options.name + " could not be found");
  } else if(partial instanceof Function) {
    return partial(context, options);
  }
}

exports.invokePartial = invokePartial;function noop() { return ""; }

exports.noop = noop;function initData(context, data) {
  if (!data || !('root' in data)) {
    data = data ? createFrame(data) : {};
    data.root = context;
  }
  return data;
}
},{"./base":35,"./exception":36,"./utils":39}],38:[function(require,module,exports){
"use strict";
// Build out our basic SafeString type
function SafeString(string) {
  this.string = string;
}

SafeString.prototype.toString = SafeString.prototype.toHTML = function() {
  return "" + this.string;
};

exports["default"] = SafeString;
},{}],39:[function(require,module,exports){
"use strict";
/*jshint -W004 */
var escape = {
  "&": "&amp;",
  "<": "&lt;",
  ">": "&gt;",
  '"': "&quot;",
  "'": "&#x27;",
  "`": "&#x60;"
};

var badChars = /[&<>"'`]/g;
var possible = /[&<>"'`]/;

function escapeChar(chr) {
  return escape[chr];
}

function extend(obj /* , ...source */) {
  for (var i = 1; i < arguments.length; i++) {
    for (var key in arguments[i]) {
      if (Object.prototype.hasOwnProperty.call(arguments[i], key)) {
        obj[key] = arguments[i][key];
      }
    }
  }

  return obj;
}

exports.extend = extend;var toString = Object.prototype.toString;
exports.toString = toString;
// Sourced from lodash
// https://github.com/bestiejs/lodash/blob/master/LICENSE.txt
var isFunction = function(value) {
  return typeof value === 'function';
};
// fallback for older versions of Chrome and Safari
/* istanbul ignore next */
if (isFunction(/x/)) {
  isFunction = function(value) {
    return typeof value === 'function' && toString.call(value) === '[object Function]';
  };
}
var isFunction;
exports.isFunction = isFunction;
/* istanbul ignore next */
var isArray = Array.isArray || function(value) {
  return (value && typeof value === 'object') ? toString.call(value) === '[object Array]' : false;
};
exports.isArray = isArray;
// Older IE versions do not directly support indexOf so we must implement our own, sadly.
function indexOf(array, value) {
  for (var i = 0, len = array.length; i < len; i++) {
    if (array[i] === value) {
      return i;
    }
  }
  return -1;
}

exports.indexOf = indexOf;
function escapeExpression(string) {
  // don't escape SafeStrings, since they're already safe
  if (string && string.toHTML) {
    return string.toHTML();
  } else if (string == null) {
    return "";
  } else if (!string) {
    return string + '';
  }

  // Force a string conversion as this will be done by the append regardless and
  // the regex test will do this transparently behind the scenes, causing issues if
  // an object's to string has escaped characters in it.
  string = "" + string;

  if(!possible.test(string)) { return string; }
  return string.replace(badChars, escapeChar);
}

exports.escapeExpression = escapeExpression;function isEmpty(value) {
  if (!value && value !== 0) {
    return true;
  } else if (isArray(value) && value.length === 0) {
    return true;
  } else {
    return false;
  }
}

exports.isEmpty = isEmpty;function blockParams(params, ids) {
  params.path = ids;
  return params;
}

exports.blockParams = blockParams;function appendContextPath(contextPath, id) {
  return (contextPath ? contextPath + '.' : '') + id;
}

exports.appendContextPath = appendContextPath;
},{}],40:[function(require,module,exports){
// Create a simple path alias to allow browserify to resolve
// the runtime on a supported path.
module.exports = require('./dist/cjs/handlebars.runtime').default;

},{"./dist/cjs/handlebars.runtime":34}],41:[function(require,module,exports){
module.exports = require("handlebars/runtime")["default"];

},{"handlebars/runtime":40}],42:[function(require,module,exports){
'use strict';
var repeating = require('repeating');

module.exports = function (str, indent, count) {
	if (typeof str !== 'string' || typeof indent !== 'string') {
		throw new TypeError('`string` and `indent` should be strings');
	}

	if (count != null && typeof count !== 'number') {
		throw new TypeError('`count` should be a number');
	}

	indent = count > 1 ? repeating(indent, count) : indent;

	return str.replace(/^(?!\s*$)/mg, indent);
};

},{"repeating":43}],43:[function(require,module,exports){
'use strict';
var isFinite = require('is-finite');

module.exports = function (str, n) {
	if (typeof str !== 'string') {
		throw new TypeError('Expected a string as the first argument');
	}

	if (n < 0 || !isFinite(n)) {
		throw new TypeError('Expected a finite positive number');
	}

	var ret = '';

	do {
		if (n & 1) {
			ret += str;
		}

		str += str;
	} while (n = n >> 1);

	return ret;
};

},{"is-finite":44}],44:[function(require,module,exports){
'use strict';
module.exports = Number.isFinite || function (val) {
	// Number.isNaN() => val !== val
	if (typeof val !== 'number' || val !== val || val === Infinity || val === -Infinity) {
		return false;
	}

	return true;
};

},{}],45:[function(require,module,exports){
(function (Buffer){
(function (root, stringify) {
  /* istanbul ignore else */
  if (typeof require === 'function' && typeof exports === 'object' && typeof module === 'object') {
    // Node.
    module.exports = stringify();
  } else if (typeof define === 'function' && define.amd) {
    // AMD, registers as an anonymous module.
    define(function () {
      return stringify();
    });
  } else {
    // Browser global.
    root.javascriptStringify = stringify();
  }
})(this, function () {
  /**
   * Match all characters that need to be escaped in a string. Modified from
   * source to match single quotes instead of double.
   *
   * Source: https://github.com/douglascrockford/JSON-js/blob/master/json2.js
   *
   * @type {RegExp}
   */
  var ESCAPABLE = /[\\\'\x00-\x1f\x7f-\x9f\u00ad\u0600-\u0604\u070f\u17b4\u17b5\u200c-\u200f\u2028-\u202f\u2060-\u206f\ufeff\ufff0-\uffff]/g;

  /**
   * Map of characters to escape characters.
   *
   * @type {Object}
   */
  var META_CHARS = {
    '\b': '\\b',
    '\t': '\\t',
    '\n': '\\n',
    '\f': '\\f',
    '\r': '\\r',
    "'":  "\\'",
    '"':  '\\"',
    '\\': '\\\\'
  };

  /**
   * Escape any character into its literal JavaScript string.
   *
   * @param  {String} char
   * @return {String}
   */
  var escapeChar = function (char) {
    var meta = META_CHARS[char];

    return meta || '\\u' + ('0000' + char.charCodeAt(0).toString(16)).slice(-4);
  };

  /**
   * JavaScript reserved word list.
   */
  var RESERVED_WORDS = {};

  /**
   * Map reserved words to the object.
   */
  (
    'break else new var case finally return void catch for switch while ' +
    'continue function this with default if throw delete in try ' +
    'do instanceof typeof abstract enum int short boolean export ' +
    'interface static byte extends long super char final native synchronized ' +
    'class float package throws const goto private transient debugger ' +
    'implements protected volatile double import public let yield'
  ).split(' ').map(function (key) {
    RESERVED_WORDS[key] = true;
  });

  /**
   * Check if a variable name is valid.
   *
   * @param  {String}  name
   * @return {Boolean}
   */
  var isValidVariableName = function (name) {
    return !RESERVED_WORDS[name] && /^[a-zA-Z_$][0-9a-zA-Z_$]*$/.test(name);
  };

  /**
   * Return the global variable name.
   *
   * @return {String}
   */
  var getGlobalVariable = function (value, indent, stringify) {
    return 'Function(' + stringify('return this;') + ')()';
  };

  /**
   * Convert JavaScript objects into strings.
   *
   * @type {Object}
   */
  var OBJECT_TYPES = {
    '[object Array]': function (array, indent, stringify) {
      // Map array values to their stringified values with correct indentation.
      var values = array.map(function (value) {
        return indent + stringify(value).split('\n').join('\n' + indent);
      }).join(indent ? ',\n' : ',');

      // Wrap the array in newlines if we have indentation set.
      if (indent && values) {
        return '[\n' + values + '\n]';
      }

      return '[' + values + ']';
    },
    '[object Object]': function (object, indent, stringify) {
      if (typeof Buffer === 'function' && Buffer.isBuffer(object)) {
        return 'new Buffer(' + stringify(object.toString()) + ')';
      }

      // Iterate over object keys and concat string together.
      var values = Object.keys(object).reduce(function (values, key) {
        var value = stringify(object[key]);

        // Omit `undefined` object values.
        if (value === undefined) {
          return values;
        }

        // String format the key and value data.
        key   = isValidVariableName(key) ? key : stringify(key);
        value = String(value).split('\n').join('\n' + indent);

        // Push the current object key and value into the values array.
        values.push(indent + key + ':' + (indent ? ' ' : '') + value);

        return values;
      }, []).join(indent ? ',\n' : ',');

      // Wrap the object in newlines if we have indentation set.
      if (indent && values) {
        return '{\n' + values + '\n}';
      }

      return '{' + values + '}';
    },
    '[object Date]': function (date, indent, stringify) {
      return 'new Date(' + date.getTime() + ')';
    },
    '[object String]': function (string, indent, stringify) {
      return 'new String(' + stringify(string.toString()) + ')';
    },
    '[object Number]': function (number, indent, stringify) {
      return 'new Number(' + number + ')';
    },
    '[object Boolean]': function (boolean, indent, stringify) {
      return 'new Boolean(' + boolean + ')';
    },
    '[object RegExp]': String,
    '[object Function]': String,
    '[object global]': getGlobalVariable,
    '[object Window]': getGlobalVariable
  };

  /**
   * Convert JavaScript primitives into strings.
   *
   * @type {Object}
   */
  var PRIMITIVE_TYPES = {
    'string': function (string) {
      return "'" + string.replace(ESCAPABLE, escapeChar) + "'";
    },
    'number': String,
    'object': String,
    'boolean': String,
    'undefined': String
  };

  /**
   * Convert any value to a string.
   *
   * @param  {*}        value
   * @param  {String}   indent
   * @param  {Function} stringify
   * @return {String}
   */
  var stringify = function (value, indent, stringify) {
    // Convert primitives into strings.
    if (Object(value) !== value) {
      return PRIMITIVE_TYPES[typeof value](value, indent, stringify);
    }

    // Use the internal object string to select stringification method.
    var toString = OBJECT_TYPES[Object.prototype.toString.call(value)];

    // Convert objects into strings.
    return toString && toString(value, indent, stringify);
  };

  /**
   * Stringify an object into the literal string.
   *
   * @param  {Object}          value
   * @param  {Function}        [replacer]
   * @param  {(Number|String)} [space]
   * @return {String}
   */
  return function (value, replacer, space) {
    // Convert the spaces into a string.
    if (typeof space !== 'string') {
      space = new Array(Math.max(0, space|0) + 1).join(' ');
    }

    /**
     * Handle recursion by checking if we've visited this node every iteration.
     *
     * @param  {*}      value
     * @param  {Array}  cache
     * @return {String}
     */
    var recurse = function (value, cache, next) {
      // If we've already visited this node before, break the recursion.
      if (cache.indexOf(value) > -1) {
        return;
      }

      // Push the value into the values cache to avoid an infinite loop.
      cache.push(value);

      // Stringify the value and fallback to
      return next(value, space, function (value) {
        return recurse(value, cache.slice(), next);
      });
    };

    // If the user defined a replacer function, make the recursion function
    // a double step process - `replacer -> stringify -> replacer -> etc`.
    if (typeof replacer === 'function') {
      return recurse(value, [], function (value, space, next) {
        return replacer(value, space, function (value) {
          return stringify(value, space, next);
        });
      });
    }

    return recurse(value, [], stringify);
  };
});

}).call(this,require("buffer").Buffer)
},{"buffer":23}],46:[function(require,module,exports){
/**
 * Special language-specific overrides.
 *
 * Source: ftp://ftp.unicode.org/Public/UCD/latest/ucd/SpecialCasing.txt
 *
 * @type {Object}
 */
var LANGUAGES = {
  tr: {
    regexp: /\u0130|\u0049|\u0049\u0307/g,
    map: {
      '\u0130': '\u0069',
      '\u0049': '\u0131',
      '\u0049\u0307': '\u0069'
    }
  },
  az: {
    regexp: /[\u0130]/g,
    map: {
      '\u0130': '\u0069',
      '\u0049': '\u0131',
      '\u0049\u0307': '\u0069'
    }
  },
  lt: {
    regexp: /[\u0049\u004A\u012E\u00CC\u00CD\u0128]/g,
    map: {
      '\u0049': '\u0069\u0307',
      '\u004A': '\u006A\u0307',
      '\u012E': '\u012F\u0307',
      '\u00CC': '\u0069\u0307\u0300',
      '\u00CD': '\u0069\u0307\u0301',
      '\u0128': '\u0069\u0307\u0303'
    }
  }
}

/**
 * Lowercase a string.
 *
 * @param  {String} str
 * @return {String}
 */
module.exports = function (str, locale) {
  var lang = LANGUAGES[locale]

  str = str == null ? '' : String(str)

  if (lang) {
    str = str.replace(lang.regexp, function (m) { return lang.map[m] })
  }

  return str.toLowerCase()
}

},{}],47:[function(require,module,exports){

var http = require('http');

/* istanbul ignore next: implementation differs on version */
if (http.METHODS) {

  module.exports = http.METHODS.map(function(method){
    return method.toLowerCase();
  });

} else {

  module.exports = [
    'get',
    'post',
    'put',
    'head',
    'delete',
    'options',
    'trace',
    'copy',
    'lock',
    'mkcol',
    'move',
    'purge',
    'propfind',
    'proppatch',
    'unlock',
    'report',
    'mkactivity',
    'checkout',
    'merge',
    'm-search',
    'notify',
    'subscribe',
    'unsubscribe',
    'patch',
    'search',
    'connect'
  ];

}

},{"http":22}],48:[function(require,module,exports){
/*!
 * object.pick <https://github.com/jonschlinkert/object.pick>
 *
 * Copyright (c) 2014-2015 Jon Schlinkert, contributors.
 * Licensed under the MIT License
 */

'use strict';

module.exports = function pick(obj, keys) {
  var res = {};
  var i = 0;

  if (typeof obj !== 'object') {
    return res;
  }

  if (typeof keys === 'string') {
    if (keys in obj) {
      res[keys] = obj[keys];
    }
    return res;
  }

  var len = keys.length;

  while (len--) {
    var key = keys[i++];
    if (key in obj) {
      res[key] = obj[key];
    }
  }
  return res;
};

},{}],49:[function(require,module,exports){
arguments[4][28][0].apply(exports,arguments)
},{"./vendor/camel-case-regexp":50,"./vendor/non-word-regexp":51,"./vendor/trailing-digit-regexp":52,"dup":28,"lower-case":46}],50:[function(require,module,exports){
arguments[4][29][0].apply(exports,arguments)
},{"dup":29}],51:[function(require,module,exports){
arguments[4][30][0].apply(exports,arguments)
},{"dup":30}],52:[function(require,module,exports){
arguments[4][31][0].apply(exports,arguments)
},{"dup":31}],53:[function(require,module,exports){
var sentenceCase = require('sentence-case');

/**
 * Param case a string.
 *
 * @param  {String} string
 * @param  {String} [locale]
 * @return {String}
 */
module.exports = function (string, locale) {
  return sentenceCase(string, locale, '-');
};

},{"sentence-case":49}],54:[function(require,module,exports){
var upperCase = require('upper-case');

/**
 * Upper case the first character of a string.
 *
 * @param  {String} str
 * @return {String}
 */
module.exports = function (str, locale) {
  if (str == null) {
    return '';
  }

  str = String(str);

  return upperCase(str.charAt(0), locale) + str.substr(1);
};

},{"upper-case":61}],55:[function(require,module,exports){
var camelCase      = require('camel-case');
var upperCaseFirst = require('upper-case-first');

/**
 * Pascal case a string.
 *
 * @param  {String} string
 * @param  {String} [locale]
 * @return {String}
 */
module.exports = function (string, locale) {
  return upperCaseFirst(camelCase(string, locale), locale);
};

},{"camel-case":27,"upper-case-first":54}],56:[function(require,module,exports){
arguments[4][28][0].apply(exports,arguments)
},{"./vendor/camel-case-regexp":57,"./vendor/non-word-regexp":58,"./vendor/trailing-digit-regexp":59,"dup":28,"lower-case":46}],57:[function(require,module,exports){
arguments[4][29][0].apply(exports,arguments)
},{"dup":29}],58:[function(require,module,exports){
arguments[4][30][0].apply(exports,arguments)
},{"dup":30}],59:[function(require,module,exports){
arguments[4][31][0].apply(exports,arguments)
},{"dup":31}],60:[function(require,module,exports){
var sentenceCase = require('sentence-case');

/**
 * Snake case a string.
 *
 * @param  {String} str
 * @param  {String} [locale]
 * @return {String}
 */
module.exports = function (str, locale) {
  return sentenceCase(str, locale, '_');
};

},{"sentence-case":56}],61:[function(require,module,exports){
/**
 * Special language-specific overrides.
 *
 * Source: ftp://ftp.unicode.org/Public/UCD/latest/ucd/SpecialCasing.txt
 *
 * @type {Object}
 */
var LANGUAGES = {
  tr: {
    regexp: /[\u0069]/g,
    map: {
      '\u0069': '\u0130'
    }
  },
  az: {
    regexp: /[\u0069]/g,
    map: {
      '\u0069': '\u0130'
    }
  },
  lt: {
    regexp: /[\u0069\u006A\u012F]\u0307|\u0069\u0307[\u0300\u0301\u0303]/g,
    map: {
      '\u0069\u0307': '\u0049',
      '\u006A\u0307': '\u004A',
      '\u012F\u0307': '\u012E',
      '\u0069\u0307\u0300': '\u00CC',
      '\u0069\u0307\u0301': '\u00CD',
      '\u0069\u0307\u0303': '\u0128'
    }
  }
}

/**
 * Upper case a string.
 *
 * @param  {String} str
 * @return {String}
 */
module.exports = function (str, locale) {
  var lang = LANGUAGES[locale]

  str = str == null ? '' : String(str)

  if (lang) {
    str = str.replace(lang.regexp, function (m) { return lang.map[m] })
  }

  return str.toUpperCase()
}

},{}],62:[function(require,module,exports){
/**
 * Export all implemented languages.
 */
exports.javascript = require('./javascript');

},{"./javascript":4}]},{},[62])(62)
});
(function (window) {
  'use strict';

  // Namespaces
  RAML.Directives     = {};
  RAML.Services       = {};
  RAML.Filters        = {};
  RAML.Services.TryIt = {};
  RAML.Security       = {};
  RAML.Settings       = RAML.Settings || {};

  // Angular Modules
  angular.module('RAML.Directives', []);
  angular.module('raml', []);
  angular.module('RAML.Services', ['raml']);
  angular.module('RAML.Security', []);
  angular.module('ramlConsoleApp', [
    'RAML.Directives',
    'RAML.Services',
    'RAML.Security',
    'hc.marked',
    'ui.codemirror',
    'hljs',
    'ngSanitize'
  ]).config(['hljsServiceProvider', function (hljsServiceProvider) {
    hljsServiceProvider.setOptions({
      classPrefix: 'raml-console-hljs-'
    });
  }]);

  var loc = window.location;
  var uri = loc.protocol + '//' + loc.host + loc.pathname.replace(/\/$/, '');

  window.hljs.configure({
    classPrefix: 'raml-console-hljs-'
  });

  // Settings
  RAML.Settings.proxy             = RAML.Settings.proxy || false;
  RAML.Settings.oauth2RedirectUri = RAML.Settings.oauth2RedirectUri || uri + '/authentication/oauth2.html';
  RAML.Settings.oauth1RedirectUri = RAML.Settings.oauth1RedirectUri || uri + '/authentication/oauth1.html';
  RAML.Settings.marked            = {
    gfm: true,
    tables: true,
    breaks: true,
    pedantic: false,
    sanitize: false,
    smartLists: true,
    silent: false,
    langPrefix: 'lang-',
    smartypants: false,
    headerPrefix: '',
    renderer: new window.marked.Renderer(),
    xhtml: false,
    highlight: function (code, lang) {
      var result = [
        '<pre class="raml-console-resource-pre raml-console-hljs hljs">',
        lang ? window.hljs.highlightAuto(code).value : code,
        '</pre>'
      ];

      return result.join('');
    }
  };
})(window);

(function () {
  'use strict';

  RAML.Directives.clickOutside = function ($document) {
    return {
      restrict: 'A',
      link: function ($scope, $element, $attrs) {
        function onClick (e) {
          if ($element[0] === e.target || $element.has(e.target).length) {
            return;
          }

          $scope.$apply($attrs.clickOutside);
        }

        $document.on('click', onClick);

        $scope.$on('$destroy', function () {
          $document.off('click', onClick);
        });
      }
    };
  };

  angular.module('RAML.Directives')
    .directive('clickOutside', ['$document', RAML.Directives.clickOutside]);
})();

(function () {
  'use strict';

  RAML.Directives.closeButton = function() {
    return {
      restrict: 'E',
      templateUrl: 'directives/close-button.tpl.html',
      replace: true,
      controller: ['$scope', '$rootScope', function($scope, $rootScope) {
        $scope.close = function () {
          var $inactiveElements = jQuery('.raml-console-tab').add('.raml-console-resource').add('li');

          $rootScope.$broadcast('resetData');
          $inactiveElements.removeClass('raml-console-is-active');
          $scope.showPanel = false;
          $scope.traits = null;
          $scope.methodInfo = {};
        };
      }]
    };
  };

  angular.module('RAML.Directives')
    .directive('closeButton', RAML.Directives.closeButton);
})();

(function () {
  'use strict';

  RAML.Directives.documentation = function() {
    return {
      restrict: 'E',
      templateUrl: 'directives/documentation.tpl.html',
      controller: ['$scope', function($scope) {
        var defaultSchemaKey = Object.keys($scope.securitySchemes).sort()[0];
        var defaultSchema    = $scope.securitySchemes[defaultSchemaKey];

        $scope.markedOptions = RAML.Settings.marked;
        $scope.documentationSchemeSelected = defaultSchema;

        function mergeResponseCodes(methodCodes, schemas) {
          var extractSchema = function (key) { return schemas.hasOwnProperty(key) ? schemas[key] : undefined; };
          var isValidSchema = function (schema) { return schema.describedBy && schema.describedBy.responses; };

          var codes = {};

          // Copy all method codes
          Object.keys(methodCodes).forEach(function (code) {
            if (methodCodes.hasOwnProperty(code)) { codes[code] = methodCodes[code]; }
          });

          // Copy schema's code that are not present in the method
          Object.keys(schemas)
            .map(extractSchema)
            .filter(isValidSchema)
            .forEach(function (schema) {
              copyToCodesIfNotPresent(codes, schema.describedBy.responses);
            });

          return codes;
        }

        function copyToCodesIfNotPresent(codes, schemaCodes) {
          if (Array.isArray(schemaCodes)) {
            schemaCodes.forEach(function (response) {
              if (!codes.hasOwnProperty(response.code)) {
                codes[response.code] = response.code;
              }
            });
          } else {
            Object.keys(schemaCodes).forEach(function (code) {
              if (schemaCodes.hasOwnProperty(code) && !codes.hasOwnProperty(code)) {
                codes[code] = schemaCodes[code];
              }
            });
          }
        }
        $scope.fullResponses = mergeResponseCodes($scope.methodInfo.responses || {}, $scope.methodInfo.securitySchemes());
        $scope.fullResponseCodes = Object.keys($scope.fullResponses);

        $scope.isSchemeSelected = function isSchemeSelected(scheme) {
          return scheme.id === $scope.documentationSchemeSelected.id;
        };

        $scope.selectDocumentationScheme = function selectDocumentationScheme(scheme) {
          $scope.documentationSchemeSelected = scheme;
        };

        $scope.schemaSettingsDocumentation = function schemaSettingsDocumentation(settings) {
          var doc = settings;

          if (typeof settings === 'object') {
            doc = settings.join(', ');
          }

          return doc;
        };

        $scope.unique = function (arr) {
          return arr.filter (function (v, i, a) { return a.indexOf (v) === i; });
        };

        $scope.currentStatusCode = '200';

        if ($scope.fullResponseCodes && $scope.fullResponseCodes.length > 0) {
          $scope.currentStatusCode = $scope.fullResponseCodes[0];
        }

        $scope.$on('resetData', function() {
          if ($scope.fullResponseCodes && $scope.fullResponseCodes.length > 0) {
            $scope.currentStatusCode = $scope.fullResponseCodes[0];
          }
        });

        function beautify(body, contentType) {
          if(contentType.indexOf('json') !== -1) {
            body = vkbeautify.json(body, 2);
          }

          if(contentType.indexOf('xml') !== -1) {
            body = vkbeautify.xml(body, 2);
          }

          return body;
        }

        $scope.getBeatifiedExample = function (value) {
          var result = value;

          try {
            result = beautify(value, $scope.currentBodySelected);
          }
          catch (e) { }

          return result;
        };

        $scope.getColorCode = function (code) {
          return code[0] + 'xx';
        };

        $scope.showCodeDetails = function (code) {
          $scope.currentStatusCode = code;
        };

        $scope.isActiveCode = function (code) {
          return $scope.currentStatusCode === code;
        };

        $scope.showRequestDocumentation = true;
        $scope.toggleRequestDocumentation = function () {
          $scope.showRequestDocumentation = !$scope.showRequestDocumentation;
        };

        $scope.showResponseDocumentation = true;
        $scope.toggleResponseDocumentation = function () {
          $scope.showResponseDocumentation = !$scope.showResponseDocumentation;
        };

        $scope.parameterDocumentation = function (parameter) {
          var result = '';

          if (parameter) {
            if (parameter.required) {
              result += 'required, ';
            }

            if (parameter['enum']) {
              var enumValues = $scope.unique(parameter['enum']);

              if (enumValues.length > 1) {
                result += 'one of ';
              }

              result += '(' + enumValues.filter(function (value) { return value !== ''; }).join(', ') + ')';

            } else {
              result += parameter.type || '';
            }

            if (parameter.pattern) {
              result += ' matching ' + parameter.pattern;
            }

            if (parameter.minLength && parameter.maxLength) {
              result += ', ' + parameter.minLength + '-' + parameter.maxLength + ' characters';
            } else if (parameter.minLength && !parameter.maxLength) {
              result += ', at least ' + parameter.minLength + ' characters';
            } else if (parameter.maxLength && !parameter.minLength) {
              result += ', at most ' + parameter.maxLength + ' characters';
            }


            if (parameter.minimum && parameter.maximum) {
              result += ' between ' + parameter.minimum + '-' + parameter.maximum;
            } else if (parameter.minimum && !parameter.maximum) {
              result += ' ≥ ' + parameter.minimum;
            } else if (parameter.maximum && !parameter.minimum) {
              result += ' ≤ ' + parameter.maximum;
            }

            if (parameter.repeat) {
              result += ', repeatable';
            }

            if (parameter['default'] !== undefined) {
              result += ', default: ' + parameter['default'];
            }
          }

          return result;
        };

        $scope.toggleTab = function ($event) {
          var $this        = jQuery($event.currentTarget);
          var $eachTab     = $this.parent().children('.raml-console-toggle-tab');
          var $panel       = $this.closest('.raml-console-resource-panel');
          var $eachContent = $panel.find('.raml-console-resource-panel-content');

          if (!$this.hasClass('raml-console-is-active')) {
            $eachTab.toggleClass('raml-console-is-active');
            $eachContent.toggleClass('raml-console-is-active');
          }
        };

        $scope.changeType = function ($event, type, code) {
          var $this        = jQuery($event.currentTarget);
          var $panel       = $this.closest('.raml-console-resource-body-heading');
          var $eachContent = $panel.find('span');

          $eachContent.removeClass('raml-console-is-active');
          $this.addClass('raml-console-is-active');

          $scope.responseInfo[code].currentType = type;
        };

        $scope.changeResourceBodyType = function ($event, type) {
          var $this        = jQuery($event.currentTarget);
          var $panel       = $this.closest('.raml-console-request-body-heading');
          var $eachContent = $panel.find('span');

          $eachContent.removeClass('raml-console-is-active');
          $this.addClass('raml-console-is-active');

          $scope.currentBodySelected = type;
        };

        $scope.getBodyId = function (bodyType) {
          return jQuery.trim(bodyType.toString().replace(/\W/g, ' ')).replace(/\s+/g, '_');
        };

        $scope.bodySelected = function (value) {
          return value === $scope.currentBodySelected;
        };

        $scope.$watch('currentBodySelected', function (value) {
          var $container = jQuery('.raml-console-request-body-heading');
          var $elements  = $container.find('span');

          $elements.removeClass('raml-console-is-active');
          $container.find('.raml-console-body-' + $scope.getBodyId(value)).addClass('raml-console-is-active');
        });

        $scope.$watch('methodInfo.responses', function (responses) {
          $scope.methodInfo.responses = responses;
          $scope.fullResponses = mergeResponseCodes($scope.methodInfo.responses || {}, $scope.methodInfo.securitySchemes());
          $scope.fullResponseCodes = Object.keys($scope.fullResponses);
          if ($scope.fullResponseCodes && $scope.fullResponseCodes.length > 0) {
            $scope.currentStatusCode = $scope.fullResponseCodes[0];
          }
        });

      }],
      replace: true
    };
  };

  angular.module('RAML.Directives')
    .directive('documentation', RAML.Directives.documentation);
})();

(function () {
  'use strict';
  angular.module('RAML.Directives').directive('dynamicName', ['$parse', function($parse) {
    return {
      restrict: 'A',
      controller: ['$scope', '$element', '$attrs', function($scope, $element, $attrs){
        var name = $parse($attrs.dynamicName)($scope);

        delete($attrs.dynamicName);
        $element.removeAttr('data-dynamic-name');
        $element.removeAttr('dynamic-name');
        $attrs.$set('name', name);
      }]
    };
  }]);
})();

(function () {
  'use strict';

  RAML.Directives.examples = function() {
    return {
      restrict: 'E',
      templateUrl: 'directives/examples.tpl.html',
      scope: {
        exampleContainer: '=',
        getBeatifiedExampleRef: '&'
      },
      controller: ['$scope', function($scope) {
        $scope.getBeatifiedExample = $scope.getBeatifiedExampleRef();
        $scope.examples = transformExample($scope.exampleContainer);
        $scope.currentExample = 0;

        $scope.isXML = $scope.exampleContainer.name === 'application/xml';

        $scope.changeExample = function(example) {
          $scope.currentExample = example;
        };

        $scope.$watch('exampleContainer', function (value) {
          $scope.examples = transformExample(value);
        });
      }]
    };
  };

  function transformExample(exampleContainer) {
    if (exampleContainer.example) {
      return [{
        name: 'Example',
        content: (typeof exampleContainer.example === 'object') ?
            JSON.stringify(exampleContainer.example, null, 2) : exampleContainer.example
      }];
    } else if (exampleContainer.examples) {
      if (Array.isArray(exampleContainer.examples)) {
        return exampleContainer.examples.map(function (example, index) {
          return {
            name: example.name || 'Example ' + index,
            content: (typeof example.value === 'object') ?
                JSON.stringify(example.value, null, 2) : example.value
          };
        });
      } else {
        return Object.keys(exampleContainer.examples).sort().map(function (key) {
          return {
            name: key,
            content: exampleContainer.examples[key].value
          };
        });
      }
    }
  }

  angular.module('RAML.Directives')
    .directive('examples', RAML.Directives.examples);
})();

(function () {
  'use strict';

  RAML.Directives.markdown = function() {
    return {
      restrict: 'A',
      scope: {
        markdown: '='
      },
      controller: ['$scope', '$sanitize', '$window', '$element', function($scope, $sanitize, $window, $element) {
        $scope.$watch('markdown', function (markdown) {
          var allowUnsafeMarkdown = $scope.$parent.allowUnsafeMarkdown;
          var html = $window.marked(markdown || '', RAML.Settings.marked);

          if (!allowUnsafeMarkdown) {
            html = $sanitize(html);
          }

          $element.html(html);
        });
      }]
    };
  };

  angular.module('RAML.Directives')
    .directive('markdown', RAML.Directives.markdown);
})();

(function () {
  'use strict';

  RAML.Directives.methodList = function() {
    return {
      restrict: 'E',
      templateUrl: 'directives/method-list.tpl.html',
      replace: true,
      controller: ['$scope', '$timeout', '$rootScope', function($scope, $timeout, $rootScope) {
        function loadExamples () {
          $scope.context.uriParameters.reset($scope.resource.uriParametersForDocumentation);
          $scope.context.queryParameters.reset($scope.methodInfo.queryParameters);
          $scope.context.headers.reset($scope.methodInfo.headers.plain);

          function beautify(body, contentType) {
            if(contentType.indexOf('json') !== -1) {
              body = vkbeautify.json(body, 2);
            }

            if(contentType.indexOf('xml') !== -1) {
              body = vkbeautify.xml(body, 2);
            }

            return body;
          }

          $scope.getBeatifiedExample = function (value) {
            var result = value;

            try {
              result = beautify(value, $scope.currentBodySelected);
            }
            catch (e) { }

            return result;
          };

          if ($scope.context.bodyContent) {
            var definitions = $scope.context.bodyContent.definitions;

            Object.keys(definitions).map(function (key) {
              if (typeof definitions[key].reset !== 'undefined') {
                definitions[key].reset($scope.methodInfo.body[key].formParameters);
              } else {
                definitions[key].fillWithExample();
                if (definitions[key].value) {
                  definitions[key].value = $scope.getBeatifiedExample(definitions[key].value);
                }
              }
            });
          }
        }

        function getResponseInfo() {
          var responseInfo = {};
          var responses    = $scope.methodInfo.responses;

          if (responses) {
            Object.keys(responses).map(function (key) {
              if(responses[key] && typeof responses[key].body !== 'undefined' && responses[key].body) {
                responseInfo[key] = {};

                Object.keys(responses[key].body).sort().reverse().map(function (type) {
                  responseInfo[key][type] = responses[key].body[type];
                  responseInfo[key].currentType = type;
                });
              }
            });
          }

          return responseInfo;
        }

        function toUIModel (collection) {
          if(collection) {
            Object.keys(collection).forEach(function (key) {
              collection[key][0].id = key;
              if (collection[key][0].properties) {
                toUIModel(collection[key][0].properties);
              }
            });
          }
        }

        function beautifyCustomSecuritySchemeName (name) {
          return (name.charAt(0).toUpperCase() + name.slice(1)).replace(/_/g, ' ');
        }

        $scope.readTraits = function (traits) {
          var list = [];
          var traitList = traits || [];

          traitList = traitList.concat($scope.resource.traits);

          traitList.map(function (trait) {
            if (trait) {
              if (typeof trait === 'object') {
              trait = Object.keys(trait).join(', ');
              }

              if (list.indexOf(trait) === -1) {
                list.push(trait);
              }
            }
          });

          return list.join(', ');
        };

        $scope.generateId = function (path) {
          return jQuery.trim(path.toString().replace(/\W/g, ' ')).replace(/\s+/g, '_');
        };

        var $inactiveElements = jQuery('.raml-console-tab').add('.raml-console-resource')
                                                           .add('li')
                                                           .add('.raml-console-tab');

        $scope.$on('openMethod', function(event, $currentScope) {
          if ($scope.$id !== $currentScope.$id) {
            $inactiveElements.removeClass('raml-console-is-active');
            $scope.showPanel = false;
          }
        });

        $scope.showResource = function ($event, $index) {
          var $this             = jQuery($event.currentTarget);
          var $resource         = $this.closest('.raml-console-resource');
          var methodInfo        = $scope.resource.methods[$index];
          var $inactiveElements = jQuery('.raml-console-tab').add('.raml-console-resource')
                                                             .add('li')
                                                             .add('.raml-console-tab');

          $scope.methodInfo               = methodInfo;
          $scope.responseInfo             = getResponseInfo();
          $scope.context                  = new RAML.Services.TryIt.Context($scope.raml.baseUriParameters, $scope.resource, $scope.methodInfo);
          $scope.requestUrl               = '';
          $scope.response                 = {};
          $scope.requestOptions           = {};
          $scope.requestEnd               = false;
          $scope.showRequestMetadata      = false;
          $scope.showMoreEnable           = true;
          $scope.showSpinner              = false;
          $scope.securitySchemes          = $scope.methodInfo.securitySchemes();
          $scope.traits                   = $scope.readTraits($scope.methodInfo.is);
          $scope.context.customParameters = { headers: [], queryParameters: [] };
          $scope.currentBodySelected      = methodInfo.body ? Object.keys(methodInfo.body)[0] : 'application/json';

          toUIModel($scope.methodInfo.queryParameters);
          toUIModel($scope.methodInfo.headers.plain);
          toUIModel($scope.resource.uriParametersForDocumentation);

          Object.keys($scope.securitySchemes).map(function (key) {
            var type = $scope.securitySchemes[key].type;

            $scope.securitySchemes[key].name = type;
            $scope.securitySchemes[key].id = type + '|' + key;

            if (type === 'x-custom') {
              $scope.securitySchemes[key].name = beautifyCustomSecuritySchemeName(key);
              $scope.securitySchemes[key].id = type + '|' + key;
            }
          });

          $rootScope.$broadcast('resetData');

          /*jshint camelcase: false */
          // Digest Authentication is not supported
          delete $scope.securitySchemes.digest_auth;
          /*jshint camelcase: true */

          loadExamples();

          // Hack for codemirror
          setTimeout(function () {
            var editors = jQuery('.raml-console-sidebar-content-wrapper #sidebar-body .raml-console-codemirror-body-editor .CodeMirror');

            editors.map(function (index) {
              var bodyEditor = editors[index].CodeMirror;

              if (bodyEditor && $scope.context.bodyContent) {
                bodyEditor.setOption('mode', $scope.context.bodyContent.selected);
                bodyEditor.refresh();
              }
            });
          }, 10);

          if (!$resource.hasClass('raml-console-is-active')) {
            var hash = $scope.generateId($scope.resource.pathSegments);

            $rootScope.$broadcast('openMethod', $scope);
            jQuery($this).addClass('raml-console-is-active');
            $scope.showPanel = true;

            $timeout(function () {
              jQuery('html, body').animate({
                scrollTop: jQuery('#'+hash).offset().top + 'px'
              }, 'fast');
            }, 10);

          } else if (jQuery($this).hasClass('raml-console-is-active')) {
            $scope.showPanel = false;
            $inactiveElements.removeClass('raml-console-is-active');
            $scope.traits = null;
            $scope.methodInfo = {};
          } else {
            jQuery($this).addClass('raml-console-is-active');
            jQuery($this).siblings('.raml-console-tab').removeClass('raml-console-is-active');
          }
        };
      }]
    };
  };

  angular.module('RAML.Directives')
    .directive('methodList', RAML.Directives.methodList);
})();

(function () {
  'use strict';

  RAML.Directives.namedParameters = function() {
    return {
      restrict: 'E',
      templateUrl: 'directives/named-parameters.tpl.html',
      replace: true,
      scope: {
        src: '=',
        context: '=',
        types: '=',
        type: '@',
        title: '@'
      },
      controller: ['$scope', '$attrs', function ($scope, $attrs) {
        $scope.markedOptions = RAML.Settings.marked;

        if ($attrs.hasOwnProperty('enableCustomParameters')) {
          $scope.enableCustomParameters = true;
        }

        if ($attrs.hasOwnProperty('showBaseUrl')) {
          $scope.showBaseUrl = true;
        }

        $scope.segments = [];

        var baseUri = $scope.$parent.raml.baseUri;

        if (typeof baseUri !== 'undefined' && baseUri.templated) {
          var tokens = baseUri.tokens;

          for (var i = 0; i < tokens.length; i++) {
            $scope.segments.push({
              name: tokens[i],
              templated: typeof baseUri.parameters[tokens[i]] !== 'undefined' ? true : false
            });
          }
        }

        $scope.$parent.resource.pathSegments.map(function (element) {
          var tokens = element.tokens;

          for (var i = 0; i < tokens.length; i++) {
            $scope.segments.push({
              name: tokens[i],
              templated: element.templated && typeof element.parameters[tokens[i]] !== 'undefined' ? true : false
            });
          }
        });

        $scope.addCustomParameter = function () {
          $scope.context.customParameters[$scope.type].push({});
        };

        $scope.removeCutomParam = function (param) {
          $scope.context.customParameters[$scope.type] = $scope.context.customParameters[$scope.type].filter(function (el) {
            return el.name !== param.name;
          });
        };

        $scope.isValueProvided = function isValueProvided(value) {
          if (!value) {
            return false;
          }

          if (typeof value !== 'object') {
            return true;
          }

          return Object.keys(value).filter(function (k) {
            return $scope.isValueProvided(value[k]);
          }).length > 0;
        };

        $scope.cleanupValue = RAML.Inspector.Properties.cleanupPropertyValue;
      }]
    };
  };

  angular.module('RAML.Directives')
    .directive('namedParameters', RAML.Directives.namedParameters);
})();

(function () {
  'use strict';

  var PATTERN_PATTERN = /^\/[^\/]*\/$/;

  RAML.Directives.properties = function(RecursionHelper) {
    return {
      restrict: 'E',
      templateUrl: 'directives/properties.tpl.html',
      replace: true,
      scope: {
        list: '=',
        collapsible: '=',
        isNestedProperty: '=',
        hideTypeLinks: '=',
        hidePropertyDetails: '=',
        showExamples: '=',
        showSecuritySchemaProperties: '='
      },
      controller: ['$scope', '$rootScope', function ($scope, $rootScope) {
        $scope.$watch('list', function () {
          if (!Array.isArray($scope.list)) {
            $scope.listArray = Object.keys($scope.list).map(function (key) {
              return $scope.list[key];
            });

            $scope.listArray = RAML.Inspector.Properties.normalizeNamedParameters($scope.listArray);
          } else {
            $scope.listArray = $scope.list;
          }
        });

        var getArrayTypes = function(arrayType) {
          if (arrayType.items.type || Array.isArray(arrayType.items.type)) {
            return arrayType.items.type;
          }

          return [arrayType.items];
        };

        $scope.getType = function (type) {
          var newType = $scope.mergeType(type);
          newType.type = RAML.Inspector.Types.ensureArray(newType.type);

          if (newType.type[0] === 'array') {
            newType.type = getArrayTypes(newType).map(function (aType) {
              return aType + '[]';
            });
            newType.properties = newType.items.properties;
          }

          return newType;
        };

        var isPattern = function (propertyName) {
          return propertyName.match(PATTERN_PATTERN);
        };

        $scope.isPropertyVisible = function(property) {
          return ($scope.showSecuritySchemaProperties || !property[0].isFromSecurityScheme) && !isPattern(property[0].displayName);
        };

        $scope.mergeType = function (type) {
          var newType = angular.copy(type);

          if (!$scope.isNestedProperty && $rootScope.types) {
            return RAML.Inspector.Types.mergeType(newType, $rootScope.types);
          }
          return newType;
        };

        $scope.isNativeType = RAML.Inspector.Types.isNativeType;

        $scope.isSchema = RAML.Inspector.Types.isSchema;

        $scope.isCollapsible = function isCollapsible(property) {
          return $scope.collapsible && !!(property.description || property.properties || $scope.isSchema(property.type[0]));
        };

        $scope.parameterDocumentation = function (parameter) {
          var result = [];

          if (parameter) {
            if (parameter.required) {
              result.push('required');
            }

            if (parameter.discriminator) {
              result.push('discriminator');
            }

            if (parameter['enum']) {
              var enumValues = $scope.unique(parameter['enum']);
              var enumDescription = '';

              if (enumValues.length > 1) {
                enumDescription += 'one of ';
              }

              enumDescription += '(' + enumValues.filter(function (value) { return value !== ''; }).join(', ') + ')';

              result.push(enumDescription);
            }

            if (parameter.pattern) {
              result.push(' matching ' + parameter.pattern);
            }

            if (parameter.minLength && parameter.maxLength) {
              result.push(parameter.minLength + '-' + parameter.maxLength + ' characters');
            } else if (parameter.minLength && !parameter.maxLength) {
              result.push('at least ' + parameter.minLength + ' characters');
            } else if (parameter.maxLength && !parameter.minLength) {
              result.push('at most ' + parameter.maxLength + ' characters');
            }

            if (parameter.minimum && parameter.maximum) {
              result.push('between ' + parameter.minimum + '-' + parameter.maximum);
            } else if (parameter.minimum && !parameter.maximum) {
              result.push('≥ ' + parameter.minimum);
            } else if (parameter.maximum && !parameter.minimum) {
              result.push('≤ ' + parameter.maximum);
            }

            if (parameter.repeat) {
              result.push('repeatable');
            }

            if (parameter['default'] !== undefined) {
              result.push('default: ' + parameter['default']);
            }
          }

          return result.join(', ');
        };

        $scope.typeDocumentation = function (type) {
          var result = [];

          if (type.minItems) {
            result.push('minItems: ' + type.minItems);
          }

          if (type.maxItems) {
            result.push('maxItems: ' + type.maxItems);
          }

          if (type['enum']) {
            var enumValues = type['enum'];
            var enumDescription = '';

            if (enumValues.length > 1) {
              enumDescription += 'one of ';
            }

            enumDescription += '(' + enumValues.filter(function (value) { return value !== ''; }).join(', ') + ')';

            result.push(enumDescription);
          }

          if (type.pattern) {
            result.push('pattern: ' + type.pattern);
          }

          if (type.minLength) {
            result.push('minLength: ' + type.minLength);
          }

          if (type.maxLength) {
            result.push('maxLength: ' + type.maxLength);
          }

          if (type.minimum) {
            result.push('minimum: ' + type.minimum);
          }

          if (type.format) {
            result.push('format: ' + type.format);
          }

          if (type.multipleOf) {
            result.push('multipleOf: ' + type.multipleOf);
          }

          if (type.fileTypes) {
            result.push('fileTypes: ' + type.fileTypes.join(', '));
          }

          return result.join(', ');
        };

        $scope.unique = function (arr) {
          return arr.filter (function (v, i, a) { return a.indexOf (v) === i; });
        };
      }],
      compile: function (element) {
        return RecursionHelper.compile(element);
      }
    };
  };

  angular.module('RAML.Directives')
    .directive('properties', ['RecursionHelper', RAML.Directives.properties]);
})();

(function () {
  'use strict';

  RAML.Directives.ramlBody = function() {
    return {
      restrict: 'E',
      templateUrl: 'directives/raml-body.tpl.html',
      scope: {
        body: '=',
        getBeatifiedExampleRef: '&'
      },
      controller: ['$scope', '$rootScope', function($scope, $rootScope) {
        $scope.getBeatifiedExample = $scope.getBeatifiedExampleRef();

        $scope.$watch('body', function () {
          $scope.identifyBodyType();
        });

        $scope.getTopSchema = function (name) {
          return RAML.Inspector.Types.findSchema(name, $rootScope.schemas);
        };

        $scope.getTopType = function (name) {
          name = Array.isArray(name) ? name[0] : name;
          return RAML.Inspector.Types.findType(name, $rootScope.types);
        };

        $scope.identifyBodyType = function () {
          var node = angular.copy($scope.body);
          node.type = node.type || node.schema;
          $scope.isType = false;
          $scope.isSchema = false;

          if (node.type) {
            node.type = Array.isArray(node.type) ? node.type : [node.type];
            node.type.forEach(function (aType) {
              if (typeof aType !== 'object') {
                var isNative = RAML.Inspector.Types.isNativeType(aType);

                if (isNative) {
                  $scope.isType = true;
                } else {
                  var declaredType = RAML.Inspector.Types.findType(aType, $rootScope.types);
                  var declaredSchema = RAML.Inspector.Types.findSchema(aType, $rootScope.schemas);

                  if (declaredType) {
                    var typeParts = declaredType.type[0].split('|');
                    var firstType = RAML.Inspector.Types.cleanupTypeName(typeParts[0]);

                    if (RAML.Inspector.Types.isNativeType(firstType) ||
                        RAML.Inspector.Types.findType(firstType, $rootScope.types)) {
                      $scope.isType = true;
                    } else {
                      $scope.isSchema = true;
                      $scope.definition = declaredType.type[0];
                    }
                  } else {
                    $scope.isSchema = true;
                    if (declaredSchema) {
                      if (declaredSchema.type) {
                        $scope.definition = declaredSchema.type[0];
                      } else {
                        $scope.definition = declaredSchema;
                      }
                    } else {
                      if (aType.indexOf('|') !== -1) {
                        $scope.isSchema = false;
                        $scope.isType = true;
                      } else {
                        $scope.definition = aType;
                      }
                    }
                  }
                }
              } else {
                $scope.isSchema = true;
                $scope.definition = JSON.stringify(aType, null, 2);
              }
            });
          }
        };

        $scope.showSchema = function ($event) {
          var $this   = jQuery($event.currentTarget);
          var $panel  = $this.closest('.raml-console-schema-container');
          var $schema = $panel.find('.raml-console-resource-pre-toggle');

          $this.toggleClass('raml-console-is-active');

          if (!$schema.hasClass('raml-console-is-active')) {
            $this.text('Hide Schema');
            $schema
              .addClass('raml-console-is-active')
              .velocity('slideDown');
          } else {
            $this.text('Show Schema');
            $schema
              .removeClass('raml-console-is-active')
              .velocity('slideUp');
          }
        };

        $scope.identifyBodyType();
      }]
    };
  };

  angular.module('RAML.Directives')
    .directive('ramlBody', RAML.Directives.ramlBody);
})();

(function () {
  'use strict';

  var generator = window.ramlClientGenerator;

  function downloadClient (language, ast) {
    var zip    = new window.JSZip();
    var output = generator[language](ast);
    var title  = window.slug(output.context.title);

    Object.keys(output.files).forEach(function (key) {
      zip.file(key, output.files[key]);
    });

    var content  = zip.generate({ type: 'blob' });
    var filename = title + '-' + language + '.zip';

    // Download as a zip file with an appropriate language name.
    window.saveAs(content, filename);
  }

  RAML.Directives.ramlClientGenerator = function () {
    return {
      restrict: 'E',
      templateUrl: 'directives/raml-client-generator.tpl.html',
      controller: ['$scope', function ($scope) {
        $scope.downloadJavaScriptClient = function () {
          return downloadClient('javascript', $scope.rawRaml);
        };
      }]
    };
  };

  angular.module('RAML.Directives')
    .directive('ramlClientGenerator', RAML.Directives.ramlClientGenerator);
})();

(function () {
  'use strict';

  angular.module('RAML.Directives')
    .directive('ramlConsoleLoader', function ramlConsoleLoader() {
      return {
        restrict:    'E',
        templateUrl: 'directives/raml-console-loader.tpl.html',
        replace:     true,
        controller:  'RamlConsoleLoaderController',
        scope:       {
          src:     '@',
          options: '='
        }
      };
    })
    .controller('RamlConsoleLoaderController', function RamlConsoleLoaderController(
      $scope,
      $window,
      ramlParser
    ) {
      $scope.vm = {
        error:   void(0),
        loaded:  false,
        options: $scope.options,
        raml:    void(0),
        src:     $scope.src
      };

      // ---

      (function activate() {
        loadFromUrl($scope.vm.src);
      })();

      // ---

      function loadFromUrl(url) {
        $scope.vm.raml   = void(0);
        $scope.vm.loaded = false;
        $scope.vm.error  = void(0);

        if(RAML.LoaderUtils.ramlOriginValidate(url, $scope.options)) {
          $scope.vm.error = {message : 'RAML origin check failed. Raml does not reside underneath the path:' + RAML.LoaderUtils.allowedRamlOrigin($scope.options)};
        } else {
          return ramlParser.loadPath($window.resolveUrl(url), null, $scope.options)
            .then(function (api) {
              var success = true;
              var issues = api.errors; // errors and warnings
              if (issues && issues.length > 0) {
                success = issues.filter(function (issue) {
                    return !issue.isWarning;
                  }).length === 0;
              }

              if (success) {
                $scope.vm.raml = api.specification;
              } else {
                $scope.vm.error = { message: 'Api contains errors.', errors : issues};
              }
            })
            .finally(function () {
              $scope.vm.loaded = true;
            })
          ;
        }
      }
    })
  ;
})();

(function () {
  'use strict';

  angular.module('RAML.Directives')
    .directive('ramlConsoleSpinner', function ramlConsoleSpinner() {
      return {
        restrict:    'E',
        templateUrl: 'directives/raml-console-spinner.tpl.html',
        replace:     true
      };
    })
  ;
})();

(function () {
  'use strict';

  angular.module('RAML.Directives')
    .directive('ramlConsole', function ramlConsole() {
      return {
        restrict:    'E',
        templateUrl: 'directives/raml-console.tpl.html',
        replace:     true,
        controller:  'RamlConsoleController',
        scope:       {
          raml:    '=',
          options: '='
        }
      };
    })
    .controller('RamlConsoleController', 
      ['$attrs', '$scope', '$rootScope', '$timeout', '$window', function RamlConsoleController(
      $attrs, $scope, $rootScope, $timeout, $window
    ) {
      $scope.allowUnsafeMarkdown        = $attrs.hasOwnProperty('allowUnsafeMarkdown');
      $scope.collapseAll                = collapseAll;
      $scope.credentials                = {};
      $scope.disableRamlClientGenerator = $attrs.hasOwnProperty('disableRamlClientGenerator');
      $scope.disableThemeSwitcher       = $attrs.hasOwnProperty('disableThemeSwitcher');
      $scope.disableTitle               = $attrs.hasOwnProperty('disableTitle');
      $scope.disableTryIt               = $attrs.hasOwnProperty('disableTryIt');
      $scope.documentationCollapsed     = $attrs.hasOwnProperty('documentationCollapsed');
      $scope.proxy                      = $window.RAML.Settings.proxy;
      $scope.readResourceTraits         = readResourceTraits;
      $scope.resourcesCollapsed         = $attrs.hasOwnProperty('resourcesCollapsed');
      $scope.singleView                 = $attrs.hasOwnProperty('singleView');
      $scope.hasResourcesWithChilds     = hasResourcesWithChilds;
      $scope.toggle                     = toggle;
      $scope.updateProxyConfig          = updateProxyConfig;

      // ---

      (function activate() {
        $scope.options && [
          'allowUnsafeMarkdown',
          'disableRamlClientGenerator',
          'disableThemeSwitcher',
          'disableTitle',
          'disableTryIt',
          'documentationCollapsed',
          'resourcesCollapsed',
          'singleView'
        ].forEach(function (property) {
          if ($scope.options[property]) {
            $scope[property] = true;
          }
        });

        $scope.$watch('raml', function (raml) {
          if (!raml) {
            return;
          }
          delete $scope.types;
          delete $rootScope.types;

          $timeout(function () {
            var securitySchemes = raml.securitySchemes ? angular.copy(raml.securitySchemes) : [];
            var librarySecuritySchemes = getSecuritySchemes();

            if (securitySchemes || librarySecuritySchemes) {
              raml.securitySchemes = securitySchemes.concat(librarySecuritySchemes);
            }

            inspectRaml(raml);

            var types = raml.types ? angular.copy(raml.types) : [];
            var libraryTypes = getLibraryTypes();

            if (types.length || libraryTypes.length) {
              $scope.types = types.concat(libraryTypes);

              $rootScope.types = $scope.types.map(function (type) {
                var theType = type[Object.keys(type)[0]];
                theType.properties = RAML.Inspector.Properties.normalizeNamedParameters(theType.properties);
                return type;
              });
            }

            var schemas = raml.schemas ? angular.copy(raml.schemas) : [];
            var librarySchemas = getLibrarySchemas();

            if (schemas || librarySchemas) {
              $rootScope.schemas = schemas.concat(librarySchemas);
            }
          });

          function getLibraryTypes() {
            var result = [] ;
            if (raml.uses) {
              Object.keys(raml.uses).forEach(function (usesKey) {
                var usesTypes = raml.uses[usesKey].types;
                if (usesTypes) {
                  usesTypes.forEach(function (aType) {
                    Object.keys(aType).forEach(function (typeKey) {
                      var tempType = {};
                      convertType(aType[typeKey], usesKey);

                      tempType[usesKey + '.' + typeKey] = aType[typeKey];
                      tempType[usesKey + '.' + typeKey].displayName = usesKey + '.' + typeKey;
                      result.push(tempType);
                    });
                  });
                }
              });
            }

            return result;
          }

          function convertType(typeNode, usesKey) {
            typeNode.type = typeNode.type.map(function (typeName) {
              if (!RAML.Inspector.Types.isSchema(typeName)) {
                var typeInfo = RAML.Inspector.Types.getTypeInfo(typeName);

                typeInfo.parts = typeInfo.parts.map(function (theType) {
                  if (!RAML.Inspector.Types.isNativeType(theType)) {
                    return usesKey + '.' + RAML.Inspector.Types.cleanupTypeName(theType);
                  }
                  return theType;
                });

                return RAML.Inspector.Types.getTypeFromTypeInfo(typeInfo);
              }
              return typeName;
            });

            if (typeNode.properties) {
              Object.keys(typeNode.properties).forEach(function (propertiesKey) {
                convertType(typeNode.properties[propertiesKey], usesKey);
              });
            }
          }

          function getLibrarySchemas() {
            var result = [];
            if (raml.uses) {
              Object.keys(raml.uses).forEach(function (usesKey) {
                var usesSchemas = raml.uses[usesKey].schemas;
                if (usesSchemas) {
                  usesSchemas.forEach(function (aSchema) {
                    Object.keys(aSchema).forEach(function (schemaKey) {
                      var tempSchema = {};
                      tempSchema[usesKey + '.' + schemaKey] = aSchema[schemaKey];
                      result.push(tempSchema);
                    });
                  });
                }
              });
            }

            return result;
          }

          function getSecuritySchemes() {
            var result = [];
            if (raml.uses) {
              Object.keys(raml.uses).forEach(function (usesKey) {
                var usesSecuritySchemes = raml.uses[usesKey].securitySchemes;
                if (usesSecuritySchemes) {
                  usesSecuritySchemes.forEach(function (aScheme) {
                    Object.keys(aScheme).forEach(function (schemaKey) {
                      var tempSchema = {};
                      tempSchema[usesKey + '.' + schemaKey] = aScheme[schemaKey];
                      result.push(tempSchema);
                    });
                  });
                }
              });
            }

            return result;
          }
        });
      })();

      // ---

      function collapseAll($event, collection, flagKey) {
        var $this = jQuery($event.currentTarget);

        if ($this.hasClass('raml-console-resources-expanded')) {
          $scope[flagKey] = true;
        } else {
          if (flagKey === 'resourcesCollapsed') {
            jQuery('.raml-console-resource-description').removeClass('ng-hide');
          }
          $scope[flagKey] = false;
        }

        jQuery('.raml-console-resources-' + flagKey).find('ol.raml-console-resource-list').toggleClass('raml-console-is-collapsed');

        toggleCollapsed($scope[flagKey], collection);
      }

      function readResourceTraits(traits) {
        var list = [];

        if (traits) {
          traits.map(function (trait) {
            if (trait) {
              if (typeof trait === 'object') {
                list.push(Object.keys(trait).join(', '));
              } else {
                list.push(trait);
              }
            }
          });
        }

        return list.join(', ');
      }

      function toggle($event, index, collection, flagKey) {
        var $this    = jQuery($event.currentTarget);
        var $section = $this
          .closest('.raml-console-resource-list-item')
          .find('.raml-console-resource-list');

        collection[index] = !collection[index];

        $scope[flagKey] = checkItemStatus(false, collection) ? false : $scope[flagKey];
        $scope[flagKey] = checkItemStatus(true, collection) ? true : $scope[flagKey];

        $section.toggleClass('raml-console-is-collapsed');
      }

      function updateProxyConfig(status) {
        $window.RAML.Settings.disableProxy = status;
      }

      // ---

      function toggleCollapsed(status, collection) {
        for (var i = 0; i < collection.length; i++) {
          collection[i] = collection[i] !== null ? status : collection[i];
        }
      }

      function checkItemStatus(status, collection) {
        return collection.filter(function (el) { return el === status || el === null; }).length === collection.length;
      }

      function hasResourcesWithChilds() {
        return $scope.inspectedRaml && $scope.inspectedRaml.resourceGroups.filter(function (el) {
          return el.length > 1;
        }).length > 0;
      }

      function inspectRaml(raml) {
        $scope.inspectedRaml = RAML.Inspector.create(raml);
        $scope.resourceList  = [];
        $scope.documentList  = [];

        for (var i = 0; i < $scope.inspectedRaml.resourceGroups.length; i++) {
          var resources = $scope.inspectedRaml.resourceGroups[i];
          var status    = resources.length > 1 ? false : null;
          $scope.resourceList.push($scope.resourcesCollapsed ? true : status);
        }

        if ($scope.inspectedRaml.documentation) {
          for (var j = 0; j < $scope.inspectedRaml.documentation.length; j++) {
            $scope.documentList.push($scope.documentationCollapsed ? true : false);
          }
        }
      }
    }])
  ;
})();

(function () {
  'use strict';

  RAML.Directives.ramlField = function(RecursionHelper) {
    return {
      restrict: 'E',
      templateUrl: 'directives/raml-field.tpl.html',
      replace: true,
      scope: {
        context: '=',
        type: '=',
        types: '=',
        model: '=',
        param: '='
      },
      controller: ['$scope', function($scope) {
        var bodyContent = $scope.context.bodyContent;
        var context     = $scope.context[$scope.type];

        if (bodyContent) {
          context = context || bodyContent.definitions[bodyContent.selected];
        }

        Object.keys(context.plain).map(function (key) {
          var definition = context.plain[key].definitions[0];

          if (typeof definition['enum'] !== 'undefined') {
            context.values[definition.id][0] = definition['enum'][0];
          }
        });

        $scope.isArray = function (param) {
          return param.type[0].indexOf('[]') !== -1;
        };

        $scope.addArrayElement = function (model) {
          model.push([undefined]);
        };

        $scope.removeArrayElement = function (model, index) {
          model.splice(index, 1);
        };

        $scope.canOverride = function (definition) {
          return definition.type === 'boolean' ||  typeof definition['enum'] !== 'undefined';
        };

        $scope.overrideField = function ($event, definition) {
          var $this      = jQuery($event.currentTarget);
          var $container = $this.closest('p');
          var $el        = $container.find('#' + definition.id);
          var $checkbox  = $container.find('#checkbox_' + definition.id);
          var $select    = $container.find('#select_' + definition.id);

          $el.toggleClass('raml-console-sidebar-override-show');
          $checkbox.toggleClass('raml-console-sidebar-override-hide');
          $select.toggleClass('raml-console-sidebar-override-hide');

          $this.text('Override');

          if($el.hasClass('raml-console-sidebar-override-show')) {
            definition.overwritten = true;
            $this.text('Cancel override');
          } else {
            definition.overwritten = false;
            $scope.context[$scope.type].values[definition.id][0] = definition['enum'][0];
          }
        };

        $scope.onChange = function () {
          $scope.context.forceRequest = false;
        };

        $scope.isDefault = function (definition) {
          return typeof definition['enum'] === 'undefined' && definition.type !== 'boolean';
        };

        $scope.isEnum = function (definition) {
          return typeof definition['enum'] !== 'undefined';
        };

        $scope.isBoolean = function (definition) {
          return definition.type === 'boolean';
        };

        $scope.hasExampleValue = function (value) {
          return $scope.isEnum(value) ? false : value.type === 'boolean' ? false : typeof value['enum'] !== 'undefined' ? false : (typeof value.example !== 'undefined' || typeof value.examples !== 'undefined') ? true : false;
        };

        $scope.reset = function (param) {
          var type = $scope.type || 'bodyContent';
          var info = {};

          info[param.id] = [param];

          $scope.context[type].reset(info, param.id);
        };

        $scope.unique = function (arr) {
          return arr.filter (function (v, i, a) { return a.indexOf (v) === i; });
        };

        $scope.toString = function toString(value) {
          return Array.isArray(value) ? value.join(', ') : value;
        };
      }],
      compile: function (element) {
        return RecursionHelper.compile(element);
      }
    };
  };

  angular.module('RAML.Directives')
    .directive('ramlField', ['RecursionHelper', RAML.Directives.ramlField]);
})();

(function () {
  'use strict';

  angular.module('RAML.Directives')
    .directive('ramlInitializer', function ramlInitializer() {
      return {
        restrict:    'E',
        templateUrl: 'directives/raml-initializer.tpl.html',
        replace:     true,
        controller:  'RamlInitializerController',
        scope:       {
          options: '='
        }
      };
    })
    .controller('RamlInitializerController', ['$scope', '$window', 'ramlParser', function RamlInitializerController(
      $scope, $window, ramlParser
    ) {
      $scope.vm = {
        codeMirror: {
          gutters:      ['CodeMirror-lint-markers'],
          lineNumbers:  true,
          lineWrapping: true,
          lint:         null,
          mode:         'yaml',
          tabSize:      2,
          theme:        'raml-console'
        },

        error:           null,
        isLoadedFromUrl: false,
        isLoading:       false,
        loadFromString:  loadFromString,
        loadFromUrl:     loadFromUrl,
        raml:            null
      };

      // ---

      (function activate() {
        if (document.location.search.indexOf('?raml=') !== -1) {
          loadFromUrl(document.location.search.replace('?raml=', ''));
        }
      })();

      // ---

      function loadFromUrl(url) {
        $scope.vm.ramlUrl = url;
        if(RAML.LoaderUtils.ramlOriginValidate(url, $scope.options)) {
          $scope.vm.isLoadedFromUrl = true;
          $scope.vm.error = {message : 'RAML origin check failed. Raml does not reside underneath the path:' + RAML.LoaderUtils.allowedRamlOrigin($scope.options)};
        } else {
          return loadFromPromise(ramlParser.loadPath($window.resolveUrl(url)), {isLoadingFromUrl: true});
        }
      }

      function loadFromString(string) {
        $scope.vm.ramlString = string;
        return loadFromPromise(ramlParser.load(string));
      }

      // ---

      /**
       * @param {Promise} promise
       * @param {Boolean} options.isLoadingFromUrl
       */
      function loadFromPromise(promise, options) {
        options                   = options || {};
        $scope.vm.error           = null;
        $scope.vm.raml            = null;
        $scope.vm.isLoading       = true;
        $scope.vm.isLoadedFromUrl = false;
        $scope.vm.codeMirror.lint = null;

        return promise
          .then(function (api) {
            var success = true;
            var issues = api.errors; // errors and warnings
            if (issues && issues.length > 0) {
              success = issues.filter(function (issue) {
                  return !issue.isWarning;
                }).length === 0;
            }

            if (success) {
              $scope.vm.raml = api.specification;
            } else {
              $scope.vm.error           = { message: 'Api contains errors.'};
              $scope.vm.codeMirror.lint = lintFromError(issues);
            }
          })
          .finally(function () {
            $scope.vm.isLoading       = false;
            $scope.vm.isLoadedFromUrl = options.isLoadingFromUrl;
          })
        ;
      }

      function lintFromError(errors) {
        return function getAnnotations() {
          return (errors || []).map(function (error) {
            return {
              message:  error.message,
              severity: error.isWarning ? 'warning' : 'error',
              from:     CodeMirror.Pos(error.line),
              to:       CodeMirror.Pos(error.line)
            };
          });
        };
      }
    }])
  ;
})();

(function () {
  'use strict';

  RAML.Directives.resourcePanel = function() {
    return {
      restrict: 'E',
      templateUrl: 'directives/resource-panel.tpl.html',
      replace: true
    };
  };

  angular.module('RAML.Directives')
    .directive('resourcePanel', RAML.Directives.resourcePanel);
})();

(function () {
  'use strict';

  RAML.Directives.resourceType = function() {
    return {
      restrict: 'E',
      templateUrl: 'directives/resource-type.tpl.html',
      replace: true,
      controller: ['$scope', function ($scope) {
        var resourceType = $scope.resource.resourceType;

        if (typeof resourceType === 'object') {
          $scope.resource.resourceType = Object.keys(resourceType).join();
        }
      }]
    };
  };

  angular.module('RAML.Directives')
    .directive('resourceType', RAML.Directives.resourceType);
})();

(function () {
  'use strict';

  RAML.Directives.rootDocumentation = function() {
    return {
      restrict: 'E',
      templateUrl: 'directives/root-documentation.tpl.html',
      replace: true,
      controller: ['$scope', '$timeout', function($scope, $timeout) {
        $scope.markedOptions = RAML.Settings.marked;
        $scope.selectedSection = 'all';

        $scope.hasDocumentationWithIndex = function () {
          var regex = /(^#|^##)+\s(.*)$/gim;

          return $scope.raml.documentation.filter(function (el) {
            return regex.test(el.content);
          }).length > 0;
        };

        $scope.generateDocId = function (path) {
          return jQuery.trim(path.toString().replace(/\W/g, ' ')).replace(/\s+/g, '_').toLowerCase();
        };

        $scope.toggleSection = function ($event, key, section) {
          var $el = jQuery($event.currentTarget).closest('.raml-console-documentation');
          $scope.selectedDocumentSection = key;
          $scope.documentationEnabled = $el.hasClass('raml-console-documentation-active') ? false : true;

          jQuery('.raml-console-resource-list-item').removeClass('raml-console-documentation-active');

          $el[!$scope.documentationEnabled ? 'removeClass' : 'addClass']('raml-console-documentation-active');

          $timeout(function () {
            jQuery('html, body').animate({
              scrollTop: jQuery('#'+$scope.generateDocId(section)).offset().top + 'px'
            }, 'fast');
          }, 10);
        };

        $scope.closeDocumentation = function ($event) {
          var $container = jQuery($event.currentTarget).closest('.raml-console-documentation');
          $container.toggleClass('raml-console-documentation-active');
          $scope.documentationEnabled = false;
          jQuery('.raml-console-resource-list-item').removeClass('raml-console-documentation-active');
        };

        $scope.sectionChange = function (value) {
          $scope.selectedDocumentSection = value;
        };

        $scope.getDocumentationContent = function (content, selected) {
          var lines  = content.split(/\r|\n/);
          var index  = lines.indexOf(selected);
          var result = [];
          var regex  = /(^#|^##)+\s(.*)$/gim;

          result.push(lines[index]);

          for (var i = index+1; i < lines.length; i++) {
            var line = lines[i];

            if (regex.test(line)) {
              break;
            }

            result.push(line);
          }

          return !selected || selected === 'all' ? content : result.join('\n');
        };

        $scope.filterHeaders = function (c) {
          return c.filter(function (el) {
            return el.heading <= 2;
          });
        };

        $scope.getMarkdownHeaders = function (content) {
          var headers = content.match(/^#+\s(.*)$/gim);
          var result  = [];
          var regex   = new RegExp(/(^#|^##)+\s(.*)$/gim);

          if (headers) {
            var key = headers[0];

            headers.map(function(el) {
              if(el.match(regex) !== null) {
                key = el;
              }

              result.push({
                value: key,
                heading: el.match(/#/g).length,
                label: el.replace(/#/ig, '').trim()
              });
            });
          }

          return result;
        };
      }]
    };
  };

  angular.module('RAML.Directives')
    .directive('rootDocumentation', RAML.Directives.rootDocumentation);
})();

(function () {
  'use strict';

  RAML.Directives.rootTypes = function() {
    return {
      restrict: 'E',
      templateUrl: 'directives/root-types.tpl.html',
      replace: true,
      scope: {
        types: '='
      },
      controller: ['$scope', function ($scope) {
        $scope.convertTypes = function () {
          var types = {};
          $scope.types.forEach(function (type) {
            types[Object.keys(type)[0]] = type[Object.keys(type)[0]];
          });
          $scope.theTypes = RAML.Inspector.Properties.normalizeNamedParameters(types);
        };

        $scope.$watch('types', function () {
          $scope.convertTypes();
        });
      }]
    };
  };

  angular.module('RAML.Directives')
    .directive('rootTypes', RAML.Directives.rootTypes);
})();

(function () {
  'use strict';

  RAML.Directives.sidebar = function() {
    return {
      restrict: 'E',
      templateUrl: 'directives/sidebar.tpl.html',
      replace: true,
      controller: ['$scope', '$timeout', function ($scope, $timeout) {
        var defaultSchemaKey = Object.keys($scope.securitySchemes).sort()[0];
        var defaultSchema    = $scope.securitySchemes[defaultSchemaKey];
        var defaultAccept    = 'application/json';

        $scope.markedOptions     = RAML.Settings.marked;
        $scope.currentSchemeType = defaultSchema.type;
        $scope.currentScheme     = defaultSchema.id;
        $scope.responseDetails   = false;

        function readCustomSchemeInfo (name) {
          if (!$scope.methodInfo.headers.plain) {
            $scope.methodInfo.headers.plain = {};
          }

          if (!$scope.methodInfo.queryParameters) {
            $scope.methodInfo.queryParameters = {};
          }

          updateContextData('headers', name, $scope.methodInfo.headers.plain, $scope.context.headers);
          updateContextData('queryParameters', name, $scope.methodInfo.queryParameters, $scope.context.queryParameters);
        }

        if (defaultSchema.type === 'x-custom') {
          readCustomSchemeInfo(defaultSchema.id.split('|')[1]);
        }

        function completeAnimation (element) {
          jQuery(element).removeAttr('style');
        }

        function parseHeaders(headers) {
          var parsed = {}, key, val, i;

          if (!headers) {
            return parsed;
          }

          headers.split('\n').forEach(function(line) {
            i   = line.indexOf(':');
            key = line.substr(0, i).trim().toLowerCase();
            val = line.substr(i + 1).trim();

            if (key) {
              if (parsed[key]) {
                parsed[key] += ', ' + val;
              } else {
                parsed[key] = val;
              }
            }
          });

          return parsed;
        }

        function apply () {
          $scope.$apply.apply($scope, arguments);
        }

        function beautify(body, contentType) {
          if(contentType.indexOf('json')) {
            body = vkbeautify.json(body, 2);
          }

          if(contentType.indexOf('xml')) {
            body = vkbeautify.xml(body, 2);
          }

          return body;
        }

        function handleResponse(jqXhr, err) {
          $scope.response.status = jqXhr ? jqXhr.status : err ? (err.status ? err.status : err.message) : 0;

          if (jqXhr) {
            $scope.response.headers = parseHeaders(jqXhr.getAllResponseHeaders());

            if ($scope.response.headers['content-type']) {
              $scope.response.contentType = $scope.response.headers['content-type'].split(';')[0];
            }

            try {
              $scope.response.body = beautify(jqXhr.responseText, $scope.response.contentType);
            }
            catch (e) {
              $scope.response.body = jqXhr.responseText;
            }
          }

          $scope.requestEnd      = true;
          $scope.showMoreEnable  = true;
          $scope.showSpinner     = false;
          $scope.responseDetails = true;

          // If the response fails because of CORS, responseText is null
          var editorHeight = 50;

          if (jqXhr && jqXhr.responseText) {
            var lines = $scope.response.body.split('\n').length;
            editorHeight = lines > 100 ? 2000 : 25*lines;
          }

          $scope.editorStyle = {
            height: editorHeight + 'px'
          };

          apply();

          var hash = 'request_' + $scope.generateId($scope.resource.pathSegments);

          $timeout(function () {
            if (jqXhr) {
              var $editors = jQuery('.raml-console-sidebar-content-wrapper .CodeMirror').toArray();

              $editors.forEach(function (editor) {
                var cm = editor.CodeMirror;
                cm.setOption('mode', $scope.response.contentType);
                cm.refresh();
              });
            }

            jQuery('html, body').animate({
              scrollTop: jQuery('#'+hash).offset().top + 'px'
            }, 'fast');
          }, 10);
        }

        function resolveSegementContexts(pathSegments, uriParameters) {
          var segmentContexts = [];

          pathSegments.forEach(function (element) {
            if (element.templated) {
              var segment = {};
              Object.keys(element.parameters).map(function (key) {
                segment[key] = uriParameters[key];
              });
              segmentContexts.push(segment);
            } else {
              segmentContexts.push({});
            }
          });

          return segmentContexts;
        }

        function validateForm(form) {
          var keys = Object.keys(form.form).filter(function (key) { return key.indexOf('$') === -1;});

          keys.forEach(function (fieldName) {
            form.form[fieldName].$setDirty();
          });

          return form.form.$valid;
        }

        function getParameters (context, type) {
          var params           = {};
          var customParameters = context.customParameters[type];

          if (!RAML.Utils.isEmpty(context[type].data())) {
            params = angular.copy(context[type].data());
          }

          Object.keys(params).forEach(function (key) {
            if (Array.isArray(params[key][0])) {
              var input = angular.copy(params[key][0]);

              input.forEach(function (each, index) {
                params[key][index] = each[0];
              });
            }

            params[key].forEach(function (param, index) {
              if (typeof param === 'object') {
                params[key][index] = JSON.stringify(
                  RAML.Inspector.Properties.cleanupPropertyValue(params[key][index]));
              }
            });

            // Remove empty array property
            if (params[key][0] === '[null]') {
              delete params[key];
            }
          });

          if (customParameters.length > 0) {
            for(var i = 0; i < customParameters.length; i++) {
              var key = customParameters[i].name;

              params[key] = [];
              params[key].push(customParameters[i].value);
            }
          }

          return params;
        }

        function clearCustomFields (types) {
          types.map(function (type) {
            var custom = $scope.context.customParameters[type];

            for (var i = 0; i < custom.length; i++) {
              custom[i].value = '';
            }
          });
        }

        $scope.$watch('methodInfo', function () {
          $scope.protocols       = $scope.methodInfo.protocols || $scope.raml.protocols;
          $scope.currentProtocol = $scope.protocols && $scope.protocols.length ? $scope.protocols[0] : null;
        });

        $scope.$on('resetData', function() {
          var defaultSchemaKey = Object.keys($scope.securitySchemes).sort()[0];
          var defaultSchema    = $scope.securitySchemes[defaultSchemaKey];

          $scope.currentSchemeType           = defaultSchema.type;
          $scope.currentScheme               = defaultSchema.id;
          $scope.protocols                   = $scope.methodInfo.protocols || $scope.raml.protocols;
          $scope.currentProtocol             = $scope.protocols && $scope.protocols.length ? $scope.protocols[0] : null;
          $scope.documentationSchemeSelected = defaultSchema;
          $scope.responseDetails             = null;

          cleanSchemeMetadata($scope.methodInfo.headers.plain, $scope.context.headers);
          cleanSchemeMetadata($scope.methodInfo.queryParameters, $scope.context.queryParameters);
        });

        $scope.cancelRequest = function () {
          $scope.showSpinner = false;
        };

        $scope.prefillBody = function (current) {
          var definition   = $scope.context.bodyContent.definitions[current];
          definition.fillWithExample();

          if (definition.value) {
            definition.value = $scope.getBeatifiedExample(definition.value);
          }
        };

        $scope.clearFields = function () {
          $scope.context.uriParameters.clear($scope.resource.uriParametersForDocumentation);
          $scope.context.queryParameters.clear($scope.methodInfo.queryParameters);
          $scope.context.headers.clear($scope.methodInfo.headers.plain);
          if ($scope.context.bodyContent) {
            $scope.context.bodyContent.definitions[$scope.context.bodyContent.selected].value = '';
          }
          $scope.context.forceRequest = false;

          if ($scope.credentials) {
            Object.keys($scope.credentials).map(function (key) {
              $scope.credentials[key] = '';
            });
          }

          clearCustomFields(['headers', 'queryParameters']);

          if ($scope.context.bodyContent) {
            var current    = $scope.context.bodyContent.selected;
            var definition = $scope.context.bodyContent.definitions[current];

            if (typeof definition.clear !== 'undefined') {
              definition.clear($scope.methodInfo.body[current].formParameters);
            } else {
              definition.value = '';
            }
          }
        };

        $scope.resetFormParameter = function (param) {
          var current    = $scope.context.bodyContent.selected;
          var definition = $scope.context.bodyContent.definitions[current];

          definition.reset($scope.methodInfo.body[current].formParameters, param.id);
        };

        $scope.resetFields = function () {
          $scope.context.uriParameters.reset($scope.resource.uriParametersForDocumentation);
          $scope.context.queryParameters.reset($scope.methodInfo.queryParameters);
          $scope.context.headers.reset($scope.methodInfo.headers.plain);

          if ($scope.context.bodyContent) {
            var current    = $scope.context.bodyContent.selected;
            var definition = $scope.context.bodyContent.definitions[current];

            if (typeof definition.reset !== 'undefined') {
              definition.reset($scope.methodInfo.body[current].formParameters);
            } else {
              definition.value = definition.contentType.example;
            }
          }

          $scope.context.forceRequest = false;
        };

        $scope.requestBodySelectionChange = function (bodyType) {
          $scope.currentBodySelected = bodyType;
        };

        $scope.toggleBodyType = function ($event, bodyType) {
          var $this  = jQuery($event.currentTarget);
          var $panel = $this.closest('.raml-console-sidebar-toggle-type').find('button');

          $panel.removeClass('raml-console-is-active');
          $this.addClass('raml-console-is-active');

          $scope.context.bodyContent.selected = bodyType;
        };

        $scope.getHeaderValue = function (header) {
          if (typeof header === 'string') {
            return header;
          }

          return header[0];
        };

        $scope.hasExampleValue = function (value) {
          return typeof value !== 'undefined' ? true : false;
        };

        $scope.context.forceRequest = false;

        function cleanSchemeMetadata(collection, context) {
          if (collection) {
            Object.keys(collection).map(function (key) {
              if (collection[key][0].isFromSecurityScheme) {
                delete collection[key];
              }

              if (context.plain[key].definitions[0].isFromSecurityScheme) {
                delete context.plain[key];
              }
            });
          }
        }

        function updateContextData (type, scheme, collection, context) {
          var details         = jQuery.extend({}, $scope.securitySchemes[scheme].describedBy || {});
          var securityHeaders = details[type] || {};

          if (securityHeaders) {
            Object.keys(securityHeaders).map(function (key) {
              if (!securityHeaders[key]) {
                securityHeaders[key] = {
                  id: key,
                  type: 'string'
                };
              }

              securityHeaders[key].id                   = key;
              securityHeaders[key].displayName          = key;
              securityHeaders[key].isFromSecurityScheme = true;
              collection[key] = [securityHeaders[key]];

              context.plain[key] = {
                definitions: [securityHeaders[key]],
                selected: securityHeaders[key].type
              };
              context.values[key] = [undefined];
            });
          }
        }

        $scope.protocolChanged = function protocolChanged(protocol) {
          $scope.currentProtocol = protocol;
        };

        $scope.securitySchemeChanged = function securitySchemeChanged(scheme) {
          var info            = scheme.split('|');
          var type            = info[0];
          var name            = info[1];

          $scope.currentSchemeType = type;
          $scope.context.forceRequest = false;

          cleanSchemeMetadata($scope.methodInfo.headers.plain, $scope.context.headers);
          cleanSchemeMetadata($scope.methodInfo.queryParameters, $scope.context.queryParameters);

          $scope.documentationSchemeSelected = $scope.securitySchemes[name];

          if (type === 'x-custom') {
            readCustomSchemeInfo(name);
          }
        };

        $scope.setFormScope = function (form) {
          $scope.form = form;
        };

        $scope.tryIt = function ($event) {
          $scope.requestOptions  = null;
          $scope.responseDetails = false;
          $scope.response        = {};

          if (!$scope.context.forceRequest) {
            jQuery($event.currentTarget).closest('form').find('.ng-invalid').first().focus();
          }

          if($scope.context.forceRequest || validateForm($scope.form)) {
            var url;
            var context         = $scope.context;
            var segmentContexts = resolveSegementContexts($scope.resource.pathSegments, $scope.context.uriParameters.data());

            $scope.showSpinner = true;
            $scope.queryStringHasError = false;
            $scope.toggleRequestMetadata($event, true);

            try {
              var pathBuilder = context.pathBuilder;
              var client      = RAML.Client.create($scope.raml, function(client) {
                if ($scope.raml.baseUriParameters) {
                  Object.keys($scope.raml.baseUriParameters).map(function (key) {
                    var uriParameters = $scope.context.uriParameters.data();
                    pathBuilder.baseUriContext[key] = uriParameters[key][0];
                    delete uriParameters[key];
                  });
                }
                client.baseUriParameters(pathBuilder.baseUriContext);
              });

              client.baseUri = client.baseUri.replace(/(https)|(http)/, $scope.currentProtocol.toLocaleLowerCase());
              url = client.baseUri + pathBuilder(segmentContexts);
            } catch (e) {
              console.error(e);
              $scope.response = {};
              return;
            }
            var request = RAML.Client.Request.create(url, $scope.methodInfo.method);

            $scope.parameters = getParameters(context, 'queryParameters');

            if (context.queryString) {
              var parameters;
              try {
                parameters = JSON.parse(context.queryString);
              } catch (e) {
                $scope.queryStringHasError = true;
                $scope.response = {};

                $scope.showSpinner = false;
                return;
              }
              Object.keys(parameters).forEach(function (key) {
                if (!$scope.parameters[key]) {
                  $scope.parameters[key] = [];
                }
                var value = parameters[key];
                if (typeof value === 'object') {
                  value = JSON.stringify(value);
                }
                $scope.parameters[key].push(value);
              });
            }

            request.queryParams($scope.parameters);
            request.header('Accept', $scope.raml.mediaType || defaultAccept);
            request.headers(getParameters(context, 'headers'));

            if (context.bodyContent) {
              request.header('Content-Type', context.bodyContent.selected);
              request.data(context.bodyContent.data());
            }

            var authStrategy;

            try {
              var securitySchemes = $scope.methodInfo.securitySchemes();
              var scheme;

              Object.keys(securitySchemes).map(function(key) {
                if (securitySchemes[key].type === $scope.currentSchemeType) {
                  scheme = securitySchemes && securitySchemes[key];
                  return;
                }
              });

              //// TODO: Make a uniform interface
              if (scheme && scheme.type === 'OAuth 2.0') {
                authStrategy = new RAML.Client.AuthStrategies.Oauth2(scheme, $scope.credentials);
                authStrategy.authenticate(request.toOptions(), function (jqXhr, err) {
                  $scope.requestOptions = request.toOptions();
                  handleResponse(jqXhr, err);
                });
                return;
              }
              authStrategy = RAML.Client.AuthStrategies.forScheme(scheme, $scope.credentials);
              authStrategy.authenticate().then(function(token) {
                token.sign(request);
                $scope.requestOptions = request.toOptions();
                jQuery.ajax(request.toOptions()).then(
                  function(data, textStatus, jqXhr) { handleResponse(jqXhr); },
                  function(jqXhr) { handleResponse(jqXhr); }
                );
              });

              $scope.requestOptions = request.toOptions();
            } catch (e) {
              console.error(e);
              $scope.customStrategyError = true;
              $scope.response = {};

              $scope.showSpinner = false;
            }
          } else {
            $scope.context.forceRequest = true;
          }
        };

        $scope.documentationEnabled = true;

        $scope.closeSidebar = function ($event) {
          var $this         = jQuery($event.currentTarget);
          var $panel        = $this.closest('.raml-console-resource-panel');
          var $sidebar      = $panel.find('.raml-console-sidebar');
          var sidebarWidth  = 0;

          if (jQuery(window).width() > 960) {
            sidebarWidth = 430;
          }

          $scope.documentationEnabled = true;
          $sidebar.velocity(
            { width: 0 },
            {
              duration: 200,
              complete: function (element) {
                jQuery(element).removeAttr('style');
                $sidebar.removeClass('raml-console-is-fullscreen');
              }
            }
          );
          $sidebar.toggleClass('raml-console-is-collapsed');
          $sidebar.removeClass('raml-console-is-responsive');
          $panel.toggleClass('raml-console-has-sidebar-collapsed');
        };

        $scope.toggleSidebar = function ($event) {
          var $this        = jQuery($event.currentTarget);
          var $panel       = $this.closest('.raml-console-resource-panel');
          var $sidebar     = $panel.find('.raml-console-sidebar');
          var sidebarWidth = 0;

          if (jQuery(window).width() > 960) {
            sidebarWidth = 430;
          }

          if ($sidebar.hasClass('raml-console-is-fullscreen')) {
            $scope.documentationEnabled = true;
            $sidebar.velocity(
              { width: $scope.singleView ? 0 : sidebarWidth },
              {
                duration: 200,
                complete: function (element) {
                  jQuery(element).removeAttr('style');
                  $sidebar.removeClass('raml-console-is-fullscreen');
                }
              }
            );
            $sidebar.removeClass('raml-console-is-responsive');
            $panel.removeClass('raml-console-has-sidebar-fullscreen');
          } else {
            $sidebar.velocity(
              { width: '100%' },
              {
                duration: 200,
                complete: function (element) {
                  jQuery(element).removeAttr('style');
                  $scope.documentationEnabled = false;
                  apply();
                }
              }
            );

            $sidebar.addClass('raml-console-is-fullscreen');
            $sidebar.addClass('raml-console-is-responsive');
            $panel.addClass('raml-console-has-sidebar-fullscreen');
          }

          if ($scope.singleView) {
            $sidebar.toggleClass('raml-console-is-collapsed');
            $panel.toggleClass('raml-console-has-sidebar-collapsed');
          }
        };

        $scope.collapseSidebar = function ($event) {
          var $this         = jQuery($event.currentTarget);
          var $panel        = $this.closest('.raml-console-resource-panel');
          var $panelContent = $panel.find('.raml-console-resource-panel-primary');
          var $sidebar      = $panel.find('.raml-console-sidebar');
          var animation     = 430;
          var speed         = 200;

          if ((!$sidebar.hasClass('raml-console-is-fullscreen') && !$sidebar.hasClass('raml-console-is-collapsed')) || $sidebar.hasClass('raml-console-is-responsive')) {
            animation = 0;
          }

          if ($scope.singleView) {
            $panel.toggleClass('raml-console-has-sidebar-fullscreen');
            speed = 0;
          }

          $sidebar.velocity(
            { width: animation },
            {
              duration: speed,
              complete: function (element) {
                jQuery(element).removeAttr('style');
                if ($scope.singleView) {
                  $scope.documentationEnabled = false;
                }
                apply();
              }
            }
          );

          $panelContent.velocity(
            { 'padding-right': animation },
            {
              duration: speed,
              complete: completeAnimation
            }
          );

          $sidebar.toggleClass('raml-console-is-collapsed');
          $sidebar.removeClass('raml-console-is-responsive');
          $panel.toggleClass('raml-console-has-sidebar-collapsed');

          if ($sidebar.hasClass('raml-console-is-fullscreen') || $scope.singleView) {
            $sidebar.toggleClass('raml-console-is-fullscreen');
          }
        };

        $scope.toggleRequestMetadata = function (enabled) {
          if ($scope.showRequestMetadata && !enabled) {
            $scope.showRequestMetadata = false;
          } else {
            $scope.showRequestMetadata = true;
          }
        };

        $scope.showResponseMetadata = true;

        $scope.toggleResponseMetadata = function () {
          $scope.showResponseMetadata = !$scope.showResponseMetadata;
        };
      }]
    };
  };

  angular.module('RAML.Directives')
    .directive('sidebar', RAML.Directives.sidebar);
})();

(function () {
  'use strict';

  RAML.Directives.spinner = function() {
    return {
      restrict: 'E',
      templateUrl: 'directives/spinner.tpl.html',
      replace: true,
      link: function($scope, $element) {
        $scope.$on('loading-started', function() {
          $element.css({ 'display': ''});
        });

        $scope.$on('loading-complete', function() {
          $element.css({ 'display': 'none' });
        });
      }
    };
  };

  angular.module('RAML.Directives')
    .directive('spinner', RAML.Directives.spinner);
})();

(function () {
  'use strict';

  RAML.Directives.theme = function() {
    return {
      restrict: 'E',
      templateUrl: 'directives/theme-switcher.tpl.html',
      replace: true,
      link: function($scope, $element) {
        $element.on('click', function() {
          // var $link = jQuery('head link.theme');
          var $theme = jQuery('head').find('#raml-console-theme-dark');

          // $link.attr('href', 'styles/light-theme.css');
          // $element.removeClass('raml-console-theme-toggle-dark');

          if ($theme.length === 0) {
            jQuery.ajax({
              url: 'styles/api-console-dark-theme.css'
            }).done(function (data) {
              jQuery('head').append('<style id="raml-console-theme-dark">' + data + '</style>');
              jQuery('head').find('#raml-console-theme-light').remove();
            });
          } else {
            jQuery.ajax({
              url: 'styles/api-console-light-theme.css'
            }).done(function (data) {
              jQuery('head').append('<style id="raml-console-theme-light">' + data + '</style>');
              jQuery('head').find('#raml-console-theme-dark').remove();
            });
          }
        });
      }
    };
  };

  angular.module('RAML.Directives')
    .directive('themeSwitcher', RAML.Directives.theme);
})();

(function () {
  'use strict';

  RAML.Directives.typeProperties = function() {
    return {
      restrict: 'E',
      templateUrl: 'directives/type-properties.tpl.html',
      replace: true,
      scope: {
        type: '='
      },
      controller: ['$scope', function ($scope) {
        $scope.properties = {
          body: [$scope.type]
        };
      }]
    };
  };

  angular.module('RAML.Directives')
    .directive('typeProperties', RAML.Directives.typeProperties);
})();

(function () {
  'use strict';

  RAML.Directives.type = function() {
    var TOGGLE_POPOVER = 'popover:toggle';
    return {
      restrict: 'E',
      templateUrl: 'directives/type.tpl.html',
      scope: {
        typeName: '=',
        hideTypeLinks: '=',
        items: '='
      },
      controller: ['$scope', '$rootScope', '$timeout', function ($scope, $rootScope, $timeout) {
        $scope.typeInfo = RAML.Inspector.Types.getTypeInfo($scope.typeName, $scope.items);

        $scope.closePopover = function () {
          $scope.selectedType = null;
        };

        $rootScope.$on(TOGGLE_POPOVER, function () {
          $scope.closePopover();
        });

        $scope.showTypeLink = function (type) {
          return !$scope.hideTypeLinks && !RAML.Inspector.Types.isNativeType(type);
        };

        $scope.cleanupTypeName = RAML.Inspector.Types.cleanupTypeName;

        $scope.typeDocumentation = function(type) {
          type = RAML.Inspector.Types.findType(type.type[0], $rootScope.types);
          return RAML.Inspector.Types.typeDocumentation(type);
        };

        $scope.getSupertTypes = function (type) {
          return RAML.Inspector.Types.findType(type.type[0], $rootScope.types).type.map(function (aTypeName) {
            return aTypeName;
          });
        };

        $scope.selectType = function ($event, type) {
          jQuery(document).one('click', function () {
            $timeout(function () {
              $rootScope.$broadcast(TOGGLE_POPOVER);
            });
          });

          $rootScope.$broadcast(TOGGLE_POPOVER);

          $timeout(function () {
            $scope.selectedType = RAML.Inspector.Types.mergeType({
                displayName: type,
                type: [type]
              },
              $rootScope.types);
          });

          $event.stopPropagation();
        };
      }]
    };
  };

  angular.module('RAML.Directives')
    .directive('type', RAML.Directives.type);
})();

(function () {
  'use strict';

  RAML.Directives.validate = function($parse) {
    return {
      require: 'ngModel',
      link: function ($scope, $element, $attrs, $ctrl) {
        function clear ($ctrl, rules) {
          Object.keys(rules).map(function (key) {
            $ctrl.$setValidity(key, true);
          });
        }

        function validate(value) {
          var sanitizer = (new RAMLSanitize())(sanitationRules);
          var validator = (new RAMLValidate())(validationRules);
          var current   = {};
          var errors;

          value = typeof value !== 'undefined' && value !== null && value.length === 0 ? undefined : value;
          current[validationId] = value;

          errors = validator(sanitizer(current)).errors;

          if (errors.length > 0) {
            control.$setValidity(errors[0].rule, errors[0].valid);
            // Note: We want to allow invalid errors for testing purposes
            return value;
          } else {
            clear(control, validationRules[validationId]);
            return value;
          }
        }

        var validation      = $parse($attrs.validate)($scope);
        var validationId    = validation.id;
        var sanitationRules = {};
        var validationRules = {};
        var control         = $ctrl;

        if (validation && validation.type) {
          var declaredType = RAML.Inspector.Types.findType(validation.type[0], $scope.types);
          if (declaredType) { validation = declaredType; }
        }

        sanitationRules[validationId] = {
          type: validation.type || null,
          repeat: validation.repeat || null
        };

        sanitationRules[validationId] = RAML.Utils.filterEmpty(sanitationRules[validationId]);

        validationRules[validationId] = {
          type: validation.type || null,
          minLength: validation.minLength || null,
          maxLength: validation.maxLength || null,
          required: validation.required || null,
          'enum': validation['enum'] || null,
          pattern: validation.pattern || null,
          minimum: validation.minimum || null,
          maximum: validation.maximum || null,
          repeat: validation.repeat || null
        };

        validationRules[validationId] = RAML.Utils.filterEmpty(validationRules[validationId]);

        $ctrl.$formatters.unshift(function(value) {
          return validate(value);
        });

        $ctrl.$parsers.unshift(function(value) {
          return validate(value);
        });
      }
    };
  };

  angular.module('RAML.Directives')
    .directive('validate', ['$parse', RAML.Directives.validate]);
})();

(function () {
  'use strict';

  angular.module('raml')
    .factory('jsTraverse', ['$window', function jsTraverse($window) {
      return {traverse: $window.traverse};
    }])
  ;
})();

(function () {
  'use strict';

  angular.module('raml')
    .factory('ramlExpander',['$q', 'jsTraverse', function ramlExpander(
      $q,
      jsTraverse
    ) {
      return {
        expandRaml: expandRaml
      };

      // ---

      function retrieveType(raml, typeName) {
        if (!raml.types) { return; }

        var object = raml.types.filter(function (type) { return type[typeName]; })[0];
        return object ? object[typeName] : object;
      }

      function replaceTypeIfExists(raml, type, value) {
        var valueHasExamples = value.example || value.examples;
        var expandedType = retrieveType(raml, type);
        if (expandedType) {
          for (var key in expandedType) {
            if (expandedType.hasOwnProperty(key)) {
              if (['example', 'examples'].includes(key) && valueHasExamples) { continue; }
              value[key] = expandedType[key];
            }
          }
        }
      }

      function dereferenceTypes(raml) {
        jsTraverse.traverse(raml).forEach(function (value) {
          if (this.path.slice(-2).join('.') === 'body.application/json' && value.type) {
            var type = value.type[0];
            replaceTypeIfExists(raml, type, value);
          }
        });

      }

      function extractArrayType(arrayNode) {
        if(arrayNode.items.type) { return arrayNode.items.type[0]; }
        return arrayNode.items;
      }

      function isNotObject(value) {
        return value === null || typeof value !== 'object';
      }

      function dereferenceTypesInArrays(raml) {
        jsTraverse.traverse(raml).forEach(function (value) {
          if (this.path.slice(-2).join('.') === 'body.application/json' && value.type && value.type[0] === 'array') {
            var type = extractArrayType(value);
            if (isNotObject(value.items)) { value.items = {}; }
            replaceTypeIfExists(raml, type, value.items);

            if (!value.examples && !value.example) { generateArrayExampleIfPossible(value); }
          }
        });

      }

      function generateArrayExampleIfPossible(arrayNode) {
        var examples = getExampleList(arrayNode.items);
        if (examples.length === 0 ) { return; }

        arrayNode.example = examples;
      }

      function getExampleList(node) {
        if(node.examples) {
          return node.examples.map(function (example) {
            return example.structuredValue;
          });
        }
        if(node.example) { return [node.example]; }

        return [];
      }

      function dereferenceSchemas(raml) {
        jsTraverse.traverse(raml).forEach(function (value) {
          if (this.path.slice(-2).join('.') === 'body.application/json' && value.schema) {
            var schema = value.schema[0];
            replaceSchemaIfExists(raml, schema, value);
          }
        });

      }

      function replaceSchemaIfExists(raml, schema, value) {
        var expandedSchema = retrieveSchema(raml, schema);
        if (expandedSchema) {
          value.schema[0] = expandedSchema.type[0];
        }
      }

      function retrieveSchema(raml, schemaName) {
        if (!raml.schemas) { return; }

        var object = raml.schemas.filter(function (schema) { return schema[schemaName]; })[0];
        return object ? object[schemaName] : object;
      }

      function expandRaml(raml) {
        dereferenceTypes(raml);
        dereferenceSchemas(raml);
        dereferenceTypesInArrays(raml);
      }

    }])
  ;
})();

(function () {
  'use strict';

  angular.module('raml')
    .factory('ramlParser', ['$http', '$q', '$window', 'ramlExpander', function ramlParser(
      $http,
      $q,
      $window,
      ramlExpander
    ) {
      var jsonOptions=  {
        serializeMetadata: false,
        dumpSchemaContents: true,
        rootNodeDetails: true
      };

      return {
        load:     toQ(load),
        loadPath: toQ(loadPath)
      };

      // ---

      function load(text, contentAsyncFn, options) {
        var virtualPath = '/' + Date.now() + '.raml';
        return loadApi(virtualPath, function contentAsync(path) {
          return (path === virtualPath) ? $q.when(text) : (contentAsyncFn ? contentAsyncFn(path) : $q.reject(new Error('ramlParser: load: contentAsync: ' + path + ': no such path')));
        }, options);
      }

      function loadPath(path, contentAsyncFn, options) {
        return loadApi(path, function contentAsync(path) {
          return contentAsyncFn ? contentAsyncFn(path) : $q.reject(new Error('ramlParser: loadPath: contentAsync: ' + path + ': no such path'));
        }, options);
      }

      // ---

      function toQ(fn) {
        return function toQWrapper() {
          return $q.when(fn.apply(this, arguments));
        };
      }

      /**
       * @param  {String}   path
       * @param  {Function} contentAsyncFn
       * @param  {Object}   options
       * @param  {Boolean}  options.bypassProxy
       */
      function loadApi(path, contentAsyncFn, options) {
        options = options || {};
        return RAML.Parser.loadApi(path, {
          attributeDefaults: true,
          rejectOnErrors:    false,
          fsResolver:        {
            contentAsync: contentAsyncFn,
            content:      content
          },
          httpResolver:      {
            getResourceAsync: function getResourceAsync(url) {
              var settings = ($window.RAML || {}).Settings || {};
              var proxy    = (options.bypassProxy ? {} : settings).proxy || '';
              var req      = {
                method: 'GET',
                url: proxy + url,
                headers: {
                  'Accept': 'application/raml+yaml'
                },
                transformResponse: null
              };
              return $http(req)
                .then(function (res) {
                  return {content: res.data};
                })
              ;
            }
          }
        }).then(function(api) {
          api = api.expand ? api.expand(true) : api;
          var raml = api.toJSON(jsonOptions);
          if (raml.specification) {
            ramlExpander.expandRaml(raml.specification);
          }
          return raml;
        });

        // ---

        function content(path) {
          throw new Error('ramlParser: loadPath: loadApi: content: ' + path + ': no such path');
        }
      }
    }])
  ;
})();

(function () {
  'use strict';

  RAML.Security.basicAuth = function() {
    return {
      restrict: 'E',
      templateUrl: 'security/basic_auth.tpl.html',
      replace: true,
      scope: {
        credentials: '='
      },
      controller: ['$scope', function ($scope) {
        $scope.onChange = function () {
          $scope.$parent.context.forceRequest = false;
        };
      }]
    };
  };

  angular.module('RAML.Security')
    .directive('basicAuth', RAML.Security.basicAuth);
})();

(function () {
  'use strict';

  RAML.Security.oauth1 = function() {
    return {
      restrict: 'E',
      templateUrl: 'security/oauth1.tpl.html',
      replace: true,
      scope: {
        credentials: '='
      },
      controller: ['$scope', function ($scope) {
        $scope.onChange = function () {
          $scope.$parent.context.forceRequest = false;
        };
      }]
    };
  };

  angular.module('RAML.Security')
    .directive('oauth1', RAML.Security.oauth1);
})();

(function () {
  'use strict';

  RAML.Security.oauth2 = function() {
    return {
      restrict: 'E',
      templateUrl: 'security/oauth2.tpl.html',
      replace: true,
      controller: ['$scope', function ($scope) {
        $scope.onChange = function () {
          $scope.$parent.context.forceRequest = false;
        };

        $scope.ownerOptionsEnabled = function () {
          return $scope.credentials.grant === 'owner';
        };

        $scope.isImplicitEnabled = function () {
          return $scope.credentials.grant === 'token';
        };

        $scope.grants = [
          {
            label: 'Implicit',
            value: 'token'
          },
          {
            label: 'Implicit',
            value: 'implicit'
          },
          {
            label: 'Authorization Code',
            value: 'code'
          },
          {
            label: 'Authorization Code',
            value: 'authorization_code'
          },
          {
            label: 'Resource Owner Password Credentials',
            value: 'owner'
          },
          {
            label: 'Resource Owner Password Credentials',
            value: 'password'
          },
          {
            label: 'Client Credentials',
            value: 'credentials'
          },
          {
            label: 'Client Credentials',
            value: 'client_credentials'
          }
        ];

        /* jshint camelcase: false */
        $scope.getOAuth2Settings = function () {
          var result;
          for (var securitySchemesKey in $scope.$parent.securitySchemes) {
            if ($scope.$parent.securitySchemes.hasOwnProperty(securitySchemesKey)) {
              if ($scope.$parent.securitySchemes[securitySchemesKey].type === 'OAuth 2.0') {
                result = $scope.$parent.securitySchemes[securitySchemesKey].settings;
                break;
              }
            }
          }
          return result;
        };

        var oauth2Settings = $scope.getOAuth2Settings();
        var authorizationGrants = oauth2Settings.authorizationGrants;

        $scope.scopes = oauth2Settings.scopes;
        $scope.credentials.scopes = {};

        if (authorizationGrants) {
          $scope.grants = $scope.grants.filter(function (el) {
            return authorizationGrants.indexOf(el.value) > -1;
          });
        }
        /* jshint camelcase: true */

        $scope.credentials.grant = $scope.grants[0].value;
      }]
    };
  };


  angular.module('RAML.Security')
    .directive('oauth2', RAML.Security.oauth2);
})();

(function () {
  'use strict';
  angular.module('RAML.Services').factory('RecursionHelper', ['$compile', function ($compile) {
    return {
      /**
      * Manually compiles the element, fixing the recursion loop.
      * @param element
      * @param [link] A post-link function, or an object with function(s) registered via pre and post properties.
      * @returns An object containing the linking functions.
      */
      compile: function (element, link) {
        // Normalize the link parameter
        if (angular.isFunction(link)) {
          link = { post: link };
        }

        // Break the recursion loop by removing the contents
        var contents = element.contents().remove();
        var compiledContents;
        return {
          pre: (link && link.pre) ? link.pre : null,
          /**
          * Compiles and re-adds the contents
          */
          post: function (scope, element) {
            // Compile the contents
            if (!compiledContents) {
              compiledContents = $compile(contents);
            }
            // Re-add the compiled contents to the element
            compiledContents(scope, function (clone) {
              element.append(clone);
            });

            // Call the post-linking function, if any
            if (link && link.post) {
              link.post.apply(null, arguments);
            }
          }
        };
      }
    };
  }]);
})();

'use strict';

(function() {
  var Client = function(configuration) {
    this.baseUri = configuration.getBaseUri();
  };

  function createConfiguration(parsed) {
    var config = {
      baseUriParameters: {}
    };

    return {
      baseUriParameters: function(baseUriParameters) {
        config.baseUriParameters = baseUriParameters || {};
      },

      getBaseUri: function() {
        var template = RAML.Client.createBaseUri(parsed);
        config.baseUriParameters.version = parsed.version;

        return template.render(config.baseUriParameters);
      }
    };
  }

  RAML.Client = {
    create: function(parsed, configure) {
      var configuration = createConfiguration(parsed);

      if (configure) {
        configure(configuration);
      }

      return new Client(configuration);
    },

    createBaseUri: function(rootRAML) {
      var baseUri = rootRAML.baseUri.toString().replace(/\/+$/, '');

      return new RAML.Client.ParameterizedString(baseUri, rootRAML.baseUriParameters, { parameterValues: {version: rootRAML.version}, encodeURIComponent: true });
    },

    createPathSegment: function(resourceRAML) {
      return new RAML.Client.ParameterizedString(resourceRAML.relativeUri, resourceRAML.uriParameters, { encodeURIComponent: true });
    }
  };
})();

(function() {
  'use strict';

  RAML.Client.AuthStrategies = {
    forScheme: function(scheme, credentials) {
      if (!scheme) {
        return RAML.Client.AuthStrategies.anonymous();
      }

      switch(scheme.type) {
      case 'Basic Authentication':
        return new RAML.Client.AuthStrategies.Basic(scheme, credentials);
      case 'OAuth 2.0':
        return new RAML.Client.AuthStrategies.Oauth2(scheme, credentials);
      case 'OAuth 1.0':
        return new RAML.Client.AuthStrategies.Oauth1(scheme, credentials);
      case 'Pass Through':
        return RAML.Client.AuthStrategies.anonymous();
      case 'x-custom':
        return RAML.Client.AuthStrategies.anonymous();
      case 'Anonymous':
        return RAML.Client.AuthStrategies.anonymous();
      default:
        throw new Error('Unknown authentication strategy: ' + scheme.type);
      }
    }
  };
})();

'use strict';

(function() {
  var NO_OP_TOKEN = {
    sign: function() {}
  };

  var Anonymous = function() {};

  Anonymous.prototype.authenticate = function() {
    return {
      then: function(success) { success(NO_OP_TOKEN); }
    };
  };

  var anonymous = new Anonymous();

  RAML.Client.AuthStrategies.Anonymous = Anonymous;
  RAML.Client.AuthStrategies.anonymous = function() {
    return anonymous;
  };
})();

'use strict';

(function() {
  var Basic = function(scheme, credentials) {
    this.token = new Basic.Token(credentials);
  };

  Basic.prototype.authenticate = function() {
    var token = this.token;

    return {
      then: function(success) { success(token); }
    };
  };

  Basic.Token = function(credentials) {
    var words = CryptoJS.enc.Utf8.parse((credentials.username || '') + ':' + (credentials.password || ''));
    this.encoded = CryptoJS.enc.Base64.stringify(words);
  };

  Basic.Token.prototype.sign = function(request) {
    request.header('Authorization', 'Basic ' + this.encoded);
  };

  RAML.Client.AuthStrategies.Basic = Basic;
})();

(function() {
  'use strict';

  var Oauth1 = function(scheme, credentials) {
    var signerFactory = RAML.Client.AuthStrategies.Oauth1.Signer.createFactory(scheme.settings, credentials);
    this.requestTemporaryCredentials = RAML.Client.AuthStrategies.Oauth1.requestTemporaryCredentials(scheme.settings, signerFactory);
    this.requestAuthorization = RAML.Client.AuthStrategies.Oauth1.requestAuthorization(scheme.settings);
    this.requestTokenCredentials = RAML.Client.AuthStrategies.Oauth1.requestTokenCredentials(scheme.settings, signerFactory);
  };

  Oauth1.parseUrlEncodedData = function(data) {
    var result = {};

    data.split('&').forEach(function(param) {
      var keyAndValue = param.split('=');
      result[keyAndValue[0]] = keyAndValue[1];
    });

    return result;
  };

  Oauth1.prototype.authenticate = function() {
    return this.requestTemporaryCredentials().then(this.requestAuthorization).then(this.requestTokenCredentials);
  };

  RAML.Client.AuthStrategies.Oauth1 = Oauth1;
})();

(function() {
  /* jshint camelcase: false */
  'use strict';

  var WINDOW_NAME = 'raml-console-oauth1';

  RAML.Client.AuthStrategies.Oauth1.requestAuthorization = function(settings) {
    return function requestAuthorization(temporaryCredentials) {
      var authorizationUrl = settings.authorizationUri + '?oauth_token=' + temporaryCredentials.token,
      deferred = jQuery.Deferred();

      window.RAML.authorizationSuccess = function(authResult) {
        temporaryCredentials.verifier = authResult.verifier;
        deferred.resolve(temporaryCredentials);
      };
      window.open(authorizationUrl, WINDOW_NAME);
      return deferred.promise();
    };
  };
})();

(function() {
  /* jshint camelcase: false */
  'use strict';

  RAML.Client.AuthStrategies.Oauth1.requestTemporaryCredentials = function(settings, signerFactory) {
    return function requestTemporaryCredentials() {
      var request = RAML.Client.Request.create(settings.requestTokenUri, 'post');

      signerFactory().sign(request);

      return jQuery.ajax(request.toOptions()).then(function(rawFormData) {
        var data = RAML.Client.AuthStrategies.Oauth1.parseUrlEncodedData(rawFormData);

        return {
          token: data.oauth_token,
          tokenSecret: data.oauth_token_secret
        };
      });
    };
  };

})();

(function() {
  /* jshint camelcase: false */
  'use strict';

  RAML.Client.AuthStrategies.Oauth1.requestTokenCredentials = function(settings, signerFactory) {
    return function requestTokenCredentials(temporaryCredentials) {
      var request = RAML.Client.Request.create(settings.tokenCredentialsUri, 'post');

      signerFactory(temporaryCredentials).sign(request);

      return jQuery.ajax(request.toOptions()).then(function(rawFormData) {
        var credentials = RAML.Client.AuthStrategies.Oauth1.parseUrlEncodedData(rawFormData);

        return signerFactory({
          token: credentials.oauth_token,
          tokenSecret: credentials.oauth_token_secret
        });
      });
    };
  };
})();

(function() {
  /* jshint camelcase: false */
  'use strict';

  var Signer = RAML.Client.AuthStrategies.Oauth1.Signer = {};

  Signer.createFactory = function(settings, consumerCredentials) {
    settings = settings || {};

    return function createSigner(tokenCredentials) {
      var type = settings.signatureMethod === 'PLAINTEXT' ? 'Plaintext' : 'Hmac';
      var mode = tokenCredentials === undefined ? 'Temporary' : 'Token';

      return new Signer[type][mode](consumerCredentials, tokenCredentials);
    };
  };

  function baseParameters(consumerCredentials) {
    return {
      oauth_consumer_key: consumerCredentials.consumerKey,
      oauth_version: '1.0'
    };
  }

  Signer.generateTemporaryCredentialParameters = function(consumerCredentials) {
    var result = baseParameters(consumerCredentials);
    result.oauth_callback = RAML.Settings.oauth1RedirectUri;

    return result;
  };

  Signer.generateTokenCredentialParameters = function(consumerCredentials, tokenCredentials) {
    var result = baseParameters(consumerCredentials);

    result.oauth_token = tokenCredentials.token;
    if (tokenCredentials.verifier) {
      result.oauth_verifier = tokenCredentials.verifier;
    }

    return result;
  };

  // https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/encodeURIComponent
  Signer.rfc3986Encode = function(str) {
    return encodeURIComponent(str).replace(/[!'()]/g, window.escape).replace(/\*/g, '%2A');
  };

  Signer.setRequestHeader = function(params, request) {
    var header = Object.keys(params).map(function(key) {
      return key + '="' + Signer.rfc3986Encode(params[key]) + '"';
    }).join(', ');

    request.header('Authorization', 'OAuth ' + header);
  };
})();

(function() {
  /* jshint camelcase: false */
  'use strict';

  var generateTemporaryCredentialParameters = RAML.Client.AuthStrategies.Oauth1.Signer.generateTemporaryCredentialParameters,
      generateTokenCredentialParameters = RAML.Client.AuthStrategies.Oauth1.Signer.generateTokenCredentialParameters,
      rfc3986Encode = RAML.Client.AuthStrategies.Oauth1.Signer.rfc3986Encode,
      setRequestHeader = RAML.Client.AuthStrategies.Oauth1.Signer.setRequestHeader;

  function generateSignature(params, request, key) {
    params.oauth_signature_method = 'HMAC-SHA1';
    params.oauth_timestamp = Math.floor(Date.now() / 1000);
    params.oauth_nonce = CryptoJS.lib.WordArray.random(16).toString();

    var data = Hmac.constructHmacText(request, params);
    var hash = CryptoJS.HmacSHA1(data, key);
    params.oauth_signature = hash.toString(CryptoJS.enc.Base64);
  }

  var Hmac = {
    constructHmacText: function(request, oauthParams) {
      var options = request.toOptions();

      return [
        options.method.toUpperCase(),
        this.encodeURI(options.url),
        rfc3986Encode(this.encodeParameters(request, oauthParams))
      ].join('&');
    },

    encodeURI: function(uri) {
      var parser = document.createElement('a');
      parser.href = uri;

      var hostname = '';
      if (parser.protocol === 'https:' && parser.port === 443 || parser.protocol === 'http:' && parser.port === 80) {
        hostname = parser.hostname.toLowerCase();
      } else {
        hostname = parser.host.toLowerCase();
      }

      return rfc3986Encode(parser.protocol + '//' + hostname + parser.pathname);
    },

    encodeParameters: function(request, oauthParameters) {
      var params = request.queryParams();
      var formParams = {};
      if (request.toOptions().contentType === 'application/x-www-form-urlencoded') {
        formParams = request.data();
      }

      var result = [];
      for (var key in params) {
        result.push([rfc3986Encode(key), rfc3986Encode(params[key])]);
      }

      for (var formKey in formParams) {
        result.push([rfc3986Encode(formKey), rfc3986Encode(formParams[formKey])]);
      }

      for (var oauthKey in oauthParameters) {
        result.push([rfc3986Encode(oauthKey), rfc3986Encode(oauthParameters[oauthKey])]);
      }

      result.sort(function(a, b) {
        return (a[0] === b[0] ? a[1].localeCompare(b[1]) : a[0].localeCompare(b[0]));
      });

      return result.map(function(tuple) { return tuple.join('='); }).join('&');
    }
  };

  Hmac.Temporary = function(consumerCredentials) {
    this.consumerCredentials = consumerCredentials;
  };

  Hmac.Temporary.prototype.sign = function(request) {
    var params = generateTemporaryCredentialParameters(this.consumerCredentials);
    var key = rfc3986Encode(this.consumerCredentials.consumerSecret) + '&';

    generateSignature(params, request, key);
    setRequestHeader(params, request);
  };

  Hmac.Token = function(consumerCredentials, tokenCredentials) {
    this.consumerCredentials = consumerCredentials;
    this.tokenCredentials = tokenCredentials;
  };

  Hmac.Token.prototype.sign = function(request) {
    var params = generateTokenCredentialParameters(this.consumerCredentials, this.tokenCredentials);
    var key = rfc3986Encode(this.consumerCredentials.consumerSecret) + '&' + rfc3986Encode(this.tokenCredentials.tokenSecret);

    generateSignature(params, request, key);
    setRequestHeader(params, request);
  };

  RAML.Client.AuthStrategies.Oauth1.Signer.Hmac = Hmac;
})();

(function() {
  /* jshint camelcase: false */
  'use strict';

  var generateTemporaryCredentialParameters = RAML.Client.AuthStrategies.Oauth1.Signer.generateTemporaryCredentialParameters,
      generateTokenCredentialParameters = RAML.Client.AuthStrategies.Oauth1.Signer.generateTokenCredentialParameters,
      rfc3986Encode = RAML.Client.AuthStrategies.Oauth1.Signer.rfc3986Encode,
      setRequestHeader = RAML.Client.AuthStrategies.Oauth1.Signer.setRequestHeader;

  var Plaintext = {};

  Plaintext.Temporary = function(consumerCredentials) {
    this.consumerCredentials = consumerCredentials;
  };

  Plaintext.Temporary.prototype.sign = function(request) {
    var params = generateTemporaryCredentialParameters(this.consumerCredentials);
    params.oauth_signature = rfc3986Encode(this.consumerCredentials.consumerSecret) + '&';
    params.oauth_signature_method = 'PLAINTEXT';

    setRequestHeader(params, request);
  };

  Plaintext.Token = function(consumerCredentials, tokenCredentials) {
    this.consumerCredentials = consumerCredentials;
    this.tokenCredentials = tokenCredentials;
  };

  Plaintext.Token.prototype.sign = function(request) {
    var params = generateTokenCredentialParameters(this.consumerCredentials, this.tokenCredentials);
    params.oauth_signature = rfc3986Encode(this.consumerCredentials.consumerSecret) + '&' + rfc3986Encode(this.tokenCredentials.tokenSecret);
    params.oauth_signature_method = 'PLAINTEXT';

    setRequestHeader(params, request);
  };

  RAML.Client.AuthStrategies.Oauth1.Signer.Plaintext = Plaintext;
})();

(function() {
  'use strict';

  var Oauth2 = function(scheme, credentials) {
    this.scheme = scheme;
    this.credentials = credentials;
  };

  function getScopes(credentials) {
    var scopes = [];

    if (credentials.scopes) {
      scopes = Object.keys(credentials.scopes).filter(function (scope) {
        return credentials.scopes[scope] === true;
      });
    }

    return scopes;
  }

  function popup(location) {
    var w    = 640;
    var h    = 480;
    var left = (screen.width / 2) - (w / 2);
    var top  = (screen.height / 2) - (h / 2);
    return window.open(location, 'Authentication', 'toolbar=no, location=no, directories=no, status=no, menubar=no, scrollbars=no, resizable=no, copyhistory=no, width=' + w + ', height=' + h + ', top=' + top + ', left=' + left);
  }

  Oauth2.prototype.authenticate = function(options, done) {
    var auth = new ClientOAuth2({
      clientId:         this.credentials.clientId,
      clientSecret:     this.credentials.clientSecret,
      accessTokenUri:   this.scheme.settings.accessTokenUri,
      authorizationUri: this.scheme.settings.authorizationUri,
      redirectUri:      RAML.Settings.oauth2RedirectUri,
      scopes:           getScopes(this.credentials)
    });
    var grantType = this.credentials.grant;

    if (grantType === 'token' || grantType === 'code' || grantType === 'authorization_code' || grantType === 'implicit') {
      window.oauth2Callback = function (uri) {
        auth[grantType].getToken(uri, function (err, user, raw) {
          if (err) {
            done(raw, err);
          }

          if (user && user.accessToken) {
            user.request(options, function (err, res) {
              done(res.raw, err);
            });
          }
        });
      };
      //// TODO: Find a way to handle 404
      popup(auth[grantType].getUri());
    }

    if (grantType === 'owner' || grantType === 'password') {
      auth.owner.getToken(this.credentials.username, this.credentials.password, function (err, user, raw) {
        if (err) {
          done(raw, err);
        }

        if (user && user.accessToken) {
          user.request(options, function (err, res) {
            done(res.raw, err);
          });
        }
      });
    }

    if (grantType === 'credentials'|| grantType === 'client_credentials') {
      auth.credentials.getToken(function (err, user, raw) {
        if (err) {
          done(raw, err);
        }

        if (user && user.accessToken) {
          user.request(options, function (err, res) {
            done(res.raw, err);
          });
        }
      });
    }
  };

  RAML.Client.AuthStrategies.Oauth2 = Oauth2;
})();

(function() {
  'use strict';

  var templateMatcher = /\{([^}]*)\}/g;

  function tokenize(template) {
    var tokens = template.split(templateMatcher);

    return tokens.filter(function(token) {
      return token.length > 0;
    });
  }

  function rendererFor(template, uriParameters, options) {
    return function renderer(context) {
      context = context || {};

      // Enforce request without URI parameters
      // requiredParameters.forEach(function(name) {
      //   if (!context[name]) {
      //     throw new Error('Missing required uri parameter: ' + name);
      //   }
      // });

      var templated = template.replace(templateMatcher, function(match, parameterName) {
        if (context[parameterName]) {
          if (typeof context[parameterName][0] !== 'object') {
            return context[parameterName];
          }
          var tempValue = JSON.stringify(
            RAML.Inspector.Properties.cleanupPropertyValue(context[parameterName][0]));

          if (options.encodeURIComponent) {
            tempValue = encodeURIComponent(tempValue);
          }

          return tempValue;
        }
        return '';
      });

      return templated;
    };
  }

  RAML.Client.ParameterizedString = function(template, uriParameters, options) {
    options = angular.extend({ parameterValues: {} }, options);
    template = template.replace(templateMatcher, function(match, parameterName) {
      if (options.parameterValues[parameterName]) {
        return options.parameterValues[parameterName];
      }
      return '{' + parameterName + '}';
    });

    this.parameters = uriParameters;
    this.templated = Object.keys(this.parameters || {}).length > 0;
    this.tokens = tokenize(template);
    this.render = rendererFor(template, uriParameters, options);
    this.toString = function() { return template; };
  };
})();

(function() {
  'use strict';

  RAML.Client.PathBuilder = {
    create: function(pathSegments) {
      return function pathBuilder(contexts) {
        contexts = contexts || [];

        return pathSegments.map(function(pathSegment, index) {
          return pathSegment.render(contexts[index]);
        }).join('');
      };
    }
  };
})();

(function() {
  'use strict';

  var CONTENT_TYPE = 'content-type';
  var FORM_DATA = 'multipart/form-data';

  var RequestDsl = function(options) {
    var rawData;
    var queryParams;
    var isMultipartRequest;

    this.data = function(data) {
      if (data === undefined) {
        return RAML.Utils.clone(rawData);
      } else {
        rawData = data;
      }
    };

    this.queryParams = function(parameters) {
      if (parameters === undefined) {
        return RAML.Utils.clone(queryParams);
      } else {
        queryParams = parameters;
      }
    };

    this.queryParam = function(name, value) {
      queryParams = queryParams || {};
      queryParams[name] = value;
    };

    this.header = function(name, value) {
      options.headers = options.headers || {};

      if (name.toLowerCase() === CONTENT_TYPE) {
        if (value === FORM_DATA) {
          isMultipartRequest = true;
          options.contentType = false;
          return;
        } else {
          isMultipartRequest = false;
          options.contentType = value;
        }
      }

      options.headers[name] = value;
    };

    this.headers = function(headers) {
      options.headers = {};
      isMultipartRequest = false;

      for (var name in headers) {
        this.header(name, headers[name]);
      }

      if (Object.keys(options.headers).length === 0) {
        options.headers = null;
      }
    };

    this.toOptions = function() {
      var o = RAML.Utils.copy(options);
      o.traditional = true;

      if (rawData) {
        if (isMultipartRequest) {
          var data = new FormData();

          var appendValueForKey = function(key) {
            return function(value) {
              data.append(key, value);
            };
          };

          for (var key in rawData) {
            rawData[key].forEach(appendValueForKey(key));
          }

          o.processData = false;
          o.data = data;
        } else {
          o.processData = true;
          o.data = rawData;
        }
      }

      o.baseUrl = options.url;

      if (!RAML.Utils.isEmpty(queryParams)) {
        var separator = (options.url.match('\\?') ? '&' : '?');

        o.baseUrl = options.url + separator;
        o.url = options.url + separator + jQuery.param(queryParams, true);
      }

      if (!RAML.Settings.disableProxy && RAML.Settings.proxy) {
        o.url = RAML.Settings.proxy + o.url;
      }

      return o;
    };
  };

  RAML.Client.Request = {
    create: function(url, method) {
      return new RequestDsl({ url: url, method: method });
    }
  };
})();

(function() {
  'use strict';

  // number regular expressions from http://yaml.org/spec/1.2/spec.html#id2804092

  var RFC1123 = /^(Mon|Tue|Wed|Thu|Fri|Sat|Sun), \d{2} (Jan|Feb|Mar|Apr|May|Jun|Jul|Aug|Sep|Oct|Nov|Dec) \d{4} \d{2}:\d{2}:\d{2} GMT$/;

  function isEmpty(value) {
    return value == null || value === '';
  }

  var VALIDATIONS = {
    required: function(value) {
      return !isEmpty(value);
    },
    'boolean': function(value) {
      return isEmpty(value) || value === 'true' || value === 'false';
    },
    'enum': function(enumeration) {
      return function(value) {
        return isEmpty(value) || enumeration.indexOf(value) > -1;
      };
    },
    integer: function(value) {
      return isEmpty(value) || /^-?(0|[1-9][0-9]*)$/.test(value);
    },
    number: function(value) {
      return isEmpty(value) || /^-?(0|[1-9][0-9]*)(\.[0-9]*)?([eE][-+]?[0-9]+)?$/.test(value);
    },
    minimum: function(minimum) {
      return function(value) {
        return isEmpty(value) || value >= minimum;
      };
    },
    maximum: function(maximum) {
      return function(value) {
        return isEmpty(value) || value <= maximum;
      };
    },
    minLength: function(minimum) {
      return function(value) {
        return isEmpty(value) || value.length >= minimum;
      };
    },
    maxLength: function(maximum) {
      return function(value) {
        return isEmpty(value) || value.length <= maximum;
      };
    },
    pattern: function(pattern) {
      var regex = new RegExp(pattern);

      return function(value) {
        return isEmpty(value) || regex.test(value);
      };
    },
    date: function(value) {
      return isEmpty(value) || RFC1123.test(value);
    }
  };

  function baseValidations(definition) {
    var validations = {};

    if (definition.required) {
      validations.required = VALIDATIONS.required;
    }

    return validations;
  }

  function numberValidations(validations, definition) {
    if (definition.minimum != null) {
      validations.minimum = VALIDATIONS.minimum(definition.minimum);
    }

    if (definition.maximum != null) {
      validations.maximum = VALIDATIONS.maximum(definition.maximum);
    }
  }

  // function copyValidations(validations, types) {
  //   Object.keys(types).forEach(function(type) {
  //     validations[type] = VALIDATIONS[type](types[type]);
  //   });
  // }

  var VALIDATIONS_FOR_TYPE = {
    string: function(definition) {
      var validations = baseValidations(definition);

      if (Array.isArray(definition['enum'])) {
        validations['enum'] = VALIDATIONS['enum'](definition['enum']);
      }

      if (definition.minLength != null) {
        validations.minLength = VALIDATIONS.minLength(definition.minLength);
      }

      if (definition.maxLength != null) {
        validations.maxLength = VALIDATIONS.maxLength(definition.maxLength);
      }

      if (definition.pattern) {
        validations.pattern = VALIDATIONS.pattern(definition.pattern);
      }

      return validations;
    },

    integer: function(definition) {
      var validations = baseValidations(definition);
      validations.integer = VALIDATIONS.integer;
      numberValidations(validations, definition);
      return validations;
    },

    number: function(definition) {
      var validations = baseValidations(definition);
      validations.number = VALIDATIONS.number;
      numberValidations(validations, definition);
      return validations;
    },

    'boolean': function(definition) {
      var validations = baseValidations(definition);
      // Ignore better written in dot notation rule
      /*jshint -W069 */
      validations['boolean'] = VALIDATIONS['boolean'];
      /*jshint +W069 */
      return validations;
    },

    date: function(definition) {
      var validations = baseValidations(definition);
      validations.date = VALIDATIONS.date;
      return validations;
    }
  };

  function Validator(validations) {
    this.validations = validations;
  }

  Validator.prototype.validate = function(value) {
    var errors;

    for (var validation in this.validations) {
      if (!this.validations[validation](value)) {
        errors = errors || [];
        errors.push(validation);
      }
    }

    return errors;
  };

  Validator.from = function(definition) {
    if (!definition) {
      throw new Error('definition is required!');
    }

    var validations;

    if (VALIDATIONS_FOR_TYPE[definition.type]) {
      validations = VALIDATIONS_FOR_TYPE[definition.type](definition);
    } else {
      validations = {};
    }

    return new Validator(validations);
  };

  RAML.Client.Validator = Validator;
})();

(function() {
  'use strict';

  RAML.Filters.nameFromParameterizable = function() {
    return function(input) {
      if (typeof input === 'object' && input !== null) {
        return Object.keys(input)[0];
      } else if (input) {
        return input;
      } else {
        return undefined;
      }
    };
  };
})();

RAML.Inspector = (function() {
  'use strict';

  var exports = {};

  var METHOD_ORDERING = ['GET', 'POST', 'PUT', 'PATCH', 'DELETE', 'HEAD', 'OPTIONS', 'TRACE', 'CONNECT'];

  function extractResources(basePathSegments, api, securitySchemes) {
    var resources = [], apiResources = api.resources || [];

    apiResources.forEach(function(resource) {
      var resourcePathSegments = basePathSegments.concat(RAML.Client.createPathSegment(resource));
      var overview = exports.resourceOverviewSource(resourcePathSegments, resource);

      overview.methods = overview.methods.map(function(method) {
        return RAML.Inspector.Method.create(method, securitySchemes);
      });


      resources.push(overview);

      if (resource.resources) {
        var extracted = extractResources(resourcePathSegments, resource, securitySchemes);
        extracted.forEach(function(resource) {
          resources.push(resource);
        });
      }
    });

    return resources;
  }

  function groupResources(resources) {
    var currentPrefix, resourceGroups = [];

    (resources || []).forEach(function(resource) {
      var prefix = resource.pathSegments[0].toString();
      if (prefix === currentPrefix || prefix.indexOf(currentPrefix + '/') === 0) {
        resourceGroups[resourceGroups.length-1].push(resource);
      } else {
        currentPrefix = resource.pathSegments[0].toString();
        resourceGroups.push([resource]);
      }
    });

    return resourceGroups;
  }

  exports.resourceOverviewSource = function(pathSegments, resource) {
    var clone = RAML.Utils.clone(resource);

    clone.traits = resource.is;
    clone.resourceType = resource.type;
    clone.type = clone.is = undefined;
    clone.pathSegments = pathSegments;

    clone.methods = (resource.methods || []);

    clone.methods.sort(function(a, b) {
      var aOrder = METHOD_ORDERING.indexOf(a.method.toUpperCase());
      var bOrder = METHOD_ORDERING.indexOf(b.method.toUpperCase());

      return aOrder > bOrder ? 1 : -1;
    });

    clone.uriParametersForDocumentation = RAML.Inspector.Properties.normalizeNamedParameters(pathSegments
      .map(function(segment) { return segment.parameters; })
      .filter(function(params) { return !!params; })
      .reduce(function(accum, parameters) {
        for (var key in parameters) {
          accum[key] = parameters[key];
        }
        return accum;
      }, {}));

    if (Object.keys(clone.uriParametersForDocumentation).length === 0) {
      clone.uriParametersForDocumentation = null;
    }

    clone.toString = function() {
      return this.pathSegments.map(function(segment) { return segment.toString(); }).join('');
    };

    return clone;
  };

  exports.create = function(api) {
    // Perform deep copy to avoid mutating object.
    // TODO: Audit code and only use parts of object that are required.
    api = jQuery.extend(true, {}, api);

    if (api.baseUri) {
      api.baseUri = RAML.Client.createBaseUri(api);
    }

    api.resources = extractResources([], api, api.securitySchemes);
    api.resourceGroups = groupResources(api.resources);

    return api;
  };

  return exports;
})();

(function() {
  'use strict';

  var PARAMETER = /\{\*\}/;

  function wrapWithParameterizedHeader(name, definitions) {
    return definitions.map(function(definition) {
      return RAML.Inspector.ParameterizedHeader.fromRAML(name, definition);
    });
  }

  function filterHeaders(headers) {
    var filtered = {
      plain: {},
      parameterized: {}
    };

    Object.keys(headers || {}).forEach(function(key) {
      if (key.match(PARAMETER)) {
        filtered.parameterized[key] = wrapWithParameterizedHeader(key, headers[key]);
      } else {
        filtered.plain[key] = headers[key];
      }
    });

    if(Object.keys(filtered.plain).length === 0) {
      filtered.plain = null;
    }

    return filtered;
  }

  function processBody(body) {
    var content = body['application/x-www-form-urlencoded'];
    if (content) {
      RAML.Inspector.Properties.normalizeNamedParameters(content.formParameters);
    }

    content = body['multipart/form-data'];
    if (content) {
      RAML.Inspector.Properties.normalizeNamedParameters(content.formParameters);
    }
  }

  function processResponses(responses) {
    Object.keys(responses).forEach(function(status) {
      var response = responses[status];
      if (response) {
        RAML.Inspector.Properties.normalizeNamedParameters(response.headers);
      }
    });
  }

  function securitySchemesExtractor(securitySchemes) {
    securitySchemes = securitySchemes || [];

    return function() {
      var securedBy = this.securedBy || [],
          selectedSchemes = {};

      var overwrittenSchemes = {};

      securedBy.map(function(el) {
        if (el === null) {
          securitySchemes.push({
            anonymous: {
              type: 'Anonymous'
            }
          });
          securedBy.push('anonymous');
        }

        if (typeof el === 'object' && el) {
          var key = Object.keys(el)[0];

          overwrittenSchemes[key] = el[key];
          securedBy.push(key);
        }
      });

      securedBy = securedBy.filter(function(name) {
        return name !== null && typeof name !== 'object';
      });

      securitySchemes.forEach(function(scheme) {
        securedBy.forEach(function(name) {
          if (scheme[name]) {
            selectedSchemes[name] = jQuery.extend(true, {}, scheme[name]);
          }
        });
      });

      Object.keys(overwrittenSchemes).map(function (key) {
        Object.keys(overwrittenSchemes[key]).map(function (prop) {
          if (selectedSchemes[key].settings) {
            selectedSchemes[key].settings[prop] = overwrittenSchemes[key][prop];
          }
        });
      });

      if(Object.keys(selectedSchemes).length === 0) {
        selectedSchemes.anonymous = {
          type: 'Anonymous'
        };
      }

      return selectedSchemes;
    };
  }

  function allowsAnonymousAccess() {
    /*jshint validthis: true */
    var securedBy = this.securedBy || [null];
    return securedBy.some(function(name) { return name === null; });
  }

  RAML.Inspector.Method = {
    create: function(raml, securitySchemes) {
      var method = RAML.Utils.clone(raml);

      method.responseCodes = Object.keys(method.responses || {});
      method.securitySchemes = securitySchemesExtractor(securitySchemes);
      method.allowsAnonymousAccess = allowsAnonymousAccess;
      RAML.Inspector.Properties.normalizeNamedParameters(method.headers);
      RAML.Inspector.Properties.normalizeNamedParameters(method.queryParameters);

      method.headers = filterHeaders(method.headers);
      processBody(method.body || {});
      processResponses(method.responses || {});

      method.plainAndParameterizedHeaders = RAML.Utils.copy(method.headers.plain);
      Object.keys(method.headers.parameterized).forEach(function(parameterizedHeader) {
        method.plainAndParameterizedHeaders[parameterizedHeader] = method.headers.parameterized[parameterizedHeader].map(function(parameterized) {
          return parameterized.definition();
        });
      });

      return method;
    }
  };
})();

(function () {
  'use strict';

  function validate(value) {
    value = value ? value.trim() : '';

    if (value === '') {
      throw new Error();
    }

    return value;
  }

  function fromRAML(name, definition) {
    var parameterizedString = new RAML.Client.ParameterizedString(name, definition);

    return {
      create: function(value) {
        value = validate(value);

        var header = RAML.Utils.clone(definition);
        header.displayName = parameterizedString.render({'*': value});

        return header;
      },
      definition: function() {
        return definition;
      }
    };
  }

  RAML.Inspector.ParameterizedHeader = {
    fromRAML: fromRAML
  };
})();

(function() {
  'use strict';

  function ensureArray(value) {
    if (value === undefined || value === null) {
      return;
    }

    return (value instanceof Array) ? value : [ value ];
  }

  function normalizeNamedParameters(parameters) {
    Object.keys(parameters || {}).forEach(function(key) {
      if (parameters[key].properties) {
        normalizeNamedParameters(parameters[key].properties);
      }

      parameters[key] = ensureArray(parameters[key]);
    });

    return parameters;
  }

  function cleanupPropertyValue(value) {
    if (typeof value !== 'object') {
      return value;
    }
    var cleanedValue = {};

    if (Array.isArray(value)) {
      cleanedValue = value.map(function (arrayItem) {
        return cleanupPropertyValue(arrayItem[0]);
      });
    } else {
      Object.keys(value).forEach(function (key) {
        cleanedValue[key] = cleanupPropertyValue(value[key] ? value[key][0] : value[key]);

        // Remove empty array property
        if (!cleanedValue[key][0]) {
          delete cleanedValue[key];
        }
      });
    }

    return cleanedValue;
  }

  RAML.Inspector.Properties = {
    normalizeNamedParameters: normalizeNamedParameters,
    cleanupPropertyValue: cleanupPropertyValue
  };
})();

(function() {
  'use strict';

  var UNION_ARRAY_REGEXP = /^\([^\)]*\)\[\]$/;

  function cleanupTypeName(typeName) {
    return typeName.replace('[]', '').replace('(', '').replace(')', '').trim();
  }

  function isNativeType(typeName) {
    typeName = cleanupTypeName(typeName);
    var nativeTypes = [
      'object',
      'string',
      'number',
      'integer',
      'boolean',
      'date-only',
      'time-only',
      'datetime-only',
      'datetime',
      'file',
      'array'
    ];
    return nativeTypes.indexOf(typeName) !== -1;
  }

  function isSchema(typeName) {
    try {
      JSON.parse(typeName);
      return true;
    } catch (error) {
      return false;
    }
  }

  function find(name, collection) {
    var found;
    var length = collection.length;
    for (var i = 0; i < length; i++) {
      if (collection[i][name]) {
        found = collection[i][name];
        break;
      }
    }
    return found;
  }

  function findType(typeName, types) {
    if (types) {
      typeName = cleanupTypeName(typeName);
      var existingType = find(typeName, types);
      return existingType;
    }
  }

  function findSchema(schemaName, schemas) {
    if (schemas) {
      var existingSchema = find(schemaName, schemas);
      return existingSchema;
    }
  }

  function getSuperTypesProperties(properties, typeName, types) {
    if (!isNativeType(typeName)) {
      var superType = findType(typeName, types);

      if (superType) {
        var superTypeProperties = convertProperties(superType);
        properties = angular.extend({}, superTypeProperties, properties);
        return getSuperTypesProperties(properties, superType.type[0], types);
      }
    }
    return properties;
  }

  function convertProperties(type) {
    if (type.properties) {
      Object.keys(type.properties).forEach(function (propertyKey) {
        var aProperty = type.properties[propertyKey];
        if (type.discriminator && type.discriminator === aProperty[0].name) {
          aProperty[0].discriminator = true;
        }
      });
    }
    return type.properties;
  }

  function mergeType(type, types) {
    var resultingType = angular.copy(type);
    resultingType.type = resultingType.type || resultingType.schema;
    var properties = angular.copy(resultingType.properties || {});
    var currentType = Array.isArray(resultingType.type) ?
        resultingType.type[0] : resultingType.type;

    properties = convertProperties(resultingType);

    if (!isNativeType(currentType)) {
      resultingType.type.forEach(function (superType) {
        properties = getSuperTypesProperties(properties, superType, types);
      });
    }
    if (properties) {
      var propertiesKeys = Object.keys(properties).sort();

      if (propertiesKeys.length > 0) {
        resultingType.properties = propertiesKeys.map(function (key) {
          return ensureArray(properties[key]);
        });
      }
    }

    return resultingType;
  }

  function getTypeInfo(typeName) {
    var types = typeName.split('|');
    var typeInfo = {};

    if (types.length > 1) {
      typeInfo.type = 'union';
      typeInfo.isArray = UNION_ARRAY_REGEXP.test(typeName);
      typeInfo.parts = types.map(function (type) {
        return cleanupTypeName(type);
      });
    } else if (typeName.indexOf('[]') !== -1) {
      typeInfo.type = 'array';
      typeInfo.parts = [typeName.replace('[]', '').trim()];
    } else {
      typeInfo.type = 'custom';
      typeInfo.parts = [typeName.trim()];
    }

    return typeInfo;
  }

  function getTypeFromTypeInfo(typeInfo) {
    var type;
    if (typeInfo.type === 'union') {
      type = typeInfo.parts.join('|');
      if (typeInfo.isArray) {
        type = '(' + type + ')[]';
      }

      return type;
    } else if (typeInfo.type === 'array') {
      return typeInfo.parts.join('') + '[]';
    } else {
      return typeInfo.parts.join('');
    }
  }

  function ensureArray(type) {
    return Array.isArray(type) ? type : [type];
  }

  function typeDocumentation(type) {
    var result = [];

    if (type.minItems) {
      result.push('minItems: ' + type.minItems);
    }

    if (type.maxItems) {
      result.push('maxItems: ' + type.maxItems);
    }

    if (type['enum']) {
      var enumValues = type['enum'];
      var enumDescription = '';

      if (enumValues.length > 1) {
        enumDescription += 'one of ';
      }

      enumDescription += '(' + enumValues.filter(function (value) { return value !== ''; }).join(', ') + ')';

      result.push(enumDescription);
    }

    if (type.pattern) {
      result.push('pattern: ' + type.pattern);
    }

    if (type.minLength) {
      result.push('minLength: ' + type.minLength);
    }

    if (type.maxLength) {
      result.push('maxLength: ' + type.maxLength);
    }

    if (type.minimum) {
      result.push('minimum: ' + type.minimum);
    }

    if (type.format) {
      result.push('format: ' + type.format);
    }

    if (type.multipleOf) {
      result.push('multipleOf: ' + type.multipleOf);
    }

    if (type.fileTypes) {
      result.push('fileTypes: ' + type.fileTypes.join(', '));
    }

    return result.join(', ');
  }

  RAML.Inspector.Types = {
    mergeType:           mergeType,
    isNativeType:        isNativeType,
    isSchema:            isSchema,
    findType:            findType,
    findSchema:          findSchema,
    getTypeInfo:         getTypeInfo,
    getTypeFromTypeInfo: getTypeFromTypeInfo,
    ensureArray:         ensureArray,
    cleanupTypeName:     cleanupTypeName,
    typeDocumentation:   typeDocumentation
  };
})();

(function() {
  'use strict';

  window.ramlErrors = {};

  CodeMirror.registerHelper('lint', 'yaml', function () {
    var found = [];

    found.push({
      message: window.ramlErrors.message,
      severity: 'error',
      from: CodeMirror.Pos(window.ramlErrors.line),
      to: CodeMirror.Pos(window.ramlErrors.line)
    });

    return found;
  });
})();

(function () {
  'use strict';

  RAML.LoaderUtils = {
    allowedRamlOrigin: function (options) {
      var basepath = '../';
      if (typeof options.ramlOriginCheck === 'string') {
        basepath = options.ramlOriginCheck;
      }
      return basepath;
    },

    // prevent loading stuff from other hosts and/or services
    ramlOriginValidate: function (url, options) {
      var absolutePath = function (href) {
        var link = document.createElement('a');
        link.href = href;
        return link.href;
      };

      var isSameBasePath = function (href, basepath) {
        var absoluteBasepath = absolutePath(basepath);
        var absoluteRamlPath = absolutePath(href);
        return absoluteRamlPath.indexOf(absoluteBasepath, 0) === 0;
      };

      var decodedRamlUrl = decodeURIComponent(url);
      return options && options.ramlOriginCheck && !isSameBasePath(decodedRamlUrl, RAML.LoaderUtils.allowedRamlOrigin(options));
    }
  };
})();

(function() {
  'use strict';

  var FORM_URLENCODED = 'application/x-www-form-urlencoded';
  var FORM_DATA = 'multipart/form-data';

  var BodyContent = function(contentTypes) {
    this.contentTypes = Object.keys(contentTypes).sort();
    this.selected = this.contentTypes[0];

    var definitions = this.definitions = {};
    this.contentTypes.forEach(function(contentType) {
      var definition = contentTypes[contentType] || {};

      if (definition.formParameters) {
        Object.keys(definition.formParameters).map(function (key) {
          definition.formParameters[key][0].id = key;
        });
      }

      switch (contentType) {
      case FORM_URLENCODED:
      case FORM_DATA:
        definitions[contentType] = new RAML.Services.TryIt.NamedParameters(definition.formParameters);
        break;
      default:
        definitions[contentType] = new RAML.Services.TryIt.BodyType(definition);
      }
    });
  };

  BodyContent.prototype.isForm = function(contentType) {
    return contentType === FORM_URLENCODED || contentType === FORM_DATA;
  };

  BodyContent.prototype.isSelected = function(contentType) {
    return contentType === this.selected;
  };

  BodyContent.prototype.fillWithExample = function($event) {
    $event.preventDefault();
    this.definitions[this.selected].fillWithExample();
  };

  BodyContent.prototype.hasExample = function(contentType) {
    return this.definitions[contentType].hasExample();
  };

  BodyContent.prototype.data = function() {
    if (this.selected) {
      return this.definitions[this.selected].data();
    }
  };

  BodyContent.prototype.copyFrom = function(oldContent) {
    var content = this;

    oldContent.contentTypes.forEach(function(contentType) {
      if (content.definitions[contentType]) {
        content.definitions[contentType].copyFrom(oldContent.definitions[contentType]);
      }
    });

    if (this.contentTypes.some(function(contentType) { return contentType === oldContent.selected; })) {
      this.selected = oldContent.selected;
    }
  };

  BodyContent.prototype.clear = function (info) {
    var that = this.definitions[this.selected];
    Object.keys(this.values).map(function (key) {
      if (typeof info[key][0]['enum'] === 'undefined' || info[key][0].overwritten === true) {
        that.values[key] = [''];
      }
    });
  };

  BodyContent.prototype.reset = function (info, field) {
    var that = this.definitions[this.selected];
    if (info) {
      Object.keys(info).map(function (key) {
        if (typeof field === 'undefined' || field === key) {
          if (typeof info[key][0]['enum'] === 'undefined') {
            that.values[key][0] = info[key][0].example;
          }
        }
      });
    }
  };

  RAML.Services.TryIt.BodyContent = BodyContent;
})();

(function() {
  'use strict';

  var BodyType = function(contentType) {
    this.contentType = contentType || {};
    this.value = undefined;
  };

  BodyType.prototype.fillWithExample = function() {
    var example;
    if (this.contentType.examples) {
      example = this.contentType.examples[0].value;
    } else {
      example = this.contentType.example;
    }

    if (typeof example === 'object') {
      this.value = JSON.stringify(example);
    } else {
      this.value = example;
    }

  };

  BodyType.prototype.hasExample = function() {
    return !!this.contentType.example || !!this.contentType.examples;
  };

  BodyType.prototype.data = function() {
    return this.value;
  };

  BodyType.prototype.copyFrom = function(oldBodyType) {
    this.value = oldBodyType.value;
  };

  RAML.Services.TryIt.BodyType = BodyType;
})();

(function() {
  'use strict';

  var Context = function(baseUriParameters, resource, method) {
    this.headers = new RAML.Services.TryIt.NamedParameters(method.headers.plain, method.headers.parameterized);
    this.queryParameters = new RAML.Services.TryIt.NamedParameters(method.queryParameters);

    resource.uriParametersForDocumentation = resource.uriParametersForDocumentation || {};

    if (baseUriParameters) {
      Object.keys(baseUriParameters).map(function (key) {
        resource.uriParametersForDocumentation[key] = [baseUriParameters[key]];
      });
    }

    if (Object.keys(resource.uriParametersForDocumentation).length === 0) {
      resource.uriParametersForDocumentation = null;
    }

    this.uriParameters = new RAML.Services.TryIt.NamedParameters(resource.uriParametersForDocumentation);

    if (method.body) {
      this.bodyContent = new RAML.Services.TryIt.BodyContent(method.body);
    }

    this.pathBuilder = new RAML.Client.PathBuilder.create(resource.pathSegments);
    this.pathBuilder.baseUriContext = {};
    this.pathBuilder.segmentContexts = resource.pathSegments.map(function() {
      return {};
    });
  };

  Context.prototype.merge = function(oldContext) {
    this.headers.copyFrom(oldContext.headers);
    this.queryParameters.copyFrom(oldContext.queryParameters);
    this.uriParameters.copyFrom(oldContext.uriParameters);
    if (this.bodyContent && oldContext.bodyContent) {
      this.bodyContent.copyFrom(oldContext.bodyContent);
    }

    this.pathBuilder.baseUriContext = oldContext.pathBuilder.baseUriContext;
    this.pathBuilder.segmentContexts = oldContext.pathBuilder.segmentContexts;
  };

  RAML.Services.TryIt.Context = Context;
})();

(function() {
  'use strict';

  var NamedParameter = function(definitions) {
    this.definitions = definitions;
    this.selected = definitions[0].type;
  };

  NamedParameter.prototype.hasMultipleTypes = function() {
    return this.definitions.length > 1;
  };

  NamedParameter.prototype.isSelected = function(definition) {
    return this.selected === definition.type;
  };

  RAML.Services.TryIt.NamedParameter = NamedParameter;
})();

(function() {
  'use strict';

  function copy(object) {
    var shallow = {};
    Object.keys(object || {}).forEach(function(key) {
      shallow[key] = new RAML.Services.TryIt.NamedParameter(object[key]);
    });

    return shallow;
  }

  function filterEmpty(object) {
    var copy = {};

    Object.keys(object).forEach(function(key) {
      var values = object[key].filter(function(value) {
        return value !== undefined && value !== null && (typeof value !== 'string' || value.trim().length > 0);
      });

      if (values.length > 0) {
        copy[key] = values;
      }
    });

    return copy;
  }

  var NamedParameters = function(plain, parameterized) {
    this.plain = copy(plain);
    this.parameterized = parameterized;
    Object.keys(this.plain).forEach(function (key) {
      var data = this.plain[key].definitions[0];

      if (typeof data['enum'] !== 'undefined') {
        if (!data.required) {
          var temp = [''];
          data['enum'] = temp.concat(data['enum']);
        }
      }

      if (key.charAt(0) === '$') {
        var tempKey = '&#36;' + key.substring(1);
        this.plain[tempKey] = this.plain[key];
      }
    }.bind(this));

    Object.keys(parameterized || {}).forEach(function(key) {
      parameterized[key].created = [];
    });

    this.values = {};
    Object.keys(this.plain).forEach(function(key) {
      this.values[key] = [undefined];
    }.bind(this));
  };

  NamedParameters.prototype.clear = function (info) {
    var that = this;
    Object.keys(this.values).map(function (key) {
      if (typeof info[key][0]['enum'] === 'undefined' || info[key][0].overwritten === true) {
        that.values[key] = [''];
      }
    });
  };

  NamedParameters.prototype.reset = function (info, field) {
    var that = this;
    if (info) {
      Object.keys(info).map(function (key) {
        if (typeof field === 'undefined' || field === key) {
          if (typeof info[key][0]['enum'] === 'undefined') {
            if (info[key][0].type === 'date' && typeof info[key][0].example === 'object') {
              info[key][0].example = info[key][0].example.toUTCString();
            }

            if (info[key][0].example) {
              that.values[key][0] = info[key][0].example;
            } else if (info[key][0].examples && info[key][0].examples[0] && info[key][0].examples[0].value) {
              that.values[key][0] = info[key][0].examples[0].value;
            }
          }
        }
      });
    }
  };

  NamedParameters.prototype.create = function(name, value) {
    var parameters = this.parameterized[name];

    var definition = parameters.map(function(parameterizedHeader) {
      return parameterizedHeader.create(value);
    });

    var parameterizedName = definition[0].displayName;

    parameters.created.push(parameterizedName);
    this.plain[parameterizedName] = new RAML.Services.TryIt.NamedParameter(definition);
    this.values[parameterizedName] = [undefined];
  };

  NamedParameters.prototype.remove = function(name) {
    delete this.plain[name];
    delete this.values[name];
    return;
  };

  NamedParameters.prototype.data = function() {
    return filterEmpty(this.values);
  };

  NamedParameters.prototype.copyFrom = function(oldParameters) {
    var parameters = this;

    Object.keys(oldParameters.parameterized || {}).forEach(function(key) {
      if (parameters.parameterized[key]) {
        oldParameters.parameterized[key].created.forEach(function(createdParam) {
          parameters.plain[createdParam] = oldParameters.plain[createdParam];
        });
      }
    });

    var keys = Object.keys(oldParameters.plain || {}).filter(function(key) {
      return parameters.plain[key];
    });

    keys.forEach(function(key) {
      parameters.values[key] = oldParameters.values[key];
    });
  };

  RAML.Services.TryIt.NamedParameters = NamedParameters;
})();

(function() {
  'use strict';

  function Clone() {}

  RAML.Utils = {
    clone: function(object) {
      Clone.prototype = object;
      return new Clone();
    },

    copy: function(object) {
      var copiedObject = {};
      for (var key in object) {
        copiedObject[key] = object[key];
      }
      return copiedObject;
    },

    isEmpty: function(object) {
      if (object) {
        return Object.keys(object).length === 0;
      } else {
        return true;
      }
    },

    filterEmpty: function (object) {
      var copy = {};

      Object.keys(object).forEach(function(key) {
        var value = object[key];
        var flag = value !== undefined && value !== null && (typeof value !== 'string' || value.trim().length > 0);

        if (flag) {
          copy[key] = value;
        }
      });

      return copy;
    }
  };
})();

(function (root) {
  var _hasOwnProperty = Object.prototype.hasOwnProperty;
  var btoa            = typeof Buffer === 'function' ? bufferBtoa : root.btoa;

  /**
   * Format error response types to regular strings for displaying to clients.
   *
   * Reference: http://tools.ietf.org/html/rfc6749#section-4.1.2.1
   *
   * @type {Object}
   */
  var ERROR_RESPONSES = {
    'invalid_request': [
      'The request is missing a required parameter, includes an',
      'invalid parameter value, includes a parameter more than',
      'once, or is otherwise malformed.'
    ].join(' '),
    'invalid_client': [
      'Client authentication failed (e.g., unknown client, no',
      'client authentication included, or unsupported',
      'authentication method).'
    ].join(' '),
    'invalid_grant': [
      'The provided authorization grant (e.g., authorization',
      'code, resource owner credentials) or refresh token is',
      'invalid, expired, revoked, does not match the redirection',
      'URI used in the authorization request, or was issued to',
      'another client.'
    ].join(' '),
    'unauthorized_client': [
      'The client is not authorized to request an authorization',
      'code using this method.'
    ].join(' '),
    'unsupported_grant_type': [
      'The authorization grant type is not supported by the',
      'authorization server.'
    ].join(' '),
    'access_denied': [
      'The resource owner or authorization server denied the request.'
    ].join(' '),
    'unsupported_response_type': [
      'The authorization server does not support obtaining',
      'an authorization code using this method.'
    ].join(' '),
    'invalid_scope': [
      'The requested scope is invalid, unknown, or malformed.'
    ].join(' '),
    'server_error': [
      'The authorization server encountered an unexpected',
      'condition that prevented it from fulfilling the request.',
      '(This error code is needed because a 500 Internal Server',
      'Error HTTP status code cannot be returned to the client',
      'via an HTTP redirect.)'
    ].join(' '),
    'temporarily_unavailable': [
      'The authorization server is currently unable to handle',
      'the request due to a temporary overloading or maintenance',
      'of the server.'
    ].join(' ')
  };

  /**
   * Iterate over a source object and copy properties to the destination object.
   *
   * @param  {Object} dest
   * @param  {Object} source
   * @return {Object}
   */
  function assign (dest /*, ...source */) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i];

      for (var key in source) {
        if (_hasOwnProperty.call(source, key)) {
          dest[key] = source[key];
        }
      }
    }

    return dest;
  }

  /**
   * Support base64 in node like how it works in the browser.
   *
   * @param  {String} string
   * @return {String}
   */
  function bufferBtoa (string) {
    return new Buffer(string).toString('base64');
  }

  /**
   * Check if properties exist on an object and throw when they aren't.
   *
   * @throws {TypeError} If an expected property is missing.
   *
   * @param {Object} obj
   * @param {Array}  props
   */
  function expects (obj, props) {
    for (var i = 0; i < props.length; i++) {
      var prop = props[i];
    }
  }

  /**
   * Create a new object based on a source object with keys omitted.
   *
   * @param  {Object} source
   * @param  {Array}  keys
   * @return {Object}
   */
  function omit (source, keys) {
    var obj = {};

    // Iterate over the source object and set properties on a new object.
    Object.keys(source || {}).forEach(function (key) {
      if (keys.indexOf(key) === -1) {
        obj[key] = source[key];
      }
    });

    return obj;
  }

  /**
   * Attempt (and fix) URI component encoding.
   *
   * @param  {String} str
   * @return {String}
   */
  function encodeComponent (str) {
    return encodeURIComponent(str)
      .replace(/[!'()]/g, root.escape)
      .replace(/\*/g, '%2A');
  }

  /**
   * Attempt URI component decoding.
   *
   * @param  {String} str
   * @return {String}
   */
  function decodeComponent (str) {
    return decodeURIComponent(str);
  }

  /**
   * Convert an object into a query string.
   *
   * @param  {Object} obj
   * @param  {String} sep
   * @param  {String} eq
   * @return {String}
   */
  function uriEncode (obj, sep, eq) {
    var params = [];

    eq  = eq  || '=';
    sep = sep || '&';

    Object.keys(obj).forEach(function (key) {
      var value  = obj[key];
      var keyStr = encodeComponent(key) + eq;

      if (Array.isArray(value)) {
        for (var i = 0; i < value.length; i++) {
          params.push(keyStr + encodeComponent(value[i]));
        }
      } else if (value != null) {
        params.push(keyStr + encodeComponent(value));
      }
    });

    return params.join(sep);
  }

  /**
   * Convert a query string into an object.
   *
   * @param  {String} qs
   * @param  {String} sep
   * @param  {String} eq
   * @return {Object}
   */
  function uriDecode (qs, sep, eq) {
    eq  = eq  || '=';
    sep = sep || '&';
    qs  = qs.split(sep);

    var obj     = {};
    var maxKeys = 1000;
    var len     = qs.length > maxKeys ? maxKeys : qs.length;

    for (var i = 0; i < len; i++) {
      var key   = qs[i].replace(/\+/g, '%20');
      var value = '';
      var index = key.indexOf(eq);

      if (index !== -1) {
        value = key.substr(index + 1);
        key   = key.substr(0, index);
      }

      key   = decodeComponent(key);
      value = decodeComponent(value);

      if (!_hasOwnProperty.call(obj, key)) {
        obj[key] = value;
      } else if (Array.isArray(obj[key])) {
        obj[key].push(value);
      } else {
        obj[key] = [obj[key], value];
      }
    }

    return obj;
  }

  /**
   * Pull an authentication error from the response data.
   *
   * @param  {Object} data
   * @return {String}
   */
  function getAuthError (data) {
    var message = ERROR_RESPONSES[data.error] ||
      data.error ||
      data.error_message;

    // Return an error instance with the message if it exists.
    return message && new Error(message);
  }

  /**
   * Retrieve all the HTTP response headers for an XMLHttpRequest instance.
   *
   * @param  {XMLHttpRequest} xhr
   * @return {Object}
   */
  function getAllReponseHeaders (xhr) {
    var headers = {};

    // Split all header lines and iterate.
    xhr.getAllResponseHeaders().split('\n').forEach(function (header) {
      var index = header.indexOf(':');

      if (index === -1) {
        return;
      }

      var name  = header.substr(0, index).toLowerCase();
      var value = header.substr(index + 1).trim();

      headers[name] = value;
    });

    return headers;
  }

  /**
   * Retrieve body request with valid format depending content type
   *
   * @param {Mixed} data
   * @param {String} contentType
   * @return {Mixed}
   */
  function getBodyRequest(data, contentType) {
    if (contentType === 'application/x-www-form-urlencoded' && typeof data === 'object') {
      return uriEncode(data);
    }
    return data;
  }

  /**
   * Sanitize the scopes option to be a string.
   *
   * @param  {Array}  scopes
   * @return {String}
   */
  function sanitizeScope (scopes) {
    if (!Array.isArray(scopes)) {
      return scopes == null ? null : String(scopes);
    }

    return scopes.join(' ');
  }

  /**
   * Construct an object that can handle the multiple OAuth 2.0 flows.
   *
   * @param {Object} options
   */
  function ClientOAuth2 (options) {
    this.options = options;

    this.code        = this['authorization_code'] = new CodeFlow(this);
    this.token       = this.implicit              = new TokenFlow(this);
    this.owner       = this.password              = new OwnerFlow(this);
    this.credentials = this['client_credentials'] = new CredentialsFlow(this);
  }

  /**
   * Alias the token constructor.
   *
   * @type {Function}
   */
  ClientOAuth2.Token = ClientOAuth2Token;

  /**
   * Create a new token from existing data.
   *
   * @param  {String} access
   * @param  {String} [refresh]
   * @param  {String} [type]
   * @param  {Object} [data]
   * @return {Object}
   */
  ClientOAuth2.prototype.createToken = function (access, refresh, type, data) {
    return new ClientOAuth2Token(this, assign({}, data, {
      access_token:  access,
      refresh_token: refresh,
      token_type:    type
    }));
  };

  /**
   * Using the built-in request method, we'll automatically attempt to parse
   * the response.
   *
   * @param {Object}   options
   * @param {Function} done
   */
  ClientOAuth2.prototype._request = function (options, done) {
    return this.request(options, function (err, res) {
      if (err) {
        return done(err);
      }

      // Check the response status and fail.
      if (res.status && Math.floor(res.status / 100) !== 2) {
        err = new Error('HTTP Status ' + res.status);
        err.status = res.status;

        return done(err);
      }

      // Support already parsed responses in case of custom body parsing.
      if (typeof res.body !== 'string') {
        return done(null, res.body);
      }

      // Attempt to parse as JSON, falling back to parsing as a query string.
      try {
        done(null, JSON.parse(res.body), res.raw);
      } catch (e) {
        done(null, uriDecode(res.body), res.raw);
      }
    });
  };

  if (typeof window !== 'undefined') {
    /**
     * Make a HTTP request using XMLHttpRequest.
     *
     * @param {Object}   options
     * @param {Function} done
     */
    ClientOAuth2.prototype.request = function (options, done) {
      var xhr     = new root.XMLHttpRequest();
      var headers = options.headers || {};
      var body = getBodyRequest(options.data, options.contentType);

      // Open the request to the url and method.
      xhr.open(options.method, options.url);

      // When the request has loaded, attempt to automatically parse the body.
      xhr.onload = function () {
        return done(null, {
          raw:     xhr,
          status:  xhr.status,
          headers: getAllReponseHeaders(xhr),
          body:    xhr.responseText
        });
      };

      // Catch request errors.
      xhr.onerror = xhr.onabort = function () {
        return done(new Error(xhr.statusText || 'XHR aborted'));
      };

      // Set all request headers.
      Object.keys(headers).forEach(function (header) {
        xhr.setRequestHeader(header, headers[header]);
      });

      // Make the request with the body.
      xhr.send(body);
    };
  } else {
    var url   = require('url');
    var http  = require('http');
    var https = require('https');

    /**
     * Make a request using the built-in node http library.
     *
     * @param {Object}   options
     * @param {Function} done
     */
    ClientOAuth2.prototype.request = function (options, done) {
      var lib        = http;
      var reqOptions = url.parse(options.url);

      // If the protocol is over https, switch request library.
      if (reqOptions.protocol === 'https:') {
        lib = https;
      }

      // Alias request options.
      reqOptions.method  = options.method;
      reqOptions.headers = options.headers;

      // Send the http request and listen for the response to finish.
      var req = lib.request(reqOptions, function (res) {
        var data = '';

        // Callback to `done` if a response error occurs.
        res.on('error', done);

        // Concat all the data chunks into a string.
        res.on('data', function (chunk) {
          data += chunk;
        });

        // When the response is finished, attempt to parse the data string.
        res.on('end', function () {
          return done(null, {
            raw:     res,
            status:  res.statusCode,
            headers: res.headers,
            body:    data
          });
        });
      });

      // Callback to `done` if a request error occurs.
      req.on('error', done);

      // Send the body and make the request.
      req.write(options.body);
      req.end();
    };
  }

  /**
   * General purpose client token generator.
   *
   * @param {Object} client
   * @param {Object} data
   */
  function ClientOAuth2Token (client, data) {
    this.client = client;

    this.data = omit(data, [
      'access_token', 'refresh_token', 'token_type', 'expires_in', 'scope',
      'state', 'error', 'error_description', 'error_uri'
    ]);

    this.tokenType    = (data.token_type || 'bearer').toLowerCase();
    this.accessToken  = data.access_token;
    this.refreshToken = data.refresh_token;

    // Set the expiration date.
    if (data.expires_in) {
      this.expires = new Date();

      this.expires.setSeconds(this.expires.getSeconds() + data.expires_in);
    }
  }

  /**
   * Sign a standardised request object with user authentication information.
   *
   * @param  {Object} options
   * @return {Object}
   */
  ClientOAuth2Token.prototype.sign = function (options) {
    if (!this.accessToken) {
      throw new Error('Unable to sign without access token');
    }

    options.headers = options.headers || {};

    if (this.tokenType === 'bearer') {
      options.headers.Authorization = 'Bearer ' + this.accessToken;
    } else {
      var parts    = options.url.split('#');
      var token    = 'access_token=' + this.accessToken;
      var url      = parts[0].replace(/[?&]access_token=[^&#]/, '');
      var fragment = parts[1] ? '#' + parts[1] : '';

      // Prepend the correct query string parameter to the url.
      options.url = url + (url.indexOf('?') > -1 ? '&' : '?') + token + fragment;

      // Attempt to avoid storing the url in proxies, since the access token
      // is exposed in the query parameters.
      options.headers.Pragma           = 'no-store';
      options.headers['Cache-Control'] = 'no-store';
    }

    return options;
  };

  /**
   * Make a HTTP request as the user.
   *
   * @param {Object}   options
   * @param {Function} done
   */
  ClientOAuth2Token.prototype.request = function (options, done) {
    return this.client.client.request(this.sign(options), done);
  };

  /**
   * Refresh a user access token with the supplied token.
   *
   * @param {Function} done
   */
  ClientOAuth2Token.prototype.refresh = function (done) {
    var self    = this;
    var options = this.client.options;

    if (!this.refreshToken) {
      return done(new Error('No refresh token set'));
    }

    var authorization = btoa(options.clientId + ':' + options.clientSecret);

    return this.client._request({
      url: options.accessTokenUri,
      method: 'POST',
      headers: {
        'Accept':        'application/json, application/x-www-form-urlencoded',
        'Content-Type':  'application/x-www-form-urlencoded',
        'Authorization': 'Basic ' + authorization
      },
      data: uriEncode({
        refresh_token: this.refreshToken,
        grant_type:    'refresh_token'
      })
    }, function (err, data) {
      // If an error exists or the data contains an error, return `done`.
      if (err || (err = getAuthError(data))) {
        return done(err);
      }

      // Update stored tokens on the current instance.
      self.accessToken  = data.access_token;
      self.refreshToken = data.refresh_token;

      return done(null, self);
    });
  };

  /**
   * Check whether the token has expired.
   *
   * @return {Boolean}
   */
  ClientOAuth2Token.prototype.expired = function () {
    if (this.expires) {
      return Date.now() < this.expires.getTime();
    }

    return false;
  };

  /**
   * Support resource owner password credentials OAuth 2.0 grant.
   *
   * Reference: http://tools.ietf.org/html/rfc6749#section-4.3
   *
   * @param {ClientOAuth2} client
   */
  function OwnerFlow (client) {
    this.client = client;
  }

  /**
   * Make a request on behalf of the user credentials to get an acces token.
   *
   * @param {String}   username
   * @param {String}   password
   * @param {Function} done
   */
  OwnerFlow.prototype.getToken = function (username, password, done) {
    var self          = this;
    var options       = this.client.options;
    var authorization = btoa(options.clientId + ':' + options.clientSecret);

    return this.client._request({
      url: options.accessTokenUri,
      method: 'POST',
      headers: {
        'Accept':        'application/json, application/x-www-form-urlencoded',
        'Content-Type':  'application/x-www-form-urlencoded',
        'Authorization': 'Basic ' + authorization
      },
      data: uriEncode({
        scope:      sanitizeScope(options.scopes),
        username:   username,
        password:   password,
        grant_type: 'password'
      })
    }, function (err, data) {
      // If an error exists or the data contains an error, return `done`.
      if (err || (err = getAuthError(data))) {
        return done(err);
      }

      return done(null, new ClientOAuth2Token(self, data));
    });
  };

  /**
   * Support implicit OAuth 2.0 grant.
   *
   * Reference: http://tools.ietf.org/html/rfc6749#section-4.2
   *
   * @param {ClientOAuth2} client
   */
  function TokenFlow (client) {
    this.client = client;
  }

  /**
   * Get the uri to redirect the user to for implicit authentication.
   *
   * @param  {Object} options
   * @return {String}
   */
  TokenFlow.prototype.getUri = function (options) {
    options = assign({}, this.client.options, options);

    // Check the parameters have been set.
    expects(options, [
      'clientId',
      'redirectUri',
      'authorizationUri'
    ]);

    return options.authorizationUri + '?' + uriEncode({
      state:         options.state,
      scope:         sanitizeScope(options.scopes),
      client_id:     options.clientId,
      redirect_uri:  options.redirectUri,
      response_type: 'token'
    });
  };

  /**
   * Get the user access token from the url.
   *
   * @param {String}   url
   * @param {String}   [state]
   * @param {Function} done
   */
  TokenFlow.prototype.getToken = function (url, state, done) {
    var options = this.client.options;
    var err;

    // State is an optional pass in.
    if (typeof state === 'function') {
      done  = state;
      state = null;
    }

    // Make sure the url matches our expected redirect url.
    if (url.substr(0, options.redirectUri.length) !== options.redirectUri) {
      return done(new Error('Invalid url (should to match redirect): ' + url));
    }

    var queryString    = url.replace(/^[^\?]*|\#.*$/g, '').substr(1);
    var fragmentString = url.replace(/^[^\#]*/, '').substr(1);

    // Check whether a query string is present in the url.
    if (!queryString && !fragmentString) {
      return done(new Error('Unable to process url: ' + url));
    }

    // Merge the fragment with the the query string. This is because, at least,
    // Instagram has a bug where the OAuth 2.0 state is being passed back as
    // part of the query string instead of the fragment. For example:
    // "?state=123#access_token=abc"
    var data = assign(
      queryString ? uriDecode(queryString) : {},
      fragmentString ? uriDecode(fragmentString) : {}
    );

    // Check if the query string was populated with a known error.
    if (err = getAuthError(data)) {
      return done(err);
    }

    // Check whether the state is correct.
    if (state && data.state !== state) {
      return done(new Error('Invalid state:' + data.state));
    }

    // Initalize a new token and return.
    return done(null, new ClientOAuth2Token(this, data));
  };

  /**
   * Support client credentials OAuth 2.0 grant.
   *
   * Reference: http://tools.ietf.org/html/rfc6749#section-4.4
   *
   * @param {ClientOAuth2} client
   */
  function CredentialsFlow (client) {
    this.client = client;
  }

  /**
   * Request an access token using the client credentials.
   *
   * @param {Object}   [options]
   * @param {Function} done
   */
  CredentialsFlow.prototype.getToken = function (options, done) {
    var self = this;

    // Allow the options argument to be omitted.
    if (typeof options === 'function') {
      done = options;
      options = null;
    }

    options = assign({}, this.client.options, options);

    expects(options, [
      'clientId',
      'clientSecret',
      'accessTokenUri'
    ]);

    // Base64 encode the client id and secret for the Authorization header.
    var authorization = btoa(options.clientId + ':' + options.clientSecret);

    return this.client._request({
      url: options.accessTokenUri,
      method: 'POST',
      headers: {
        'Accept':        'application/json, application/x-www-form-urlencoded',
        'Content-Type':  'application/x-www-form-urlencoded',
        'Authorization': 'Basic ' + authorization
      },
      data: uriEncode({
        scope:      sanitizeScope(options.scopes),
        grant_type: 'client_credentials'
      })
    }, function (err, data) {
      // If an error exists or the data contains an error, return `done`.
      if (err || (err = getAuthError(data))) {
        return done(err);
      }

      return done(null, new ClientOAuth2Token(self, data));
    });
  };

  /**
   * Support authorization code OAuth 2.0 grant.
   *
   * Reference: http://tools.ietf.org/html/rfc6749#section-4.1
   *
   * @param {ClientOAuth2} client
   */
  function CodeFlow (client) {
    this.client = client;
  }

  /**
   * Generate the uri for doing the first redirect.
   *
   * @return {String}
   */
  CodeFlow.prototype.getUri = function (options) {
    options = assign({}, this.client.options, options);

    // Check the parameters have been set.
    expects(options, [
      'clientId',
      'redirectUri',
      'authorizationUri'
    ]);

    return options.authorizationUri + '?' + uriEncode({
      state:         options.state,
      scope:         sanitizeScope(options.scopes),
      client_id:     options.clientId,
      redirect_uri:  options.redirectUri,
      response_type: 'code'
    });
  };

  /**
   * Get the code token from the redirected uri and make another request for
   * the user access token.
   *
   * @param {String}   url
   * @param {String}   [state]
   * @param {Function} done
   */
  CodeFlow.prototype.getToken = function (url, state, done) {
    var self    = this;
    var options = this.client.options;
    var err;

    // State is an optional pass in.
    if (typeof state === 'function') {
      done  = state;
      state = null;
    }

    expects(options, [
      'clientId',
      'clientSecret',
      'redirectUri',
      'accessTokenUri'
    ]);

    // Make sure the url matches our expected redirect url.
    if (url.substr(0, options.redirectUri.length) !== options.redirectUri) {
      return done(new Error('Invalid url (should to match redirect): ' + url));
    }

    // Extract the query string from the url.
    var queryString = url.replace(/^[^\?]*|\#.*$/g, '').substr(1);

    // Check whether a query string is present in the url.
    if (!queryString) {
      return done(new Error('Unable to process url: ' + url));
    }

    var query = uriDecode(queryString);

    // Check if the query string was populated with a known error.
    if (err = getAuthError(query)) {
      return done(err);
    }

    // Check whether the state is correct.
    if (state && query.state !== state) {
      return done(new Error('Invalid state:' + query.state));
    }

    // Check whether the response code is set.
    if (!query.code) {
      return done(new Error('Missing code, unable to request token'));
    }

    return this.client._request({
      url: options.accessTokenUri,
      method: 'POST',
      headers: {
        'Accept':       'application/json, application/x-www-form-urlencoded',
        'Content-Type': 'application/x-www-form-urlencoded'
      },
      data: uriEncode({
        code:          query.code,
        grant_type:    'authorization_code',
        redirect_uri:  options.redirectUri,
        client_id:     options.clientId,
        client_secret: options.clientSecret
      })
    }, function (err, data, raw) {
      // If an error exists or the data contains an error, return `done`.
      if (err || (err = getAuthError(data))) {
        return done(err, null, raw);
      }

      return done(null, new ClientOAuth2Token(self, data), raw);
    });
  };

  /**
   * Export the OAuth2 client for multiple environments.
   */
  if (typeof define === 'function' && define.amd) {
    define([], function () {
      return ClientOAuth2;
    });
  } else if (typeof exports === 'object') {
    module.exports = ClientOAuth2;
  } else {
    root.ClientOAuth2 = ClientOAuth2;
  }
})(this);

(function (root) {
  /**
   * Check if a value is empty.
   *
   * @param  {*}       value
   * @return {Boolean}
   */
  var isEmpty = function (value) {
    return value == null;
  };

  /**
   * Convert a value into a boolean.
   *
   * @param  {String}  value
   * @return {Boolean}
   */
  var toBoolean = function (value) {
    if ([0, false, '0', 'false'].indexOf(value) !== -1) return false;
    if ([1, true, '1', 'true'].indexOf(value) !== -1) return true;
    return null;
  };

  /**
   * Convert a value into a number. Non-number strings and infinite values will
   * sanitize into `NaN`.
   *
   * @param  {String} value
   * @return {Number}
   */
  var toNumber = function (value) {
    return isFinite(value) ? Number(value) : null;
  };

  /**
   * Convert a value into an integer. Use strict sanitization - if something is
   * not an integer, return `NaN`.
   *
   * @param  {String} value
   * @return {Number}
   */
  var toInteger = function (value) {
    return value % 1 === 0 ? Number(value) : null;
  };

  /**
   * Convert a value into a date.
   *
   * @param  {String} value
   * @return {Date}
   */
  var toDate = function (value) {
    return !isNaN(Date.parse(value)) ? new Date(value) : null;
  };

  /**
   * Returns the passed value unchanged.
   */
  var returnValue = function (value) {
    return value;
  };

  var toUnion = function (value, key, object, configs) {
    var any = null;
    configs.forEach(function (config) {
      config.unionTypes.forEach(function (type) {
        any = any || TYPES[type](value, key, object, configs);
      });
    });

    return any;
  };

  function isNativeType(typeName) {
    typeName = typeName.replace('[]', '');
    var nativeTypes = [
      'object',
      'string',
      'number',
      'integer',
      'boolean',
      'date-only',
      'time-only',
      'datetime-only',
      'datetime',
      'file',
      'array'
    ];
    return nativeTypes.indexOf(typeName) !== -1;
  }

  function convertType(config) {
    var newConfig = {};
    // Clone config object.
    Object.keys(config).forEach(function (key) {
      newConfig[key] = config[key];
    });

    if (Array.isArray(newConfig.type)) {
      newConfig.type = newConfig.type.map(function (aType) {
        var newType = aType.replace('[]', '');
        var parts = aType.split('|');
        if (parts.length > 1) {
          newType = 'union';
          newConfig.unionTypes = parts.map(function (part) {
            part = part.trim();
            return !isNativeType(part) ? 'object' : part;
          });
        } else {
          newType = !isNativeType(newType) ? 'object' : newType;
        }
        return newType;
      });
    }
    return newConfig;
  }

  /**
   * Convert the schema config into a single sanitization function.
   *
   * @param  {Object}   configs
   * @param  {Object}   rules
   * @param  {Object}   types
   * @return {Function}
   */
  var toSanitization = function (configs, rules, types) {
    configs = Array.isArray(configs) ? configs : [configs];

    // Map configurations into function sanitization chains.
    var sanitizations = configs.map(function (config) {
      var fns = [];

      // Push type sanitization first.
      if (typeof types[config.type] === 'function') {
        fns.push(types[config.type]);
      }

      // Iterate over the schema configuration and push sanitization functions
      // into the sanitization array.
      Object.keys(config).filter(function (rule) {
        return rule !== 'type' && rule !== 'repeat' && rule !== 'default';
      }).forEach(function (rule) {
        if (typeof rules[rule] === 'function') {
          fns.push(rules[rule](config[rule], rule, config));
        }
      });

      /**
       * Sanitize a single value using the function chain. Breaks when any value
       * returns an empty value (`null` or `undefined`).
       *
       * @param  {*}      value
       * @param  {String} key
       * @param  {Object} object
       * @return {*}
       */
      var sanitize = function (value, key, object) {
        // Iterate over each sanitization function and return a single value.
        fns.every(function (fn) {
          value = fn(value, key, object, configs);

          // Break when the value returns `null`.
          return value != null;
        });

        return value;
      };

      /**
       * Do the entire sanitization flow using the current config.
       *
       * @param  {*}      value
       * @param  {String} key
       * @param  {Object} object
       * @return {*}
       */
      return function sanitization (value, key, object) {
        // Immediately return empty values with attempting to sanitize.
        if (isEmpty(value)) {
          // Fallback to providing the default value instead.
          if (config["default"] != null) {
            return sanitization(config["default"], key, object);
          }

          // Return an empty array for repeatable values.
          return config.repeat && !config.required ? [] : value;
        }

        // Support repeated parameters as arrays.
        if (config.repeat) {
          // Turn the result into an array
          if (!Array.isArray(value)) {
            value = [value];
          }

          // Map every value to be sanitized into a new array.
          value = value.map(function (value) {
            return sanitize(value, key, object);
          });

          // If any of the values are empty, refuse the sanitization.
          return value.some(isEmpty) ? null : value;
        }

        return sanitize(value, key, object);
      };
    });

    /**
     * Pass in a value to be sanitized.
     *
     * @param  {*}      value
     * @param  {String} key
     * @param  {Object} object
     * @return {*}
     */
    return function (value, key, object) {
      var result = value;

      // Iterate over each sanitization until one is not empty.
      sanitizations.some(function (sanitization) {
        var sanitized = sanitization(value, key, object);

        // If the value was accepted and sanitized, return it.
        if (sanitized != null) {
          // Assign the sanitized value to the result.
          result = sanitized;

          return true;
        }

        return false;
      });

      return result;
    };
  };

  var TYPES = {
    string:          String,
    number:          toNumber,
    integer:         toInteger,
    'boolean':       toBoolean,
    date:            toDate,
    'date-only':     toDate,
    'time-only':     toDate,
    'datetime-only': toDate,
    'datetime':      toDate,
    object:          returnValue,
    union:           toUnion
  };

  /**
   * Every time the module is exported and executed, we return a new instance.
   *
   * @return {Function}
   */
  RAMLSanitize = function () {
    /**
     * Return a sanitization function based on the passed in schema.
     *
     * @param  {Object}   schema
     * @return {Function}
     */
    var sanitize = function (schema) {
      var sanitizations = {};

      // Map each parameter in the schema to a validation function.
      Object.keys(schema).forEach(function (param) {
        var config = convertType(schema[param]);
        var types  = sanitize.TYPES;
        var rules  = sanitize.RULES;

        sanitizations[param] = toSanitization(config, rules, types);
      });

      /**
       * Execute the returned function with a model to return a sanitized object.
       *
       * @param  {Object} model
       * @return {Object}
       */
      return function (model) {
        model = model || {};

        // Create a new model instance to be sanitized without any additional
        // properties or overrides occuring.
        var sanitized = {};

        // Iterate only the sanitized parameters to get a clean model.
        Object.keys(sanitizations).forEach(function (param) {
          var value    = model[param];
          var sanitize = sanitizations[param];

          // Ensure the value is a direct property on the model object before
          // sanitizing. The keeps model handling in sync with expectations.
          if (Object.prototype.hasOwnProperty.call(model, param)) {
            sanitized[param] = sanitize(value, param, model);
          }
        });

        return sanitized;
      };
    };

    /**
     * Provide sanitization based on types.
     *
     * @type {Object}
     */
    sanitize.TYPES = TYPES;

    /**
     * Provide sanitization based on rules.
     *
     * @type {Object}
     */
    sanitize.RULES = {};

    return sanitize;
  };

  /**
   * Export the raml-sanitize for multiple environments.
   */
  if (typeof define === 'function' && define.amd) {
    define([], function () {
      return RAMLSanitize;
    });
  } else if (typeof exports === 'object') {
    module.exports = RAMLSanitize;
  } else {
    root.RAMLSanitize = RAMLSanitize;
  }
})(this);

(function (root) {
  /**
   * `Object.prototype.toString` as a function.
   *
   * @type {Function}
   */
  var toString = Function.prototype.call.bind(Object.prototype.toString);

  /**
   * Check the value is a valid date.
   *
   * @param  {Date}    check
   * @return {Boolean}
   */
  var isDate = function (check) {
    return toString(check) === '[object Date]' && !isNaN(check.getTime());
  };

  /**
   * Check if the value is a boolean.
   *
   * @param  {Boolean}  check
   * @return {Boolean}
   */
  var isBoolean = function (check) {
    return typeof check === 'boolean';
  };

  /**
   * Check the value is a string.
   *
   * @param  {String}  check
   * @return {Boolean}
   */
  var isString = function (check) {
    return typeof check === 'string';
  };

  /**
   * Check if the value is an integer.
   *
   * @param  {Number}  check
   * @return {Boolean}
   */
  var isInteger = function (check) {
    return typeof check === 'number' && check % 1 === 0;
  };

  /**
   * Check if the value is a number.
   *
   * @param  {Number}  check
   * @return {Boolean}
   */
  var isNumber = function (check) {
    return typeof check === 'number' && isFinite(check);
  };

  /**
   * Check if the value is a JSON string.
   *
   * @param  {String}  check
   * @return {Boolean}
   */
  var isJSON = function (check) {
    try {
      JSON.parse(check);
      return true;
    } catch(e) {
      return false;
    }
  };

  var isUnion = function (check, key, object, configs) {
    var any = false;
    configs.forEach(function (config) {
      config.unionTypes.forEach(function (type) {
        any = any || TYPES[type](check, key, object, configs);
      });
    });

    return any;
  };

  /**
   * Check a number is not smaller than the minimum.
   *
   * @param  {Number}   min
   * @return {Function}
   */
  var isMinimum = function (min) {
    return function (check) {
      return check >= min;
    };
  };

  /**
   * Check a number doesn't exceed the maximum.
   *
   * @param  {Number}  max
   * @return {Boolean}
   */
  var isMaximum = function (max) {
    return function (check) {
      return check <= max;
    };
  };

  /**
   * Check a string is not smaller than a minimum length.
   *
   * @param  {Number}  min
   * @return {Boolean}
   */
  var isMinimumLength = function (min) {
    return function (check) {
      return check.length >= min;
    };
  };

  /**
   * Check a string does not exceed a maximum length.
   *
   * @param  {Number}  max
   * @return {Boolean}
   */
  var isMaximumLength = function (max) {
    return function (check) {
      return check.length <= max;
    };
  };

  /**
   * Check a value is equal to anything in an array.
   *
   * @param  {Array}    values
   * @return {Function}
   */
  var isEnum = function (values) {
    return function (check) {
      return values.indexOf(check) > -1;
    };
  };

  /**
   * Check if a pattern matches the value.
   *
   * @param  {(String|RegExp)} pattern
   * @return {Function}
   */
  var isPattern = function (pattern) {
    if (toString(pattern) !== '[object RegExp]') {
      pattern = new RegExp(pattern);
    }

    return pattern.test.bind(pattern);
  };

  /**
   * Convert arguments into an object.
   *
   * @param  {Boolean} valid
   * @param  {String}  rule
   * @param  {*}       value
   * @param  {String}  key
   * @return {Object}
   */
  var toValidationObject = function (valid, rule, value, key) {
    return { valid: valid, rule: rule, value: value, key: key };
  };

  /**
   * Convert a single config into a function.
   *
   * @param  {Object}   config
   * @param  {Object}   rules
   * @return {Function}
   */
  var toValidationFunction = function (config, rules) {
    var fns = [];

    // Iterate over all of the keys and dynamically push validation rules.
    Object.keys(config).forEach(function (rule) {
      if (rules.hasOwnProperty(rule)) {
        fns.push([rule, rules[rule](config[rule], rule)]);
      }
    });

    /**
     * Run every validation that has been attached.
     *
     * @param  {String} value
     * @param  {String} value
     * @param  {Object} object
     * @return {Object}
     */
    return function (value, key, object) {
      // Run each of the validations returning early when something fails.
      for (var i = 0; i < fns.length; i++) {
        var valid = fns[i][1](value, key, object);

        if (!valid) {
          return toValidationObject(false, fns[i][0], value, key);
        }
      }

      return toValidationObject(true, null, value, key);
    };
  };

  /**
   * Convert a rules object into a simple validation function.
   *
   * @param  {Object}   configs
   * @param  {Object}   rules
   * @param  {Object}   types
   * @return {Function}
   */
  var toValidation = function (configs, rules, types) {
    // Initialize the configs to an array if they aren't already.
    configs = Array.isArray(configs) ? configs : [configs];

    var isOptional        = !configs.length;
    var simpleValidations = [];
    var repeatValidations = [];

    // Support multiple type validations.
    configs.forEach(function (config) {
      var validation = [config.type, toValidationFunction(config, rules)];

      // Allow short-circuiting of non-required values.
      if (!config.required) {
        isOptional = true;
      }

      // Push validations into each stack depending on the "repeat".
      if (config.repeat) {
        repeatValidations.push(validation);
      } else {
        simpleValidations.push(validation);
      }
    });

    /**
     * Validate a value based on "type" and "repeat".
     *
     * @param  {*}      value
     * @param  {String} key
     * @param  {Object} object
     * @return {Object}
     */
    return function (value, key, object) {

      // Switch validation type depending on if the value is an array or not.
      var isArray = Array.isArray(value);

      // Short-circuit validation if empty value
      if (value == null || (isArray && value.length === 0)) {
        return toValidationObject(isOptional, 'required', value, key);
      }

      // Select the validation stack to use based on the (repeated) value.
      var values      = isArray ? value : [value];
      var validations = isArray ? repeatValidations : simpleValidations;

      // Set the initial response to be an error.
      var response = toValidationObject(
        false, validations.length ? 'type' : 'repeat', value, key
      );

      // Iterate over each value and test using type validation.
      validations.some(function (validation) {
        // Non-existant types should always be invalid.
        if (!types.hasOwnProperty(validation[0])) {
          return false;
        }

        // Check all the types match. If they don't, attempt another validation.
        var isType = values.every(function (value) {
          return types[validation[0]](value, key, object, configs);
        });

        // Skip to the next check if not all types match.
        if (!isType) {
          return false;
        }

        // When every value is the correct type, run the validation on each value
        // and break the loop if we get a failure.
        values.every(function (value) {
          return (response = validation[1](value, key, object)).valid;
        });

        // Always break the loop when the type was successful. If anything has
        // failed, `response` will have been set to the invalid object.
        return true;
      });

      return response;
    };
  };

  function isNativeType(typeName) {
    typeName = typeName.replace('[]', '');
    var nativeTypes = [
      'object',
      'string',
      'number',
      'integer',
      'boolean',
      'date-only',
      'time-only',
      'datetime-only',
      'datetime',
      'file',
      'array'
    ];
    return nativeTypes.indexOf(typeName) !== -1;
  }

  function convertType(config) {
    var newConfig = {};
    // Clone config object.
    Object.keys(config).forEach(function (key) {
      newConfig[key] = config[key];
    });

    if (Array.isArray(newConfig.type)) {
      newConfig.type = newConfig.type.map(function (aType) {
        var newType = aType.replace('[]', '');
        var parts = aType.split('|');
        if (parts.length > 1) {
          newType = 'union';
          newConfig.unionTypes = parts.map(function (part) {
            part = part.trim();
            return !isNativeType(part) ? 'object' : part;
          });
        } else {
          newType = !isNativeType(newType) ? 'object' : newType;
        }
        return newType;
      });
    }
    return newConfig;
  }

  var TYPES = {
    date:            isDate,
    'date-only':     isDate,
    'time-only':     isDate,
    'datetime-only': isDate,
    datetime:        isDate,
    number:          isNumber,
    integer:         isInteger,
    'boolean':       isBoolean,
    string:          isString,
    object:          isJSON,
    union:           isUnion
  };

  /**
   * Every time you require the module you're expected to call it as a function
   * to create a new instance. This is to ensure two modules can't make competing
   * changes with their own validation rules.
   *
   * @return {Function}
   */
  RAMLValidate = function () {
    /**
     * Return a validation function that validates a model based on the schema.
     *
     * @param  {Object}   schema
     * @return {Function}
     */
    var validate = function (schema) {
      var validations = {};

      // Convert all parameters into validation functions.
      Object.keys(schema).forEach(function (param) {
        var config = convertType(schema[param]);
        var rules  = validate.RULES;
        var types  = validate.TYPES;

        validations[param] = toValidation(config, rules, types);
      });

      /**
       * The function accepts an object to be validated. All rules are already
       * precompiled.
       *
       * @param  {Object}  model
       * @return {Boolean}
       */
      return function (model) {
        model = model || {};

        // Map all validations to their object and filter for failures.
        var errors = Object.keys(validations).map(function (param) {
          var value      = model[param];
          var validation = validations[param];

          // Return the validation result.
          return validation(value, param, model);
        }).filter(function (validation) {
          return !validation.valid;
        });

        return {
          valid:  errors.length === 0,
          errors: errors
        };
      };
    };

    /**
     * Provide validation of types.
     *
     * @type {Object}
     */
    validate.TYPES = TYPES;

    /**
     * Provide overridable validation of parameters.
     *
     * @type {Object}
     */
    validate.RULES = {
      minimum:   isMinimum,
      maximum:   isMaximum,
      minLength: isMinimumLength,
      maxLength: isMaximumLength,
      'enum':    isEnum,
      pattern:   isPattern
    };

    /**
     * Return the validate function.
     */
    return validate;
  };

  /**
   * Export the raml-validate for multiple environments.
   */
  if (typeof define === 'function' && define.amd) {
    define([], function () {
      return RAMLValidate;
    });
  } else if (typeof exports === 'object') {
    module.exports = RAMLValidate;
  } else {
    root.RAMLValidate = RAMLValidate;
  }
})(this);

angular.module('ramlConsoleApp').run(['$templateCache', function($templateCache) {
  'use strict';

  $templateCache.put('directives/close-button.tpl.html',
    "<button class=\"raml-console-resource-close-btn\" ng-click=\"close($event)\">\n" +
    "  Close\n" +
    "</button>\n"
  );


  $templateCache.put('directives/documentation.tpl.html',
    "<div class=\"raml-console-resource-panel-primary\" ng-if=\"documentationEnabled\">\n" +
    "  <!-- Request -->\n" +
    "  <header class=\"raml-console-resource-header\">\n" +
    "    <h3 class=\"raml-console-resource-head\">\n" +
    "      Request\n" +
    "    </h3>\n" +
    "  </header>\n" +
    "  <div id=\"request-documentation\" class=\"raml-console-resource-panel-primary-row raml-console-resource-panel-content raml-console-is-active\" ng-class=\"{'raml-console-is-active':showRequestDocumentation}\">\n" +
    "    <h3 class=\"raml-console-resource-heading-a\">Description</h3>\n" +
    "\n" +
    "    <p markdown=\"methodInfo.description\" class=\"raml-console-marked-content\"></p>\n" +
    "\n" +
    "    <section class=\"raml-console-resource-section\" id=\"docs-uri-parameters\" ng-if=\"resource.uriParametersForDocumentation\">\n" +
    "      <h3 class=\"raml-console-resource-heading-a\">URI Parameters</h3>\n" +
    "      <properties list=\"resource.uriParametersForDocumentation\" show-examples=\"true\"></properties>\n" +
    "    </section>\n" +
    "\n" +
    "    <section class=\"raml-console-resource-section\" id=\"docs-headers\" ng-if=\"methodInfo.headers.plain\">\n" +
    "      <h3 class=\"raml-console-resource-heading-a\">Headers</h3>\n" +
    "      <properties list=\"methodInfo.headers.plain\" show-examples=\"true\"></properties>\n" +
    "    </section>\n" +
    "\n" +
    "    <section class=\"raml-console-resource-section\" id=\"docs-query-parameters\" ng-if=\"methodInfo.queryParameters\">\n" +
    "      <h3 class=\"raml-console-resource-heading-a\">Query Parameters</h3>\n" +
    "      <properties list=\"methodInfo.queryParameters\" show-examples=\"true\"></properties>\n" +
    "    </section>\n" +
    "\n" +
    "    <section class=\"raml-console-resource-section\" id=\"docs-query-string\" ng-if=\"methodInfo.queryString\">\n" +
    "      <h3 class=\"raml-console-resource-heading-a\">Query String</h3>\n" +
    "      <type-properties type=\"methodInfo.queryString\"></type-properties>\n" +
    "    </section>\n" +
    "\n" +
    "    <section class=\"raml-console-resource-section raml-console-documentation-schemes\">\n" +
    "      <h3 class=\"raml-console-resource-heading-a\">Security Schemes</h3>\n" +
    "      <ol class=\"raml-console-documentation-security-scheme\">\n" +
    "        <li class=\"raml-console-documentation-scheme\" ng-class=\"{'raml-console-is-active':isSchemeSelected(value)}\" ng-click=\"selectDocumentationScheme(value)\" ng-repeat=\"(key, value) in securitySchemes\">{{value.name}}</li>\n" +
    "      </ol>\n" +
    "\n" +
    "      <p ng-if=\"documentationSchemeSelected.description\" markdown=\"documentationSchemeSelected.description\" class=\"raml-console-marked-content\"></p>\n" +
    "\n" +
    "      <section class=\"raml-console-resource-section raml-console-scheme-headers\" ng-if=\"documentationSchemeSelected.describedBy.headers\">\n" +
    "        <h4 class=\"raml-console-resource-heading-a\">Headers</h4>\n" +
    "        <properties list=\"documentationSchemeSelected.describedBy.headers\" show-security-schema-properties=\"true\" show-examples=\"true\"></properties>\n" +
    "      </section>\n" +
    "\n" +
    "      <section class=\"raml-console-resource-section raml-console-scheme-query-parameters\" ng-if=\"documentationSchemeSelected.describedBy.queryParameters\">\n" +
    "        <h4 class=\"raml-console-resource-heading-a\">Query Parameters</h4>\n" +
    "        <properties list=\"documentationSchemeSelected.describedBy.queryParameters\" show-security-schema-properties=\"true\" show-examples=\"true\"></properties>\n" +
    "      </section>\n" +
    "\n" +
    "      <section class=\"raml-console-resource-section raml-console-scheme-responses\" ng-if=\"documentationSchemeSelected.describedBy.responses\">\n" +
    "        <h4 class=\"raml-console-resource-heading-a\">Responses</h4>\n" +
    "\n" +
    "        <div class=\"raml-console-resource-param\" ng-repeat=\"(code, info) in documentationSchemeSelected.describedBy.responses\">\n" +
    "          <h4 class=\"raml-console-resource-param-heading\">{{info.code}}</h4>\n" +
    "          <p markdown=\"info.description\" class=\"raml-console-marked-content\"></p>\n" +
    "        </div>\n" +
    "      </section>\n" +
    "\n" +
    "      <section class=\"raml-console-resource-section raml-console-scheme-settings\" ng-if=\"documentationSchemeSelected.settings\">\n" +
    "        <h4 class=\"raml-console-resource-heading-a\">Settings</h4>\n" +
    "\n" +
    "        <div class=\"raml-console-resource-param\" ng-repeat=\"(key, config) in documentationSchemeSelected.settings\">\n" +
    "          <h4 class=\"raml-console-resource-param-heading\">{{key}}</h4>\n" +
    "          <p>{{schemaSettingsDocumentation(config)}}</p>\n" +
    "        </div>\n" +
    "      </section>\n" +
    "    </section>\n" +
    "\n" +
    "\n" +
    "    <section class=\"raml-console-resource-section\" ng-if=\"methodInfo.body\">\n" +
    "      <h3 class=\"raml-console-resource-heading-a\">\n" +
    "        Body\n" +
    "      </h3>\n" +
    "\n" +
    "      <h4 class=\"raml-console-request-body-heading\">\n" +
    "        <span ng-click=\"changeResourceBodyType($event, key)\" ng-class=\"{ 'raml-console-is-active' : bodySelected(key)}\" class=\"raml-console-flag raml-console-body-{{getBodyId(key)}}\" ng-repeat=\"(key, value) in methodInfo.body\">{{key}}</span>\n" +
    "      </h4>\n" +
    "\n" +
    "      <div ng-repeat=\"(key, value) in methodInfo.body\">\n" +
    "        <div ng-if=\"key === currentBodySelected\">\n" +
    "          <section ng-if=\"value.formParameters\">\n" +
    "             <div class=\"raml-console-resource-param\" ng-repeat=\"formParam in value.formParameters\">\n" +
    "              <h4 class=\"raml-console-resource-param-heading\">{{formParam[0].displayName}}<span class=\"raml-console-resource-param-instructional\">{{parameterDocumentation(formParam[0])}}</span></h4>\n" +
    "\n" +
    "              <p markdown=\"formParam[0].description\" class=\"raml-console-marked-content\"></p>\n" +
    "\n" +
    "              <p ng-if=\"formParam[0].example !== undefined\">\n" +
    "                <span class=\"raml-console-resource-param-example\"><b>Example:</b> {{formParam[0].example}}</span>\n" +
    "              </p>\n" +
    "            </div>\n" +
    "          </section>\n" +
    "\n" +
    "          <examples\n" +
    "            ng-if=\"value\"\n" +
    "            example-container=\"value\"\n" +
    "            get-beatified-example-ref=\"getBeatifiedExample\">\n" +
    "          </examples>\n" +
    "\n" +
    "          <raml-body\n" +
    "            ng-if=\"value\"\n" +
    "            body=\"value\"\n" +
    "            get-beatified-example-ref=\"getBeatifiedExample\">\n" +
    "          </raml-body>\n" +
    "        </div>\n" +
    "      </div>\n" +
    "    </section>\n" +
    "  </div>\n" +
    "\n" +
    "  <!-- Response -->\n" +
    "  <div ng-if=\"fullResponseCodes\">\n" +
    "    <header class=\"raml-console-resource-header\">\n" +
    "      <h3 class=\"raml-console-resource-head\">\n" +
    "        Response\n" +
    "      </h3>\n" +
    "    </header>\n" +
    "\n" +
    "    <div class=\"raml-console-resource-response-jump\">\n" +
    "      <ul class=\"raml-console-resource-menu\">\n" +
    "        <li class=\"raml-console-resource-btns raml-console-resource-menu-item\" ng-repeat=\"code in fullResponseCodes\">\n" +
    "          <button ng-click=\"showCodeDetails(code)\" class=\"raml-console-resource-btn raml-console-resource-menu-button raml-console-resource-menu-btn-{{getColorCode(code)}}\" ng-class=\"{ 'raml-console-button-is-active': isActiveCode(code) }\" href=\"#code{{code}}\">{{code}}</button>\n" +
    "        </li>\n" +
    "      </ul>\n" +
    "    </div>\n" +
    "\n" +
    "    <div class=\"raml-console-resource-panel-primary-row raml-console-resource-panel-content raml-console-is-active raml-console-response-container\" ng-class=\"{'raml-console-is-active':showResponseDocumentation}\">\n" +
    "      <section ng-if=\"isActiveCode(code)\" class=\"raml-console-resource-section raml-console-resource-response-section\" ng-repeat=\"code in fullResponseCodes\">\n" +
    "        <a name=\"code{{code}}\"></a>\n" +
    "        <h3 class=\"raml-console-resource-heading-a\">Status {{code}}</h3>\n" +
    "\n" +
    "        <div class=\"raml-console-resource-response\">\n" +
    "          <p markdown=\"fullResponses[code].description\" class=\"raml-console-marked-content\"></p>\n" +
    "        </div>\n" +
    "\n" +
    "        <div class=\"raml-console-resource-response\" ng-if=\"fullResponses[code].headers\">\n" +
    "          <h4 class=\"raml-console-resource-body-heading\">Headers</h4>\n" +
    "          <properties list=\"fullResponses[code].headers\"></properties>\n" +
    "        </div>\n" +
    "\n" +
    "        <div class=\"raml-console-resource-response\" ng-if=\"fullResponses[code].body\">\n" +
    "          <h4 class=\"raml-console-resource-body-heading\">\n" +
    "            Body\n" +
    "            <span\n" +
    "              ng-click=\"changeType($event, key, code)\"\n" +
    "              ng-class=\"{ 'raml-console-is-active': responseInfo[code].currentType === key}\"\n" +
    "              class=\"raml-console-flag\"\n" +
    "              ng-repeat=\"(key, value) in fullResponses[code].body\">\n" +
    "                {{key}}\n" +
    "            </span>\n" +
    "          </h4>\n" +
    "\n" +
    "          <div ng-repeat=\"(key, value) in fullResponses[code].body\">\n" +
    "            <div ng-if=\"responseInfo[code].currentType === key\">\n" +
    "              <examples\n" +
    "                ng-if=\"responseInfo[code] && responseInfo[code].currentType\"\n" +
    "                example-container=\"value\"\n" +
    "                get-beatified-example-ref=\"getBeatifiedExample\">\n" +
    "              </examples>\n" +
    "\n" +
    "              <raml-body\n" +
    "                ng-if=\"responseInfo[code] && responseInfo[code].currentType\"\n" +
    "                body=\"value\"\n" +
    "                get-beatified-example-ref=\"getBeatifiedExample\">\n" +
    "              </raml-body>\n" +
    "            </div>\n" +
    "          </div>\n" +
    "        </div>\n" +
    "      </section>\n" +
    "\n" +
    "    </div>\n" +
    "  </div>\n" +
    "</div>\n"
  );


  $templateCache.put('directives/examples.tpl.html',
    "<div class=\"raml-console-examples-container\" ng-if=\"examples && examples.length\">\n" +
    "  <span>Examples:</span>\n" +
    "  <span\n" +
    "    class=\"raml-console-flag\"\n" +
    "    ng-class=\"{ 'raml-console-is-active': currentExample === $index }\"\n" +
    "    ng-repeat=\"example in examples\"\n" +
    "    ng-click=\"changeExample($index)\">{{example.name}}</span>\n" +
    "\n" +
    "  <div\n" +
    "      class=\"raml-console-resource-param-instructional\"\n" +
    "      ng-if=\"isXML\">\n" +
    "    Examples are shown as JSON string for demonstrative purposes only. Actual API output will be in a different format.\n" +
    "  </div>\n" +
    "  <pre class=\"raml-console-resource-pre\">\n" +
    "    <code class=\"raml-console-hljs\" hljs source=\"getBeatifiedExample(examples[currentExample].content)\"></code>\n" +
    "  </pre>\n" +
    "</div>\n"
  );


  $templateCache.put('directives/method-list.tpl.html',
    "<div class=\"raml-console-tab-list\">\n" +
    "  <div class=\"raml-console-tab\" ng-repeat=\"method in resource.methods\" ng-click=\"showResource($event, $index)\">\n" +
    "    <span class=\"raml-console-tab-label raml-console-tab-{{method.method}}\">{{method.method.toLocaleUpperCase()}}</span>\n" +
    "  </div>\n" +
    "</div>\n"
  );


  $templateCache.put('directives/named-parameters.tpl.html',
    "<section>\n" +
    "  <header class=\"raml-console-sidebar-row raml-console-sidebar-subheader\">\n" +
    "    <h4 class=\"raml-console-sidebar-subhead\">{{title}}</h4>\n" +
    "    <button class=\"raml-console-sidebar-add-btn\" ng-click=\"addCustomParameter()\" ng-if=\"enableCustomParameters\"></button>\n" +
    "  </header>\n" +
    "\n" +
    "  <div class=\"raml-console-sidebar-row\">\n" +
    "    <p class=\"raml-console-sidebar-input-container raml-console-sidebar-input-container-custom\" ng-repeat=\"customParam in context.customParameters[type]\">\n" +
    "      <button class=\"raml-console-sidebar-input-delete\" ng-click=\"removeCutomParam(customParam)\"></button>\n" +
    "      <label class=\"raml-console-sidebar-label raml-console-sidebar-label-custom\">\n" +
    "        <input class=\"raml-console-sidebar-custom-input-for-label\" ng-model=\"customParam.name\" placeholder=\"custom key\">\n" +
    "      </label>\n" +
    "      <input name=\"custom-header\" class=\"raml-console-sidebar-input raml-console-sidebar-input-custom\" placeholder=\"custom value\" ng-model=\"customParam.value\">\n" +
    "    </p>\n" +
    "\n" +
    "    <p ng-show=\"showBaseUrl\" class=\"raml-console-sidebar-method\">{{$parent.methodInfo.method.toUpperCase()}}</p>\n" +
    "    <div ng-show=\"showBaseUrl\" class=\"raml-console-sidebar-method-content\">\n" +
    "      <div class=\"raml-console-sidebar-url\" ng-repeat=\"segment in segments\">\n" +
    "        <div ng-hide=\"segment.templated\">{{segment.name}}</div>\n" +
    "        <div ng-show=\"segment.templated\" ng-if=\"isValueProvided(context[type].values[segment.name][0])\" class=\"raml-console-sidebar-url-segment\">{{cleanupValue(context[type].values[segment.name][0])}}</div>\n" +
    "        <div ng-show=\"segment.templated\" ng-if=\"!isValueProvided(context[type].values[segment.name][0])\" class=\"raml-console-sidebar-url-segment\"><span ng-non-bindable>&#123;</span>{{segment.name}}<span ng-non-bindable>&#125;</span></div>\n" +
    "      </div>\n" +
    "    </div>\n" +
    "\n" +
    "    <p class=\"raml-console-sidebar-input-container\" ng-repeat=\"param in context[type].plain\">\n" +
    "      <span class=\"raml-console-sidebar-input-tooltip-container\" ng-if=\"param.definitions[0].description\" ng-class=\"{'raml-console-sidebar-input-tooltip-container-enum': param.definitions[0].enum}\">\n" +
    "        <button tabindex=\"-1\" class=\"raml-console-sidebar-input-tooltip\"><span class=\"raml-console-visuallyhidden\">Show documentation</span></button>\n" +
    "        <span class=\"raml-console-sidebar-tooltip-flyout\">\n" +
    "          <span markdown=\"param.definitions[0].description\" class=\"raml-console-marked-content\"></span>\n" +
    "        </span>\n" +
    "      </span>\n" +
    "\n" +
    "      <raml-field context=\"context\" type=\"type\" types=\"types\" param=\"param.definitions[0]\" model=\"context[type].values[param.definitions[0].id]\"></raml-field>\n" +
    "    </p>\n" +
    "  </div>\n" +
    "</section>\n"
  );


  $templateCache.put('directives/properties.tpl.html',
    "<div>\n" +
    "  <div class=\"raml-console-resource-param\" ng-repeat=\"property in listArray\"\n" +
    "       ng-if=\"isPropertyVisible(property)\"\n" +
    "       ng-init=\"vm.isCollapsed = !!collapsible\">\n" +
    "    <div ng-init=\"type = getType(property[0])\">\n" +
    "      <h4 class=\"raml-console-resource-param-heading\" style=\"position: relative\">\n" +
    "        <span ng-if=\"isCollapsible(type)\" ng-click=\"vm.isCollapsed = !vm.isCollapsed\" style=\"cursor: pointer\">{{ vm.isCollapsed ? '▶' : '▼' }}</span>&nbsp;{{type.displayName}}\n" +
    "        <span ng-if=\"!hidePropertyDetails\" class=\"raml-console-resource-param-instructional\">{{parameterDocumentation(type)}}</span>\n" +
    "        <span ng-if=\"hidePropertyDetails\" class=\"raml-console-resource-param-instructional\">{{typeDocumentation(type)}}</span>\n" +
    "        <span class=\"raml-console-resource-param-instructional\" ng-repeat=\"typeName in type.type\">\n" +
    "          <span ng-if=\"isNativeType(typeName)\">{{typeName}}</span>\n" +
    "          <span ng-if=\"isSchema(typeName)\">Schema</span>\n" +
    "          <span ng-if=\"!isNativeType(typeName) && !isSchema(typeName)\">\n" +
    "            <type type-name=\"typeName\" hide-type-links=\"hideTypeLinks\"></type>\n" +
    "          </span>\n" +
    "        </span>\n" +
    "      </h4>\n" +
    "\n" +
    "      <div ng-if=\"!vm.isCollapsed\">\n" +
    "        <p ng-if=\"type.description\" markdown=\"type.description\" class=\"raml-console-marked-content\"></p>\n" +
    "\n" +
    "        <p ng-if=\"type.example !== undefined && showExamples\">\n" +
    "          <span class=\"raml-console-resource-param-example\"><b>Example:</b> {{type.example}}</span>\n" +
    "        </p>\n" +
    "\n" +
    "        <pre ng-if=\"isSchema(type.type[0])\" class=\"raml-console-resource-pre\">\n" +
    "          <code class=\"raml-console-hljs\" hljs source=\"type.type[0]\"></code>\n" +
    "        </pre>\n" +
    "\n" +
    "        <properties\n" +
    "          style=\"padding-left: 10px; margin-top: 11px;\"\n" +
    "          list=\"type.properties\"\n" +
    "          ng-if=\"type.properties\"\n" +
    "          hide-type-links=\"hideTypeLinks\"\n" +
    "          is-nested-property=\"true\">\n" +
    "        </properties>\n" +
    "      </div>\n" +
    "    </div>\n" +
    "  </div>\n" +
    "</div>\n"
  );


  $templateCache.put('directives/raml-body.tpl.html',
    "<div class=\"raml-console-schema-container\" ng-if=\"isSchema\">\n" +
    "  <p><button ng-click=\"showSchema($event)\" class=\"raml-console-resource-btn\">Show Schema</button></p>\n" +
    "  <pre class=\"raml-console-resource-pre raml-console-resource-pre-toggle\">\n" +
    "    <code class=\"raml-console-hljs\" hljs source=\"getBeatifiedExample(definition)\"></code>\n" +
    "  </pre>\n" +
    "</div>\n" +
    "\n" +
    "<div class=\"raml-console-schema-container\" ng-if=\"isType\">\n" +
    "  <type-properties type=\"body\"></type-properties>\n" +
    "</div>\n"
  );


  $templateCache.put('directives/raml-client-generator.tpl.html',
    "<div class=\"raml-console-meta-button-container\">\n" +
    "  <a\n" +
    "    class=\"raml-console-meta-button raml-console-meta-button-first\"\n" +
    "    ng-click=\"open = !open\"\n" +
    "    click-outside=\"open = false\">\n" +
    "    Download API Client\n" +
    "  </a>\n" +
    "\n" +
    "  <div class=\"raml-console-meta-button-dropdown\" ng-show=\"open\">\n" +
    "    <a class=\"raml-console-meta-button-dropdown-item\" ng-click=\"downloadJavaScriptClient()\">\n" +
    "      JavaScript\n" +
    "    </a>\n" +
    "  </div>\n" +
    "</div>\n"
  );


  $templateCache.put('directives/raml-console-loader.tpl.html',
    "<div class=\"raml-console-error-container raml-console-error-primary\">\n" +
    "  <raml-console-spinner ng-if=\"!vm.loaded\"></raml-console-spinner>\n" +
    "\n" +
    "  <raml-console ng-if=\"vm.raml\" raml=\"vm.raml\" options=\"vm.options\"></raml-console>\n" +
    "\n" +
    "  <div ng-if=\"vm.error\">\n" +
    "    <div class=\"raml-console-initializer-container raml-console-initializer-primary\">\n" +
    "      <h1 class=\"raml-console-title\">RAML Console</h1>\n" +
    "\n" +
    "      <section>\n" +
    "        <header class=\"raml-console-initializer-row raml-console-initializer-subheader\">\n" +
    "          <h4 class=\"raml-console-initializer-subhead\">Error while parsing</h4>\n" +
    "        </header>\n" +
    "\n" +
    "        <div class=\"raml-console-initializer-row\">\n" +
    "          <div class=\"raml-console-parser-error\">\n" +
    "            <span>{{ vm.error.message }}</span>\n" +
    "          </div>\n" +
    "          <div class=\"raml-console-error-pre\" ng-repeat=\"err in vm.error.errors\">\n" +
    "            [{{err.isWarning && 'warning' || 'error'}}] {{err.message}}\n" +
    "          </div>\n" +
    "        </div>\n" +
    "      </section>\n" +
    "    </div>\n" +
    "\n" +
    "    {{vm.raml}}\n" +
    "  </div>\n" +
    "</div>\n"
  );


  $templateCache.put('directives/raml-console-spinner.tpl.html',
    "<div class=\"raml-console-spinner\">\n" +
    "  <div class=\"raml-console-rect1\"></div>\n" +
    "  <div class=\"raml-console-rect2\"></div>\n" +
    "  <div class=\"raml-console-rect3\"></div>\n" +
    "  <div class=\"raml-console-rect4\"></div>\n" +
    "  <div class=\"raml-console-rect5\"></div>\n" +
    "</div>\n"
  );


  $templateCache.put('directives/raml-console.tpl.html',
    "<div>\n" +
    "  <div class=\"raml-console-meta-button-group\">\n" +
    "    <theme-switcher ng-if=\"!disableThemeSwitcher\"></theme-switcher>\n" +
    "    <raml-client-generator ng-if=\"!disableRamlClientGenerator\"></raml-client-generator>\n" +
    "  </div>\n" +
    "\n" +
    "  <h1 ng-if=\"!disableTitle\" class=\"raml-console-title\">{{raml.title}}</h1>\n" +
    "\n" +
    "  <root-documentation></root-documentation>\n" +
    "\n" +
    "  <root-types types=\"types\" ng-if=\"types\"></root-types>\n" +
    "\n" +
    "  <ol ng-class=\"{'raml-console-resources-container-no-title': disableTitle, 'raml-console-resources-container': !disableTitle}\" id=\"raml-console-resources-container\" class=\"raml-console-resource-list raml-console-resource-list-root raml-console-resources-resourcesCollapsed\">\n" +
    "    <li id=\"raml_documentation\" class=\"raml-console-resource-list-item raml-console-documentation-header\">\n" +
    "      <div ng-if=\"proxy\" align=\"right\" class=\"raml-console-resource-proxy\">\n" +
    "        <label for=\"raml-console-api-behind-firewall\">API is behind a firewall <a href=\"http://www.mulesoft.org/documentation/display/current/Accessing+Your+API+Behind+a+Firewall\" target=\"_blank\">(?)</a></label>\n" +
    "        <input id=\"raml-console-api-behind-firewall\" type=\"checkbox\" ng-model=\"disableProxy\" ng-change=\"updateProxyConfig(disableProxy)\">\n" +
    "      </div>\n" +
    "      <header class=\"raml-console-resource raml-console-resource-root raml-console-clearfix\">\n" +
    "        <span ng-if=\"hasResourcesWithChilds()\" class=\"raml-console-flag raml-console-resource-heading-flag raml-console-toggle-all\" ng-click=\"collapseAll($event, resourceList, 'resourcesCollapsed')\" ng-class=\"{'raml-console-resources-expanded':!resourcesCollapsed}\">\n" +
    "          <span ng-if=\"!resourcesCollapsed\">collapse</span>\n" +
    "          <span ng-if=\"resourcesCollapsed\">expand</span> all\n" +
    "        </span>\n" +
    "\n" +
    "        <div class=\"raml-console-resource-path-container\">\n" +
    "          <h2 class=\"raml-console-resource-section-title\">\n" +
    "            <span class=\"raml-console-resource-path-active\">Resources</span>\n" +
    "          </h2>\n" +
    "        </div>\n" +
    "        <close-button></close-button>\n" +
    "      </header>\n" +
    "    </li>\n" +
    "\n" +
    "    <li id=\"{{generateId(resource.pathSegments)}}\" class=\"raml-console-resource-list-item\" ng-repeat=\"resourceGroup in inspectedRaml.resourceGroups\">\n" +
    "      <header class=\"raml-console-resource raml-console-resource-root raml-console-clearfix\" ng-class=\"{ 'raml-console-is-active':showPanel }\" ng-init=\"resource = resourceGroup[0]\">\n" +
    "        <div class=\"raml-console-resource-path-container\" ng-init=\"index=$index\" ng-class=\"{'raml-console-resource-with-description': resource.description}\">\n" +
    "          <button class=\"raml-console-resource-root-toggle\" ng-class=\"{'raml-console-is-active': resourceList[$index]}\" ng-if=\"resourceGroup.length > 1\" ng-click=\"toggle($event, index, resourceList, 'resourcesCollapsed')\"></button>\n" +
    "\n" +
    "          <h2 class=\"raml-console-resource-heading raml-console-resource-heading-large\">\n" +
    "            <a ng-if=\"resourceGroup.length > 1\" class=\"raml-console-resource-path-active\" ng-class=\"{'raml-console-resource-heading-hover':resourceGroup.length > 1}\" ng-repeat='segment in resource.pathSegments' ng-click=\"toggle($event, index, resourceList, 'resourcesCollapsed')\">{{segment.toString()}}</a>\n" +
    "\n" +
    "            <a ng-if=\"resourceGroup.length == 1\" style=\"cursor: default;\" class=\"raml-console-resource-path-active\" ng-repeat='segment in resource.pathSegments'>{{segment.toString()}}</a>\n" +
    "          </h2>\n" +
    "\n" +
    "          <resource-type></resource-type>\n" +
    "\n" +
    "          <span ng-if=\"methodInfo.is\" class=\"raml-console-flag raml-console-resource-heading-flag raml-console-resource-trait\"><b>Traits:</b> {{readTraits(methodInfo.is)}}</span>\n" +
    "\n" +
    "          <span ng-hide=\"methodInfo.is\" ng-if=\"resource.traits\" class=\"raml-console-flag raml-console-resource-heading-flag\"><b>Traits:</b> {{readResourceTraits(resource.traits)}}</span>\n" +
    "\n" +
    "          <span class=\"raml-console-resource-level-description raml-console-marked-content\" markdown=\"resource.description\"></span>\n" +
    "\n" +
    "        </div>\n" +
    "        <method-list></method-list>\n" +
    "        <close-button></close-button>\n" +
    "      </header>\n" +
    "\n" +
    "      <resource-panel></resource-panel>\n" +
    "\n" +
    "      <!-- Child Resources -->\n" +
    "      <ol class=\"raml-console-resource-list\" ng-class=\"{'raml-console-is-collapsed': resourcesCollapsed}\">\n" +
    "\n" +
    "        <li id=\"{{generateId(resource.pathSegments)}}\" class=\"raml-console-resource-list-item\" ng-repeat=\"resource in resourceGroup\" ng-if=\"!$first\">\n" +
    "          <div class=\"raml-console-resource raml-console-clearfix\" ng-class=\"{ 'raml-console-is-active':showPanel }\">\n" +
    "            <div class=\"raml-console-resource-path-container\" ng-class=\"{'raml-console-resource-with-description': resource.description}\">\n" +
    "              <h3 class=\"raml-console-resource-heading\" style=\"cursor: default;\">\n" +
    "                <span ng-repeat-start='segment in resource.pathSegments' ng-if=\"!$last\">{{segment.toString()}}</span><span ng-repeat-end ng-if=\"$last\" class=\"raml-console-resource-path-active\">{{segment.toString()}}</span>\n" +
    "              </h3>\n" +
    "\n" +
    "              <resource-type></resource-type>\n" +
    "              <span ng-if=\"methodInfo.is\" class=\"raml-console-flag raml-console-resource-heading-flag raml-console-resource-trait\"><b>Traits:</b> {{readTraits(methodInfo.is)}}</span>\n" +
    "\n" +
    "              <span ng-hide=\"methodInfo.is\" ng-if=\"resource.traits\" class=\"raml-console-flag raml-console-resource-heading-flag\"><b>Traits:</b> {{readResourceTraits(resource.traits)}}</span>\n" +
    "\n" +
    "              <span class=\"raml-console-resource-level-description raml-console-marked-content\" markdown=\"resource.description\"></span>\n" +
    "            </div>\n" +
    "\n" +
    "            <method-list></method-list>\n" +
    "            <close-button></close-button>\n" +
    "          </div>\n" +
    "\n" +
    "          <resource-panel></resource-panel>\n" +
    "        </li>\n" +
    "      </ol>\n" +
    "\n" +
    "    </li>\n" +
    "  </ol>\n" +
    "</div>\n"
  );


  $templateCache.put('directives/raml-field.tpl.html',
    "<div style=\"position: relative;\">\n" +
    "  <label for=\"{{param.id}}\" class=\"raml-console-sidebar-label\">\n" +
    "    {{param.displayName}}\n" +
    "    <a class=\"raml-console-sidebar-override\" ng-if=\"canOverride(param)\" ng-click=\"overrideField($event, param)\">Override</a>\n" +
    "    <span class=\"raml-console-side-bar-required-field\" ng-if=\"param.required\">*</span>\n" +
    "    <label ng-if=\"param.isFromSecurityScheme\" class=\"raml-console-sidebar-security-label\">from security scheme</label>\n" +
    "    <span class=\"raml-console-resource-param-instructional\">{{toString(param.type)}}</span>\n" +
    "  </label>\n" +
    "\n" +
    "  <div ng-if=\"!param.properties && !isArray(param)\">\n" +
    "    <span class=\"raml-console-sidebar-input-tooltip-container raml-console-sidebar-input-left\" ng-if=\"hasExampleValue(param)\">\n" +
    "      <button tabindex=\"-1\" class=\"raml-console-sidebar-input-reset\" ng-click=\"reset(param)\"><span class=\"raml-console-visuallyhidden\">Reset field</span></button>\n" +
    "      <span class=\"raml-console-sidebar-tooltip-flyout-left\">\n" +
    "        <span>Use example value</span>\n" +
    "      </span>\n" +
    "    </span>\n" +
    "\n" +
    "    <select id=\"select_{{param.id}}\" ng-if=\"isEnum(param)\" name=\"param.id\" class=\"raml-console-sidebar-input\" ng-model=\"model[0]\" style=\"margin-bottom: 0;\" ng-change=\"onChange()\">\n" +
    "     <option ng-repeat=\"enum in unique(param.enum)\" value=\"{{enum}}\" ng-selected=\"{{param.example === enum}}\">{{enum}}</option>\n" +
    "    </select>\n" +
    "\n" +
    "    <input id=\"{{param.id}}\" ng-hide=\"!isDefault(param)\" class=\"raml-console-sidebar-input\" ng-model=\"model[0]\" ng-class=\"{'raml-console-sidebar-field-no-default': !hasExampleValue(param)}\" validate=\"param\" dynamic-name=\"param.id\" ng-change=\"onChange()\"/>\n" +
    "\n" +
    "    <input id=\"checkbox_{{param.id}}\" ng-if=\"isBoolean(param)\" class=\"raml-console-sidebar-input\" type=\"checkbox\" ng-model=\"model[0]\" dynamic-name=\"param.id\" ng-change=\"onChange()\" />\n" +
    "\n" +
    "    <span class=\"raml-console-field-validation-error\"></span>\n" +
    "  </div>\n" +
    "\n" +
    "  <div ng-if=\"!param.properties && isArray(param)\" ng-init=\"model[0] = [[undefined]]\">\n" +
    "    <button class=\"raml-console-sidebar-add-btn\" ng-click=\"addArrayElement(model[0])\"></button>\n" +
    "    <div ng-repeat=\"aModel in model[0] track by $index\" style=\"position: relative;\">\n" +
    "      <button class=\"raml-console-sidebar-input-delete\" ng-click=\"removeArrayElement(model[0], $index)\"></button>\n" +
    "      <span class=\"raml-console-sidebar-input-tooltip-container raml-console-sidebar-input-left\" ng-if=\"hasExampleValue(param)\">\n" +
    "        <button tabindex=\"-1\" class=\"raml-console-sidebar-input-reset\" ng-click=\"reset(param)\"><span class=\"raml-console-visuallyhidden\">Reset field</span></button>\n" +
    "        <span class=\"raml-console-sidebar-tooltip-flyout-left\">\n" +
    "          <span>Use example value</span>\n" +
    "        </span>\n" +
    "      </span>\n" +
    "\n" +
    "      <select id=\"select_{{param.id}}\" ng-if=\"isEnum(param)\" name=\"param.id\" class=\"raml-console-sidebar-input\" ng-model=\"aModel[0]\" style=\"margin-bottom: 0;\" ng-change=\"onChange()\">\n" +
    "       <option ng-repeat=\"enum in unique(param.enum)\" value=\"{{enum}}\" ng-selected=\"{{param.example === enum}}\">{{enum}}</option>\n" +
    "      </select>\n" +
    "\n" +
    "      <input id=\"{{param.id}}\" ng-hide=\"!isDefault(param)\" class=\"raml-console-sidebar-input\" ng-model=\"aModel[0]\" validate=\"param\" dynamic-name=\"param.id\" ng-change=\"onChange()\"/>\n" +
    "\n" +
    "      <input id=\"checkbox_{{param.id}}\" ng-if=\"isBoolean(param)\" class=\"raml-console-sidebar-input\" type=\"checkbox\" ng-model=\"aModel[0]\" dynamic-name=\"param.id\" ng-change=\"onChange()\" />\n" +
    "\n" +
    "      <span class=\"raml-console-field-validation-error\"></span>\n" +
    "    </div>\n" +
    "  </div>\n" +
    "\n" +
    "  <div ng-if=\"param.properties\" style=\"padding-left: 10px\">\n" +
    "    <raml-field ng-repeat=\"aParam in param.properties\" context=\"context\" type=\"type\" types=\"types\" param=\"aParam[0]\" ng-init=\"model[0][aParam[0].name] = [undefined]\" model=\"model[0][aParam[0].name]\"></raml-field>\n" +
    "  </div>\n" +
    "</div>\n"
  );


  $templateCache.put('directives/raml-initializer.tpl.html',
    "<div class=\"raml-console-initializer-container raml-console-initializer-primary\">\n" +
    "  <div ng-if=\"!vm.isLoading && !vm.raml\">\n" +
    "    <h1 class=\"raml-console-title\">RAML Console</h1>\n" +
    "\n" +
    "    <div class=\"raml-console-initializer-content-wrapper\">\n" +
    "      <section>\n" +
    "        <header class=\"raml-console-initializer-row raml-console-initializer-subheader\">\n" +
    "          <h4 class=\"raml-console-initializer-subhead\">Initialize from the URL of a RAML file</h4>\n" +
    "        </header>\n" +
    "\n" +
    "        <div class=\"raml-console-initializer-row\">\n" +
    "          <form novalidate ng-submit=\"vm.loadFromUrl(vm.ramlUrl)\">\n" +
    "            <p class=\"raml-console-initializer-input-container\" ng-class=\"{'raml-console-initializer-input-container-error': vm.isLoadedFromUrl && vm.error}\">\n" +
    "              <input id=\"ramlPath\" autofocus class=\"raml-console-initializer-input raml-console-initializer-raml-field\" ng-model=\"vm.ramlUrl\">\n" +
    "            </p>\n" +
    "            <div class=\"raml-console-parser-error\" ng-if=\"vm.isLoadedFromUrl && vm.error\">\n" +
    "              <span>{{ vm.error.message }}</span>\n" +
    "            </div>\n" +
    "            <div class=\"raml-console-initializer-action-group\" align=\"right\">\n" +
    "              <button id=\"loadRamlFromUrl\" class=\"raml-console-initializer-action raml-console-initializer-action-btn\" type=\"submit\">Load from URL</button>\n" +
    "            </div>\n" +
    "          </form>\n" +
    "        </div>\n" +
    "      </section>\n" +
    "\n" +
    "      <section>\n" +
    "        <header class=\"raml-console-initializer-row raml-console-initializer-subheader\">\n" +
    "          <h4 class=\"raml-console-initializer-subhead\">or parse RAML in here</h4>\n" +
    "        </header>\n" +
    "\n" +
    "        <div class=\"raml-console-initializer-row\">\n" +
    "          <p class=\"raml-console-initializer-input-container\" ng-class=\"{'raml-console-initializer-input-container-error': !vm.isLoadedFromUrl && vm.error}\">\n" +
    "            <textarea id=\"raml\" ui-codemirror=\"vm.codeMirror\" ng-model=\"vm.ramlString\"></textarea>\n" +
    "          </p>\n" +
    "          <div class=\"raml-console-initializer-action-group\" align=\"right\">\n" +
    "            <button id=\"loadRaml\" class=\"raml-console-initializer-action raml-console-initializer-action-btn\" ng-click=\"vm.loadFromString(vm.ramlString)\">Load RAML</button>\n" +
    "          </div>\n" +
    "        </div>\n" +
    "      </section>\n" +
    "    </div>\n" +
    "  </div>\n" +
    "\n" +
    "  <raml-console ng-if=\"vm.raml\" raml=\"vm.raml\"></raml-console>\n" +
    "\n" +
    "  <raml-console-spinner ng-if=\"vm.isLoading\"></raml-console-spinner>\n" +
    "</div>\n"
  );


  $templateCache.put('directives/resource-panel.tpl.html',
    "<div class=\"raml-console-resource-panel\" ng-if=\"showPanel\" ng-class=\"{ 'raml-console-has-sidebar-collapsed': singleView }\">\n" +
    "  <div class=\"raml-console-resource-no-baseuri\" ng-hide=\"raml.baseUri\">\n" +
    "    <strong>Try-it</strong> is disabled because <strong>baseUri</strong> is not present\n" +
    "  </div>\n" +
    "  <div class=\"raml-console-resource-panel-wrapper\">\n" +
    "    <documentation></documentation>\n" +
    "\n" +
    "    <sidebar ng-show=\"raml.baseUri\"></sidebar>\n" +
    "\n" +
    "    <div class=\"raml-console-sidebar-controls raml-console-sidebar-controls-collapse\" ng-click=\"collapseSidebar($event)\" style=\"right: -1px; position: absolute;\"ng-hide=\"!raml.baseUri\" ng-if=\"!disableTryIt\">\n" +
    "      <button class=\"raml-console-collapse\" style=\"height: 21px; margin-top: 9px;\">\n" +
    "        <svg style=\"transform: rotate(-180deg); display: inline;\" version=\"1.1\" xmlns=\"http://www.w3.org/2000/svg\" xmlns:xlink=\"http://www.w3.org/1999/xlink\" x=\"0px\" y=\"0px\" viewBox=\"0 0 612 792\" enable-background=\"new 0 0 612 792\" xml:space=\"preserve\">\n" +
    "          <g id=\"Layer_3\">\n" +
    "            <polygon fill=\"#585961\" points=\"480.9,396 142.1,46.2 142.1,745.8  \"/>\n" +
    "          </g>\n" +
    "        </svg>\n" +
    "        <span class=\"raml-console-discoverable\">Try it</span>\n" +
    "      </button>\n" +
    "    </div>\n" +
    "\n" +
    "    <div class=\"raml-console-sidebar-controls raml-console-sidebar-controls-fullscreen\" ng-click=\"toggleSidebar($event)\" style=\"right: -1px; position: absolute;\">\n" +
    "      <button class=\"raml-console-collapse\" style=\"height: 21px; margin-top: 9px;\">\n" +
    "\n" +
    "        <svg style=\"transform: rotate(-180deg); display: inline;\" version=\"1.1\" xmlns=\"http://www.w3.org/2000/svg\" xmlns:xlink=\"http://www.w3.org/1999/xlink\" x=\"0px\" y=\"0px\" viewBox=\"0 0 612 792\" enable-background=\"new 0 0 612 792\" xml:space=\"preserve\">\n" +
    "          <g id=\"Layer_3\">\n" +
    "            <polygon fill=\"#585961\" points=\"480.9,396 142.1,46.2 142.1,745.8  \"/>\n" +
    "          </g>\n" +
    "        </svg>\n" +
    "        <span class=\"raml-console-discoverable\">Try it</span>\n" +
    "      </button>\n" +
    "    </div>\n" +
    "  </div>\n" +
    "</div>\n"
  );


  $templateCache.put('directives/resource-type.tpl.html',
    "<span ng-if=\"resource.resourceType\" class=\"raml-console-flag raml-console-resource-heading-flag\"><b>Type:</b> {{resource.resourceType}}</span>\n"
  );


  $templateCache.put('directives/root-documentation.tpl.html',
    "<ol id=\"raml-console-documentation-container\" ng-if=\"raml.documentation\" class=\"raml-console-resource-list raml-console-resource-list-root raml-console-root-documentation raml-console-resources-documentationCollapsed\">\n" +
    "  <li class=\"raml-console-resource-list-item raml-console-documentation-header\" ng-if=\"raml.documentation.length > 0\">\n" +
    "    <header class=\"raml-console-resource raml-console-resource-root raml-console-clearfix\">\n" +
    "      <span ng-if=\"hasDocumentationWithIndex()\" class=\"raml-console-flag raml-console-resource-heading-flag raml-console-toggle-all\" ng-click=\"collapseAll($event, documentList, 'documentationCollapsed')\" ng-class=\"{'raml-console-resources-expanded':!documentationCollapsed}\"><span ng-if=\"!documentationCollapsed\">collapse</span><span ng-if=\"documentationCollapsed\">expand</span> all</span>\n" +
    "      <div class=\"raml-console-resource-path-container\">\n" +
    "        <h2 class=\"raml-console-resource-section-title\">\n" +
    "          <span class=\"raml-console-resource-path-active\">Documentation</span>\n" +
    "        </h2>\n" +
    "      </div>\n" +
    "    </header>\n" +
    "  </li>\n" +
    "\n" +
    "  <li id=\"{{generateDocId(doc.title)}}\" class=\"raml-console-resource-list-item raml-console-documentation\" ng-repeat=\"doc in raml.documentation\">\n" +
    "    <div ng-init=\"content = getMarkdownHeaders(doc.content)\">\n" +
    "      <div class=\"raml-console-resource raml-console-clearfix raml-console-document-header\">\n" +
    "        <div class=\"raml-console-resource-path-container\" style=\"padding-top: 11px;\" ng-init=\"index=$index\">\n" +
    "          <h3 class=\"raml-console-resource-heading\">\n" +
    "            <button class=\"raml-console-resource-root-toggle\" ng-if=\"content.length > 0\" ng-click=\"toggle($event, index, documentList, 'documentationCollapsed')\" ng-class=\"{'raml-console-is-active': documentList[index]}\"></button>\n" +
    "            <span class=\"raml-console-resource-path-active raml-console-document-heading\" ng-click=\"toggleSection($event, 'all', doc.title)\">{{doc.title}}</span>\n" +
    "          </h3>\n" +
    "          <select ng-if=\"content.length > 0\" ng-model=\"selectedSection\" ng-if=\"documentationEnabled\" class=\"raml-console-document-section-selector\" ng-change=\"sectionChange(selectedSection)\">\n" +
    "            <option value=\"all\">-- choose a section --</option>\n" +
    "            <option ng-repeat=\"header in filterHeaders(content)\" value=\"{{header.value}}\" ng-selected=\"header.value == selectedDocumentSection\">{{header.label}}</option>\n" +
    "          </select>\n" +
    "        </div>\n" +
    "        <button class=\"raml-console-resource-close-btn\" ng-click=\"closeDocumentation($event)\">\n" +
    "          Close\n" +
    "        </button>\n" +
    "      </div>\n" +
    "\n" +
    "      <div class=\"raml-console-resource-panel raml-console-documentation-content\" ng-if=\"documentationEnabled\">\n" +
    "        <div class=\"raml-console-resource-panel-wrapper\">\n" +
    "          <div class=\"raml-console-documentation-section-content raml-console-marked-content\" markdown=\"getDocumentationContent(doc.content, selectedDocumentSection)\"></div>\n" +
    "        </div>\n" +
    "      </div>\n" +
    "\n" +
    "      <ol class=\"raml-console-resource-list raml-console-documentation-contents\" ng-if=\"content.length > 0\" ng-class=\"{'raml-console-is-collapsed': documentationCollapsed}\">\n" +
    "        <li ng-repeat=\"header in content\" class=\"raml-console-resource-list-item\">\n" +
    "           <div class=\"raml-console-resource raml-console-clearfix raml-console-documentation-clearfix\">\n" +
    "            <div class=\"raml-console-resource-path-container raml-console-documentation-path-container\">\n" +
    "              <h3 class=\"raml-console-resource-heading raml-console-documentation-heading raml-console-md-heading-{{header.heading}}\">\n" +
    "                <div class=\"raml-console-resource-path-active\">\n" +
    "                  <div class=\"raml-consoledocumentation-title raml-console-document-heading\" ng-click=\"toggleSection($event, header.value, doc.title)\">{{header.label}}</div>\n" +
    "                </div>\n" +
    "              </h3>\n" +
    "            </div>\n" +
    "          </div>\n" +
    "        </li>\n" +
    "      </ol>\n" +
    "    </div>\n" +
    "  </li>\n" +
    "</ol>\n"
  );


  $templateCache.put('directives/root-types.tpl.html',
    "<ol id=\"raml-console-documentation-container\" class=\"raml-console-resource-list raml-console-resource-list-root raml-console-root-documentation raml-console-resources-documentationCollapsed\" ng-init=\"vm.isCollapsed = true\">\n" +
    "  <li class=\"raml-console-resource-list-item raml-console-documentation-header\">\n" +
    "    <header class=\"raml-console-resource raml-console-resource-root raml-console-clearfix\">\n" +
    "      <div class=\"raml-console-resource-path-container\">\n" +
    "        <h2 class=\"raml-console-resource-section-title raml-console-documentation-heading\" ng-click=\"vm.isCollapsed = !vm.isCollapsed\">\n" +
    "          <button class=\"raml-console-resource-root-toggle\" ng-class=\"{'raml-console-is-active': vm.isCollapsed}\"></button>\n" +
    "          <span class=\"raml-console-resource-path-active\">Types</span>\n" +
    "        </h2>\n" +
    "      </div>\n" +
    "    </header>\n" +
    "  </li>\n" +
    "  <li ng-if=\"!vm.isCollapsed\" class=\"raml-console-resource-panel raml-console-type-panel\" style=\"padding: 32px;\">\n" +
    "    <properties list=\"theTypes\" collapsible=\"true\" hide-property-details=\"true\"></types>\n" +
    "  </li>\n" +
    "</ol>\n"
  );


  $templateCache.put('directives/sidebar.tpl.html',
    "  <form name=\"form\" class=\"raml-console-sidebar\" novalidate ng-class=\"{ 'raml-console-is-collapsed': singleView }\" ng-if=\"!disableTryIt\" ng-init=\"setFormScope(this)\">\n" +
    "    <div class=\"raml-console-sidebar-flex-wrapper\">\n" +
    "      <div class=\"raml-console-sidebar-content\">\n" +
    "        <header class=\"raml-console-sidebar-row raml-console-sidebar-header\">\n" +
    "          <h3 class=\"raml-console-sidebar-head\">\n" +
    "            Try it\n" +
    "            <a ng-if=\"!singleView\" class=\"raml-console-sidebar-fullscreen-toggle\" ng-click=\"collapseSidebar($event)\"><div class=\"raml-console-close-sidebar\">&times;</div></a>\n" +
    "            <a ng-if=\"!singleView\" class=\"raml-console-sidebar-collapse-toggle\" ng-click=\"closeSidebar($event)\"><div class=\"raml-console-close-sidebar\">&times;</div></a>\n" +
    "\n" +
    "            <a ng-if=\"singleView\" class=\"raml-console-sidebar-collapse-toggle\" ng-click=\"toggleSidebar($event)\"><div class=\"raml-console-close-sidebar\">&times;</div></a>\n" +
    "\n" +
    "            <a ng-if=\"!singleView\" class=\"raml-console-sidebar-resize-toggle raml-console-sidebar-resize\" ng-click=\"toggleSidebar($event)\">\n" +
    "              <svg x=\"0px\" y=\"0px\" viewBox=\"0 0 850 1000\" class=\"raml-console-full-resize\" fill=\"#808080\" xmlns=\"http://www.w3.org/2000/svg\" version=\"1.1\"><path d=\"M421.29 589.312q0 7.254 -5.58 12.834l-185.256 185.256 80.352 80.352q10.602 10.602 10.602 25.11t-10.602 25.11 -25.11 10.602h-249.984q-14.508 0 -25.11 -10.602t-10.602 -25.11v-249.984q0 -14.508 10.602 -25.11t25.11 -10.602 25.11 10.602l80.352 80.352 185.256 -185.256q5.58 -5.58 12.834 -5.58t12.834 5.58l63.612 63.612q5.58 5.58 5.58 12.834zm435.798 -482.112v249.984q0 14.508 -10.602 25.11t-25.11 10.602 -25.11 -10.602l-80.352 -80.352 -185.256 185.256q-5.58 5.58 -12.834 5.58t-12.834 -5.58l-63.612 -63.612q-5.58 -5.58 -5.58 -12.834t5.58 -12.834l185.256 -185.256 -80.352 -80.352q-10.602 -10.602 -10.602 -25.11t10.602 -25.11 25.11 -10.602h249.984q14.508 0 25.11 10.602t10.602 25.11z\"/></svg>\n" +
    "\n" +
    "              <svg x=\"0px\" y=\"0px\" viewBox=\"0 0 850 1000\" class=\"raml-console-small-resize\" fill=\"#808080\" xmlns=\"http://www.w3.org/2000/svg\" version=\"1.1\"><path d=\"M428.544 535.744v249.984q0 14.508 -10.602 25.11t-25.11 10.602 -25.11 -10.602l-80.352 -80.352 -185.256 185.256q-5.58 5.58 -12.834 5.58t-12.834 -5.58l-63.612 -63.612q-5.58 -5.58 -5.58 -12.834t5.58 -12.834l185.256 -185.256 -80.352 -80.352q-10.602 -10.602 -10.602 -25.11t10.602 -25.11 25.11 -10.602h249.984q14.508 0 25.11 10.602t10.602 25.11zm421.29 -374.976q0 7.254 -5.58 12.834l-185.256 185.256 80.352 80.352q10.602 10.602 10.602 25.11t-10.602 25.11 -25.11 10.602h-249.984q-14.508 0 -25.11 -10.602t-10.602 -25.11v-249.984q0 -14.508 10.602 -25.11t25.11 -10.602 25.11 10.602l80.352 80.352 185.256 -185.256q5.58 -5.58 12.834 -5.58t12.834 5.58l63.612 63.612q5.58 5.58 5.58 12.834z\"/></svg>\n" +
    "            </a>\n" +
    "          </h3>\n" +
    "        </header>\n" +
    "\n" +
    "        <div class=\"raml-console-sidebar-content-wrapper\">\n" +
    "          <section ng-if=\"protocols.length > 1\">\n" +
    "            <header class=\"raml-console-sidebar-row raml-console-sidebar-subheader raml-console-sidebar-subheader-top\">\n" +
    "              <h4 class=\"raml-console-sidebar-subhead\">Protocols</h4>\n" +
    "            </header>\n" +
    "            <div class=\"raml-console-sidebar-row raml-console-sidebar-securty\">\n" +
    "              <select ng-change=\"protocolChanged(currentProtocol)\" class=\"raml-console-sidebar-input\" ng-model=\"currentProtocol\" style=\"margin-bottom: 0;\">\n" +
    "               <option ng-repeat=\"protocol in protocols\" value=\"{{protocol}}\">{{protocol}}</option>\n" +
    "              </select>\n" +
    "            </div>\n" +
    "          </section>\n" +
    "\n" +
    "          <section>\n" +
    "            <header class=\"raml-console-sidebar-row raml-console-sidebar-subheader\" ng-class=\"{'raml-console-sidebar-subheader-top':raml.protocols.length == 1}\">\n" +
    "              <h4 class=\"raml-console-sidebar-subhead\">Authentication</h4>\n" +
    "            </header>\n" +
    "            <div class=\"raml-console-sidebar-row raml-console-sidebar-securty\">\n" +
    "              <div class=\"raml-console-toggle-group raml-console-sidebar-toggle-group\">\n" +
    "                <label class=\"raml-console-sidebar-label\">Security Scheme</label>\n" +
    "                <span class=\"raml-console-resource-param-instructional\">Custom Security Schemes are not supported in Try It</span>\n" +
    "                <select ng-change=\"securitySchemeChanged(currentScheme)\" class=\"raml-console-sidebar-input\" ng-model=\"currentScheme\" style=\"margin-bottom: 0;\">\n" +
    "                 <option ng-repeat=\"(key, scheme) in securitySchemes\" value=\"{{scheme.id}}\">{{scheme.name}}</option>\n" +
    "                </select>\n" +
    "              </div>\n" +
    "            </div>\n" +
    "\n" +
    "            <div ng-switch=\"currentSchemeType\">\n" +
    "              <basic-auth ng-switch-when=\"Basic Authentication\" credentials='credentials'></basic-auth>\n" +
    "              <oauth1 ng-switch-when=\"OAuth 1.0\" credentials='credentials'></oauth1>\n" +
    "              <oauth2 ng-switch-when=\"OAuth 2.0\" credentials='credentials'></oauth2>\n" +
    "            </div>\n" +
    "          </section>\n" +
    "\n" +
    "          <named-parameters ng-if=\"resource.uriParametersForDocumentation\" src=\"resource.uriParametersForDocumentation\" context=\"context\" type=\"uriParameters\" title=\"URI Parameters\" show-base-url></named-parameters>\n" +
    "\n" +
    "          <named-parameters src=\"methodInfo.headers.plain\" context=\"context\" type=\"headers\" title=\"Headers\" enable-custom-parameters></named-parameters>\n" +
    "\n" +
    "          <named-parameters src=\"methodInfo.queryParameters\" context=\"context\" type=\"queryParameters\" types=\"types\" title=\"Query Parameters\" enable-custom-parameters></named-parameters>\n" +
    "\n" +
    "          <section ng-if=\"methodInfo.queryString\">\n" +
    "            <header class=\"raml-console-sidebar-row raml-console-sidebar-subheader\">\n" +
    "              <h4 class=\"raml-console-sidebar-subhead\">Query String</h4>\n" +
    "            </header>\n" +
    "\n" +
    "            <div class=\"raml-console-sidebar-row\" style=\"padding-bottom: 0;\">\n" +
    "              <div\n" +
    "                class=\"raml-console-resource-param-instructional\"\n" +
    "                ng-show=\"queryStringHasError\"\n" +
    "                style=\"color: red;\">\n" +
    "                  Query String format is invalid, JSON string expected\n" +
    "              </div>\n" +
    "              <div\n" +
    "                class=\"raml-console-codemirror-body-editor\"\n" +
    "                ui-codemirror=\"{ lineNumbers: true, tabSize: 2, theme : 'raml-console', mode: context.bodyContent.selected }\"\n" +
    "                ng-model=\"context.queryString\">\n" +
    "              </div>\n" +
    "            </div>\n" +
    "          </section>\n" +
    "\n" +
    "          <section id=\"sidebar-body\" ng-if=\"methodInfo.body\">\n" +
    "            <header class=\"raml-console-sidebar-row raml-console-sidebar-subheader\">\n" +
    "              <h4 class=\"raml-console-sidebar-subhead\">Body</h4>\n" +
    "            </header>\n" +
    "\n" +
    "            <div class=\"raml-console-sidebar-row\" style=\"padding-bottom: 0;\">\n" +
    "              <select ng-change=\"requestBodySelectionChange(context.bodyContent.selected)\" class=\"raml-console-sidebar-input\" ng-model=\"context.bodyContent.selected\" style=\"margin-bottom: 0;\">\n" +
    "               <option ng-repeat=\"(key, scheme) in methodInfo.body\" value=\"{{key}}\">{{key}}</option>\n" +
    "              </select>\n" +
    "            </div>\n" +
    "\n" +
    "            <div class=\"raml-console-sidebar-row\" ng-switch=\"context.bodyContent.isForm(context.bodyContent.selected)\">\n" +
    "              <div ng-switch-when=\"false\">\n" +
    "                <div class=\"raml-console-codemirror-body-editor\" ui-codemirror=\"{ lineNumbers: true, tabSize: 2, theme : 'raml-console', mode: context.bodyContent.selected }\" ng-model=\"context.bodyContent.definitions[context.bodyContent.selected].value\"></div>\n" +
    "                <div class=\"raml-console-sidebar-prefill raml-console-sidebar-row\" align=\"right\" ng-if=\"context.bodyContent.definitions[context.bodyContent.selected].hasExample()\">\n" +
    "                  <button class=\"raml-console-sidebar-action-prefill\" ng-click=\"prefillBody(context.bodyContent.selected)\">Prefill with example</button>\n" +
    "                </div>\n" +
    "              </div>\n" +
    "\n" +
    "\n" +
    "              <div ng-switch-when=\"true\">\n" +
    "                <p class=\"raml-console-sidebar-input-container\" ng-repeat=\"param in context.bodyContent.definitions[context.bodyContent.selected].plain\">\n" +
    "                  <span class=\"raml-console-sidebar-input-tooltip-container\" ng-if=\"param.definitions[0].description\">\n" +
    "                    <button tabindex=\"-1\" class=\"raml-console-sidebar-input-tooltip\"><span class=\"raml-console-visuallyhidden\">Show documentation</span></button>\n" +
    "                    <span class=\"raml-console-sidebar-tooltip-flyout\">\n" +
    "                      <span markdown=\"param.definitions[0].description\" class=\"raml-console-marked-content\"></span>\n" +
    "                    </span>\n" +
    "                  </span>\n" +
    "\n" +
    "                  <raml-field context=\"context\" type=\"type\" types=\"types\" param=\"param.definitions[0]\" model=\"context.bodyContent.definitions[context.bodyContent.selected].values[param.definitions[0].id]\"></raml-field>\n" +
    "                </p>\n" +
    "              </div>\n" +
    "            </div>\n" +
    "          </section>\n" +
    "\n" +
    "          <section>\n" +
    "            <div class=\"raml-console-sidebar-row\">\n" +
    "              <span\n" +
    "                class=\"raml-console-resource-param-instructional\"\n" +
    "                ng-show=\"customStrategyError\"\n" +
    "                style=\"color: red;\">\n" +
    "                  Custom Security Schemes are not supported in Try It\n" +
    "              </span>\n" +
    "              <div class=\"raml-console-sidebar-action-group\">\n" +
    "                <button ng-hide=\"showSpinner\" type=\"submit\" class=\"raml-console-sidebar-action raml-console-sidebar-action-{{methodInfo.method}}\" ng-click=\"tryIt($event)\" ng-class=\"{'raml-console-sidebar-action-force':context.forceRequest}\"><span ng-if=\"context.forceRequest\">Force</span> {{methodInfo.method.toUpperCase()}}\n" +
    "                </button>\n" +
    "                <button ng-if=\"showSpinner\" type=\"submit\" class=\"raml-console-sidebar-action raml-console-sidebar-action-{{methodInfo.method}} raml-console-sidebar-action-cancel-request\" ng-click=\"cancelRequest()\">Cancel <div class=\"raml-console-spinner-request\" ng-if=\"showSpinner\">Loading ...</div></button>\n" +
    "                <button class=\"raml-console-sidebar-action raml-console-sidebar-action-clear\" ng-click=\"clearFields()\">Clear</button>\n" +
    "                <button class=\"raml-console-sidebar-action raml-console-sidebar-action-reset\" ng-click=\"resetFields()\">Reset</button>\n" +
    "              </div>\n" +
    "            </div>\n" +
    "          </section>\n" +
    "\n" +
    "          <div ng-if=\"responseDetails\">\n" +
    "            <section id=\"request_{{generateId(resource.pathSegments)}}\" class=\"raml-console-side-bar-try-it-description\">\n" +
    "              <header class=\"raml-console-sidebar-row raml-console-sidebar-header\">\n" +
    "                <h3 class=\"raml-console-sidebar-head raml-console-sidebar-head-expand\">\n" +
    "                  <button ng-class=\"{'raml-console-is-open':showRequestMetadata, 'raml-console-is-collapsed':!showRequestMetadata}\" class=\"raml-console-sidebar-expand-btn\" ng-click=\"toggleRequestMetadata()\">\n" +
    "                    Request\n" +
    "                  </button>\n" +
    "                </h3>\n" +
    "              </header>\n" +
    "              <div class=\"raml-console-sidebar-request-metadata\" ng-class=\"{'raml-console-is-active':showRequestMetadata}\">\n" +
    "\n" +
    "                <div class=\"raml-console-sidebar-row\">\n" +
    "                  <div ng-if=\"requestOptions.url\">\n" +
    "                    <h3 class=\"raml-console-sidebar-response-head raml-console-sidebar-response-head-pre\">Request URL</h3>\n" +
    "                    <div class=\"raml-console-sidebar-response-item\">\n" +
    "                      <p class=\"raml-console-sidebar-response-metadata raml-console-sidebar-request-url\">{{requestOptions.url}}</p>\n" +
    "                    </div>\n" +
    "                  </div>\n" +
    "\n" +
    "                  <div ng-if=\"requestOptions.headers\">\n" +
    "                    <h3 class=\"raml-console-sidebar-response-head\">Headers</h3>\n" +
    "                    <div class=\"raml-console-sidebar-response-item\">\n" +
    "                      <p class=\"raml-console-sidebar-response-metadata\" ng-repeat=\"(key, value) in requestOptions.headers\">\n" +
    "                        <b>{{key}}:</b> <br>{{getHeaderValue(value)}}\n" +
    "                      </p>\n" +
    "                    </div>\n" +
    "                  </div>\n" +
    "\n" +
    "                  <div ng-if=\"requestOptions.data\">\n" +
    "                    <h3 class=\"raml-console-sidebar-response-head raml-console-sidebar-response-head-pre\">Body</h3>\n" +
    "                    <div ng-switch=\"context.bodyContent.isForm(context.bodyContent.selected)\">\n" +
    "                      <div ng-switch-when=\"false\" class=\"raml-console-sidebar-pre raml-console-sidebar-request-body\">\n" +
    "                        <div ui-codemirror=\"{ readOnly: 'nocursor', tabSize: 2, lineNumbers: true, theme : 'raml-console', mode: context.bodyContent.selected }\" ng-model=\"requestOptions.data\"></div>\n" +
    "                      </div>\n" +
    "                      <div ng-switch-when=\"true\" class=\"raml-console-sidebar-response-item\">\n" +
    "                        <p class=\"raml-console-sidebar-response-metadata\" ng-repeat=\"(key, value) in context.bodyContent.definitions[context.bodyContent.selected].values\">\n" +
    "                          <b>{{key}}:</b> <br>{{value}}\n" +
    "                        </p>\n" +
    "                      </div>\n" +
    "                    </div>\n" +
    "                  </div>\n" +
    "                </div>\n" +
    "              </div>\n" +
    "            </section>\n" +
    "\n" +
    "            <section class=\"raml-console-side-bar-try-it-description\">\n" +
    "              <header class=\"raml-console-sidebar-row raml-console-sidebar-header\">\n" +
    "                <h3 class=\"raml-console-sidebar-head\">\n" +
    "                  <button ng-class=\"{'raml-console-is-open':showResponseMetadata, 'raml-console-is-collapsed':!showResponseMetadata}\" class=\"raml-console-sidebar-expand-btn\" ng-click=\"toggleResponseMetadata()\">\n" +
    "                    Response\n" +
    "                  </button>\n" +
    "                </h3>\n" +
    "              </header>\n" +
    "\n" +
    "              <div class=\"raml-console-sidebar-row raml-console-sidebar-response\" ng-class=\"{'raml-console-is-active':showResponseMetadata}\">\n" +
    "                <h3 class=\"raml-console-sidebar-response-head\">Status</h3>\n" +
    "                <p class=\"raml-console-sidebar-response-item\">{{response.status}}</p>\n" +
    "\n" +
    "                <h3 class=\"raml-console-sidebar-response-head\" ng-if=\"response.headers\">Headers</h3>\n" +
    "                <div class=\"raml-console-sidebar-response-item\">\n" +
    "                  <p class=\"raml-console-sidebar-response-metadata\" ng-repeat=\"(key, value) in response.headers\">\n" +
    "                    <b>{{key}}:</b> <br>{{value}}\n" +
    "                  </p>\n" +
    "                </div>\n" +
    "                <div ng-if=\"response.body\">\n" +
    "                  <h3 class=\"raml-console-sidebar-response-head raml-console-sidebar-response-head-pre\">Body</h3>\n" +
    "                  <div class=\"raml-console-sidebar-pre\">\n" +
    "                    <div ui-codemirror=\"{ readOnly: true, tabSize: 2, lineNumbers: true, theme : 'raml-console', mode: response.contentType }\" ng-model=\"response.body\" ng-style=\"editorStyle\">\n" +
    "                    </div>\n" +
    "                  </div>\n" +
    "                </div>\n" +
    "              </div>\n" +
    "            </section>\n" +
    "          </div>\n" +
    "      </div>\n" +
    "    </div>\n" +
    "  </div>\n" +
    "</form>\n"
  );


  $templateCache.put('directives/spinner.tpl.html',
    "<img src=\"img/spinner.gif\">\n"
  );


  $templateCache.put('directives/theme-switcher.tpl.html',
    "<div class=\"raml-console-meta-button-container\">\n" +
    "  <a class=\"raml-console-meta-button\">Switch Theme</a>\n" +
    "</div>\n"
  );


  $templateCache.put('directives/type-properties.tpl.html',
    "<div>\n" +
    "  <properties list=\"properties\" hide-property-details=\"true\" show-examples=\"true\"></properties>\n" +
    "<div>\n"
  );


  $templateCache.put('directives/type.tpl.html',
    "<span ng-repeat=\"type in typeInfo.parts\">\n" +
    "  <span ng-if=\"$first && typeInfo.isArray\">(</span>\n" +
    "  <span ng-if=\"!$first && typeInfo.type === 'union'\"> | </span>\n" +
    "  <a href=\"\" ng-click=\"selectType($event, cleanupTypeName(type))\" ng-if=\"showTypeLink(type)\">{{cleanupTypeName(type)}}</a>\n" +
    "  <span ng-if=\"!showTypeLink(type)\">{{type}}</span>\n" +
    "  <span ng-if=\"typeInfo.type === 'array'\">[]</span>\n" +
    "  <span ng-if=\"$last && typeInfo.isArray\">)[]</span>\n" +
    "</span>\n" +
    "<div ng-if=\"selectedType\" class=\"raml-console-type-info-popover\">\n" +
    "  <h3>\n" +
    "    <span>{{selectedType.displayName}}</span>\n" +
    "    <span class=\"raml-console-resource-param-instructional\">{{typeDocumentation(selectedType)}}</span>\n" +
    "    <div class=\"raml-console-subtitle\">\n" +
    "      <span ng-repeat-start=\"superType in getSupertTypes(selectedType)\">{{superType}}</span>\n" +
    "      <span ng-if=\"!$last\" ng-repeat-end>, </span>\n" +
    "    </div>\n" +
    "  </h3>\n" +
    "  <properties\n" +
    "    ng-click=\"$event.preventDefault()\"\n" +
    "    list=\"selectedType.properties\"\n" +
    "    ng-if=\"selectedType.properties\"\n" +
    "    is-nested-property=\"true\"\n" +
    "    hide-type-links=\"true\">\n" +
    "  </properties>\n" +
    "</div>\n"
  );


  $templateCache.put('security/basic_auth.tpl.html',
    "<div class=\"raml-console-sidebar-row\">\n" +
    "  <p class=\"raml-console-sidebar-input-container\">\n" +
    "    <label for=\"username\" class=\"raml-console-sidebar-label\">Username <span class=\"raml-console-side-bar-required-field\">*</span></label>\n" +
    "    <input required=\"true\" type=\"text\" name=\"username\" class=\"raml-console-sidebar-input raml-console-sidebar-security-field\" ng-model=\"credentials.username\" ng-change=\"onChange()\"/>\n" +
    "    <span class=\"raml-console-field-validation-error\"></span>\n" +
    "  </p>\n" +
    "\n" +
    "  <p class=\"raml-console-sidebar-input-container\">\n" +
    "    <label for=\"password\" class=\"raml-console-sidebar-label\">Password <span class=\"raml-console-side-bar-required-field\">*</span></label>\n" +
    "    <input required=\"true\" type=\"password\" name=\"password\" class=\"raml-console-sidebar-input raml-console-sidebar-security-field\" ng-model=\"credentials.password\" ng-change=\"onChange()\"/>\n" +
    "    <span class=\"raml-console-field-validation-error\"></span>\n" +
    "  </p>\n" +
    "</div>\n"
  );


  $templateCache.put('security/oauth1.tpl.html',
    "<div class=\"raml-console-sidebar-row\">\n" +
    "  <p class=\"raml-console-sidebar-input-container\">\n" +
    "    <label for=\"consumerKey\" class=\"raml-console-sidebar-label\">Consumer Key <span class=\"raml-console-side-bar-required-field\">*</span></label>\n" +
    "    <input required=\"true\" type=\"text\" name=\"consumerKey\" class=\"raml-console-sidebar-input raml-console-sidebar-security-field\" ng-model=\"credentials.consumerKey\" ng-change=\"onChange()\"/>\n" +
    "    <span class=\"raml-console-field-validation-error\"></span>\n" +
    "  </p>\n" +
    "\n" +
    "  <p class=\"raml-console-sidebar-input-container\">\n" +
    "    <label for=\"consumerSecret\" class=\"raml-console-sidebar-label\">Consumer Secret <span class=\"raml-console-side-bar-required-field\">*</span></label>\n" +
    "    <input required=\"true\" type=\"password\" name=\"consumerSecret\" class=\"raml-console-sidebar-input raml-console-sidebar-security-field\" ng-model=\"credentials.consumerSecret\" ng-change=\"onChange()\"/>\n" +
    "    <span class=\"raml-console-field-validation-error\"></span>\n" +
    "  </p>\n" +
    "</div>\n"
  );


  $templateCache.put('security/oauth2.tpl.html',
    "<div class=\"raml-console-sidebar-row\">\n" +
    "  <p class=\"raml-console-sidebar-input-container\">\n" +
    "    <label for=\"clientId\" class=\"raml-console-sidebar-label\">Authorization Grant</label>\n" +
    "    <select class=\"raml-console-sidebar-input\" ng-model=\"credentials.grant\">\n" +
    "     <option ng-repeat=\"grant in grants\" value=\"{{grant.value}}\" ng-selected=\"grant.value=='token'\">{{grant.label}}</option>\n" +
    "    </select>\n" +
    "  </p>\n" +
    "\n" +
    "  <p class=\"raml-console-sidebar-input-container\">\n" +
    "    <label for=\"clientId\" class=\"raml-console-sidebar-label\">Client ID <span class=\"raml-console-side-bar-required-field\">*</span></label>\n" +
    "    <input required=\"true\" type=\"text\" name=\"clientId\" class=\"raml-console-sidebar-input raml-console-sidebar-security-field\" ng-model=\"credentials.clientId\" ng-change=\"onChange()\"/>\n" +
    "    <span class=\"raml-console-field-validation-error\"></span>\n" +
    "  </p>\n" +
    "\n" +
    "  <p class=\"raml-console-sidebar-input-container\" ng-if=\"!isImplicitEnabled()\">\n" +
    "    <label for=\"clientSecret\" class=\"raml-console-sidebar-label\">Client Secret <span class=\"raml-console-side-bar-required-field\">*</span></label>\n" +
    "    <input required=\"true\" type=\"password\" name=\"clientSecret\" class=\"raml-console-sidebar-input raml-console-sidebar-security-field\" ng-model=\"credentials.clientSecret\" ng-change=\"onChange()\"/>\n" +
    "    <span class=\"raml-console-field-validation-error\"></span>\n" +
    "  </p>\n" +
    "\n" +
    "  <p class=\"raml-console-sidebar-input-container\" ng-if=\"ownerOptionsEnabled()\">\n" +
    "    <label for=\"username\" class=\"raml-console-sidebar-label\">Username <span class=\"raml-console-side-bar-required-field\">*</span></label>\n" +
    "    <input required=\"true\" type=\"text\" name=\"username\" class=\"raml-console-sidebar-input raml-console-sidebar-security-field\" ng-model=\"credentials.username\" ng-change=\"onChange()\"/>\n" +
    "    <span class=\"raml-console-field-validation-error\"></span>\n" +
    "  </p>\n" +
    "\n" +
    "  <p class=\"raml-console-sidebar-input-container\" ng-if=\"ownerOptionsEnabled()\">\n" +
    "    <label for=\"password\" class=\"raml-console-sidebar-label\">Password <span class=\"raml-console-side-bar-required-field\">*</span></label>\n" +
    "    <input required=\"true\" type=\"password\" name=\"password\" class=\"raml-console-sidebar-input raml-console-sidebar-security-field\" ng-model=\"credentials.password\" ng-change=\"onChange()\"/>\n" +
    "    <span class=\"raml-console-field-validation-error\"></span>\n" +
    "  </p>\n" +
    "\n" +
    "  <p class=\"raml-console-sidebar-input-container\">\n" +
    "    <label for=\"password\" class=\"raml-console-sidebar-label\">Scopes</label>\n" +
    "    <ol class=\"raml-console-sidebar-oauth-scopes\">\n" +
    "      <li ng-repeat=\"scope in scopes\">\n" +
    "        <input type=\"checkbox\" ng-model=\"credentials.scopes[scope]\"> {{scope}}\n" +
    "      </li>\n" +
    "    </ol>\n" +
    "  </p>\n" +
    "</div>\n"
  );

}]);

/* FileSaver.js
 * A saveAs() FileSaver implementation.
 * 2015-03-04
 *
 * By Eli Grey, http://eligrey.com
 * License: X11/MIT
 *   See https://github.com/eligrey/FileSaver.js/blob/master/LICENSE.md
 */

/*global self */
/*jslint bitwise: true, indent: 4, laxbreak: true, laxcomma: true, smarttabs: true, plusplus: true */

/*! @source http://purl.eligrey.com/github/FileSaver.js/blob/master/FileSaver.js */

var saveAs = saveAs
  // IE 10+ (native saveAs)
  || (typeof navigator !== "undefined" &&
      navigator.msSaveOrOpenBlob && navigator.msSaveOrOpenBlob.bind(navigator))
  // Everyone else
  || (function(view) {
	"use strict";
	// IE <10 is explicitly unsupported
	if (typeof navigator !== "undefined" &&
	    /MSIE [1-9]\./.test(navigator.userAgent)) {
		return;
	}
	var
		  doc = view.document
		  // only get URL when necessary in case Blob.js hasn't overridden it yet
		, get_URL = function() {
			return view.URL || view.webkitURL || view;
		}
		, save_link = doc.createElementNS("http://www.w3.org/1999/xhtml", "a")
		, can_use_save_link = "download" in save_link
		, click = function(node) {
			var event = doc.createEvent("MouseEvents");
			event.initMouseEvent(
				"click", true, false, view, 0, 0, 0, 0, 0
				, false, false, false, false, 0, null
			);
			node.dispatchEvent(event);
		}
		, webkit_req_fs = view.webkitRequestFileSystem
		, req_fs = view.requestFileSystem || webkit_req_fs || view.mozRequestFileSystem
		, throw_outside = function(ex) {
			(view.setImmediate || view.setTimeout)(function() {
				throw ex;
			}, 0);
		}
		, force_saveable_type = "application/octet-stream"
		, fs_min_size = 0
		// See https://code.google.com/p/chromium/issues/detail?id=375297#c7 and
		// https://github.com/eligrey/FileSaver.js/commit/485930a#commitcomment-8768047
		// for the reasoning behind the timeout and revocation flow
		, arbitrary_revoke_timeout = 500 // in ms
		, revoke = function(file) {
			var revoker = function() {
				if (typeof file === "string") { // file is an object URL
					get_URL().revokeObjectURL(file);
				} else { // file is a File
					file.remove();
				}
			};
			if (view.chrome) {
				revoker();
			} else {
				setTimeout(revoker, arbitrary_revoke_timeout);
			}
		}
		, dispatch = function(filesaver, event_types, event) {
			event_types = [].concat(event_types);
			var i = event_types.length;
			while (i--) {
				var listener = filesaver["on" + event_types[i]];
				if (typeof listener === "function") {
					try {
						listener.call(filesaver, event || filesaver);
					} catch (ex) {
						throw_outside(ex);
					}
				}
			}
		}
		, FileSaver = function(blob, name) {
			// First try a.download, then web filesystem, then object URLs
			var
				  filesaver = this
				, type = blob.type
				, blob_changed = false
				, object_url
				, target_view
				, dispatch_all = function() {
					dispatch(filesaver, "writestart progress write writeend".split(" "));
				}
				// on any filesys errors revert to saving with object URLs
				, fs_error = function() {
					// don't create more object URLs than needed
					if (blob_changed || !object_url) {
						object_url = get_URL().createObjectURL(blob);
					}
					if (target_view) {
						target_view.location.href = object_url;
					} else {
						var new_tab = view.open(object_url, "_blank");
						if (new_tab == undefined && typeof safari !== "undefined") {
							//Apple do not allow window.open, see http://bit.ly/1kZffRI
							view.location.href = object_url
						}
					}
					filesaver.readyState = filesaver.DONE;
					dispatch_all();
					revoke(object_url);
				}
				, abortable = function(func) {
					return function() {
						if (filesaver.readyState !== filesaver.DONE) {
							return func.apply(this, arguments);
						}
					};
				}
				, create_if_not_found = {create: true, exclusive: false}
				, slice
			;
			filesaver.readyState = filesaver.INIT;
			if (!name) {
				name = "download";
			}
			if (can_use_save_link) {
				object_url = get_URL().createObjectURL(blob);
				save_link.href = object_url;
				save_link.download = name;
				click(save_link);
				filesaver.readyState = filesaver.DONE;
				dispatch_all();
				revoke(object_url);
				return;
			}
			// prepend BOM for UTF-8 XML and text/plain types
			if (/^\s*(?:text\/(?:plain|xml)|application\/xml|\S*\/\S*\+xml)\s*;.*charset\s*=\s*utf-8/i.test(blob.type)) {
				blob = new Blob(["\ufeff", blob], {type: blob.type});
			}
			// Object and web filesystem URLs have a problem saving in Google Chrome when
			// viewed in a tab, so I force save with application/octet-stream
			// http://code.google.com/p/chromium/issues/detail?id=91158
			// Update: Google errantly closed 91158, I submitted it again:
			// https://code.google.com/p/chromium/issues/detail?id=389642
			if (view.chrome && type && type !== force_saveable_type) {
				slice = blob.slice || blob.webkitSlice;
				blob = slice.call(blob, 0, blob.size, force_saveable_type);
				blob_changed = true;
			}
			// Since I can't be sure that the guessed media type will trigger a download
			// in WebKit, I append .download to the filename.
			// https://bugs.webkit.org/show_bug.cgi?id=65440
			if (webkit_req_fs && name !== "download") {
				name += ".download";
			}
			if (type === force_saveable_type || webkit_req_fs) {
				target_view = view;
			}
			if (!req_fs) {
				fs_error();
				return;
			}
			fs_min_size += blob.size;
			req_fs(view.TEMPORARY, fs_min_size, abortable(function(fs) {
				fs.root.getDirectory("saved", create_if_not_found, abortable(function(dir) {
					var save = function() {
						dir.getFile(name, create_if_not_found, abortable(function(file) {
							file.createWriter(abortable(function(writer) {
								writer.onwriteend = function(event) {
									target_view.location.href = file.toURL();
									filesaver.readyState = filesaver.DONE;
									dispatch(filesaver, "writeend", event);
									revoke(file);
								};
								writer.onerror = function() {
									var error = writer.error;
									if (error.code !== error.ABORT_ERR) {
										fs_error();
									}
								};
								"writestart progress write abort".split(" ").forEach(function(event) {
									writer["on" + event] = filesaver["on" + event];
								});
								writer.write(blob);
								filesaver.abort = function() {
									writer.abort();
									filesaver.readyState = filesaver.DONE;
								};
								filesaver.readyState = filesaver.WRITING;
							}), fs_error);
						}), fs_error);
					};
					dir.getFile(name, {create: false}, abortable(function(file) {
						// delete file if it already exists
						file.remove();
						save();
					}), abortable(function(ex) {
						if (ex.code === ex.NOT_FOUND_ERR) {
							save();
						} else {
							fs_error();
						}
					}));
				}), fs_error);
			}), fs_error);
		}
		, FS_proto = FileSaver.prototype
		, saveAs = function(blob, name) {
			return new FileSaver(blob, name);
		}
	;
	FS_proto.abort = function() {
		var filesaver = this;
		filesaver.readyState = filesaver.DONE;
		dispatch(filesaver, "abort");
	};
	FS_proto.readyState = FS_proto.INIT = 0;
	FS_proto.WRITING = 1;
	FS_proto.DONE = 2;

	FS_proto.error =
	FS_proto.onwritestart =
	FS_proto.onprogress =
	FS_proto.onwrite =
	FS_proto.onabort =
	FS_proto.onerror =
	FS_proto.onwriteend =
		null;

	return saveAs;
}(
	   typeof self !== "undefined" && self
	|| typeof window !== "undefined" && window
	|| this.content
));
// `self` is undefined in Firefox for Android content script context
// while `this` is nsIContentFrameMessageManager
// with an attribute `content` that corresponds to the window

if (typeof module !== "undefined" && module.exports) {
  module.exports.saveAs = saveAs;
} else if ((typeof define !== "undefined" && define !== null) && (define.amd != null)) {
  define([], function() {
    return saveAs;
  });
}

(function(f){if(typeof exports==="object"&&typeof module!=="undefined"){module.exports=f()}else if(typeof define==="function"&&define.amd){define([],f)}else{var g;if(typeof window!=="undefined"){g=window}else if(typeof global!=="undefined"){g=global}else if(typeof self!=="undefined"){g=self}else{g=this}g.$RefParser = f()}})(function(){var define,module,exports;return (function e(t,n,r){function s(o,u){if(!n[o]){if(!t[o]){var a=typeof require=="function"&&require;if(!u&&a)return a(o,!0);if(i)return i(o,!0);var f=new Error("Cannot find module '"+o+"'");throw f.code="MODULE_NOT_FOUND",f}var l=n[o]={exports:{}};t[o][0].call(l.exports,function(e){var n=t[o][1][e];return s(n?n:e)},l,l.exports,e,t,n,r)}return n[o].exports}var i=typeof require=="function"&&require;for(var o=0;o<r.length;o++)s(r[o]);return s})({1:[function(require,module,exports){
/** !
 * JSON Schema $Ref Parser v2.2.1
 *
 * @link https://github.com/BigstickCarpet/json-schema-ref-parser
 * @license MIT
 */
'use strict';

var $Ref    = require('./ref'),
    Pointer = require('./pointer'),
    util    = require('./util'),
    url     = require('url');

module.exports = bundle;

/**
 * Bundles all external JSON references into the main JSON schema, thus resulting in a schema that
 * only has *internal* references, not any *external* references.
 * This method mutates the JSON schema object, adding new references and re-mapping existing ones.
 *
 * @param {$RefParser} parser
 * @param {$RefParserOptions} options
 */
function bundle(parser, options) {
  util.debug('Bundling $ref pointers in %s', parser.$refs._basePath);

  // Build an inventory of all $ref pointers in the JSON Schema
  var inventory = [];
  crawl(parser.schema, parser.$refs._basePath + '#', '#', inventory, parser.$refs, options);

  // Remap all $ref pointers
  remap(inventory);
}

/**
 * Recursively crawls the given value, and inventories all JSON references.
 *
 * @param {*} obj - The value to crawl. If it's not an object or array, it will be ignored.
 * @param {string} path - The full path of `obj`, possibly with a JSON Pointer in the hash
 * @param {string} pathFromRoot - The path of `obj` from the schema root
 * @param {object[]} inventory - An array of already-inventoried $ref pointers
 * @param {$Refs} $refs
 * @param {$RefParserOptions} options
 */
function crawl(obj, path, pathFromRoot, inventory, $refs, options) {
  if (obj && typeof obj === 'object') {
    var keys = Object.keys(obj);

    // Most people will expect references to be bundled into the the "definitions" property,
    // so we always crawl that property first, if it exists.
    var defs = keys.indexOf('definitions');
    if (defs > 0) {
      keys.splice(0, 0, keys.splice(defs, 1)[0]);
    }

    keys.forEach(function(key) {
      var keyPath = Pointer.join(path, key);
      var keyPathFromRoot = Pointer.join(pathFromRoot, key);
      var value = obj[key];

      if ($Ref.is$Ref(value)) {
        // Skip this $ref if we've already inventoried it
        if (!inventory.some(function(i) { return i.parent === obj && i.key === key; })) {
          inventory$Ref(obj, key, path, keyPathFromRoot, inventory, $refs, options);
        }
      }
      else {
        crawl(value, keyPath, keyPathFromRoot, inventory, $refs, options);
      }
    });
  }
}

/**
 * Inventories the given JSON Reference (i.e. records detailed information about it so we can
 * optimize all $refs in the schema), and then crawls the resolved value.
 *
 * @param {object} $refParent - The object that contains a JSON Reference as one of its keys
 * @param {string} $refKey - The key in `$refParent` that is a JSON Reference
 * @param {string} path - The full path of the JSON Reference at `$refKey`, possibly with a JSON Pointer in the hash
 * @param {string} pathFromRoot - The path of the JSON Reference at `$refKey`, from the schema root
 * @param {object[]} inventory - An array of already-inventoried $ref pointers
 * @param {$Refs} $refs
 * @param {$RefParserOptions} options
 */
function inventory$Ref($refParent, $refKey, path, pathFromRoot, inventory, $refs, options) {
  var $ref = $refParent[$refKey];
  var $refPath = url.resolve(path, $ref.$ref);
  var pointer = $refs._resolve($refPath, options);
  var depth = Pointer.parse(pathFromRoot).length;
  var file = util.path.stripHash(pointer.path);
  var hash = util.path.getHash(pointer.path);
  var external = file !== $refs._basePath;
  var extended = Object.keys($ref).length > 1;

  inventory.push({
    $ref: $ref,                   // The JSON Reference (e.g. {$ref: string})
    parent: $refParent,           // The object that contains this $ref pointer
    key: $refKey,                 // The key in `parent` that is the $ref pointer
    pathFromRoot: pathFromRoot,   // The path to the $ref pointer, from the JSON Schema root
    depth: depth,                 // How far from the JSON Schema root is this $ref pointer?
    file: file,                   // The file that the $ref pointer resolves to
    hash: hash,                   // The hash within `file` that the $ref pointer resolves to
    value: pointer.value,         // The resolved value of the $ref pointer
    circular: pointer.circular,   // Is this $ref pointer DIRECTLY circular? (i.e. it references itself)
    extended: extended,           // Does this $ref extend its resolved value? (i.e. it has extra properties, in addition to "$ref")
    external: external            // Does this $ref pointer point to a file other than the main JSON Schema file?
  });

  // Recursively crawl the resolved value
  crawl(pointer.value, pointer.path, pathFromRoot, inventory, $refs, options);
}

/**
 * Re-maps every $ref pointer, so that they're all relative to the root of the JSON Schema.
 * Each referenced value is dereferenced EXACTLY ONCE.  All subsequent references to the same
 * value are re-mapped to point to the first reference.
 *
 * @example:
 *  {
 *    first: { $ref: somefile.json#/some/part },
 *    second: { $ref: somefile.json#/another/part },
 *    third: { $ref: somefile.json },
 *    fourth: { $ref: somefile.json#/some/part/sub/part }
 *  }
 *
 * In this example, there are four references to the same file, but since the third reference points
 * to the ENTIRE file, that's the only one we need to dereference.  The other three can just be
 * remapped to point inside the third one.
 *
 * On the other hand, if the third reference DIDN'T exist, then the first and second would both need
 * to be dereferenced, since they point to different parts of the file. The fourth reference does NOT
 * need to be dereferenced, because it can be remapped to point inside the first one.
 *
 * @param {object[]} inventory
 */
function remap(inventory) {
  // Group & sort all the $ref pointers, so they're in the order that we need to dereference/remap them
  inventory.sort(function(a, b) {
    if (a.file !== b.file) {
      return a.file < b.file ? -1 : +1;   // Group all the $refs that point to the same file
    }
    else if (a.hash !== b.hash) {
      return a.hash < b.hash ? -1 : +1;   // Group all the $refs that point to the same part of the file
    }
    else if (a.circular !== b.circular) {
      return a.circular ? -1 : +1;        // If the $ref points to itself, then sort it higher than other $refs that point to this $ref
    }
    else if (a.extended !== b.extended) {
      return a.extended ? +1 : -1;        // If the $ref extends the resolved value, then sort it lower than other $refs that don't extend the value
    }
    else if (a.depth !== b.depth) {
      return a.depth - b.depth;           // Sort $refs by how close they are to the JSON Schema root
    }
    else {
      // If all else is equal, use the $ref that's in the "definitions" property
      return b.pathFromRoot.lastIndexOf('/definitions') - a.pathFromRoot.lastIndexOf('/definitions');
    }
  });

  var file, hash, pathFromRoot;
  inventory.forEach(function(i) {
    util.debug('Re-mapping $ref pointer "%s" at %s', i.$ref.$ref, i.pathFromRoot);

    if (!i.external) {
      // This $ref already resolves to the main JSON Schema file
      i.$ref.$ref = i.hash;
    }
    else if (i.file !== file || i.hash.indexOf(hash) !== 0) {
      // We've moved to a new file or new hash
      file = i.file;
      hash = i.hash;
      pathFromRoot = i.pathFromRoot;

      // This is the first $ref to point to this value, so dereference the value.
      // Any other $refs that point to the same value will point to this $ref instead
      i.$ref = i.parent[i.key] = util.dereference(i.$ref, i.value);

      if (i.circular) {
        // This $ref points to itself
        i.$ref.$ref = i.pathFromRoot;
      }
    }
    else {
      // This $ref points to the same value as the prevous $ref
      i.$ref.$ref = Pointer.join(pathFromRoot, Pointer.parse(i.hash));
    }

    util.debug('    new value: %s', (i.$ref && i.$ref.$ref) ? i.$ref.$ref : '[object Object]');
  });
}

},{"./pointer":8,"./ref":11,"./util":14,"url":91}],2:[function(require,module,exports){
'use strict';

var $Ref    = require('./ref'),
    Pointer = require('./pointer'),
    util    = require('./util'),
    ono     = require('ono'),
    url     = require('url');

module.exports = dereference;

/**
 * Crawls the JSON schema, finds all JSON references, and dereferences them.
 * This method mutates the JSON schema object, replacing JSON references with their resolved value.
 *
 * @param {$RefParser} parser
 * @param {$RefParserOptions} options
 */
function dereference(parser, options) {
  util.debug('Dereferencing $ref pointers in %s', parser.$refs._basePath);
  parser.$refs.circular = false;
  crawl(parser.schema, parser.$refs._basePath, '#', [], parser.$refs, options);
}

/**
 * Recursively crawls the given value, and dereferences any JSON references.
 *
 * @param {*} obj - The value to crawl. If it's not an object or array, it will be ignored.
 * @param {string} path - The full path of `obj`, possibly with a JSON Pointer in the hash
 * @param {string} pathFromRoot - The path of `obj` from the schema root
 * @param {object[]} parents - An array of the parent objects that have already been dereferenced
 * @param {$Refs} $refs
 * @param {$RefParserOptions} options
 * @returns {boolean} - Returns true if a circular reference was found
 */
function crawl(obj, path, pathFromRoot, parents, $refs, options) {
  var isCircular = false;

  if (obj && typeof obj === 'object') {
    parents.push(obj);

    Object.keys(obj).forEach(function(key) {
      var keyPath = Pointer.join(path, key);
      var keyPathFromRoot = Pointer.join(pathFromRoot, key);
      var value = obj[key];
      var circular = false;

      if ($Ref.isAllowed$Ref(value, options)) {
        var dereferenced = dereference$Ref(value, keyPath, keyPathFromRoot, parents, $refs, options);
        circular = dereferenced.circular;
        obj[key] = dereferenced.value;
      }
      else {
        if (parents.indexOf(value) === -1) {
          circular = crawl(value, keyPath, keyPathFromRoot, parents, $refs, options);
        }
        else {
          circular = foundCircularReference(keyPath, $refs, options);
        }
      }

      // Set the "isCircular" flag if this or any other property is circular
      isCircular = isCircular || circular;
    });

    parents.pop();
  }
  return isCircular;
}

/**
 * Dereferences the given JSON Reference, and then crawls the resulting value.
 *
 * @param {{$ref: string}} $ref - The JSON Reference to resolve
 * @param {string} path - The full path of `$ref`, possibly with a JSON Pointer in the hash
 * @param {string} pathFromRoot - The path of `$ref` from the schema root
 * @param {object[]} parents - An array of the parent objects that have already been dereferenced
 * @param {$Refs} $refs
 * @param {$RefParserOptions} options
 * @returns {object}
 */
function dereference$Ref($ref, path, pathFromRoot, parents, $refs, options) {
  util.debug('Dereferencing $ref pointer "%s" at %s', $ref.$ref, path);

  var $refPath = url.resolve(path, $ref.$ref);
  var pointer = $refs._resolve($refPath, options);

  // Check for circular references
  var directCircular = pointer.circular;
  var circular = directCircular || parents.indexOf(pointer.value) !== -1;
  circular && foundCircularReference(path, $refs, options);

  // Dereference the JSON reference
  var dereferencedValue = util.dereference($ref, pointer.value);

  // Crawl the dereferenced value (unless it's circular)
  if (!circular) {
    // If the `crawl` method returns true, then dereferenced value is circular
    circular = crawl(dereferencedValue, pointer.path, pathFromRoot, parents, $refs, options);
  }

  if (circular && !directCircular && options.$refs.circular === 'ignore') {
    // The user has chosen to "ignore" circular references, so don't change the value
    dereferencedValue = $ref;
  }

  if (directCircular) {
    // The pointer is a DIRECT circular reference (i.e. it references itself).
    // So replace the $ref path with the absolute path from the JSON Schema root
    dereferencedValue.$ref = pathFromRoot;
  }

  return {
    circular: circular,
    value: dereferencedValue
  };
}

/**
 * Called when a circular reference is found.
 * It sets the {@link $Refs#circular} flag, and throws an error if options.$refs.circular is false.
 *
 * @param {string} keyPath - The JSON Reference path of the circular reference
 * @param {$Refs} $refs
 * @param {$RefParserOptions} options
 * @returns {boolean} - always returns true, to indicate that a circular reference was found
 */
function foundCircularReference(keyPath, $refs, options) {
  $refs.circular = true;
  if (!options.$refs.circular) {
    throw ono.reference('Circular $ref pointer found at %s', keyPath);
  }
  return true;
}

},{"./pointer":8,"./ref":11,"./util":14,"ono":54,"url":91}],3:[function(require,module,exports){
(function (Buffer){
'use strict';

var http    = require('http'),
    https   = require('https'),
    url     = require('url'),
    util    = require('./util'),
    Promise = require('./promise'),
    ono     = require('ono');

module.exports = download;

/**
 * Downloads the given file.
 *
 * @param {Url|string} u - The url to download (can be a parsed {@link Url} object)
 * @param {$RefParserOptions} options
 * @param {number} [redirects] - The redirect URLs that have already been followed
 *
 * @returns {Promise<Buffer>}
 * The promise resolves with the raw downloaded data, or rejects if there is an HTTP error.
 */
function download(u, options, redirects) {
  return new Promise(function(resolve, reject) {
    u = url.parse(u);
    redirects = redirects || [];
    redirects.push(u.href);

    get(u, options)
      .then(function(res) {
        if (res.statusCode >= 400) {
          throw ono({status: res.statusCode}, 'HTTP ERROR %d', res.statusCode);
        }
        else if (res.statusCode >= 300) {
          if (redirects.length > options.http.redirects) {
            reject(ono({status: res.statusCode}, 'Error downloading %s. \nToo many redirects: \n  %s',
              redirects[0], redirects.join(' \n  ')));
          }
          else if (!res.headers.location) {
            throw ono({status: res.statusCode}, 'HTTP %d redirect with no location header', res.statusCode);
          }
          else {
            util.debug('HTTP %d redirect %s -> %s', res.statusCode, u.href, res.headers.location);
            var redirectTo = url.resolve(u, res.headers.location);
            download(redirectTo, options, redirects).then(resolve, reject);
          }
        }
        else if (res.statusCode === 204 && !options.allow.empty) {
          throw ono({status: 204}, 'HTTP 204 (No Content)');
        }
        else {
          resolve(res.body || new Buffer(0));
        }
      })
      .catch(function(err) {
        reject(ono(err, 'Error downloading', u.href));
      });
  });
}

/**
 * Sends an HTTP GET request.
 *
 * @param {Url} u - A parsed {@link Url} object
 * @param {$RefParserOptions} options
 *
 * @returns {Promise<Response>}
 * The promise resolves with the HTTP Response object.
 */
function get(u, options) {
  return new Promise(function(resolve, reject) {
    util.debug('GET', u.href);

    var protocol = u.protocol === 'https:' ? https : http;
    var req = protocol.get({
      hostname: u.hostname,
      port: u.port,
      path: u.path,
      auth: u.auth,
      headers: options.http.headers,
      withCredentials: options.http.withCredentials
    });

    if (typeof req.setTimeout === 'function') {
      req.setTimeout(options.http.timeout);
    }

    req.on('timeout', function() {
      req.abort();
    });

    req.on('error', reject);

    req.once('response', function(res) {
      res.body = new Buffer(0);

      res.on('data', function(data) {
        res.body = Buffer.concat([res.body, new Buffer(data)]);
      });

      res.on('error', reject);

      res.on('end', function() {
        resolve(res);
      });
    });
  });
}

}).call(this,require("buffer").Buffer)

},{"./promise":9,"./util":14,"buffer":57,"http":85,"https":62,"ono":54,"url":91}],4:[function(require,module,exports){
(function (Buffer){
'use strict';

var Promise     = require('./promise'),
    Options     = require('./options'),
    $Refs       = require('./refs'),
    $Ref        = require('./ref'),
    read        = require('./read'),
    resolve     = require('./resolve'),
    bundle      = require('./bundle'),
    dereference = require('./dereference'),
    util        = require('./util'),
    url         = require('url'),
    maybe       = require('call-me-maybe'),
    ono         = require('ono');

module.exports = $RefParser;
module.exports.YAML = require('./yaml');

/**
 * This class parses a JSON schema, builds a map of its JSON references and their resolved values,
 * and provides methods for traversing, manipulating, and dereferencing those references.
 *
 * @constructor
 */
function $RefParser() {
  /**
   * The parsed (and possibly dereferenced) JSON schema object
   *
   * @type {object}
   * @readonly
   */
  this.schema = null;

  /**
   * The resolved JSON references
   *
   * @type {$Refs}
   */
  this.$refs = new $Refs();
}

/**
 * Parses the given JSON schema.
 * This method does not resolve any JSON references.
 * It just reads a single file in JSON or YAML format, and parse it as a JavaScript object.
 *
 * @param {string|object} schema - The file path or URL of the JSON schema. Or a JSON schema object.
 * @param {$RefParserOptions} [options] - Options that determine how the schema is parsed
 * @param {function} [callback] - An error-first callback. The second parameter is the parsed JSON schema object.
 * @returns {Promise} - The returned promise resolves with the parsed JSON schema object.
 */
$RefParser.parse = function(schema, options, callback) {
  var Class = this; // eslint-disable-line consistent-this
  return new Class().parse(schema, options, callback);
};

/**
 * Parses the given JSON schema.
 * This method does not resolve any JSON references.
 * It just reads a single file in JSON or YAML format, and parse it as a JavaScript object.
 *
 * @param {string|object} schema - The file path or URL of the JSON schema. Or a JSON schema object.
 * @param {$RefParserOptions} [options] - Options that determine how the schema is parsed
 * @param {function} [callback] - An error-first callback. The second parameter is the parsed JSON schema object.
 * @returns {Promise} - The returned promise resolves with the parsed JSON schema object.
 */
$RefParser.prototype.parse = function(schema, options, callback) {
  var args = normalizeArgs(arguments);

  if (args.schema && typeof args.schema === 'object') {
    // The schema is an object, not a path/url
    this.schema = args.schema;
    this.$refs._basePath = '';
    var $ref = new $Ref(this.$refs, this.$refs._basePath);
    $ref.setValue(this.schema, args.options);

    return maybe(args.callback, Promise.resolve(this.schema));
  }

  if (!args.schema || typeof args.schema !== 'string') {
    var err = ono('Expected a file path, URL, or object. Got %s', args.schema);
    return maybe(args.callback, Promise.reject(err));
  }

  var me = this;

  // Resolve the absolute path of the schema
  args.schema = util.path.localPathToUrl(args.schema);
  args.schema = url.resolve(util.path.cwd(), args.schema);
  this.$refs._basePath = util.path.stripHash(args.schema);

  // Read the schema file/url
  return read(args.schema, this.$refs, args.options)
    .then(function(result) {
      var value = result.$ref.value;
      if (!value || typeof value !== 'object' || value instanceof Buffer) {
        throw ono.syntax('"%s" is not a valid JSON Schema', me.$refs._basePath);
      }
      else {
        me.schema = value;
        return maybe(args.callback, Promise.resolve(me.schema));
      }
    })
    .catch(function(e) {
      return maybe(args.callback, Promise.reject(e));
    });
};

/**
 * Parses the given JSON schema and resolves any JSON references, including references in
 * externally-referenced files.
 *
 * @param {string|object} schema - The file path or URL of the JSON schema. Or a JSON schema object.
 * @param {$RefParserOptions} [options] - Options that determine how the schema is parsed and resolved
 * @param {function} [callback]
 * - An error-first callback. The second parameter is a {@link $Refs} object containing the resolved JSON references
 *
 * @returns {Promise}
 * The returned promise resolves with a {@link $Refs} object containing the resolved JSON references
 */
$RefParser.resolve = function(schema, options, callback) {
  var Class = this; // eslint-disable-line consistent-this
  return new Class().resolve(schema, options, callback);
};

/**
 * Parses the given JSON schema and resolves any JSON references, including references in
 * externally-referenced files.
 *
 * @param {string|object} schema - The file path or URL of the JSON schema. Or a JSON schema object.
 * @param {$RefParserOptions} [options] - Options that determine how the schema is parsed and resolved
 * @param {function} [callback]
 * - An error-first callback. The second parameter is a {@link $Refs} object containing the resolved JSON references
 *
 * @returns {Promise}
 * The returned promise resolves with a {@link $Refs} object containing the resolved JSON references
 */
$RefParser.prototype.resolve = function(schema, options, callback) {
  var me = this;
  var args = normalizeArgs(arguments);

  return this.parse(args.schema, args.options)
    .then(function() {
      return resolve(me, args.options);
    })
    .then(function() {
      return maybe(args.callback, Promise.resolve(me.$refs));
    })
    .catch(function(err) {
      return maybe(args.callback, Promise.reject(err));
    });
};

/**
 * Parses the given JSON schema, resolves any JSON references, and bundles all external references
 * into the main JSON schema. This produces a JSON schema that only has *internal* references,
 * not any *external* references.
 *
 * @param {string|object} schema - The file path or URL of the JSON schema. Or a JSON schema object.
 * @param {$RefParserOptions} [options] - Options that determine how the schema is parsed, resolved, and dereferenced
 * @param {function} [callback] - An error-first callback. The second parameter is the bundled JSON schema object
 * @returns {Promise} - The returned promise resolves with the bundled JSON schema object.
 */
$RefParser.bundle = function(schema, options, callback) {
  var Class = this; // eslint-disable-line consistent-this
  return new Class().bundle(schema, options, callback);
};

/**
 * Parses the given JSON schema, resolves any JSON references, and bundles all external references
 * into the main JSON schema. This produces a JSON schema that only has *internal* references,
 * not any *external* references.
 *
 * @param {string|object} schema - The file path or URL of the JSON schema. Or a JSON schema object.
 * @param {$RefParserOptions} [options] - Options that determine how the schema is parsed, resolved, and dereferenced
 * @param {function} [callback] - An error-first callback. The second parameter is the bundled JSON schema object
 * @returns {Promise} - The returned promise resolves with the bundled JSON schema object.
 */
$RefParser.prototype.bundle = function(schema, options, callback) {
  var me = this;
  var args = normalizeArgs(arguments);

  return this.resolve(args.schema, args.options)
    .then(function() {
      bundle(me, args.options);
      return maybe(args.callback, Promise.resolve(me.schema));
    })
    .catch(function(err) {
      return maybe(args.callback, Promise.reject(err));
    });
};

/**
 * Parses the given JSON schema, resolves any JSON references, and dereferences the JSON schema.
 * That is, all JSON references are replaced with their resolved values.
 *
 * @param {string|object} schema - The file path or URL of the JSON schema. Or a JSON schema object.
 * @param {$RefParserOptions} [options] - Options that determine how the schema is parsed, resolved, and dereferenced
 * @param {function} [callback] - An error-first callback. The second parameter is the dereferenced JSON schema object
 * @returns {Promise} - The returned promise resolves with the dereferenced JSON schema object.
 */
$RefParser.dereference = function(schema, options, callback) {
  var Class = this; // eslint-disable-line consistent-this
  return new Class().dereference(schema, options, callback);
};

/**
 * Parses the given JSON schema, resolves any JSON references, and dereferences the JSON schema.
 * That is, all JSON references are replaced with their resolved values.
 *
 * @param {string|object} schema - The file path or URL of the JSON schema. Or a JSON schema object.
 * @param {$RefParserOptions} [options] - Options that determine how the schema is parsed, resolved, and dereferenced
 * @param {function} [callback] - An error-first callback. The second parameter is the dereferenced JSON schema object
 * @returns {Promise} - The returned promise resolves with the dereferenced JSON schema object.
 */
$RefParser.prototype.dereference = function(schema, options, callback) {
  var me = this;
  var args = normalizeArgs(arguments);

  return this.resolve(args.schema, args.options)
    .then(function() {
      dereference(me, args.options);
      return maybe(args.callback, Promise.resolve(me.schema));
    })
    .catch(function(err) {
      return maybe(args.callback, Promise.reject(err));
    });
};

/**
 * Normalizes the given arguments, accounting for optional args.
 *
 * @param {Arguments} args
 * @returns {object}
 */
function normalizeArgs(args) {
  var options = args[1], callback = args[2];
  if (typeof options === 'function') {
    callback = options;
    options = undefined;
  }
  if (!(options instanceof Options)) {
    options = new Options(options);
  }
  return {
    schema: args[0],
    options: options,
    callback: callback
  };
}

}).call(this,require("buffer").Buffer)

},{"./bundle":1,"./dereference":2,"./options":5,"./promise":9,"./read":10,"./ref":11,"./refs":12,"./resolve":13,"./util":14,"./yaml":15,"buffer":57,"call-me-maybe":16,"ono":54,"url":91}],5:[function(require,module,exports){
/* eslint lines-around-comment: [2, {beforeBlockComment: false}] */
'use strict';

module.exports = $RefParserOptions;

/**
 * Options that determine how JSON schemas are parsed, dereferenced, and cached.
 *
 * @param {object|$RefParserOptions} [options] - Overridden options
 * @constructor
 */
function $RefParserOptions(options) {
  /**
   * Determines what types of files can be parsed
   */
  this.allow = {
    /**
     * Are JSON files allowed?
     * If false, then all schemas must be in YAML format.
     * @type {boolean}
     */
    json: true,

    /**
     * Are YAML files allowed?
     * If false, then all schemas must be in JSON format.
     * @type {boolean}
     */
    yaml: true,

    /**
     * Are zero-byte files allowed?
     * If false, then an error will be thrown if a file is empty.
     * @type {boolean}
     */
    empty: true,

    /**
     * Can unknown file types be $referenced?
     * If true, then they will be parsed as Buffers (byte arrays).
     * If false, then an error will be thrown.
     * @type {boolean}
     */
    unknown: true
  };

  /**
   * Determines the types of JSON references that are allowed.
   */
  this.$refs = {
    /**
     * Allow JSON references to other parts of the same file?
     * @type {boolean}
     */
    internal: true,

    /**
     * Allow JSON references to external files/URLs?
     * @type {boolean}
     */
    external: true,

    /**
     * Allow circular (recursive) JSON references?
     * If false, then a {@link ReferenceError} will be thrown if a circular reference is found.
     * If "ignore", then circular references will not be dereferenced.
     * @type {boolean|string}
     */
    circular: true,

    /**
     * Overrides implementation of internal reader. Default implementation looks at $ref value and decides
     * whether it should use local file or URL reader.
     * @type {function|null}
     */
    read$Ref: null,

    /**
     * Overrides implementation of internal reader for local files.
     * @type {function|null}
     */
    read$RefFile: null,

    /**
     * Overrides implementation of internal reader for URLs.
     * @type {function|null}
     */
    read$RefUrl: null
  };

  /**
   * How long to cache files (in seconds).
   */
  this.cache = {
    /**
     * How long to cache local files, in seconds.
     * @type {number}
     */
    fs: 60, // 1 minute

    /**
     * How long to cache files downloaded via HTTP, in seconds.
     * @type {number}
     */
    http: 5 * 60, // 5 minutes

    /**
     * How long to cache files downloaded via HTTPS, in seconds.
     * @type {number}
     */
    https: 5 * 60 // 5 minutes
  };

  /**
   * HTTP request options
   */
  this.http = {
    /**
     * HTTP headers to send when downloading files.
     */
    headers: {},

    /**
     * HTTP request timeout (in milliseconds).
     */
    timeout: 5000,

    /**
     * The maximum number of HTTP redirects to follow.
     * To disable automatic following of redirects, set this to zero.
     */
    redirects: 5,

    /**
     * The `withCredentials` option of XMLHttpRequest.
     * Set this to `true` if you're downloading files from a CORS-enabled server that requires authentication
     */
    withCredentials: false,

  };

  merge(options, this);
}

/**
 * Fast, two-level object merge.
 *
 * @param {?object} src - The object to merge into dest
 * @param {object} dest - The object to be modified
 */
function merge(src, dest) {
  if (src) {
    var topKeys = Object.keys(src);
    for (var i = 0; i < topKeys.length; i++) {
      var topKey = topKeys[i];
      var srcChild = src[topKey];
      if (dest[topKey] === undefined) {
        dest[topKey] = srcChild;
      }
      else {
        var childKeys = Object.keys(srcChild);
        for (var j = 0; j < childKeys.length; j++) {
          var childKey = childKeys[j];
          var srcChildValue = srcChild[childKey];
          if (srcChildValue !== undefined) {
            dest[topKey][childKey] = srcChildValue;
          }
        }
      }
    }
  }
}

},{}],6:[function(require,module,exports){
(function (Buffer){
'use strict';

var YAML = require('./yaml'),
    util = require('./util'),
    ono  = require('ono');

module.exports = parse;

/**
 * Parses the given data as YAML, JSON, or a raw Buffer (byte array), depending on the options.
 *
 * @param {string|Buffer} data - The data to be parsed
 * @param {string} path - The file path or URL that `data` came from
 * @param {$RefParserOptions} options
 *
 * @returns {string|Buffer|object}
 * If `data` can be parsed as YAML or JSON, then the returned value is a JavaScript object.
 * Otherwise, the returned value is the raw string or Buffer that was passed in.
 */
function parse(data, path, options) {
  var parsed;

  try {
    if (options.allow.yaml) {
      util.debug('Parsing YAML file: %s', path);
      parsed = YAML.parse(data.toString());
      util.debug('    Parsed successfully');
    }
    else if (options.allow.json) {
      util.debug('Parsing JSON file: %s', path);
      parsed = JSON.parse(data.toString());
      util.debug('    Parsed successfully');
    }
    else {
      parsed = data;
    }
  }
  catch (e) {
    var ext = util.path.extname(path);
    if (options.allow.unknown && ['.json', '.yaml', '.yml'].indexOf(ext) === -1) {
      // It's not a YAML or JSON file, and unknown formats are allowed,
      // so ignore the parsing error and just return the raw data
      util.debug('    Unknown file format. Not parsed.');
      parsed = data;
    }
    else {
      throw ono.syntax(e, 'Error parsing "%s"', path);
    }
  }

  if (isEmpty(parsed) && !options.allow.empty) {
    throw ono.syntax('Error parsing "%s". \nParsed value is empty', path);
  }

  return parsed;
}

/**
 * Determines whether the parsed value is "empty".
 *
 * @param {*} value
 * @returns {boolean}
 */
function isEmpty(value) {
  return !value ||
    (typeof value === 'object' && Object.keys(value).length === 0) ||
    (typeof value === 'string' && value.trim().length === 0) ||
    (value instanceof Buffer && value.length === 0);
}

}).call(this,require("buffer").Buffer)

},{"./util":14,"./yaml":15,"buffer":57,"ono":54}],7:[function(require,module,exports){
(function (process){
'use strict';

var isWindows           = /^win/.test(process.platform),
    forwardSlashPattern = /\//g,
    protocolPattern     = /^([a-z0-9.+-]+):\/\//i;

// RegExp patterns to URL-encode special characters in local filesystem paths
var urlEncodePatterns = [
  /\?/g, '%3F',
  /\#/g, '%23',
  isWindows ? /\\/g : /\//, '/'
];

// RegExp patterns to URL-decode special characters for local filesystem paths
var urlDecodePatterns = [
  /\%23/g, '#',
  /\%24/g, '$',
  /\%26/g, '&',
  /\%2C/g, ',',
  /\%40/g, '@'
];

/**
 * Returns the current working directory (in Node) or the current page URL (in browsers).
 *
 * @returns {string}
 */
exports.cwd = function cwd() {
  return process.browser ? location.href : process.cwd() + '/';
};

/**
 * Determines whether the given path is a URL.
 *
 * @param   {string} path
 * @returns {boolean}
 */
exports.isUrl = function isUrl(path) {
  var protocol = protocolPattern.exec(path);
  if (protocol) {
    protocol = protocol[1].toLowerCase();
    return protocol !== 'file';
  }
  return false;
};

/**
 * If the given path is a local filesystem path, it is converted to a URL.
 *
 * @param {string} path
 * @returns {string}
 */
exports.localPathToUrl = function localPathToUrl(path) {
  if (!process.browser && !exports.isUrl(path)) {
    // Manually encode characters that are not encoded by `encodeURI`
    for (var i = 0; i < urlEncodePatterns.length; i += 2) {
      path = path.replace(urlEncodePatterns[i], urlEncodePatterns[i + 1]);
    }
    path = encodeURI(path);
  }
  return path;
};

/**
 * Converts a URL to a local filesystem path
 *
 * @param {string} url
 * @param {boolean} [keepFileProtocol] - If true, then "file://" will NOT be stripped
 * @returns {string}
 */
exports.urlToLocalPath = function urlToLocalPath(url, keepFileProtocol) {
  // Decode URL-encoded characters
  url = decodeURI(url);

  // Manually decode characters that are not decoded by `decodeURI`
  for (var i = 0; i < urlDecodePatterns.length; i += 2) {
    url = url.replace(urlDecodePatterns[i], urlDecodePatterns[i + 1]);
  }

  // Handle "file://" URLs
  var isFileUrl = url.substr(0, 7).toLowerCase() === 'file://';
  if (isFileUrl) {
    var protocol = 'file:///';

    // Remove the third "/" if there is one
    var path = url[7] === '/' ? url.substr(8) : url.substr(7);

    if (isWindows && path[1] === '/') {
      // insert a colon (":") after the drive letter on Windows
      path = path[0] + ':' + path.substr(1);
    }

    if (keepFileProtocol) {
      url = protocol + path;
    }
    else {
      isFileUrl = false;
      url = isWindows ? path : '/' + path;
    }
  }

  // Format path separators on Windows
  if (isWindows && !isFileUrl) {
    url = url.replace(forwardSlashPattern, '\\');
  }

  return url;
};

/**
 * Returns the hash (URL fragment), of the given path.
 * If there is no hash, then the root hash ("#") is returned.
 *
 * @param   {string} path
 * @returns {string}
 */
exports.getHash = function getHash(path) {
  var hashIndex = path.indexOf('#');
  if (hashIndex >= 0) {
    return path.substr(hashIndex);
  }
  return '#';
};

/**
 * Removes the hash (URL fragment), if any, from the given path.
 *
 * @param   {string} path
 * @returns {string}
 */
exports.stripHash = function stripHash(path) {
  var hashIndex = path.indexOf('#');
  if (hashIndex >= 0) {
    path = path.substr(0, hashIndex);
  }
  return path;
};

/**
 * Returns the file extension of the given path.
 *
 * @param   {string} path
 * @returns {string}
 */
exports.extname = function extname(path) {
  var lastDot = path.lastIndexOf('.');
  if (lastDot >= 0) {
    return path.substr(lastDot).toLowerCase();
  }
  return '';
};

}).call(this,require('_process'))

},{"_process":66}],8:[function(require,module,exports){
'use strict';

module.exports = Pointer;

var $Ref         = require('./ref'),
    util         = require('./util'),
    url          = require('url'),
    ono          = require('ono'),
    slashes      = /\//g,
    tildes       = /~/g,
    escapedSlash = /~1/g,
    escapedTilde = /~0/g;

/**
 * This class represents a single JSON pointer and its resolved value.
 *
 * @param {$Ref} $ref
 * @param {string} path
 * @constructor
 */
function Pointer($ref, path) {
  /**
   * The {@link $Ref} object that contains this {@link Pointer} object.
   * @type {$Ref}
   */
  this.$ref = $ref;

  /**
   * The file path or URL, containing the JSON pointer in the hash.
   * This path is relative to the path of the main JSON schema file.
   * @type {string}
   */
  this.path = path;

  /**
   * The value of the JSON pointer.
   * Can be any JSON type, not just objects. Unknown file types are represented as Buffers (byte arrays).
   * @type {?*}
   */
  this.value = undefined;

  /**
   * Indicates whether the pointer references itself.
   * @type {boolean}
   */
  this.circular = false;
}

/**
 * Resolves the value of a nested property within the given object.
 *
 * @param {*} obj - The object that will be crawled
 * @param {$RefParserOptions} [options]
 *
 * @returns {Pointer}
 * Returns a JSON pointer whose {@link Pointer#value} is the resolved value.
 * If resolving this value required resolving other JSON references, then
 * the {@link Pointer#$ref} and {@link Pointer#path} will reflect the resolution path
 * of the resolved value.
 */
Pointer.prototype.resolve = function(obj, options) {
  var tokens = Pointer.parse(this.path);

  // Crawl the object, one token at a time
  this.value = obj;
  for (var i = 0; i < tokens.length; i++) {
    if (resolveIf$Ref(this, options)) {
      // The $ref path has changed, so append the remaining tokens to the path
      this.path = Pointer.join(this.path, tokens.slice(i));
    }

    var token = tokens[i];
    if (this.value[token] === undefined) {
      throw ono.syntax('Error resolving $ref pointer "%s". \nToken "%s" does not exist.', this.path, token);
    }
    else {
      this.value = this.value[token];
    }
  }

  // Resolve the final value
  resolveIf$Ref(this, options);
  return this;
};

/**
 * Sets the value of a nested property within the given object.
 *
 * @param {*} obj - The object that will be crawled
 * @param {*} value - the value to assign
 * @param {$RefParserOptions} [options]
 *
 * @returns {*}
 * Returns the modified object, or an entirely new object if the entire object is overwritten.
 */
Pointer.prototype.set = function(obj, value, options) {
  var tokens = Pointer.parse(this.path);
  var token;

  if (tokens.length === 0) {
    // There are no tokens, replace the entire object with the new value
    this.value = value;
    return value;
  }

  // Crawl the object, one token at a time
  this.value = obj;
  for (var i = 0; i < tokens.length - 1; i++) {
    resolveIf$Ref(this, options);

    token = tokens[i];
    if (this.value && this.value[token] !== undefined) {
      // The token exists
      this.value = this.value[token];
    }
    else {
      // The token doesn't exist, so create it
      this.value = setValue(this, token, {});
    }
  }

  // Set the value of the final token
  resolveIf$Ref(this, options);
  token = tokens[tokens.length - 1];
  setValue(this, token, value);

  // Return the updated object
  return obj;
};

/**
 * Parses a JSON pointer (or a path containing a JSON pointer in the hash)
 * and returns an array of the pointer's tokens.
 * (e.g. "schema.json#/definitions/person/name" => ["definitions", "person", "name"])
 *
 * The pointer is parsed according to RFC 6901
 * {@link https://tools.ietf.org/html/rfc6901#section-3}
 *
 * @param {string} path
 * @returns {string[]}
 */
Pointer.parse = function(path) {
  // Get the JSON pointer from the path's hash
  var pointer = util.path.getHash(path).substr(1);

  // If there's no pointer, then there are no tokens,
  // so return an empty array
  if (!pointer) {
    return [];
  }

  // Split into an array
  pointer = pointer.split('/');

  // Decode each part, according to RFC 6901
  for (var i = 0; i < pointer.length; i++) {
    pointer[i] = decodeURI(pointer[i].replace(escapedSlash, '/').replace(escapedTilde, '~'));
  }

  if (pointer[0] !== '') {
    throw ono.syntax('Invalid $ref pointer "%s". Pointers must begin with "#/"', pointer);
  }

  return pointer.slice(1);
};

/**
 * Creates a JSON pointer path, by joining one or more tokens to a base path.
 *
 * @param {string} base - The base path (e.g. "schema.json#/definitions/person")
 * @param {string|string[]} tokens - The token(s) to append (e.g. ["name", "first"])
 * @returns {string}
 */
Pointer.join = function(base, tokens) {
  // Ensure that the base path contains a hash
  if (base.indexOf('#') === -1) {
    base += '#';
  }

  // Append each token to the base path
  tokens = Array.isArray(tokens) ? tokens : [tokens];
  for (var i = 0; i < tokens.length; i++) {
    var token = tokens[i];
    // Encode the token, according to RFC 6901
    base += '/' + encodeURI(token.replace(tildes, '~0').replace(slashes, '~1'));
  }

  return base;
};

/**
 * If the given pointer's {@link Pointer#value} is a JSON reference,
 * then the reference is resolved and {@link Pointer#value} is replaced with the resolved value.
 * In addition, {@link Pointer#path} and {@link Pointer#$ref} are updated to reflect the
 * resolution path of the new value.
 *
 * @param {Pointer} pointer
 * @param {$RefParserOptions} [options]
 * @returns {boolean} - Returns `true` if the resolution path changed
 */
function resolveIf$Ref(pointer, options) {
  // Is the value a JSON reference? (and allowed?)

  if ($Ref.isAllowed$Ref(pointer.value, options)) {
    var $refPath = url.resolve(pointer.path, pointer.value.$ref);

    if ($refPath === pointer.path) {
      // The value is a reference to itself, so there's nothing to do.
      pointer.circular = true;
    }
    else {
      var resolved = pointer.$ref.$refs._resolve($refPath);

      if (Object.keys(pointer.value).length === 1) {
        // Resolve the reference
        pointer.$ref = resolved.$ref;
        pointer.path = resolved.path;
        pointer.value = resolved.value;
      }
      else {
        // This JSON reference has additional properties (other than "$ref"),
        // so it "extends" the resolved value, rather than simply pointing to it.
        pointer.value = util.dereference(pointer.value, resolved.value);
      }

      return true;
    }
  }
}

/**
 * Sets the specified token value of the {@link Pointer#value}.
 *
 * The token is evaluated according to RFC 6901.
 * {@link https://tools.ietf.org/html/rfc6901#section-4}
 *
 * @param {Pointer} pointer - The JSON Pointer whose value will be modified
 * @param {string} token - A JSON Pointer token that indicates how to modify `obj`
 * @param {*} value - The value to assign
 * @returns {*} - Returns the assigned value
 */
function setValue(pointer, token, value) {
  if (pointer.value && typeof pointer.value === 'object') {
    if (token === '-' && Array.isArray(pointer.value)) {
      pointer.value.push(value);
    }
    else {
      pointer.value[token] = value;
    }
  }
  else {
    throw ono.syntax('Error assigning $ref pointer "%s". \nCannot set "%s" of a non-object.', pointer.path, token);
  }
  return value;
}

},{"./ref":11,"./util":14,"ono":54,"url":91}],9:[function(require,module,exports){
'use strict';

/** @type {Promise} **/
module.exports = typeof Promise === 'function' ? Promise : require('es6-promise').Promise;

},{"es6-promise":20}],10:[function(require,module,exports){
(function (process){
'use strict';

var fs       = require('fs'),
    download = require('./download'),
    parse    = require('./parse'),
    util     = require('./util'),
    $Ref     = require('./ref'),
    Promise  = require('./promise'),
    url      = require('url'),
    ono      = require('ono');

module.exports = read;

/**
 * Reads the specified file path or URL, possibly from cache.
 *
 * @param {string} path - This path MUST already be resolved, since `read` doesn't know the resolution context
 * @param {$Refs} $refs
 * @param {$RefParserOptions} options
 *
 * @returns {Promise}
 * The promise resolves with an object that contains a {@link $Ref}
 * and a flag indicating whether the {@link $Ref} came from cache or not.
 */
function read(path, $refs, options) {
  try {
    // Remove the URL fragment, if any
    path = util.path.stripHash(path);
    util.debug('Reading %s', path);

    // Return from cache, if possible
    var $ref = $refs._get$Ref(path);
    if ($ref && !$ref.isExpired()) {
      util.debug('    cached from %s', $ref.pathType);
      return Promise.resolve({
        $ref: $ref,
        cached: true
      });
    }

    // Add a placeholder $ref to the cache, so we don't read this URL multiple times
    $ref = new $Ref($refs, path);

    // Read and return the $ref
    return read$Ref($ref, options);
  }
  catch (e) {
    return Promise.reject(e);
  }
}

/**
 * Reads the specified file path or URL and updates the given {@link $Ref} accordingly.
 *
 * @param {$Ref} $ref - The {@link $Ref} to read and update
 * @param {$RefParserOptions} options
 *
 * @returns {Promise}
 * The promise resolves with the updated {@link $Ref} object (the same instance that was passed in)
 */
function read$Ref($ref, options) {
  try {
    var promise = options.$refs.external && (
      (options.$refs.read$Ref     && options.$refs.read$Ref($ref, options)) ||
      (options.$refs.read$RefFile || read$RefFile)($ref, options) ||
      (options.$refs.read$RefUrl  || read$RefUrl)($ref, options)
    );

    if (promise) {
      return promise
        .then(function(data) {
          // Update the $ref with the parsed file contents
          var value = parse(data, $ref.path, options);
          $ref.setValue(value, options);

          return {
            $ref: $ref,
            cached: false
          };
        });
    }
    else {
      return Promise.reject(ono.syntax('Unable to resolve $ref pointer "%s"', $ref.path));
    }
  }
  catch (e) {
    return Promise.reject(e);
  }
}

/**
 * If the given {@link $Ref#path} is a local file, then the file is read
 * and {@link $Ref#type} is set to "fs".
 *
 * @param {$Ref} $ref - The {@link $Ref} to read and update
 * @param {$RefParserOptions} options
 *
 * @returns {Promise|undefined}
 * Returns a promise if {@link $Ref#path} is a local file.
 * The promise resolves with the raw file contents.
 */
function read$RefFile($ref, options) {
  if (process.browser || util.path.isUrl($ref.path)) {
    return;
  }

  $ref.pathType = 'fs';
  return new Promise(function(resolve, reject) {
    var file;
    try {
      file = util.path.urlToLocalPath($ref.path);
    }
    catch (err) {
      reject(ono.uri(err, 'Malformed URI: %s', $ref.path));
    }

    util.debug('Opening file: %s', file);

    try {
      fs.readFile(file, function(err, data) {
        if (err) {
          reject(ono(err, 'Error opening file "%s"', $ref.path));
        }
        else {
          resolve(data);
        }
      });
    }
    catch (err) {
      reject(ono(err, 'Error opening file "%s"', file));
    }
  });
}

/**
 * If the given {@link $Ref#path} is a URL, then the file is downloaded
 * and {@link $Ref#type} is set to "http" or "https".
 *
 * @param {$Ref} $ref - The {@link $Ref} to read and update
 * @param {$RefParserOptions} options
 *
 * @returns {Promise|undefined}
 * Returns a promise if {@link $Ref#path} is a URL.
 * The promise resolves with the raw file contents.
 */
function read$RefUrl($ref, options) {
  var u = url.parse($ref.path);

  if (process.browser && !u.protocol) {
    // Use the protocol of the current page
    u.protocol = url.parse(location.href).protocol;
  }

  if (u.protocol === 'http:') {
    $ref.pathType = 'http';
    return download(u, options);
  }
  else if (u.protocol === 'https:') {
    $ref.pathType = 'https';
    return download(u, options);
  }
}

}).call(this,require('_process'))

},{"./download":3,"./parse":6,"./promise":9,"./ref":11,"./util":14,"_process":66,"fs":55,"ono":54,"url":91}],11:[function(require,module,exports){
'use strict';

module.exports = $Ref;

var Pointer = require('./pointer'),
    util    = require('./util');

/**
 * This class represents a single JSON reference and its resolved value.
 *
 * @param {$Refs} $refs
 * @param {string} path
 * @constructor
 */
function $Ref($refs, path) {
  path = util.path.stripHash(path);

  // Add this $ref to its parent collection
  $refs._$refs[path] = this;

  /**
   * The {@link $Refs} object that contains this {@link $Ref} object.
   * @type {$Refs}
   */
  this.$refs = $refs;

  /**
   * The file path or URL of the referenced file.
   * This path is relative to the path of the main JSON schema file.
   *
   * This path does NOT contain document fragments (JSON pointers). It always references an ENTIRE file.
   * Use methods such as {@link $Ref#get}, {@link $Ref#resolve}, and {@link $Ref#exists} to get
   * specific JSON pointers within the file.
   *
   * @type {string}
   */
  this.path = path;

  /**
   * Indicates the type of {@link $Ref#path} (e.g. "fs", "http", or "https")
   * @type {?string}
   */
  this.pathType = undefined;

  /**
   * The resolved value of the JSON reference.
   * Can be any JSON type, not just objects. Unknown file types are represented as Buffers (byte arrays).
   * @type {?*}
   */
  this.value = undefined;

  /**
   * The date/time that the cached value will expire.
   * @type {?Date}
   */
  this.expires = undefined;
}

/**
 * Determines whether the {@link $Ref#value} has expired.
 *
 * @returns {boolean}
 */
$Ref.prototype.isExpired = function() {
  return !!(this.expires && this.expires <= new Date());
};

/**
 * Immediately expires the {@link $Ref#value}.
 */
$Ref.prototype.expire = function() {
  this.expires = new Date();
};

/**
 * Sets the {@link $Ref#value} and renews the cache expiration.
 *
 * @param {*} value
 * @param {$RefParserOptions} options
 */
$Ref.prototype.setValue = function(value, options) {
  this.value = value;

  // Extend the cache expiration
  var cacheDuration = options.cache[this.pathType];
  if (cacheDuration > 0) {
    var expires = Date.now() + (cacheDuration * 1000);
    this.expires = new Date(expires);
  }
};

/**
 * Determines whether the given JSON reference exists within this {@link $Ref#value}.
 *
 * @param {string} path - The full path being resolved, optionally with a JSON pointer in the hash
 * @returns {boolean}
 */
$Ref.prototype.exists = function(path) {
  try {
    this.resolve(path);
    return true;
  }
  catch (e) {
    return false;
  }
};

/**
 * Resolves the given JSON reference within this {@link $Ref#value} and returns the resolved value.
 *
 * @param {string} path - The full path being resolved, optionally with a JSON pointer in the hash
 * @param {$RefParserOptions} options
 * @returns {*} - Returns the resolved value
 */
$Ref.prototype.get = function(path, options) {
  return this.resolve(path, options).value;
};

/**
 * Resolves the given JSON reference within this {@link $Ref#value}.
 *
 * @param {string} path - The full path being resolved, optionally with a JSON pointer in the hash
 * @param {$RefParserOptions} options
 * @returns {Pointer}
 */
$Ref.prototype.resolve = function(path, options) {
  var pointer = new Pointer(this, path);
  return pointer.resolve(this.value, options);
};

/**
 * Sets the value of a nested property within this {@link $Ref#value}.
 * If the property, or any of its parents don't exist, they will be created.
 *
 * @param {string} path - The full path of the property to set, optionally with a JSON pointer in the hash
 * @param {*} value - The value to assign
 * @param {$RefParserOptions} options
 */
$Ref.prototype.set = function(path, value, options) {
  var pointer = new Pointer(this, path);
  this.value = pointer.set(this.value, value, options);
};

/**
 * Determines whether the given value is a JSON reference.
 *
 * @param {*} value - The value to inspect
 * @returns {boolean}
 */
$Ref.is$Ref = function(value) {
  return value && typeof value === 'object' && typeof value.$ref === 'string' && value.$ref.length > 0;
};

/**
 * Determines whether the given value is an external JSON reference.
 *
 * @param {*} value - The value to inspect
 * @returns {boolean}
 */
$Ref.isExternal$Ref = function(value) {
  return $Ref.is$Ref(value) && value.$ref[0] !== '#';
};

/**
 * Determines whether the given value is a JSON reference, and whether it is allowed by the options.
 * For example, if it references an external file, then options.$refs.external must be true.
 *
 * @param {*} value - The value to inspect
 * @param {$RefParserOptions} options
 * @returns {boolean}
 */
$Ref.isAllowed$Ref = function(value, options) {
  if ($Ref.is$Ref(value)) {
    if (value.$ref[0] === '#') {
      if (options.$refs.internal) {
        return true;
      }
    }
    else if (options.$refs.external) {
      return true;
    }
  }
};

},{"./pointer":8,"./util":14}],12:[function(require,module,exports){
'use strict';

var Options = require('./options'),
    util    = require('./util'),
    url     = require('url'),
    ono     = require('ono');

module.exports = $Refs;

/**
 * This class is a map of JSON references and their resolved values.
 */
function $Refs() {
  /**
   * Indicates whether the schema contains any circular references.
   *
   * @type {boolean}
   */
  this.circular = false;

  /**
   * The file path or URL of the main JSON schema file.
   * This will be empty if the schema was passed as an object rather than a path.
   *
   * @type {string}
   * @protected
   */
  this._basePath = '';

  /**
   * A map of paths/urls to {@link $Ref} objects
   *
   * @type {object}
   * @protected
   */
  this._$refs = {};
}

/**
 * Returns the paths of all the files/URLs that are referenced by the JSON schema,
 * including the schema itself.
 *
 * @param {...string|string[]} [types] - Only return paths of the given types ("fs", "http", "https")
 * @returns {string[]}
 */
$Refs.prototype.paths = function(types) {
  var paths = getPaths(this._$refs, arguments);
  return paths.map(function(path) {
    return path.decoded;
  });
};

/**
 * Returns the map of JSON references and their resolved values.
 *
 * @param {...string|string[]} [types] - Only return references of the given types ("fs", "http", "https")
 * @returns {object}
 */
$Refs.prototype.values = function(types) {
  var $refs = this._$refs;
  var paths = getPaths($refs, arguments);
  return paths.reduce(function(obj, path) {
    obj[path.decoded] = $refs[path.encoded].value;
    return obj;
  }, {});
};

/**
 * Returns a POJO (plain old JavaScript object) for serialization as JSON.
 *
 * @returns {object}
 */
$Refs.prototype.toJSON = $Refs.prototype.values;

/**
 * Determines whether the given JSON reference has expired.
 * Returns true if the reference does not exist.
 *
 * @param {string} path - The path being resolved, optionally with a JSON pointer in the hash
 * @returns {boolean}
 */
$Refs.prototype.isExpired = function(path) {
  var $ref = this._get$Ref(path);
  return $ref === undefined || $ref.isExpired();
};

/**
 * Immediately expires the given JSON reference.
 * If the reference does not exist, nothing happens.
 *
 * @param {string} path - The path being resolved, optionally with a JSON pointer in the hash
 */
$Refs.prototype.expire = function(path) {
  var $ref = this._get$Ref(path);
  if ($ref) {
    $ref.expire();
  }
};

/**
 * Determines whether the given JSON reference exists.
 *
 * @param {string} path - The path being resolved, optionally with a JSON pointer in the hash
 * @returns {boolean}
 */
$Refs.prototype.exists = function(path) {
  try {
    this._resolve(path);
    return true;
  }
  catch (e) {
    return false;
  }
};

/**
 * Resolves the given JSON reference and returns the resolved value.
 *
 * @param {string} path - The path being resolved, with a JSON pointer in the hash
 * @param {$RefParserOptions} options
 * @returns {*} - Returns the resolved value
 */
$Refs.prototype.get = function(path, options) {
  return this._resolve(path, options).value;
};

/**
 * Sets the value of a nested property within this {@link $Ref#value}.
 * If the property, or any of its parents don't exist, they will be created.
 *
 * @param {string} path - The path of the property to set, optionally with a JSON pointer in the hash
 * @param {*} value - The value to assign
 * @param {$RefParserOptions} options
 */
$Refs.prototype.set = function(path, value, options) {
  path = url.resolve(this._basePath, path);
  var withoutHash = util.path.stripHash(path);
  var $ref = this._$refs[withoutHash];

  if (!$ref) {
    throw ono('Error resolving $ref pointer "%s". \n"%s" not found.', path, withoutHash);
  }

  options = new Options(options);
  $ref.set(path, value, options);
};

/**
 * Resolves the given JSON reference.
 *
 * @param {string} path - The path being resolved, optionally with a JSON pointer in the hash
 * @param {$RefParserOptions} options
 * @returns {Pointer}
 * @protected
 */
$Refs.prototype._resolve = function(path, options) {
  path = url.resolve(this._basePath, path);
  var withoutHash = util.path.stripHash(path);
  var $ref = this._$refs[withoutHash];

  if (!$ref) {
    throw ono('Error resolving $ref pointer "%s". \n"%s" not found.', path, withoutHash);
  }

  options = new Options(options);
  return $ref.resolve(path, options);
};

/**
 * Returns the specified {@link $Ref} object, or undefined.
 *
 * @param {string} path - The path being resolved, optionally with a JSON pointer in the hash
 * @returns {$Ref|undefined}
 * @protected
 */
$Refs.prototype._get$Ref = function(path) {
  path = url.resolve(this._basePath, path);
  var withoutHash = util.path.stripHash(path);
  return this._$refs[withoutHash];
};

/**
 * Returns the encoded and decoded paths keys of the given object.
 *
 * @param {object} $refs - The object whose keys are URL-encoded paths
 * @param {...string|string[]} [types] - Only return paths of the given types ("fs", "http", "https")
 * @returns {object[]}
 */
function getPaths($refs, types) {
  var paths = Object.keys($refs);

  // Filter the paths by type
  types = Array.isArray(types[0]) ? types[0] : Array.prototype.slice.call(types);
  if (types.length > 0 && types[0]) {
    paths = paths.filter(function(key) {
      return types.indexOf($refs[key].pathType) !== -1;
    });
  }

  // Decode local filesystem paths
  return paths.map(function(path) {
    return {
      encoded: path,
      decoded: $refs[path].pathType === 'fs' ? util.path.urlToLocalPath(path, true) : path
    };
  });
}

},{"./options":5,"./util":14,"ono":54,"url":91}],13:[function(require,module,exports){
'use strict';

var Promise = require('./promise'),
    $Ref    = require('./ref'),
    Pointer = require('./pointer'),
    read    = require('./read'),
    util    = require('./util'),
    url     = require('url');

module.exports = resolve;

/**
 * Crawls the JSON schema, finds all external JSON references, and resolves their values.
 * This method does not mutate the JSON schema. The resolved values are added to {@link $RefParser#$refs}.
 *
 * NOTE: We only care about EXTERNAL references here. INTERNAL references are only relevant when dereferencing.
 *
 * @param {$RefParser} parser
 * @param {$RefParserOptions} options
 *
 * @returns {Promise}
 * The promise resolves once all JSON references in the schema have been resolved,
 * including nested references that are contained in externally-referenced files.
 */
function resolve(parser, options) {
  try {
    if (!options.$refs.external) {
      // Nothing to resolve, so exit early
      return Promise.resolve();
    }

    util.debug('Resolving $ref pointers in %s', parser.$refs._basePath);
    var promises = crawl(parser.schema, parser.$refs._basePath + '#', parser.$refs, options);
    return Promise.all(promises);
  }
  catch (e) {
    return Promise.reject(e);
  }
}

/**
 * Recursively crawls the given value, and resolves any external JSON references.
 *
 * @param {*} obj - The value to crawl. If it's not an object or array, it will be ignored.
 * @param {string} path - The full path of `obj`, possibly with a JSON Pointer in the hash
 * @param {$Refs} $refs
 * @param {$RefParserOptions} options
 *
 * @returns {Promise[]}
 * Returns an array of promises. There will be one promise for each JSON reference in `obj`.
 * If `obj` does not contain any JSON references, then the array will be empty.
 * If any of the JSON references point to files that contain additional JSON references,
 * then the corresponding promise will internally reference an array of promises.
 */
function crawl(obj, path, $refs, options) {
  var promises = [];

  if (obj && typeof obj === 'object') {
    Object.keys(obj).forEach(function(key) {
      var keyPath = Pointer.join(path, key);
      var value = obj[key];

      if ($Ref.isExternal$Ref(value)) {
        var promise = resolve$Ref(value, keyPath, $refs, options);
        promises.push(promise);
      }
      else {
        promises = promises.concat(crawl(value, keyPath, $refs, options));
      }
    });
  }
  return promises;
}

/**
 * Resolves the given JSON Reference, and then crawls the resulting value.
 *
 * @param {{$ref: string}} $ref - The JSON Reference to resolve
 * @param {string} path - The full path of `$ref`, possibly with a JSON Pointer in the hash
 * @param {$Refs} $refs
 * @param {$RefParserOptions} options
 *
 * @returns {Promise}
 * The promise resolves once all JSON references in the object have been resolved,
 * including nested references that are contained in externally-referenced files.
 */
function resolve$Ref($ref, path, $refs, options) {
  util.debug('Resolving $ref pointer "%s" at %s', $ref.$ref, path);
  var resolvedPath = url.resolve(path, $ref.$ref);

  return read(resolvedPath, $refs, options)
    .then(function(result) {
      // If the result was already cached, then we DON'T need to crawl it
      if (!result.cached) {
        // Crawl the new $ref
        util.debug('Resolving $ref pointers in %s', result.$ref.path);
        var promises = crawl(result.$ref.value, result.$ref.path + '#', $refs, options);
        return Promise.all(promises);
      }
    });
}

},{"./pointer":8,"./promise":9,"./read":10,"./ref":11,"./util":14,"url":91}],14:[function(require,module,exports){
'use strict';

var debug = require('debug'),
    path  = require('./path');

/**
 * Writes messages to stdout.
 * Log messages are suppressed by default, but can be enabled by setting the DEBUG variable.
 * @type {function}
 */
exports.debug = debug('json-schema-ref-parser');

exports.path = path;

/**
 * Returns the resolved value of a JSON Reference.
 * If necessary, the resolved value is merged with the JSON Reference to create a new object
 *
 * @example:
 *  {
 *    person: {
 *      properties: {
 *        firstName: { type: string }
 *        lastName: { type: string }
 *      }
 *    }
 *    employee: {
 *      properties: {
 *        $ref: #/person/properties
 *        salary: { type: number }
 *      }
 *    }
 *  }
 *
 *  When "person" and "employee" are merged, you end up with the following object:
 *
 *  {
 *    properties: {
 *      firstName: { type: string }
 *      lastName: { type: string }
 *      salary: { type: number }
 *    }
 *  }
 *
 * @param {object} $ref - The JSON reference object (the one with the "$ref" property)
 * @param {*} resolvedValue - The resolved value, which can be any type
 * @returns {*} - Returns the dereferenced value
 */
exports.dereference = function($ref, resolvedValue) {
  if (resolvedValue && typeof resolvedValue === 'object' && Object.keys($ref).length > 1) {
    var merged = {};
    Object.keys($ref).forEach(function(key) {
      if (key !== '$ref') {
        merged[key] = $ref[key];
      }
    });
    Object.keys(resolvedValue).forEach(function(key) {
      if (!(key in merged)) {
        merged[key] = resolvedValue[key];
      }
    });
    return merged;
  }
  else {
    // Completely replace the original reference with the resolved value
    return resolvedValue;
  }
};

},{"./path":7,"debug":17}],15:[function(require,module,exports){
/* eslint lines-around-comment: [2, {beforeBlockComment: false}] */
'use strict';

var yaml = require('js-yaml'),
    ono  = require('ono');

/**
 * Simple YAML parsing functions, similar to {@link JSON.parse} and {@link JSON.stringify}
 */
module.exports = {
  /**
   * Parses a YAML string and returns the value.
   *
   * @param {string} text - The YAML string to be parsed
   * @param {function} [reviver] - Not currently supported. Provided for consistency with {@link JSON.parse}
   * @returns {*}
   */
  parse: function yamlParse(text, reviver) {
    try {
      return yaml.safeLoad(text);
    }
    catch (e) {
      if (e instanceof Error) {
        throw e;
      }
      else {
        // https://github.com/nodeca/js-yaml/issues/153
        throw ono(e, e.message);
      }
    }
  },

  /**
   * Converts a JavaScript value to a YAML string.
   *
   * @param   {*} value - The value to convert to YAML
   * @param   {function|array} replacer - Not currently supported. Provided for consistency with {@link JSON.stringify}
   * @param   {string|number} space - The number of spaces to use for indentation, or a string containing the number of spaces.
   * @returns {string}
   */
  stringify: function yamlStringify(value, replacer, space) {
    try {
      var indent = (typeof space === 'string' ? space.length : space) || 2;
      return yaml.safeDump(value, {indent: indent});
    }
    catch (e) {
      if (e instanceof Error) {
        throw e;
      }
      else {
        // https://github.com/nodeca/js-yaml/issues/153
        throw ono(e, e.message);
      }
    }
  }
};

},{"js-yaml":21,"ono":54}],16:[function(require,module,exports){
(function (process,global){
"use strict"

var next = (global.process && process.nextTick) || global.setImmediate || function (f) {
  setTimeout(f, 0)
}

module.exports = function maybe (cb, promise) {
  if (cb) {
    promise
      .then(function (result) {
        next(function () { cb(null, result) })
      }, function (err) {
        next(function () { cb(err) })
      })
    return undefined
  }
  else {
    return promise
  }
}

}).call(this,require('_process'),typeof global !== "undefined" ? global : typeof self !== "undefined" ? self : typeof window !== "undefined" ? window : {})

},{"_process":66}],17:[function(require,module,exports){

/**
 * This is the web browser implementation of `debug()`.
 *
 * Expose `debug()` as the module.
 */

exports = module.exports = require('./debug');
exports.log = log;
exports.formatArgs = formatArgs;
exports.save = save;
exports.load = load;
exports.useColors = useColors;
exports.storage = 'undefined' != typeof chrome
               && 'undefined' != typeof chrome.storage
                  ? chrome.storage.local
                  : localstorage();

/**
 * Colors.
 */

exports.colors = [
  'lightseagreen',
  'forestgreen',
  'goldenrod',
  'dodgerblue',
  'darkorchid',
  'crimson'
];

/**
 * Currently only WebKit-based Web Inspectors, Firefox >= v31,
 * and the Firebug extension (any Firefox version) are known
 * to support "%c" CSS customizations.
 *
 * TODO: add a `localStorage` variable to explicitly enable/disable colors
 */

function useColors() {
  // is webkit? http://stackoverflow.com/a/16459606/376773
  return ('WebkitAppearance' in document.documentElement.style) ||
    // is firebug? http://stackoverflow.com/a/398120/376773
    (window.console && (console.firebug || (console.exception && console.table))) ||
    // is firefox >= v31?
    // https://developer.mozilla.org/en-US/docs/Tools/Web_Console#Styling_messages
    (navigator.userAgent.toLowerCase().match(/firefox\/(\d+)/) && parseInt(RegExp.$1, 10) >= 31);
}

/**
 * Map %j to `JSON.stringify()`, since no Web Inspectors do that by default.
 */

exports.formatters.j = function(v) {
  return JSON.stringify(v);
};


/**
 * Colorize log arguments if enabled.
 *
 * @api public
 */

function formatArgs() {
  var args = arguments;
  var useColors = this.useColors;

  args[0] = (useColors ? '%c' : '')
    + this.namespace
    + (useColors ? ' %c' : ' ')
    + args[0]
    + (useColors ? '%c ' : ' ')
    + '+' + exports.humanize(this.diff);

  if (!useColors) return args;

  var c = 'color: ' + this.color;
  args = [args[0], c, 'color: inherit'].concat(Array.prototype.slice.call(args, 1));

  // the final "%c" is somewhat tricky, because there could be other
  // arguments passed either before or after the %c, so we need to
  // figure out the correct index to insert the CSS into
  var index = 0;
  var lastC = 0;
  args[0].replace(/%[a-z%]/g, function(match) {
    if ('%%' === match) return;
    index++;
    if ('%c' === match) {
      // we only are interested in the *last* %c
      // (the user may have provided their own)
      lastC = index;
    }
  });

  args.splice(lastC, 0, c);
  return args;
}

/**
 * Invokes `console.log()` when available.
 * No-op when `console.log` is not a "function".
 *
 * @api public
 */

function log() {
  // this hackery is required for IE8/9, where
  // the `console.log` function doesn't have 'apply'
  return 'object' === typeof console
    && console.log
    && Function.prototype.apply.call(console.log, console, arguments);
}

/**
 * Save `namespaces`.
 *
 * @param {String} namespaces
 * @api private
 */

function save(namespaces) {
  try {
    if (null == namespaces) {
      exports.storage.removeItem('debug');
    } else {
      exports.storage.debug = namespaces;
    }
  } catch(e) {}
}

/**
 * Load `namespaces`.
 *
 * @return {String} returns the previously persisted debug modes
 * @api private
 */

function load() {
  var r;
  try {
    r = exports.storage.debug;
  } catch(e) {}
  return r;
}

/**
 * Enable namespaces listed in `localStorage.debug` initially.
 */

exports.enable(load());

/**
 * Localstorage attempts to return the localstorage.
 *
 * This is necessary because safari throws
 * when a user disables cookies/localstorage
 * and you attempt to access it.
 *
 * @return {LocalStorage}
 * @api private
 */

function localstorage(){
  try {
    return window.localStorage;
  } catch (e) {}
}

},{"./debug":18}],18:[function(require,module,exports){

/**
 * This is the common logic for both the Node.js and web browser
 * implementations of `debug()`.
 *
 * Expose `debug()` as the module.
 */

exports = module.exports = debug;
exports.coerce = coerce;
exports.disable = disable;
exports.enable = enable;
exports.enabled = enabled;
exports.humanize = require('ms');

/**
 * The currently active debug mode names, and names to skip.
 */

exports.names = [];
exports.skips = [];

/**
 * Map of special "%n" handling functions, for the debug "format" argument.
 *
 * Valid key names are a single, lowercased letter, i.e. "n".
 */

exports.formatters = {};

/**
 * Previously assigned color.
 */

var prevColor = 0;

/**
 * Previous log timestamp.
 */

var prevTime;

/**
 * Select a color.
 *
 * @return {Number}
 * @api private
 */

function selectColor() {
  return exports.colors[prevColor++ % exports.colors.length];
}

/**
 * Create a debugger with the given `namespace`.
 *
 * @param {String} namespace
 * @return {Function}
 * @api public
 */

function debug(namespace) {

  // define the `disabled` version
  function disabled() {
  }
  disabled.enabled = false;

  // define the `enabled` version
  function enabled() {

    var self = enabled;

    // set `diff` timestamp
    var curr = +new Date();
    var ms = curr - (prevTime || curr);
    self.diff = ms;
    self.prev = prevTime;
    self.curr = curr;
    prevTime = curr;

    // add the `color` if not set
    if (null == self.useColors) self.useColors = exports.useColors();
    if (null == self.color && self.useColors) self.color = selectColor();

    var args = Array.prototype.slice.call(arguments);

    args[0] = exports.coerce(args[0]);

    if ('string' !== typeof args[0]) {
      // anything else let's inspect with %o
      args = ['%o'].concat(args);
    }

    // apply any `formatters` transformations
    var index = 0;
    args[0] = args[0].replace(/%([a-z%])/g, function(match, format) {
      // if we encounter an escaped % then don't increase the array index
      if (match === '%%') return match;
      index++;
      var formatter = exports.formatters[format];
      if ('function' === typeof formatter) {
        var val = args[index];
        match = formatter.call(self, val);

        // now we need to remove `args[index]` since it's inlined in the `format`
        args.splice(index, 1);
        index--;
      }
      return match;
    });

    if ('function' === typeof exports.formatArgs) {
      args = exports.formatArgs.apply(self, args);
    }
    var logFn = enabled.log || exports.log || console.log.bind(console);
    logFn.apply(self, args);
  }
  enabled.enabled = true;

  var fn = exports.enabled(namespace) ? enabled : disabled;

  fn.namespace = namespace;

  return fn;
}

/**
 * Enables a debug mode by namespaces. This can include modes
 * separated by a colon and wildcards.
 *
 * @param {String} namespaces
 * @api public
 */

function enable(namespaces) {
  exports.save(namespaces);

  var split = (namespaces || '').split(/[\s,]+/);
  var len = split.length;

  for (var i = 0; i < len; i++) {
    if (!split[i]) continue; // ignore empty strings
    namespaces = split[i].replace(/\*/g, '.*?');
    if (namespaces[0] === '-') {
      exports.skips.push(new RegExp('^' + namespaces.substr(1) + '$'));
    } else {
      exports.names.push(new RegExp('^' + namespaces + '$'));
    }
  }
}

/**
 * Disable debug output.
 *
 * @api public
 */

function disable() {
  exports.enable('');
}

/**
 * Returns true if the given mode name is enabled, false otherwise.
 *
 * @param {String} name
 * @return {Boolean}
 * @api public
 */

function enabled(name) {
  var i, len;
  for (i = 0, len = exports.skips.length; i < len; i++) {
    if (exports.skips[i].test(name)) {
      return false;
    }
  }
  for (i = 0, len = exports.names.length; i < len; i++) {
    if (exports.names[i].test(name)) {
      return true;
    }
  }
  return false;
}

/**
 * Coerce `val`.
 *
 * @param {Mixed} val
 * @return {Mixed}
 * @api private
 */

function coerce(val) {
  if (val instanceof Error) return val.stack || val.message;
  return val;
}

},{"ms":19}],19:[function(require,module,exports){
/**
 * Helpers.
 */

var s = 1000;
var m = s * 60;
var h = m * 60;
var d = h * 24;
var y = d * 365.25;

/**
 * Parse or format the given `val`.
 *
 * Options:
 *
 *  - `long` verbose formatting [false]
 *
 * @param {String|Number} val
 * @param {Object} options
 * @return {String|Number}
 * @api public
 */

module.exports = function(val, options){
  options = options || {};
  if ('string' == typeof val) return parse(val);
  return options.long
    ? long(val)
    : short(val);
};

/**
 * Parse the given `str` and return milliseconds.
 *
 * @param {String} str
 * @return {Number}
 * @api private
 */

function parse(str) {
  str = '' + str;
  if (str.length > 10000) return;
  var match = /^((?:\d+)?\.?\d+) *(milliseconds?|msecs?|ms|seconds?|secs?|s|minutes?|mins?|m|hours?|hrs?|h|days?|d|years?|yrs?|y)?$/i.exec(str);
  if (!match) return;
  var n = parseFloat(match[1]);
  var type = (match[2] || 'ms').toLowerCase();
  switch (type) {
    case 'years':
    case 'year':
    case 'yrs':
    case 'yr':
    case 'y':
      return n * y;
    case 'days':
    case 'day':
    case 'd':
      return n * d;
    case 'hours':
    case 'hour':
    case 'hrs':
    case 'hr':
    case 'h':
      return n * h;
    case 'minutes':
    case 'minute':
    case 'mins':
    case 'min':
    case 'm':
      return n * m;
    case 'seconds':
    case 'second':
    case 'secs':
    case 'sec':
    case 's':
      return n * s;
    case 'milliseconds':
    case 'millisecond':
    case 'msecs':
    case 'msec':
    case 'ms':
      return n;
  }
}

/**
 * Short format for `ms`.
 *
 * @param {Number} ms
 * @return {String}
 * @api private
 */

function short(ms) {
  if (ms >= d) return Math.round(ms / d) + 'd';
  if (ms >= h) return Math.round(ms / h) + 'h';
  if (ms >= m) return Math.round(ms / m) + 'm';
  if (ms >= s) return Math.round(ms / s) + 's';
  return ms + 'ms';
}

/**
 * Long format for `ms`.
 *
 * @param {Number} ms
 * @return {String}
 * @api private
 */

function long(ms) {
  return plural(ms, d, 'day')
    || plural(ms, h, 'hour')
    || plural(ms, m, 'minute')
    || plural(ms, s, 'second')
    || ms + ' ms';
}

/**
 * Pluralization helper.
 */

function plural(ms, n, name) {
  if (ms < n) return;
  if (ms < n * 1.5) return Math.floor(ms / n) + ' ' + name;
  return Math.ceil(ms / n) + ' ' + name + 's';
}

},{}],20:[function(require,module,exports){
(function (process,global){
/*!
 * @overview es6-promise - a tiny implementation of Promises/A+.
 * @copyright Copyright (c) 2014 Yehuda Katz, Tom Dale, Stefan Penner and contributors (Conversion to ES6 API by Jake Archibald)
 * @license   Licensed under MIT license
 *            See https://raw.githubusercontent.com/jakearchibald/es6-promise/master/LICENSE
 * @version   3.0.2
 */

(function() {
    "use strict";
    function lib$es6$promise$utils$$objectOrFunction(x) {
      return typeof x === 'function' || (typeof x === 'object' && x !== null);
    }

    function lib$es6$promise$utils$$isFunction(x) {
      return typeof x === 'function';
    }

    function lib$es6$promise$utils$$isMaybeThenable(x) {
      return typeof x === 'object' && x !== null;
    }

    var lib$es6$promise$utils$$_isArray;
    if (!Array.isArray) {
      lib$es6$promise$utils$$_isArray = function (x) {
        return Object.prototype.toString.call(x) === '[object Array]';
      };
    } else {
      lib$es6$promise$utils$$_isArray = Array.isArray;
    }

    var lib$es6$promise$utils$$isArray = lib$es6$promise$utils$$_isArray;
    var lib$es6$promise$asap$$len = 0;
    var lib$es6$promise$asap$$toString = {}.toString;
    var lib$es6$promise$asap$$vertxNext;
    var lib$es6$promise$asap$$customSchedulerFn;

    var lib$es6$promise$asap$$asap = function asap(callback, arg) {
      lib$es6$promise$asap$$queue[lib$es6$promise$asap$$len] = callback;
      lib$es6$promise$asap$$queue[lib$es6$promise$asap$$len + 1] = arg;
      lib$es6$promise$asap$$len += 2;
      if (lib$es6$promise$asap$$len === 2) {
        // If len is 2, that means that we need to schedule an async flush.
        // If additional callbacks are queued before the queue is flushed, they
        // will be processed by this flush that we are scheduling.
        if (lib$es6$promise$asap$$customSchedulerFn) {
          lib$es6$promise$asap$$customSchedulerFn(lib$es6$promise$asap$$flush);
        } else {
          lib$es6$promise$asap$$scheduleFlush();
        }
      }
    }

    function lib$es6$promise$asap$$setScheduler(scheduleFn) {
      lib$es6$promise$asap$$customSchedulerFn = scheduleFn;
    }

    function lib$es6$promise$asap$$setAsap(asapFn) {
      lib$es6$promise$asap$$asap = asapFn;
    }

    var lib$es6$promise$asap$$browserWindow = (typeof window !== 'undefined') ? window : undefined;
    var lib$es6$promise$asap$$browserGlobal = lib$es6$promise$asap$$browserWindow || {};
    var lib$es6$promise$asap$$BrowserMutationObserver = lib$es6$promise$asap$$browserGlobal.MutationObserver || lib$es6$promise$asap$$browserGlobal.WebKitMutationObserver;
    var lib$es6$promise$asap$$isNode = typeof process !== 'undefined' && {}.toString.call(process) === '[object process]';

    // test for web worker but not in IE10
    var lib$es6$promise$asap$$isWorker = typeof Uint8ClampedArray !== 'undefined' &&
      typeof importScripts !== 'undefined' &&
      typeof MessageChannel !== 'undefined';

    // node
    function lib$es6$promise$asap$$useNextTick() {
      // node version 0.10.x displays a deprecation warning when nextTick is used recursively
      // see https://github.com/cujojs/when/issues/410 for details
      return function() {
        process.nextTick(lib$es6$promise$asap$$flush);
      };
    }

    // vertx
    function lib$es6$promise$asap$$useVertxTimer() {
      return function() {
        lib$es6$promise$asap$$vertxNext(lib$es6$promise$asap$$flush);
      };
    }

    function lib$es6$promise$asap$$useMutationObserver() {
      var iterations = 0;
      var observer = new lib$es6$promise$asap$$BrowserMutationObserver(lib$es6$promise$asap$$flush);
      var node = document.createTextNode('');
      observer.observe(node, { characterData: true });

      return function() {
        node.data = (iterations = ++iterations % 2);
      };
    }

    // web worker
    function lib$es6$promise$asap$$useMessageChannel() {
      var channel = new MessageChannel();
      channel.port1.onmessage = lib$es6$promise$asap$$flush;
      return function () {
        channel.port2.postMessage(0);
      };
    }

    function lib$es6$promise$asap$$useSetTimeout() {
      return function() {
        setTimeout(lib$es6$promise$asap$$flush, 1);
      };
    }

    var lib$es6$promise$asap$$queue = new Array(1000);
    function lib$es6$promise$asap$$flush() {
      for (var i = 0; i < lib$es6$promise$asap$$len; i+=2) {
        var callback = lib$es6$promise$asap$$queue[i];
        var arg = lib$es6$promise$asap$$queue[i+1];

        callback(arg);

        lib$es6$promise$asap$$queue[i] = undefined;
        lib$es6$promise$asap$$queue[i+1] = undefined;
      }

      lib$es6$promise$asap$$len = 0;
    }

    function lib$es6$promise$asap$$attemptVertx() {
      try {
        var r = require;
        var vertx = r('vertx');
        lib$es6$promise$asap$$vertxNext = vertx.runOnLoop || vertx.runOnContext;
        return lib$es6$promise$asap$$useVertxTimer();
      } catch(e) {
        return lib$es6$promise$asap$$useSetTimeout();
      }
    }

    var lib$es6$promise$asap$$scheduleFlush;
    // Decide what async method to use to triggering processing of queued callbacks:
    if (lib$es6$promise$asap$$isNode) {
      lib$es6$promise$asap$$scheduleFlush = lib$es6$promise$asap$$useNextTick();
    } else if (lib$es6$promise$asap$$BrowserMutationObserver) {
      lib$es6$promise$asap$$scheduleFlush = lib$es6$promise$asap$$useMutationObserver();
    } else if (lib$es6$promise$asap$$isWorker) {
      lib$es6$promise$asap$$scheduleFlush = lib$es6$promise$asap$$useMessageChannel();
    } else if (lib$es6$promise$asap$$browserWindow === undefined && typeof require === 'function') {
      lib$es6$promise$asap$$scheduleFlush = lib$es6$promise$asap$$attemptVertx();
    } else {
      lib$es6$promise$asap$$scheduleFlush = lib$es6$promise$asap$$useSetTimeout();
    }

    function lib$es6$promise$$internal$$noop() {}

    var lib$es6$promise$$internal$$PENDING   = void 0;
    var lib$es6$promise$$internal$$FULFILLED = 1;
    var lib$es6$promise$$internal$$REJECTED  = 2;

    var lib$es6$promise$$internal$$GET_THEN_ERROR = new lib$es6$promise$$internal$$ErrorObject();

    function lib$es6$promise$$internal$$selfFulfillment() {
      return new TypeError("You cannot resolve a promise with itself");
    }

    function lib$es6$promise$$internal$$cannotReturnOwn() {
      return new TypeError('A promises callback cannot return that same promise.');
    }

    function lib$es6$promise$$internal$$getThen(promise) {
      try {
        return promise.then;
      } catch(error) {
        lib$es6$promise$$internal$$GET_THEN_ERROR.error = error;
        return lib$es6$promise$$internal$$GET_THEN_ERROR;
      }
    }

    function lib$es6$promise$$internal$$tryThen(then, value, fulfillmentHandler, rejectionHandler) {
      try {
        then.call(value, fulfillmentHandler, rejectionHandler);
      } catch(e) {
        return e;
      }
    }

    function lib$es6$promise$$internal$$handleForeignThenable(promise, thenable, then) {
       lib$es6$promise$asap$$asap(function(promise) {
        var sealed = false;
        var error = lib$es6$promise$$internal$$tryThen(then, thenable, function(value) {
          if (sealed) { return; }
          sealed = true;
          if (thenable !== value) {
            lib$es6$promise$$internal$$resolve(promise, value);
          } else {
            lib$es6$promise$$internal$$fulfill(promise, value);
          }
        }, function(reason) {
          if (sealed) { return; }
          sealed = true;

          lib$es6$promise$$internal$$reject(promise, reason);
        }, 'Settle: ' + (promise._label || ' unknown promise'));

        if (!sealed && error) {
          sealed = true;
          lib$es6$promise$$internal$$reject(promise, error);
        }
      }, promise);
    }

    function lib$es6$promise$$internal$$handleOwnThenable(promise, thenable) {
      if (thenable._state === lib$es6$promise$$internal$$FULFILLED) {
        lib$es6$promise$$internal$$fulfill(promise, thenable._result);
      } else if (thenable._state === lib$es6$promise$$internal$$REJECTED) {
        lib$es6$promise$$internal$$reject(promise, thenable._result);
      } else {
        lib$es6$promise$$internal$$subscribe(thenable, undefined, function(value) {
          lib$es6$promise$$internal$$resolve(promise, value);
        }, function(reason) {
          lib$es6$promise$$internal$$reject(promise, reason);
        });
      }
    }

    function lib$es6$promise$$internal$$handleMaybeThenable(promise, maybeThenable) {
      if (maybeThenable.constructor === promise.constructor) {
        lib$es6$promise$$internal$$handleOwnThenable(promise, maybeThenable);
      } else {
        var then = lib$es6$promise$$internal$$getThen(maybeThenable);

        if (then === lib$es6$promise$$internal$$GET_THEN_ERROR) {
          lib$es6$promise$$internal$$reject(promise, lib$es6$promise$$internal$$GET_THEN_ERROR.error);
        } else if (then === undefined) {
          lib$es6$promise$$internal$$fulfill(promise, maybeThenable);
        } else if (lib$es6$promise$utils$$isFunction(then)) {
          lib$es6$promise$$internal$$handleForeignThenable(promise, maybeThenable, then);
        } else {
          lib$es6$promise$$internal$$fulfill(promise, maybeThenable);
        }
      }
    }

    function lib$es6$promise$$internal$$resolve(promise, value) {
      if (promise === value) {
        lib$es6$promise$$internal$$reject(promise, lib$es6$promise$$internal$$selfFulfillment());
      } else if (lib$es6$promise$utils$$objectOrFunction(value)) {
        lib$es6$promise$$internal$$handleMaybeThenable(promise, value);
      } else {
        lib$es6$promise$$internal$$fulfill(promise, value);
      }
    }

    function lib$es6$promise$$internal$$publishRejection(promise) {
      if (promise._onerror) {
        promise._onerror(promise._result);
      }

      lib$es6$promise$$internal$$publish(promise);
    }

    function lib$es6$promise$$internal$$fulfill(promise, value) {
      if (promise._state !== lib$es6$promise$$internal$$PENDING) { return; }

      promise._result = value;
      promise._state = lib$es6$promise$$internal$$FULFILLED;

      if (promise._subscribers.length !== 0) {
        lib$es6$promise$asap$$asap(lib$es6$promise$$internal$$publish, promise);
      }
    }

    function lib$es6$promise$$internal$$reject(promise, reason) {
      if (promise._state !== lib$es6$promise$$internal$$PENDING) { return; }
      promise._state = lib$es6$promise$$internal$$REJECTED;
      promise._result = reason;

      lib$es6$promise$asap$$asap(lib$es6$promise$$internal$$publishRejection, promise);
    }

    function lib$es6$promise$$internal$$subscribe(parent, child, onFulfillment, onRejection) {
      var subscribers = parent._subscribers;
      var length = subscribers.length;

      parent._onerror = null;

      subscribers[length] = child;
      subscribers[length + lib$es6$promise$$internal$$FULFILLED] = onFulfillment;
      subscribers[length + lib$es6$promise$$internal$$REJECTED]  = onRejection;

      if (length === 0 && parent._state) {
        lib$es6$promise$asap$$asap(lib$es6$promise$$internal$$publish, parent);
      }
    }

    function lib$es6$promise$$internal$$publish(promise) {
      var subscribers = promise._subscribers;
      var settled = promise._state;

      if (subscribers.length === 0) { return; }

      var child, callback, detail = promise._result;

      for (var i = 0; i < subscribers.length; i += 3) {
        child = subscribers[i];
        callback = subscribers[i + settled];

        if (child) {
          lib$es6$promise$$internal$$invokeCallback(settled, child, callback, detail);
        } else {
          callback(detail);
        }
      }

      promise._subscribers.length = 0;
    }

    function lib$es6$promise$$internal$$ErrorObject() {
      this.error = null;
    }

    var lib$es6$promise$$internal$$TRY_CATCH_ERROR = new lib$es6$promise$$internal$$ErrorObject();

    function lib$es6$promise$$internal$$tryCatch(callback, detail) {
      try {
        return callback(detail);
      } catch(e) {
        lib$es6$promise$$internal$$TRY_CATCH_ERROR.error = e;
        return lib$es6$promise$$internal$$TRY_CATCH_ERROR;
      }
    }

    function lib$es6$promise$$internal$$invokeCallback(settled, promise, callback, detail) {
      var hasCallback = lib$es6$promise$utils$$isFunction(callback),
          value, error, succeeded, failed;

      if (hasCallback) {
        value = lib$es6$promise$$internal$$tryCatch(callback, detail);

        if (value === lib$es6$promise$$internal$$TRY_CATCH_ERROR) {
          failed = true;
          error = value.error;
          value = null;
        } else {
          succeeded = true;
        }

        if (promise === value) {
          lib$es6$promise$$internal$$reject(promise, lib$es6$promise$$internal$$cannotReturnOwn());
          return;
        }

      } else {
        value = detail;
        succeeded = true;
      }

      if (promise._state !== lib$es6$promise$$internal$$PENDING) {
        // noop
      } else if (hasCallback && succeeded) {
        lib$es6$promise$$internal$$resolve(promise, value);
      } else if (failed) {
        lib$es6$promise$$internal$$reject(promise, error);
      } else if (settled === lib$es6$promise$$internal$$FULFILLED) {
        lib$es6$promise$$internal$$fulfill(promise, value);
      } else if (settled === lib$es6$promise$$internal$$REJECTED) {
        lib$es6$promise$$internal$$reject(promise, value);
      }
    }

    function lib$es6$promise$$internal$$initializePromise(promise, resolver) {
      try {
        resolver(function resolvePromise(value){
          lib$es6$promise$$internal$$resolve(promise, value);
        }, function rejectPromise(reason) {
          lib$es6$promise$$internal$$reject(promise, reason);
        });
      } catch(e) {
        lib$es6$promise$$internal$$reject(promise, e);
      }
    }

    function lib$es6$promise$enumerator$$Enumerator(Constructor, input) {
      var enumerator = this;

      enumerator._instanceConstructor = Constructor;
      enumerator.promise = new Constructor(lib$es6$promise$$internal$$noop);

      if (enumerator._validateInput(input)) {
        enumerator._input     = input;
        enumerator.length     = input.length;
        enumerator._remaining = input.length;

        enumerator._init();

        if (enumerator.length === 0) {
          lib$es6$promise$$internal$$fulfill(enumerator.promise, enumerator._result);
        } else {
          enumerator.length = enumerator.length || 0;
          enumerator._enumerate();
          if (enumerator._remaining === 0) {
            lib$es6$promise$$internal$$fulfill(enumerator.promise, enumerator._result);
          }
        }
      } else {
        lib$es6$promise$$internal$$reject(enumerator.promise, enumerator._validationError());
      }
    }

    lib$es6$promise$enumerator$$Enumerator.prototype._validateInput = function(input) {
      return lib$es6$promise$utils$$isArray(input);
    };

    lib$es6$promise$enumerator$$Enumerator.prototype._validationError = function() {
      return new Error('Array Methods must be provided an Array');
    };

    lib$es6$promise$enumerator$$Enumerator.prototype._init = function() {
      this._result = new Array(this.length);
    };

    var lib$es6$promise$enumerator$$default = lib$es6$promise$enumerator$$Enumerator;

    lib$es6$promise$enumerator$$Enumerator.prototype._enumerate = function() {
      var enumerator = this;

      var length  = enumerator.length;
      var promise = enumerator.promise;
      var input   = enumerator._input;

      for (var i = 0; promise._state === lib$es6$promise$$internal$$PENDING && i < length; i++) {
        enumerator._eachEntry(input[i], i);
      }
    };

    lib$es6$promise$enumerator$$Enumerator.prototype._eachEntry = function(entry, i) {
      var enumerator = this;
      var c = enumerator._instanceConstructor;

      if (lib$es6$promise$utils$$isMaybeThenable(entry)) {
        if (entry.constructor === c && entry._state !== lib$es6$promise$$internal$$PENDING) {
          entry._onerror = null;
          enumerator._settledAt(entry._state, i, entry._result);
        } else {
          enumerator._willSettleAt(c.resolve(entry), i);
        }
      } else {
        enumerator._remaining--;
        enumerator._result[i] = entry;
      }
    };

    lib$es6$promise$enumerator$$Enumerator.prototype._settledAt = function(state, i, value) {
      var enumerator = this;
      var promise = enumerator.promise;

      if (promise._state === lib$es6$promise$$internal$$PENDING) {
        enumerator._remaining--;

        if (state === lib$es6$promise$$internal$$REJECTED) {
          lib$es6$promise$$internal$$reject(promise, value);
        } else {
          enumerator._result[i] = value;
        }
      }

      if (enumerator._remaining === 0) {
        lib$es6$promise$$internal$$fulfill(promise, enumerator._result);
      }
    };

    lib$es6$promise$enumerator$$Enumerator.prototype._willSettleAt = function(promise, i) {
      var enumerator = this;

      lib$es6$promise$$internal$$subscribe(promise, undefined, function(value) {
        enumerator._settledAt(lib$es6$promise$$internal$$FULFILLED, i, value);
      }, function(reason) {
        enumerator._settledAt(lib$es6$promise$$internal$$REJECTED, i, reason);
      });
    };
    function lib$es6$promise$promise$all$$all(entries) {
      return new lib$es6$promise$enumerator$$default(this, entries).promise;
    }
    var lib$es6$promise$promise$all$$default = lib$es6$promise$promise$all$$all;
    function lib$es6$promise$promise$race$$race(entries) {
      /*jshint validthis:true */
      var Constructor = this;

      var promise = new Constructor(lib$es6$promise$$internal$$noop);

      if (!lib$es6$promise$utils$$isArray(entries)) {
        lib$es6$promise$$internal$$reject(promise, new TypeError('You must pass an array to race.'));
        return promise;
      }

      var length = entries.length;

      function onFulfillment(value) {
        lib$es6$promise$$internal$$resolve(promise, value);
      }

      function onRejection(reason) {
        lib$es6$promise$$internal$$reject(promise, reason);
      }

      for (var i = 0; promise._state === lib$es6$promise$$internal$$PENDING && i < length; i++) {
        lib$es6$promise$$internal$$subscribe(Constructor.resolve(entries[i]), undefined, onFulfillment, onRejection);
      }

      return promise;
    }
    var lib$es6$promise$promise$race$$default = lib$es6$promise$promise$race$$race;
    function lib$es6$promise$promise$resolve$$resolve(object) {
      /*jshint validthis:true */
      var Constructor = this;

      if (object && typeof object === 'object' && object.constructor === Constructor) {
        return object;
      }

      var promise = new Constructor(lib$es6$promise$$internal$$noop);
      lib$es6$promise$$internal$$resolve(promise, object);
      return promise;
    }
    var lib$es6$promise$promise$resolve$$default = lib$es6$promise$promise$resolve$$resolve;
    function lib$es6$promise$promise$reject$$reject(reason) {
      /*jshint validthis:true */
      var Constructor = this;
      var promise = new Constructor(lib$es6$promise$$internal$$noop);
      lib$es6$promise$$internal$$reject(promise, reason);
      return promise;
    }
    var lib$es6$promise$promise$reject$$default = lib$es6$promise$promise$reject$$reject;

    var lib$es6$promise$promise$$counter = 0;

    function lib$es6$promise$promise$$needsResolver() {
      throw new TypeError('You must pass a resolver function as the first argument to the promise constructor');
    }

    function lib$es6$promise$promise$$needsNew() {
      throw new TypeError("Failed to construct 'Promise': Please use the 'new' operator, this object constructor cannot be called as a function.");
    }

    var lib$es6$promise$promise$$default = lib$es6$promise$promise$$Promise;
    /**
      Promise objects represent the eventual result of an asynchronous operation. The
      primary way of interacting with a promise is through its `then` method, which
      registers callbacks to receive either a promise's eventual value or the reason
      why the promise cannot be fulfilled.

      Terminology
      -----------

      - `promise` is an object or function with a `then` method whose behavior conforms to this specification.
      - `thenable` is an object or function that defines a `then` method.
      - `value` is any legal JavaScript value (including undefined, a thenable, or a promise).
      - `exception` is a value that is thrown using the throw statement.
      - `reason` is a value that indicates why a promise was rejected.
      - `settled` the final resting state of a promise, fulfilled or rejected.

      A promise can be in one of three states: pending, fulfilled, or rejected.

      Promises that are fulfilled have a fulfillment value and are in the fulfilled
      state.  Promises that are rejected have a rejection reason and are in the
      rejected state.  A fulfillment value is never a thenable.

      Promises can also be said to *resolve* a value.  If this value is also a
      promise, then the original promise's settled state will match the value's
      settled state.  So a promise that *resolves* a promise that rejects will
      itself reject, and a promise that *resolves* a promise that fulfills will
      itself fulfill.


      Basic Usage:
      ------------

      ```js
      var promise = new Promise(function(resolve, reject) {
        // on success
        resolve(value);

        // on failure
        reject(reason);
      });

      promise.then(function(value) {
        // on fulfillment
      }, function(reason) {
        // on rejection
      });
      ```

      Advanced Usage:
      ---------------

      Promises shine when abstracting away asynchronous interactions such as
      `XMLHttpRequest`s.

      ```js
      function getJSON(url) {
        return new Promise(function(resolve, reject){
          var xhr = new XMLHttpRequest();

          xhr.open('GET', url);
          xhr.onreadystatechange = handler;
          xhr.responseType = 'json';
          xhr.setRequestHeader('Accept', 'application/json');
          xhr.send();

          function handler() {
            if (this.readyState === this.DONE) {
              if (this.status === 200) {
                resolve(this.response);
              } else {
                reject(new Error('getJSON: `' + url + '` failed with status: [' + this.status + ']'));
              }
            }
          };
        });
      }

      getJSON('/posts.json').then(function(json) {
        // on fulfillment
      }, function(reason) {
        // on rejection
      });
      ```

      Unlike callbacks, promises are great composable primitives.

      ```js
      Promise.all([
        getJSON('/posts'),
        getJSON('/comments')
      ]).then(function(values){
        values[0] // => postsJSON
        values[1] // => commentsJSON

        return values;
      });
      ```

      @class Promise
      @param {function} resolver
      Useful for tooling.
      @constructor
    */
    function lib$es6$promise$promise$$Promise(resolver) {
      this._id = lib$es6$promise$promise$$counter++;
      this._state = undefined;
      this._result = undefined;
      this._subscribers = [];

      if (lib$es6$promise$$internal$$noop !== resolver) {
        if (!lib$es6$promise$utils$$isFunction(resolver)) {
          lib$es6$promise$promise$$needsResolver();
        }

        if (!(this instanceof lib$es6$promise$promise$$Promise)) {
          lib$es6$promise$promise$$needsNew();
        }

        lib$es6$promise$$internal$$initializePromise(this, resolver);
      }
    }

    lib$es6$promise$promise$$Promise.all = lib$es6$promise$promise$all$$default;
    lib$es6$promise$promise$$Promise.race = lib$es6$promise$promise$race$$default;
    lib$es6$promise$promise$$Promise.resolve = lib$es6$promise$promise$resolve$$default;
    lib$es6$promise$promise$$Promise.reject = lib$es6$promise$promise$reject$$default;
    lib$es6$promise$promise$$Promise._setScheduler = lib$es6$promise$asap$$setScheduler;
    lib$es6$promise$promise$$Promise._setAsap = lib$es6$promise$asap$$setAsap;
    lib$es6$promise$promise$$Promise._asap = lib$es6$promise$asap$$asap;

    lib$es6$promise$promise$$Promise.prototype = {
      constructor: lib$es6$promise$promise$$Promise,

    /**
      The primary way of interacting with a promise is through its `then` method,
      which registers callbacks to receive either a promise's eventual value or the
      reason why the promise cannot be fulfilled.

      ```js
      findUser().then(function(user){
        // user is available
      }, function(reason){
        // user is unavailable, and you are given the reason why
      });
      ```

      Chaining
      --------

      The return value of `then` is itself a promise.  This second, 'downstream'
      promise is resolved with the return value of the first promise's fulfillment
      or rejection handler, or rejected if the handler throws an exception.

      ```js
      findUser().then(function (user) {
        return user.name;
      }, function (reason) {
        return 'default name';
      }).then(function (userName) {
        // If `findUser` fulfilled, `userName` will be the user's name, otherwise it
        // will be `'default name'`
      });

      findUser().then(function (user) {
        throw new Error('Found user, but still unhappy');
      }, function (reason) {
        throw new Error('`findUser` rejected and we're unhappy');
      }).then(function (value) {
        // never reached
      }, function (reason) {
        // if `findUser` fulfilled, `reason` will be 'Found user, but still unhappy'.
        // If `findUser` rejected, `reason` will be '`findUser` rejected and we're unhappy'.
      });
      ```
      If the downstream promise does not specify a rejection handler, rejection reasons will be propagated further downstream.

      ```js
      findUser().then(function (user) {
        throw new PedagogicalException('Upstream error');
      }).then(function (value) {
        // never reached
      }).then(function (value) {
        // never reached
      }, function (reason) {
        // The `PedgagocialException` is propagated all the way down to here
      });
      ```

      Assimilation
      ------------

      Sometimes the value you want to propagate to a downstream promise can only be
      retrieved asynchronously. This can be achieved by returning a promise in the
      fulfillment or rejection handler. The downstream promise will then be pending
      until the returned promise is settled. This is called *assimilation*.

      ```js
      findUser().then(function (user) {
        return findCommentsByAuthor(user);
      }).then(function (comments) {
        // The user's comments are now available
      });
      ```

      If the assimliated promise rejects, then the downstream promise will also reject.

      ```js
      findUser().then(function (user) {
        return findCommentsByAuthor(user);
      }).then(function (comments) {
        // If `findCommentsByAuthor` fulfills, we'll have the value here
      }, function (reason) {
        // If `findCommentsByAuthor` rejects, we'll have the reason here
      });
      ```

      Simple Example
      --------------

      Synchronous Example

      ```javascript
      var result;

      try {
        result = findResult();
        // success
      } catch(reason) {
        // failure
      }
      ```

      Errback Example

      ```js
      findResult(function(result, err){
        if (err) {
          // failure
        } else {
          // success
        }
      });
      ```

      Promise Example;

      ```javascript
      findResult().then(function(result){
        // success
      }, function(reason){
        // failure
      });
      ```

      Advanced Example
      --------------

      Synchronous Example

      ```javascript
      var author, books;

      try {
        author = findAuthor();
        books  = findBooksByAuthor(author);
        // success
      } catch(reason) {
        // failure
      }
      ```

      Errback Example

      ```js

      function foundBooks(books) {

      }

      function failure(reason) {

      }

      findAuthor(function(author, err){
        if (err) {
          failure(err);
          // failure
        } else {
          try {
            findBoooksByAuthor(author, function(books, err) {
              if (err) {
                failure(err);
              } else {
                try {
                  foundBooks(books);
                } catch(reason) {
                  failure(reason);
                }
              }
            });
          } catch(error) {
            failure(err);
          }
          // success
        }
      });
      ```

      Promise Example;

      ```javascript
      findAuthor().
        then(findBooksByAuthor).
        then(function(books){
          // found books
      }).catch(function(reason){
        // something went wrong
      });
      ```

      @method then
      @param {Function} onFulfilled
      @param {Function} onRejected
      Useful for tooling.
      @return {Promise}
    */
      then: function(onFulfillment, onRejection) {
        var parent = this;
        var state = parent._state;

        if (state === lib$es6$promise$$internal$$FULFILLED && !onFulfillment || state === lib$es6$promise$$internal$$REJECTED && !onRejection) {
          return this;
        }

        var child = new this.constructor(lib$es6$promise$$internal$$noop);
        var result = parent._result;

        if (state) {
          var callback = arguments[state - 1];
          lib$es6$promise$asap$$asap(function(){
            lib$es6$promise$$internal$$invokeCallback(state, child, callback, result);
          });
        } else {
          lib$es6$promise$$internal$$subscribe(parent, child, onFulfillment, onRejection);
        }

        return child;
      },

    /**
      `catch` is simply sugar for `then(undefined, onRejection)` which makes it the same
      as the catch block of a try/catch statement.

      ```js
      function findAuthor(){
        throw new Error('couldn't find that author');
      }

      // synchronous
      try {
        findAuthor();
      } catch(reason) {
        // something went wrong
      }

      // async with promises
      findAuthor().catch(function(reason){
        // something went wrong
      });
      ```

      @method catch
      @param {Function} onRejection
      Useful for tooling.
      @return {Promise}
    */
      'catch': function(onRejection) {
        return this.then(null, onRejection);
      }
    };
    function lib$es6$promise$polyfill$$polyfill() {
      var local;

      if (typeof global !== 'undefined') {
          local = global;
      } else if (typeof self !== 'undefined') {
          local = self;
      } else {
          try {
              local = Function('return this')();
          } catch (e) {
              throw new Error('polyfill failed because global object is unavailable in this environment');
          }
      }

      var P = local.Promise;

      if (P && Object.prototype.toString.call(P.resolve()) === '[object Promise]' && !P.cast) {
        return;
      }

      local.Promise = lib$es6$promise$promise$$default;
    }
    var lib$es6$promise$polyfill$$default = lib$es6$promise$polyfill$$polyfill;

    var lib$es6$promise$umd$$ES6Promise = {
      'Promise': lib$es6$promise$promise$$default,
      'polyfill': lib$es6$promise$polyfill$$default
    };

    /* global define:true module:true window: true */
    if (typeof define === 'function' && define['amd']) {
      define(function() { return lib$es6$promise$umd$$ES6Promise; });
    } else if (typeof module !== 'undefined' && module['exports']) {
      module['exports'] = lib$es6$promise$umd$$ES6Promise;
    } else if (typeof this !== 'undefined') {
      this['ES6Promise'] = lib$es6$promise$umd$$ES6Promise;
    }

    lib$es6$promise$polyfill$$default();
}).call(this);


}).call(this,require('_process'),typeof global !== "undefined" ? global : typeof self !== "undefined" ? self : typeof window !== "undefined" ? window : {})

},{"_process":66}],21:[function(require,module,exports){
'use strict';


var yaml = require('./lib/js-yaml.js');


module.exports = yaml;

},{"./lib/js-yaml.js":22}],22:[function(require,module,exports){
'use strict';


var loader = require('./js-yaml/loader');
var dumper = require('./js-yaml/dumper');


function deprecated(name) {
  return function () {
    throw new Error('Function ' + name + ' is deprecated and cannot be used.');
  };
}


module.exports.Type                = require('./js-yaml/type');
module.exports.Schema              = require('./js-yaml/schema');
module.exports.FAILSAFE_SCHEMA     = require('./js-yaml/schema/failsafe');
module.exports.JSON_SCHEMA         = require('./js-yaml/schema/json');
module.exports.CORE_SCHEMA         = require('./js-yaml/schema/core');
module.exports.DEFAULT_SAFE_SCHEMA = require('./js-yaml/schema/default_safe');
module.exports.DEFAULT_FULL_SCHEMA = require('./js-yaml/schema/default_full');
module.exports.load                = loader.load;
module.exports.loadAll             = loader.loadAll;
module.exports.safeLoad            = loader.safeLoad;
module.exports.safeLoadAll         = loader.safeLoadAll;
module.exports.dump                = dumper.dump;
module.exports.safeDump            = dumper.safeDump;
module.exports.YAMLException       = require('./js-yaml/exception');

// Deprecated schema names from JS-YAML 2.0.x
module.exports.MINIMAL_SCHEMA = require('./js-yaml/schema/failsafe');
module.exports.SAFE_SCHEMA    = require('./js-yaml/schema/default_safe');
module.exports.DEFAULT_SCHEMA = require('./js-yaml/schema/default_full');

// Deprecated functions from JS-YAML 1.x.x
module.exports.scan           = deprecated('scan');
module.exports.parse          = deprecated('parse');
module.exports.compose        = deprecated('compose');
module.exports.addConstructor = deprecated('addConstructor');

},{"./js-yaml/dumper":24,"./js-yaml/exception":25,"./js-yaml/loader":26,"./js-yaml/schema":28,"./js-yaml/schema/core":29,"./js-yaml/schema/default_full":30,"./js-yaml/schema/default_safe":31,"./js-yaml/schema/failsafe":32,"./js-yaml/schema/json":33,"./js-yaml/type":34}],23:[function(require,module,exports){
'use strict';


function isNothing(subject) {
  return (typeof subject === 'undefined') || (null === subject);
}


function isObject(subject) {
  return (typeof subject === 'object') && (null !== subject);
}


function toArray(sequence) {
  if (Array.isArray(sequence)) {
    return sequence;
  } else if (isNothing(sequence)) {
    return [];
  }
  return [ sequence ];
}


function extend(target, source) {
  var index, length, key, sourceKeys;

  if (source) {
    sourceKeys = Object.keys(source);

    for (index = 0, length = sourceKeys.length; index < length; index += 1) {
      key = sourceKeys[index];
      target[key] = source[key];
    }
  }

  return target;
}


function repeat(string, count) {
  var result = '', cycle;

  for (cycle = 0; cycle < count; cycle += 1) {
    result += string;
  }

  return result;
}


function isNegativeZero(number) {
  return (0 === number) && (Number.NEGATIVE_INFINITY === 1 / number);
}


module.exports.isNothing      = isNothing;
module.exports.isObject       = isObject;
module.exports.toArray        = toArray;
module.exports.repeat         = repeat;
module.exports.isNegativeZero = isNegativeZero;
module.exports.extend         = extend;

},{}],24:[function(require,module,exports){
'use strict';

/*eslint-disable no-use-before-define*/

var common              = require('./common');
var YAMLException       = require('./exception');
var DEFAULT_FULL_SCHEMA = require('./schema/default_full');
var DEFAULT_SAFE_SCHEMA = require('./schema/default_safe');

var _toString       = Object.prototype.toString;
var _hasOwnProperty = Object.prototype.hasOwnProperty;

var CHAR_TAB                  = 0x09; /* Tab */
var CHAR_LINE_FEED            = 0x0A; /* LF */
var CHAR_CARRIAGE_RETURN      = 0x0D; /* CR */
var CHAR_SPACE                = 0x20; /* Space */
var CHAR_EXCLAMATION          = 0x21; /* ! */
var CHAR_DOUBLE_QUOTE         = 0x22; /* " */
var CHAR_SHARP                = 0x23; /* # */
var CHAR_PERCENT              = 0x25; /* % */
var CHAR_AMPERSAND            = 0x26; /* & */
var CHAR_SINGLE_QUOTE         = 0x27; /* ' */
var CHAR_ASTERISK             = 0x2A; /* * */
var CHAR_COMMA                = 0x2C; /* , */
var CHAR_MINUS                = 0x2D; /* - */
var CHAR_COLON                = 0x3A; /* : */
var CHAR_GREATER_THAN         = 0x3E; /* > */
var CHAR_QUESTION             = 0x3F; /* ? */
var CHAR_COMMERCIAL_AT        = 0x40; /* @ */
var CHAR_LEFT_SQUARE_BRACKET  = 0x5B; /* [ */
var CHAR_RIGHT_SQUARE_BRACKET = 0x5D; /* ] */
var CHAR_GRAVE_ACCENT         = 0x60; /* ` */
var CHAR_LEFT_CURLY_BRACKET   = 0x7B; /* { */
var CHAR_VERTICAL_LINE        = 0x7C; /* | */
var CHAR_RIGHT_CURLY_BRACKET  = 0x7D; /* } */

var ESCAPE_SEQUENCES = {};

ESCAPE_SEQUENCES[0x00]   = '\\0';
ESCAPE_SEQUENCES[0x07]   = '\\a';
ESCAPE_SEQUENCES[0x08]   = '\\b';
ESCAPE_SEQUENCES[0x09]   = '\\t';
ESCAPE_SEQUENCES[0x0A]   = '\\n';
ESCAPE_SEQUENCES[0x0B]   = '\\v';
ESCAPE_SEQUENCES[0x0C]   = '\\f';
ESCAPE_SEQUENCES[0x0D]   = '\\r';
ESCAPE_SEQUENCES[0x1B]   = '\\e';
ESCAPE_SEQUENCES[0x22]   = '\\"';
ESCAPE_SEQUENCES[0x5C]   = '\\\\';
ESCAPE_SEQUENCES[0x85]   = '\\N';
ESCAPE_SEQUENCES[0xA0]   = '\\_';
ESCAPE_SEQUENCES[0x2028] = '\\L';
ESCAPE_SEQUENCES[0x2029] = '\\P';

var DEPRECATED_BOOLEANS_SYNTAX = [
  'y', 'Y', 'yes', 'Yes', 'YES', 'on', 'On', 'ON',
  'n', 'N', 'no', 'No', 'NO', 'off', 'Off', 'OFF'
];

function compileStyleMap(schema, map) {
  var result, keys, index, length, tag, style, type;

  if (null === map) {
    return {};
  }

  result = {};
  keys = Object.keys(map);

  for (index = 0, length = keys.length; index < length; index += 1) {
    tag = keys[index];
    style = String(map[tag]);

    if ('!!' === tag.slice(0, 2)) {
      tag = 'tag:yaml.org,2002:' + tag.slice(2);
    }

    type = schema.compiledTypeMap[tag];

    if (type && _hasOwnProperty.call(type.styleAliases, style)) {
      style = type.styleAliases[style];
    }

    result[tag] = style;
  }

  return result;
}

function encodeHex(character) {
  var string, handle, length;

  string = character.toString(16).toUpperCase();

  if (character <= 0xFF) {
    handle = 'x';
    length = 2;
  } else if (character <= 0xFFFF) {
    handle = 'u';
    length = 4;
  } else if (character <= 0xFFFFFFFF) {
    handle = 'U';
    length = 8;
  } else {
    throw new YAMLException('code point within a string may not be greater than 0xFFFFFFFF');
  }

  return '\\' + handle + common.repeat('0', length - string.length) + string;
}

function State(options) {
  this.schema      = options['schema'] || DEFAULT_FULL_SCHEMA;
  this.indent      = Math.max(1, (options['indent'] || 2));
  this.skipInvalid = options['skipInvalid'] || false;
  this.flowLevel   = (common.isNothing(options['flowLevel']) ? -1 : options['flowLevel']);
  this.styleMap    = compileStyleMap(this.schema, options['styles'] || null);
  this.sortKeys    = options['sortKeys'] || false;
  this.lineWidth    = options['lineWidth'] || 80;

  this.implicitTypes = this.schema.compiledImplicit;
  this.explicitTypes = this.schema.compiledExplicit;

  this.tag = null;
  this.result = '';

  this.duplicates = [];
  this.usedDuplicates = null;
}

function indentString(string, spaces) {
  var ind = common.repeat(' ', spaces),
      position = 0,
      next = -1,
      result = '',
      line,
      length = string.length;

  while (position < length) {
    next = string.indexOf('\n', position);
    if (next === -1) {
      line = string.slice(position);
      position = length;
    } else {
      line = string.slice(position, next + 1);
      position = next + 1;
    }
    if (line.length && line !== '\n') {
      result += ind;
    }
    result += line;
  }

  return result;
}

function generateNextLine(state, level) {
  return '\n' + common.repeat(' ', state.indent * level);
}

function testImplicitResolving(state, str) {
  var index, length, type;

  for (index = 0, length = state.implicitTypes.length; index < length; index += 1) {
    type = state.implicitTypes[index];

    if (type.resolve(str)) {
      return true;
    }
  }

  return false;
}

function StringBuilder(source) {
  this.source = source;
  this.result = '';
  this.checkpoint = 0;
}

StringBuilder.prototype.takeUpTo = function (position) {
  var er;

  if (position < this.checkpoint) {
    er = new Error('position should be > checkpoint');
    er.position = position;
    er.checkpoint = this.checkpoint;
    throw er;
  }

  this.result += this.source.slice(this.checkpoint, position);
  this.checkpoint = position;
  return this;
};

StringBuilder.prototype.escapeChar = function () {
  var character, esc;

  character = this.source.charCodeAt(this.checkpoint);
  esc = ESCAPE_SEQUENCES[character] || encodeHex(character);
  this.result += esc;
  this.checkpoint += 1;

  return this;
};

StringBuilder.prototype.finish = function () {
  if (this.source.length > this.checkpoint) {
    this.takeUpTo(this.source.length);
  }
};

function writeScalar(state, object, level, iskey) {
  var simple, first, spaceWrap, folded, literal, single, double,
      sawLineFeed, linePosition, longestLine, indent, max, character,
      position, escapeSeq, hexEsc, previous, lineLength, modifier,
      trailingLineBreaks, result;

  if (0 === object.length) {
    state.dump = "''";
    return;
  }

  if (-1 !== DEPRECATED_BOOLEANS_SYNTAX.indexOf(object)) {
    state.dump = "'" + object + "'";
    return;
  }

  simple = true;
  first = object.length ? object.charCodeAt(0) : 0;
  spaceWrap = (CHAR_SPACE === first ||
               CHAR_SPACE === object.charCodeAt(object.length - 1));

  // Simplified check for restricted first characters
  // http://www.yaml.org/spec/1.2/spec.html#ns-plain-first%28c%29
  if (CHAR_MINUS         === first ||
      CHAR_QUESTION      === first ||
      CHAR_COMMERCIAL_AT === first ||
      CHAR_GRAVE_ACCENT  === first) {
    simple = false;
  }

  // can only use > and | if not wrapped in spaces or is not a key.
  if (spaceWrap) {
    simple = false;
    folded = false;
    literal = false;
  } else {
    folded = !iskey;
    literal = !iskey;
  }

  single = true;
  double = new StringBuilder(object);

  sawLineFeed = false;
  linePosition = 0;
  longestLine = 0;

  indent = state.indent * level;
  max = state.lineWidth;
  if (max === -1) {
    // Replace -1 with biggest ingeger number according to
    // http://ecma262-5.com/ELS5_HTML.htm#Section_8.5
    max = 9007199254740991;
  }

  if (indent < 40) {
    max -= indent;
  } else {
    max = 40;
  }

  for (position = 0; position < object.length; position++) {
    character = object.charCodeAt(position);
    if (simple) {
      // Characters that can never appear in the simple scalar
      if (!simpleChar(character)) {
        simple = false;
      } else {
        // Still simple.  If we make it all the way through like
        // this, then we can just dump the string as-is.
        continue;
      }
    }

    if (single && character === CHAR_SINGLE_QUOTE) {
      single = false;
    }

    escapeSeq = ESCAPE_SEQUENCES[character];
    hexEsc = needsHexEscape(character);

    if (!escapeSeq && !hexEsc) {
      continue;
    }

    if (character !== CHAR_LINE_FEED &&
        character !== CHAR_DOUBLE_QUOTE &&
        character !== CHAR_SINGLE_QUOTE) {
      folded = false;
      literal = false;
    } else if (character === CHAR_LINE_FEED) {
      sawLineFeed = true;
      single = false;
      if (position > 0) {
        previous = object.charCodeAt(position - 1);
        if (previous === CHAR_SPACE) {
          literal = false;
          folded = false;
        }
      }
      if (folded) {
        lineLength = position - linePosition;
        linePosition = position;
        if (lineLength > longestLine) {
          longestLine = lineLength;
        }
      }
    }

    if (character !== CHAR_DOUBLE_QUOTE) {
      single = false;
    }

    double.takeUpTo(position);
    double.escapeChar();
  }

  if (simple && testImplicitResolving(state, object)) {
    simple = false;
  }

  modifier = '';
  if (folded || literal) {
    trailingLineBreaks = 0;
    if (object.charCodeAt(object.length - 1) === CHAR_LINE_FEED) {
      trailingLineBreaks += 1;
      if (object.charCodeAt(object.length - 2) === CHAR_LINE_FEED) {
        trailingLineBreaks += 1;
      }
    }

    if (trailingLineBreaks === 0) {
      modifier = '-';
    } else if (trailingLineBreaks === 2) {
      modifier = '+';
    }
  }

  if (literal && longestLine < max) {
    folded = false;
  }

  // If it's literally one line, then don't bother with the literal.
  // We may still want to do a fold, though, if it's a super long line.
  if (!sawLineFeed) {
    literal = false;
  }

  if (simple) {
    state.dump = object;
  } else if (single) {
    state.dump = '\'' + object + '\'';
  } else if (folded) {
    result = fold(object, max);
    state.dump = '>' + modifier + '\n' + indentString(result, indent);
  } else if (literal) {
    if (!modifier) {
      object = object.replace(/\n$/, '');
    }
    state.dump = '|' + modifier + '\n' + indentString(object, indent);
  } else if (double) {
    double.finish();
    state.dump = '"' + double.result + '"';
  } else {
    throw new Error('Failed to dump scalar value');
  }

  return;
}

// The `trailing` var is a regexp match of any trailing `\n` characters.
//
// There are three cases we care about:
//
// 1. One trailing `\n` on the string.  Just use `|` or `>`.
//    This is the assumed default. (trailing = null)
// 2. No trailing `\n` on the string.  Use `|-` or `>-` to "chomp" the end.
// 3. More than one trailing `\n` on the string.  Use `|+` or `>+`.
//
// In the case of `>+`, these line breaks are *not* doubled (like the line
// breaks within the string), so it's important to only end with the exact
// same number as we started.
function fold(object, max) {
  var result = '',
      position = 0,
      length = object.length,
      trailing = /\n+$/.exec(object),
      newLine;

  if (trailing) {
    length = trailing.index + 1;
  }

  while (position < length) {
    newLine = object.indexOf('\n', position);
    if (newLine > length || newLine === -1) {
      if (result) {
        result += '\n\n';
      }
      result += foldLine(object.slice(position, length), max);
      position = length;
    } else {
      if (result) {
        result += '\n\n';
      }
      result += foldLine(object.slice(position, newLine), max);
      position = newLine + 1;
    }
  }
  if (trailing && trailing[0] !== '\n') {
    result += trailing[0];
  }

  return result;
}

function foldLine(line, max) {
  if (line === '') {
    return line;
  }

  var foldRe = /[^\s] [^\s]/g,
      result = '',
      prevMatch = 0,
      foldStart = 0,
      match = foldRe.exec(line),
      index,
      foldEnd,
      folded;

  while (match) {
    index = match.index;

    // when we cross the max len, if the previous match would've
    // been ok, use that one, and carry on.  If there was no previous
    // match on this fold section, then just have a long line.
    if (index - foldStart > max) {
      if (prevMatch !== foldStart) {
        foldEnd = prevMatch;
      } else {
        foldEnd = index;
      }

      if (result) {
        result += '\n';
      }
      folded = line.slice(foldStart, foldEnd);
      result += folded;
      foldStart = foldEnd + 1;
    }
    prevMatch = index + 1;
    match = foldRe.exec(line);
  }

  if (result) {
    result += '\n';
  }

  // if we end up with one last word at the end, then the last bit might
  // be slightly bigger than we wanted, because we exited out of the loop.
  if (foldStart !== prevMatch && line.length - foldStart > max) {
    result += line.slice(foldStart, prevMatch) + '\n' +
              line.slice(prevMatch + 1);
  } else {
    result += line.slice(foldStart);
  }

  return result;
}

// Returns true if character can be found in a simple scalar
function simpleChar(character) {
  return CHAR_TAB                  !== character &&
         CHAR_LINE_FEED            !== character &&
         CHAR_CARRIAGE_RETURN      !== character &&
         CHAR_COMMA                !== character &&
         CHAR_LEFT_SQUARE_BRACKET  !== character &&
         CHAR_RIGHT_SQUARE_BRACKET !== character &&
         CHAR_LEFT_CURLY_BRACKET   !== character &&
         CHAR_RIGHT_CURLY_BRACKET  !== character &&
         CHAR_SHARP                !== character &&
         CHAR_AMPERSAND            !== character &&
         CHAR_ASTERISK             !== character &&
         CHAR_EXCLAMATION          !== character &&
         CHAR_VERTICAL_LINE        !== character &&
         CHAR_GREATER_THAN         !== character &&
         CHAR_SINGLE_QUOTE         !== character &&
         CHAR_DOUBLE_QUOTE         !== character &&
         CHAR_PERCENT              !== character &&
         CHAR_COLON                !== character &&
         !ESCAPE_SEQUENCES[character]            &&
         !needsHexEscape(character);
}

// Returns true if the character code needs to be escaped.
function needsHexEscape(character) {
  return !((0x00020 <= character && character <= 0x00007E) ||
           (0x00085 === character)                         ||
           (0x000A0 <= character && character <= 0x00D7FF) ||
           (0x0E000 <= character && character <= 0x00FFFD) ||
           (0x10000 <= character && character <= 0x10FFFF));
}

function writeFlowSequence(state, level, object) {
  var _result = '',
      _tag    = state.tag,
      index,
      length;

  for (index = 0, length = object.length; index < length; index += 1) {
    // Write only valid elements.
    if (writeNode(state, level, object[index], false, false)) {
      if (0 !== index) {
        _result += ', ';
      }
      _result += state.dump;
    }
  }

  state.tag = _tag;
  state.dump = '[' + _result + ']';
}

function writeBlockSequence(state, level, object, compact) {
  var _result = '',
      _tag    = state.tag,
      index,
      length;

  for (index = 0, length = object.length; index < length; index += 1) {
    // Write only valid elements.
    if (writeNode(state, level + 1, object[index], true, true)) {
      if (!compact || 0 !== index) {
        _result += generateNextLine(state, level);
      }
      _result += '- ' + state.dump;
    }
  }

  state.tag = _tag;
  state.dump = _result || '[]'; // Empty sequence if no valid values.
}

function writeFlowMapping(state, level, object) {
  var _result       = '',
      _tag          = state.tag,
      objectKeyList = Object.keys(object),
      index,
      length,
      objectKey,
      objectValue,
      pairBuffer;

  for (index = 0, length = objectKeyList.length; index < length; index += 1) {
    pairBuffer = '';

    if (0 !== index) {
      pairBuffer += ', ';
    }

    objectKey = objectKeyList[index];
    objectValue = object[objectKey];

    if (!writeNode(state, level, objectKey, false, false)) {
      continue; // Skip this pair because of invalid key;
    }

    if (state.dump.length > 1024) {
      pairBuffer += '? ';
    }

    pairBuffer += state.dump + ': ';

    if (!writeNode(state, level, objectValue, false, false)) {
      continue; // Skip this pair because of invalid value.
    }

    pairBuffer += state.dump;

    // Both key and value are valid.
    _result += pairBuffer;
  }

  state.tag = _tag;
  state.dump = '{' + _result + '}';
}

function writeBlockMapping(state, level, object, compact) {
  var _result       = '',
      _tag          = state.tag,
      objectKeyList = Object.keys(object),
      index,
      length,
      objectKey,
      objectValue,
      explicitPair,
      pairBuffer;

  // Allow sorting keys so that the output file is deterministic
  if (state.sortKeys === true) {
    // Default sorting
    objectKeyList.sort();
  } else if (typeof state.sortKeys === 'function') {
    // Custom sort function
    objectKeyList.sort(state.sortKeys);
  } else if (state.sortKeys) {
    // Something is wrong
    throw new YAMLException('sortKeys must be a boolean or a function');
  }

  for (index = 0, length = objectKeyList.length; index < length; index += 1) {
    pairBuffer = '';

    if (!compact || 0 !== index) {
      pairBuffer += generateNextLine(state, level);
    }

    objectKey = objectKeyList[index];
    objectValue = object[objectKey];

    if (!writeNode(state, level + 1, objectKey, true, true, true)) {
      continue; // Skip this pair because of invalid key.
    }

    explicitPair = (null !== state.tag && '?' !== state.tag) ||
                   (state.dump && state.dump.length > 1024);

    if (explicitPair) {
      if (state.dump && CHAR_LINE_FEED === state.dump.charCodeAt(0)) {
        pairBuffer += '?';
      } else {
        pairBuffer += '? ';
      }
    }

    pairBuffer += state.dump;

    if (explicitPair) {
      pairBuffer += generateNextLine(state, level);
    }

    if (!writeNode(state, level + 1, objectValue, true, explicitPair)) {
      continue; // Skip this pair because of invalid value.
    }

    if (state.dump && CHAR_LINE_FEED === state.dump.charCodeAt(0)) {
      pairBuffer += ':';
    } else {
      pairBuffer += ': ';
    }

    pairBuffer += state.dump;

    // Both key and value are valid.
    _result += pairBuffer;
  }

  state.tag = _tag;
  state.dump = _result || '{}'; // Empty mapping if no valid pairs.
}

function detectType(state, object, explicit) {
  var _result, typeList, index, length, type, style;

  typeList = explicit ? state.explicitTypes : state.implicitTypes;

  for (index = 0, length = typeList.length; index < length; index += 1) {
    type = typeList[index];

    if ((type.instanceOf  || type.predicate) &&
        (!type.instanceOf || (('object' === typeof object) && (object instanceof type.instanceOf))) &&
        (!type.predicate  || type.predicate(object))) {

      state.tag = explicit ? type.tag : '?';

      if (type.represent) {
        style = state.styleMap[type.tag] || type.defaultStyle;

        if ('[object Function]' === _toString.call(type.represent)) {
          _result = type.represent(object, style);
        } else if (_hasOwnProperty.call(type.represent, style)) {
          _result = type.represent[style](object, style);
        } else {
          throw new YAMLException('!<' + type.tag + '> tag resolver accepts not "' + style + '" style');
        }

        state.dump = _result;
      }

      return true;
    }
  }

  return false;
}

// Serializes `object` and writes it to global `result`.
// Returns true on success, or false on invalid object.
//
function writeNode(state, level, object, block, compact, iskey) {
  state.tag = null;
  state.dump = object;

  if (!detectType(state, object, false)) {
    detectType(state, object, true);
  }

  var type = _toString.call(state.dump);

  if (block) {
    block = (0 > state.flowLevel || state.flowLevel > level);
  }

  var objectOrArray = '[object Object]' === type || '[object Array]' === type,
      duplicateIndex,
      duplicate;

  if (objectOrArray) {
    duplicateIndex = state.duplicates.indexOf(object);
    duplicate = duplicateIndex !== -1;
  }

  if ((null !== state.tag && '?' !== state.tag) || duplicate || (2 !== state.indent && level > 0)) {
    compact = false;
  }

  if (duplicate && state.usedDuplicates[duplicateIndex]) {
    state.dump = '*ref_' + duplicateIndex;
  } else {
    if (objectOrArray && duplicate && !state.usedDuplicates[duplicateIndex]) {
      state.usedDuplicates[duplicateIndex] = true;
    }
    if ('[object Object]' === type) {
      if (block && (0 !== Object.keys(state.dump).length)) {
        writeBlockMapping(state, level, state.dump, compact);
        if (duplicate) {
          state.dump = '&ref_' + duplicateIndex + state.dump;
        }
      } else {
        writeFlowMapping(state, level, state.dump);
        if (duplicate) {
          state.dump = '&ref_' + duplicateIndex + ' ' + state.dump;
        }
      }
    } else if ('[object Array]' === type) {
      if (block && (0 !== state.dump.length)) {
        writeBlockSequence(state, level, state.dump, compact);
        if (duplicate) {
          state.dump = '&ref_' + duplicateIndex + state.dump;
        }
      } else {
        writeFlowSequence(state, level, state.dump);
        if (duplicate) {
          state.dump = '&ref_' + duplicateIndex + ' ' + state.dump;
        }
      }
    } else if ('[object String]' === type) {
      if ('?' !== state.tag) {
        writeScalar(state, state.dump, level, iskey);
      }
    } else {
      if (state.skipInvalid) {
        return false;
      }
      throw new YAMLException('unacceptable kind of an object to dump ' + type);
    }

    if (null !== state.tag && '?' !== state.tag) {
      state.dump = '!<' + state.tag + '> ' + state.dump;
    }
  }

  return true;
}

function getDuplicateReferences(object, state) {
  var objects = [],
      duplicatesIndexes = [],
      index,
      length;

  inspectNode(object, objects, duplicatesIndexes);

  for (index = 0, length = duplicatesIndexes.length; index < length; index += 1) {
    state.duplicates.push(objects[duplicatesIndexes[index]]);
  }
  state.usedDuplicates = new Array(length);
}

function inspectNode(object, objects, duplicatesIndexes) {
  var objectKeyList,
      index,
      length;

  if (null !== object && 'object' === typeof object) {
    index = objects.indexOf(object);
    if (-1 !== index) {
      if (-1 === duplicatesIndexes.indexOf(index)) {
        duplicatesIndexes.push(index);
      }
    } else {
      objects.push(object);

      if (Array.isArray(object)) {
        for (index = 0, length = object.length; index < length; index += 1) {
          inspectNode(object[index], objects, duplicatesIndexes);
        }
      } else {
        objectKeyList = Object.keys(object);

        for (index = 0, length = objectKeyList.length; index < length; index += 1) {
          inspectNode(object[objectKeyList[index]], objects, duplicatesIndexes);
        }
      }
    }
  }
}

function dump(input, options) {
  options = options || {};

  var state = new State(options);

  getDuplicateReferences(input, state);

  if (writeNode(state, 0, input, true, true)) {
    return state.dump + '\n';
  }
  return '';
}

function safeDump(input, options) {
  return dump(input, common.extend({ schema: DEFAULT_SAFE_SCHEMA }, options));
}

module.exports.dump     = dump;
module.exports.safeDump = safeDump;

},{"./common":23,"./exception":25,"./schema/default_full":30,"./schema/default_safe":31}],25:[function(require,module,exports){
// YAML error class. http://stackoverflow.com/questions/8458984
//
'use strict';


var inherits = require('inherit');


function YAMLException(reason, mark) {
  // Super constructor
  Error.call(this);

  // Include stack trace in error object
  if (Error.captureStackTrace) {
    // Chrome and NodeJS
    Error.captureStackTrace(this, this.constructor);
  } else {
    // FF, IE 10+ and Safari 6+. Fallback for others
    this.stack = (new Error()).stack || '';
  }

  this.name = 'YAMLException';
  this.reason = reason;
  this.mark = mark;
  this.message = (this.reason || '(unknown reason)') + (this.mark ? ' ' + this.mark.toString() : '');
}


// Inherit from Error
inherits(YAMLException, Error);


YAMLException.prototype.toString = function toString(compact) {
  var result = this.name + ': ';

  result += this.reason || '(unknown reason)';

  if (!compact && this.mark) {
    result += ' ' + this.mark.toString();
  }

  return result;
};


module.exports = YAMLException;

},{"inherit":52}],26:[function(require,module,exports){
'use strict';

/*eslint-disable max-len,no-use-before-define*/

var common              = require('./common');
var YAMLException       = require('./exception');
var Mark                = require('./mark');
var DEFAULT_SAFE_SCHEMA = require('./schema/default_safe');
var DEFAULT_FULL_SCHEMA = require('./schema/default_full');


var _hasOwnProperty = Object.prototype.hasOwnProperty;


var CONTEXT_FLOW_IN   = 1;
var CONTEXT_FLOW_OUT  = 2;
var CONTEXT_BLOCK_IN  = 3;
var CONTEXT_BLOCK_OUT = 4;


var CHOMPING_CLIP  = 1;
var CHOMPING_STRIP = 2;
var CHOMPING_KEEP  = 3;


var PATTERN_NON_PRINTABLE         = /[\x00-\x08\x0B\x0C\x0E-\x1F\x7F-\x84\x86-\x9F\uFFFE\uFFFF]|[\uD800-\uDBFF](?![\uDC00-\uDFFF])|(?:[^\uD800-\uDBFF]|^)[\uDC00-\uDFFF]/;
var PATTERN_NON_ASCII_LINE_BREAKS = /[\x85\u2028\u2029]/;
var PATTERN_FLOW_INDICATORS       = /[,\[\]\{\}]/;
var PATTERN_TAG_HANDLE            = /^(?:!|!!|![a-z\-]+!)$/i;
var PATTERN_TAG_URI               = /^(?:!|[^,\[\]\{\}])(?:%[0-9a-f]{2}|[0-9a-z\-#;\/\?:@&=\+\$,_\.!~\*'\(\)\[\]])*$/i;


function is_EOL(c) {
  return (c === 0x0A/* LF */) || (c === 0x0D/* CR */);
}

function is_WHITE_SPACE(c) {
  return (c === 0x09/* Tab */) || (c === 0x20/* Space */);
}

function is_WS_OR_EOL(c) {
  return (c === 0x09/* Tab */) ||
         (c === 0x20/* Space */) ||
         (c === 0x0A/* LF */) ||
         (c === 0x0D/* CR */);
}

function is_FLOW_INDICATOR(c) {
  return 0x2C/* , */ === c ||
         0x5B/* [ */ === c ||
         0x5D/* ] */ === c ||
         0x7B/* { */ === c ||
         0x7D/* } */ === c;
}

function fromHexCode(c) {
  var lc;

  if ((0x30/* 0 */ <= c) && (c <= 0x39/* 9 */)) {
    return c - 0x30;
  }

  /*eslint-disable no-bitwise*/
  lc = c | 0x20;

  if ((0x61/* a */ <= lc) && (lc <= 0x66/* f */)) {
    return lc - 0x61 + 10;
  }

  return -1;
}

function escapedHexLen(c) {
  if (c === 0x78/* x */) { return 2; }
  if (c === 0x75/* u */) { return 4; }
  if (c === 0x55/* U */) { return 8; }
  return 0;
}

function fromDecimalCode(c) {
  if ((0x30/* 0 */ <= c) && (c <= 0x39/* 9 */)) {
    return c - 0x30;
  }

  return -1;
}

function simpleEscapeSequence(c) {
  return (c === 0x30/* 0 */) ? '\x00' :
        (c === 0x61/* a */) ? '\x07' :
        (c === 0x62/* b */) ? '\x08' :
        (c === 0x74/* t */) ? '\x09' :
        (c === 0x09/* Tab */) ? '\x09' :
        (c === 0x6E/* n */) ? '\x0A' :
        (c === 0x76/* v */) ? '\x0B' :
        (c === 0x66/* f */) ? '\x0C' :
        (c === 0x72/* r */) ? '\x0D' :
        (c === 0x65/* e */) ? '\x1B' :
        (c === 0x20/* Space */) ? ' ' :
        (c === 0x22/* " */) ? '\x22' :
        (c === 0x2F/* / */) ? '/' :
        (c === 0x5C/* \ */) ? '\x5C' :
        (c === 0x4E/* N */) ? '\x85' :
        (c === 0x5F/* _ */) ? '\xA0' :
        (c === 0x4C/* L */) ? '\u2028' :
        (c === 0x50/* P */) ? '\u2029' : '';
}

function charFromCodepoint(c) {
  if (c <= 0xFFFF) {
    return String.fromCharCode(c);
  }
  // Encode UTF-16 surrogate pair
  // https://en.wikipedia.org/wiki/UTF-16#Code_points_U.2B010000_to_U.2B10FFFF
  return String.fromCharCode(((c - 0x010000) >> 10) + 0xD800,
                             ((c - 0x010000) & 0x03FF) + 0xDC00);
}

var simpleEscapeCheck = new Array(256); // integer, for fast access
var simpleEscapeMap = new Array(256);
for (var i = 0; i < 256; i++) {
  simpleEscapeCheck[i] = simpleEscapeSequence(i) ? 1 : 0;
  simpleEscapeMap[i] = simpleEscapeSequence(i);
}


function State(input, options) {
  this.input = input;

  this.filename  = options['filename']  || null;
  this.schema    = options['schema']    || DEFAULT_FULL_SCHEMA;
  this.onWarning = options['onWarning'] || null;
  this.legacy    = options['legacy']    || false;

  this.implicitTypes = this.schema.compiledImplicit;
  this.typeMap       = this.schema.compiledTypeMap;

  this.length     = input.length;
  this.position   = 0;
  this.line       = 0;
  this.lineStart  = 0;
  this.lineIndent = 0;

  this.documents = [];

  /*
  this.version;
  this.checkLineBreaks;
  this.tagMap;
  this.anchorMap;
  this.tag;
  this.anchor;
  this.kind;
  this.result;*/

}


function generateError(state, message) {
  return new YAMLException(
    message,
    new Mark(state.filename, state.input, state.position, state.line, (state.position - state.lineStart)));
}

function throwError(state, message) {
  throw generateError(state, message);
}

function throwWarning(state, message) {
  if (state.onWarning) {
    state.onWarning.call(null, generateError(state, message));
  }
}


var directiveHandlers = {

  YAML: function handleYamlDirective(state, name, args) {

      var match, major, minor;

      if (null !== state.version) {
        throwError(state, 'duplication of %YAML directive');
      }

      if (1 !== args.length) {
        throwError(state, 'YAML directive accepts exactly one argument');
      }

      match = /^([0-9]+)\.([0-9]+)$/.exec(args[0]);

      if (null === match) {
        throwError(state, 'ill-formed argument of the YAML directive');
      }

      major = parseInt(match[1], 10);
      minor = parseInt(match[2], 10);

      if (1 !== major) {
        throwError(state, 'unacceptable YAML version of the document');
      }

      state.version = args[0];
      state.checkLineBreaks = (minor < 2);

      if (1 !== minor && 2 !== minor) {
        throwWarning(state, 'unsupported YAML version of the document');
      }
    },

  TAG: function handleTagDirective(state, name, args) {

      var handle, prefix;

      if (2 !== args.length) {
        throwError(state, 'TAG directive accepts exactly two arguments');
      }

      handle = args[0];
      prefix = args[1];

      if (!PATTERN_TAG_HANDLE.test(handle)) {
        throwError(state, 'ill-formed tag handle (first argument) of the TAG directive');
      }

      if (_hasOwnProperty.call(state.tagMap, handle)) {
        throwError(state, 'there is a previously declared suffix for "' + handle + '" tag handle');
      }

      if (!PATTERN_TAG_URI.test(prefix)) {
        throwError(state, 'ill-formed tag prefix (second argument) of the TAG directive');
      }

      state.tagMap[handle] = prefix;
    }
};


function captureSegment(state, start, end, checkJson) {
  var _position, _length, _character, _result;

  if (start < end) {
    _result = state.input.slice(start, end);

    if (checkJson) {
      for (_position = 0, _length = _result.length;
           _position < _length;
           _position += 1) {
        _character = _result.charCodeAt(_position);
        if (!(0x09 === _character ||
              0x20 <= _character && _character <= 0x10FFFF)) {
          throwError(state, 'expected valid JSON character');
        }
      }
    } else if (PATTERN_NON_PRINTABLE.test(_result)) {
      throwError(state, 'the stream contains non-printable characters');
    }

    state.result += _result;
  }
}

function mergeMappings(state, destination, source) {
  var sourceKeys, key, index, quantity;

  if (!common.isObject(source)) {
    throwError(state, 'cannot merge mappings; the provided source object is unacceptable');
  }

  sourceKeys = Object.keys(source);

  for (index = 0, quantity = sourceKeys.length; index < quantity; index += 1) {
    key = sourceKeys[index];

    if (!_hasOwnProperty.call(destination, key)) {
      destination[key] = source[key];
    }
  }
}

function storeMappingPair(state, _result, keyTag, keyNode, valueNode) {
  var index, quantity;

  keyNode = String(keyNode);

  if (null === _result) {
    _result = {};
  }

  if ('tag:yaml.org,2002:merge' === keyTag) {
    if (Array.isArray(valueNode)) {
      for (index = 0, quantity = valueNode.length; index < quantity; index += 1) {
        mergeMappings(state, _result, valueNode[index]);
      }
    } else {
      mergeMappings(state, _result, valueNode);
    }
  } else {
    _result[keyNode] = valueNode;
  }

  return _result;
}

function readLineBreak(state) {
  var ch;

  ch = state.input.charCodeAt(state.position);

  if (0x0A/* LF */ === ch) {
    state.position++;
  } else if (0x0D/* CR */ === ch) {
    state.position++;
    if (0x0A/* LF */ === state.input.charCodeAt(state.position)) {
      state.position++;
    }
  } else {
    throwError(state, 'a line break is expected');
  }

  state.line += 1;
  state.lineStart = state.position;
}

function skipSeparationSpace(state, allowComments, checkIndent) {
  var lineBreaks = 0,
      ch = state.input.charCodeAt(state.position);

  while (0 !== ch) {
    while (is_WHITE_SPACE(ch)) {
      ch = state.input.charCodeAt(++state.position);
    }

    if (allowComments && 0x23/* # */ === ch) {
      do {
        ch = state.input.charCodeAt(++state.position);
      } while (ch !== 0x0A/* LF */ && ch !== 0x0D/* CR */ && 0 !== ch);
    }

    if (is_EOL(ch)) {
      readLineBreak(state);

      ch = state.input.charCodeAt(state.position);
      lineBreaks++;
      state.lineIndent = 0;

      while (0x20/* Space */ === ch) {
        state.lineIndent++;
        ch = state.input.charCodeAt(++state.position);
      }
    } else {
      break;
    }
  }

  if (-1 !== checkIndent && 0 !== lineBreaks && state.lineIndent < checkIndent) {
    throwWarning(state, 'deficient indentation');
  }

  return lineBreaks;
}

function testDocumentSeparator(state) {
  var _position = state.position,
      ch;

  ch = state.input.charCodeAt(_position);

  // Condition state.position === state.lineStart is tested
  // in parent on each call, for efficiency. No needs to test here again.
  if ((0x2D/* - */ === ch || 0x2E/* . */ === ch) &&
      state.input.charCodeAt(_position + 1) === ch &&
      state.input.charCodeAt(_position + 2) === ch) {

    _position += 3;

    ch = state.input.charCodeAt(_position);

    if (ch === 0 || is_WS_OR_EOL(ch)) {
      return true;
    }
  }

  return false;
}

function writeFoldedLines(state, count) {
  if (1 === count) {
    state.result += ' ';
  } else if (count > 1) {
    state.result += common.repeat('\n', count - 1);
  }
}


function readPlainScalar(state, nodeIndent, withinFlowCollection) {
  var preceding,
      following,
      captureStart,
      captureEnd,
      hasPendingContent,
      _line,
      _lineStart,
      _lineIndent,
      _kind = state.kind,
      _result = state.result,
      ch;

  ch = state.input.charCodeAt(state.position);

  if (is_WS_OR_EOL(ch)             ||
      is_FLOW_INDICATOR(ch)        ||
      0x23/* # */           === ch ||
      0x26/* & */           === ch ||
      0x2A/* * */           === ch ||
      0x21/* ! */           === ch ||
      0x7C/* | */           === ch ||
      0x3E/* > */           === ch ||
      0x27/* ' */           === ch ||
      0x22/* " */           === ch ||
      0x25/* % */           === ch ||
      0x40/* @ */           === ch ||
      0x60/* ` */           === ch) {
    return false;
  }

  if (0x3F/* ? */ === ch || 0x2D/* - */ === ch) {
    following = state.input.charCodeAt(state.position + 1);

    if (is_WS_OR_EOL(following) ||
        withinFlowCollection && is_FLOW_INDICATOR(following)) {
      return false;
    }
  }

  state.kind = 'scalar';
  state.result = '';
  captureStart = captureEnd = state.position;
  hasPendingContent = false;

  while (0 !== ch) {
    if (0x3A/* : */ === ch) {
      following = state.input.charCodeAt(state.position + 1);

      if (is_WS_OR_EOL(following) ||
          withinFlowCollection && is_FLOW_INDICATOR(following)) {
        break;
      }

    } else if (0x23/* # */ === ch) {
      preceding = state.input.charCodeAt(state.position - 1);

      if (is_WS_OR_EOL(preceding)) {
        break;
      }

    } else if ((state.position === state.lineStart && testDocumentSeparator(state)) ||
               withinFlowCollection && is_FLOW_INDICATOR(ch)) {
      break;

    } else if (is_EOL(ch)) {
      _line = state.line;
      _lineStart = state.lineStart;
      _lineIndent = state.lineIndent;
      skipSeparationSpace(state, false, -1);

      if (state.lineIndent >= nodeIndent) {
        hasPendingContent = true;
        ch = state.input.charCodeAt(state.position);
        continue;
      } else {
        state.position = captureEnd;
        state.line = _line;
        state.lineStart = _lineStart;
        state.lineIndent = _lineIndent;
        break;
      }
    }

    if (hasPendingContent) {
      captureSegment(state, captureStart, captureEnd, false);
      writeFoldedLines(state, state.line - _line);
      captureStart = captureEnd = state.position;
      hasPendingContent = false;
    }

    if (!is_WHITE_SPACE(ch)) {
      captureEnd = state.position + 1;
    }

    ch = state.input.charCodeAt(++state.position);
  }

  captureSegment(state, captureStart, captureEnd, false);

  if (state.result) {
    return true;
  }

  state.kind = _kind;
  state.result = _result;
  return false;
}

function readSingleQuotedScalar(state, nodeIndent) {
  var ch,
      captureStart, captureEnd;

  ch = state.input.charCodeAt(state.position);

  if (0x27/* ' */ !== ch) {
    return false;
  }

  state.kind = 'scalar';
  state.result = '';
  state.position++;
  captureStart = captureEnd = state.position;

  while (0 !== (ch = state.input.charCodeAt(state.position))) {
    if (0x27/* ' */ === ch) {
      captureSegment(state, captureStart, state.position, true);
      ch = state.input.charCodeAt(++state.position);

      if (0x27/* ' */ === ch) {
        captureStart = captureEnd = state.position;
        state.position++;
      } else {
        return true;
      }

    } else if (is_EOL(ch)) {
      captureSegment(state, captureStart, captureEnd, true);
      writeFoldedLines(state, skipSeparationSpace(state, false, nodeIndent));
      captureStart = captureEnd = state.position;

    } else if (state.position === state.lineStart && testDocumentSeparator(state)) {
      throwError(state, 'unexpected end of the document within a single quoted scalar');

    } else {
      state.position++;
      captureEnd = state.position;
    }
  }

  throwError(state, 'unexpected end of the stream within a single quoted scalar');
}

function readDoubleQuotedScalar(state, nodeIndent) {
  var captureStart,
      captureEnd,
      hexLength,
      hexResult,
      tmp,
      ch;

  ch = state.input.charCodeAt(state.position);

  if (0x22/* " */ !== ch) {
    return false;
  }

  state.kind = 'scalar';
  state.result = '';
  state.position++;
  captureStart = captureEnd = state.position;

  while (0 !== (ch = state.input.charCodeAt(state.position))) {
    if (0x22/* " */ === ch) {
      captureSegment(state, captureStart, state.position, true);
      state.position++;
      return true;

    } else if (0x5C/* \ */ === ch) {
      captureSegment(state, captureStart, state.position, true);
      ch = state.input.charCodeAt(++state.position);

      if (is_EOL(ch)) {
        skipSeparationSpace(state, false, nodeIndent);

        // TODO: rework to inline fn with no type cast?
      } else if (ch < 256 && simpleEscapeCheck[ch]) {
        state.result += simpleEscapeMap[ch];
        state.position++;

      } else if ((tmp = escapedHexLen(ch)) > 0) {
        hexLength = tmp;
        hexResult = 0;

        for (; hexLength > 0; hexLength--) {
          ch = state.input.charCodeAt(++state.position);

          if ((tmp = fromHexCode(ch)) >= 0) {
            hexResult = (hexResult << 4) + tmp;

          } else {
            throwError(state, 'expected hexadecimal character');
          }
        }

        state.result += charFromCodepoint(hexResult);

        state.position++;

      } else {
        throwError(state, 'unknown escape sequence');
      }

      captureStart = captureEnd = state.position;

    } else if (is_EOL(ch)) {
      captureSegment(state, captureStart, captureEnd, true);
      writeFoldedLines(state, skipSeparationSpace(state, false, nodeIndent));
      captureStart = captureEnd = state.position;

    } else if (state.position === state.lineStart && testDocumentSeparator(state)) {
      throwError(state, 'unexpected end of the document within a double quoted scalar');

    } else {
      state.position++;
      captureEnd = state.position;
    }
  }

  throwError(state, 'unexpected end of the stream within a double quoted scalar');
}

function readFlowCollection(state, nodeIndent) {
  var readNext = true,
      _line,
      _tag     = state.tag,
      _result,
      _anchor  = state.anchor,
      following,
      terminator,
      isPair,
      isExplicitPair,
      isMapping,
      keyNode,
      keyTag,
      valueNode,
      ch;

  ch = state.input.charCodeAt(state.position);

  if (ch === 0x5B/* [ */) {
    terminator = 0x5D;/* ] */
    isMapping = false;
    _result = [];
  } else if (ch === 0x7B/* { */) {
    terminator = 0x7D;/* } */
    isMapping = true;
    _result = {};
  } else {
    return false;
  }

  if (null !== state.anchor) {
    state.anchorMap[state.anchor] = _result;
  }

  ch = state.input.charCodeAt(++state.position);

  while (0 !== ch) {
    skipSeparationSpace(state, true, nodeIndent);

    ch = state.input.charCodeAt(state.position);

    if (ch === terminator) {
      state.position++;
      state.tag = _tag;
      state.anchor = _anchor;
      state.kind = isMapping ? 'mapping' : 'sequence';
      state.result = _result;
      return true;
    } else if (!readNext) {
      throwError(state, 'missed comma between flow collection entries');
    }

    keyTag = keyNode = valueNode = null;
    isPair = isExplicitPair = false;

    if (0x3F/* ? */ === ch) {
      following = state.input.charCodeAt(state.position + 1);

      if (is_WS_OR_EOL(following)) {
        isPair = isExplicitPair = true;
        state.position++;
        skipSeparationSpace(state, true, nodeIndent);
      }
    }

    _line = state.line;
    composeNode(state, nodeIndent, CONTEXT_FLOW_IN, false, true);
    keyTag = state.tag;
    keyNode = state.result;
    skipSeparationSpace(state, true, nodeIndent);

    ch = state.input.charCodeAt(state.position);

    if ((isExplicitPair || state.line === _line) && 0x3A/* : */ === ch) {
      isPair = true;
      ch = state.input.charCodeAt(++state.position);
      skipSeparationSpace(state, true, nodeIndent);
      composeNode(state, nodeIndent, CONTEXT_FLOW_IN, false, true);
      valueNode = state.result;
    }

    if (isMapping) {
      storeMappingPair(state, _result, keyTag, keyNode, valueNode);
    } else if (isPair) {
      _result.push(storeMappingPair(state, null, keyTag, keyNode, valueNode));
    } else {
      _result.push(keyNode);
    }

    skipSeparationSpace(state, true, nodeIndent);

    ch = state.input.charCodeAt(state.position);

    if (0x2C/* , */ === ch) {
      readNext = true;
      ch = state.input.charCodeAt(++state.position);
    } else {
      readNext = false;
    }
  }

  throwError(state, 'unexpected end of the stream within a flow collection');
}

function readBlockScalar(state, nodeIndent) {
  var captureStart,
      folding,
      chomping       = CHOMPING_CLIP,
      detectedIndent = false,
      textIndent     = nodeIndent,
      emptyLines     = 0,
      atMoreIndented = false,
      tmp,
      ch;

  ch = state.input.charCodeAt(state.position);

  if (ch === 0x7C/* | */) {
    folding = false;
  } else if (ch === 0x3E/* > */) {
    folding = true;
  } else {
    return false;
  }

  state.kind = 'scalar';
  state.result = '';

  while (0 !== ch) {
    ch = state.input.charCodeAt(++state.position);

    if (0x2B/* + */ === ch || 0x2D/* - */ === ch) {
      if (CHOMPING_CLIP === chomping) {
        chomping = (0x2B/* + */ === ch) ? CHOMPING_KEEP : CHOMPING_STRIP;
      } else {
        throwError(state, 'repeat of a chomping mode identifier');
      }

    } else if ((tmp = fromDecimalCode(ch)) >= 0) {
      if (tmp === 0) {
        throwError(state, 'bad explicit indentation width of a block scalar; it cannot be less than one');
      } else if (!detectedIndent) {
        textIndent = nodeIndent + tmp - 1;
        detectedIndent = true;
      } else {
        throwError(state, 'repeat of an indentation width identifier');
      }

    } else {
      break;
    }
  }

  if (is_WHITE_SPACE(ch)) {
    do { ch = state.input.charCodeAt(++state.position); }
    while (is_WHITE_SPACE(ch));

    if (0x23/* # */ === ch) {
      do { ch = state.input.charCodeAt(++state.position); }
      while (!is_EOL(ch) && (0 !== ch));
    }
  }

  while (0 !== ch) {
    readLineBreak(state);
    state.lineIndent = 0;

    ch = state.input.charCodeAt(state.position);

    while ((!detectedIndent || state.lineIndent < textIndent) &&
           (0x20/* Space */ === ch)) {
      state.lineIndent++;
      ch = state.input.charCodeAt(++state.position);
    }

    if (!detectedIndent && state.lineIndent > textIndent) {
      textIndent = state.lineIndent;
    }

    if (is_EOL(ch)) {
      emptyLines++;
      continue;
    }

    // End of the scalar.
    if (state.lineIndent < textIndent) {

      // Perform the chomping.
      if (chomping === CHOMPING_KEEP) {
        state.result += common.repeat('\n', emptyLines);
      } else if (chomping === CHOMPING_CLIP) {
        if (detectedIndent) { // i.e. only if the scalar is not empty.
          state.result += '\n';
        }
      }

      // Break this `while` cycle and go to the funciton's epilogue.
      break;
    }

    // Folded style: use fancy rules to handle line breaks.
    if (folding) {

      // Lines starting with white space characters (more-indented lines) are not folded.
      if (is_WHITE_SPACE(ch)) {
        atMoreIndented = true;
        state.result += common.repeat('\n', emptyLines + 1);

      // End of more-indented block.
      } else if (atMoreIndented) {
        atMoreIndented = false;
        state.result += common.repeat('\n', emptyLines + 1);

      // Just one line break - perceive as the same line.
      } else if (0 === emptyLines) {
        if (detectedIndent) { // i.e. only if we have already read some scalar content.
          state.result += ' ';
        }

      // Several line breaks - perceive as different lines.
      } else {
        state.result += common.repeat('\n', emptyLines);
      }

    // Literal style: just add exact number of line breaks between content lines.
    } else if (detectedIndent) {
      // If current line isn't the first one - count line break from the last content line.
      state.result += common.repeat('\n', emptyLines + 1);
    } else {
      // In case of the first content line - count only empty lines.
      state.result += common.repeat('\n', emptyLines);
    }

    detectedIndent = true;
    emptyLines = 0;
    captureStart = state.position;

    while (!is_EOL(ch) && (0 !== ch)) {
      ch = state.input.charCodeAt(++state.position);
    }

    captureSegment(state, captureStart, state.position, false);
  }

  return true;
}

function readBlockSequence(state, nodeIndent) {
  var _line,
      _tag      = state.tag,
      _anchor   = state.anchor,
      _result   = [],
      following,
      detected  = false,
      ch;

  if (null !== state.anchor) {
    state.anchorMap[state.anchor] = _result;
  }

  ch = state.input.charCodeAt(state.position);

  while (0 !== ch) {

    if (0x2D/* - */ !== ch) {
      break;
    }

    following = state.input.charCodeAt(state.position + 1);

    if (!is_WS_OR_EOL(following)) {
      break;
    }

    detected = true;
    state.position++;

    if (skipSeparationSpace(state, true, -1)) {
      if (state.lineIndent <= nodeIndent) {
        _result.push(null);
        ch = state.input.charCodeAt(state.position);
        continue;
      }
    }

    _line = state.line;
    composeNode(state, nodeIndent, CONTEXT_BLOCK_IN, false, true);
    _result.push(state.result);
    skipSeparationSpace(state, true, -1);

    ch = state.input.charCodeAt(state.position);

    if ((state.line === _line || state.lineIndent > nodeIndent) && (0 !== ch)) {
      throwError(state, 'bad indentation of a sequence entry');
    } else if (state.lineIndent < nodeIndent) {
      break;
    }
  }

  if (detected) {
    state.tag = _tag;
    state.anchor = _anchor;
    state.kind = 'sequence';
    state.result = _result;
    return true;
  }
  return false;
}

function readBlockMapping(state, nodeIndent, flowIndent) {
  var following,
      allowCompact,
      _line,
      _tag          = state.tag,
      _anchor       = state.anchor,
      _result       = {},
      keyTag        = null,
      keyNode       = null,
      valueNode     = null,
      atExplicitKey = false,
      detected      = false,
      ch;

  if (null !== state.anchor) {
    state.anchorMap[state.anchor] = _result;
  }

  ch = state.input.charCodeAt(state.position);

  while (0 !== ch) {
    following = state.input.charCodeAt(state.position + 1);
    _line = state.line; // Save the current line.

    //
    // Explicit notation case. There are two separate blocks:
    // first for the key (denoted by "?") and second for the value (denoted by ":")
    //
    if ((0x3F/* ? */ === ch || 0x3A/* : */  === ch) && is_WS_OR_EOL(following)) {

      if (0x3F/* ? */ === ch) {
        if (atExplicitKey) {
          storeMappingPair(state, _result, keyTag, keyNode, null);
          keyTag = keyNode = valueNode = null;
        }

        detected = true;
        atExplicitKey = true;
        allowCompact = true;

      } else if (atExplicitKey) {
        // i.e. 0x3A/* : */ === character after the explicit key.
        atExplicitKey = false;
        allowCompact = true;

      } else {
        throwError(state, 'incomplete explicit mapping pair; a key node is missed');
      }

      state.position += 1;
      ch = following;

    //
    // Implicit notation case. Flow-style node as the key first, then ":", and the value.
    //
    } else if (composeNode(state, flowIndent, CONTEXT_FLOW_OUT, false, true)) {

      if (state.line === _line) {
        ch = state.input.charCodeAt(state.position);

        while (is_WHITE_SPACE(ch)) {
          ch = state.input.charCodeAt(++state.position);
        }

        if (0x3A/* : */ === ch) {
          ch = state.input.charCodeAt(++state.position);

          if (!is_WS_OR_EOL(ch)) {
            throwError(state, 'a whitespace character is expected after the key-value separator within a block mapping');
          }

          if (atExplicitKey) {
            storeMappingPair(state, _result, keyTag, keyNode, null);
            keyTag = keyNode = valueNode = null;
          }

          detected = true;
          atExplicitKey = false;
          allowCompact = false;
          keyTag = state.tag;
          keyNode = state.result;

        } else if (detected) {
          throwError(state, 'can not read an implicit mapping pair; a colon is missed');

        } else {
          state.tag = _tag;
          state.anchor = _anchor;
          return true; // Keep the result of `composeNode`.
        }

      } else if (detected) {
        throwError(state, 'can not read a block mapping entry; a multiline key may not be an implicit key');

      } else {
        state.tag = _tag;
        state.anchor = _anchor;
        return true; // Keep the result of `composeNode`.
      }

    } else {
      break; // Reading is done. Go to the epilogue.
    }

    //
    // Common reading code for both explicit and implicit notations.
    //
    if (state.line === _line || state.lineIndent > nodeIndent) {
      if (composeNode(state, nodeIndent, CONTEXT_BLOCK_OUT, true, allowCompact)) {
        if (atExplicitKey) {
          keyNode = state.result;
        } else {
          valueNode = state.result;
        }
      }

      if (!atExplicitKey) {
        storeMappingPair(state, _result, keyTag, keyNode, valueNode);
        keyTag = keyNode = valueNode = null;
      }

      skipSeparationSpace(state, true, -1);
      ch = state.input.charCodeAt(state.position);
    }

    if (state.lineIndent > nodeIndent && (0 !== ch)) {
      throwError(state, 'bad indentation of a mapping entry');
    } else if (state.lineIndent < nodeIndent) {
      break;
    }
  }

  //
  // Epilogue.
  //

  // Special case: last mapping's node contains only the key in explicit notation.
  if (atExplicitKey) {
    storeMappingPair(state, _result, keyTag, keyNode, null);
  }

  // Expose the resulting mapping.
  if (detected) {
    state.tag = _tag;
    state.anchor = _anchor;
    state.kind = 'mapping';
    state.result = _result;
  }

  return detected;
}

function readTagProperty(state) {
  var _position,
      isVerbatim = false,
      isNamed    = false,
      tagHandle,
      tagName,
      ch;

  ch = state.input.charCodeAt(state.position);

  if (0x21/* ! */ !== ch) {
    return false;
  }

  if (null !== state.tag) {
    throwError(state, 'duplication of a tag property');
  }

  ch = state.input.charCodeAt(++state.position);

  if (0x3C/* < */ === ch) {
    isVerbatim = true;
    ch = state.input.charCodeAt(++state.position);

  } else if (0x21/* ! */ === ch) {
    isNamed = true;
    tagHandle = '!!';
    ch = state.input.charCodeAt(++state.position);

  } else {
    tagHandle = '!';
  }

  _position = state.position;

  if (isVerbatim) {
    do { ch = state.input.charCodeAt(++state.position); }
    while (0 !== ch && 0x3E/* > */ !== ch);

    if (state.position < state.length) {
      tagName = state.input.slice(_position, state.position);
      ch = state.input.charCodeAt(++state.position);
    } else {
      throwError(state, 'unexpected end of the stream within a verbatim tag');
    }
  } else {
    while (0 !== ch && !is_WS_OR_EOL(ch)) {

      if (0x21/* ! */ === ch) {
        if (!isNamed) {
          tagHandle = state.input.slice(_position - 1, state.position + 1);

          if (!PATTERN_TAG_HANDLE.test(tagHandle)) {
            throwError(state, 'named tag handle cannot contain such characters');
          }

          isNamed = true;
          _position = state.position + 1;
        } else {
          throwError(state, 'tag suffix cannot contain exclamation marks');
        }
      }

      ch = state.input.charCodeAt(++state.position);
    }

    tagName = state.input.slice(_position, state.position);

    if (PATTERN_FLOW_INDICATORS.test(tagName)) {
      throwError(state, 'tag suffix cannot contain flow indicator characters');
    }
  }

  if (tagName && !PATTERN_TAG_URI.test(tagName)) {
    throwError(state, 'tag name cannot contain such characters: ' + tagName);
  }

  if (isVerbatim) {
    state.tag = tagName;

  } else if (_hasOwnProperty.call(state.tagMap, tagHandle)) {
    state.tag = state.tagMap[tagHandle] + tagName;

  } else if ('!' === tagHandle) {
    state.tag = '!' + tagName;

  } else if ('!!' === tagHandle) {
    state.tag = 'tag:yaml.org,2002:' + tagName;

  } else {
    throwError(state, 'undeclared tag handle "' + tagHandle + '"');
  }

  return true;
}

function readAnchorProperty(state) {
  var _position,
      ch;

  ch = state.input.charCodeAt(state.position);

  if (0x26/* & */ !== ch) {
    return false;
  }

  if (null !== state.anchor) {
    throwError(state, 'duplication of an anchor property');
  }

  ch = state.input.charCodeAt(++state.position);
  _position = state.position;

  while (0 !== ch && !is_WS_OR_EOL(ch) && !is_FLOW_INDICATOR(ch)) {
    ch = state.input.charCodeAt(++state.position);
  }

  if (state.position === _position) {
    throwError(state, 'name of an anchor node must contain at least one character');
  }

  state.anchor = state.input.slice(_position, state.position);
  return true;
}

function readAlias(state) {
  var _position, alias,
      ch;

  ch = state.input.charCodeAt(state.position);

  if (0x2A/* * */ !== ch) {
    return false;
  }

  ch = state.input.charCodeAt(++state.position);
  _position = state.position;

  while (0 !== ch && !is_WS_OR_EOL(ch) && !is_FLOW_INDICATOR(ch)) {
    ch = state.input.charCodeAt(++state.position);
  }

  if (state.position === _position) {
    throwError(state, 'name of an alias node must contain at least one character');
  }

  alias = state.input.slice(_position, state.position);

  if (!state.anchorMap.hasOwnProperty(alias)) {
    throwError(state, 'unidentified alias "' + alias + '"');
  }

  state.result = state.anchorMap[alias];
  skipSeparationSpace(state, true, -1);
  return true;
}

function composeNode(state, parentIndent, nodeContext, allowToSeek, allowCompact) {
  var allowBlockStyles,
      allowBlockScalars,
      allowBlockCollections,
      indentStatus = 1, // 1: this>parent, 0: this=parent, -1: this<parent
      atNewLine  = false,
      hasContent = false,
      typeIndex,
      typeQuantity,
      type,
      flowIndent,
      blockIndent;

  state.tag    = null;
  state.anchor = null;
  state.kind   = null;
  state.result = null;

  allowBlockStyles = allowBlockScalars = allowBlockCollections =
    CONTEXT_BLOCK_OUT === nodeContext ||
    CONTEXT_BLOCK_IN  === nodeContext;

  if (allowToSeek) {
    if (skipSeparationSpace(state, true, -1)) {
      atNewLine = true;

      if (state.lineIndent > parentIndent) {
        indentStatus = 1;
      } else if (state.lineIndent === parentIndent) {
        indentStatus = 0;
      } else if (state.lineIndent < parentIndent) {
        indentStatus = -1;
      }
    }
  }

  if (1 === indentStatus) {
    while (readTagProperty(state) || readAnchorProperty(state)) {
      if (skipSeparationSpace(state, true, -1)) {
        atNewLine = true;
        allowBlockCollections = allowBlockStyles;

        if (state.lineIndent > parentIndent) {
          indentStatus = 1;
        } else if (state.lineIndent === parentIndent) {
          indentStatus = 0;
        } else if (state.lineIndent < parentIndent) {
          indentStatus = -1;
        }
      } else {
        allowBlockCollections = false;
      }
    }
  }

  if (allowBlockCollections) {
    allowBlockCollections = atNewLine || allowCompact;
  }

  if (1 === indentStatus || CONTEXT_BLOCK_OUT === nodeContext) {
    if (CONTEXT_FLOW_IN === nodeContext || CONTEXT_FLOW_OUT === nodeContext) {
      flowIndent = parentIndent;
    } else {
      flowIndent = parentIndent + 1;
    }

    blockIndent = state.position - state.lineStart;

    if (1 === indentStatus) {
      if (allowBlockCollections &&
          (readBlockSequence(state, blockIndent) ||
           readBlockMapping(state, blockIndent, flowIndent)) ||
          readFlowCollection(state, flowIndent)) {
        hasContent = true;
      } else {
        if ((allowBlockScalars && readBlockScalar(state, flowIndent)) ||
            readSingleQuotedScalar(state, flowIndent) ||
            readDoubleQuotedScalar(state, flowIndent)) {
          hasContent = true;

        } else if (readAlias(state)) {
          hasContent = true;

          if (null !== state.tag || null !== state.anchor) {
            throwError(state, 'alias node should not have any properties');
          }

        } else if (readPlainScalar(state, flowIndent, CONTEXT_FLOW_IN === nodeContext)) {
          hasContent = true;

          if (null === state.tag) {
            state.tag = '?';
          }
        }

        if (null !== state.anchor) {
          state.anchorMap[state.anchor] = state.result;
        }
      }
    } else if (0 === indentStatus) {
      // Special case: block sequences are allowed to have same indentation level as the parent.
      // http://www.yaml.org/spec/1.2/spec.html#id2799784
      hasContent = allowBlockCollections && readBlockSequence(state, blockIndent);
    }
  }

  if (null !== state.tag && '!' !== state.tag) {
    if ('?' === state.tag) {
      for (typeIndex = 0, typeQuantity = state.implicitTypes.length;
           typeIndex < typeQuantity;
           typeIndex += 1) {
        type = state.implicitTypes[typeIndex];

        // Implicit resolving is not allowed for non-scalar types, and '?'
        // non-specific tag is only assigned to plain scalars. So, it isn't
        // needed to check for 'kind' conformity.

        if (type.resolve(state.result)) { // `state.result` updated in resolver if matched
          state.result = type.construct(state.result);
          state.tag = type.tag;
          if (null !== state.anchor) {
            state.anchorMap[state.anchor] = state.result;
          }
          break;
        }
      }
    } else if (_hasOwnProperty.call(state.typeMap, state.tag)) {
      type = state.typeMap[state.tag];

      if (null !== state.result && type.kind !== state.kind) {
        throwError(state, 'unacceptable node kind for !<' + state.tag + '> tag; it should be "' + type.kind + '", not "' + state.kind + '"');
      }

      if (!type.resolve(state.result)) { // `state.result` updated in resolver if matched
        throwError(state, 'cannot resolve a node with !<' + state.tag + '> explicit tag');
      } else {
        state.result = type.construct(state.result);
        if (null !== state.anchor) {
          state.anchorMap[state.anchor] = state.result;
        }
      }
    } else {
      throwError(state, 'unknown tag !<' + state.tag + '>');
    }
  }

  return null !== state.tag || null !== state.anchor || hasContent;
}

function readDocument(state) {
  var documentStart = state.position,
      _position,
      directiveName,
      directiveArgs,
      hasDirectives = false,
      ch;

  state.version = null;
  state.checkLineBreaks = state.legacy;
  state.tagMap = {};
  state.anchorMap = {};

  while (0 !== (ch = state.input.charCodeAt(state.position))) {
    skipSeparationSpace(state, true, -1);

    ch = state.input.charCodeAt(state.position);

    if (state.lineIndent > 0 || 0x25/* % */ !== ch) {
      break;
    }

    hasDirectives = true;
    ch = state.input.charCodeAt(++state.position);
    _position = state.position;

    while (0 !== ch && !is_WS_OR_EOL(ch)) {
      ch = state.input.charCodeAt(++state.position);
    }

    directiveName = state.input.slice(_position, state.position);
    directiveArgs = [];

    if (directiveName.length < 1) {
      throwError(state, 'directive name must not be less than one character in length');
    }

    while (0 !== ch) {
      while (is_WHITE_SPACE(ch)) {
        ch = state.input.charCodeAt(++state.position);
      }

      if (0x23/* # */ === ch) {
        do { ch = state.input.charCodeAt(++state.position); }
        while (0 !== ch && !is_EOL(ch));
        break;
      }

      if (is_EOL(ch)) {
        break;
      }

      _position = state.position;

      while (0 !== ch && !is_WS_OR_EOL(ch)) {
        ch = state.input.charCodeAt(++state.position);
      }

      directiveArgs.push(state.input.slice(_position, state.position));
    }

    if (0 !== ch) {
      readLineBreak(state);
    }

    if (_hasOwnProperty.call(directiveHandlers, directiveName)) {
      directiveHandlers[directiveName](state, directiveName, directiveArgs);
    } else {
      throwWarning(state, 'unknown document directive "' + directiveName + '"');
    }
  }

  skipSeparationSpace(state, true, -1);

  if (0 === state.lineIndent &&
      0x2D/* - */ === state.input.charCodeAt(state.position) &&
      0x2D/* - */ === state.input.charCodeAt(state.position + 1) &&
      0x2D/* - */ === state.input.charCodeAt(state.position + 2)) {
    state.position += 3;
    skipSeparationSpace(state, true, -1);

  } else if (hasDirectives) {
    throwError(state, 'directives end mark is expected');
  }

  composeNode(state, state.lineIndent - 1, CONTEXT_BLOCK_OUT, false, true);
  skipSeparationSpace(state, true, -1);

  if (state.checkLineBreaks &&
      PATTERN_NON_ASCII_LINE_BREAKS.test(state.input.slice(documentStart, state.position))) {
    throwWarning(state, 'non-ASCII line breaks are interpreted as content');
  }

  state.documents.push(state.result);

  if (state.position === state.lineStart && testDocumentSeparator(state)) {

    if (0x2E/* . */ === state.input.charCodeAt(state.position)) {
      state.position += 3;
      skipSeparationSpace(state, true, -1);
    }
    return;
  }

  if (state.position < (state.length - 1)) {
    throwError(state, 'end of the stream or a document separator is expected');
  } else {
    return;
  }
}


function loadDocuments(input, options) {
  input = String(input);
  options = options || {};

  if (input.length !== 0) {

    // Add tailing `\n` if not exists
    if (0x0A/* LF */ !== input.charCodeAt(input.length - 1) &&
        0x0D/* CR */ !== input.charCodeAt(input.length - 1)) {
      input += '\n';
    }

    // Strip BOM
    if (input.charCodeAt(0) === 0xFEFF) {
      input = input.slice(1);
    }
  }

  var state = new State(input, options);

  // Use 0 as string terminator. That significantly simplifies bounds check.
  state.input += '\0';

  while (0x20/* Space */ === state.input.charCodeAt(state.position)) {
    state.lineIndent += 1;
    state.position += 1;
  }

  while (state.position < (state.length - 1)) {
    readDocument(state);
  }

  return state.documents;
}


function loadAll(input, iterator, options) {
  var documents = loadDocuments(input, options), index, length;

  for (index = 0, length = documents.length; index < length; index += 1) {
    iterator(documents[index]);
  }
}


function load(input, options) {
  var documents = loadDocuments(input, options);

  if (0 === documents.length) {
    /*eslint-disable no-undefined*/
    return undefined;
  } else if (1 === documents.length) {
    return documents[0];
  }
  throw new YAMLException('expected a single document in the stream, but found more');
}


function safeLoadAll(input, output, options) {
  loadAll(input, output, common.extend({ schema: DEFAULT_SAFE_SCHEMA }, options));
}


function safeLoad(input, options) {
  return load(input, common.extend({ schema: DEFAULT_SAFE_SCHEMA }, options));
}


module.exports.loadAll     = loadAll;
module.exports.load        = load;
module.exports.safeLoadAll = safeLoadAll;
module.exports.safeLoad    = safeLoad;

},{"./common":23,"./exception":25,"./mark":27,"./schema/default_full":30,"./schema/default_safe":31}],27:[function(require,module,exports){
'use strict';


var common = require('./common');


function Mark(name, buffer, position, line, column) {
  this.name     = name;
  this.buffer   = buffer;
  this.position = position;
  this.line     = line;
  this.column   = column;
}


Mark.prototype.getSnippet = function getSnippet(indent, maxLength) {
  var head, start, tail, end, snippet;

  if (!this.buffer) {
    return null;
  }

  indent = indent || 4;
  maxLength = maxLength || 75;

  head = '';
  start = this.position;

  while (start > 0 && -1 === '\x00\r\n\x85\u2028\u2029'.indexOf(this.buffer.charAt(start - 1))) {
    start -= 1;
    if (this.position - start > (maxLength / 2 - 1)) {
      head = ' ... ';
      start += 5;
      break;
    }
  }

  tail = '';
  end = this.position;

  while (end < this.buffer.length && -1 === '\x00\r\n\x85\u2028\u2029'.indexOf(this.buffer.charAt(end))) {
    end += 1;
    if (end - this.position > (maxLength / 2 - 1)) {
      tail = ' ... ';
      end -= 5;
      break;
    }
  }

  snippet = this.buffer.slice(start, end);

  return common.repeat(' ', indent) + head + snippet + tail + '\n' +
         common.repeat(' ', indent + this.position - start + head.length) + '^';
};


Mark.prototype.toString = function toString(compact) {
  var snippet, where = '';

  if (this.name) {
    where += 'in "' + this.name + '" ';
  }

  where += 'at line ' + (this.line + 1) + ', column ' + (this.column + 1);

  if (!compact) {
    snippet = this.getSnippet();

    if (snippet) {
      where += ':\n' + snippet;
    }
  }

  return where;
};


module.exports = Mark;

},{"./common":23}],28:[function(require,module,exports){
'use strict';

/*eslint-disable max-len*/

var common        = require('./common');
var YAMLException = require('./exception');
var Type          = require('./type');


function compileList(schema, name, result) {
  var exclude = [];

  schema.include.forEach(function (includedSchema) {
    result = compileList(includedSchema, name, result);
  });

  schema[name].forEach(function (currentType) {
    result.forEach(function (previousType, previousIndex) {
      if (previousType.tag === currentType.tag) {
        exclude.push(previousIndex);
      }
    });

    result.push(currentType);
  });

  return result.filter(function (type, index) {
    return -1 === exclude.indexOf(index);
  });
}


function compileMap(/* lists... */) {
  var result = {}, index, length;

  function collectType(type) {
    result[type.tag] = type;
  }

  for (index = 0, length = arguments.length; index < length; index += 1) {
    arguments[index].forEach(collectType);
  }

  return result;
}


function Schema(definition) {
  this.include  = definition.include  || [];
  this.implicit = definition.implicit || [];
  this.explicit = definition.explicit || [];

  this.implicit.forEach(function (type) {
    if (type.loadKind && 'scalar' !== type.loadKind) {
      throw new YAMLException('There is a non-scalar type in the implicit list of a schema. Implicit resolving of such types is not supported.');
    }
  });

  this.compiledImplicit = compileList(this, 'implicit', []);
  this.compiledExplicit = compileList(this, 'explicit', []);
  this.compiledTypeMap  = compileMap(this.compiledImplicit, this.compiledExplicit);
}


Schema.DEFAULT = null;


Schema.create = function createSchema() {
  var schemas, types;

  switch (arguments.length) {
  case 1:
    schemas = Schema.DEFAULT;
    types = arguments[0];
    break;

  case 2:
    schemas = arguments[0];
    types = arguments[1];
    break;

  default:
    throw new YAMLException('Wrong number of arguments for Schema.create function');
  }

  schemas = common.toArray(schemas);
  types = common.toArray(types);

  if (!schemas.every(function (schema) { return schema instanceof Schema; })) {
    throw new YAMLException('Specified list of super schemas (or a single Schema object) contains a non-Schema object.');
  }

  if (!types.every(function (type) { return type instanceof Type; })) {
    throw new YAMLException('Specified list of YAML types (or a single Type object) contains a non-Type object.');
  }

  return new Schema({
    include: schemas,
    explicit: types
  });
};


module.exports = Schema;

},{"./common":23,"./exception":25,"./type":34}],29:[function(require,module,exports){
// Standard YAML's Core schema.
// http://www.yaml.org/spec/1.2/spec.html#id2804923
//
// NOTE: JS-YAML does not support schema-specific tag resolution restrictions.
// So, Core schema has no distinctions from JSON schema is JS-YAML.


'use strict';


var Schema = require('../schema');


module.exports = new Schema({
  include: [
    require('./json')
  ]
});

},{"../schema":28,"./json":33}],30:[function(require,module,exports){
// JS-YAML's default schema for `load` function.
// It is not described in the YAML specification.
//
// This schema is based on JS-YAML's default safe schema and includes
// JavaScript-specific types: !!js/undefined, !!js/regexp and !!js/function.
//
// Also this schema is used as default base schema at `Schema.create` function.


'use strict';


var Schema = require('../schema');


module.exports = Schema.DEFAULT = new Schema({
  include: [
    require('./default_safe')
  ],
  explicit: [
    require('../type/js/undefined'),
    require('../type/js/regexp'),
    require('../type/js/function')
  ]
});

},{"../schema":28,"../type/js/function":39,"../type/js/regexp":40,"../type/js/undefined":41,"./default_safe":31}],31:[function(require,module,exports){
// JS-YAML's default schema for `safeLoad` function.
// It is not described in the YAML specification.
//
// This schema is based on standard YAML's Core schema and includes most of
// extra types described at YAML tag repository. (http://yaml.org/type/)


'use strict';


var Schema = require('../schema');


module.exports = new Schema({
  include: [
    require('./core')
  ],
  implicit: [
    require('../type/timestamp'),
    require('../type/merge')
  ],
  explicit: [
    require('../type/binary'),
    require('../type/omap'),
    require('../type/pairs'),
    require('../type/set')
  ]
});

},{"../schema":28,"../type/binary":35,"../type/merge":43,"../type/omap":45,"../type/pairs":46,"../type/set":48,"../type/timestamp":50,"./core":29}],32:[function(require,module,exports){
// Standard YAML's Failsafe schema.
// http://www.yaml.org/spec/1.2/spec.html#id2802346


'use strict';


var Schema = require('../schema');


module.exports = new Schema({
  explicit: [
    require('../type/str'),
    require('../type/seq'),
    require('../type/map')
  ]
});

},{"../schema":28,"../type/map":42,"../type/seq":47,"../type/str":49}],33:[function(require,module,exports){
// Standard YAML's JSON schema.
// http://www.yaml.org/spec/1.2/spec.html#id2803231
//
// NOTE: JS-YAML does not support schema-specific tag resolution restrictions.
// So, this schema is not such strict as defined in the YAML specification.
// It allows numbers in binary notaion, use `Null` and `NULL` as `null`, etc.


'use strict';


var Schema = require('../schema');


module.exports = new Schema({
  include: [
    require('./failsafe')
  ],
  implicit: [
    require('../type/null'),
    require('../type/bool'),
    require('../type/int'),
    require('../type/float')
  ]
});

},{"../schema":28,"../type/bool":36,"../type/float":37,"../type/int":38,"../type/null":44,"./failsafe":32}],34:[function(require,module,exports){
'use strict';

var YAMLException = require('./exception');

var TYPE_CONSTRUCTOR_OPTIONS = [
  'kind',
  'resolve',
  'construct',
  'instanceOf',
  'predicate',
  'represent',
  'defaultStyle',
  'styleAliases'
];

var YAML_NODE_KINDS = [
  'scalar',
  'sequence',
  'mapping'
];

function compileStyleAliases(map) {
  var result = {};

  if (null !== map) {
    Object.keys(map).forEach(function (style) {
      map[style].forEach(function (alias) {
        result[String(alias)] = style;
      });
    });
  }

  return result;
}

function Type(tag, options) {
  options = options || {};

  Object.keys(options).forEach(function (name) {
    if (-1 === TYPE_CONSTRUCTOR_OPTIONS.indexOf(name)) {
      throw new YAMLException('Unknown option "' + name + '" is met in definition of "' + tag + '" YAML type.');
    }
  });

  // TODO: Add tag format check.
  this.tag          = tag;
  this.kind         = options['kind']         || null;
  this.resolve      = options['resolve']      || function () { return true; };
  this.construct    = options['construct']    || function (data) { return data; };
  this.instanceOf   = options['instanceOf']   || null;
  this.predicate    = options['predicate']    || null;
  this.represent    = options['represent']    || null;
  this.defaultStyle = options['defaultStyle'] || null;
  this.styleAliases = compileStyleAliases(options['styleAliases'] || null);

  if (-1 === YAML_NODE_KINDS.indexOf(this.kind)) {
    throw new YAMLException('Unknown kind "' + this.kind + '" is specified for "' + tag + '" YAML type.');
  }
}

module.exports = Type;

},{"./exception":25}],35:[function(require,module,exports){
'use strict';

/*eslint-disable no-bitwise*/

// A trick for browserified version.
// Since we make browserifier to ignore `buffer` module, NodeBuffer will be undefined
var NodeBuffer = require('buffer').Buffer;
var Type       = require('../type');


// [ 64, 65, 66 ] -> [ padding, CR, LF ]
var BASE64_MAP = 'ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/=\n\r';


function resolveYamlBinary(data) {
  if (null === data) {
    return false;
  }

  var code, idx, bitlen = 0, max = data.length, map = BASE64_MAP;

  // Convert one by one.
  for (idx = 0; idx < max; idx++) {
    code = map.indexOf(data.charAt(idx));

    // Skip CR/LF
    if (code > 64) { continue; }

    // Fail on illegal characters
    if (code < 0) { return false; }

    bitlen += 6;
  }

  // If there are any bits left, source was corrupted
  return (bitlen % 8) === 0;
}

function constructYamlBinary(data) {
  var idx, tailbits,
      input = data.replace(/[\r\n=]/g, ''), // remove CR/LF & padding to simplify scan
      max = input.length,
      map = BASE64_MAP,
      bits = 0,
      result = [];

  // Collect by 6*4 bits (3 bytes)

  for (idx = 0; idx < max; idx++) {
    if ((idx % 4 === 0) && idx) {
      result.push((bits >> 16) & 0xFF);
      result.push((bits >> 8) & 0xFF);
      result.push(bits & 0xFF);
    }

    bits = (bits << 6) | map.indexOf(input.charAt(idx));
  }

  // Dump tail

  tailbits = (max % 4) * 6;

  if (tailbits === 0) {
    result.push((bits >> 16) & 0xFF);
    result.push((bits >> 8) & 0xFF);
    result.push(bits & 0xFF);
  } else if (tailbits === 18) {
    result.push((bits >> 10) & 0xFF);
    result.push((bits >> 2) & 0xFF);
  } else if (tailbits === 12) {
    result.push((bits >> 4) & 0xFF);
  }

  // Wrap into Buffer for NodeJS and leave Array for browser
  if (NodeBuffer) {
    return new NodeBuffer(result);
  }

  return result;
}

function representYamlBinary(object /*, style*/) {
  var result = '', bits = 0, idx, tail,
      max = object.length,
      map = BASE64_MAP;

  // Convert every three bytes to 4 ASCII characters.

  for (idx = 0; idx < max; idx++) {
    if ((idx % 3 === 0) && idx) {
      result += map[(bits >> 18) & 0x3F];
      result += map[(bits >> 12) & 0x3F];
      result += map[(bits >> 6) & 0x3F];
      result += map[bits & 0x3F];
    }

    bits = (bits << 8) + object[idx];
  }

  // Dump tail

  tail = max % 3;

  if (tail === 0) {
    result += map[(bits >> 18) & 0x3F];
    result += map[(bits >> 12) & 0x3F];
    result += map[(bits >> 6) & 0x3F];
    result += map[bits & 0x3F];
  } else if (tail === 2) {
    result += map[(bits >> 10) & 0x3F];
    result += map[(bits >> 4) & 0x3F];
    result += map[(bits << 2) & 0x3F];
    result += map[64];
  } else if (tail === 1) {
    result += map[(bits >> 2) & 0x3F];
    result += map[(bits << 4) & 0x3F];
    result += map[64];
    result += map[64];
  }

  return result;
}

function isBinary(object) {
  return NodeBuffer && NodeBuffer.isBuffer(object);
}

module.exports = new Type('tag:yaml.org,2002:binary', {
  kind: 'scalar',
  resolve: resolveYamlBinary,
  construct: constructYamlBinary,
  predicate: isBinary,
  represent: representYamlBinary
});

},{"../type":34,"buffer":56}],36:[function(require,module,exports){
'use strict';

var Type = require('../type');

function resolveYamlBoolean(data) {
  if (null === data) {
    return false;
  }

  var max = data.length;

  return (max === 4 && (data === 'true' || data === 'True' || data === 'TRUE')) ||
         (max === 5 && (data === 'false' || data === 'False' || data === 'FALSE'));
}

function constructYamlBoolean(data) {
  return data === 'true' ||
         data === 'True' ||
         data === 'TRUE';
}

function isBoolean(object) {
  return '[object Boolean]' === Object.prototype.toString.call(object);
}

module.exports = new Type('tag:yaml.org,2002:bool', {
  kind: 'scalar',
  resolve: resolveYamlBoolean,
  construct: constructYamlBoolean,
  predicate: isBoolean,
  represent: {
    lowercase: function (object) { return object ? 'true' : 'false'; },
    uppercase: function (object) { return object ? 'TRUE' : 'FALSE'; },
    camelcase: function (object) { return object ? 'True' : 'False'; }
  },
  defaultStyle: 'lowercase'
});

},{"../type":34}],37:[function(require,module,exports){
'use strict';

var common = require('../common');
var Type   = require('../type');

var YAML_FLOAT_PATTERN = new RegExp(
  '^(?:[-+]?(?:[0-9][0-9_]*)\\.[0-9_]*(?:[eE][-+][0-9]+)?' +
  '|\\.[0-9_]+(?:[eE][-+][0-9]+)?' +
  '|[-+]?[0-9][0-9_]*(?::[0-5]?[0-9])+\\.[0-9_]*' +
  '|[-+]?\\.(?:inf|Inf|INF)' +
  '|\\.(?:nan|NaN|NAN))$');

function resolveYamlFloat(data) {
  if (null === data) {
    return false;
  }

  if (!YAML_FLOAT_PATTERN.test(data)) {
    return false;
  }
  return true;
}

function constructYamlFloat(data) {
  var value, sign, base, digits;

  value  = data.replace(/_/g, '').toLowerCase();
  sign   = '-' === value[0] ? -1 : 1;
  digits = [];

  if (0 <= '+-'.indexOf(value[0])) {
    value = value.slice(1);
  }

  if ('.inf' === value) {
    return (1 === sign) ? Number.POSITIVE_INFINITY : Number.NEGATIVE_INFINITY;

  } else if ('.nan' === value) {
    return NaN;

  } else if (0 <= value.indexOf(':')) {
    value.split(':').forEach(function (v) {
      digits.unshift(parseFloat(v, 10));
    });

    value = 0.0;
    base = 1;

    digits.forEach(function (d) {
      value += d * base;
      base *= 60;
    });

    return sign * value;

  }
  return sign * parseFloat(value, 10);
}


var SCIENTIFIC_WITHOUT_DOT = /^[-+]?[0-9]+e/;

function representYamlFloat(object, style) {
  var res;

  if (isNaN(object)) {
    switch (style) {
    case 'lowercase':
      return '.nan';
    case 'uppercase':
      return '.NAN';
    case 'camelcase':
      return '.NaN';
    }
  } else if (Number.POSITIVE_INFINITY === object) {
    switch (style) {
    case 'lowercase':
      return '.inf';
    case 'uppercase':
      return '.INF';
    case 'camelcase':
      return '.Inf';
    }
  } else if (Number.NEGATIVE_INFINITY === object) {
    switch (style) {
    case 'lowercase':
      return '-.inf';
    case 'uppercase':
      return '-.INF';
    case 'camelcase':
      return '-.Inf';
    }
  } else if (common.isNegativeZero(object)) {
    return '-0.0';
  }

  res = object.toString(10);

  // JS stringifier can build scientific format without dots: 5e-100,
  // while YAML requres dot: 5.e-100. Fix it with simple hack

  return SCIENTIFIC_WITHOUT_DOT.test(res) ? res.replace('e', '.e') : res;
}

function isFloat(object) {
  return ('[object Number]' === Object.prototype.toString.call(object)) &&
         (0 !== object % 1 || common.isNegativeZero(object));
}

module.exports = new Type('tag:yaml.org,2002:float', {
  kind: 'scalar',
  resolve: resolveYamlFloat,
  construct: constructYamlFloat,
  predicate: isFloat,
  represent: representYamlFloat,
  defaultStyle: 'lowercase'
});

},{"../common":23,"../type":34}],38:[function(require,module,exports){
'use strict';

var common = require('../common');
var Type   = require('../type');

function isHexCode(c) {
  return ((0x30/* 0 */ <= c) && (c <= 0x39/* 9 */)) ||
         ((0x41/* A */ <= c) && (c <= 0x46/* F */)) ||
         ((0x61/* a */ <= c) && (c <= 0x66/* f */));
}

function isOctCode(c) {
  return ((0x30/* 0 */ <= c) && (c <= 0x37/* 7 */));
}

function isDecCode(c) {
  return ((0x30/* 0 */ <= c) && (c <= 0x39/* 9 */));
}

function resolveYamlInteger(data) {
  if (null === data) {
    return false;
  }

  var max = data.length,
      index = 0,
      hasDigits = false,
      ch;

  if (!max) { return false; }

  ch = data[index];

  // sign
  if (ch === '-' || ch === '+') {
    ch = data[++index];
  }

  if (ch === '0') {
    // 0
    if (index + 1 === max) { return true; }
    ch = data[++index];

    // base 2, base 8, base 16

    if (ch === 'b') {
      // base 2
      index++;

      for (; index < max; index++) {
        ch = data[index];
        if (ch === '_') { continue; }
        if (ch !== '0' && ch !== '1') {
          return false;
        }
        hasDigits = true;
      }
      return hasDigits;
    }


    if (ch === 'x') {
      // base 16
      index++;

      for (; index < max; index++) {
        ch = data[index];
        if (ch === '_') { continue; }
        if (!isHexCode(data.charCodeAt(index))) {
          return false;
        }
        hasDigits = true;
      }
      return hasDigits;
    }

    // base 8
    for (; index < max; index++) {
      ch = data[index];
      if (ch === '_') { continue; }
      if (!isOctCode(data.charCodeAt(index))) {
        return false;
      }
      hasDigits = true;
    }
    return hasDigits;
  }

  // base 10 (except 0) or base 60

  for (; index < max; index++) {
    ch = data[index];
    if (ch === '_') { continue; }
    if (ch === ':') { break; }
    if (!isDecCode(data.charCodeAt(index))) {
      return false;
    }
    hasDigits = true;
  }

  if (!hasDigits) { return false; }

  // if !base60 - done;
  if (ch !== ':') { return true; }

  // base60 almost not used, no needs to optimize
  return /^(:[0-5]?[0-9])+$/.test(data.slice(index));
}

function constructYamlInteger(data) {
  var value = data, sign = 1, ch, base, digits = [];

  if (value.indexOf('_') !== -1) {
    value = value.replace(/_/g, '');
  }

  ch = value[0];

  if (ch === '-' || ch === '+') {
    if (ch === '-') { sign = -1; }
    value = value.slice(1);
    ch = value[0];
  }

  if ('0' === value) {
    return 0;
  }

  if (ch === '0') {
    if (value[1] === 'b') {
      return sign * parseInt(value.slice(2), 2);
    }
    if (value[1] === 'x') {
      return sign * parseInt(value, 16);
    }
    return sign * parseInt(value, 8);

  }

  if (value.indexOf(':') !== -1) {
    value.split(':').forEach(function (v) {
      digits.unshift(parseInt(v, 10));
    });

    value = 0;
    base = 1;

    digits.forEach(function (d) {
      value += (d * base);
      base *= 60;
    });

    return sign * value;

  }

  return sign * parseInt(value, 10);
}

function isInteger(object) {
  return ('[object Number]' === Object.prototype.toString.call(object)) &&
         (0 === object % 1 && !common.isNegativeZero(object));
}

module.exports = new Type('tag:yaml.org,2002:int', {
  kind: 'scalar',
  resolve: resolveYamlInteger,
  construct: constructYamlInteger,
  predicate: isInteger,
  represent: {
    binary:      function (object) { return '0b' + object.toString(2); },
    octal:       function (object) { return '0'  + object.toString(8); },
    decimal:     function (object) { return        object.toString(10); },
    hexadecimal: function (object) { return '0x' + object.toString(16).toUpperCase(); }
  },
  defaultStyle: 'decimal',
  styleAliases: {
    binary:      [ 2,  'bin' ],
    octal:       [ 8,  'oct' ],
    decimal:     [ 10, 'dec' ],
    hexadecimal: [ 16, 'hex' ]
  }
});

},{"../common":23,"../type":34}],39:[function(require,module,exports){
'use strict';

var esprima;

// Browserified version does not have esprima
//
// 1. For node.js just require module as deps
// 2. For browser try to require mudule via external AMD system.
//    If not found - try to fallback to window.esprima. If not
//    found too - then fail to parse.
//
try {
  esprima = require('esprima');
} catch (_) {
  /*global window */
  if (typeof window !== 'undefined') { esprima = window.esprima; }
}

var Type = require('../../type');

function resolveJavascriptFunction(data) {
  if (null === data) {
    return false;
  }

  try {
    var source = '(' + data + ')',
        ast    = esprima.parse(source, { range: true });

    if ('Program'             !== ast.type         ||
        1                     !== ast.body.length  ||
        'ExpressionStatement' !== ast.body[0].type ||
        'FunctionExpression'  !== ast.body[0].expression.type) {
      return false;
    }

    return true;
  } catch (err) {
    return false;
  }
}

function constructJavascriptFunction(data) {
  /*jslint evil:true*/

  var source = '(' + data + ')',
      ast    = esprima.parse(source, { range: true }),
      params = [],
      body;

  if ('Program'             !== ast.type         ||
      1                     !== ast.body.length  ||
      'ExpressionStatement' !== ast.body[0].type ||
      'FunctionExpression'  !== ast.body[0].expression.type) {
    throw new Error('Failed to resolve function');
  }

  ast.body[0].expression.params.forEach(function (param) {
    params.push(param.name);
  });

  body = ast.body[0].expression.body.range;

  // Esprima's ranges include the first '{' and the last '}' characters on
  // function expressions. So cut them out.
  /*eslint-disable no-new-func*/
  return new Function(params, source.slice(body[0] + 1, body[1] - 1));
}

function representJavascriptFunction(object /*, style*/) {
  return object.toString();
}

function isFunction(object) {
  return '[object Function]' === Object.prototype.toString.call(object);
}

module.exports = new Type('tag:yaml.org,2002:js/function', {
  kind: 'scalar',
  resolve: resolveJavascriptFunction,
  construct: constructJavascriptFunction,
  predicate: isFunction,
  represent: representJavascriptFunction
});

},{"../../type":34,"esprima":51}],40:[function(require,module,exports){
'use strict';

var Type = require('../../type');

function resolveJavascriptRegExp(data) {
  if (null === data) {
    return false;
  }

  if (0 === data.length) {
    return false;
  }

  var regexp = data,
      tail   = /\/([gim]*)$/.exec(data),
      modifiers = '';

  // if regexp starts with '/' it can have modifiers and must be properly closed
  // `/foo/gim` - modifiers tail can be maximum 3 chars
  if ('/' === regexp[0]) {
    if (tail) {
      modifiers = tail[1];
    }

    if (modifiers.length > 3) { return false; }
    // if expression starts with /, is should be properly terminated
    if (regexp[regexp.length - modifiers.length - 1] !== '/') { return false; }

    regexp = regexp.slice(1, regexp.length - modifiers.length - 1);
  }

  try {
    return true;
  } catch (error) {
    return false;
  }
}

function constructJavascriptRegExp(data) {
  var regexp = data,
      tail   = /\/([gim]*)$/.exec(data),
      modifiers = '';

  // `/foo/gim` - tail can be maximum 4 chars
  if ('/' === regexp[0]) {
    if (tail) {
      modifiers = tail[1];
    }
    regexp = regexp.slice(1, regexp.length - modifiers.length - 1);
  }

  return new RegExp(regexp, modifiers);
}

function representJavascriptRegExp(object /*, style*/) {
  var result = '/' + object.source + '/';

  if (object.global) {
    result += 'g';
  }

  if (object.multiline) {
    result += 'm';
  }

  if (object.ignoreCase) {
    result += 'i';
  }

  return result;
}

function isRegExp(object) {
  return '[object RegExp]' === Object.prototype.toString.call(object);
}

module.exports = new Type('tag:yaml.org,2002:js/regexp', {
  kind: 'scalar',
  resolve: resolveJavascriptRegExp,
  construct: constructJavascriptRegExp,
  predicate: isRegExp,
  represent: representJavascriptRegExp
});

},{"../../type":34}],41:[function(require,module,exports){
'use strict';

var Type = require('../../type');

function resolveJavascriptUndefined() {
  return true;
}

function constructJavascriptUndefined() {
  /*eslint-disable no-undefined*/
  return undefined;
}

function representJavascriptUndefined() {
  return '';
}

function isUndefined(object) {
  return 'undefined' === typeof object;
}

module.exports = new Type('tag:yaml.org,2002:js/undefined', {
  kind: 'scalar',
  resolve: resolveJavascriptUndefined,
  construct: constructJavascriptUndefined,
  predicate: isUndefined,
  represent: representJavascriptUndefined
});

},{"../../type":34}],42:[function(require,module,exports){
'use strict';

var Type = require('../type');

module.exports = new Type('tag:yaml.org,2002:map', {
  kind: 'mapping',
  construct: function (data) { return null !== data ? data : {}; }
});

},{"../type":34}],43:[function(require,module,exports){
'use strict';

var Type = require('../type');

function resolveYamlMerge(data) {
  return '<<' === data || null === data;
}

module.exports = new Type('tag:yaml.org,2002:merge', {
  kind: 'scalar',
  resolve: resolveYamlMerge
});

},{"../type":34}],44:[function(require,module,exports){
'use strict';

var Type = require('../type');

function resolveYamlNull(data) {
  if (null === data) {
    return true;
  }

  var max = data.length;

  return (max === 1 && data === '~') ||
         (max === 4 && (data === 'null' || data === 'Null' || data === 'NULL'));
}

function constructYamlNull() {
  return null;
}

function isNull(object) {
  return null === object;
}

module.exports = new Type('tag:yaml.org,2002:null', {
  kind: 'scalar',
  resolve: resolveYamlNull,
  construct: constructYamlNull,
  predicate: isNull,
  represent: {
    canonical: function () { return '~';    },
    lowercase: function () { return 'null'; },
    uppercase: function () { return 'NULL'; },
    camelcase: function () { return 'Null'; }
  },
  defaultStyle: 'lowercase'
});

},{"../type":34}],45:[function(require,module,exports){
'use strict';

var Type = require('../type');

var _hasOwnProperty = Object.prototype.hasOwnProperty;
var _toString       = Object.prototype.toString;

function resolveYamlOmap(data) {
  if (null === data) {
    return true;
  }

  var objectKeys = [], index, length, pair, pairKey, pairHasKey,
      object = data;

  for (index = 0, length = object.length; index < length; index += 1) {
    pair = object[index];
    pairHasKey = false;

    if ('[object Object]' !== _toString.call(pair)) {
      return false;
    }

    for (pairKey in pair) {
      if (_hasOwnProperty.call(pair, pairKey)) {
        if (!pairHasKey) {
          pairHasKey = true;
        } else {
          return false;
        }
      }
    }

    if (!pairHasKey) {
      return false;
    }

    if (-1 === objectKeys.indexOf(pairKey)) {
      objectKeys.push(pairKey);
    } else {
      return false;
    }
  }

  return true;
}

function constructYamlOmap(data) {
  return null !== data ? data : [];
}

module.exports = new Type('tag:yaml.org,2002:omap', {
  kind: 'sequence',
  resolve: resolveYamlOmap,
  construct: constructYamlOmap
});

},{"../type":34}],46:[function(require,module,exports){
'use strict';

var Type = require('../type');

var _toString = Object.prototype.toString;

function resolveYamlPairs(data) {
  if (null === data) {
    return true;
  }

  var index, length, pair, keys, result,
      object = data;

  result = new Array(object.length);

  for (index = 0, length = object.length; index < length; index += 1) {
    pair = object[index];

    if ('[object Object]' !== _toString.call(pair)) {
      return false;
    }

    keys = Object.keys(pair);

    if (1 !== keys.length) {
      return false;
    }

    result[index] = [ keys[0], pair[keys[0]] ];
  }

  return true;
}

function constructYamlPairs(data) {
  if (null === data) {
    return [];
  }

  var index, length, pair, keys, result,
      object = data;

  result = new Array(object.length);

  for (index = 0, length = object.length; index < length; index += 1) {
    pair = object[index];

    keys = Object.keys(pair);

    result[index] = [ keys[0], pair[keys[0]] ];
  }

  return result;
}

module.exports = new Type('tag:yaml.org,2002:pairs', {
  kind: 'sequence',
  resolve: resolveYamlPairs,
  construct: constructYamlPairs
});

},{"../type":34}],47:[function(require,module,exports){
'use strict';

var Type = require('../type');

module.exports = new Type('tag:yaml.org,2002:seq', {
  kind: 'sequence',
  construct: function (data) { return null !== data ? data : []; }
});

},{"../type":34}],48:[function(require,module,exports){
'use strict';

var Type = require('../type');

var _hasOwnProperty = Object.prototype.hasOwnProperty;

function resolveYamlSet(data) {
  if (null === data) {
    return true;
  }

  var key, object = data;

  for (key in object) {
    if (_hasOwnProperty.call(object, key)) {
      if (null !== object[key]) {
        return false;
      }
    }
  }

  return true;
}

function constructYamlSet(data) {
  return null !== data ? data : {};
}

module.exports = new Type('tag:yaml.org,2002:set', {
  kind: 'mapping',
  resolve: resolveYamlSet,
  construct: constructYamlSet
});

},{"../type":34}],49:[function(require,module,exports){
'use strict';

var Type = require('../type');

module.exports = new Type('tag:yaml.org,2002:str', {
  kind: 'scalar',
  construct: function (data) { return null !== data ? data : ''; }
});

},{"../type":34}],50:[function(require,module,exports){
'use strict';

var Type = require('../type');

var YAML_TIMESTAMP_REGEXP = new RegExp(
  '^([0-9][0-9][0-9][0-9])'          + // [1] year
  '-([0-9][0-9]?)'                   + // [2] month
  '-([0-9][0-9]?)'                   + // [3] day
  '(?:(?:[Tt]|[ \\t]+)'              + // ...
  '([0-9][0-9]?)'                    + // [4] hour
  ':([0-9][0-9])'                    + // [5] minute
  ':([0-9][0-9])'                    + // [6] second
  '(?:\\.([0-9]*))?'                 + // [7] fraction
  '(?:[ \\t]*(Z|([-+])([0-9][0-9]?)' + // [8] tz [9] tz_sign [10] tz_hour
  '(?::([0-9][0-9]))?))?)?$');         // [11] tz_minute

function resolveYamlTimestamp(data) {
  if (null === data) {
    return false;
  }

  if (YAML_TIMESTAMP_REGEXP.exec(data) === null) {
    return false;
  }

  return true;
}

function constructYamlTimestamp(data) {
  var match, year, month, day, hour, minute, second, fraction = 0,
      delta = null, tz_hour, tz_minute, date;

  match = YAML_TIMESTAMP_REGEXP.exec(data);

  if (null === match) {
    throw new Error('Date resolve error');
  }

  // match: [1] year [2] month [3] day

  year = +(match[1]);
  month = +(match[2]) - 1; // JS month starts with 0
  day = +(match[3]);

  if (!match[4]) { // no hour
    return new Date(Date.UTC(year, month, day));
  }

  // match: [4] hour [5] minute [6] second [7] fraction

  hour = +(match[4]);
  minute = +(match[5]);
  second = +(match[6]);

  if (match[7]) {
    fraction = match[7].slice(0, 3);
    while (fraction.length < 3) { // milli-seconds
      fraction += '0';
    }
    fraction = +fraction;
  }

  // match: [8] tz [9] tz_sign [10] tz_hour [11] tz_minute

  if (match[9]) {
    tz_hour = +(match[10]);
    tz_minute = +(match[11] || 0);
    delta = (tz_hour * 60 + tz_minute) * 60000; // delta in mili-seconds
    if ('-' === match[9]) {
      delta = -delta;
    }
  }

  date = new Date(Date.UTC(year, month, day, hour, minute, second, fraction));

  if (delta) {
    date.setTime(date.getTime() - delta);
  }

  return date;
}

function representYamlTimestamp(object /*, style*/) {
  return object.toISOString();
}

module.exports = new Type('tag:yaml.org,2002:timestamp', {
  kind: 'scalar',
  resolve: resolveYamlTimestamp,
  construct: constructYamlTimestamp,
  instanceOf: Date,
  represent: representYamlTimestamp
});

},{"../type":34}],51:[function(require,module,exports){
/*
  Copyright (c) jQuery Foundation, Inc. and Contributors, All Rights Reserved.

  Redistribution and use in source and binary forms, with or without
  modification, are permitted provided that the following conditions are met:

    * Redistributions of source code must retain the above copyright
      notice, this list of conditions and the following disclaimer.
    * Redistributions in binary form must reproduce the above copyright
      notice, this list of conditions and the following disclaimer in the
      documentation and/or other materials provided with the distribution.

  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
  AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
  IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
  ARE DISCLAIMED. IN NO EVENT SHALL <COPYRIGHT HOLDER> BE LIABLE FOR ANY
  DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
  (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
  LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
  THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/

(function (root, factory) {
    'use strict';

    // Universal Module Definition (UMD) to support AMD, CommonJS/Node.js,
    // Rhino, and plain browser loading.

    /* istanbul ignore next */
    if (typeof define === 'function' && define.amd) {
        define(['exports'], factory);
    } else if (typeof exports !== 'undefined') {
        factory(exports);
    } else {
        factory((root.esprima = {}));
    }
}(this, function (exports) {
    'use strict';

    var Token,
        TokenName,
        FnExprTokens,
        Syntax,
        PlaceHolders,
        Messages,
        Regex,
        source,
        strict,
        index,
        lineNumber,
        lineStart,
        hasLineTerminator,
        lastIndex,
        lastLineNumber,
        lastLineStart,
        startIndex,
        startLineNumber,
        startLineStart,
        scanning,
        length,
        lookahead,
        state,
        extra,
        isBindingElement,
        isAssignmentTarget,
        firstCoverInitializedNameError;

    Token = {
        BooleanLiteral: 1,
        EOF: 2,
        Identifier: 3,
        Keyword: 4,
        NullLiteral: 5,
        NumericLiteral: 6,
        Punctuator: 7,
        StringLiteral: 8,
        RegularExpression: 9,
        Template: 10
    };

    TokenName = {};
    TokenName[Token.BooleanLiteral] = 'Boolean';
    TokenName[Token.EOF] = '<end>';
    TokenName[Token.Identifier] = 'Identifier';
    TokenName[Token.Keyword] = 'Keyword';
    TokenName[Token.NullLiteral] = 'Null';
    TokenName[Token.NumericLiteral] = 'Numeric';
    TokenName[Token.Punctuator] = 'Punctuator';
    TokenName[Token.StringLiteral] = 'String';
    TokenName[Token.RegularExpression] = 'RegularExpression';
    TokenName[Token.Template] = 'Template';

    // A function following one of those tokens is an expression.
    FnExprTokens = ['(', '{', '[', 'in', 'typeof', 'instanceof', 'new',
                    'return', 'case', 'delete', 'throw', 'void',
                    // assignment operators
                    '=', '+=', '-=', '*=', '/=', '%=', '<<=', '>>=', '>>>=',
                    '&=', '|=', '^=', ',',
                    // binary/unary operators
                    '+', '-', '*', '/', '%', '++', '--', '<<', '>>', '>>>', '&',
                    '|', '^', '!', '~', '&&', '||', '?', ':', '===', '==', '>=',
                    '<=', '<', '>', '!=', '!=='];

    Syntax = {
        AssignmentExpression: 'AssignmentExpression',
        AssignmentPattern: 'AssignmentPattern',
        ArrayExpression: 'ArrayExpression',
        ArrayPattern: 'ArrayPattern',
        ArrowFunctionExpression: 'ArrowFunctionExpression',
        BlockStatement: 'BlockStatement',
        BinaryExpression: 'BinaryExpression',
        BreakStatement: 'BreakStatement',
        CallExpression: 'CallExpression',
        CatchClause: 'CatchClause',
        ClassBody: 'ClassBody',
        ClassDeclaration: 'ClassDeclaration',
        ClassExpression: 'ClassExpression',
        ConditionalExpression: 'ConditionalExpression',
        ContinueStatement: 'ContinueStatement',
        DoWhileStatement: 'DoWhileStatement',
        DebuggerStatement: 'DebuggerStatement',
        EmptyStatement: 'EmptyStatement',
        ExportAllDeclaration: 'ExportAllDeclaration',
        ExportDefaultDeclaration: 'ExportDefaultDeclaration',
        ExportNamedDeclaration: 'ExportNamedDeclaration',
        ExportSpecifier: 'ExportSpecifier',
        ExpressionStatement: 'ExpressionStatement',
        ForStatement: 'ForStatement',
        ForOfStatement: 'ForOfStatement',
        ForInStatement: 'ForInStatement',
        FunctionDeclaration: 'FunctionDeclaration',
        FunctionExpression: 'FunctionExpression',
        Identifier: 'Identifier',
        IfStatement: 'IfStatement',
        ImportDeclaration: 'ImportDeclaration',
        ImportDefaultSpecifier: 'ImportDefaultSpecifier',
        ImportNamespaceSpecifier: 'ImportNamespaceSpecifier',
        ImportSpecifier: 'ImportSpecifier',
        Literal: 'Literal',
        LabeledStatement: 'LabeledStatement',
        LogicalExpression: 'LogicalExpression',
        MemberExpression: 'MemberExpression',
        MetaProperty: 'MetaProperty',
        MethodDefinition: 'MethodDefinition',
        NewExpression: 'NewExpression',
        ObjectExpression: 'ObjectExpression',
        ObjectPattern: 'ObjectPattern',
        Program: 'Program',
        Property: 'Property',
        RestElement: 'RestElement',
        ReturnStatement: 'ReturnStatement',
        SequenceExpression: 'SequenceExpression',
        SpreadElement: 'SpreadElement',
        Super: 'Super',
        SwitchCase: 'SwitchCase',
        SwitchStatement: 'SwitchStatement',
        TaggedTemplateExpression: 'TaggedTemplateExpression',
        TemplateElement: 'TemplateElement',
        TemplateLiteral: 'TemplateLiteral',
        ThisExpression: 'ThisExpression',
        ThrowStatement: 'ThrowStatement',
        TryStatement: 'TryStatement',
        UnaryExpression: 'UnaryExpression',
        UpdateExpression: 'UpdateExpression',
        VariableDeclaration: 'VariableDeclaration',
        VariableDeclarator: 'VariableDeclarator',
        WhileStatement: 'WhileStatement',
        WithStatement: 'WithStatement',
        YieldExpression: 'YieldExpression'
    };

    PlaceHolders = {
        ArrowParameterPlaceHolder: 'ArrowParameterPlaceHolder'
    };

    // Error messages should be identical to V8.
    Messages = {
        UnexpectedToken: 'Unexpected token %0',
        UnexpectedNumber: 'Unexpected number',
        UnexpectedString: 'Unexpected string',
        UnexpectedIdentifier: 'Unexpected identifier',
        UnexpectedReserved: 'Unexpected reserved word',
        UnexpectedTemplate: 'Unexpected quasi %0',
        UnexpectedEOS: 'Unexpected end of input',
        NewlineAfterThrow: 'Illegal newline after throw',
        InvalidRegExp: 'Invalid regular expression',
        UnterminatedRegExp: 'Invalid regular expression: missing /',
        InvalidLHSInAssignment: 'Invalid left-hand side in assignment',
        InvalidLHSInForIn: 'Invalid left-hand side in for-in',
        InvalidLHSInForLoop: 'Invalid left-hand side in for-loop',
        MultipleDefaultsInSwitch: 'More than one default clause in switch statement',
        NoCatchOrFinally: 'Missing catch or finally after try',
        UnknownLabel: 'Undefined label \'%0\'',
        Redeclaration: '%0 \'%1\' has already been declared',
        IllegalContinue: 'Illegal continue statement',
        IllegalBreak: 'Illegal break statement',
        IllegalReturn: 'Illegal return statement',
        StrictModeWith: 'Strict mode code may not include a with statement',
        StrictCatchVariable: 'Catch variable may not be eval or arguments in strict mode',
        StrictVarName: 'Variable name may not be eval or arguments in strict mode',
        StrictParamName: 'Parameter name eval or arguments is not allowed in strict mode',
        StrictParamDupe: 'Strict mode function may not have duplicate parameter names',
        StrictFunctionName: 'Function name may not be eval or arguments in strict mode',
        StrictOctalLiteral: 'Octal literals are not allowed in strict mode.',
        StrictDelete: 'Delete of an unqualified identifier in strict mode.',
        StrictLHSAssignment: 'Assignment to eval or arguments is not allowed in strict mode',
        StrictLHSPostfix: 'Postfix increment/decrement may not have eval or arguments operand in strict mode',
        StrictLHSPrefix: 'Prefix increment/decrement may not have eval or arguments operand in strict mode',
        StrictReservedWord: 'Use of future reserved word in strict mode',
        TemplateOctalLiteral: 'Octal literals are not allowed in template strings.',
        ParameterAfterRestParameter: 'Rest parameter must be last formal parameter',
        DefaultRestParameter: 'Unexpected token =',
        ObjectPatternAsRestParameter: 'Unexpected token {',
        DuplicateProtoProperty: 'Duplicate __proto__ fields are not allowed in object literals',
        ConstructorSpecialMethod: 'Class constructor may not be an accessor',
        DuplicateConstructor: 'A class may only have one constructor',
        StaticPrototype: 'Classes may not have static property named prototype',
        MissingFromClause: 'Unexpected token',
        NoAsAfterImportNamespace: 'Unexpected token',
        InvalidModuleSpecifier: 'Unexpected token',
        IllegalImportDeclaration: 'Unexpected token',
        IllegalExportDeclaration: 'Unexpected token',
        DuplicateBinding: 'Duplicate binding %0'
    };

    // See also tools/generate-unicode-regex.js.
    Regex = {
        // ECMAScript 6/Unicode v7.0.0 NonAsciiIdentifierStart:
        NonAsciiIdentifierStart: /[\xAA\xB5\xBA\xC0-\xD6\xD8-\xF6\xF8-\u02C1\u02C6-\u02D1\u02E0-\u02E4\u02EC\u02EE\u0370-\u0374\u0376\u0377\u037A-\u037D\u037F\u0386\u0388-\u038A\u038C\u038E-\u03A1\u03A3-\u03F5\u03F7-\u0481\u048A-\u052F\u0531-\u0556\u0559\u0561-\u0587\u05D0-\u05EA\u05F0-\u05F2\u0620-\u064A\u066E\u066F\u0671-\u06D3\u06D5\u06E5\u06E6\u06EE\u06EF\u06FA-\u06FC\u06FF\u0710\u0712-\u072F\u074D-\u07A5\u07B1\u07CA-\u07EA\u07F4\u07F5\u07FA\u0800-\u0815\u081A\u0824\u0828\u0840-\u0858\u08A0-\u08B2\u0904-\u0939\u093D\u0950\u0958-\u0961\u0971-\u0980\u0985-\u098C\u098F\u0990\u0993-\u09A8\u09AA-\u09B0\u09B2\u09B6-\u09B9\u09BD\u09CE\u09DC\u09DD\u09DF-\u09E1\u09F0\u09F1\u0A05-\u0A0A\u0A0F\u0A10\u0A13-\u0A28\u0A2A-\u0A30\u0A32\u0A33\u0A35\u0A36\u0A38\u0A39\u0A59-\u0A5C\u0A5E\u0A72-\u0A74\u0A85-\u0A8D\u0A8F-\u0A91\u0A93-\u0AA8\u0AAA-\u0AB0\u0AB2\u0AB3\u0AB5-\u0AB9\u0ABD\u0AD0\u0AE0\u0AE1\u0B05-\u0B0C\u0B0F\u0B10\u0B13-\u0B28\u0B2A-\u0B30\u0B32\u0B33\u0B35-\u0B39\u0B3D\u0B5C\u0B5D\u0B5F-\u0B61\u0B71\u0B83\u0B85-\u0B8A\u0B8E-\u0B90\u0B92-\u0B95\u0B99\u0B9A\u0B9C\u0B9E\u0B9F\u0BA3\u0BA4\u0BA8-\u0BAA\u0BAE-\u0BB9\u0BD0\u0C05-\u0C0C\u0C0E-\u0C10\u0C12-\u0C28\u0C2A-\u0C39\u0C3D\u0C58\u0C59\u0C60\u0C61\u0C85-\u0C8C\u0C8E-\u0C90\u0C92-\u0CA8\u0CAA-\u0CB3\u0CB5-\u0CB9\u0CBD\u0CDE\u0CE0\u0CE1\u0CF1\u0CF2\u0D05-\u0D0C\u0D0E-\u0D10\u0D12-\u0D3A\u0D3D\u0D4E\u0D60\u0D61\u0D7A-\u0D7F\u0D85-\u0D96\u0D9A-\u0DB1\u0DB3-\u0DBB\u0DBD\u0DC0-\u0DC6\u0E01-\u0E30\u0E32\u0E33\u0E40-\u0E46\u0E81\u0E82\u0E84\u0E87\u0E88\u0E8A\u0E8D\u0E94-\u0E97\u0E99-\u0E9F\u0EA1-\u0EA3\u0EA5\u0EA7\u0EAA\u0EAB\u0EAD-\u0EB0\u0EB2\u0EB3\u0EBD\u0EC0-\u0EC4\u0EC6\u0EDC-\u0EDF\u0F00\u0F40-\u0F47\u0F49-\u0F6C\u0F88-\u0F8C\u1000-\u102A\u103F\u1050-\u1055\u105A-\u105D\u1061\u1065\u1066\u106E-\u1070\u1075-\u1081\u108E\u10A0-\u10C5\u10C7\u10CD\u10D0-\u10FA\u10FC-\u1248\u124A-\u124D\u1250-\u1256\u1258\u125A-\u125D\u1260-\u1288\u128A-\u128D\u1290-\u12B0\u12B2-\u12B5\u12B8-\u12BE\u12C0\u12C2-\u12C5\u12C8-\u12D6\u12D8-\u1310\u1312-\u1315\u1318-\u135A\u1380-\u138F\u13A0-\u13F4\u1401-\u166C\u166F-\u167F\u1681-\u169A\u16A0-\u16EA\u16EE-\u16F8\u1700-\u170C\u170E-\u1711\u1720-\u1731\u1740-\u1751\u1760-\u176C\u176E-\u1770\u1780-\u17B3\u17D7\u17DC\u1820-\u1877\u1880-\u18A8\u18AA\u18B0-\u18F5\u1900-\u191E\u1950-\u196D\u1970-\u1974\u1980-\u19AB\u19C1-\u19C7\u1A00-\u1A16\u1A20-\u1A54\u1AA7\u1B05-\u1B33\u1B45-\u1B4B\u1B83-\u1BA0\u1BAE\u1BAF\u1BBA-\u1BE5\u1C00-\u1C23\u1C4D-\u1C4F\u1C5A-\u1C7D\u1CE9-\u1CEC\u1CEE-\u1CF1\u1CF5\u1CF6\u1D00-\u1DBF\u1E00-\u1F15\u1F18-\u1F1D\u1F20-\u1F45\u1F48-\u1F4D\u1F50-\u1F57\u1F59\u1F5B\u1F5D\u1F5F-\u1F7D\u1F80-\u1FB4\u1FB6-\u1FBC\u1FBE\u1FC2-\u1FC4\u1FC6-\u1FCC\u1FD0-\u1FD3\u1FD6-\u1FDB\u1FE0-\u1FEC\u1FF2-\u1FF4\u1FF6-\u1FFC\u2071\u207F\u2090-\u209C\u2102\u2107\u210A-\u2113\u2115\u2118-\u211D\u2124\u2126\u2128\u212A-\u2139\u213C-\u213F\u2145-\u2149\u214E\u2160-\u2188\u2C00-\u2C2E\u2C30-\u2C5E\u2C60-\u2CE4\u2CEB-\u2CEE\u2CF2\u2CF3\u2D00-\u2D25\u2D27\u2D2D\u2D30-\u2D67\u2D6F\u2D80-\u2D96\u2DA0-\u2DA6\u2DA8-\u2DAE\u2DB0-\u2DB6\u2DB8-\u2DBE\u2DC0-\u2DC6\u2DC8-\u2DCE\u2DD0-\u2DD6\u2DD8-\u2DDE\u3005-\u3007\u3021-\u3029\u3031-\u3035\u3038-\u303C\u3041-\u3096\u309B-\u309F\u30A1-\u30FA\u30FC-\u30FF\u3105-\u312D\u3131-\u318E\u31A0-\u31BA\u31F0-\u31FF\u3400-\u4DB5\u4E00-\u9FCC\uA000-\uA48C\uA4D0-\uA4FD\uA500-\uA60C\uA610-\uA61F\uA62A\uA62B\uA640-\uA66E\uA67F-\uA69D\uA6A0-\uA6EF\uA717-\uA71F\uA722-\uA788\uA78B-\uA78E\uA790-\uA7AD\uA7B0\uA7B1\uA7F7-\uA801\uA803-\uA805\uA807-\uA80A\uA80C-\uA822\uA840-\uA873\uA882-\uA8B3\uA8F2-\uA8F7\uA8FB\uA90A-\uA925\uA930-\uA946\uA960-\uA97C\uA984-\uA9B2\uA9CF\uA9E0-\uA9E4\uA9E6-\uA9EF\uA9FA-\uA9FE\uAA00-\uAA28\uAA40-\uAA42\uAA44-\uAA4B\uAA60-\uAA76\uAA7A\uAA7E-\uAAAF\uAAB1\uAAB5\uAAB6\uAAB9-\uAABD\uAAC0\uAAC2\uAADB-\uAADD\uAAE0-\uAAEA\uAAF2-\uAAF4\uAB01-\uAB06\uAB09-\uAB0E\uAB11-\uAB16\uAB20-\uAB26\uAB28-\uAB2E\uAB30-\uAB5A\uAB5C-\uAB5F\uAB64\uAB65\uABC0-\uABE2\uAC00-\uD7A3\uD7B0-\uD7C6\uD7CB-\uD7FB\uF900-\uFA6D\uFA70-\uFAD9\uFB00-\uFB06\uFB13-\uFB17\uFB1D\uFB1F-\uFB28\uFB2A-\uFB36\uFB38-\uFB3C\uFB3E\uFB40\uFB41\uFB43\uFB44\uFB46-\uFBB1\uFBD3-\uFD3D\uFD50-\uFD8F\uFD92-\uFDC7\uFDF0-\uFDFB\uFE70-\uFE74\uFE76-\uFEFC\uFF21-\uFF3A\uFF41-\uFF5A\uFF66-\uFFBE\uFFC2-\uFFC7\uFFCA-\uFFCF\uFFD2-\uFFD7\uFFDA-\uFFDC]|\uD800[\uDC00-\uDC0B\uDC0D-\uDC26\uDC28-\uDC3A\uDC3C\uDC3D\uDC3F-\uDC4D\uDC50-\uDC5D\uDC80-\uDCFA\uDD40-\uDD74\uDE80-\uDE9C\uDEA0-\uDED0\uDF00-\uDF1F\uDF30-\uDF4A\uDF50-\uDF75\uDF80-\uDF9D\uDFA0-\uDFC3\uDFC8-\uDFCF\uDFD1-\uDFD5]|\uD801[\uDC00-\uDC9D\uDD00-\uDD27\uDD30-\uDD63\uDE00-\uDF36\uDF40-\uDF55\uDF60-\uDF67]|\uD802[\uDC00-\uDC05\uDC08\uDC0A-\uDC35\uDC37\uDC38\uDC3C\uDC3F-\uDC55\uDC60-\uDC76\uDC80-\uDC9E\uDD00-\uDD15\uDD20-\uDD39\uDD80-\uDDB7\uDDBE\uDDBF\uDE00\uDE10-\uDE13\uDE15-\uDE17\uDE19-\uDE33\uDE60-\uDE7C\uDE80-\uDE9C\uDEC0-\uDEC7\uDEC9-\uDEE4\uDF00-\uDF35\uDF40-\uDF55\uDF60-\uDF72\uDF80-\uDF91]|\uD803[\uDC00-\uDC48]|\uD804[\uDC03-\uDC37\uDC83-\uDCAF\uDCD0-\uDCE8\uDD03-\uDD26\uDD50-\uDD72\uDD76\uDD83-\uDDB2\uDDC1-\uDDC4\uDDDA\uDE00-\uDE11\uDE13-\uDE2B\uDEB0-\uDEDE\uDF05-\uDF0C\uDF0F\uDF10\uDF13-\uDF28\uDF2A-\uDF30\uDF32\uDF33\uDF35-\uDF39\uDF3D\uDF5D-\uDF61]|\uD805[\uDC80-\uDCAF\uDCC4\uDCC5\uDCC7\uDD80-\uDDAE\uDE00-\uDE2F\uDE44\uDE80-\uDEAA]|\uD806[\uDCA0-\uDCDF\uDCFF\uDEC0-\uDEF8]|\uD808[\uDC00-\uDF98]|\uD809[\uDC00-\uDC6E]|[\uD80C\uD840-\uD868\uD86A-\uD86C][\uDC00-\uDFFF]|\uD80D[\uDC00-\uDC2E]|\uD81A[\uDC00-\uDE38\uDE40-\uDE5E\uDED0-\uDEED\uDF00-\uDF2F\uDF40-\uDF43\uDF63-\uDF77\uDF7D-\uDF8F]|\uD81B[\uDF00-\uDF44\uDF50\uDF93-\uDF9F]|\uD82C[\uDC00\uDC01]|\uD82F[\uDC00-\uDC6A\uDC70-\uDC7C\uDC80-\uDC88\uDC90-\uDC99]|\uD835[\uDC00-\uDC54\uDC56-\uDC9C\uDC9E\uDC9F\uDCA2\uDCA5\uDCA6\uDCA9-\uDCAC\uDCAE-\uDCB9\uDCBB\uDCBD-\uDCC3\uDCC5-\uDD05\uDD07-\uDD0A\uDD0D-\uDD14\uDD16-\uDD1C\uDD1E-\uDD39\uDD3B-\uDD3E\uDD40-\uDD44\uDD46\uDD4A-\uDD50\uDD52-\uDEA5\uDEA8-\uDEC0\uDEC2-\uDEDA\uDEDC-\uDEFA\uDEFC-\uDF14\uDF16-\uDF34\uDF36-\uDF4E\uDF50-\uDF6E\uDF70-\uDF88\uDF8A-\uDFA8\uDFAA-\uDFC2\uDFC4-\uDFCB]|\uD83A[\uDC00-\uDCC4]|\uD83B[\uDE00-\uDE03\uDE05-\uDE1F\uDE21\uDE22\uDE24\uDE27\uDE29-\uDE32\uDE34-\uDE37\uDE39\uDE3B\uDE42\uDE47\uDE49\uDE4B\uDE4D-\uDE4F\uDE51\uDE52\uDE54\uDE57\uDE59\uDE5B\uDE5D\uDE5F\uDE61\uDE62\uDE64\uDE67-\uDE6A\uDE6C-\uDE72\uDE74-\uDE77\uDE79-\uDE7C\uDE7E\uDE80-\uDE89\uDE8B-\uDE9B\uDEA1-\uDEA3\uDEA5-\uDEA9\uDEAB-\uDEBB]|\uD869[\uDC00-\uDED6\uDF00-\uDFFF]|\uD86D[\uDC00-\uDF34\uDF40-\uDFFF]|\uD86E[\uDC00-\uDC1D]|\uD87E[\uDC00-\uDE1D]/,

        // ECMAScript 6/Unicode v7.0.0 NonAsciiIdentifierPart:
        NonAsciiIdentifierPart: /[\xAA\xB5\xB7\xBA\xC0-\xD6\xD8-\xF6\xF8-\u02C1\u02C6-\u02D1\u02E0-\u02E4\u02EC\u02EE\u0300-\u0374\u0376\u0377\u037A-\u037D\u037F\u0386-\u038A\u038C\u038E-\u03A1\u03A3-\u03F5\u03F7-\u0481\u0483-\u0487\u048A-\u052F\u0531-\u0556\u0559\u0561-\u0587\u0591-\u05BD\u05BF\u05C1\u05C2\u05C4\u05C5\u05C7\u05D0-\u05EA\u05F0-\u05F2\u0610-\u061A\u0620-\u0669\u066E-\u06D3\u06D5-\u06DC\u06DF-\u06E8\u06EA-\u06FC\u06FF\u0710-\u074A\u074D-\u07B1\u07C0-\u07F5\u07FA\u0800-\u082D\u0840-\u085B\u08A0-\u08B2\u08E4-\u0963\u0966-\u096F\u0971-\u0983\u0985-\u098C\u098F\u0990\u0993-\u09A8\u09AA-\u09B0\u09B2\u09B6-\u09B9\u09BC-\u09C4\u09C7\u09C8\u09CB-\u09CE\u09D7\u09DC\u09DD\u09DF-\u09E3\u09E6-\u09F1\u0A01-\u0A03\u0A05-\u0A0A\u0A0F\u0A10\u0A13-\u0A28\u0A2A-\u0A30\u0A32\u0A33\u0A35\u0A36\u0A38\u0A39\u0A3C\u0A3E-\u0A42\u0A47\u0A48\u0A4B-\u0A4D\u0A51\u0A59-\u0A5C\u0A5E\u0A66-\u0A75\u0A81-\u0A83\u0A85-\u0A8D\u0A8F-\u0A91\u0A93-\u0AA8\u0AAA-\u0AB0\u0AB2\u0AB3\u0AB5-\u0AB9\u0ABC-\u0AC5\u0AC7-\u0AC9\u0ACB-\u0ACD\u0AD0\u0AE0-\u0AE3\u0AE6-\u0AEF\u0B01-\u0B03\u0B05-\u0B0C\u0B0F\u0B10\u0B13-\u0B28\u0B2A-\u0B30\u0B32\u0B33\u0B35-\u0B39\u0B3C-\u0B44\u0B47\u0B48\u0B4B-\u0B4D\u0B56\u0B57\u0B5C\u0B5D\u0B5F-\u0B63\u0B66-\u0B6F\u0B71\u0B82\u0B83\u0B85-\u0B8A\u0B8E-\u0B90\u0B92-\u0B95\u0B99\u0B9A\u0B9C\u0B9E\u0B9F\u0BA3\u0BA4\u0BA8-\u0BAA\u0BAE-\u0BB9\u0BBE-\u0BC2\u0BC6-\u0BC8\u0BCA-\u0BCD\u0BD0\u0BD7\u0BE6-\u0BEF\u0C00-\u0C03\u0C05-\u0C0C\u0C0E-\u0C10\u0C12-\u0C28\u0C2A-\u0C39\u0C3D-\u0C44\u0C46-\u0C48\u0C4A-\u0C4D\u0C55\u0C56\u0C58\u0C59\u0C60-\u0C63\u0C66-\u0C6F\u0C81-\u0C83\u0C85-\u0C8C\u0C8E-\u0C90\u0C92-\u0CA8\u0CAA-\u0CB3\u0CB5-\u0CB9\u0CBC-\u0CC4\u0CC6-\u0CC8\u0CCA-\u0CCD\u0CD5\u0CD6\u0CDE\u0CE0-\u0CE3\u0CE6-\u0CEF\u0CF1\u0CF2\u0D01-\u0D03\u0D05-\u0D0C\u0D0E-\u0D10\u0D12-\u0D3A\u0D3D-\u0D44\u0D46-\u0D48\u0D4A-\u0D4E\u0D57\u0D60-\u0D63\u0D66-\u0D6F\u0D7A-\u0D7F\u0D82\u0D83\u0D85-\u0D96\u0D9A-\u0DB1\u0DB3-\u0DBB\u0DBD\u0DC0-\u0DC6\u0DCA\u0DCF-\u0DD4\u0DD6\u0DD8-\u0DDF\u0DE6-\u0DEF\u0DF2\u0DF3\u0E01-\u0E3A\u0E40-\u0E4E\u0E50-\u0E59\u0E81\u0E82\u0E84\u0E87\u0E88\u0E8A\u0E8D\u0E94-\u0E97\u0E99-\u0E9F\u0EA1-\u0EA3\u0EA5\u0EA7\u0EAA\u0EAB\u0EAD-\u0EB9\u0EBB-\u0EBD\u0EC0-\u0EC4\u0EC6\u0EC8-\u0ECD\u0ED0-\u0ED9\u0EDC-\u0EDF\u0F00\u0F18\u0F19\u0F20-\u0F29\u0F35\u0F37\u0F39\u0F3E-\u0F47\u0F49-\u0F6C\u0F71-\u0F84\u0F86-\u0F97\u0F99-\u0FBC\u0FC6\u1000-\u1049\u1050-\u109D\u10A0-\u10C5\u10C7\u10CD\u10D0-\u10FA\u10FC-\u1248\u124A-\u124D\u1250-\u1256\u1258\u125A-\u125D\u1260-\u1288\u128A-\u128D\u1290-\u12B0\u12B2-\u12B5\u12B8-\u12BE\u12C0\u12C2-\u12C5\u12C8-\u12D6\u12D8-\u1310\u1312-\u1315\u1318-\u135A\u135D-\u135F\u1369-\u1371\u1380-\u138F\u13A0-\u13F4\u1401-\u166C\u166F-\u167F\u1681-\u169A\u16A0-\u16EA\u16EE-\u16F8\u1700-\u170C\u170E-\u1714\u1720-\u1734\u1740-\u1753\u1760-\u176C\u176E-\u1770\u1772\u1773\u1780-\u17D3\u17D7\u17DC\u17DD\u17E0-\u17E9\u180B-\u180D\u1810-\u1819\u1820-\u1877\u1880-\u18AA\u18B0-\u18F5\u1900-\u191E\u1920-\u192B\u1930-\u193B\u1946-\u196D\u1970-\u1974\u1980-\u19AB\u19B0-\u19C9\u19D0-\u19DA\u1A00-\u1A1B\u1A20-\u1A5E\u1A60-\u1A7C\u1A7F-\u1A89\u1A90-\u1A99\u1AA7\u1AB0-\u1ABD\u1B00-\u1B4B\u1B50-\u1B59\u1B6B-\u1B73\u1B80-\u1BF3\u1C00-\u1C37\u1C40-\u1C49\u1C4D-\u1C7D\u1CD0-\u1CD2\u1CD4-\u1CF6\u1CF8\u1CF9\u1D00-\u1DF5\u1DFC-\u1F15\u1F18-\u1F1D\u1F20-\u1F45\u1F48-\u1F4D\u1F50-\u1F57\u1F59\u1F5B\u1F5D\u1F5F-\u1F7D\u1F80-\u1FB4\u1FB6-\u1FBC\u1FBE\u1FC2-\u1FC4\u1FC6-\u1FCC\u1FD0-\u1FD3\u1FD6-\u1FDB\u1FE0-\u1FEC\u1FF2-\u1FF4\u1FF6-\u1FFC\u200C\u200D\u203F\u2040\u2054\u2071\u207F\u2090-\u209C\u20D0-\u20DC\u20E1\u20E5-\u20F0\u2102\u2107\u210A-\u2113\u2115\u2118-\u211D\u2124\u2126\u2128\u212A-\u2139\u213C-\u213F\u2145-\u2149\u214E\u2160-\u2188\u2C00-\u2C2E\u2C30-\u2C5E\u2C60-\u2CE4\u2CEB-\u2CF3\u2D00-\u2D25\u2D27\u2D2D\u2D30-\u2D67\u2D6F\u2D7F-\u2D96\u2DA0-\u2DA6\u2DA8-\u2DAE\u2DB0-\u2DB6\u2DB8-\u2DBE\u2DC0-\u2DC6\u2DC8-\u2DCE\u2DD0-\u2DD6\u2DD8-\u2DDE\u2DE0-\u2DFF\u3005-\u3007\u3021-\u302F\u3031-\u3035\u3038-\u303C\u3041-\u3096\u3099-\u309F\u30A1-\u30FA\u30FC-\u30FF\u3105-\u312D\u3131-\u318E\u31A0-\u31BA\u31F0-\u31FF\u3400-\u4DB5\u4E00-\u9FCC\uA000-\uA48C\uA4D0-\uA4FD\uA500-\uA60C\uA610-\uA62B\uA640-\uA66F\uA674-\uA67D\uA67F-\uA69D\uA69F-\uA6F1\uA717-\uA71F\uA722-\uA788\uA78B-\uA78E\uA790-\uA7AD\uA7B0\uA7B1\uA7F7-\uA827\uA840-\uA873\uA880-\uA8C4\uA8D0-\uA8D9\uA8E0-\uA8F7\uA8FB\uA900-\uA92D\uA930-\uA953\uA960-\uA97C\uA980-\uA9C0\uA9CF-\uA9D9\uA9E0-\uA9FE\uAA00-\uAA36\uAA40-\uAA4D\uAA50-\uAA59\uAA60-\uAA76\uAA7A-\uAAC2\uAADB-\uAADD\uAAE0-\uAAEF\uAAF2-\uAAF6\uAB01-\uAB06\uAB09-\uAB0E\uAB11-\uAB16\uAB20-\uAB26\uAB28-\uAB2E\uAB30-\uAB5A\uAB5C-\uAB5F\uAB64\uAB65\uABC0-\uABEA\uABEC\uABED\uABF0-\uABF9\uAC00-\uD7A3\uD7B0-\uD7C6\uD7CB-\uD7FB\uF900-\uFA6D\uFA70-\uFAD9\uFB00-\uFB06\uFB13-\uFB17\uFB1D-\uFB28\uFB2A-\uFB36\uFB38-\uFB3C\uFB3E\uFB40\uFB41\uFB43\uFB44\uFB46-\uFBB1\uFBD3-\uFD3D\uFD50-\uFD8F\uFD92-\uFDC7\uFDF0-\uFDFB\uFE00-\uFE0F\uFE20-\uFE2D\uFE33\uFE34\uFE4D-\uFE4F\uFE70-\uFE74\uFE76-\uFEFC\uFF10-\uFF19\uFF21-\uFF3A\uFF3F\uFF41-\uFF5A\uFF66-\uFFBE\uFFC2-\uFFC7\uFFCA-\uFFCF\uFFD2-\uFFD7\uFFDA-\uFFDC]|\uD800[\uDC00-\uDC0B\uDC0D-\uDC26\uDC28-\uDC3A\uDC3C\uDC3D\uDC3F-\uDC4D\uDC50-\uDC5D\uDC80-\uDCFA\uDD40-\uDD74\uDDFD\uDE80-\uDE9C\uDEA0-\uDED0\uDEE0\uDF00-\uDF1F\uDF30-\uDF4A\uDF50-\uDF7A\uDF80-\uDF9D\uDFA0-\uDFC3\uDFC8-\uDFCF\uDFD1-\uDFD5]|\uD801[\uDC00-\uDC9D\uDCA0-\uDCA9\uDD00-\uDD27\uDD30-\uDD63\uDE00-\uDF36\uDF40-\uDF55\uDF60-\uDF67]|\uD802[\uDC00-\uDC05\uDC08\uDC0A-\uDC35\uDC37\uDC38\uDC3C\uDC3F-\uDC55\uDC60-\uDC76\uDC80-\uDC9E\uDD00-\uDD15\uDD20-\uDD39\uDD80-\uDDB7\uDDBE\uDDBF\uDE00-\uDE03\uDE05\uDE06\uDE0C-\uDE13\uDE15-\uDE17\uDE19-\uDE33\uDE38-\uDE3A\uDE3F\uDE60-\uDE7C\uDE80-\uDE9C\uDEC0-\uDEC7\uDEC9-\uDEE6\uDF00-\uDF35\uDF40-\uDF55\uDF60-\uDF72\uDF80-\uDF91]|\uD803[\uDC00-\uDC48]|\uD804[\uDC00-\uDC46\uDC66-\uDC6F\uDC7F-\uDCBA\uDCD0-\uDCE8\uDCF0-\uDCF9\uDD00-\uDD34\uDD36-\uDD3F\uDD50-\uDD73\uDD76\uDD80-\uDDC4\uDDD0-\uDDDA\uDE00-\uDE11\uDE13-\uDE37\uDEB0-\uDEEA\uDEF0-\uDEF9\uDF01-\uDF03\uDF05-\uDF0C\uDF0F\uDF10\uDF13-\uDF28\uDF2A-\uDF30\uDF32\uDF33\uDF35-\uDF39\uDF3C-\uDF44\uDF47\uDF48\uDF4B-\uDF4D\uDF57\uDF5D-\uDF63\uDF66-\uDF6C\uDF70-\uDF74]|\uD805[\uDC80-\uDCC5\uDCC7\uDCD0-\uDCD9\uDD80-\uDDB5\uDDB8-\uDDC0\uDE00-\uDE40\uDE44\uDE50-\uDE59\uDE80-\uDEB7\uDEC0-\uDEC9]|\uD806[\uDCA0-\uDCE9\uDCFF\uDEC0-\uDEF8]|\uD808[\uDC00-\uDF98]|\uD809[\uDC00-\uDC6E]|[\uD80C\uD840-\uD868\uD86A-\uD86C][\uDC00-\uDFFF]|\uD80D[\uDC00-\uDC2E]|\uD81A[\uDC00-\uDE38\uDE40-\uDE5E\uDE60-\uDE69\uDED0-\uDEED\uDEF0-\uDEF4\uDF00-\uDF36\uDF40-\uDF43\uDF50-\uDF59\uDF63-\uDF77\uDF7D-\uDF8F]|\uD81B[\uDF00-\uDF44\uDF50-\uDF7E\uDF8F-\uDF9F]|\uD82C[\uDC00\uDC01]|\uD82F[\uDC00-\uDC6A\uDC70-\uDC7C\uDC80-\uDC88\uDC90-\uDC99\uDC9D\uDC9E]|\uD834[\uDD65-\uDD69\uDD6D-\uDD72\uDD7B-\uDD82\uDD85-\uDD8B\uDDAA-\uDDAD\uDE42-\uDE44]|\uD835[\uDC00-\uDC54\uDC56-\uDC9C\uDC9E\uDC9F\uDCA2\uDCA5\uDCA6\uDCA9-\uDCAC\uDCAE-\uDCB9\uDCBB\uDCBD-\uDCC3\uDCC5-\uDD05\uDD07-\uDD0A\uDD0D-\uDD14\uDD16-\uDD1C\uDD1E-\uDD39\uDD3B-\uDD3E\uDD40-\uDD44\uDD46\uDD4A-\uDD50\uDD52-\uDEA5\uDEA8-\uDEC0\uDEC2-\uDEDA\uDEDC-\uDEFA\uDEFC-\uDF14\uDF16-\uDF34\uDF36-\uDF4E\uDF50-\uDF6E\uDF70-\uDF88\uDF8A-\uDFA8\uDFAA-\uDFC2\uDFC4-\uDFCB\uDFCE-\uDFFF]|\uD83A[\uDC00-\uDCC4\uDCD0-\uDCD6]|\uD83B[\uDE00-\uDE03\uDE05-\uDE1F\uDE21\uDE22\uDE24\uDE27\uDE29-\uDE32\uDE34-\uDE37\uDE39\uDE3B\uDE42\uDE47\uDE49\uDE4B\uDE4D-\uDE4F\uDE51\uDE52\uDE54\uDE57\uDE59\uDE5B\uDE5D\uDE5F\uDE61\uDE62\uDE64\uDE67-\uDE6A\uDE6C-\uDE72\uDE74-\uDE77\uDE79-\uDE7C\uDE7E\uDE80-\uDE89\uDE8B-\uDE9B\uDEA1-\uDEA3\uDEA5-\uDEA9\uDEAB-\uDEBB]|\uD869[\uDC00-\uDED6\uDF00-\uDFFF]|\uD86D[\uDC00-\uDF34\uDF40-\uDFFF]|\uD86E[\uDC00-\uDC1D]|\uD87E[\uDC00-\uDE1D]|\uDB40[\uDD00-\uDDEF]/
    };

    // Ensure the condition is true, otherwise throw an error.
    // This is only to have a better contract semantic, i.e. another safety net
    // to catch a logic error. The condition shall be fulfilled in normal case.
    // Do NOT use this to enforce a certain condition on any user input.

    function assert(condition, message) {
        /* istanbul ignore if */
        if (!condition) {
            throw new Error('ASSERT: ' + message);
        }
    }

    function isDecimalDigit(ch) {
        return (ch >= 0x30 && ch <= 0x39);   // 0..9
    }

    function isHexDigit(ch) {
        return '0123456789abcdefABCDEF'.indexOf(ch) >= 0;
    }

    function isOctalDigit(ch) {
        return '01234567'.indexOf(ch) >= 0;
    }

    function octalToDecimal(ch) {
        // \0 is not octal escape sequence
        var octal = (ch !== '0'), code = '01234567'.indexOf(ch);

        if (index < length && isOctalDigit(source[index])) {
            octal = true;
            code = code * 8 + '01234567'.indexOf(source[index++]);

            // 3 digits are only allowed when string starts
            // with 0, 1, 2, 3
            if ('0123'.indexOf(ch) >= 0 &&
                    index < length &&
                    isOctalDigit(source[index])) {
                code = code * 8 + '01234567'.indexOf(source[index++]);
            }
        }

        return {
            code: code,
            octal: octal
        };
    }

    // ECMA-262 11.2 White Space

    function isWhiteSpace(ch) {
        return (ch === 0x20) || (ch === 0x09) || (ch === 0x0B) || (ch === 0x0C) || (ch === 0xA0) ||
            (ch >= 0x1680 && [0x1680, 0x180E, 0x2000, 0x2001, 0x2002, 0x2003, 0x2004, 0x2005, 0x2006, 0x2007, 0x2008, 0x2009, 0x200A, 0x202F, 0x205F, 0x3000, 0xFEFF].indexOf(ch) >= 0);
    }

    // ECMA-262 11.3 Line Terminators

    function isLineTerminator(ch) {
        return (ch === 0x0A) || (ch === 0x0D) || (ch === 0x2028) || (ch === 0x2029);
    }

    // ECMA-262 11.6 Identifier Names and Identifiers

    function fromCodePoint(cp) {
        return (cp < 0x10000) ? String.fromCharCode(cp) :
            String.fromCharCode(0xD800 + ((cp - 0x10000) >> 10)) +
            String.fromCharCode(0xDC00 + ((cp - 0x10000) & 1023));
    }

    function isIdentifierStart(ch) {
        return (ch === 0x24) || (ch === 0x5F) ||  // $ (dollar) and _ (underscore)
            (ch >= 0x41 && ch <= 0x5A) ||         // A..Z
            (ch >= 0x61 && ch <= 0x7A) ||         // a..z
            (ch === 0x5C) ||                      // \ (backslash)
            ((ch >= 0x80) && Regex.NonAsciiIdentifierStart.test(fromCodePoint(ch)));
    }

    function isIdentifierPart(ch) {
        return (ch === 0x24) || (ch === 0x5F) ||  // $ (dollar) and _ (underscore)
            (ch >= 0x41 && ch <= 0x5A) ||         // A..Z
            (ch >= 0x61 && ch <= 0x7A) ||         // a..z
            (ch >= 0x30 && ch <= 0x39) ||         // 0..9
            (ch === 0x5C) ||                      // \ (backslash)
            ((ch >= 0x80) && Regex.NonAsciiIdentifierPart.test(fromCodePoint(ch)));
    }

    // ECMA-262 11.6.2.2 Future Reserved Words

    function isFutureReservedWord(id) {
        switch (id) {
        case 'enum':
        case 'export':
        case 'import':
        case 'super':
            return true;
        default:
            return false;
        }
    }

    function isStrictModeReservedWord(id) {
        switch (id) {
        case 'implements':
        case 'interface':
        case 'package':
        case 'private':
        case 'protected':
        case 'public':
        case 'static':
        case 'yield':
        case 'let':
            return true;
        default:
            return false;
        }
    }

    function isRestrictedWord(id) {
        return id === 'eval' || id === 'arguments';
    }

    // ECMA-262 11.6.2.1 Keywords

    function isKeyword(id) {
        switch (id.length) {
        case 2:
            return (id === 'if') || (id === 'in') || (id === 'do');
        case 3:
            return (id === 'var') || (id === 'for') || (id === 'new') ||
                (id === 'try') || (id === 'let');
        case 4:
            return (id === 'this') || (id === 'else') || (id === 'case') ||
                (id === 'void') || (id === 'with') || (id === 'enum');
        case 5:
            return (id === 'while') || (id === 'break') || (id === 'catch') ||
                (id === 'throw') || (id === 'const') || (id === 'yield') ||
                (id === 'class') || (id === 'super');
        case 6:
            return (id === 'return') || (id === 'typeof') || (id === 'delete') ||
                (id === 'switch') || (id === 'export') || (id === 'import');
        case 7:
            return (id === 'default') || (id === 'finally') || (id === 'extends');
        case 8:
            return (id === 'function') || (id === 'continue') || (id === 'debugger');
        case 10:
            return (id === 'instanceof');
        default:
            return false;
        }
    }

    // ECMA-262 11.4 Comments

    function addComment(type, value, start, end, loc) {
        var comment;

        assert(typeof start === 'number', 'Comment must have valid position');

        state.lastCommentStart = start;

        comment = {
            type: type,
            value: value
        };
        if (extra.range) {
            comment.range = [start, end];
        }
        if (extra.loc) {
            comment.loc = loc;
        }
        extra.comments.push(comment);
        if (extra.attachComment) {
            extra.leadingComments.push(comment);
            extra.trailingComments.push(comment);
        }
        if (extra.tokenize) {
            comment.type = comment.type + 'Comment';
            if (extra.delegate) {
                comment = extra.delegate(comment);
            }
            extra.tokens.push(comment);
        }
    }

    function skipSingleLineComment(offset) {
        var start, loc, ch, comment;

        start = index - offset;
        loc = {
            start: {
                line: lineNumber,
                column: index - lineStart - offset
            }
        };

        while (index < length) {
            ch = source.charCodeAt(index);
            ++index;
            if (isLineTerminator(ch)) {
                hasLineTerminator = true;
                if (extra.comments) {
                    comment = source.slice(start + offset, index - 1);
                    loc.end = {
                        line: lineNumber,
                        column: index - lineStart - 1
                    };
                    addComment('Line', comment, start, index - 1, loc);
                }
                if (ch === 13 && source.charCodeAt(index) === 10) {
                    ++index;
                }
                ++lineNumber;
                lineStart = index;
                return;
            }
        }

        if (extra.comments) {
            comment = source.slice(start + offset, index);
            loc.end = {
                line: lineNumber,
                column: index - lineStart
            };
            addComment('Line', comment, start, index, loc);
        }
    }

    function skipMultiLineComment() {
        var start, loc, ch, comment;

        if (extra.comments) {
            start = index - 2;
            loc = {
                start: {
                    line: lineNumber,
                    column: index - lineStart - 2
                }
            };
        }

        while (index < length) {
            ch = source.charCodeAt(index);
            if (isLineTerminator(ch)) {
                if (ch === 0x0D && source.charCodeAt(index + 1) === 0x0A) {
                    ++index;
                }
                hasLineTerminator = true;
                ++lineNumber;
                ++index;
                lineStart = index;
            } else if (ch === 0x2A) {
                // Block comment ends with '*/'.
                if (source.charCodeAt(index + 1) === 0x2F) {
                    ++index;
                    ++index;
                    if (extra.comments) {
                        comment = source.slice(start + 2, index - 2);
                        loc.end = {
                            line: lineNumber,
                            column: index - lineStart
                        };
                        addComment('Block', comment, start, index, loc);
                    }
                    return;
                }
                ++index;
            } else {
                ++index;
            }
        }

        // Ran off the end of the file - the whole thing is a comment
        if (extra.comments) {
            loc.end = {
                line: lineNumber,
                column: index - lineStart
            };
            comment = source.slice(start + 2, index);
            addComment('Block', comment, start, index, loc);
        }
        tolerateUnexpectedToken();
    }

    function skipComment() {
        var ch, start;
        hasLineTerminator = false;

        start = (index === 0);
        while (index < length) {
            ch = source.charCodeAt(index);

            if (isWhiteSpace(ch)) {
                ++index;
            } else if (isLineTerminator(ch)) {
                hasLineTerminator = true;
                ++index;
                if (ch === 0x0D && source.charCodeAt(index) === 0x0A) {
                    ++index;
                }
                ++lineNumber;
                lineStart = index;
                start = true;
            } else if (ch === 0x2F) { // U+002F is '/'
                ch = source.charCodeAt(index + 1);
                if (ch === 0x2F) {
                    ++index;
                    ++index;
                    skipSingleLineComment(2);
                    start = true;
                } else if (ch === 0x2A) {  // U+002A is '*'
                    ++index;
                    ++index;
                    skipMultiLineComment();
                } else {
                    break;
                }
            } else if (start && ch === 0x2D) { // U+002D is '-'
                // U+003E is '>'
                if ((source.charCodeAt(index + 1) === 0x2D) && (source.charCodeAt(index + 2) === 0x3E)) {
                    // '-->' is a single-line comment
                    index += 3;
                    skipSingleLineComment(3);
                } else {
                    break;
                }
            } else if (ch === 0x3C) { // U+003C is '<'
                if (source.slice(index + 1, index + 4) === '!--') {
                    ++index; // `<`
                    ++index; // `!`
                    ++index; // `-`
                    ++index; // `-`
                    skipSingleLineComment(4);
                } else {
                    break;
                }
            } else {
                break;
            }
        }
    }

    function scanHexEscape(prefix) {
        var i, len, ch, code = 0;

        len = (prefix === 'u') ? 4 : 2;
        for (i = 0; i < len; ++i) {
            if (index < length && isHexDigit(source[index])) {
                ch = source[index++];
                code = code * 16 + '0123456789abcdef'.indexOf(ch.toLowerCase());
            } else {
                return '';
            }
        }
        return String.fromCharCode(code);
    }

    function scanUnicodeCodePointEscape() {
        var ch, code;

        ch = source[index];
        code = 0;

        // At least, one hex digit is required.
        if (ch === '}') {
            throwUnexpectedToken();
        }

        while (index < length) {
            ch = source[index++];
            if (!isHexDigit(ch)) {
                break;
            }
            code = code * 16 + '0123456789abcdef'.indexOf(ch.toLowerCase());
        }

        if (code > 0x10FFFF || ch !== '}') {
            throwUnexpectedToken();
        }

        return fromCodePoint(code);
    }

    function codePointAt(i) {
        var cp, first, second;

        cp = source.charCodeAt(i);
        if (cp >= 0xD800 && cp <= 0xDBFF) {
            second = source.charCodeAt(i + 1);
            if (second >= 0xDC00 && second <= 0xDFFF) {
                first = cp;
                cp = (first - 0xD800) * 0x400 + second - 0xDC00 + 0x10000;
            }
        }

        return cp;
    }

    function getComplexIdentifier() {
        var cp, ch, id;

        cp = codePointAt(index);
        id = fromCodePoint(cp);
        index += id.length;

        // '\u' (U+005C, U+0075) denotes an escaped character.
        if (cp === 0x5C) {
            if (source.charCodeAt(index) !== 0x75) {
                throwUnexpectedToken();
            }
            ++index;
            if (source[index] === '{') {
                ++index;
                ch = scanUnicodeCodePointEscape();
            } else {
                ch = scanHexEscape('u');
                cp = ch.charCodeAt(0);
                if (!ch || ch === '\\' || !isIdentifierStart(cp)) {
                    throwUnexpectedToken();
                }
            }
            id = ch;
        }

        while (index < length) {
            cp = codePointAt(index);
            if (!isIdentifierPart(cp)) {
                break;
            }
            ch = fromCodePoint(cp);
            id += ch;
            index += ch.length;

            // '\u' (U+005C, U+0075) denotes an escaped character.
            if (cp === 0x5C) {
                id = id.substr(0, id.length - 1);
                if (source.charCodeAt(index) !== 0x75) {
                    throwUnexpectedToken();
                }
                ++index;
                if (source[index] === '{') {
                    ++index;
                    ch = scanUnicodeCodePointEscape();
                } else {
                    ch = scanHexEscape('u');
                    cp = ch.charCodeAt(0);
                    if (!ch || ch === '\\' || !isIdentifierPart(cp)) {
                        throwUnexpectedToken();
                    }
                }
                id += ch;
            }
        }

        return id;
    }

    function getIdentifier() {
        var start, ch;

        start = index++;
        while (index < length) {
            ch = source.charCodeAt(index);
            if (ch === 0x5C) {
                // Blackslash (U+005C) marks Unicode escape sequence.
                index = start;
                return getComplexIdentifier();
            } else if (ch >= 0xD800 && ch < 0xDFFF) {
                // Need to handle surrogate pairs.
                index = start;
                return getComplexIdentifier();
            }
            if (isIdentifierPart(ch)) {
                ++index;
            } else {
                break;
            }
        }

        return source.slice(start, index);
    }

    function scanIdentifier() {
        var start, id, type;

        start = index;

        // Backslash (U+005C) starts an escaped character.
        id = (source.charCodeAt(index) === 0x5C) ? getComplexIdentifier() : getIdentifier();

        // There is no keyword or literal with only one character.
        // Thus, it must be an identifier.
        if (id.length === 1) {
            type = Token.Identifier;
        } else if (isKeyword(id)) {
            type = Token.Keyword;
        } else if (id === 'null') {
            type = Token.NullLiteral;
        } else if (id === 'true' || id === 'false') {
            type = Token.BooleanLiteral;
        } else {
            type = Token.Identifier;
        }

        return {
            type: type,
            value: id,
            lineNumber: lineNumber,
            lineStart: lineStart,
            start: start,
            end: index
        };
    }


    // ECMA-262 11.7 Punctuators

    function scanPunctuator() {
        var token, str;

        token = {
            type: Token.Punctuator,
            value: '',
            lineNumber: lineNumber,
            lineStart: lineStart,
            start: index,
            end: index
        };

        // Check for most common single-character punctuators.
        str = source[index];
        switch (str) {

        case '(':
            if (extra.tokenize) {
                extra.openParenToken = extra.tokenValues.length;
            }
            ++index;
            break;

        case '{':
            if (extra.tokenize) {
                extra.openCurlyToken = extra.tokenValues.length;
            }
            state.curlyStack.push('{');
            ++index;
            break;

        case '.':
            ++index;
            if (source[index] === '.' && source[index + 1] === '.') {
                // Spread operator: ...
                index += 2;
                str = '...';
            }
            break;

        case '}':
            ++index;
            state.curlyStack.pop();
            break;
        case ')':
        case ';':
        case ',':
        case '[':
        case ']':
        case ':':
        case '?':
        case '~':
            ++index;
            break;

        default:
            // 4-character punctuator.
            str = source.substr(index, 4);
            if (str === '>>>=') {
                index += 4;
            } else {

                // 3-character punctuators.
                str = str.substr(0, 3);
                if (str === '===' || str === '!==' || str === '>>>' ||
                    str === '<<=' || str === '>>=') {
                    index += 3;
                } else {

                    // 2-character punctuators.
                    str = str.substr(0, 2);
                    if (str === '&&' || str === '||' || str === '==' || str === '!=' ||
                        str === '+=' || str === '-=' || str === '*=' || str === '/=' ||
                        str === '++' || str === '--' || str === '<<' || str === '>>' ||
                        str === '&=' || str === '|=' || str === '^=' || str === '%=' ||
                        str === '<=' || str === '>=' || str === '=>') {
                        index += 2;
                    } else {

                        // 1-character punctuators.
                        str = source[index];
                        if ('<>=!+-*%&|^/'.indexOf(str) >= 0) {
                            ++index;
                        }
                    }
                }
            }
        }

        if (index === token.start) {
            throwUnexpectedToken();
        }

        token.end = index;
        token.value = str;
        return token;
    }

    // ECMA-262 11.8.3 Numeric Literals

    function scanHexLiteral(start) {
        var number = '';

        while (index < length) {
            if (!isHexDigit(source[index])) {
                break;
            }
            number += source[index++];
        }

        if (number.length === 0) {
            throwUnexpectedToken();
        }

        if (isIdentifierStart(source.charCodeAt(index))) {
            throwUnexpectedToken();
        }

        return {
            type: Token.NumericLiteral,
            value: parseInt('0x' + number, 16),
            lineNumber: lineNumber,
            lineStart: lineStart,
            start: start,
            end: index
        };
    }

    function scanBinaryLiteral(start) {
        var ch, number;

        number = '';

        while (index < length) {
            ch = source[index];
            if (ch !== '0' && ch !== '1') {
                break;
            }
            number += source[index++];
        }

        if (number.length === 0) {
            // only 0b or 0B
            throwUnexpectedToken();
        }

        if (index < length) {
            ch = source.charCodeAt(index);
            /* istanbul ignore else */
            if (isIdentifierStart(ch) || isDecimalDigit(ch)) {
                throwUnexpectedToken();
            }
        }

        return {
            type: Token.NumericLiteral,
            value: parseInt(number, 2),
            lineNumber: lineNumber,
            lineStart: lineStart,
            start: start,
            end: index
        };
    }

    function scanOctalLiteral(prefix, start) {
        var number, octal;

        if (isOctalDigit(prefix)) {
            octal = true;
            number = '0' + source[index++];
        } else {
            octal = false;
            ++index;
            number = '';
        }

        while (index < length) {
            if (!isOctalDigit(source[index])) {
                break;
            }
            number += source[index++];
        }

        if (!octal && number.length === 0) {
            // only 0o or 0O
            throwUnexpectedToken();
        }

        if (isIdentifierStart(source.charCodeAt(index)) || isDecimalDigit(source.charCodeAt(index))) {
            throwUnexpectedToken();
        }

        return {
            type: Token.NumericLiteral,
            value: parseInt(number, 8),
            octal: octal,
            lineNumber: lineNumber,
            lineStart: lineStart,
            start: start,
            end: index
        };
    }

    function isImplicitOctalLiteral() {
        var i, ch;

        // Implicit octal, unless there is a non-octal digit.
        // (Annex B.1.1 on Numeric Literals)
        for (i = index + 1; i < length; ++i) {
            ch = source[i];
            if (ch === '8' || ch === '9') {
                return false;
            }
            if (!isOctalDigit(ch)) {
                return true;
            }
        }

        return true;
    }

    function scanNumericLiteral() {
        var number, start, ch;

        ch = source[index];
        assert(isDecimalDigit(ch.charCodeAt(0)) || (ch === '.'),
            'Numeric literal must start with a decimal digit or a decimal point');

        start = index;
        number = '';
        if (ch !== '.') {
            number = source[index++];
            ch = source[index];

            // Hex number starts with '0x'.
            // Octal number starts with '0'.
            // Octal number in ES6 starts with '0o'.
            // Binary number in ES6 starts with '0b'.
            if (number === '0') {
                if (ch === 'x' || ch === 'X') {
                    ++index;
                    return scanHexLiteral(start);
                }
                if (ch === 'b' || ch === 'B') {
                    ++index;
                    return scanBinaryLiteral(start);
                }
                if (ch === 'o' || ch === 'O') {
                    return scanOctalLiteral(ch, start);
                }

                if (isOctalDigit(ch)) {
                    if (isImplicitOctalLiteral()) {
                        return scanOctalLiteral(ch, start);
                    }
                }
            }

            while (isDecimalDigit(source.charCodeAt(index))) {
                number += source[index++];
            }
            ch = source[index];
        }

        if (ch === '.') {
            number += source[index++];
            while (isDecimalDigit(source.charCodeAt(index))) {
                number += source[index++];
            }
            ch = source[index];
        }

        if (ch === 'e' || ch === 'E') {
            number += source[index++];

            ch = source[index];
            if (ch === '+' || ch === '-') {
                number += source[index++];
            }
            if (isDecimalDigit(source.charCodeAt(index))) {
                while (isDecimalDigit(source.charCodeAt(index))) {
                    number += source[index++];
                }
            } else {
                throwUnexpectedToken();
            }
        }

        if (isIdentifierStart(source.charCodeAt(index))) {
            throwUnexpectedToken();
        }

        return {
            type: Token.NumericLiteral,
            value: parseFloat(number),
            lineNumber: lineNumber,
            lineStart: lineStart,
            start: start,
            end: index
        };
    }

    // ECMA-262 11.8.4 String Literals

    function scanStringLiteral() {
        var str = '', quote, start, ch, unescaped, octToDec, octal = false;

        quote = source[index];
        assert((quote === '\'' || quote === '"'),
            'String literal must starts with a quote');

        start = index;
        ++index;

        while (index < length) {
            ch = source[index++];

            if (ch === quote) {
                quote = '';
                break;
            } else if (ch === '\\') {
                ch = source[index++];
                if (!ch || !isLineTerminator(ch.charCodeAt(0))) {
                    switch (ch) {
                    case 'u':
                    case 'x':
                        if (source[index] === '{') {
                            ++index;
                            str += scanUnicodeCodePointEscape();
                        } else {
                            unescaped = scanHexEscape(ch);
                            if (!unescaped) {
                                throw throwUnexpectedToken();
                            }
                            str += unescaped;
                        }
                        break;
                    case 'n':
                        str += '\n';
                        break;
                    case 'r':
                        str += '\r';
                        break;
                    case 't':
                        str += '\t';
                        break;
                    case 'b':
                        str += '\b';
                        break;
                    case 'f':
                        str += '\f';
                        break;
                    case 'v':
                        str += '\x0B';
                        break;
                    case '8':
                    case '9':
                        str += ch;
                        tolerateUnexpectedToken();
                        break;

                    default:
                        if (isOctalDigit(ch)) {
                            octToDec = octalToDecimal(ch);

                            octal = octToDec.octal || octal;
                            str += String.fromCharCode(octToDec.code);
                        } else {
                            str += ch;
                        }
                        break;
                    }
                } else {
                    ++lineNumber;
                    if (ch === '\r' && source[index] === '\n') {
                        ++index;
                    }
                    lineStart = index;
                }
            } else if (isLineTerminator(ch.charCodeAt(0))) {
                break;
            } else {
                str += ch;
            }
        }

        if (quote !== '') {
            throwUnexpectedToken();
        }

        return {
            type: Token.StringLiteral,
            value: str,
            octal: octal,
            lineNumber: startLineNumber,
            lineStart: startLineStart,
            start: start,
            end: index
        };
    }

    // ECMA-262 11.8.6 Template Literal Lexical Components

    function scanTemplate() {
        var cooked = '', ch, start, rawOffset, terminated, head, tail, restore, unescaped;

        terminated = false;
        tail = false;
        start = index;
        head = (source[index] === '`');
        rawOffset = 2;

        ++index;

        while (index < length) {
            ch = source[index++];
            if (ch === '`') {
                rawOffset = 1;
                tail = true;
                terminated = true;
                break;
            } else if (ch === '$') {
                if (source[index] === '{') {
                    state.curlyStack.push('${');
                    ++index;
                    terminated = true;
                    break;
                }
                cooked += ch;
            } else if (ch === '\\') {
                ch = source[index++];
                if (!isLineTerminator(ch.charCodeAt(0))) {
                    switch (ch) {
                    case 'n':
                        cooked += '\n';
                        break;
                    case 'r':
                        cooked += '\r';
                        break;
                    case 't':
                        cooked += '\t';
                        break;
                    case 'u':
                    case 'x':
                        if (source[index] === '{') {
                            ++index;
                            cooked += scanUnicodeCodePointEscape();
                        } else {
                            restore = index;
                            unescaped = scanHexEscape(ch);
                            if (unescaped) {
                                cooked += unescaped;
                            } else {
                                index = restore;
                                cooked += ch;
                            }
                        }
                        break;
                    case 'b':
                        cooked += '\b';
                        break;
                    case 'f':
                        cooked += '\f';
                        break;
                    case 'v':
                        cooked += '\v';
                        break;

                    default:
                        if (ch === '0') {
                            if (isDecimalDigit(source.charCodeAt(index))) {
                                // Illegal: \01 \02 and so on
                                throwError(Messages.TemplateOctalLiteral);
                            }
                            cooked += '\0';
                        } else if (isOctalDigit(ch)) {
                            // Illegal: \1 \2
                            throwError(Messages.TemplateOctalLiteral);
                        } else {
                            cooked += ch;
                        }
                        break;
                    }
                } else {
                    ++lineNumber;
                    if (ch === '\r' && source[index] === '\n') {
                        ++index;
                    }
                    lineStart = index;
                }
            } else if (isLineTerminator(ch.charCodeAt(0))) {
                ++lineNumber;
                if (ch === '\r' && source[index] === '\n') {
                    ++index;
                }
                lineStart = index;
                cooked += '\n';
            } else {
                cooked += ch;
            }
        }

        if (!terminated) {
            throwUnexpectedToken();
        }

        if (!head) {
            state.curlyStack.pop();
        }

        return {
            type: Token.Template,
            value: {
                cooked: cooked,
                raw: source.slice(start + 1, index - rawOffset)
            },
            head: head,
            tail: tail,
            lineNumber: lineNumber,
            lineStart: lineStart,
            start: start,
            end: index
        };
    }

    // ECMA-262 11.8.5 Regular Expression Literals

    function testRegExp(pattern, flags) {
        // The BMP character to use as a replacement for astral symbols when
        // translating an ES6 "u"-flagged pattern to an ES5-compatible
        // approximation.
        // Note: replacing with '\uFFFF' enables false positives in unlikely
        // scenarios. For example, `[\u{1044f}-\u{10440}]` is an invalid
        // pattern that would not be detected by this substitution.
        var astralSubstitute = '\uFFFF',
            tmp = pattern;

        if (flags.indexOf('u') >= 0) {
            tmp = tmp
                // Replace every Unicode escape sequence with the equivalent
                // BMP character or a constant ASCII code point in the case of
                // astral symbols. (See the above note on `astralSubstitute`
                // for more information.)
                .replace(/\\u\{([0-9a-fA-F]+)\}|\\u([a-fA-F0-9]{4})/g, function ($0, $1, $2) {
                    var codePoint = parseInt($1 || $2, 16);
                    if (codePoint > 0x10FFFF) {
                        throwUnexpectedToken(null, Messages.InvalidRegExp);
                    }
                    if (codePoint <= 0xFFFF) {
                        return String.fromCharCode(codePoint);
                    }
                    return astralSubstitute;
                })
                // Replace each paired surrogate with a single ASCII symbol to
                // avoid throwing on regular expressions that are only valid in
                // combination with the "u" flag.
                .replace(
                    /[\uD800-\uDBFF][\uDC00-\uDFFF]/g,
                    astralSubstitute
                );
        }

        // First, detect invalid regular expressions.
        try {
            RegExp(tmp);
        } catch (e) {
            throwUnexpectedToken(null, Messages.InvalidRegExp);
        }

        // Return a regular expression object for this pattern-flag pair, or
        // `null` in case the current environment doesn't support the flags it
        // uses.
        try {
            return new RegExp(pattern, flags);
        } catch (exception) {
            return null;
        }
    }

    function scanRegExpBody() {
        var ch, str, classMarker, terminated, body;

        ch = source[index];
        assert(ch === '/', 'Regular expression literal must start with a slash');
        str = source[index++];

        classMarker = false;
        terminated = false;
        while (index < length) {
            ch = source[index++];
            str += ch;
            if (ch === '\\') {
                ch = source[index++];
                // ECMA-262 7.8.5
                if (isLineTerminator(ch.charCodeAt(0))) {
                    throwUnexpectedToken(null, Messages.UnterminatedRegExp);
                }
                str += ch;
            } else if (isLineTerminator(ch.charCodeAt(0))) {
                throwUnexpectedToken(null, Messages.UnterminatedRegExp);
            } else if (classMarker) {
                if (ch === ']') {
                    classMarker = false;
                }
            } else {
                if (ch === '/') {
                    terminated = true;
                    break;
                } else if (ch === '[') {
                    classMarker = true;
                }
            }
        }

        if (!terminated) {
            throwUnexpectedToken(null, Messages.UnterminatedRegExp);
        }

        // Exclude leading and trailing slash.
        body = str.substr(1, str.length - 2);
        return {
            value: body,
            literal: str
        };
    }

    function scanRegExpFlags() {
        var ch, str, flags, restore;

        str = '';
        flags = '';
        while (index < length) {
            ch = source[index];
            if (!isIdentifierPart(ch.charCodeAt(0))) {
                break;
            }

            ++index;
            if (ch === '\\' && index < length) {
                ch = source[index];
                if (ch === 'u') {
                    ++index;
                    restore = index;
                    ch = scanHexEscape('u');
                    if (ch) {
                        flags += ch;
                        for (str += '\\u'; restore < index; ++restore) {
                            str += source[restore];
                        }
                    } else {
                        index = restore;
                        flags += 'u';
                        str += '\\u';
                    }
                    tolerateUnexpectedToken();
                } else {
                    str += '\\';
                    tolerateUnexpectedToken();
                }
            } else {
                flags += ch;
                str += ch;
            }
        }

        return {
            value: flags,
            literal: str
        };
    }

    function scanRegExp() {
        var start, body, flags, value;
        scanning = true;

        lookahead = null;
        skipComment();
        start = index;

        body = scanRegExpBody();
        flags = scanRegExpFlags();
        value = testRegExp(body.value, flags.value);
        scanning = false;
        if (extra.tokenize) {
            return {
                type: Token.RegularExpression,
                value: value,
                regex: {
                    pattern: body.value,
                    flags: flags.value
                },
                lineNumber: lineNumber,
                lineStart: lineStart,
                start: start,
                end: index
            };
        }

        return {
            literal: body.literal + flags.literal,
            value: value,
            regex: {
                pattern: body.value,
                flags: flags.value
            },
            start: start,
            end: index
        };
    }

    function collectRegex() {
        var pos, loc, regex, token;

        skipComment();

        pos = index;
        loc = {
            start: {
                line: lineNumber,
                column: index - lineStart
            }
        };

        regex = scanRegExp();

        loc.end = {
            line: lineNumber,
            column: index - lineStart
        };

        /* istanbul ignore next */
        if (!extra.tokenize) {
            // Pop the previous token, which is likely '/' or '/='
            if (extra.tokens.length > 0) {
                token = extra.tokens[extra.tokens.length - 1];
                if (token.range[0] === pos && token.type === 'Punctuator') {
                    if (token.value === '/' || token.value === '/=') {
                        extra.tokens.pop();
                    }
                }
            }

            extra.tokens.push({
                type: 'RegularExpression',
                value: regex.literal,
                regex: regex.regex,
                range: [pos, index],
                loc: loc
            });
        }

        return regex;
    }

    function isIdentifierName(token) {
        return token.type === Token.Identifier ||
            token.type === Token.Keyword ||
            token.type === Token.BooleanLiteral ||
            token.type === Token.NullLiteral;
    }

    // Using the following algorithm:
    // https://github.com/mozilla/sweet.js/wiki/design

    function advanceSlash() {
        var regex, previous, check;

        function testKeyword(value) {
            return value && (value.length > 1) && (value[0] >= 'a') && (value[0] <= 'z');
        }

        previous = extra.tokenValues[extra.tokens.length - 1];
        regex = (previous !== null);

        switch (previous) {
        case 'this':
        case ']':
            regex = false;
            break;

        case ')':
            check = extra.tokenValues[extra.openParenToken - 1];
            regex = (check === 'if' || check === 'while' || check === 'for' || check === 'with');
            break;

        case '}':
            // Dividing a function by anything makes little sense,
            // but we have to check for that.
            regex = false;
            if (testKeyword(extra.tokenValues[extra.openCurlyToken - 3])) {
                // Anonymous function, e.g. function(){} /42
                check = extra.tokenValues[extra.openCurlyToken - 4];
                regex = check ? (FnExprTokens.indexOf(check) < 0) : false;
            } else if (testKeyword(extra.tokenValues[extra.openCurlyToken - 4])) {
                // Named function, e.g. function f(){} /42/
                check = extra.tokenValues[extra.openCurlyToken - 5];
                regex = check ? (FnExprTokens.indexOf(check) < 0) : true;
            }
        }

        return regex ? collectRegex() : scanPunctuator();
    }

    function advance() {
        var cp, token;

        if (index >= length) {
            return {
                type: Token.EOF,
                lineNumber: lineNumber,
                lineStart: lineStart,
                start: index,
                end: index
            };
        }

        cp = source.charCodeAt(index);

        if (isIdentifierStart(cp)) {
            token = scanIdentifier();
            if (strict && isStrictModeReservedWord(token.value)) {
                token.type = Token.Keyword;
            }
            return token;
        }

        // Very common: ( and ) and ;
        if (cp === 0x28 || cp === 0x29 || cp === 0x3B) {
            return scanPunctuator();
        }

        // String literal starts with single quote (U+0027) or double quote (U+0022).
        if (cp === 0x27 || cp === 0x22) {
            return scanStringLiteral();
        }

        // Dot (.) U+002E can also start a floating-point number, hence the need
        // to check the next character.
        if (cp === 0x2E) {
            if (isDecimalDigit(source.charCodeAt(index + 1))) {
                return scanNumericLiteral();
            }
            return scanPunctuator();
        }

        if (isDecimalDigit(cp)) {
            return scanNumericLiteral();
        }

        // Slash (/) U+002F can also start a regex.
        if (extra.tokenize && cp === 0x2F) {
            return advanceSlash();
        }

        // Template literals start with ` (U+0060) for template head
        // or } (U+007D) for template middle or template tail.
        if (cp === 0x60 || (cp === 0x7D && state.curlyStack[state.curlyStack.length - 1] === '${')) {
            return scanTemplate();
        }

        // Possible identifier start in a surrogate pair.
        if (cp >= 0xD800 && cp < 0xDFFF) {
            cp = codePointAt(index);
            if (isIdentifierStart(cp)) {
                return scanIdentifier();
            }
        }

        return scanPunctuator();
    }

    function collectToken() {
        var loc, token, value, entry;

        loc = {
            start: {
                line: lineNumber,
                column: index - lineStart
            }
        };

        token = advance();
        loc.end = {
            line: lineNumber,
            column: index - lineStart
        };

        if (token.type !== Token.EOF) {
            value = source.slice(token.start, token.end);
            entry = {
                type: TokenName[token.type],
                value: value,
                range: [token.start, token.end],
                loc: loc
            };
            if (token.regex) {
                entry.regex = {
                    pattern: token.regex.pattern,
                    flags: token.regex.flags
                };
            }
            if (extra.tokenValues) {
                extra.tokenValues.push((entry.type === 'Punctuator' || entry.type === 'Keyword') ? entry.value : null);
            }
            if (extra.tokenize) {
                if (!extra.range) {
                    delete entry.range;
                }
                if (!extra.loc) {
                    delete entry.loc;
                }
                if (extra.delegate) {
                    entry = extra.delegate(entry);
                }
            }
            extra.tokens.push(entry);
        }

        return token;
    }

    function lex() {
        var token;
        scanning = true;

        lastIndex = index;
        lastLineNumber = lineNumber;
        lastLineStart = lineStart;

        skipComment();

        token = lookahead;

        startIndex = index;
        startLineNumber = lineNumber;
        startLineStart = lineStart;

        lookahead = (typeof extra.tokens !== 'undefined') ? collectToken() : advance();
        scanning = false;
        return token;
    }

    function peek() {
        scanning = true;

        skipComment();

        lastIndex = index;
        lastLineNumber = lineNumber;
        lastLineStart = lineStart;

        startIndex = index;
        startLineNumber = lineNumber;
        startLineStart = lineStart;

        lookahead = (typeof extra.tokens !== 'undefined') ? collectToken() : advance();
        scanning = false;
    }

    function Position() {
        this.line = startLineNumber;
        this.column = startIndex - startLineStart;
    }

    function SourceLocation() {
        this.start = new Position();
        this.end = null;
    }

    function WrappingSourceLocation(startToken) {
        this.start = {
            line: startToken.lineNumber,
            column: startToken.start - startToken.lineStart
        };
        this.end = null;
    }

    function Node() {
        if (extra.range) {
            this.range = [startIndex, 0];
        }
        if (extra.loc) {
            this.loc = new SourceLocation();
        }
    }

    function WrappingNode(startToken) {
        if (extra.range) {
            this.range = [startToken.start, 0];
        }
        if (extra.loc) {
            this.loc = new WrappingSourceLocation(startToken);
        }
    }

    WrappingNode.prototype = Node.prototype = {

        processComment: function () {
            var lastChild,
                innerComments,
                leadingComments,
                trailingComments,
                bottomRight = extra.bottomRightStack,
                i,
                comment,
                last = bottomRight[bottomRight.length - 1];

            if (this.type === Syntax.Program) {
                if (this.body.length > 0) {
                    return;
                }
            }
            /**
             * patch innnerComments for properties empty block
             * `function a() {/** comments **\/}`
             */

            if (this.type === Syntax.BlockStatement && this.body.length === 0) {
                innerComments = [];
                for (i = extra.leadingComments.length - 1; i >= 0; --i) {
                    comment = extra.leadingComments[i];
                    if (this.range[1] >= comment.range[1]) {
                        innerComments.unshift(comment);
                        extra.leadingComments.splice(i, 1);
                        extra.trailingComments.splice(i, 1);
                    }
                }
                if (innerComments.length) {
                    this.innerComments = innerComments;
                    //bottomRight.push(this);
                    return;
                }
            }

            if (extra.trailingComments.length > 0) {
                trailingComments = [];
                for (i = extra.trailingComments.length - 1; i >= 0; --i) {
                    comment = extra.trailingComments[i];
                    if (comment.range[0] >= this.range[1]) {
                        trailingComments.unshift(comment);
                        extra.trailingComments.splice(i, 1);
                    }
                }
                extra.trailingComments = [];
            } else {
                if (last && last.trailingComments && last.trailingComments[0].range[0] >= this.range[1]) {
                    trailingComments = last.trailingComments;
                    delete last.trailingComments;
                }
            }

            // Eating the stack.
            while (last && last.range[0] >= this.range[0]) {
                lastChild = bottomRight.pop();
                last = bottomRight[bottomRight.length - 1];
            }

            if (lastChild) {
                if (lastChild.leadingComments) {
                    leadingComments = [];
                    for (i = lastChild.leadingComments.length - 1; i >= 0; --i) {
                        comment = lastChild.leadingComments[i];
                        if (comment.range[1] <= this.range[0]) {
                            leadingComments.unshift(comment);
                            lastChild.leadingComments.splice(i, 1);
                        }
                    }

                    if (!lastChild.leadingComments.length) {
                        lastChild.leadingComments = undefined;
                    }
                }
            } else if (extra.leadingComments.length > 0) {
                leadingComments = [];
                for (i = extra.leadingComments.length - 1; i >= 0; --i) {
                    comment = extra.leadingComments[i];
                    if (comment.range[1] <= this.range[0]) {
                        leadingComments.unshift(comment);
                        extra.leadingComments.splice(i, 1);
                    }
                }
            }


            if (leadingComments && leadingComments.length > 0) {
                this.leadingComments = leadingComments;
            }
            if (trailingComments && trailingComments.length > 0) {
                this.trailingComments = trailingComments;
            }

            bottomRight.push(this);
        },

        finish: function () {
            if (extra.range) {
                this.range[1] = lastIndex;
            }
            if (extra.loc) {
                this.loc.end = {
                    line: lastLineNumber,
                    column: lastIndex - lastLineStart
                };
                if (extra.source) {
                    this.loc.source = extra.source;
                }
            }

            if (extra.attachComment) {
                this.processComment();
            }
        },

        finishArrayExpression: function (elements) {
            this.type = Syntax.ArrayExpression;
            this.elements = elements;
            this.finish();
            return this;
        },

        finishArrayPattern: function (elements) {
            this.type = Syntax.ArrayPattern;
            this.elements = elements;
            this.finish();
            return this;
        },

        finishArrowFunctionExpression: function (params, defaults, body, expression) {
            this.type = Syntax.ArrowFunctionExpression;
            this.id = null;
            this.params = params;
            this.defaults = defaults;
            this.body = body;
            this.generator = false;
            this.expression = expression;
            this.finish();
            return this;
        },

        finishAssignmentExpression: function (operator, left, right) {
            this.type = Syntax.AssignmentExpression;
            this.operator = operator;
            this.left = left;
            this.right = right;
            this.finish();
            return this;
        },

        finishAssignmentPattern: function (left, right) {
            this.type = Syntax.AssignmentPattern;
            this.left = left;
            this.right = right;
            this.finish();
            return this;
        },

        finishBinaryExpression: function (operator, left, right) {
            this.type = (operator === '||' || operator === '&&') ? Syntax.LogicalExpression : Syntax.BinaryExpression;
            this.operator = operator;
            this.left = left;
            this.right = right;
            this.finish();
            return this;
        },

        finishBlockStatement: function (body) {
            this.type = Syntax.BlockStatement;
            this.body = body;
            this.finish();
            return this;
        },

        finishBreakStatement: function (label) {
            this.type = Syntax.BreakStatement;
            this.label = label;
            this.finish();
            return this;
        },

        finishCallExpression: function (callee, args) {
            this.type = Syntax.CallExpression;
            this.callee = callee;
            this.arguments = args;
            this.finish();
            return this;
        },

        finishCatchClause: function (param, body) {
            this.type = Syntax.CatchClause;
            this.param = param;
            this.body = body;
            this.finish();
            return this;
        },

        finishClassBody: function (body) {
            this.type = Syntax.ClassBody;
            this.body = body;
            this.finish();
            return this;
        },

        finishClassDeclaration: function (id, superClass, body) {
            this.type = Syntax.ClassDeclaration;
            this.id = id;
            this.superClass = superClass;
            this.body = body;
            this.finish();
            return this;
        },

        finishClassExpression: function (id, superClass, body) {
            this.type = Syntax.ClassExpression;
            this.id = id;
            this.superClass = superClass;
            this.body = body;
            this.finish();
            return this;
        },

        finishConditionalExpression: function (test, consequent, alternate) {
            this.type = Syntax.ConditionalExpression;
            this.test = test;
            this.consequent = consequent;
            this.alternate = alternate;
            this.finish();
            return this;
        },

        finishContinueStatement: function (label) {
            this.type = Syntax.ContinueStatement;
            this.label = label;
            this.finish();
            return this;
        },

        finishDebuggerStatement: function () {
            this.type = Syntax.DebuggerStatement;
            this.finish();
            return this;
        },

        finishDoWhileStatement: function (body, test) {
            this.type = Syntax.DoWhileStatement;
            this.body = body;
            this.test = test;
            this.finish();
            return this;
        },

        finishEmptyStatement: function () {
            this.type = Syntax.EmptyStatement;
            this.finish();
            return this;
        },

        finishExpressionStatement: function (expression) {
            this.type = Syntax.ExpressionStatement;
            this.expression = expression;
            this.finish();
            return this;
        },

        finishForStatement: function (init, test, update, body) {
            this.type = Syntax.ForStatement;
            this.init = init;
            this.test = test;
            this.update = update;
            this.body = body;
            this.finish();
            return this;
        },

        finishForOfStatement: function (left, right, body) {
            this.type = Syntax.ForOfStatement;
            this.left = left;
            this.right = right;
            this.body = body;
            this.finish();
            return this;
        },

        finishForInStatement: function (left, right, body) {
            this.type = Syntax.ForInStatement;
            this.left = left;
            this.right = right;
            this.body = body;
            this.each = false;
            this.finish();
            return this;
        },

        finishFunctionDeclaration: function (id, params, defaults, body, generator) {
            this.type = Syntax.FunctionDeclaration;
            this.id = id;
            this.params = params;
            this.defaults = defaults;
            this.body = body;
            this.generator = generator;
            this.expression = false;
            this.finish();
            return this;
        },

        finishFunctionExpression: function (id, params, defaults, body, generator) {
            this.type = Syntax.FunctionExpression;
            this.id = id;
            this.params = params;
            this.defaults = defaults;
            this.body = body;
            this.generator = generator;
            this.expression = false;
            this.finish();
            return this;
        },

        finishIdentifier: function (name) {
            this.type = Syntax.Identifier;
            this.name = name;
            this.finish();
            return this;
        },

        finishIfStatement: function (test, consequent, alternate) {
            this.type = Syntax.IfStatement;
            this.test = test;
            this.consequent = consequent;
            this.alternate = alternate;
            this.finish();
            return this;
        },

        finishLabeledStatement: function (label, body) {
            this.type = Syntax.LabeledStatement;
            this.label = label;
            this.body = body;
            this.finish();
            return this;
        },

        finishLiteral: function (token) {
            this.type = Syntax.Literal;
            this.value = token.value;
            this.raw = source.slice(token.start, token.end);
            if (token.regex) {
                this.regex = token.regex;
            }
            this.finish();
            return this;
        },

        finishMemberExpression: function (accessor, object, property) {
            this.type = Syntax.MemberExpression;
            this.computed = accessor === '[';
            this.object = object;
            this.property = property;
            this.finish();
            return this;
        },

        finishMetaProperty: function (meta, property) {
            this.type = Syntax.MetaProperty;
            this.meta = meta;
            this.property = property;
            this.finish();
            return this;
        },

        finishNewExpression: function (callee, args) {
            this.type = Syntax.NewExpression;
            this.callee = callee;
            this.arguments = args;
            this.finish();
            return this;
        },

        finishObjectExpression: function (properties) {
            this.type = Syntax.ObjectExpression;
            this.properties = properties;
            this.finish();
            return this;
        },

        finishObjectPattern: function (properties) {
            this.type = Syntax.ObjectPattern;
            this.properties = properties;
            this.finish();
            return this;
        },

        finishPostfixExpression: function (operator, argument) {
            this.type = Syntax.UpdateExpression;
            this.operator = operator;
            this.argument = argument;
            this.prefix = false;
            this.finish();
            return this;
        },

        finishProgram: function (body, sourceType) {
            this.type = Syntax.Program;
            this.body = body;
            this.sourceType = sourceType;
            this.finish();
            return this;
        },

        finishProperty: function (kind, key, computed, value, method, shorthand) {
            this.type = Syntax.Property;
            this.key = key;
            this.computed = computed;
            this.value = value;
            this.kind = kind;
            this.method = method;
            this.shorthand = shorthand;
            this.finish();
            return this;
        },

        finishRestElement: function (argument) {
            this.type = Syntax.RestElement;
            this.argument = argument;
            this.finish();
            return this;
        },

        finishReturnStatement: function (argument) {
            this.type = Syntax.ReturnStatement;
            this.argument = argument;
            this.finish();
            return this;
        },

        finishSequenceExpression: function (expressions) {
            this.type = Syntax.SequenceExpression;
            this.expressions = expressions;
            this.finish();
            return this;
        },

        finishSpreadElement: function (argument) {
            this.type = Syntax.SpreadElement;
            this.argument = argument;
            this.finish();
            return this;
        },

        finishSwitchCase: function (test, consequent) {
            this.type = Syntax.SwitchCase;
            this.test = test;
            this.consequent = consequent;
            this.finish();
            return this;
        },

        finishSuper: function () {
            this.type = Syntax.Super;
            this.finish();
            return this;
        },

        finishSwitchStatement: function (discriminant, cases) {
            this.type = Syntax.SwitchStatement;
            this.discriminant = discriminant;
            this.cases = cases;
            this.finish();
            return this;
        },

        finishTaggedTemplateExpression: function (tag, quasi) {
            this.type = Syntax.TaggedTemplateExpression;
            this.tag = tag;
            this.quasi = quasi;
            this.finish();
            return this;
        },

        finishTemplateElement: function (value, tail) {
            this.type = Syntax.TemplateElement;
            this.value = value;
            this.tail = tail;
            this.finish();
            return this;
        },

        finishTemplateLiteral: function (quasis, expressions) {
            this.type = Syntax.TemplateLiteral;
            this.quasis = quasis;
            this.expressions = expressions;
            this.finish();
            return this;
        },

        finishThisExpression: function () {
            this.type = Syntax.ThisExpression;
            this.finish();
            return this;
        },

        finishThrowStatement: function (argument) {
            this.type = Syntax.ThrowStatement;
            this.argument = argument;
            this.finish();
            return this;
        },

        finishTryStatement: function (block, handler, finalizer) {
            this.type = Syntax.TryStatement;
            this.block = block;
            this.guardedHandlers = [];
            this.handlers = handler ? [handler] : [];
            this.handler = handler;
            this.finalizer = finalizer;
            this.finish();
            return this;
        },

        finishUnaryExpression: function (operator, argument) {
            this.type = (operator === '++' || operator === '--') ? Syntax.UpdateExpression : Syntax.UnaryExpression;
            this.operator = operator;
            this.argument = argument;
            this.prefix = true;
            this.finish();
            return this;
        },

        finishVariableDeclaration: function (declarations) {
            this.type = Syntax.VariableDeclaration;
            this.declarations = declarations;
            this.kind = 'var';
            this.finish();
            return this;
        },

        finishLexicalDeclaration: function (declarations, kind) {
            this.type = Syntax.VariableDeclaration;
            this.declarations = declarations;
            this.kind = kind;
            this.finish();
            return this;
        },

        finishVariableDeclarator: function (id, init) {
            this.type = Syntax.VariableDeclarator;
            this.id = id;
            this.init = init;
            this.finish();
            return this;
        },

        finishWhileStatement: function (test, body) {
            this.type = Syntax.WhileStatement;
            this.test = test;
            this.body = body;
            this.finish();
            return this;
        },

        finishWithStatement: function (object, body) {
            this.type = Syntax.WithStatement;
            this.object = object;
            this.body = body;
            this.finish();
            return this;
        },

        finishExportSpecifier: function (local, exported) {
            this.type = Syntax.ExportSpecifier;
            this.exported = exported || local;
            this.local = local;
            this.finish();
            return this;
        },

        finishImportDefaultSpecifier: function (local) {
            this.type = Syntax.ImportDefaultSpecifier;
            this.local = local;
            this.finish();
            return this;
        },

        finishImportNamespaceSpecifier: function (local) {
            this.type = Syntax.ImportNamespaceSpecifier;
            this.local = local;
            this.finish();
            return this;
        },

        finishExportNamedDeclaration: function (declaration, specifiers, src) {
            this.type = Syntax.ExportNamedDeclaration;
            this.declaration = declaration;
            this.specifiers = specifiers;
            this.source = src;
            this.finish();
            return this;
        },

        finishExportDefaultDeclaration: function (declaration) {
            this.type = Syntax.ExportDefaultDeclaration;
            this.declaration = declaration;
            this.finish();
            return this;
        },

        finishExportAllDeclaration: function (src) {
            this.type = Syntax.ExportAllDeclaration;
            this.source = src;
            this.finish();
            return this;
        },

        finishImportSpecifier: function (local, imported) {
            this.type = Syntax.ImportSpecifier;
            this.local = local || imported;
            this.imported = imported;
            this.finish();
            return this;
        },

        finishImportDeclaration: function (specifiers, src) {
            this.type = Syntax.ImportDeclaration;
            this.specifiers = specifiers;
            this.source = src;
            this.finish();
            return this;
        },

        finishYieldExpression: function (argument, delegate) {
            this.type = Syntax.YieldExpression;
            this.argument = argument;
            this.delegate = delegate;
            this.finish();
            return this;
        }
    };


    function recordError(error) {
        var e, existing;

        for (e = 0; e < extra.errors.length; e++) {
            existing = extra.errors[e];
            // Prevent duplicated error.
            /* istanbul ignore next */
            if (existing.index === error.index && existing.message === error.message) {
                return;
            }
        }

        extra.errors.push(error);
    }

    function constructError(msg, column) {
        var error = new Error(msg);
        try {
            throw error;
        } catch (base) {
            /* istanbul ignore else */
            if (Object.create && Object.defineProperty) {
                error = Object.create(base);
                Object.defineProperty(error, 'column', { value: column });
            }
        } finally {
            return error;
        }
    }

    function createError(line, pos, description) {
        var msg, column, error;

        msg = 'Line ' + line + ': ' + description;
        column = pos - (scanning ? lineStart : lastLineStart) + 1;
        error = constructError(msg, column);
        error.lineNumber = line;
        error.description = description;
        error.index = pos;
        return error;
    }

    // Throw an exception

    function throwError(messageFormat) {
        var args, msg;

        args = Array.prototype.slice.call(arguments, 1);
        msg = messageFormat.replace(/%(\d)/g,
            function (whole, idx) {
                assert(idx < args.length, 'Message reference must be in range');
                return args[idx];
            }
        );

        throw createError(lastLineNumber, lastIndex, msg);
    }

    function tolerateError(messageFormat) {
        var args, msg, error;

        args = Array.prototype.slice.call(arguments, 1);
        /* istanbul ignore next */
        msg = messageFormat.replace(/%(\d)/g,
            function (whole, idx) {
                assert(idx < args.length, 'Message reference must be in range');
                return args[idx];
            }
        );

        error = createError(lineNumber, lastIndex, msg);
        if (extra.errors) {
            recordError(error);
        } else {
            throw error;
        }
    }

    // Throw an exception because of the token.

    function unexpectedTokenError(token, message) {
        var value, msg = message || Messages.UnexpectedToken;

        if (token) {
            if (!message) {
                msg = (token.type === Token.EOF) ? Messages.UnexpectedEOS :
                    (token.type === Token.Identifier) ? Messages.UnexpectedIdentifier :
                    (token.type === Token.NumericLiteral) ? Messages.UnexpectedNumber :
                    (token.type === Token.StringLiteral) ? Messages.UnexpectedString :
                    (token.type === Token.Template) ? Messages.UnexpectedTemplate :
                    Messages.UnexpectedToken;

                if (token.type === Token.Keyword) {
                    if (isFutureReservedWord(token.value)) {
                        msg = Messages.UnexpectedReserved;
                    } else if (strict && isStrictModeReservedWord(token.value)) {
                        msg = Messages.StrictReservedWord;
                    }
                }
            }

            value = (token.type === Token.Template) ? token.value.raw : token.value;
        } else {
            value = 'ILLEGAL';
        }

        msg = msg.replace('%0', value);

        return (token && typeof token.lineNumber === 'number') ?
            createError(token.lineNumber, token.start, msg) :
            createError(scanning ? lineNumber : lastLineNumber, scanning ? index : lastIndex, msg);
    }

    function throwUnexpectedToken(token, message) {
        throw unexpectedTokenError(token, message);
    }

    function tolerateUnexpectedToken(token, message) {
        var error = unexpectedTokenError(token, message);
        if (extra.errors) {
            recordError(error);
        } else {
            throw error;
        }
    }

    // Expect the next token to match the specified punctuator.
    // If not, an exception will be thrown.

    function expect(value) {
        var token = lex();
        if (token.type !== Token.Punctuator || token.value !== value) {
            throwUnexpectedToken(token);
        }
    }

    /**
     * @name expectCommaSeparator
     * @description Quietly expect a comma when in tolerant mode, otherwise delegates
     * to <code>expect(value)</code>
     * @since 2.0
     */
    function expectCommaSeparator() {
        var token;

        if (extra.errors) {
            token = lookahead;
            if (token.type === Token.Punctuator && token.value === ',') {
                lex();
            } else if (token.type === Token.Punctuator && token.value === ';') {
                lex();
                tolerateUnexpectedToken(token);
            } else {
                tolerateUnexpectedToken(token, Messages.UnexpectedToken);
            }
        } else {
            expect(',');
        }
    }

    // Expect the next token to match the specified keyword.
    // If not, an exception will be thrown.

    function expectKeyword(keyword) {
        var token = lex();
        if (token.type !== Token.Keyword || token.value !== keyword) {
            throwUnexpectedToken(token);
        }
    }

    // Return true if the next token matches the specified punctuator.

    function match(value) {
        return lookahead.type === Token.Punctuator && lookahead.value === value;
    }

    // Return true if the next token matches the specified keyword

    function matchKeyword(keyword) {
        return lookahead.type === Token.Keyword && lookahead.value === keyword;
    }

    // Return true if the next token matches the specified contextual keyword
    // (where an identifier is sometimes a keyword depending on the context)

    function matchContextualKeyword(keyword) {
        return lookahead.type === Token.Identifier && lookahead.value === keyword;
    }

    // Return true if the next token is an assignment operator

    function matchAssign() {
        var op;

        if (lookahead.type !== Token.Punctuator) {
            return false;
        }
        op = lookahead.value;
        return op === '=' ||
            op === '*=' ||
            op === '/=' ||
            op === '%=' ||
            op === '+=' ||
            op === '-=' ||
            op === '<<=' ||
            op === '>>=' ||
            op === '>>>=' ||
            op === '&=' ||
            op === '^=' ||
            op === '|=';
    }

    function consumeSemicolon() {
        // Catch the very common case first: immediately a semicolon (U+003B).
        if (source.charCodeAt(startIndex) === 0x3B || match(';')) {
            lex();
            return;
        }

        if (hasLineTerminator) {
            return;
        }

        // FIXME(ikarienator): this is seemingly an issue in the previous location info convention.
        lastIndex = startIndex;
        lastLineNumber = startLineNumber;
        lastLineStart = startLineStart;

        if (lookahead.type !== Token.EOF && !match('}')) {
            throwUnexpectedToken(lookahead);
        }
    }

    // Cover grammar support.
    //
    // When an assignment expression position starts with an left parenthesis, the determination of the type
    // of the syntax is to be deferred arbitrarily long until the end of the parentheses pair (plus a lookahead)
    // or the first comma. This situation also defers the determination of all the expressions nested in the pair.
    //
    // There are three productions that can be parsed in a parentheses pair that needs to be determined
    // after the outermost pair is closed. They are:
    //
    //   1. AssignmentExpression
    //   2. BindingElements
    //   3. AssignmentTargets
    //
    // In order to avoid exponential backtracking, we use two flags to denote if the production can be
    // binding element or assignment target.
    //
    // The three productions have the relationship:
    //
    //   BindingElements ⊆ AssignmentTargets ⊆ AssignmentExpression
    //
    // with a single exception that CoverInitializedName when used directly in an Expression, generates
    // an early error. Therefore, we need the third state, firstCoverInitializedNameError, to track the
    // first usage of CoverInitializedName and report it when we reached the end of the parentheses pair.
    //
    // isolateCoverGrammar function runs the given parser function with a new cover grammar context, and it does not
    // effect the current flags. This means the production the parser parses is only used as an expression. Therefore
    // the CoverInitializedName check is conducted.
    //
    // inheritCoverGrammar function runs the given parse function with a new cover grammar context, and it propagates
    // the flags outside of the parser. This means the production the parser parses is used as a part of a potential
    // pattern. The CoverInitializedName check is deferred.
    function isolateCoverGrammar(parser) {
        var oldIsBindingElement = isBindingElement,
            oldIsAssignmentTarget = isAssignmentTarget,
            oldFirstCoverInitializedNameError = firstCoverInitializedNameError,
            result;
        isBindingElement = true;
        isAssignmentTarget = true;
        firstCoverInitializedNameError = null;
        result = parser();
        if (firstCoverInitializedNameError !== null) {
            throwUnexpectedToken(firstCoverInitializedNameError);
        }
        isBindingElement = oldIsBindingElement;
        isAssignmentTarget = oldIsAssignmentTarget;
        firstCoverInitializedNameError = oldFirstCoverInitializedNameError;
        return result;
    }

    function inheritCoverGrammar(parser) {
        var oldIsBindingElement = isBindingElement,
            oldIsAssignmentTarget = isAssignmentTarget,
            oldFirstCoverInitializedNameError = firstCoverInitializedNameError,
            result;
        isBindingElement = true;
        isAssignmentTarget = true;
        firstCoverInitializedNameError = null;
        result = parser();
        isBindingElement = isBindingElement && oldIsBindingElement;
        isAssignmentTarget = isAssignmentTarget && oldIsAssignmentTarget;
        firstCoverInitializedNameError = oldFirstCoverInitializedNameError || firstCoverInitializedNameError;
        return result;
    }

    // ECMA-262 13.3.3 Destructuring Binding Patterns

    function parseArrayPattern(params, kind) {
        var node = new Node(), elements = [], rest, restNode;
        expect('[');

        while (!match(']')) {
            if (match(',')) {
                lex();
                elements.push(null);
            } else {
                if (match('...')) {
                    restNode = new Node();
                    lex();
                    params.push(lookahead);
                    rest = parseVariableIdentifier(kind);
                    elements.push(restNode.finishRestElement(rest));
                    break;
                } else {
                    elements.push(parsePatternWithDefault(params, kind));
                }
                if (!match(']')) {
                    expect(',');
                }
            }

        }

        expect(']');

        return node.finishArrayPattern(elements);
    }

    function parsePropertyPattern(params, kind) {
        var node = new Node(), key, keyToken, computed = match('['), init;
        if (lookahead.type === Token.Identifier) {
            keyToken = lookahead;
            key = parseVariableIdentifier();
            if (match('=')) {
                params.push(keyToken);
                lex();
                init = parseAssignmentExpression();

                return node.finishProperty(
                    'init', key, false,
                    new WrappingNode(keyToken).finishAssignmentPattern(key, init), false, false);
            } else if (!match(':')) {
                params.push(keyToken);
                return node.finishProperty('init', key, false, key, false, true);
            }
        } else {
            key = parseObjectPropertyKey();
        }
        expect(':');
        init = parsePatternWithDefault(params, kind);
        return node.finishProperty('init', key, computed, init, false, false);
    }

    function parseObjectPattern(params, kind) {
        var node = new Node(), properties = [];

        expect('{');

        while (!match('}')) {
            properties.push(parsePropertyPattern(params, kind));
            if (!match('}')) {
                expect(',');
            }
        }

        lex();

        return node.finishObjectPattern(properties);
    }

    function parsePattern(params, kind) {
        if (match('[')) {
            return parseArrayPattern(params, kind);
        } else if (match('{')) {
            return parseObjectPattern(params, kind);
        } else if (matchKeyword('let')) {
            if (kind === 'const' || kind === 'let') {
                tolerateUnexpectedToken(lookahead, Messages.UnexpectedToken);
            }
        }

        params.push(lookahead);
        return parseVariableIdentifier(kind);
    }

    function parsePatternWithDefault(params, kind) {
        var startToken = lookahead, pattern, previousAllowYield, right;
        pattern = parsePattern(params, kind);
        if (match('=')) {
            lex();
            previousAllowYield = state.allowYield;
            state.allowYield = true;
            right = isolateCoverGrammar(parseAssignmentExpression);
            state.allowYield = previousAllowYield;
            pattern = new WrappingNode(startToken).finishAssignmentPattern(pattern, right);
        }
        return pattern;
    }

    // ECMA-262 12.2.5 Array Initializer

    function parseArrayInitializer() {
        var elements = [], node = new Node(), restSpread;

        expect('[');

        while (!match(']')) {
            if (match(',')) {
                lex();
                elements.push(null);
            } else if (match('...')) {
                restSpread = new Node();
                lex();
                restSpread.finishSpreadElement(inheritCoverGrammar(parseAssignmentExpression));

                if (!match(']')) {
                    isAssignmentTarget = isBindingElement = false;
                    expect(',');
                }
                elements.push(restSpread);
            } else {
                elements.push(inheritCoverGrammar(parseAssignmentExpression));

                if (!match(']')) {
                    expect(',');
                }
            }
        }

        lex();

        return node.finishArrayExpression(elements);
    }

    // ECMA-262 12.2.6 Object Initializer

    function parsePropertyFunction(node, paramInfo, isGenerator) {
        var previousStrict, body;

        isAssignmentTarget = isBindingElement = false;

        previousStrict = strict;
        body = isolateCoverGrammar(parseFunctionSourceElements);

        if (strict && paramInfo.firstRestricted) {
            tolerateUnexpectedToken(paramInfo.firstRestricted, paramInfo.message);
        }
        if (strict && paramInfo.stricted) {
            tolerateUnexpectedToken(paramInfo.stricted, paramInfo.message);
        }

        strict = previousStrict;
        return node.finishFunctionExpression(null, paramInfo.params, paramInfo.defaults, body, isGenerator);
    }

    function parsePropertyMethodFunction() {
        var params, method, node = new Node(),
            previousAllowYield = state.allowYield;

        state.allowYield = false;
        params = parseParams();
        state.allowYield = previousAllowYield;

        state.allowYield = false;
        method = parsePropertyFunction(node, params, false);
        state.allowYield = previousAllowYield;

        return method;
    }

    function parseObjectPropertyKey() {
        var token, node = new Node(), expr;

        token = lex();

        // Note: This function is called only from parseObjectProperty(), where
        // EOF and Punctuator tokens are already filtered out.

        switch (token.type) {
        case Token.StringLiteral:
        case Token.NumericLiteral:
            if (strict && token.octal) {
                tolerateUnexpectedToken(token, Messages.StrictOctalLiteral);
            }
            return node.finishLiteral(token);
        case Token.Identifier:
        case Token.BooleanLiteral:
        case Token.NullLiteral:
        case Token.Keyword:
            return node.finishIdentifier(token.value);
        case Token.Punctuator:
            if (token.value === '[') {
                expr = isolateCoverGrammar(parseAssignmentExpression);
                expect(']');
                return expr;
            }
            break;
        }
        throwUnexpectedToken(token);
    }

    function lookaheadPropertyName() {
        switch (lookahead.type) {
        case Token.Identifier:
        case Token.StringLiteral:
        case Token.BooleanLiteral:
        case Token.NullLiteral:
        case Token.NumericLiteral:
        case Token.Keyword:
            return true;
        case Token.Punctuator:
            return lookahead.value === '[';
        }
        return false;
    }

    // This function is to try to parse a MethodDefinition as defined in 14.3. But in the case of object literals,
    // it might be called at a position where there is in fact a short hand identifier pattern or a data property.
    // This can only be determined after we consumed up to the left parentheses.
    //
    // In order to avoid back tracking, it returns `null` if the position is not a MethodDefinition and the caller
    // is responsible to visit other options.
    function tryParseMethodDefinition(token, key, computed, node) {
        var value, options, methodNode, params,
            previousAllowYield = state.allowYield;

        if (token.type === Token.Identifier) {
            // check for `get` and `set`;

            if (token.value === 'get' && lookaheadPropertyName()) {
                computed = match('[');
                key = parseObjectPropertyKey();
                methodNode = new Node();
                expect('(');
                expect(')');

                state.allowYield = false;
                value = parsePropertyFunction(methodNode, {
                    params: [],
                    defaults: [],
                    stricted: null,
                    firstRestricted: null,
                    message: null
                }, false);
                state.allowYield = previousAllowYield;

                return node.finishProperty('get', key, computed, value, false, false);
            } else if (token.value === 'set' && lookaheadPropertyName()) {
                computed = match('[');
                key = parseObjectPropertyKey();
                methodNode = new Node();
                expect('(');

                options = {
                    params: [],
                    defaultCount: 0,
                    defaults: [],
                    firstRestricted: null,
                    paramSet: {}
                };
                if (match(')')) {
                    tolerateUnexpectedToken(lookahead);
                } else {
                    state.allowYield = false;
                    parseParam(options);
                    state.allowYield = previousAllowYield;
                    if (options.defaultCount === 0) {
                        options.defaults = [];
                    }
                }
                expect(')');

                state.allowYield = false;
                value = parsePropertyFunction(methodNode, options, false);
                state.allowYield = previousAllowYield;

                return node.finishProperty('set', key, computed, value, false, false);
            }
        } else if (token.type === Token.Punctuator && token.value === '*' && lookaheadPropertyName()) {
            computed = match('[');
            key = parseObjectPropertyKey();
            methodNode = new Node();

            state.allowYield = true;
            params = parseParams();
            state.allowYield = previousAllowYield;

            state.allowYield = false;
            value = parsePropertyFunction(methodNode, params, true);
            state.allowYield = previousAllowYield;

            return node.finishProperty('init', key, computed, value, true, false);
        }

        if (key && match('(')) {
            value = parsePropertyMethodFunction();
            return node.finishProperty('init', key, computed, value, true, false);
        }

        // Not a MethodDefinition.
        return null;
    }

    function parseObjectProperty(hasProto) {
        var token = lookahead, node = new Node(), computed, key, maybeMethod, proto, value;

        computed = match('[');
        if (match('*')) {
            lex();
        } else {
            key = parseObjectPropertyKey();
        }
        maybeMethod = tryParseMethodDefinition(token, key, computed, node);
        if (maybeMethod) {
            return maybeMethod;
        }

        if (!key) {
            throwUnexpectedToken(lookahead);
        }

        // Check for duplicated __proto__
        if (!computed) {
            proto = (key.type === Syntax.Identifier && key.name === '__proto__') ||
                (key.type === Syntax.Literal && key.value === '__proto__');
            if (hasProto.value && proto) {
                tolerateError(Messages.DuplicateProtoProperty);
            }
            hasProto.value |= proto;
        }

        if (match(':')) {
            lex();
            value = inheritCoverGrammar(parseAssignmentExpression);
            return node.finishProperty('init', key, computed, value, false, false);
        }

        if (token.type === Token.Identifier) {
            if (match('=')) {
                firstCoverInitializedNameError = lookahead;
                lex();
                value = isolateCoverGrammar(parseAssignmentExpression);
                return node.finishProperty('init', key, computed,
                    new WrappingNode(token).finishAssignmentPattern(key, value), false, true);
            }
            return node.finishProperty('init', key, computed, key, false, true);
        }

        throwUnexpectedToken(lookahead);
    }

    function parseObjectInitializer() {
        var properties = [], hasProto = {value: false}, node = new Node();

        expect('{');

        while (!match('}')) {
            properties.push(parseObjectProperty(hasProto));

            if (!match('}')) {
                expectCommaSeparator();
            }
        }

        expect('}');

        return node.finishObjectExpression(properties);
    }

    function reinterpretExpressionAsPattern(expr) {
        var i;
        switch (expr.type) {
        case Syntax.Identifier:
        case Syntax.MemberExpression:
        case Syntax.RestElement:
        case Syntax.AssignmentPattern:
            break;
        case Syntax.SpreadElement:
            expr.type = Syntax.RestElement;
            reinterpretExpressionAsPattern(expr.argument);
            break;
        case Syntax.ArrayExpression:
            expr.type = Syntax.ArrayPattern;
            for (i = 0; i < expr.elements.length; i++) {
                if (expr.elements[i] !== null) {
                    reinterpretExpressionAsPattern(expr.elements[i]);
                }
            }
            break;
        case Syntax.ObjectExpression:
            expr.type = Syntax.ObjectPattern;
            for (i = 0; i < expr.properties.length; i++) {
                reinterpretExpressionAsPattern(expr.properties[i].value);
            }
            break;
        case Syntax.AssignmentExpression:
            expr.type = Syntax.AssignmentPattern;
            reinterpretExpressionAsPattern(expr.left);
            break;
        default:
            // Allow other node type for tolerant parsing.
            break;
        }
    }

    // ECMA-262 12.2.9 Template Literals

    function parseTemplateElement(option) {
        var node, token;

        if (lookahead.type !== Token.Template || (option.head && !lookahead.head)) {
            throwUnexpectedToken();
        }

        node = new Node();
        token = lex();

        return node.finishTemplateElement({ raw: token.value.raw, cooked: token.value.cooked }, token.tail);
    }

    function parseTemplateLiteral() {
        var quasi, quasis, expressions, node = new Node();

        quasi = parseTemplateElement({ head: true });
        quasis = [quasi];
        expressions = [];

        while (!quasi.tail) {
            expressions.push(parseExpression());
            quasi = parseTemplateElement({ head: false });
            quasis.push(quasi);
        }

        return node.finishTemplateLiteral(quasis, expressions);
    }

    // ECMA-262 12.2.10 The Grouping Operator

    function parseGroupExpression() {
        var expr, expressions, startToken, i, params = [];

        expect('(');

        if (match(')')) {
            lex();
            if (!match('=>')) {
                expect('=>');
            }
            return {
                type: PlaceHolders.ArrowParameterPlaceHolder,
                params: [],
                rawParams: []
            };
        }

        startToken = lookahead;
        if (match('...')) {
            expr = parseRestElement(params);
            expect(')');
            if (!match('=>')) {
                expect('=>');
            }
            return {
                type: PlaceHolders.ArrowParameterPlaceHolder,
                params: [expr]
            };
        }

        isBindingElement = true;
        expr = inheritCoverGrammar(parseAssignmentExpression);

        if (match(',')) {
            isAssignmentTarget = false;
            expressions = [expr];

            while (startIndex < length) {
                if (!match(',')) {
                    break;
                }
                lex();

                if (match('...')) {
                    if (!isBindingElement) {
                        throwUnexpectedToken(lookahead);
                    }
                    expressions.push(parseRestElement(params));
                    expect(')');
                    if (!match('=>')) {
                        expect('=>');
                    }
                    isBindingElement = false;
                    for (i = 0; i < expressions.length; i++) {
                        reinterpretExpressionAsPattern(expressions[i]);
                    }
                    return {
                        type: PlaceHolders.ArrowParameterPlaceHolder,
                        params: expressions
                    };
                }

                expressions.push(inheritCoverGrammar(parseAssignmentExpression));
            }

            expr = new WrappingNode(startToken).finishSequenceExpression(expressions);
        }


        expect(')');

        if (match('=>')) {
            if (expr.type === Syntax.Identifier && expr.name === 'yield') {
                return {
                    type: PlaceHolders.ArrowParameterPlaceHolder,
                    params: [expr]
                };
            }

            if (!isBindingElement) {
                throwUnexpectedToken(lookahead);
            }

            if (expr.type === Syntax.SequenceExpression) {
                for (i = 0; i < expr.expressions.length; i++) {
                    reinterpretExpressionAsPattern(expr.expressions[i]);
                }
            } else {
                reinterpretExpressionAsPattern(expr);
            }

            expr = {
                type: PlaceHolders.ArrowParameterPlaceHolder,
                params: expr.type === Syntax.SequenceExpression ? expr.expressions : [expr]
            };
        }
        isBindingElement = false;
        return expr;
    }


    // ECMA-262 12.2 Primary Expressions

    function parsePrimaryExpression() {
        var type, token, expr, node;

        if (match('(')) {
            isBindingElement = false;
            return inheritCoverGrammar(parseGroupExpression);
        }

        if (match('[')) {
            return inheritCoverGrammar(parseArrayInitializer);
        }

        if (match('{')) {
            return inheritCoverGrammar(parseObjectInitializer);
        }

        type = lookahead.type;
        node = new Node();

        if (type === Token.Identifier) {
            if (state.sourceType === 'module' && lookahead.value === 'await') {
                tolerateUnexpectedToken(lookahead);
            }
            expr = node.finishIdentifier(lex().value);
        } else if (type === Token.StringLiteral || type === Token.NumericLiteral) {
            isAssignmentTarget = isBindingElement = false;
            if (strict && lookahead.octal) {
                tolerateUnexpectedToken(lookahead, Messages.StrictOctalLiteral);
            }
            expr = node.finishLiteral(lex());
        } else if (type === Token.Keyword) {
            if (!strict && state.allowYield && matchKeyword('yield')) {
                return parseNonComputedProperty();
            }
            if (!strict && matchKeyword('let')) {
                return node.finishIdentifier(lex().value);
            }
            isAssignmentTarget = isBindingElement = false;
            if (matchKeyword('function')) {
                return parseFunctionExpression();
            }
            if (matchKeyword('this')) {
                lex();
                return node.finishThisExpression();
            }
            if (matchKeyword('class')) {
                return parseClassExpression();
            }
            throwUnexpectedToken(lex());
        } else if (type === Token.BooleanLiteral) {
            isAssignmentTarget = isBindingElement = false;
            token = lex();
            token.value = (token.value === 'true');
            expr = node.finishLiteral(token);
        } else if (type === Token.NullLiteral) {
            isAssignmentTarget = isBindingElement = false;
            token = lex();
            token.value = null;
            expr = node.finishLiteral(token);
        } else if (match('/') || match('/=')) {
            isAssignmentTarget = isBindingElement = false;
            index = startIndex;

            if (typeof extra.tokens !== 'undefined') {
                token = collectRegex();
            } else {
                token = scanRegExp();
            }
            lex();
            expr = node.finishLiteral(token);
        } else if (type === Token.Template) {
            expr = parseTemplateLiteral();
        } else {
            throwUnexpectedToken(lex());
        }

        return expr;
    }

    // ECMA-262 12.3 Left-Hand-Side Expressions

    function parseArguments() {
        var args = [], expr;

        expect('(');

        if (!match(')')) {
            while (startIndex < length) {
                if (match('...')) {
                    expr = new Node();
                    lex();
                    expr.finishSpreadElement(isolateCoverGrammar(parseAssignmentExpression));
                } else {
                    expr = isolateCoverGrammar(parseAssignmentExpression);
                }
                args.push(expr);
                if (match(')')) {
                    break;
                }
                expectCommaSeparator();
            }
        }

        expect(')');

        return args;
    }

    function parseNonComputedProperty() {
        var token, node = new Node();

        token = lex();

        if (!isIdentifierName(token)) {
            throwUnexpectedToken(token);
        }

        return node.finishIdentifier(token.value);
    }

    function parseNonComputedMember() {
        expect('.');

        return parseNonComputedProperty();
    }

    function parseComputedMember() {
        var expr;

        expect('[');

        expr = isolateCoverGrammar(parseExpression);

        expect(']');

        return expr;
    }

    // ECMA-262 12.3.3 The new Operator

    function parseNewExpression() {
        var callee, args, node = new Node();

        expectKeyword('new');

        if (match('.')) {
            lex();
            if (lookahead.type === Token.Identifier && lookahead.value === 'target') {
                if (state.inFunctionBody) {
                    lex();
                    return node.finishMetaProperty('new', 'target');
                }
            }
            throwUnexpectedToken(lookahead);
        }

        callee = isolateCoverGrammar(parseLeftHandSideExpression);
        args = match('(') ? parseArguments() : [];

        isAssignmentTarget = isBindingElement = false;

        return node.finishNewExpression(callee, args);
    }

    // ECMA-262 12.3.4 Function Calls

    function parseLeftHandSideExpressionAllowCall() {
        var quasi, expr, args, property, startToken, previousAllowIn = state.allowIn;

        startToken = lookahead;
        state.allowIn = true;

        if (matchKeyword('super') && state.inFunctionBody) {
            expr = new Node();
            lex();
            expr = expr.finishSuper();
            if (!match('(') && !match('.') && !match('[')) {
                throwUnexpectedToken(lookahead);
            }
        } else {
            expr = inheritCoverGrammar(matchKeyword('new') ? parseNewExpression : parsePrimaryExpression);
        }

        for (;;) {
            if (match('.')) {
                isBindingElement = false;
                isAssignmentTarget = true;
                property = parseNonComputedMember();
                expr = new WrappingNode(startToken).finishMemberExpression('.', expr, property);
            } else if (match('(')) {
                isBindingElement = false;
                isAssignmentTarget = false;
                args = parseArguments();
                expr = new WrappingNode(startToken).finishCallExpression(expr, args);
            } else if (match('[')) {
                isBindingElement = false;
                isAssignmentTarget = true;
                property = parseComputedMember();
                expr = new WrappingNode(startToken).finishMemberExpression('[', expr, property);
            } else if (lookahead.type === Token.Template && lookahead.head) {
                quasi = parseTemplateLiteral();
                expr = new WrappingNode(startToken).finishTaggedTemplateExpression(expr, quasi);
            } else {
                break;
            }
        }
        state.allowIn = previousAllowIn;

        return expr;
    }

    // ECMA-262 12.3 Left-Hand-Side Expressions

    function parseLeftHandSideExpression() {
        var quasi, expr, property, startToken;
        assert(state.allowIn, 'callee of new expression always allow in keyword.');

        startToken = lookahead;

        if (matchKeyword('super') && state.inFunctionBody) {
            expr = new Node();
            lex();
            expr = expr.finishSuper();
            if (!match('[') && !match('.')) {
                throwUnexpectedToken(lookahead);
            }
        } else {
            expr = inheritCoverGrammar(matchKeyword('new') ? parseNewExpression : parsePrimaryExpression);
        }

        for (;;) {
            if (match('[')) {
                isBindingElement = false;
                isAssignmentTarget = true;
                property = parseComputedMember();
                expr = new WrappingNode(startToken).finishMemberExpression('[', expr, property);
            } else if (match('.')) {
                isBindingElement = false;
                isAssignmentTarget = true;
                property = parseNonComputedMember();
                expr = new WrappingNode(startToken).finishMemberExpression('.', expr, property);
            } else if (lookahead.type === Token.Template && lookahead.head) {
                quasi = parseTemplateLiteral();
                expr = new WrappingNode(startToken).finishTaggedTemplateExpression(expr, quasi);
            } else {
                break;
            }
        }
        return expr;
    }

    // ECMA-262 12.4 Postfix Expressions

    function parsePostfixExpression() {
        var expr, token, startToken = lookahead;

        expr = inheritCoverGrammar(parseLeftHandSideExpressionAllowCall);

        if (!hasLineTerminator && lookahead.type === Token.Punctuator) {
            if (match('++') || match('--')) {
                // ECMA-262 11.3.1, 11.3.2
                if (strict && expr.type === Syntax.Identifier && isRestrictedWord(expr.name)) {
                    tolerateError(Messages.StrictLHSPostfix);
                }

                if (!isAssignmentTarget) {
                    tolerateError(Messages.InvalidLHSInAssignment);
                }

                isAssignmentTarget = isBindingElement = false;

                token = lex();
                expr = new WrappingNode(startToken).finishPostfixExpression(token.value, expr);
            }
        }

        return expr;
    }

    // ECMA-262 12.5 Unary Operators

    function parseUnaryExpression() {
        var token, expr, startToken;

        if (lookahead.type !== Token.Punctuator && lookahead.type !== Token.Keyword) {
            expr = parsePostfixExpression();
        } else if (match('++') || match('--')) {
            startToken = lookahead;
            token = lex();
            expr = inheritCoverGrammar(parseUnaryExpression);
            // ECMA-262 11.4.4, 11.4.5
            if (strict && expr.type === Syntax.Identifier && isRestrictedWord(expr.name)) {
                tolerateError(Messages.StrictLHSPrefix);
            }

            if (!isAssignmentTarget) {
                tolerateError(Messages.InvalidLHSInAssignment);
            }
            expr = new WrappingNode(startToken).finishUnaryExpression(token.value, expr);
            isAssignmentTarget = isBindingElement = false;
        } else if (match('+') || match('-') || match('~') || match('!')) {
            startToken = lookahead;
            token = lex();
            expr = inheritCoverGrammar(parseUnaryExpression);
            expr = new WrappingNode(startToken).finishUnaryExpression(token.value, expr);
            isAssignmentTarget = isBindingElement = false;
        } else if (matchKeyword('delete') || matchKeyword('void') || matchKeyword('typeof')) {
            startToken = lookahead;
            token = lex();
            expr = inheritCoverGrammar(parseUnaryExpression);
            expr = new WrappingNode(startToken).finishUnaryExpression(token.value, expr);
            if (strict && expr.operator === 'delete' && expr.argument.type === Syntax.Identifier) {
                tolerateError(Messages.StrictDelete);
            }
            isAssignmentTarget = isBindingElement = false;
        } else {
            expr = parsePostfixExpression();
        }

        return expr;
    }

    function binaryPrecedence(token, allowIn) {
        var prec = 0;

        if (token.type !== Token.Punctuator && token.type !== Token.Keyword) {
            return 0;
        }

        switch (token.value) {
        case '||':
            prec = 1;
            break;

        case '&&':
            prec = 2;
            break;

        case '|':
            prec = 3;
            break;

        case '^':
            prec = 4;
            break;

        case '&':
            prec = 5;
            break;

        case '==':
        case '!=':
        case '===':
        case '!==':
            prec = 6;
            break;

        case '<':
        case '>':
        case '<=':
        case '>=':
        case 'instanceof':
            prec = 7;
            break;

        case 'in':
            prec = allowIn ? 7 : 0;
            break;

        case '<<':
        case '>>':
        case '>>>':
            prec = 8;
            break;

        case '+':
        case '-':
            prec = 9;
            break;

        case '*':
        case '/':
        case '%':
            prec = 11;
            break;

        default:
            break;
        }

        return prec;
    }

    // ECMA-262 12.6 Multiplicative Operators
    // ECMA-262 12.7 Additive Operators
    // ECMA-262 12.8 Bitwise Shift Operators
    // ECMA-262 12.9 Relational Operators
    // ECMA-262 12.10 Equality Operators
    // ECMA-262 12.11 Binary Bitwise Operators
    // ECMA-262 12.12 Binary Logical Operators

    function parseBinaryExpression() {
        var marker, markers, expr, token, prec, stack, right, operator, left, i;

        marker = lookahead;
        left = inheritCoverGrammar(parseUnaryExpression);

        token = lookahead;
        prec = binaryPrecedence(token, state.allowIn);
        if (prec === 0) {
            return left;
        }
        isAssignmentTarget = isBindingElement = false;
        token.prec = prec;
        lex();

        markers = [marker, lookahead];
        right = isolateCoverGrammar(parseUnaryExpression);

        stack = [left, token, right];

        while ((prec = binaryPrecedence(lookahead, state.allowIn)) > 0) {

            // Reduce: make a binary expression from the three topmost entries.
            while ((stack.length > 2) && (prec <= stack[stack.length - 2].prec)) {
                right = stack.pop();
                operator = stack.pop().value;
                left = stack.pop();
                markers.pop();
                expr = new WrappingNode(markers[markers.length - 1]).finishBinaryExpression(operator, left, right);
                stack.push(expr);
            }

            // Shift.
            token = lex();
            token.prec = prec;
            stack.push(token);
            markers.push(lookahead);
            expr = isolateCoverGrammar(parseUnaryExpression);
            stack.push(expr);
        }

        // Final reduce to clean-up the stack.
        i = stack.length - 1;
        expr = stack[i];
        markers.pop();
        while (i > 1) {
            expr = new WrappingNode(markers.pop()).finishBinaryExpression(stack[i - 1].value, stack[i - 2], expr);
            i -= 2;
        }

        return expr;
    }


    // ECMA-262 12.13 Conditional Operator

    function parseConditionalExpression() {
        var expr, previousAllowIn, consequent, alternate, startToken;

        startToken = lookahead;

        expr = inheritCoverGrammar(parseBinaryExpression);
        if (match('?')) {
            lex();
            previousAllowIn = state.allowIn;
            state.allowIn = true;
            consequent = isolateCoverGrammar(parseAssignmentExpression);
            state.allowIn = previousAllowIn;
            expect(':');
            alternate = isolateCoverGrammar(parseAssignmentExpression);

            expr = new WrappingNode(startToken).finishConditionalExpression(expr, consequent, alternate);
            isAssignmentTarget = isBindingElement = false;
        }

        return expr;
    }

    // ECMA-262 14.2 Arrow Function Definitions

    function parseConciseBody() {
        if (match('{')) {
            return parseFunctionSourceElements();
        }
        return isolateCoverGrammar(parseAssignmentExpression);
    }

    function checkPatternParam(options, param) {
        var i;
        switch (param.type) {
        case Syntax.Identifier:
            validateParam(options, param, param.name);
            break;
        case Syntax.RestElement:
            checkPatternParam(options, param.argument);
            break;
        case Syntax.AssignmentPattern:
            checkPatternParam(options, param.left);
            break;
        case Syntax.ArrayPattern:
            for (i = 0; i < param.elements.length; i++) {
                if (param.elements[i] !== null) {
                    checkPatternParam(options, param.elements[i]);
                }
            }
            break;
        case Syntax.YieldExpression:
            break;
        default:
            assert(param.type === Syntax.ObjectPattern, 'Invalid type');
            for (i = 0; i < param.properties.length; i++) {
                checkPatternParam(options, param.properties[i].value);
            }
            break;
        }
    }
    function reinterpretAsCoverFormalsList(expr) {
        var i, len, param, params, defaults, defaultCount, options, token;

        defaults = [];
        defaultCount = 0;
        params = [expr];

        switch (expr.type) {
        case Syntax.Identifier:
            break;
        case PlaceHolders.ArrowParameterPlaceHolder:
            params = expr.params;
            break;
        default:
            return null;
        }

        options = {
            paramSet: {}
        };

        for (i = 0, len = params.length; i < len; i += 1) {
            param = params[i];
            switch (param.type) {
            case Syntax.AssignmentPattern:
                params[i] = param.left;
                if (param.right.type === Syntax.YieldExpression) {
                    if (param.right.argument) {
                        throwUnexpectedToken(lookahead);
                    }
                    param.right.type = Syntax.Identifier;
                    param.right.name = 'yield';
                    delete param.right.argument;
                    delete param.right.delegate;
                }
                defaults.push(param.right);
                ++defaultCount;
                checkPatternParam(options, param.left);
                break;
            default:
                checkPatternParam(options, param);
                params[i] = param;
                defaults.push(null);
                break;
            }
        }

        if (strict || !state.allowYield) {
            for (i = 0, len = params.length; i < len; i += 1) {
                param = params[i];
                if (param.type === Syntax.YieldExpression) {
                    throwUnexpectedToken(lookahead);
                }
            }
        }

        if (options.message === Messages.StrictParamDupe) {
            token = strict ? options.stricted : options.firstRestricted;
            throwUnexpectedToken(token, options.message);
        }

        if (defaultCount === 0) {
            defaults = [];
        }

        return {
            params: params,
            defaults: defaults,
            stricted: options.stricted,
            firstRestricted: options.firstRestricted,
            message: options.message
        };
    }

    function parseArrowFunctionExpression(options, node) {
        var previousStrict, previousAllowYield, body;

        if (hasLineTerminator) {
            tolerateUnexpectedToken(lookahead);
        }
        expect('=>');

        previousStrict = strict;
        previousAllowYield = state.allowYield;
        state.allowYield = true;

        body = parseConciseBody();

        if (strict && options.firstRestricted) {
            throwUnexpectedToken(options.firstRestricted, options.message);
        }
        if (strict && options.stricted) {
            tolerateUnexpectedToken(options.stricted, options.message);
        }

        strict = previousStrict;
        state.allowYield = previousAllowYield;

        return node.finishArrowFunctionExpression(options.params, options.defaults, body, body.type !== Syntax.BlockStatement);
    }

    // ECMA-262 14.4 Yield expression

    function parseYieldExpression() {
        var argument, expr, delegate, previousAllowYield;

        argument = null;
        expr = new Node();
        delegate = false;

        expectKeyword('yield');

        if (!hasLineTerminator) {
            previousAllowYield = state.allowYield;
            state.allowYield = false;
            delegate = match('*');
            if (delegate) {
                lex();
                argument = parseAssignmentExpression();
            } else {
                if (!match(';') && !match('}') && !match(')') && lookahead.type !== Token.EOF) {
                    argument = parseAssignmentExpression();
                }
            }
            state.allowYield = previousAllowYield;
        }

        return expr.finishYieldExpression(argument, delegate);
    }

    // ECMA-262 12.14 Assignment Operators

    function parseAssignmentExpression() {
        var token, expr, right, list, startToken;

        startToken = lookahead;
        token = lookahead;

        if (!state.allowYield && matchKeyword('yield')) {
            return parseYieldExpression();
        }

        expr = parseConditionalExpression();

        if (expr.type === PlaceHolders.ArrowParameterPlaceHolder || match('=>')) {
            isAssignmentTarget = isBindingElement = false;
            list = reinterpretAsCoverFormalsList(expr);

            if (list) {
                firstCoverInitializedNameError = null;
                return parseArrowFunctionExpression(list, new WrappingNode(startToken));
            }

            return expr;
        }

        if (matchAssign()) {
            if (!isAssignmentTarget) {
                tolerateError(Messages.InvalidLHSInAssignment);
            }

            // ECMA-262 12.1.1
            if (strict && expr.type === Syntax.Identifier) {
                if (isRestrictedWord(expr.name)) {
                    tolerateUnexpectedToken(token, Messages.StrictLHSAssignment);
                }
                if (isStrictModeReservedWord(expr.name)) {
                    tolerateUnexpectedToken(token, Messages.StrictReservedWord);
                }
            }

            if (!match('=')) {
                isAssignmentTarget = isBindingElement = false;
            } else {
                reinterpretExpressionAsPattern(expr);
            }

            token = lex();
            right = isolateCoverGrammar(parseAssignmentExpression);
            expr = new WrappingNode(startToken).finishAssignmentExpression(token.value, expr, right);
            firstCoverInitializedNameError = null;
        }

        return expr;
    }

    // ECMA-262 12.15 Comma Operator

    function parseExpression() {
        var expr, startToken = lookahead, expressions;

        expr = isolateCoverGrammar(parseAssignmentExpression);

        if (match(',')) {
            expressions = [expr];

            while (startIndex < length) {
                if (!match(',')) {
                    break;
                }
                lex();
                expressions.push(isolateCoverGrammar(parseAssignmentExpression));
            }

            expr = new WrappingNode(startToken).finishSequenceExpression(expressions);
        }

        return expr;
    }

    // ECMA-262 13.2 Block

    function parseStatementListItem() {
        if (lookahead.type === Token.Keyword) {
            switch (lookahead.value) {
            case 'export':
                if (state.sourceType !== 'module') {
                    tolerateUnexpectedToken(lookahead, Messages.IllegalExportDeclaration);
                }
                return parseExportDeclaration();
            case 'import':
                if (state.sourceType !== 'module') {
                    tolerateUnexpectedToken(lookahead, Messages.IllegalImportDeclaration);
                }
                return parseImportDeclaration();
            case 'const':
                return parseLexicalDeclaration({inFor: false});
            case 'function':
                return parseFunctionDeclaration(new Node());
            case 'class':
                return parseClassDeclaration();
            }
        }

        if (matchKeyword('let') && isLexicalDeclaration()) {
            return parseLexicalDeclaration({inFor: false});
        }

        return parseStatement();
    }

    function parseStatementList() {
        var list = [];
        while (startIndex < length) {
            if (match('}')) {
                break;
            }
            list.push(parseStatementListItem());
        }

        return list;
    }

    function parseBlock() {
        var block, node = new Node();

        expect('{');

        block = parseStatementList();

        expect('}');

        return node.finishBlockStatement(block);
    }

    // ECMA-262 13.3.2 Variable Statement

    function parseVariableIdentifier(kind) {
        var token, node = new Node();

        token = lex();

        if (token.type === Token.Keyword && token.value === 'yield') {
            if (strict) {
                tolerateUnexpectedToken(token, Messages.StrictReservedWord);
            } if (!state.allowYield) {
                throwUnexpectedToken(token);
            }
        } else if (token.type !== Token.Identifier) {
            if (strict && token.type === Token.Keyword && isStrictModeReservedWord(token.value)) {
                tolerateUnexpectedToken(token, Messages.StrictReservedWord);
            } else {
                if (strict || token.value !== 'let' || kind !== 'var') {
                    throwUnexpectedToken(token);
                }
            }
        } else if (state.sourceType === 'module' && token.type === Token.Identifier && token.value === 'await') {
            tolerateUnexpectedToken(token);
        }

        return node.finishIdentifier(token.value);
    }

    function parseVariableDeclaration(options) {
        var init = null, id, node = new Node(), params = [];

        id = parsePattern(params, 'var');

        // ECMA-262 12.2.1
        if (strict && isRestrictedWord(id.name)) {
            tolerateError(Messages.StrictVarName);
        }

        if (match('=')) {
            lex();
            init = isolateCoverGrammar(parseAssignmentExpression);
        } else if (id.type !== Syntax.Identifier && !options.inFor) {
            expect('=');
        }

        return node.finishVariableDeclarator(id, init);
    }

    function parseVariableDeclarationList(options) {
        var opt, list;

        opt = { inFor: options.inFor };
        list = [parseVariableDeclaration(opt)];

        while (match(',')) {
            lex();
            list.push(parseVariableDeclaration(opt));
        }

        return list;
    }

    function parseVariableStatement(node) {
        var declarations;

        expectKeyword('var');

        declarations = parseVariableDeclarationList({ inFor: false });

        consumeSemicolon();

        return node.finishVariableDeclaration(declarations);
    }

    // ECMA-262 13.3.1 Let and Const Declarations

    function parseLexicalBinding(kind, options) {
        var init = null, id, node = new Node(), params = [];

        id = parsePattern(params, kind);

        // ECMA-262 12.2.1
        if (strict && id.type === Syntax.Identifier && isRestrictedWord(id.name)) {
            tolerateError(Messages.StrictVarName);
        }

        if (kind === 'const') {
            if (!matchKeyword('in') && !matchContextualKeyword('of')) {
                expect('=');
                init = isolateCoverGrammar(parseAssignmentExpression);
            }
        } else if ((!options.inFor && id.type !== Syntax.Identifier) || match('=')) {
            expect('=');
            init = isolateCoverGrammar(parseAssignmentExpression);
        }

        return node.finishVariableDeclarator(id, init);
    }

    function parseBindingList(kind, options) {
        var list = [parseLexicalBinding(kind, options)];

        while (match(',')) {
            lex();
            list.push(parseLexicalBinding(kind, options));
        }

        return list;
    }


    function tokenizerState() {
        return {
            index: index,
            lineNumber: lineNumber,
            lineStart: lineStart,
            hasLineTerminator: hasLineTerminator,
            lastIndex: lastIndex,
            lastLineNumber: lastLineNumber,
            lastLineStart: lastLineStart,
            startIndex: startIndex,
            startLineNumber: startLineNumber,
            startLineStart: startLineStart,
            lookahead: lookahead,
            tokenCount: extra.tokens ? extra.tokens.length : 0
        };
    }

    function resetTokenizerState(ts) {
        index = ts.index;
        lineNumber = ts.lineNumber;
        lineStart = ts.lineStart;
        hasLineTerminator = ts.hasLineTerminator;
        lastIndex = ts.lastIndex;
        lastLineNumber = ts.lastLineNumber;
        lastLineStart = ts.lastLineStart;
        startIndex = ts.startIndex;
        startLineNumber = ts.startLineNumber;
        startLineStart = ts.startLineStart;
        lookahead = ts.lookahead;
        if (extra.tokens) {
            extra.tokens.splice(ts.tokenCount, extra.tokens.length);
        }
    }

    function isLexicalDeclaration() {
        var lexical, ts;

        ts = tokenizerState();

        lex();
        lexical = (lookahead.type === Token.Identifier) || match('[') || match('{') ||
            matchKeyword('let') || matchKeyword('yield');

        resetTokenizerState(ts);

        return lexical;
    }

    function parseLexicalDeclaration(options) {
        var kind, declarations, node = new Node();

        kind = lex().value;
        assert(kind === 'let' || kind === 'const', 'Lexical declaration must be either let or const');

        declarations = parseBindingList(kind, options);

        consumeSemicolon();

        return node.finishLexicalDeclaration(declarations, kind);
    }

    function parseRestElement(params) {
        var param, node = new Node();

        lex();

        if (match('{')) {
            throwError(Messages.ObjectPatternAsRestParameter);
        }

        params.push(lookahead);

        param = parseVariableIdentifier();

        if (match('=')) {
            throwError(Messages.DefaultRestParameter);
        }

        if (!match(')')) {
            throwError(Messages.ParameterAfterRestParameter);
        }

        return node.finishRestElement(param);
    }

    // ECMA-262 13.4 Empty Statement

    function parseEmptyStatement(node) {
        expect(';');
        return node.finishEmptyStatement();
    }

    // ECMA-262 12.4 Expression Statement

    function parseExpressionStatement(node) {
        var expr = parseExpression();
        consumeSemicolon();
        return node.finishExpressionStatement(expr);
    }

    // ECMA-262 13.6 If statement

    function parseIfStatement(node) {
        var test, consequent, alternate;

        expectKeyword('if');

        expect('(');

        test = parseExpression();

        expect(')');

        consequent = parseStatement();

        if (matchKeyword('else')) {
            lex();
            alternate = parseStatement();
        } else {
            alternate = null;
        }

        return node.finishIfStatement(test, consequent, alternate);
    }

    // ECMA-262 13.7 Iteration Statements

    function parseDoWhileStatement(node) {
        var body, test, oldInIteration;

        expectKeyword('do');

        oldInIteration = state.inIteration;
        state.inIteration = true;

        body = parseStatement();

        state.inIteration = oldInIteration;

        expectKeyword('while');

        expect('(');

        test = parseExpression();

        expect(')');

        if (match(';')) {
            lex();
        }

        return node.finishDoWhileStatement(body, test);
    }

    function parseWhileStatement(node) {
        var test, body, oldInIteration;

        expectKeyword('while');

        expect('(');

        test = parseExpression();

        expect(')');

        oldInIteration = state.inIteration;
        state.inIteration = true;

        body = parseStatement();

        state.inIteration = oldInIteration;

        return node.finishWhileStatement(test, body);
    }

    function parseForStatement(node) {
        var init, forIn, initSeq, initStartToken, test, update, left, right, kind, declarations,
            body, oldInIteration, previousAllowIn = state.allowIn;

        init = test = update = null;
        forIn = true;

        expectKeyword('for');

        expect('(');

        if (match(';')) {
            lex();
        } else {
            if (matchKeyword('var')) {
                init = new Node();
                lex();

                state.allowIn = false;
                declarations = parseVariableDeclarationList({ inFor: true });
                state.allowIn = previousAllowIn;

                if (declarations.length === 1 && matchKeyword('in')) {
                    init = init.finishVariableDeclaration(declarations);
                    lex();
                    left = init;
                    right = parseExpression();
                    init = null;
                } else if (declarations.length === 1 && declarations[0].init === null && matchContextualKeyword('of')) {
                    init = init.finishVariableDeclaration(declarations);
                    lex();
                    left = init;
                    right = parseAssignmentExpression();
                    init = null;
                    forIn = false;
                } else {
                    init = init.finishVariableDeclaration(declarations);
                    expect(';');
                }
            } else if (matchKeyword('const') || matchKeyword('let')) {
                init = new Node();
                kind = lex().value;

                if (!strict && lookahead.value === 'in') {
                    init = init.finishIdentifier(kind);
                    lex();
                    left = init;
                    right = parseExpression();
                    init = null;
                } else {
                    state.allowIn = false;
                    declarations = parseBindingList(kind, {inFor: true});
                    state.allowIn = previousAllowIn;

                    if (declarations.length === 1 && declarations[0].init === null && matchKeyword('in')) {
                        init = init.finishLexicalDeclaration(declarations, kind);
                        lex();
                        left = init;
                        right = parseExpression();
                        init = null;
                    } else if (declarations.length === 1 && declarations[0].init === null && matchContextualKeyword('of')) {
                        init = init.finishLexicalDeclaration(declarations, kind);
                        lex();
                        left = init;
                        right = parseAssignmentExpression();
                        init = null;
                        forIn = false;
                    } else {
                        consumeSemicolon();
                        init = init.finishLexicalDeclaration(declarations, kind);
                    }
                }
            } else {
                initStartToken = lookahead;
                state.allowIn = false;
                init = inheritCoverGrammar(parseAssignmentExpression);
                state.allowIn = previousAllowIn;

                if (matchKeyword('in')) {
                    if (!isAssignmentTarget) {
                        tolerateError(Messages.InvalidLHSInForIn);
                    }

                    lex();
                    reinterpretExpressionAsPattern(init);
                    left = init;
                    right = parseExpression();
                    init = null;
                } else if (matchContextualKeyword('of')) {
                    if (!isAssignmentTarget) {
                        tolerateError(Messages.InvalidLHSInForLoop);
                    }

                    lex();
                    reinterpretExpressionAsPattern(init);
                    left = init;
                    right = parseAssignmentExpression();
                    init = null;
                    forIn = false;
                } else {
                    if (match(',')) {
                        initSeq = [init];
                        while (match(',')) {
                            lex();
                            initSeq.push(isolateCoverGrammar(parseAssignmentExpression));
                        }
                        init = new WrappingNode(initStartToken).finishSequenceExpression(initSeq);
                    }
                    expect(';');
                }
            }
        }

        if (typeof left === 'undefined') {

            if (!match(';')) {
                test = parseExpression();
            }
            expect(';');

            if (!match(')')) {
                update = parseExpression();
            }
        }

        expect(')');

        oldInIteration = state.inIteration;
        state.inIteration = true;

        body = isolateCoverGrammar(parseStatement);

        state.inIteration = oldInIteration;

        return (typeof left === 'undefined') ?
                node.finishForStatement(init, test, update, body) :
                forIn ? node.finishForInStatement(left, right, body) :
                    node.finishForOfStatement(left, right, body);
    }

    // ECMA-262 13.8 The continue statement

    function parseContinueStatement(node) {
        var label = null, key;

        expectKeyword('continue');

        // Optimize the most common form: 'continue;'.
        if (source.charCodeAt(startIndex) === 0x3B) {
            lex();

            if (!state.inIteration) {
                throwError(Messages.IllegalContinue);
            }

            return node.finishContinueStatement(null);
        }

        if (hasLineTerminator) {
            if (!state.inIteration) {
                throwError(Messages.IllegalContinue);
            }

            return node.finishContinueStatement(null);
        }

        if (lookahead.type === Token.Identifier) {
            label = parseVariableIdentifier();

            key = '$' + label.name;
            if (!Object.prototype.hasOwnProperty.call(state.labelSet, key)) {
                throwError(Messages.UnknownLabel, label.name);
            }
        }

        consumeSemicolon();

        if (label === null && !state.inIteration) {
            throwError(Messages.IllegalContinue);
        }

        return node.finishContinueStatement(label);
    }

    // ECMA-262 13.9 The break statement

    function parseBreakStatement(node) {
        var label = null, key;

        expectKeyword('break');

        // Catch the very common case first: immediately a semicolon (U+003B).
        if (source.charCodeAt(lastIndex) === 0x3B) {
            lex();

            if (!(state.inIteration || state.inSwitch)) {
                throwError(Messages.IllegalBreak);
            }

            return node.finishBreakStatement(null);
        }

        if (hasLineTerminator) {
            if (!(state.inIteration || state.inSwitch)) {
                throwError(Messages.IllegalBreak);
            }
        } else if (lookahead.type === Token.Identifier) {
            label = parseVariableIdentifier();

            key = '$' + label.name;
            if (!Object.prototype.hasOwnProperty.call(state.labelSet, key)) {
                throwError(Messages.UnknownLabel, label.name);
            }
        }

        consumeSemicolon();

        if (label === null && !(state.inIteration || state.inSwitch)) {
            throwError(Messages.IllegalBreak);
        }

        return node.finishBreakStatement(label);
    }

    // ECMA-262 13.10 The return statement

    function parseReturnStatement(node) {
        var argument = null;

        expectKeyword('return');

        if (!state.inFunctionBody) {
            tolerateError(Messages.IllegalReturn);
        }

        // 'return' followed by a space and an identifier is very common.
        if (source.charCodeAt(lastIndex) === 0x20) {
            if (isIdentifierStart(source.charCodeAt(lastIndex + 1))) {
                argument = parseExpression();
                consumeSemicolon();
                return node.finishReturnStatement(argument);
            }
        }

        if (hasLineTerminator) {
            // HACK
            return node.finishReturnStatement(null);
        }

        if (!match(';')) {
            if (!match('}') && lookahead.type !== Token.EOF) {
                argument = parseExpression();
            }
        }

        consumeSemicolon();

        return node.finishReturnStatement(argument);
    }

    // ECMA-262 13.11 The with statement

    function parseWithStatement(node) {
        var object, body;

        if (strict) {
            tolerateError(Messages.StrictModeWith);
        }

        expectKeyword('with');

        expect('(');

        object = parseExpression();

        expect(')');

        body = parseStatement();

        return node.finishWithStatement(object, body);
    }

    // ECMA-262 13.12 The switch statement

    function parseSwitchCase() {
        var test, consequent = [], statement, node = new Node();

        if (matchKeyword('default')) {
            lex();
            test = null;
        } else {
            expectKeyword('case');
            test = parseExpression();
        }
        expect(':');

        while (startIndex < length) {
            if (match('}') || matchKeyword('default') || matchKeyword('case')) {
                break;
            }
            statement = parseStatementListItem();
            consequent.push(statement);
        }

        return node.finishSwitchCase(test, consequent);
    }

    function parseSwitchStatement(node) {
        var discriminant, cases, clause, oldInSwitch, defaultFound;

        expectKeyword('switch');

        expect('(');

        discriminant = parseExpression();

        expect(')');

        expect('{');

        cases = [];

        if (match('}')) {
            lex();
            return node.finishSwitchStatement(discriminant, cases);
        }

        oldInSwitch = state.inSwitch;
        state.inSwitch = true;
        defaultFound = false;

        while (startIndex < length) {
            if (match('}')) {
                break;
            }
            clause = parseSwitchCase();
            if (clause.test === null) {
                if (defaultFound) {
                    throwError(Messages.MultipleDefaultsInSwitch);
                }
                defaultFound = true;
            }
            cases.push(clause);
        }

        state.inSwitch = oldInSwitch;

        expect('}');

        return node.finishSwitchStatement(discriminant, cases);
    }

    // ECMA-262 13.14 The throw statement

    function parseThrowStatement(node) {
        var argument;

        expectKeyword('throw');

        if (hasLineTerminator) {
            throwError(Messages.NewlineAfterThrow);
        }

        argument = parseExpression();

        consumeSemicolon();

        return node.finishThrowStatement(argument);
    }

    // ECMA-262 13.15 The try statement

    function parseCatchClause() {
        var param, params = [], paramMap = {}, key, i, body, node = new Node();

        expectKeyword('catch');

        expect('(');
        if (match(')')) {
            throwUnexpectedToken(lookahead);
        }

        param = parsePattern(params);
        for (i = 0; i < params.length; i++) {
            key = '$' + params[i].value;
            if (Object.prototype.hasOwnProperty.call(paramMap, key)) {
                tolerateError(Messages.DuplicateBinding, params[i].value);
            }
            paramMap[key] = true;
        }

        // ECMA-262 12.14.1
        if (strict && isRestrictedWord(param.name)) {
            tolerateError(Messages.StrictCatchVariable);
        }

        expect(')');
        body = parseBlock();
        return node.finishCatchClause(param, body);
    }

    function parseTryStatement(node) {
        var block, handler = null, finalizer = null;

        expectKeyword('try');

        block = parseBlock();

        if (matchKeyword('catch')) {
            handler = parseCatchClause();
        }

        if (matchKeyword('finally')) {
            lex();
            finalizer = parseBlock();
        }

        if (!handler && !finalizer) {
            throwError(Messages.NoCatchOrFinally);
        }

        return node.finishTryStatement(block, handler, finalizer);
    }

    // ECMA-262 13.16 The debugger statement

    function parseDebuggerStatement(node) {
        expectKeyword('debugger');

        consumeSemicolon();

        return node.finishDebuggerStatement();
    }

    // 13 Statements

    function parseStatement() {
        var type = lookahead.type,
            expr,
            labeledBody,
            key,
            node;

        if (type === Token.EOF) {
            throwUnexpectedToken(lookahead);
        }

        if (type === Token.Punctuator && lookahead.value === '{') {
            return parseBlock();
        }
        isAssignmentTarget = isBindingElement = true;
        node = new Node();

        if (type === Token.Punctuator) {
            switch (lookahead.value) {
            case ';':
                return parseEmptyStatement(node);
            case '(':
                return parseExpressionStatement(node);
            default:
                break;
            }
        } else if (type === Token.Keyword) {
            switch (lookahead.value) {
            case 'break':
                return parseBreakStatement(node);
            case 'continue':
                return parseContinueStatement(node);
            case 'debugger':
                return parseDebuggerStatement(node);
            case 'do':
                return parseDoWhileStatement(node);
            case 'for':
                return parseForStatement(node);
            case 'function':
                return parseFunctionDeclaration(node);
            case 'if':
                return parseIfStatement(node);
            case 'return':
                return parseReturnStatement(node);
            case 'switch':
                return parseSwitchStatement(node);
            case 'throw':
                return parseThrowStatement(node);
            case 'try':
                return parseTryStatement(node);
            case 'var':
                return parseVariableStatement(node);
            case 'while':
                return parseWhileStatement(node);
            case 'with':
                return parseWithStatement(node);
            default:
                break;
            }
        }

        expr = parseExpression();

        // ECMA-262 12.12 Labelled Statements
        if ((expr.type === Syntax.Identifier) && match(':')) {
            lex();

            key = '$' + expr.name;
            if (Object.prototype.hasOwnProperty.call(state.labelSet, key)) {
                throwError(Messages.Redeclaration, 'Label', expr.name);
            }

            state.labelSet[key] = true;
            labeledBody = parseStatement();
            delete state.labelSet[key];
            return node.finishLabeledStatement(expr, labeledBody);
        }

        consumeSemicolon();

        return node.finishExpressionStatement(expr);
    }

    // ECMA-262 14.1 Function Definition

    function parseFunctionSourceElements() {
        var statement, body = [], token, directive, firstRestricted,
            oldLabelSet, oldInIteration, oldInSwitch, oldInFunctionBody, oldParenthesisCount,
            node = new Node();

        expect('{');

        while (startIndex < length) {
            if (lookahead.type !== Token.StringLiteral) {
                break;
            }
            token = lookahead;

            statement = parseStatementListItem();
            body.push(statement);
            if (statement.expression.type !== Syntax.Literal) {
                // this is not directive
                break;
            }
            directive = source.slice(token.start + 1, token.end - 1);
            if (directive === 'use strict') {
                strict = true;
                if (firstRestricted) {
                    tolerateUnexpectedToken(firstRestricted, Messages.StrictOctalLiteral);
                }
            } else {
                if (!firstRestricted && token.octal) {
                    firstRestricted = token;
                }
            }
        }

        oldLabelSet = state.labelSet;
        oldInIteration = state.inIteration;
        oldInSwitch = state.inSwitch;
        oldInFunctionBody = state.inFunctionBody;
        oldParenthesisCount = state.parenthesizedCount;

        state.labelSet = {};
        state.inIteration = false;
        state.inSwitch = false;
        state.inFunctionBody = true;
        state.parenthesizedCount = 0;

        while (startIndex < length) {
            if (match('}')) {
                break;
            }
            body.push(parseStatementListItem());
        }

        expect('}');

        state.labelSet = oldLabelSet;
        state.inIteration = oldInIteration;
        state.inSwitch = oldInSwitch;
        state.inFunctionBody = oldInFunctionBody;
        state.parenthesizedCount = oldParenthesisCount;

        return node.finishBlockStatement(body);
    }

    function validateParam(options, param, name) {
        var key = '$' + name;
        if (strict) {
            if (isRestrictedWord(name)) {
                options.stricted = param;
                options.message = Messages.StrictParamName;
            }
            if (Object.prototype.hasOwnProperty.call(options.paramSet, key)) {
                options.stricted = param;
                options.message = Messages.StrictParamDupe;
            }
        } else if (!options.firstRestricted) {
            if (isRestrictedWord(name)) {
                options.firstRestricted = param;
                options.message = Messages.StrictParamName;
            } else if (isStrictModeReservedWord(name)) {
                options.firstRestricted = param;
                options.message = Messages.StrictReservedWord;
            } else if (Object.prototype.hasOwnProperty.call(options.paramSet, key)) {
                options.stricted = param;
                options.message = Messages.StrictParamDupe;
            }
        }
        options.paramSet[key] = true;
    }

    function parseParam(options) {
        var token, param, params = [], i, def;

        token = lookahead;
        if (token.value === '...') {
            param = parseRestElement(params);
            validateParam(options, param.argument, param.argument.name);
            options.params.push(param);
            options.defaults.push(null);
            return false;
        }

        param = parsePatternWithDefault(params);
        for (i = 0; i < params.length; i++) {
            validateParam(options, params[i], params[i].value);
        }

        if (param.type === Syntax.AssignmentPattern) {
            def = param.right;
            param = param.left;
            ++options.defaultCount;
        }

        options.params.push(param);
        options.defaults.push(def);

        return !match(')');
    }

    function parseParams(firstRestricted) {
        var options;

        options = {
            params: [],
            defaultCount: 0,
            defaults: [],
            firstRestricted: firstRestricted
        };

        expect('(');

        if (!match(')')) {
            options.paramSet = {};
            while (startIndex < length) {
                if (!parseParam(options)) {
                    break;
                }
                expect(',');
            }
        }

        expect(')');

        if (options.defaultCount === 0) {
            options.defaults = [];
        }

        return {
            params: options.params,
            defaults: options.defaults,
            stricted: options.stricted,
            firstRestricted: options.firstRestricted,
            message: options.message
        };
    }

    function parseFunctionDeclaration(node, identifierIsOptional) {
        var id = null, params = [], defaults = [], body, token, stricted, tmp, firstRestricted, message, previousStrict,
            isGenerator, previousAllowYield;

        previousAllowYield = state.allowYield;

        expectKeyword('function');

        isGenerator = match('*');
        if (isGenerator) {
            lex();
        }

        if (!identifierIsOptional || !match('(')) {
            token = lookahead;
            id = parseVariableIdentifier();
            if (strict) {
                if (isRestrictedWord(token.value)) {
                    tolerateUnexpectedToken(token, Messages.StrictFunctionName);
                }
            } else {
                if (isRestrictedWord(token.value)) {
                    firstRestricted = token;
                    message = Messages.StrictFunctionName;
                } else if (isStrictModeReservedWord(token.value)) {
                    firstRestricted = token;
                    message = Messages.StrictReservedWord;
                }
            }
        }

        state.allowYield = !isGenerator;
        tmp = parseParams(firstRestricted);
        params = tmp.params;
        defaults = tmp.defaults;
        stricted = tmp.stricted;
        firstRestricted = tmp.firstRestricted;
        if (tmp.message) {
            message = tmp.message;
        }


        previousStrict = strict;
        body = parseFunctionSourceElements();
        if (strict && firstRestricted) {
            throwUnexpectedToken(firstRestricted, message);
        }
        if (strict && stricted) {
            tolerateUnexpectedToken(stricted, message);
        }

        strict = previousStrict;
        state.allowYield = previousAllowYield;

        return node.finishFunctionDeclaration(id, params, defaults, body, isGenerator);
    }

    function parseFunctionExpression() {
        var token, id = null, stricted, firstRestricted, message, tmp,
            params = [], defaults = [], body, previousStrict, node = new Node(),
            isGenerator, previousAllowYield;

        previousAllowYield = state.allowYield;

        expectKeyword('function');

        isGenerator = match('*');
        if (isGenerator) {
            lex();
        }

        state.allowYield = !isGenerator;
        if (!match('(')) {
            token = lookahead;
            id = (!strict && !isGenerator && matchKeyword('yield')) ? parseNonComputedProperty() : parseVariableIdentifier();
            if (strict) {
                if (isRestrictedWord(token.value)) {
                    tolerateUnexpectedToken(token, Messages.StrictFunctionName);
                }
            } else {
                if (isRestrictedWord(token.value)) {
                    firstRestricted = token;
                    message = Messages.StrictFunctionName;
                } else if (isStrictModeReservedWord(token.value)) {
                    firstRestricted = token;
                    message = Messages.StrictReservedWord;
                }
            }
        }

        tmp = parseParams(firstRestricted);
        params = tmp.params;
        defaults = tmp.defaults;
        stricted = tmp.stricted;
        firstRestricted = tmp.firstRestricted;
        if (tmp.message) {
            message = tmp.message;
        }

        previousStrict = strict;
        body = parseFunctionSourceElements();
        if (strict && firstRestricted) {
            throwUnexpectedToken(firstRestricted, message);
        }
        if (strict && stricted) {
            tolerateUnexpectedToken(stricted, message);
        }
        strict = previousStrict;
        state.allowYield = previousAllowYield;

        return node.finishFunctionExpression(id, params, defaults, body, isGenerator);
    }

    // ECMA-262 14.5 Class Definitions

    function parseClassBody() {
        var classBody, token, isStatic, hasConstructor = false, body, method, computed, key;

        classBody = new Node();

        expect('{');
        body = [];
        while (!match('}')) {
            if (match(';')) {
                lex();
            } else {
                method = new Node();
                token = lookahead;
                isStatic = false;
                computed = match('[');
                if (match('*')) {
                    lex();
                } else {
                    key = parseObjectPropertyKey();
                    if (key.name === 'static' && (lookaheadPropertyName() || match('*'))) {
                        token = lookahead;
                        isStatic = true;
                        computed = match('[');
                        if (match('*')) {
                            lex();
                        } else {
                            key = parseObjectPropertyKey();
                        }
                    }
                }
                method = tryParseMethodDefinition(token, key, computed, method);
                if (method) {
                    method['static'] = isStatic; // jscs:ignore requireDotNotation
                    if (method.kind === 'init') {
                        method.kind = 'method';
                    }
                    if (!isStatic) {
                        if (!method.computed && (method.key.name || method.key.value.toString()) === 'constructor') {
                            if (method.kind !== 'method' || !method.method || method.value.generator) {
                                throwUnexpectedToken(token, Messages.ConstructorSpecialMethod);
                            }
                            if (hasConstructor) {
                                throwUnexpectedToken(token, Messages.DuplicateConstructor);
                            } else {
                                hasConstructor = true;
                            }
                            method.kind = 'constructor';
                        }
                    } else {
                        if (!method.computed && (method.key.name || method.key.value.toString()) === 'prototype') {
                            throwUnexpectedToken(token, Messages.StaticPrototype);
                        }
                    }
                    method.type = Syntax.MethodDefinition;
                    delete method.method;
                    delete method.shorthand;
                    body.push(method);
                } else {
                    throwUnexpectedToken(lookahead);
                }
            }
        }
        lex();
        return classBody.finishClassBody(body);
    }

    function parseClassDeclaration(identifierIsOptional) {
        var id = null, superClass = null, classNode = new Node(), classBody, previousStrict = strict;
        strict = true;

        expectKeyword('class');

        if (!identifierIsOptional || lookahead.type === Token.Identifier) {
            id = parseVariableIdentifier();
        }

        if (matchKeyword('extends')) {
            lex();
            superClass = isolateCoverGrammar(parseLeftHandSideExpressionAllowCall);
        }
        classBody = parseClassBody();
        strict = previousStrict;

        return classNode.finishClassDeclaration(id, superClass, classBody);
    }

    function parseClassExpression() {
        var id = null, superClass = null, classNode = new Node(), classBody, previousStrict = strict;
        strict = true;

        expectKeyword('class');

        if (lookahead.type === Token.Identifier) {
            id = parseVariableIdentifier();
        }

        if (matchKeyword('extends')) {
            lex();
            superClass = isolateCoverGrammar(parseLeftHandSideExpressionAllowCall);
        }
        classBody = parseClassBody();
        strict = previousStrict;

        return classNode.finishClassExpression(id, superClass, classBody);
    }

    // ECMA-262 15.2 Modules

    function parseModuleSpecifier() {
        var node = new Node();

        if (lookahead.type !== Token.StringLiteral) {
            throwError(Messages.InvalidModuleSpecifier);
        }
        return node.finishLiteral(lex());
    }

    // ECMA-262 15.2.3 Exports

    function parseExportSpecifier() {
        var exported, local, node = new Node(), def;
        if (matchKeyword('default')) {
            // export {default} from 'something';
            def = new Node();
            lex();
            local = def.finishIdentifier('default');
        } else {
            local = parseVariableIdentifier();
        }
        if (matchContextualKeyword('as')) {
            lex();
            exported = parseNonComputedProperty();
        }
        return node.finishExportSpecifier(local, exported);
    }

    function parseExportNamedDeclaration(node) {
        var declaration = null,
            isExportFromIdentifier,
            src = null, specifiers = [];

        // non-default export
        if (lookahead.type === Token.Keyword) {
            // covers:
            // export var f = 1;
            switch (lookahead.value) {
                case 'let':
                case 'const':
                    declaration = parseLexicalDeclaration({inFor: false});
                    return node.finishExportNamedDeclaration(declaration, specifiers, null);
                case 'var':
                case 'class':
                case 'function':
                    declaration = parseStatementListItem();
                    return node.finishExportNamedDeclaration(declaration, specifiers, null);
            }
        }

        expect('{');
        while (!match('}')) {
            isExportFromIdentifier = isExportFromIdentifier || matchKeyword('default');
            specifiers.push(parseExportSpecifier());
            if (!match('}')) {
                expect(',');
                if (match('}')) {
                    break;
                }
            }
        }
        expect('}');

        if (matchContextualKeyword('from')) {
            // covering:
            // export {default} from 'foo';
            // export {foo} from 'foo';
            lex();
            src = parseModuleSpecifier();
            consumeSemicolon();
        } else if (isExportFromIdentifier) {
            // covering:
            // export {default}; // missing fromClause
            throwError(lookahead.value ?
                    Messages.UnexpectedToken : Messages.MissingFromClause, lookahead.value);
        } else {
            // cover
            // export {foo};
            consumeSemicolon();
        }
        return node.finishExportNamedDeclaration(declaration, specifiers, src);
    }

    function parseExportDefaultDeclaration(node) {
        var declaration = null,
            expression = null;

        // covers:
        // export default ...
        expectKeyword('default');

        if (matchKeyword('function')) {
            // covers:
            // export default function foo () {}
            // export default function () {}
            declaration = parseFunctionDeclaration(new Node(), true);
            return node.finishExportDefaultDeclaration(declaration);
        }
        if (matchKeyword('class')) {
            declaration = parseClassDeclaration(true);
            return node.finishExportDefaultDeclaration(declaration);
        }

        if (matchContextualKeyword('from')) {
            throwError(Messages.UnexpectedToken, lookahead.value);
        }

        // covers:
        // export default {};
        // export default [];
        // export default (1 + 2);
        if (match('{')) {
            expression = parseObjectInitializer();
        } else if (match('[')) {
            expression = parseArrayInitializer();
        } else {
            expression = parseAssignmentExpression();
        }
        consumeSemicolon();
        return node.finishExportDefaultDeclaration(expression);
    }

    function parseExportAllDeclaration(node) {
        var src;

        // covers:
        // export * from 'foo';
        expect('*');
        if (!matchContextualKeyword('from')) {
            throwError(lookahead.value ?
                    Messages.UnexpectedToken : Messages.MissingFromClause, lookahead.value);
        }
        lex();
        src = parseModuleSpecifier();
        consumeSemicolon();

        return node.finishExportAllDeclaration(src);
    }

    function parseExportDeclaration() {
        var node = new Node();
        if (state.inFunctionBody) {
            throwError(Messages.IllegalExportDeclaration);
        }

        expectKeyword('export');

        if (matchKeyword('default')) {
            return parseExportDefaultDeclaration(node);
        }
        if (match('*')) {
            return parseExportAllDeclaration(node);
        }
        return parseExportNamedDeclaration(node);
    }

    // ECMA-262 15.2.2 Imports

    function parseImportSpecifier() {
        // import {<foo as bar>} ...;
        var local, imported, node = new Node();

        imported = parseNonComputedProperty();
        if (matchContextualKeyword('as')) {
            lex();
            local = parseVariableIdentifier();
        }

        return node.finishImportSpecifier(local, imported);
    }

    function parseNamedImports() {
        var specifiers = [];
        // {foo, bar as bas}
        expect('{');
        while (!match('}')) {
            specifiers.push(parseImportSpecifier());
            if (!match('}')) {
                expect(',');
                if (match('}')) {
                    break;
                }
            }
        }
        expect('}');
        return specifiers;
    }

    function parseImportDefaultSpecifier() {
        // import <foo> ...;
        var local, node = new Node();

        local = parseNonComputedProperty();

        return node.finishImportDefaultSpecifier(local);
    }

    function parseImportNamespaceSpecifier() {
        // import <* as foo> ...;
        var local, node = new Node();

        expect('*');
        if (!matchContextualKeyword('as')) {
            throwError(Messages.NoAsAfterImportNamespace);
        }
        lex();
        local = parseNonComputedProperty();

        return node.finishImportNamespaceSpecifier(local);
    }

    function parseImportDeclaration() {
        var specifiers = [], src, node = new Node();

        if (state.inFunctionBody) {
            throwError(Messages.IllegalImportDeclaration);
        }

        expectKeyword('import');

        if (lookahead.type === Token.StringLiteral) {
            // import 'foo';
            src = parseModuleSpecifier();
        } else {

            if (match('{')) {
                // import {bar}
                specifiers = specifiers.concat(parseNamedImports());
            } else if (match('*')) {
                // import * as foo
                specifiers.push(parseImportNamespaceSpecifier());
            } else if (isIdentifierName(lookahead) && !matchKeyword('default')) {
                // import foo
                specifiers.push(parseImportDefaultSpecifier());
                if (match(',')) {
                    lex();
                    if (match('*')) {
                        // import foo, * as foo
                        specifiers.push(parseImportNamespaceSpecifier());
                    } else if (match('{')) {
                        // import foo, {bar}
                        specifiers = specifiers.concat(parseNamedImports());
                    } else {
                        throwUnexpectedToken(lookahead);
                    }
                }
            } else {
                throwUnexpectedToken(lex());
            }

            if (!matchContextualKeyword('from')) {
                throwError(lookahead.value ?
                        Messages.UnexpectedToken : Messages.MissingFromClause, lookahead.value);
            }
            lex();
            src = parseModuleSpecifier();
        }

        consumeSemicolon();
        return node.finishImportDeclaration(specifiers, src);
    }

    // ECMA-262 15.1 Scripts

    function parseScriptBody() {
        var statement, body = [], token, directive, firstRestricted;

        while (startIndex < length) {
            token = lookahead;
            if (token.type !== Token.StringLiteral) {
                break;
            }

            statement = parseStatementListItem();
            body.push(statement);
            if (statement.expression.type !== Syntax.Literal) {
                // this is not directive
                break;
            }
            directive = source.slice(token.start + 1, token.end - 1);
            if (directive === 'use strict') {
                strict = true;
                if (firstRestricted) {
                    tolerateUnexpectedToken(firstRestricted, Messages.StrictOctalLiteral);
                }
            } else {
                if (!firstRestricted && token.octal) {
                    firstRestricted = token;
                }
            }
        }

        while (startIndex < length) {
            statement = parseStatementListItem();
            /* istanbul ignore if */
            if (typeof statement === 'undefined') {
                break;
            }
            body.push(statement);
        }
        return body;
    }

    function parseProgram() {
        var body, node;

        peek();
        node = new Node();

        body = parseScriptBody();
        return node.finishProgram(body, state.sourceType);
    }

    function filterTokenLocation() {
        var i, entry, token, tokens = [];

        for (i = 0; i < extra.tokens.length; ++i) {
            entry = extra.tokens[i];
            token = {
                type: entry.type,
                value: entry.value
            };
            if (entry.regex) {
                token.regex = {
                    pattern: entry.regex.pattern,
                    flags: entry.regex.flags
                };
            }
            if (extra.range) {
                token.range = entry.range;
            }
            if (extra.loc) {
                token.loc = entry.loc;
            }
            tokens.push(token);
        }

        extra.tokens = tokens;
    }

    function tokenize(code, options, delegate) {
        var toString,
            tokens;

        toString = String;
        if (typeof code !== 'string' && !(code instanceof String)) {
            code = toString(code);
        }

        source = code;
        index = 0;
        lineNumber = (source.length > 0) ? 1 : 0;
        lineStart = 0;
        startIndex = index;
        startLineNumber = lineNumber;
        startLineStart = lineStart;
        length = source.length;
        lookahead = null;
        state = {
            allowIn: true,
            allowYield: true,
            labelSet: {},
            inFunctionBody: false,
            inIteration: false,
            inSwitch: false,
            lastCommentStart: -1,
            curlyStack: []
        };

        extra = {};

        // Options matching.
        options = options || {};

        // Of course we collect tokens here.
        options.tokens = true;
        extra.tokens = [];
        extra.tokenValues = [];
        extra.tokenize = true;
        extra.delegate = delegate;

        // The following two fields are necessary to compute the Regex tokens.
        extra.openParenToken = -1;
        extra.openCurlyToken = -1;

        extra.range = (typeof options.range === 'boolean') && options.range;
        extra.loc = (typeof options.loc === 'boolean') && options.loc;

        if (typeof options.comment === 'boolean' && options.comment) {
            extra.comments = [];
        }
        if (typeof options.tolerant === 'boolean' && options.tolerant) {
            extra.errors = [];
        }

        try {
            peek();
            if (lookahead.type === Token.EOF) {
                return extra.tokens;
            }

            lex();
            while (lookahead.type !== Token.EOF) {
                try {
                    lex();
                } catch (lexError) {
                    if (extra.errors) {
                        recordError(lexError);
                        // We have to break on the first error
                        // to avoid infinite loops.
                        break;
                    } else {
                        throw lexError;
                    }
                }
            }

            tokens = extra.tokens;
            if (typeof extra.errors !== 'undefined') {
                tokens.errors = extra.errors;
            }
        } catch (e) {
            throw e;
        } finally {
            extra = {};
        }
        return tokens;
    }

    function parse(code, options) {
        var program, toString;

        toString = String;
        if (typeof code !== 'string' && !(code instanceof String)) {
            code = toString(code);
        }

        source = code;
        index = 0;
        lineNumber = (source.length > 0) ? 1 : 0;
        lineStart = 0;
        startIndex = index;
        startLineNumber = lineNumber;
        startLineStart = lineStart;
        length = source.length;
        lookahead = null;
        state = {
            allowIn: true,
            allowYield: true,
            labelSet: {},
            inFunctionBody: false,
            inIteration: false,
            inSwitch: false,
            lastCommentStart: -1,
            curlyStack: [],
            sourceType: 'script'
        };
        strict = false;

        extra = {};
        if (typeof options !== 'undefined') {
            extra.range = (typeof options.range === 'boolean') && options.range;
            extra.loc = (typeof options.loc === 'boolean') && options.loc;
            extra.attachComment = (typeof options.attachComment === 'boolean') && options.attachComment;

            if (extra.loc && options.source !== null && options.source !== undefined) {
                extra.source = toString(options.source);
            }

            if (typeof options.tokens === 'boolean' && options.tokens) {
                extra.tokens = [];
            }
            if (typeof options.comment === 'boolean' && options.comment) {
                extra.comments = [];
            }
            if (typeof options.tolerant === 'boolean' && options.tolerant) {
                extra.errors = [];
            }
            if (extra.attachComment) {
                extra.range = true;
                extra.comments = [];
                extra.bottomRightStack = [];
                extra.trailingComments = [];
                extra.leadingComments = [];
            }
            if (options.sourceType === 'module') {
                // very restrictive condition for now
                state.sourceType = options.sourceType;
                strict = true;
            }
        }

        try {
            program = parseProgram();
            if (typeof extra.comments !== 'undefined') {
                program.comments = extra.comments;
            }
            if (typeof extra.tokens !== 'undefined') {
                filterTokenLocation();
                program.tokens = extra.tokens;
            }
            if (typeof extra.errors !== 'undefined') {
                program.errors = extra.errors;
            }
        } catch (e) {
            throw e;
        } finally {
            extra = {};
        }

        return program;
    }

    // Sync with *.json manifests.
    exports.version = '2.7.1';

    exports.tokenize = tokenize;

    exports.parse = parse;

    // Deep copy.
    /* istanbul ignore next */
    exports.Syntax = (function () {
        var name, types = {};

        if (typeof Object.create === 'function') {
            types = Object.create(null);
        }

        for (name in Syntax) {
            if (Syntax.hasOwnProperty(name)) {
                types[name] = Syntax[name];
            }
        }

        if (typeof Object.freeze === 'function') {
            Object.freeze(types);
        }

        return types;
    }());

}));
/* vim: set sw=4 ts=4 et tw=80 : */

},{}],52:[function(require,module,exports){
/*!
 * node-inherit
 * Copyright(c) 2011 Dmitry Filatov <dfilatov@yandex-team.ru>
 * MIT Licensed
 */

module.exports = require('./lib/inherit');

},{"./lib/inherit":53}],53:[function(require,module,exports){
/**
 * @module inherit
 * @version 2.2.2
 * @author Filatov Dmitry <dfilatov@yandex-team.ru>
 * @description This module provides some syntax sugar for "class" declarations, constructors, mixins, "super" calls and static members.
 */

(function(global) {

var hasIntrospection = (function(){'_';}).toString().indexOf('_') > -1,
    emptyBase = function() {},
    hasOwnProperty = Object.prototype.hasOwnProperty,
    objCreate = Object.create || function(ptp) {
        var inheritance = function() {};
        inheritance.prototype = ptp;
        return new inheritance();
    },
    objKeys = Object.keys || function(obj) {
        var res = [];
        for(var i in obj) {
            hasOwnProperty.call(obj, i) && res.push(i);
        }
        return res;
    },
    extend = function(o1, o2) {
        for(var i in o2) {
            hasOwnProperty.call(o2, i) && (o1[i] = o2[i]);
        }

        return o1;
    },
    toStr = Object.prototype.toString,
    isArray = Array.isArray || function(obj) {
        return toStr.call(obj) === '[object Array]';
    },
    isFunction = function(obj) {
        return toStr.call(obj) === '[object Function]';
    },
    noOp = function() {},
    needCheckProps = true,
    testPropObj = { toString : '' };

for(var i in testPropObj) { // fucking ie hasn't toString, valueOf in for
    testPropObj.hasOwnProperty(i) && (needCheckProps = false);
}

var specProps = needCheckProps? ['toString', 'valueOf'] : null;

function getPropList(obj) {
    var res = objKeys(obj);
    if(needCheckProps) {
        var specProp, i = 0;
        while(specProp = specProps[i++]) {
            obj.hasOwnProperty(specProp) && res.push(specProp);
        }
    }

    return res;
}

function override(base, res, add) {
    var addList = getPropList(add),
        j = 0, len = addList.length,
        name, prop;
    while(j < len) {
        if((name = addList[j++]) === '__self') {
            continue;
        }
        prop = add[name];
        if(isFunction(prop) &&
                (!hasIntrospection || prop.toString().indexOf('.__base') > -1)) {
            res[name] = (function(name, prop) {
                var baseMethod = base[name]?
                        base[name] :
                        name === '__constructor'? // case of inheritance from plane function
                            res.__self.__parent :
                            noOp;
                return function() {
                    var baseSaved = this.__base;
                    this.__base = baseMethod;
                    var res = prop.apply(this, arguments);
                    this.__base = baseSaved;
                    return res;
                };
            })(name, prop);
        } else {
            res[name] = prop;
        }
    }
}

function applyMixins(mixins, res) {
    var i = 1, mixin;
    while(mixin = mixins[i++]) {
        res?
            isFunction(mixin)?
                inherit.self(res, mixin.prototype, mixin) :
                inherit.self(res, mixin) :
            res = isFunction(mixin)?
                inherit(mixins[0], mixin.prototype, mixin) :
                inherit(mixins[0], mixin);
    }
    return res || mixins[0];
}

/**
* Creates class
* @exports
* @param {Function|Array} [baseClass|baseClassAndMixins] class (or class and mixins) to inherit from
* @param {Object} prototypeFields
* @param {Object} [staticFields]
* @returns {Function} class
*/
function inherit() {
    var args = arguments,
        withMixins = isArray(args[0]),
        hasBase = withMixins || isFunction(args[0]),
        base = hasBase? withMixins? applyMixins(args[0]) : args[0] : emptyBase,
        props = args[hasBase? 1 : 0] || {},
        staticProps = args[hasBase? 2 : 1],
        res = props.__constructor || (hasBase && base.prototype.__constructor)?
            function() {
                return this.__constructor.apply(this, arguments);
            } :
            hasBase?
                function() {
                    return base.apply(this, arguments);
                } :
                function() {};

    if(!hasBase) {
        res.prototype = props;
        res.prototype.__self = res.prototype.constructor = res;
        return extend(res, staticProps);
    }

    extend(res, base);

    res.__parent = base;

    var basePtp = base.prototype,
        resPtp = res.prototype = objCreate(basePtp);

    resPtp.__self = resPtp.constructor = res;

    props && override(basePtp, resPtp, props);
    staticProps && override(base, res, staticProps);

    return res;
}

inherit.self = function() {
    var args = arguments,
        withMixins = isArray(args[0]),
        base = withMixins? applyMixins(args[0], args[0][0]) : args[0],
        props = args[1],
        staticProps = args[2],
        basePtp = base.prototype;

    props && override(basePtp, basePtp, props);
    staticProps && override(base, base, staticProps);

    return base;
};

var defineAsGlobal = true;
if(typeof exports === 'object') {
    module.exports = inherit;
    defineAsGlobal = false;
}

if(typeof modules === 'object') {
    modules.define('inherit', function(provide) {
        provide(inherit);
    });
    defineAsGlobal = false;
}

if(typeof define === 'function') {
    define(function(require, exports, module) {
        module.exports = inherit;
    });
    defineAsGlobal = false;
}

defineAsGlobal && (global.inherit = inherit);

})(this);

},{}],54:[function(require,module,exports){
/**!
 * Ono v2.0.1
 *
 * @link https://github.com/BigstickCarpet/ono
 * @license MIT
 */
'use strict';

var util  = require('util'),
    slice = Array.prototype.slice,
    vendorSpecificErrorProperties = [
      'name', 'message', 'description', 'number', 'fileName', 'lineNumber', 'columnNumber',
      'sourceURL', 'line', 'column', 'stack'
    ];

module.exports = create(Error);
module.exports.error = create(Error);
module.exports.eval = create(EvalError);
module.exports.range = create(RangeError);
module.exports.reference = create(ReferenceError);
module.exports.syntax = create(SyntaxError);
module.exports.type = create(TypeError);
module.exports.uri = create(URIError);
module.exports.formatter = util.format;

/**
 * Creates a new {@link ono} function that creates the given Error class.
 *
 * @param {Class} Klass - The Error subclass to create
 * @returns {ono}
 */
function create(Klass) {
  /**
   * @param {Error}   [err]     - The original error, if any
   * @param {object}  [props]   - An object whose properties will be added to the error object
   * @param {string}  [message] - The error message. May contain {@link util#format} placeholders
   * @param {...*}    [params]  - Parameters that map to the `message` placeholders
   * @returns {Error}
   */
  return function ono(err, props, message, params) {
    var formattedMessage, stack;
    var formatter = module.exports.formatter;

    if (typeof(err) === 'string') {
      formattedMessage = formatter.apply(null, arguments);
      err = props = undefined;
    }
    else if (typeof(props) === 'string') {
      formattedMessage = formatter.apply(null, slice.call(arguments, 1));
    }
    else {
      formattedMessage = formatter.apply(null, slice.call(arguments, 2));
    }

    if (!(err instanceof Error)) {
      props = err;
      err = undefined;
    }

    if (err) {
      // The inner-error's message will be added to the new message
      formattedMessage += (formattedMessage ? ' \n' : '') + err.message;
    }

    // Create the new error
    // NOTE: DON'T move this to a separate function! We don't want to pollute the stack trace
    var newError = new Klass(formattedMessage);

    // Extend the new error with the additional properties
    extendError(newError, err);   // Copy properties of the original error
    extendToJSON(newError);       // Replace the original toJSON method
    extend(newError, props);      // Copy custom properties, possibly including a custom toJSON method

    return newError;
  };
}

/**
 * Extends the targetError with the properties of the source error.
 *
 * @param {Error}   targetError - The error object to extend
 * @param {?Error}  sourceError - The source error object, if any
 */
function extendError(targetError, sourceError) {
  if (sourceError) {
    var stack = sourceError.stack;
    if (stack) {
      targetError.stack += ' \n\n' + sourceError.stack;
    }

    extend(targetError, sourceError, true);
  }
}

/**
 * JavaScript engines differ in how errors are serialized to JSON - especially when it comes
 * to custom error properties and stack traces.  So we add our own toJSON method that ALWAYS
 * outputs every property of the error.
 */
function extendToJSON(error) {
  error.toJSON = errorToJSON;

  // Also add an inspect() method, for compatibility with Node.js' `util.inspect()` method
  error.inspect = errorToJSON;
}

/**
 * Extends the target object with the properties of the source object.
 *
 * @param {object}  target - The object to extend
 * @param {?source} source - The object whose properties are copied
 * @param {boolean} omitVendorSpecificProperties - Skip vendor-specific Error properties
 */
function extend(target, source, omitVendorSpecificProperties) {
  if (source && typeof(source) === 'object') {
    var keys = Object.keys(source);
    for (var i = 0; i < keys.length; i++) {
      var key = keys[i];

      // Don't bother trying to copy read-only vendor-specific Error properties
      if (omitVendorSpecificProperties && vendorSpecificErrorProperties.indexOf(key) >= 0) {
        continue;
      }

      try {
        target[key] = source[key];
      }
      catch (e) {
        // This property is read-only, so it can't be copied
      }
    }
  }
}

/**
 * Custom JSON serializer for Error objects.
 * Returns all built-in error properties, as well as extended properties.
 *
 * @returns {object}
 */
function errorToJSON() {
  // jshint -W040
  var json = {};

  // Get all the properties of this error
  var keys = Object.keys(this);

  // Also include vendor-specific properties from the prototype
  keys = keys.concat(vendorSpecificErrorProperties);

  for (var i = 0; i < keys.length; i++) {
    var key = keys[i];
    var value = this[key];
    if (value !== undefined) {
      json[key] = value;
    }
  }

  return json;
}

},{"util":94}],55:[function(require,module,exports){

},{}],56:[function(require,module,exports){
arguments[4][55][0].apply(exports,arguments)
},{"dup":55}],57:[function(require,module,exports){
(function (global){
/*!
 * The buffer module from node.js, for the browser.
 *
 * @author   Feross Aboukhadijeh <feross@feross.org> <http://feross.org>
 * @license  MIT
 */
/* eslint-disable no-proto */

'use strict'

var base64 = require('base64-js')
var ieee754 = require('ieee754')
var isArray = require('isarray')

exports.Buffer = Buffer
exports.SlowBuffer = SlowBuffer
exports.INSPECT_MAX_BYTES = 50
Buffer.poolSize = 8192 // not used by this implementation

var rootParent = {}

/**
 * If `Buffer.TYPED_ARRAY_SUPPORT`:
 *   === true    Use Uint8Array implementation (fastest)
 *   === false   Use Object implementation (most compatible, even IE6)
 *
 * Browsers that support typed arrays are IE 10+, Firefox 4+, Chrome 7+, Safari 5.1+,
 * Opera 11.6+, iOS 4.2+.
 *
 * Due to various browser bugs, sometimes the Object implementation will be used even
 * when the browser supports typed arrays.
 *
 * Note:
 *
 *   - Firefox 4-29 lacks support for adding new properties to `Uint8Array` instances,
 *     See: https://bugzilla.mozilla.org/show_bug.cgi?id=695438.
 *
 *   - Safari 5-7 lacks support for changing the `Object.prototype.constructor` property
 *     on objects.
 *
 *   - Chrome 9-10 is missing the `TypedArray.prototype.subarray` function.
 *
 *   - IE10 has a broken `TypedArray.prototype.subarray` function which returns arrays of
 *     incorrect length in some situations.

 * We detect these buggy browsers and set `Buffer.TYPED_ARRAY_SUPPORT` to `false` so they
 * get the Object implementation, which is slower but behaves correctly.
 */
Buffer.TYPED_ARRAY_SUPPORT = global.TYPED_ARRAY_SUPPORT !== undefined
  ? global.TYPED_ARRAY_SUPPORT
  : typedArraySupport()

function typedArraySupport () {
  function Bar () {}
  try {
    var arr = new Uint8Array(1)
    arr.foo = function () { return 42 }
    arr.constructor = Bar
    return arr.foo() === 42 && // typed array instances can be augmented
        arr.constructor === Bar && // constructor can be set
        typeof arr.subarray === 'function' && // chrome 9-10 lack `subarray`
        arr.subarray(1, 1).byteLength === 0 // ie10 has broken `subarray`
  } catch (e) {
    return false
  }
}

function kMaxLength () {
  return Buffer.TYPED_ARRAY_SUPPORT
    ? 0x7fffffff
    : 0x3fffffff
}

/**
 * Class: Buffer
 * =============
 *
 * The Buffer constructor returns instances of `Uint8Array` that are augmented
 * with function properties for all the node `Buffer` API functions. We use
 * `Uint8Array` so that square bracket notation works as expected -- it returns
 * a single octet.
 *
 * By augmenting the instances, we can avoid modifying the `Uint8Array`
 * prototype.
 */
function Buffer (arg) {
  if (!(this instanceof Buffer)) {
    // Avoid going through an ArgumentsAdaptorTrampoline in the common case.
    if (arguments.length > 1) return new Buffer(arg, arguments[1])
    return new Buffer(arg)
  }

  if (!Buffer.TYPED_ARRAY_SUPPORT) {
    this.length = 0
    this.parent = undefined
  }

  // Common case.
  if (typeof arg === 'number') {
    return fromNumber(this, arg)
  }

  // Slightly less common case.
  if (typeof arg === 'string') {
    return fromString(this, arg, arguments.length > 1 ? arguments[1] : 'utf8')
  }

  // Unusual.
  return fromObject(this, arg)
}

function fromNumber (that, length) {
  that = allocate(that, length < 0 ? 0 : checked(length) | 0)
  if (!Buffer.TYPED_ARRAY_SUPPORT) {
    for (var i = 0; i < length; i++) {
      that[i] = 0
    }
  }
  return that
}

function fromString (that, string, encoding) {
  if (typeof encoding !== 'string' || encoding === '') encoding = 'utf8'

  // Assumption: byteLength() return value is always < kMaxLength.
  var length = byteLength(string, encoding) | 0
  that = allocate(that, length)

  that.write(string, encoding)
  return that
}

function fromObject (that, object) {
  if (Buffer.isBuffer(object)) return fromBuffer(that, object)

  if (isArray(object)) return fromArray(that, object)

  if (object == null) {
    throw new TypeError('must start with number, buffer, array or string')
  }

  if (typeof ArrayBuffer !== 'undefined') {
    if (object.buffer instanceof ArrayBuffer) {
      return fromTypedArray(that, object)
    }
    if (object instanceof ArrayBuffer) {
      return fromArrayBuffer(that, object)
    }
  }

  if (object.length) return fromArrayLike(that, object)

  return fromJsonObject(that, object)
}

function fromBuffer (that, buffer) {
  var length = checked(buffer.length) | 0
  that = allocate(that, length)
  buffer.copy(that, 0, 0, length)
  return that
}

function fromArray (that, array) {
  var length = checked(array.length) | 0
  that = allocate(that, length)
  for (var i = 0; i < length; i += 1) {
    that[i] = array[i] & 255
  }
  return that
}

// Duplicate of fromArray() to keep fromArray() monomorphic.
function fromTypedArray (that, array) {
  var length = checked(array.length) | 0
  that = allocate(that, length)
  // Truncating the elements is probably not what people expect from typed
  // arrays with BYTES_PER_ELEMENT > 1 but it's compatible with the behavior
  // of the old Buffer constructor.
  for (var i = 0; i < length; i += 1) {
    that[i] = array[i] & 255
  }
  return that
}

function fromArrayBuffer (that, array) {
  if (Buffer.TYPED_ARRAY_SUPPORT) {
    // Return an augmented `Uint8Array` instance, for best performance
    array.byteLength
    that = Buffer._augment(new Uint8Array(array))
  } else {
    // Fallback: Return an object instance of the Buffer class
    that = fromTypedArray(that, new Uint8Array(array))
  }
  return that
}

function fromArrayLike (that, array) {
  var length = checked(array.length) | 0
  that = allocate(that, length)
  for (var i = 0; i < length; i += 1) {
    that[i] = array[i] & 255
  }
  return that
}

// Deserialize { type: 'Buffer', data: [1,2,3,...] } into a Buffer object.
// Returns a zero-length buffer for inputs that don't conform to the spec.
function fromJsonObject (that, object) {
  var array
  var length = 0

  if (object.type === 'Buffer' && isArray(object.data)) {
    array = object.data
    length = checked(array.length) | 0
  }
  that = allocate(that, length)

  for (var i = 0; i < length; i += 1) {
    that[i] = array[i] & 255
  }
  return that
}

if (Buffer.TYPED_ARRAY_SUPPORT) {
  Buffer.prototype.__proto__ = Uint8Array.prototype
  Buffer.__proto__ = Uint8Array
} else {
  // pre-set for values that may exist in the future
  Buffer.prototype.length = undefined
  Buffer.prototype.parent = undefined
}

function allocate (that, length) {
  if (Buffer.TYPED_ARRAY_SUPPORT) {
    // Return an augmented `Uint8Array` instance, for best performance
    that = Buffer._augment(new Uint8Array(length))
    that.__proto__ = Buffer.prototype
  } else {
    // Fallback: Return an object instance of the Buffer class
    that.length = length
    that._isBuffer = true
  }

  var fromPool = length !== 0 && length <= Buffer.poolSize >>> 1
  if (fromPool) that.parent = rootParent

  return that
}

function checked (length) {
  // Note: cannot use `length < kMaxLength` here because that fails when
  // length is NaN (which is otherwise coerced to zero.)
  if (length >= kMaxLength()) {
    throw new RangeError('Attempt to allocate Buffer larger than maximum ' +
                         'size: 0x' + kMaxLength().toString(16) + ' bytes')
  }
  return length | 0
}

function SlowBuffer (subject, encoding) {
  if (!(this instanceof SlowBuffer)) return new SlowBuffer(subject, encoding)

  var buf = new Buffer(subject, encoding)
  delete buf.parent
  return buf
}

Buffer.isBuffer = function isBuffer (b) {
  return !!(b != null && b._isBuffer)
}

Buffer.compare = function compare (a, b) {
  if (!Buffer.isBuffer(a) || !Buffer.isBuffer(b)) {
    throw new TypeError('Arguments must be Buffers')
  }

  if (a === b) return 0

  var x = a.length
  var y = b.length

  var i = 0
  var len = Math.min(x, y)
  while (i < len) {
    if (a[i] !== b[i]) break

    ++i
  }

  if (i !== len) {
    x = a[i]
    y = b[i]
  }

  if (x < y) return -1
  if (y < x) return 1
  return 0
}

Buffer.isEncoding = function isEncoding (encoding) {
  switch (String(encoding).toLowerCase()) {
    case 'hex':
    case 'utf8':
    case 'utf-8':
    case 'ascii':
    case 'binary':
    case 'base64':
    case 'raw':
    case 'ucs2':
    case 'ucs-2':
    case 'utf16le':
    case 'utf-16le':
      return true
    default:
      return false
  }
}

Buffer.concat = function concat (list, length) {
  if (!isArray(list)) throw new TypeError('list argument must be an Array of Buffers.')

  if (list.length === 0) {
    return new Buffer(0)
  }

  var i
  if (length === undefined) {
    length = 0
    for (i = 0; i < list.length; i++) {
      length += list[i].length
    }
  }

  var buf = new Buffer(length)
  var pos = 0
  for (i = 0; i < list.length; i++) {
    var item = list[i]
    item.copy(buf, pos)
    pos += item.length
  }
  return buf
}

function byteLength (string, encoding) {
  if (typeof string !== 'string') string = '' + string

  var len = string.length
  if (len === 0) return 0

  // Use a for loop to avoid recursion
  var loweredCase = false
  for (;;) {
    switch (encoding) {
      case 'ascii':
      case 'binary':
      // Deprecated
      case 'raw':
      case 'raws':
        return len
      case 'utf8':
      case 'utf-8':
        return utf8ToBytes(string).length
      case 'ucs2':
      case 'ucs-2':
      case 'utf16le':
      case 'utf-16le':
        return len * 2
      case 'hex':
        return len >>> 1
      case 'base64':
        return base64ToBytes(string).length
      default:
        if (loweredCase) return utf8ToBytes(string).length // assume utf8
        encoding = ('' + encoding).toLowerCase()
        loweredCase = true
    }
  }
}
Buffer.byteLength = byteLength

function slowToString (encoding, start, end) {
  var loweredCase = false

  start = start | 0
  end = end === undefined || end === Infinity ? this.length : end | 0

  if (!encoding) encoding = 'utf8'
  if (start < 0) start = 0
  if (end > this.length) end = this.length
  if (end <= start) return ''

  while (true) {
    switch (encoding) {
      case 'hex':
        return hexSlice(this, start, end)

      case 'utf8':
      case 'utf-8':
        return utf8Slice(this, start, end)

      case 'ascii':
        return asciiSlice(this, start, end)

      case 'binary':
        return binarySlice(this, start, end)

      case 'base64':
        return base64Slice(this, start, end)

      case 'ucs2':
      case 'ucs-2':
      case 'utf16le':
      case 'utf-16le':
        return utf16leSlice(this, start, end)

      default:
        if (loweredCase) throw new TypeError('Unknown encoding: ' + encoding)
        encoding = (encoding + '').toLowerCase()
        loweredCase = true
    }
  }
}

Buffer.prototype.toString = function toString () {
  var length = this.length | 0
  if (length === 0) return ''
  if (arguments.length === 0) return utf8Slice(this, 0, length)
  return slowToString.apply(this, arguments)
}

Buffer.prototype.equals = function equals (b) {
  if (!Buffer.isBuffer(b)) throw new TypeError('Argument must be a Buffer')
  if (this === b) return true
  return Buffer.compare(this, b) === 0
}

Buffer.prototype.inspect = function inspect () {
  var str = ''
  var max = exports.INSPECT_MAX_BYTES
  if (this.length > 0) {
    str = this.toString('hex', 0, max).match(/.{2}/g).join(' ')
    if (this.length > max) str += ' ... '
  }
  return '<Buffer ' + str + '>'
}

Buffer.prototype.compare = function compare (b) {
  if (!Buffer.isBuffer(b)) throw new TypeError('Argument must be a Buffer')
  if (this === b) return 0
  return Buffer.compare(this, b)
}

Buffer.prototype.indexOf = function indexOf (val, byteOffset) {
  if (byteOffset > 0x7fffffff) byteOffset = 0x7fffffff
  else if (byteOffset < -0x80000000) byteOffset = -0x80000000
  byteOffset >>= 0

  if (this.length === 0) return -1
  if (byteOffset >= this.length) return -1

  // Negative offsets start from the end of the buffer
  if (byteOffset < 0) byteOffset = Math.max(this.length + byteOffset, 0)

  if (typeof val === 'string') {
    if (val.length === 0) return -1 // special case: looking for empty string always fails
    return String.prototype.indexOf.call(this, val, byteOffset)
  }
  if (Buffer.isBuffer(val)) {
    return arrayIndexOf(this, val, byteOffset)
  }
  if (typeof val === 'number') {
    if (Buffer.TYPED_ARRAY_SUPPORT && Uint8Array.prototype.indexOf === 'function') {
      return Uint8Array.prototype.indexOf.call(this, val, byteOffset)
    }
    return arrayIndexOf(this, [ val ], byteOffset)
  }

  function arrayIndexOf (arr, val, byteOffset) {
    var foundIndex = -1
    for (var i = 0; byteOffset + i < arr.length; i++) {
      if (arr[byteOffset + i] === val[foundIndex === -1 ? 0 : i - foundIndex]) {
        if (foundIndex === -1) foundIndex = i
        if (i - foundIndex + 1 === val.length) return byteOffset + foundIndex
      } else {
        foundIndex = -1
      }
    }
    return -1
  }

  throw new TypeError('val must be string, number or Buffer')
}

// `get` is deprecated
Buffer.prototype.get = function get (offset) {
  console.log('.get() is deprecated. Access using array indexes instead.')
  return this.readUInt8(offset)
}

// `set` is deprecated
Buffer.prototype.set = function set (v, offset) {
  console.log('.set() is deprecated. Access using array indexes instead.')
  return this.writeUInt8(v, offset)
}

function hexWrite (buf, string, offset, length) {
  offset = Number(offset) || 0
  var remaining = buf.length - offset
  if (!length) {
    length = remaining
  } else {
    length = Number(length)
    if (length > remaining) {
      length = remaining
    }
  }

  // must be an even number of digits
  var strLen = string.length
  if (strLen % 2 !== 0) throw new Error('Invalid hex string')

  if (length > strLen / 2) {
    length = strLen / 2
  }
  for (var i = 0; i < length; i++) {
    var parsed = parseInt(string.substr(i * 2, 2), 16)
    if (isNaN(parsed)) throw new Error('Invalid hex string')
    buf[offset + i] = parsed
  }
  return i
}

function utf8Write (buf, string, offset, length) {
  return blitBuffer(utf8ToBytes(string, buf.length - offset), buf, offset, length)
}

function asciiWrite (buf, string, offset, length) {
  return blitBuffer(asciiToBytes(string), buf, offset, length)
}

function binaryWrite (buf, string, offset, length) {
  return asciiWrite(buf, string, offset, length)
}

function base64Write (buf, string, offset, length) {
  return blitBuffer(base64ToBytes(string), buf, offset, length)
}

function ucs2Write (buf, string, offset, length) {
  return blitBuffer(utf16leToBytes(string, buf.length - offset), buf, offset, length)
}

Buffer.prototype.write = function write (string, offset, length, encoding) {
  // Buffer#write(string)
  if (offset === undefined) {
    encoding = 'utf8'
    length = this.length
    offset = 0
  // Buffer#write(string, encoding)
  } else if (length === undefined && typeof offset === 'string') {
    encoding = offset
    length = this.length
    offset = 0
  // Buffer#write(string, offset[, length][, encoding])
  } else if (isFinite(offset)) {
    offset = offset | 0
    if (isFinite(length)) {
      length = length | 0
      if (encoding === undefined) encoding = 'utf8'
    } else {
      encoding = length
      length = undefined
    }
  // legacy write(string, encoding, offset, length) - remove in v0.13
  } else {
    var swap = encoding
    encoding = offset
    offset = length | 0
    length = swap
  }

  var remaining = this.length - offset
  if (length === undefined || length > remaining) length = remaining

  if ((string.length > 0 && (length < 0 || offset < 0)) || offset > this.length) {
    throw new RangeError('attempt to write outside buffer bounds')
  }

  if (!encoding) encoding = 'utf8'

  var loweredCase = false
  for (;;) {
    switch (encoding) {
      case 'hex':
        return hexWrite(this, string, offset, length)

      case 'utf8':
      case 'utf-8':
        return utf8Write(this, string, offset, length)

      case 'ascii':
        return asciiWrite(this, string, offset, length)

      case 'binary':
        return binaryWrite(this, string, offset, length)

      case 'base64':
        // Warning: maxLength not taken into account in base64Write
        return base64Write(this, string, offset, length)

      case 'ucs2':
      case 'ucs-2':
      case 'utf16le':
      case 'utf-16le':
        return ucs2Write(this, string, offset, length)

      default:
        if (loweredCase) throw new TypeError('Unknown encoding: ' + encoding)
        encoding = ('' + encoding).toLowerCase()
        loweredCase = true
    }
  }
}

Buffer.prototype.toJSON = function toJSON () {
  return {
    type: 'Buffer',
    data: Array.prototype.slice.call(this._arr || this, 0)
  }
}

function base64Slice (buf, start, end) {
  if (start === 0 && end === buf.length) {
    return base64.fromByteArray(buf)
  } else {
    return base64.fromByteArray(buf.slice(start, end))
  }
}

function utf8Slice (buf, start, end) {
  end = Math.min(buf.length, end)
  var res = []

  var i = start
  while (i < end) {
    var firstByte = buf[i]
    var codePoint = null
    var bytesPerSequence = (firstByte > 0xEF) ? 4
      : (firstByte > 0xDF) ? 3
      : (firstByte > 0xBF) ? 2
      : 1

    if (i + bytesPerSequence <= end) {
      var secondByte, thirdByte, fourthByte, tempCodePoint

      switch (bytesPerSequence) {
        case 1:
          if (firstByte < 0x80) {
            codePoint = firstByte
          }
          break
        case 2:
          secondByte = buf[i + 1]
          if ((secondByte & 0xC0) === 0x80) {
            tempCodePoint = (firstByte & 0x1F) << 0x6 | (secondByte & 0x3F)
            if (tempCodePoint > 0x7F) {
              codePoint = tempCodePoint
            }
          }
          break
        case 3:
          secondByte = buf[i + 1]
          thirdByte = buf[i + 2]
          if ((secondByte & 0xC0) === 0x80 && (thirdByte & 0xC0) === 0x80) {
            tempCodePoint = (firstByte & 0xF) << 0xC | (secondByte & 0x3F) << 0x6 | (thirdByte & 0x3F)
            if (tempCodePoint > 0x7FF && (tempCodePoint < 0xD800 || tempCodePoint > 0xDFFF)) {
              codePoint = tempCodePoint
            }
          }
          break
        case 4:
          secondByte = buf[i + 1]
          thirdByte = buf[i + 2]
          fourthByte = buf[i + 3]
          if ((secondByte & 0xC0) === 0x80 && (thirdByte & 0xC0) === 0x80 && (fourthByte & 0xC0) === 0x80) {
            tempCodePoint = (firstByte & 0xF) << 0x12 | (secondByte & 0x3F) << 0xC | (thirdByte & 0x3F) << 0x6 | (fourthByte & 0x3F)
            if (tempCodePoint > 0xFFFF && tempCodePoint < 0x110000) {
              codePoint = tempCodePoint
            }
          }
      }
    }

    if (codePoint === null) {
      // we did not generate a valid codePoint so insert a
      // replacement char (U+FFFD) and advance only 1 byte
      codePoint = 0xFFFD
      bytesPerSequence = 1
    } else if (codePoint > 0xFFFF) {
      // encode to utf16 (surrogate pair dance)
      codePoint -= 0x10000
      res.push(codePoint >>> 10 & 0x3FF | 0xD800)
      codePoint = 0xDC00 | codePoint & 0x3FF
    }

    res.push(codePoint)
    i += bytesPerSequence
  }

  return decodeCodePointsArray(res)
}

// Based on http://stackoverflow.com/a/22747272/680742, the browser with
// the lowest limit is Chrome, with 0x10000 args.
// We go 1 magnitude less, for safety
var MAX_ARGUMENTS_LENGTH = 0x1000

function decodeCodePointsArray (codePoints) {
  var len = codePoints.length
  if (len <= MAX_ARGUMENTS_LENGTH) {
    return String.fromCharCode.apply(String, codePoints) // avoid extra slice()
  }

  // Decode in chunks to avoid "call stack size exceeded".
  var res = ''
  var i = 0
  while (i < len) {
    res += String.fromCharCode.apply(
      String,
      codePoints.slice(i, i += MAX_ARGUMENTS_LENGTH)
    )
  }
  return res
}

function asciiSlice (buf, start, end) {
  var ret = ''
  end = Math.min(buf.length, end)

  for (var i = start; i < end; i++) {
    ret += String.fromCharCode(buf[i] & 0x7F)
  }
  return ret
}

function binarySlice (buf, start, end) {
  var ret = ''
  end = Math.min(buf.length, end)

  for (var i = start; i < end; i++) {
    ret += String.fromCharCode(buf[i])
  }
  return ret
}

function hexSlice (buf, start, end) {
  var len = buf.length

  if (!start || start < 0) start = 0
  if (!end || end < 0 || end > len) end = len

  var out = ''
  for (var i = start; i < end; i++) {
    out += toHex(buf[i])
  }
  return out
}

function utf16leSlice (buf, start, end) {
  var bytes = buf.slice(start, end)
  var res = ''
  for (var i = 0; i < bytes.length; i += 2) {
    res += String.fromCharCode(bytes[i] + bytes[i + 1] * 256)
  }
  return res
}

Buffer.prototype.slice = function slice (start, end) {
  var len = this.length
  start = ~~start
  end = end === undefined ? len : ~~end

  if (start < 0) {
    start += len
    if (start < 0) start = 0
  } else if (start > len) {
    start = len
  }

  if (end < 0) {
    end += len
    if (end < 0) end = 0
  } else if (end > len) {
    end = len
  }

  if (end < start) end = start

  var newBuf
  if (Buffer.TYPED_ARRAY_SUPPORT) {
    newBuf = Buffer._augment(this.subarray(start, end))
  } else {
    var sliceLen = end - start
    newBuf = new Buffer(sliceLen, undefined)
    for (var i = 0; i < sliceLen; i++) {
      newBuf[i] = this[i + start]
    }
  }

  if (newBuf.length) newBuf.parent = this.parent || this

  return newBuf
}

/*
 * Need to make sure that buffer isn't trying to write out of bounds.
 */
function checkOffset (offset, ext, length) {
  if ((offset % 1) !== 0 || offset < 0) throw new RangeError('offset is not uint')
  if (offset + ext > length) throw new RangeError('Trying to access beyond buffer length')
}

Buffer.prototype.readUIntLE = function readUIntLE (offset, byteLength, noAssert) {
  offset = offset | 0
  byteLength = byteLength | 0
  if (!noAssert) checkOffset(offset, byteLength, this.length)

  var val = this[offset]
  var mul = 1
  var i = 0
  while (++i < byteLength && (mul *= 0x100)) {
    val += this[offset + i] * mul
  }

  return val
}

Buffer.prototype.readUIntBE = function readUIntBE (offset, byteLength, noAssert) {
  offset = offset | 0
  byteLength = byteLength | 0
  if (!noAssert) {
    checkOffset(offset, byteLength, this.length)
  }

  var val = this[offset + --byteLength]
  var mul = 1
  while (byteLength > 0 && (mul *= 0x100)) {
    val += this[offset + --byteLength] * mul
  }

  return val
}

Buffer.prototype.readUInt8 = function readUInt8 (offset, noAssert) {
  if (!noAssert) checkOffset(offset, 1, this.length)
  return this[offset]
}

Buffer.prototype.readUInt16LE = function readUInt16LE (offset, noAssert) {
  if (!noAssert) checkOffset(offset, 2, this.length)
  return this[offset] | (this[offset + 1] << 8)
}

Buffer.prototype.readUInt16BE = function readUInt16BE (offset, noAssert) {
  if (!noAssert) checkOffset(offset, 2, this.length)
  return (this[offset] << 8) | this[offset + 1]
}

Buffer.prototype.readUInt32LE = function readUInt32LE (offset, noAssert) {
  if (!noAssert) checkOffset(offset, 4, this.length)

  return ((this[offset]) |
      (this[offset + 1] << 8) |
      (this[offset + 2] << 16)) +
      (this[offset + 3] * 0x1000000)
}

Buffer.prototype.readUInt32BE = function readUInt32BE (offset, noAssert) {
  if (!noAssert) checkOffset(offset, 4, this.length)

  return (this[offset] * 0x1000000) +
    ((this[offset + 1] << 16) |
    (this[offset + 2] << 8) |
    this[offset + 3])
}

Buffer.prototype.readIntLE = function readIntLE (offset, byteLength, noAssert) {
  offset = offset | 0
  byteLength = byteLength | 0
  if (!noAssert) checkOffset(offset, byteLength, this.length)

  var val = this[offset]
  var mul = 1
  var i = 0
  while (++i < byteLength && (mul *= 0x100)) {
    val += this[offset + i] * mul
  }
  mul *= 0x80

  if (val >= mul) val -= Math.pow(2, 8 * byteLength)

  return val
}

Buffer.prototype.readIntBE = function readIntBE (offset, byteLength, noAssert) {
  offset = offset | 0
  byteLength = byteLength | 0
  if (!noAssert) checkOffset(offset, byteLength, this.length)

  var i = byteLength
  var mul = 1
  var val = this[offset + --i]
  while (i > 0 && (mul *= 0x100)) {
    val += this[offset + --i] * mul
  }
  mul *= 0x80

  if (val >= mul) val -= Math.pow(2, 8 * byteLength)

  return val
}

Buffer.prototype.readInt8 = function readInt8 (offset, noAssert) {
  if (!noAssert) checkOffset(offset, 1, this.length)
  if (!(this[offset] & 0x80)) return (this[offset])
  return ((0xff - this[offset] + 1) * -1)
}

Buffer.prototype.readInt16LE = function readInt16LE (offset, noAssert) {
  if (!noAssert) checkOffset(offset, 2, this.length)
  var val = this[offset] | (this[offset + 1] << 8)
  return (val & 0x8000) ? val | 0xFFFF0000 : val
}

Buffer.prototype.readInt16BE = function readInt16BE (offset, noAssert) {
  if (!noAssert) checkOffset(offset, 2, this.length)
  var val = this[offset + 1] | (this[offset] << 8)
  return (val & 0x8000) ? val | 0xFFFF0000 : val
}

Buffer.prototype.readInt32LE = function readInt32LE (offset, noAssert) {
  if (!noAssert) checkOffset(offset, 4, this.length)

  return (this[offset]) |
    (this[offset + 1] << 8) |
    (this[offset + 2] << 16) |
    (this[offset + 3] << 24)
}

Buffer.prototype.readInt32BE = function readInt32BE (offset, noAssert) {
  if (!noAssert) checkOffset(offset, 4, this.length)

  return (this[offset] << 24) |
    (this[offset + 1] << 16) |
    (this[offset + 2] << 8) |
    (this[offset + 3])
}

Buffer.prototype.readFloatLE = function readFloatLE (offset, noAssert) {
  if (!noAssert) checkOffset(offset, 4, this.length)
  return ieee754.read(this, offset, true, 23, 4)
}

Buffer.prototype.readFloatBE = function readFloatBE (offset, noAssert) {
  if (!noAssert) checkOffset(offset, 4, this.length)
  return ieee754.read(this, offset, false, 23, 4)
}

Buffer.prototype.readDoubleLE = function readDoubleLE (offset, noAssert) {
  if (!noAssert) checkOffset(offset, 8, this.length)
  return ieee754.read(this, offset, true, 52, 8)
}

Buffer.prototype.readDoubleBE = function readDoubleBE (offset, noAssert) {
  if (!noAssert) checkOffset(offset, 8, this.length)
  return ieee754.read(this, offset, false, 52, 8)
}

function checkInt (buf, value, offset, ext, max, min) {
  if (!Buffer.isBuffer(buf)) throw new TypeError('buffer must be a Buffer instance')
  if (value > max || value < min) throw new RangeError('value is out of bounds')
  if (offset + ext > buf.length) throw new RangeError('index out of range')
}

Buffer.prototype.writeUIntLE = function writeUIntLE (value, offset, byteLength, noAssert) {
  value = +value
  offset = offset | 0
  byteLength = byteLength | 0
  if (!noAssert) checkInt(this, value, offset, byteLength, Math.pow(2, 8 * byteLength), 0)

  var mul = 1
  var i = 0
  this[offset] = value & 0xFF
  while (++i < byteLength && (mul *= 0x100)) {
    this[offset + i] = (value / mul) & 0xFF
  }

  return offset + byteLength
}

Buffer.prototype.writeUIntBE = function writeUIntBE (value, offset, byteLength, noAssert) {
  value = +value
  offset = offset | 0
  byteLength = byteLength | 0
  if (!noAssert) checkInt(this, value, offset, byteLength, Math.pow(2, 8 * byteLength), 0)

  var i = byteLength - 1
  var mul = 1
  this[offset + i] = value & 0xFF
  while (--i >= 0 && (mul *= 0x100)) {
    this[offset + i] = (value / mul) & 0xFF
  }

  return offset + byteLength
}

Buffer.prototype.writeUInt8 = function writeUInt8 (value, offset, noAssert) {
  value = +value
  offset = offset | 0
  if (!noAssert) checkInt(this, value, offset, 1, 0xff, 0)
  if (!Buffer.TYPED_ARRAY_SUPPORT) value = Math.floor(value)
  this[offset] = (value & 0xff)
  return offset + 1
}

function objectWriteUInt16 (buf, value, offset, littleEndian) {
  if (value < 0) value = 0xffff + value + 1
  for (var i = 0, j = Math.min(buf.length - offset, 2); i < j; i++) {
    buf[offset + i] = (value & (0xff << (8 * (littleEndian ? i : 1 - i)))) >>>
      (littleEndian ? i : 1 - i) * 8
  }
}

Buffer.prototype.writeUInt16LE = function writeUInt16LE (value, offset, noAssert) {
  value = +value
  offset = offset | 0
  if (!noAssert) checkInt(this, value, offset, 2, 0xffff, 0)
  if (Buffer.TYPED_ARRAY_SUPPORT) {
    this[offset] = (value & 0xff)
    this[offset + 1] = (value >>> 8)
  } else {
    objectWriteUInt16(this, value, offset, true)
  }
  return offset + 2
}

Buffer.prototype.writeUInt16BE = function writeUInt16BE (value, offset, noAssert) {
  value = +value
  offset = offset | 0
  if (!noAssert) checkInt(this, value, offset, 2, 0xffff, 0)
  if (Buffer.TYPED_ARRAY_SUPPORT) {
    this[offset] = (value >>> 8)
    this[offset + 1] = (value & 0xff)
  } else {
    objectWriteUInt16(this, value, offset, false)
  }
  return offset + 2
}

function objectWriteUInt32 (buf, value, offset, littleEndian) {
  if (value < 0) value = 0xffffffff + value + 1
  for (var i = 0, j = Math.min(buf.length - offset, 4); i < j; i++) {
    buf[offset + i] = (value >>> (littleEndian ? i : 3 - i) * 8) & 0xff
  }
}

Buffer.prototype.writeUInt32LE = function writeUInt32LE (value, offset, noAssert) {
  value = +value
  offset = offset | 0
  if (!noAssert) checkInt(this, value, offset, 4, 0xffffffff, 0)
  if (Buffer.TYPED_ARRAY_SUPPORT) {
    this[offset + 3] = (value >>> 24)
    this[offset + 2] = (value >>> 16)
    this[offset + 1] = (value >>> 8)
    this[offset] = (value & 0xff)
  } else {
    objectWriteUInt32(this, value, offset, true)
  }
  return offset + 4
}

Buffer.prototype.writeUInt32BE = function writeUInt32BE (value, offset, noAssert) {
  value = +value
  offset = offset | 0
  if (!noAssert) checkInt(this, value, offset, 4, 0xffffffff, 0)
  if (Buffer.TYPED_ARRAY_SUPPORT) {
    this[offset] = (value >>> 24)
    this[offset + 1] = (value >>> 16)
    this[offset + 2] = (value >>> 8)
    this[offset + 3] = (value & 0xff)
  } else {
    objectWriteUInt32(this, value, offset, false)
  }
  return offset + 4
}

Buffer.prototype.writeIntLE = function writeIntLE (value, offset, byteLength, noAssert) {
  value = +value
  offset = offset | 0
  if (!noAssert) {
    var limit = Math.pow(2, 8 * byteLength - 1)

    checkInt(this, value, offset, byteLength, limit - 1, -limit)
  }

  var i = 0
  var mul = 1
  var sub = value < 0 ? 1 : 0
  this[offset] = value & 0xFF
  while (++i < byteLength && (mul *= 0x100)) {
    this[offset + i] = ((value / mul) >> 0) - sub & 0xFF
  }

  return offset + byteLength
}

Buffer.prototype.writeIntBE = function writeIntBE (value, offset, byteLength, noAssert) {
  value = +value
  offset = offset | 0
  if (!noAssert) {
    var limit = Math.pow(2, 8 * byteLength - 1)

    checkInt(this, value, offset, byteLength, limit - 1, -limit)
  }

  var i = byteLength - 1
  var mul = 1
  var sub = value < 0 ? 1 : 0
  this[offset + i] = value & 0xFF
  while (--i >= 0 && (mul *= 0x100)) {
    this[offset + i] = ((value / mul) >> 0) - sub & 0xFF
  }

  return offset + byteLength
}

Buffer.prototype.writeInt8 = function writeInt8 (value, offset, noAssert) {
  value = +value
  offset = offset | 0
  if (!noAssert) checkInt(this, value, offset, 1, 0x7f, -0x80)
  if (!Buffer.TYPED_ARRAY_SUPPORT) value = Math.floor(value)
  if (value < 0) value = 0xff + value + 1
  this[offset] = (value & 0xff)
  return offset + 1
}

Buffer.prototype.writeInt16LE = function writeInt16LE (value, offset, noAssert) {
  value = +value
  offset = offset | 0
  if (!noAssert) checkInt(this, value, offset, 2, 0x7fff, -0x8000)
  if (Buffer.TYPED_ARRAY_SUPPORT) {
    this[offset] = (value & 0xff)
    this[offset + 1] = (value >>> 8)
  } else {
    objectWriteUInt16(this, value, offset, true)
  }
  return offset + 2
}

Buffer.prototype.writeInt16BE = function writeInt16BE (value, offset, noAssert) {
  value = +value
  offset = offset | 0
  if (!noAssert) checkInt(this, value, offset, 2, 0x7fff, -0x8000)
  if (Buffer.TYPED_ARRAY_SUPPORT) {
    this[offset] = (value >>> 8)
    this[offset + 1] = (value & 0xff)
  } else {
    objectWriteUInt16(this, value, offset, false)
  }
  return offset + 2
}

Buffer.prototype.writeInt32LE = function writeInt32LE (value, offset, noAssert) {
  value = +value
  offset = offset | 0
  if (!noAssert) checkInt(this, value, offset, 4, 0x7fffffff, -0x80000000)
  if (Buffer.TYPED_ARRAY_SUPPORT) {
    this[offset] = (value & 0xff)
    this[offset + 1] = (value >>> 8)
    this[offset + 2] = (value >>> 16)
    this[offset + 3] = (value >>> 24)
  } else {
    objectWriteUInt32(this, value, offset, true)
  }
  return offset + 4
}

Buffer.prototype.writeInt32BE = function writeInt32BE (value, offset, noAssert) {
  value = +value
  offset = offset | 0
  if (!noAssert) checkInt(this, value, offset, 4, 0x7fffffff, -0x80000000)
  if (value < 0) value = 0xffffffff + value + 1
  if (Buffer.TYPED_ARRAY_SUPPORT) {
    this[offset] = (value >>> 24)
    this[offset + 1] = (value >>> 16)
    this[offset + 2] = (value >>> 8)
    this[offset + 3] = (value & 0xff)
  } else {
    objectWriteUInt32(this, value, offset, false)
  }
  return offset + 4
}

function checkIEEE754 (buf, value, offset, ext, max, min) {
  if (value > max || value < min) throw new RangeError('value is out of bounds')
  if (offset + ext > buf.length) throw new RangeError('index out of range')
  if (offset < 0) throw new RangeError('index out of range')
}

function writeFloat (buf, value, offset, littleEndian, noAssert) {
  if (!noAssert) {
    checkIEEE754(buf, value, offset, 4, 3.4028234663852886e+38, -3.4028234663852886e+38)
  }
  ieee754.write(buf, value, offset, littleEndian, 23, 4)
  return offset + 4
}

Buffer.prototype.writeFloatLE = function writeFloatLE (value, offset, noAssert) {
  return writeFloat(this, value, offset, true, noAssert)
}

Buffer.prototype.writeFloatBE = function writeFloatBE (value, offset, noAssert) {
  return writeFloat(this, value, offset, false, noAssert)
}

function writeDouble (buf, value, offset, littleEndian, noAssert) {
  if (!noAssert) {
    checkIEEE754(buf, value, offset, 8, 1.7976931348623157E+308, -1.7976931348623157E+308)
  }
  ieee754.write(buf, value, offset, littleEndian, 52, 8)
  return offset + 8
}

Buffer.prototype.writeDoubleLE = function writeDoubleLE (value, offset, noAssert) {
  return writeDouble(this, value, offset, true, noAssert)
}

Buffer.prototype.writeDoubleBE = function writeDoubleBE (value, offset, noAssert) {
  return writeDouble(this, value, offset, false, noAssert)
}

// copy(targetBuffer, targetStart=0, sourceStart=0, sourceEnd=buffer.length)
Buffer.prototype.copy = function copy (target, targetStart, start, end) {
  if (!start) start = 0
  if (!end && end !== 0) end = this.length
  if (targetStart >= target.length) targetStart = target.length
  if (!targetStart) targetStart = 0
  if (end > 0 && end < start) end = start

  // Copy 0 bytes; we're done
  if (end === start) return 0
  if (target.length === 0 || this.length === 0) return 0

  // Fatal error conditions
  if (targetStart < 0) {
    throw new RangeError('targetStart out of bounds')
  }
  if (start < 0 || start >= this.length) throw new RangeError('sourceStart out of bounds')
  if (end < 0) throw new RangeError('sourceEnd out of bounds')

  // Are we oob?
  if (end > this.length) end = this.length
  if (target.length - targetStart < end - start) {
    end = target.length - targetStart + start
  }

  var len = end - start
  var i

  if (this === target && start < targetStart && targetStart < end) {
    // descending copy from end
    for (i = len - 1; i >= 0; i--) {
      target[i + targetStart] = this[i + start]
    }
  } else if (len < 1000 || !Buffer.TYPED_ARRAY_SUPPORT) {
    // ascending copy from start
    for (i = 0; i < len; i++) {
      target[i + targetStart] = this[i + start]
    }
  } else {
    target._set(this.subarray(start, start + len), targetStart)
  }

  return len
}

// fill(value, start=0, end=buffer.length)
Buffer.prototype.fill = function fill (value, start, end) {
  if (!value) value = 0
  if (!start) start = 0
  if (!end) end = this.length

  if (end < start) throw new RangeError('end < start')

  // Fill 0 bytes; we're done
  if (end === start) return
  if (this.length === 0) return

  if (start < 0 || start >= this.length) throw new RangeError('start out of bounds')
  if (end < 0 || end > this.length) throw new RangeError('end out of bounds')

  var i
  if (typeof value === 'number') {
    for (i = start; i < end; i++) {
      this[i] = value
    }
  } else {
    var bytes = utf8ToBytes(value.toString())
    var len = bytes.length
    for (i = start; i < end; i++) {
      this[i] = bytes[i % len]
    }
  }

  return this
}

/**
 * Creates a new `ArrayBuffer` with the *copied* memory of the buffer instance.
 * Added in Node 0.12. Only available in browsers that support ArrayBuffer.
 */
Buffer.prototype.toArrayBuffer = function toArrayBuffer () {
  if (typeof Uint8Array !== 'undefined') {
    if (Buffer.TYPED_ARRAY_SUPPORT) {
      return (new Buffer(this)).buffer
    } else {
      var buf = new Uint8Array(this.length)
      for (var i = 0, len = buf.length; i < len; i += 1) {
        buf[i] = this[i]
      }
      return buf.buffer
    }
  } else {
    throw new TypeError('Buffer.toArrayBuffer not supported in this browser')
  }
}

// HELPER FUNCTIONS
// ================

var BP = Buffer.prototype

/**
 * Augment a Uint8Array *instance* (not the Uint8Array class!) with Buffer methods
 */
Buffer._augment = function _augment (arr) {
  arr.constructor = Buffer
  arr._isBuffer = true

  // save reference to original Uint8Array set method before overwriting
  arr._set = arr.set

  // deprecated
  arr.get = BP.get
  arr.set = BP.set

  arr.write = BP.write
  arr.toString = BP.toString
  arr.toLocaleString = BP.toString
  arr.toJSON = BP.toJSON
  arr.equals = BP.equals
  arr.compare = BP.compare
  arr.indexOf = BP.indexOf
  arr.copy = BP.copy
  arr.slice = BP.slice
  arr.readUIntLE = BP.readUIntLE
  arr.readUIntBE = BP.readUIntBE
  arr.readUInt8 = BP.readUInt8
  arr.readUInt16LE = BP.readUInt16LE
  arr.readUInt16BE = BP.readUInt16BE
  arr.readUInt32LE = BP.readUInt32LE
  arr.readUInt32BE = BP.readUInt32BE
  arr.readIntLE = BP.readIntLE
  arr.readIntBE = BP.readIntBE
  arr.readInt8 = BP.readInt8
  arr.readInt16LE = BP.readInt16LE
  arr.readInt16BE = BP.readInt16BE
  arr.readInt32LE = BP.readInt32LE
  arr.readInt32BE = BP.readInt32BE
  arr.readFloatLE = BP.readFloatLE
  arr.readFloatBE = BP.readFloatBE
  arr.readDoubleLE = BP.readDoubleLE
  arr.readDoubleBE = BP.readDoubleBE
  arr.writeUInt8 = BP.writeUInt8
  arr.writeUIntLE = BP.writeUIntLE
  arr.writeUIntBE = BP.writeUIntBE
  arr.writeUInt16LE = BP.writeUInt16LE
  arr.writeUInt16BE = BP.writeUInt16BE
  arr.writeUInt32LE = BP.writeUInt32LE
  arr.writeUInt32BE = BP.writeUInt32BE
  arr.writeIntLE = BP.writeIntLE
  arr.writeIntBE = BP.writeIntBE
  arr.writeInt8 = BP.writeInt8
  arr.writeInt16LE = BP.writeInt16LE
  arr.writeInt16BE = BP.writeInt16BE
  arr.writeInt32LE = BP.writeInt32LE
  arr.writeInt32BE = BP.writeInt32BE
  arr.writeFloatLE = BP.writeFloatLE
  arr.writeFloatBE = BP.writeFloatBE
  arr.writeDoubleLE = BP.writeDoubleLE
  arr.writeDoubleBE = BP.writeDoubleBE
  arr.fill = BP.fill
  arr.inspect = BP.inspect
  arr.toArrayBuffer = BP.toArrayBuffer

  return arr
}

var INVALID_BASE64_RE = /[^+\/0-9A-Za-z-_]/g

function base64clean (str) {
  // Node strips out invalid characters like \n and \t from the string, base64-js does not
  str = stringtrim(str).replace(INVALID_BASE64_RE, '')
  // Node converts strings with length < 2 to ''
  if (str.length < 2) return ''
  // Node allows for non-padded base64 strings (missing trailing ===), base64-js does not
  while (str.length % 4 !== 0) {
    str = str + '='
  }
  return str
}

function stringtrim (str) {
  if (str.trim) return str.trim()
  return str.replace(/^\s+|\s+$/g, '')
}

function toHex (n) {
  if (n < 16) return '0' + n.toString(16)
  return n.toString(16)
}

function utf8ToBytes (string, units) {
  units = units || Infinity
  var codePoint
  var length = string.length
  var leadSurrogate = null
  var bytes = []

  for (var i = 0; i < length; i++) {
    codePoint = string.charCodeAt(i)

    // is surrogate component
    if (codePoint > 0xD7FF && codePoint < 0xE000) {
      // last char was a lead
      if (!leadSurrogate) {
        // no lead yet
        if (codePoint > 0xDBFF) {
          // unexpected trail
          if ((units -= 3) > -1) bytes.push(0xEF, 0xBF, 0xBD)
          continue
        } else if (i + 1 === length) {
          // unpaired lead
          if ((units -= 3) > -1) bytes.push(0xEF, 0xBF, 0xBD)
          continue
        }

        // valid lead
        leadSurrogate = codePoint

        continue
      }

      // 2 leads in a row
      if (codePoint < 0xDC00) {
        if ((units -= 3) > -1) bytes.push(0xEF, 0xBF, 0xBD)
        leadSurrogate = codePoint
        continue
      }

      // valid surrogate pair
      codePoint = (leadSurrogate - 0xD800 << 10 | codePoint - 0xDC00) + 0x10000
    } else if (leadSurrogate) {
      // valid bmp char, but last char was a lead
      if ((units -= 3) > -1) bytes.push(0xEF, 0xBF, 0xBD)
    }

    leadSurrogate = null

    // encode utf8
    if (codePoint < 0x80) {
      if ((units -= 1) < 0) break
      bytes.push(codePoint)
    } else if (codePoint < 0x800) {
      if ((units -= 2) < 0) break
      bytes.push(
        codePoint >> 0x6 | 0xC0,
        codePoint & 0x3F | 0x80
      )
    } else if (codePoint < 0x10000) {
      if ((units -= 3) < 0) break
      bytes.push(
        codePoint >> 0xC | 0xE0,
        codePoint >> 0x6 & 0x3F | 0x80,
        codePoint & 0x3F | 0x80
      )
    } else if (codePoint < 0x110000) {
      if ((units -= 4) < 0) break
      bytes.push(
        codePoint >> 0x12 | 0xF0,
        codePoint >> 0xC & 0x3F | 0x80,
        codePoint >> 0x6 & 0x3F | 0x80,
        codePoint & 0x3F | 0x80
      )
    } else {
      throw new Error('Invalid code point')
    }
  }

  return bytes
}

function asciiToBytes (str) {
  var byteArray = []
  for (var i = 0; i < str.length; i++) {
    // Node's code seems to be doing this and not & 0x7F..
    byteArray.push(str.charCodeAt(i) & 0xFF)
  }
  return byteArray
}

function utf16leToBytes (str, units) {
  var c, hi, lo
  var byteArray = []
  for (var i = 0; i < str.length; i++) {
    if ((units -= 2) < 0) break

    c = str.charCodeAt(i)
    hi = c >> 8
    lo = c % 256
    byteArray.push(lo)
    byteArray.push(hi)
  }

  return byteArray
}

function base64ToBytes (str) {
  return base64.toByteArray(base64clean(str))
}

function blitBuffer (src, dst, offset, length) {
  for (var i = 0; i < length; i++) {
    if ((i + offset >= dst.length) || (i >= src.length)) break
    dst[i + offset] = src[i]
  }
  return i
}

}).call(this,typeof global !== "undefined" ? global : typeof self !== "undefined" ? self : typeof window !== "undefined" ? window : {})

},{"base64-js":58,"ieee754":59,"isarray":60}],58:[function(require,module,exports){
var lookup = 'ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/';

;(function (exports) {
	'use strict';

  var Arr = (typeof Uint8Array !== 'undefined')
    ? Uint8Array
    : Array

	var PLUS   = '+'.charCodeAt(0)
	var SLASH  = '/'.charCodeAt(0)
	var NUMBER = '0'.charCodeAt(0)
	var LOWER  = 'a'.charCodeAt(0)
	var UPPER  = 'A'.charCodeAt(0)
	var PLUS_URL_SAFE = '-'.charCodeAt(0)
	var SLASH_URL_SAFE = '_'.charCodeAt(0)

	function decode (elt) {
		var code = elt.charCodeAt(0)
		if (code === PLUS ||
		    code === PLUS_URL_SAFE)
			return 62 // '+'
		if (code === SLASH ||
		    code === SLASH_URL_SAFE)
			return 63 // '/'
		if (code < NUMBER)
			return -1 //no match
		if (code < NUMBER + 10)
			return code - NUMBER + 26 + 26
		if (code < UPPER + 26)
			return code - UPPER
		if (code < LOWER + 26)
			return code - LOWER + 26
	}

	function b64ToByteArray (b64) {
		var i, j, l, tmp, placeHolders, arr

		if (b64.length % 4 > 0) {
			throw new Error('Invalid string. Length must be a multiple of 4')
		}

		// the number of equal signs (place holders)
		// if there are two placeholders, than the two characters before it
		// represent one byte
		// if there is only one, then the three characters before it represent 2 bytes
		// this is just a cheap hack to not do indexOf twice
		var len = b64.length
		placeHolders = '=' === b64.charAt(len - 2) ? 2 : '=' === b64.charAt(len - 1) ? 1 : 0

		// base64 is 4/3 + up to two characters of the original data
		arr = new Arr(b64.length * 3 / 4 - placeHolders)

		// if there are placeholders, only get up to the last complete 4 chars
		l = placeHolders > 0 ? b64.length - 4 : b64.length

		var L = 0

		function push (v) {
			arr[L++] = v
		}

		for (i = 0, j = 0; i < l; i += 4, j += 3) {
			tmp = (decode(b64.charAt(i)) << 18) | (decode(b64.charAt(i + 1)) << 12) | (decode(b64.charAt(i + 2)) << 6) | decode(b64.charAt(i + 3))
			push((tmp & 0xFF0000) >> 16)
			push((tmp & 0xFF00) >> 8)
			push(tmp & 0xFF)
		}

		if (placeHolders === 2) {
			tmp = (decode(b64.charAt(i)) << 2) | (decode(b64.charAt(i + 1)) >> 4)
			push(tmp & 0xFF)
		} else if (placeHolders === 1) {
			tmp = (decode(b64.charAt(i)) << 10) | (decode(b64.charAt(i + 1)) << 4) | (decode(b64.charAt(i + 2)) >> 2)
			push((tmp >> 8) & 0xFF)
			push(tmp & 0xFF)
		}

		return arr
	}

	function uint8ToBase64 (uint8) {
		var i,
			extraBytes = uint8.length % 3, // if we have 1 byte left, pad 2 bytes
			output = "",
			temp, length

		function encode (num) {
			return lookup.charAt(num)
		}

		function tripletToBase64 (num) {
			return encode(num >> 18 & 0x3F) + encode(num >> 12 & 0x3F) + encode(num >> 6 & 0x3F) + encode(num & 0x3F)
		}

		// go through the array every three bytes, we'll deal with trailing stuff later
		for (i = 0, length = uint8.length - extraBytes; i < length; i += 3) {
			temp = (uint8[i] << 16) + (uint8[i + 1] << 8) + (uint8[i + 2])
			output += tripletToBase64(temp)
		}

		// pad the end with zeros, but make sure to not forget the extra bytes
		switch (extraBytes) {
			case 1:
				temp = uint8[uint8.length - 1]
				output += encode(temp >> 2)
				output += encode((temp << 4) & 0x3F)
				output += '=='
				break
			case 2:
				temp = (uint8[uint8.length - 2] << 8) + (uint8[uint8.length - 1])
				output += encode(temp >> 10)
				output += encode((temp >> 4) & 0x3F)
				output += encode((temp << 2) & 0x3F)
				output += '='
				break
		}

		return output
	}

	exports.toByteArray = b64ToByteArray
	exports.fromByteArray = uint8ToBase64
}(typeof exports === 'undefined' ? (this.base64js = {}) : exports))

},{}],59:[function(require,module,exports){
exports.read = function (buffer, offset, isLE, mLen, nBytes) {
  var e, m
  var eLen = nBytes * 8 - mLen - 1
  var eMax = (1 << eLen) - 1
  var eBias = eMax >> 1
  var nBits = -7
  var i = isLE ? (nBytes - 1) : 0
  var d = isLE ? -1 : 1
  var s = buffer[offset + i]

  i += d

  e = s & ((1 << (-nBits)) - 1)
  s >>= (-nBits)
  nBits += eLen
  for (; nBits > 0; e = e * 256 + buffer[offset + i], i += d, nBits -= 8) {}

  m = e & ((1 << (-nBits)) - 1)
  e >>= (-nBits)
  nBits += mLen
  for (; nBits > 0; m = m * 256 + buffer[offset + i], i += d, nBits -= 8) {}

  if (e === 0) {
    e = 1 - eBias
  } else if (e === eMax) {
    return m ? NaN : ((s ? -1 : 1) * Infinity)
  } else {
    m = m + Math.pow(2, mLen)
    e = e - eBias
  }
  return (s ? -1 : 1) * m * Math.pow(2, e - mLen)
}

exports.write = function (buffer, value, offset, isLE, mLen, nBytes) {
  var e, m, c
  var eLen = nBytes * 8 - mLen - 1
  var eMax = (1 << eLen) - 1
  var eBias = eMax >> 1
  var rt = (mLen === 23 ? Math.pow(2, -24) - Math.pow(2, -77) : 0)
  var i = isLE ? 0 : (nBytes - 1)
  var d = isLE ? 1 : -1
  var s = value < 0 || (value === 0 && 1 / value < 0) ? 1 : 0

  value = Math.abs(value)

  if (isNaN(value) || value === Infinity) {
    m = isNaN(value) ? 1 : 0
    e = eMax
  } else {
    e = Math.floor(Math.log(value) / Math.LN2)
    if (value * (c = Math.pow(2, -e)) < 1) {
      e--
      c *= 2
    }
    if (e + eBias >= 1) {
      value += rt / c
    } else {
      value += rt * Math.pow(2, 1 - eBias)
    }
    if (value * c >= 2) {
      e++
      c /= 2
    }

    if (e + eBias >= eMax) {
      m = 0
      e = eMax
    } else if (e + eBias >= 1) {
      m = (value * c - 1) * Math.pow(2, mLen)
      e = e + eBias
    } else {
      m = value * Math.pow(2, eBias - 1) * Math.pow(2, mLen)
      e = 0
    }
  }

  for (; mLen >= 8; buffer[offset + i] = m & 0xff, i += d, m /= 256, mLen -= 8) {}

  e = (e << mLen) | m
  eLen += mLen
  for (; eLen > 0; buffer[offset + i] = e & 0xff, i += d, e /= 256, eLen -= 8) {}

  buffer[offset + i - d] |= s * 128
}

},{}],60:[function(require,module,exports){
var toString = {}.toString;

module.exports = Array.isArray || function (arr) {
  return toString.call(arr) == '[object Array]';
};

},{}],61:[function(require,module,exports){
// Copyright Joyent, Inc. and other Node contributors.
//
// Permission is hereby granted, free of charge, to any person obtaining a
// copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to permit
// persons to whom the Software is furnished to do so, subject to the
// following conditions:
//
// The above copyright notice and this permission notice shall be included
// in all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN
// NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
// DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR
// OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE
// USE OR OTHER DEALINGS IN THE SOFTWARE.

function EventEmitter() {
  this._events = this._events || {};
  this._maxListeners = this._maxListeners || undefined;
}
module.exports = EventEmitter;

// Backwards-compat with node 0.10.x
EventEmitter.EventEmitter = EventEmitter;

EventEmitter.prototype._events = undefined;
EventEmitter.prototype._maxListeners = undefined;

// By default EventEmitters will print a warning if more than 10 listeners are
// added to it. This is a useful default which helps finding memory leaks.
EventEmitter.defaultMaxListeners = 10;

// Obviously not all Emitters should be limited to 10. This function allows
// that to be increased. Set to zero for unlimited.
EventEmitter.prototype.setMaxListeners = function(n) {
  if (!isNumber(n) || n < 0 || isNaN(n))
    throw TypeError('n must be a positive number');
  this._maxListeners = n;
  return this;
};

EventEmitter.prototype.emit = function(type) {
  var er, handler, len, args, i, listeners;

  if (!this._events)
    this._events = {};

  // If there is no 'error' event listener then throw.
  if (type === 'error') {
    if (!this._events.error ||
        (isObject(this._events.error) && !this._events.error.length)) {
      er = arguments[1];
      if (er instanceof Error) {
        throw er; // Unhandled 'error' event
      }
      throw TypeError('Uncaught, unspecified "error" event.');
    }
  }

  handler = this._events[type];

  if (isUndefined(handler))
    return false;

  if (isFunction(handler)) {
    switch (arguments.length) {
      // fast cases
      case 1:
        handler.call(this);
        break;
      case 2:
        handler.call(this, arguments[1]);
        break;
      case 3:
        handler.call(this, arguments[1], arguments[2]);
        break;
      // slower
      default:
        args = Array.prototype.slice.call(arguments, 1);
        handler.apply(this, args);
    }
  } else if (isObject(handler)) {
    args = Array.prototype.slice.call(arguments, 1);
    listeners = handler.slice();
    len = listeners.length;
    for (i = 0; i < len; i++)
      listeners[i].apply(this, args);
  }

  return true;
};

EventEmitter.prototype.addListener = function(type, listener) {
  var m;

  if (!isFunction(listener))
    throw TypeError('listener must be a function');

  if (!this._events)
    this._events = {};

  // To avoid recursion in the case that type === "newListener"! Before
  // adding it to the listeners, first emit "newListener".
  if (this._events.newListener)
    this.emit('newListener', type,
              isFunction(listener.listener) ?
              listener.listener : listener);

  if (!this._events[type])
    // Optimize the case of one listener. Don't need the extra array object.
    this._events[type] = listener;
  else if (isObject(this._events[type]))
    // If we've already got an array, just append.
    this._events[type].push(listener);
  else
    // Adding the second element, need to change to array.
    this._events[type] = [this._events[type], listener];

  // Check for listener leak
  if (isObject(this._events[type]) && !this._events[type].warned) {
    if (!isUndefined(this._maxListeners)) {
      m = this._maxListeners;
    } else {
      m = EventEmitter.defaultMaxListeners;
    }

    if (m && m > 0 && this._events[type].length > m) {
      this._events[type].warned = true;
      console.error('(node) warning: possible EventEmitter memory ' +
                    'leak detected. %d listeners added. ' +
                    'Use emitter.setMaxListeners() to increase limit.',
                    this._events[type].length);
      if (typeof console.trace === 'function') {
        // not supported in IE 10
        console.trace();
      }
    }
  }

  return this;
};

EventEmitter.prototype.on = EventEmitter.prototype.addListener;

EventEmitter.prototype.once = function(type, listener) {
  if (!isFunction(listener))
    throw TypeError('listener must be a function');

  var fired = false;

  function g() {
    this.removeListener(type, g);

    if (!fired) {
      fired = true;
      listener.apply(this, arguments);
    }
  }

  g.listener = listener;
  this.on(type, g);

  return this;
};

// emits a 'removeListener' event iff the listener was removed
EventEmitter.prototype.removeListener = function(type, listener) {
  var list, position, length, i;

  if (!isFunction(listener))
    throw TypeError('listener must be a function');

  if (!this._events || !this._events[type])
    return this;

  list = this._events[type];
  length = list.length;
  position = -1;

  if (list === listener ||
      (isFunction(list.listener) && list.listener === listener)) {
    delete this._events[type];
    if (this._events.removeListener)
      this.emit('removeListener', type, listener);

  } else if (isObject(list)) {
    for (i = length; i-- > 0;) {
      if (list[i] === listener ||
          (list[i].listener && list[i].listener === listener)) {
        position = i;
        break;
      }
    }

    if (position < 0)
      return this;

    if (list.length === 1) {
      list.length = 0;
      delete this._events[type];
    } else {
      list.splice(position, 1);
    }

    if (this._events.removeListener)
      this.emit('removeListener', type, listener);
  }

  return this;
};

EventEmitter.prototype.removeAllListeners = function(type) {
  var key, listeners;

  if (!this._events)
    return this;

  // not listening for removeListener, no need to emit
  if (!this._events.removeListener) {
    if (arguments.length === 0)
      this._events = {};
    else if (this._events[type])
      delete this._events[type];
    return this;
  }

  // emit removeListener for all listeners on all events
  if (arguments.length === 0) {
    for (key in this._events) {
      if (key === 'removeListener') continue;
      this.removeAllListeners(key);
    }
    this.removeAllListeners('removeListener');
    this._events = {};
    return this;
  }

  listeners = this._events[type];

  if (isFunction(listeners)) {
    this.removeListener(type, listeners);
  } else if (listeners) {
    // LIFO order
    while (listeners.length)
      this.removeListener(type, listeners[listeners.length - 1]);
  }
  delete this._events[type];

  return this;
};

EventEmitter.prototype.listeners = function(type) {
  var ret;
  if (!this._events || !this._events[type])
    ret = [];
  else if (isFunction(this._events[type]))
    ret = [this._events[type]];
  else
    ret = this._events[type].slice();
  return ret;
};

EventEmitter.prototype.listenerCount = function(type) {
  if (this._events) {
    var evlistener = this._events[type];

    if (isFunction(evlistener))
      return 1;
    else if (evlistener)
      return evlistener.length;
  }
  return 0;
};

EventEmitter.listenerCount = function(emitter, type) {
  return emitter.listenerCount(type);
};

function isFunction(arg) {
  return typeof arg === 'function';
}

function isNumber(arg) {
  return typeof arg === 'number';
}

function isObject(arg) {
  return typeof arg === 'object' && arg !== null;
}

function isUndefined(arg) {
  return arg === void 0;
}

},{}],62:[function(require,module,exports){
var http = require('http');

var https = module.exports;

for (var key in http) {
    if (http.hasOwnProperty(key)) https[key] = http[key];
};

https.request = function (params, cb) {
    if (!params) params = {};
    params.scheme = 'https';
    params.protocol = 'https:';
    return http.request.call(this, params, cb);
}

},{"http":85}],63:[function(require,module,exports){
if (typeof Object.create === 'function') {
  // implementation from standard node.js 'util' module
  module.exports = function inherits(ctor, superCtor) {
    ctor.super_ = superCtor
    ctor.prototype = Object.create(superCtor.prototype, {
      constructor: {
        value: ctor,
        enumerable: false,
        writable: true,
        configurable: true
      }
    });
  };
} else {
  // old school shim for old browsers
  module.exports = function inherits(ctor, superCtor) {
    ctor.super_ = superCtor
    var TempCtor = function () {}
    TempCtor.prototype = superCtor.prototype
    ctor.prototype = new TempCtor()
    ctor.prototype.constructor = ctor
  }
}

},{}],64:[function(require,module,exports){
/**
 * Determine if an object is Buffer
 *
 * Author:   Feross Aboukhadijeh <feross@feross.org> <http://feross.org>
 * License:  MIT
 *
 * `npm install is-buffer`
 */

module.exports = function (obj) {
  return !!(obj != null &&
    (obj._isBuffer || // For Safari 5-7 (missing Object.prototype.constructor)
      (obj.constructor &&
      typeof obj.constructor.isBuffer === 'function' &&
      obj.constructor.isBuffer(obj))
    ))
}

},{}],65:[function(require,module,exports){
module.exports = Array.isArray || function (arr) {
  return Object.prototype.toString.call(arr) == '[object Array]';
};

},{}],66:[function(require,module,exports){
// shim for using process in browser

var process = module.exports = {};
var queue = [];
var draining = false;
var currentQueue;
var queueIndex = -1;

function cleanUpNextTick() {
    draining = false;
    if (currentQueue.length) {
        queue = currentQueue.concat(queue);
    } else {
        queueIndex = -1;
    }
    if (queue.length) {
        drainQueue();
    }
}

function drainQueue() {
    if (draining) {
        return;
    }
    var timeout = setTimeout(cleanUpNextTick);
    draining = true;

    var len = queue.length;
    while(len) {
        currentQueue = queue;
        queue = [];
        while (++queueIndex < len) {
            if (currentQueue) {
                currentQueue[queueIndex].run();
            }
        }
        queueIndex = -1;
        len = queue.length;
    }
    currentQueue = null;
    draining = false;
    clearTimeout(timeout);
}

process.nextTick = function (fun) {
    var args = new Array(arguments.length - 1);
    if (arguments.length > 1) {
        for (var i = 1; i < arguments.length; i++) {
            args[i - 1] = arguments[i];
        }
    }
    queue.push(new Item(fun, args));
    if (queue.length === 1 && !draining) {
        setTimeout(drainQueue, 0);
    }
};

// v8 likes predictible objects
function Item(fun, array) {
    this.fun = fun;
    this.array = array;
}
Item.prototype.run = function () {
    this.fun.apply(null, this.array);
};
process.title = 'browser';
process.browser = true;
process.env = {};
process.argv = [];
process.version = ''; // empty string to avoid regexp issues
process.versions = {};

function noop() {}

process.on = noop;
process.addListener = noop;
process.once = noop;
process.off = noop;
process.removeListener = noop;
process.removeAllListeners = noop;
process.emit = noop;

process.binding = function (name) {
    throw new Error('process.binding is not supported');
};

process.cwd = function () { return '/' };
process.chdir = function (dir) {
    throw new Error('process.chdir is not supported');
};
process.umask = function() { return 0; };

},{}],67:[function(require,module,exports){
(function (global){
/*! https://mths.be/punycode v1.4.0 by @mathias */
;(function(root) {

	/** Detect free variables */
	var freeExports = typeof exports == 'object' && exports &&
		!exports.nodeType && exports;
	var freeModule = typeof module == 'object' && module &&
		!module.nodeType && module;
	var freeGlobal = typeof global == 'object' && global;
	if (
		freeGlobal.global === freeGlobal ||
		freeGlobal.window === freeGlobal ||
		freeGlobal.self === freeGlobal
	) {
		root = freeGlobal;
	}

	/**
	 * The `punycode` object.
	 * @name punycode
	 * @type Object
	 */
	var punycode,

	/** Highest positive signed 32-bit float value */
	maxInt = 2147483647, // aka. 0x7FFFFFFF or 2^31-1

	/** Bootstring parameters */
	base = 36,
	tMin = 1,
	tMax = 26,
	skew = 38,
	damp = 700,
	initialBias = 72,
	initialN = 128, // 0x80
	delimiter = '-', // '\x2D'

	/** Regular expressions */
	regexPunycode = /^xn--/,
	regexNonASCII = /[^\x20-\x7E]/, // unprintable ASCII chars + non-ASCII chars
	regexSeparators = /[\x2E\u3002\uFF0E\uFF61]/g, // RFC 3490 separators

	/** Error messages */
	errors = {
		'overflow': 'Overflow: input needs wider integers to process',
		'not-basic': 'Illegal input >= 0x80 (not a basic code point)',
		'invalid-input': 'Invalid input'
	},

	/** Convenience shortcuts */
	baseMinusTMin = base - tMin,
	floor = Math.floor,
	stringFromCharCode = String.fromCharCode,

	/** Temporary variable */
	key;

	/*--------------------------------------------------------------------------*/

	/**
	 * A generic error utility function.
	 * @private
	 * @param {String} type The error type.
	 * @returns {Error} Throws a `RangeError` with the applicable error message.
	 */
	function error(type) {
		throw new RangeError(errors[type]);
	}

	/**
	 * A generic `Array#map` utility function.
	 * @private
	 * @param {Array} array The array to iterate over.
	 * @param {Function} callback The function that gets called for every array
	 * item.
	 * @returns {Array} A new array of values returned by the callback function.
	 */
	function map(array, fn) {
		var length = array.length;
		var result = [];
		while (length--) {
			result[length] = fn(array[length]);
		}
		return result;
	}

	/**
	 * A simple `Array#map`-like wrapper to work with domain name strings or email
	 * addresses.
	 * @private
	 * @param {String} domain The domain name or email address.
	 * @param {Function} callback The function that gets called for every
	 * character.
	 * @returns {Array} A new string of characters returned by the callback
	 * function.
	 */
	function mapDomain(string, fn) {
		var parts = string.split('@');
		var result = '';
		if (parts.length > 1) {
			// In email addresses, only the domain name should be punycoded. Leave
			// the local part (i.e. everything up to `@`) intact.
			result = parts[0] + '@';
			string = parts[1];
		}
		// Avoid `split(regex)` for IE8 compatibility. See #17.
		string = string.replace(regexSeparators, '\x2E');
		var labels = string.split('.');
		var encoded = map(labels, fn).join('.');
		return result + encoded;
	}

	/**
	 * Creates an array containing the numeric code points of each Unicode
	 * character in the string. While JavaScript uses UCS-2 internally,
	 * this function will convert a pair of surrogate halves (each of which
	 * UCS-2 exposes as separate characters) into a single code point,
	 * matching UTF-16.
	 * @see `punycode.ucs2.encode`
	 * @see <https://mathiasbynens.be/notes/javascript-encoding>
	 * @memberOf punycode.ucs2
	 * @name decode
	 * @param {String} string The Unicode input string (UCS-2).
	 * @returns {Array} The new array of code points.
	 */
	function ucs2decode(string) {
		var output = [],
		    counter = 0,
		    length = string.length,
		    value,
		    extra;
		while (counter < length) {
			value = string.charCodeAt(counter++);
			if (value >= 0xD800 && value <= 0xDBFF && counter < length) {
				// high surrogate, and there is a next character
				extra = string.charCodeAt(counter++);
				if ((extra & 0xFC00) == 0xDC00) { // low surrogate
					output.push(((value & 0x3FF) << 10) + (extra & 0x3FF) + 0x10000);
				} else {
					// unmatched surrogate; only append this code unit, in case the next
					// code unit is the high surrogate of a surrogate pair
					output.push(value);
					counter--;
				}
			} else {
				output.push(value);
			}
		}
		return output;
	}

	/**
	 * Creates a string based on an array of numeric code points.
	 * @see `punycode.ucs2.decode`
	 * @memberOf punycode.ucs2
	 * @name encode
	 * @param {Array} codePoints The array of numeric code points.
	 * @returns {String} The new Unicode string (UCS-2).
	 */
	function ucs2encode(array) {
		return map(array, function(value) {
			var output = '';
			if (value > 0xFFFF) {
				value -= 0x10000;
				output += stringFromCharCode(value >>> 10 & 0x3FF | 0xD800);
				value = 0xDC00 | value & 0x3FF;
			}
			output += stringFromCharCode(value);
			return output;
		}).join('');
	}

	/**
	 * Converts a basic code point into a digit/integer.
	 * @see `digitToBasic()`
	 * @private
	 * @param {Number} codePoint The basic numeric code point value.
	 * @returns {Number} The numeric value of a basic code point (for use in
	 * representing integers) in the range `0` to `base - 1`, or `base` if
	 * the code point does not represent a value.
	 */
	function basicToDigit(codePoint) {
		if (codePoint - 48 < 10) {
			return codePoint - 22;
		}
		if (codePoint - 65 < 26) {
			return codePoint - 65;
		}
		if (codePoint - 97 < 26) {
			return codePoint - 97;
		}
		return base;
	}

	/**
	 * Converts a digit/integer into a basic code point.
	 * @see `basicToDigit()`
	 * @private
	 * @param {Number} digit The numeric value of a basic code point.
	 * @returns {Number} The basic code point whose value (when used for
	 * representing integers) is `digit`, which needs to be in the range
	 * `0` to `base - 1`. If `flag` is non-zero, the uppercase form is
	 * used; else, the lowercase form is used. The behavior is undefined
	 * if `flag` is non-zero and `digit` has no uppercase form.
	 */
	function digitToBasic(digit, flag) {
		//  0..25 map to ASCII a..z or A..Z
		// 26..35 map to ASCII 0..9
		return digit + 22 + 75 * (digit < 26) - ((flag != 0) << 5);
	}

	/**
	 * Bias adaptation function as per section 3.4 of RFC 3492.
	 * https://tools.ietf.org/html/rfc3492#section-3.4
	 * @private
	 */
	function adapt(delta, numPoints, firstTime) {
		var k = 0;
		delta = firstTime ? floor(delta / damp) : delta >> 1;
		delta += floor(delta / numPoints);
		for (/* no initialization */; delta > baseMinusTMin * tMax >> 1; k += base) {
			delta = floor(delta / baseMinusTMin);
		}
		return floor(k + (baseMinusTMin + 1) * delta / (delta + skew));
	}

	/**
	 * Converts a Punycode string of ASCII-only symbols to a string of Unicode
	 * symbols.
	 * @memberOf punycode
	 * @param {String} input The Punycode string of ASCII-only symbols.
	 * @returns {String} The resulting string of Unicode symbols.
	 */
	function decode(input) {
		// Don't use UCS-2
		var output = [],
		    inputLength = input.length,
		    out,
		    i = 0,
		    n = initialN,
		    bias = initialBias,
		    basic,
		    j,
		    index,
		    oldi,
		    w,
		    k,
		    digit,
		    t,
		    /** Cached calculation results */
		    baseMinusT;

		// Handle the basic code points: let `basic` be the number of input code
		// points before the last delimiter, or `0` if there is none, then copy
		// the first basic code points to the output.

		basic = input.lastIndexOf(delimiter);
		if (basic < 0) {
			basic = 0;
		}

		for (j = 0; j < basic; ++j) {
			// if it's not a basic code point
			if (input.charCodeAt(j) >= 0x80) {
				error('not-basic');
			}
			output.push(input.charCodeAt(j));
		}

		// Main decoding loop: start just after the last delimiter if any basic code
		// points were copied; start at the beginning otherwise.

		for (index = basic > 0 ? basic + 1 : 0; index < inputLength; /* no final expression */) {

			// `index` is the index of the next character to be consumed.
			// Decode a generalized variable-length integer into `delta`,
			// which gets added to `i`. The overflow checking is easier
			// if we increase `i` as we go, then subtract off its starting
			// value at the end to obtain `delta`.
			for (oldi = i, w = 1, k = base; /* no condition */; k += base) {

				if (index >= inputLength) {
					error('invalid-input');
				}

				digit = basicToDigit(input.charCodeAt(index++));

				if (digit >= base || digit > floor((maxInt - i) / w)) {
					error('overflow');
				}

				i += digit * w;
				t = k <= bias ? tMin : (k >= bias + tMax ? tMax : k - bias);

				if (digit < t) {
					break;
				}

				baseMinusT = base - t;
				if (w > floor(maxInt / baseMinusT)) {
					error('overflow');
				}

				w *= baseMinusT;

			}

			out = output.length + 1;
			bias = adapt(i - oldi, out, oldi == 0);

			// `i` was supposed to wrap around from `out` to `0`,
			// incrementing `n` each time, so we'll fix that now:
			if (floor(i / out) > maxInt - n) {
				error('overflow');
			}

			n += floor(i / out);
			i %= out;

			// Insert `n` at position `i` of the output
			output.splice(i++, 0, n);

		}

		return ucs2encode(output);
	}

	/**
	 * Converts a string of Unicode symbols (e.g. a domain name label) to a
	 * Punycode string of ASCII-only symbols.
	 * @memberOf punycode
	 * @param {String} input The string of Unicode symbols.
	 * @returns {String} The resulting Punycode string of ASCII-only symbols.
	 */
	function encode(input) {
		var n,
		    delta,
		    handledCPCount,
		    basicLength,
		    bias,
		    j,
		    m,
		    q,
		    k,
		    t,
		    currentValue,
		    output = [],
		    /** `inputLength` will hold the number of code points in `input`. */
		    inputLength,
		    /** Cached calculation results */
		    handledCPCountPlusOne,
		    baseMinusT,
		    qMinusT;

		// Convert the input in UCS-2 to Unicode
		input = ucs2decode(input);

		// Cache the length
		inputLength = input.length;

		// Initialize the state
		n = initialN;
		delta = 0;
		bias = initialBias;

		// Handle the basic code points
		for (j = 0; j < inputLength; ++j) {
			currentValue = input[j];
			if (currentValue < 0x80) {
				output.push(stringFromCharCode(currentValue));
			}
		}

		handledCPCount = basicLength = output.length;

		// `handledCPCount` is the number of code points that have been handled;
		// `basicLength` is the number of basic code points.

		// Finish the basic string - if it is not empty - with a delimiter
		if (basicLength) {
			output.push(delimiter);
		}

		// Main encoding loop:
		while (handledCPCount < inputLength) {

			// All non-basic code points < n have been handled already. Find the next
			// larger one:
			for (m = maxInt, j = 0; j < inputLength; ++j) {
				currentValue = input[j];
				if (currentValue >= n && currentValue < m) {
					m = currentValue;
				}
			}

			// Increase `delta` enough to advance the decoder's <n,i> state to <m,0>,
			// but guard against overflow
			handledCPCountPlusOne = handledCPCount + 1;
			if (m - n > floor((maxInt - delta) / handledCPCountPlusOne)) {
				error('overflow');
			}

			delta += (m - n) * handledCPCountPlusOne;
			n = m;

			for (j = 0; j < inputLength; ++j) {
				currentValue = input[j];

				if (currentValue < n && ++delta > maxInt) {
					error('overflow');
				}

				if (currentValue == n) {
					// Represent delta as a generalized variable-length integer
					for (q = delta, k = base; /* no condition */; k += base) {
						t = k <= bias ? tMin : (k >= bias + tMax ? tMax : k - bias);
						if (q < t) {
							break;
						}
						qMinusT = q - t;
						baseMinusT = base - t;
						output.push(
							stringFromCharCode(digitToBasic(t + qMinusT % baseMinusT, 0))
						);
						q = floor(qMinusT / baseMinusT);
					}

					output.push(stringFromCharCode(digitToBasic(q, 0)));
					bias = adapt(delta, handledCPCountPlusOne, handledCPCount == basicLength);
					delta = 0;
					++handledCPCount;
				}
			}

			++delta;
			++n;

		}
		return output.join('');
	}

	/**
	 * Converts a Punycode string representing a domain name or an email address
	 * to Unicode. Only the Punycoded parts of the input will be converted, i.e.
	 * it doesn't matter if you call it on a string that has already been
	 * converted to Unicode.
	 * @memberOf punycode
	 * @param {String} input The Punycoded domain name or email address to
	 * convert to Unicode.
	 * @returns {String} The Unicode representation of the given Punycode
	 * string.
	 */
	function toUnicode(input) {
		return mapDomain(input, function(string) {
			return regexPunycode.test(string)
				? decode(string.slice(4).toLowerCase())
				: string;
		});
	}

	/**
	 * Converts a Unicode string representing a domain name or an email address to
	 * Punycode. Only the non-ASCII parts of the domain name will be converted,
	 * i.e. it doesn't matter if you call it with a domain that's already in
	 * ASCII.
	 * @memberOf punycode
	 * @param {String} input The domain name or email address to convert, as a
	 * Unicode string.
	 * @returns {String} The Punycode representation of the given domain name or
	 * email address.
	 */
	function toASCII(input) {
		return mapDomain(input, function(string) {
			return regexNonASCII.test(string)
				? 'xn--' + encode(string)
				: string;
		});
	}

	/*--------------------------------------------------------------------------*/

	/** Define the public API */
	punycode = {
		/**
		 * A string representing the current Punycode.js version number.
		 * @memberOf punycode
		 * @type String
		 */
		'version': '1.3.2',
		/**
		 * An object of methods to convert from JavaScript's internal character
		 * representation (UCS-2) to Unicode code points, and back.
		 * @see <https://mathiasbynens.be/notes/javascript-encoding>
		 * @memberOf punycode
		 * @type Object
		 */
		'ucs2': {
			'decode': ucs2decode,
			'encode': ucs2encode
		},
		'decode': decode,
		'encode': encode,
		'toASCII': toASCII,
		'toUnicode': toUnicode
	};

	/** Expose `punycode` */
	// Some AMD build optimizers, like r.js, check for specific condition patterns
	// like the following:
	if (
		typeof define == 'function' &&
		typeof define.amd == 'object' &&
		define.amd
	) {
		define('punycode', function() {
			return punycode;
		});
	} else if (freeExports && freeModule) {
		if (module.exports == freeExports) {
			// in Node.js, io.js, or RingoJS v0.8.0+
			freeModule.exports = punycode;
		} else {
			// in Narwhal or RingoJS v0.7.0-
			for (key in punycode) {
				punycode.hasOwnProperty(key) && (freeExports[key] = punycode[key]);
			}
		}
	} else {
		// in Rhino or a web browser
		root.punycode = punycode;
	}

}(this));

}).call(this,typeof global !== "undefined" ? global : typeof self !== "undefined" ? self : typeof window !== "undefined" ? window : {})

},{}],68:[function(require,module,exports){
// Copyright Joyent, Inc. and other Node contributors.
//
// Permission is hereby granted, free of charge, to any person obtaining a
// copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to permit
// persons to whom the Software is furnished to do so, subject to the
// following conditions:
//
// The above copyright notice and this permission notice shall be included
// in all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN
// NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
// DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR
// OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE
// USE OR OTHER DEALINGS IN THE SOFTWARE.

'use strict';

// If obj.hasOwnProperty has been overridden, then calling
// obj.hasOwnProperty(prop) will break.
// See: https://github.com/joyent/node/issues/1707
function hasOwnProperty(obj, prop) {
  return Object.prototype.hasOwnProperty.call(obj, prop);
}

module.exports = function(qs, sep, eq, options) {
  sep = sep || '&';
  eq = eq || '=';
  var obj = {};

  if (typeof qs !== 'string' || qs.length === 0) {
    return obj;
  }

  var regexp = /\+/g;
  qs = qs.split(sep);

  var maxKeys = 1000;
  if (options && typeof options.maxKeys === 'number') {
    maxKeys = options.maxKeys;
  }

  var len = qs.length;
  // maxKeys <= 0 means that we should not limit keys count
  if (maxKeys > 0 && len > maxKeys) {
    len = maxKeys;
  }

  for (var i = 0; i < len; ++i) {
    var x = qs[i].replace(regexp, '%20'),
        idx = x.indexOf(eq),
        kstr, vstr, k, v;

    if (idx >= 0) {
      kstr = x.substr(0, idx);
      vstr = x.substr(idx + 1);
    } else {
      kstr = x;
      vstr = '';
    }

    k = decodeURIComponent(kstr);
    v = decodeURIComponent(vstr);

    if (!hasOwnProperty(obj, k)) {
      obj[k] = v;
    } else if (isArray(obj[k])) {
      obj[k].push(v);
    } else {
      obj[k] = [obj[k], v];
    }
  }

  return obj;
};

var isArray = Array.isArray || function (xs) {
  return Object.prototype.toString.call(xs) === '[object Array]';
};

},{}],69:[function(require,module,exports){
// Copyright Joyent, Inc. and other Node contributors.
//
// Permission is hereby granted, free of charge, to any person obtaining a
// copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to permit
// persons to whom the Software is furnished to do so, subject to the
// following conditions:
//
// The above copyright notice and this permission notice shall be included
// in all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN
// NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
// DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR
// OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE
// USE OR OTHER DEALINGS IN THE SOFTWARE.

'use strict';

var stringifyPrimitive = function(v) {
  switch (typeof v) {
    case 'string':
      return v;

    case 'boolean':
      return v ? 'true' : 'false';

    case 'number':
      return isFinite(v) ? v : '';

    default:
      return '';
  }
};

module.exports = function(obj, sep, eq, name) {
  sep = sep || '&';
  eq = eq || '=';
  if (obj === null) {
    obj = undefined;
  }

  if (typeof obj === 'object') {
    return map(objectKeys(obj), function(k) {
      var ks = encodeURIComponent(stringifyPrimitive(k)) + eq;
      if (isArray(obj[k])) {
        return map(obj[k], function(v) {
          return ks + encodeURIComponent(stringifyPrimitive(v));
        }).join(sep);
      } else {
        return ks + encodeURIComponent(stringifyPrimitive(obj[k]));
      }
    }).join(sep);

  }

  if (!name) return '';
  return encodeURIComponent(stringifyPrimitive(name)) + eq +
         encodeURIComponent(stringifyPrimitive(obj));
};

var isArray = Array.isArray || function (xs) {
  return Object.prototype.toString.call(xs) === '[object Array]';
};

function map (xs, f) {
  if (xs.map) return xs.map(f);
  var res = [];
  for (var i = 0; i < xs.length; i++) {
    res.push(f(xs[i], i));
  }
  return res;
}

var objectKeys = Object.keys || function (obj) {
  var res = [];
  for (var key in obj) {
    if (Object.prototype.hasOwnProperty.call(obj, key)) res.push(key);
  }
  return res;
};

},{}],70:[function(require,module,exports){
'use strict';

exports.decode = exports.parse = require('./decode');
exports.encode = exports.stringify = require('./encode');

},{"./decode":68,"./encode":69}],71:[function(require,module,exports){
module.exports = require("./lib/_stream_duplex.js")

},{"./lib/_stream_duplex.js":72}],72:[function(require,module,exports){
// a duplex stream is just a stream that is both readable and writable.
// Since JS doesn't have multiple prototypal inheritance, this class
// prototypally inherits from Readable, and then parasitically from
// Writable.

'use strict';

/*<replacement>*/
var objectKeys = Object.keys || function (obj) {
  var keys = [];
  for (var key in obj) keys.push(key);
  return keys;
}
/*</replacement>*/


module.exports = Duplex;

/*<replacement>*/
var processNextTick = require('process-nextick-args');
/*</replacement>*/



/*<replacement>*/
var util = require('core-util-is');
util.inherits = require('inherits');
/*</replacement>*/

var Readable = require('./_stream_readable');
var Writable = require('./_stream_writable');

util.inherits(Duplex, Readable);

var keys = objectKeys(Writable.prototype);
for (var v = 0; v < keys.length; v++) {
  var method = keys[v];
  if (!Duplex.prototype[method])
    Duplex.prototype[method] = Writable.prototype[method];
}

function Duplex(options) {
  if (!(this instanceof Duplex))
    return new Duplex(options);

  Readable.call(this, options);
  Writable.call(this, options);

  if (options && options.readable === false)
    this.readable = false;

  if (options && options.writable === false)
    this.writable = false;

  this.allowHalfOpen = true;
  if (options && options.allowHalfOpen === false)
    this.allowHalfOpen = false;

  this.once('end', onend);
}

// the no-half-open enforcer
function onend() {
  // if we allow half-open state, or if the writable side ended,
  // then we're ok.
  if (this.allowHalfOpen || this._writableState.ended)
    return;

  // no more data can be written.
  // But allow more writes to happen in this tick.
  processNextTick(onEndNT, this);
}

function onEndNT(self) {
  self.end();
}

function forEach (xs, f) {
  for (var i = 0, l = xs.length; i < l; i++) {
    f(xs[i], i);
  }
}

},{"./_stream_readable":74,"./_stream_writable":76,"core-util-is":77,"inherits":63,"process-nextick-args":78}],73:[function(require,module,exports){
// a passthrough stream.
// basically just the most minimal sort of Transform stream.
// Every written chunk gets output as-is.

'use strict';

module.exports = PassThrough;

var Transform = require('./_stream_transform');

/*<replacement>*/
var util = require('core-util-is');
util.inherits = require('inherits');
/*</replacement>*/

util.inherits(PassThrough, Transform);

function PassThrough(options) {
  if (!(this instanceof PassThrough))
    return new PassThrough(options);

  Transform.call(this, options);
}

PassThrough.prototype._transform = function(chunk, encoding, cb) {
  cb(null, chunk);
};

},{"./_stream_transform":75,"core-util-is":77,"inherits":63}],74:[function(require,module,exports){
(function (process){
'use strict';

module.exports = Readable;

/*<replacement>*/
var processNextTick = require('process-nextick-args');
/*</replacement>*/


/*<replacement>*/
var isArray = require('isarray');
/*</replacement>*/


/*<replacement>*/
var Buffer = require('buffer').Buffer;
/*</replacement>*/

Readable.ReadableState = ReadableState;

var EE = require('events');

/*<replacement>*/
var EElistenerCount = function(emitter, type) {
  return emitter.listeners(type).length;
};
/*</replacement>*/



/*<replacement>*/
var Stream;
(function (){try{
  Stream = require('st' + 'ream');
}catch(_){}finally{
  if (!Stream)
    Stream = require('events').EventEmitter;
}}())
/*</replacement>*/

var Buffer = require('buffer').Buffer;

/*<replacement>*/
var util = require('core-util-is');
util.inherits = require('inherits');
/*</replacement>*/



/*<replacement>*/
var debugUtil = require('util');
var debug;
if (debugUtil && debugUtil.debuglog) {
  debug = debugUtil.debuglog('stream');
} else {
  debug = function () {};
}
/*</replacement>*/

var StringDecoder;

util.inherits(Readable, Stream);

var Duplex;
function ReadableState(options, stream) {
  Duplex = Duplex || require('./_stream_duplex');

  options = options || {};

  // object stream flag. Used to make read(n) ignore n and to
  // make all the buffer merging and length checks go away
  this.objectMode = !!options.objectMode;

  if (stream instanceof Duplex)
    this.objectMode = this.objectMode || !!options.readableObjectMode;

  // the point at which it stops calling _read() to fill the buffer
  // Note: 0 is a valid value, means "don't call _read preemptively ever"
  var hwm = options.highWaterMark;
  var defaultHwm = this.objectMode ? 16 : 16 * 1024;
  this.highWaterMark = (hwm || hwm === 0) ? hwm : defaultHwm;

  // cast to ints.
  this.highWaterMark = ~~this.highWaterMark;

  this.buffer = [];
  this.length = 0;
  this.pipes = null;
  this.pipesCount = 0;
  this.flowing = null;
  this.ended = false;
  this.endEmitted = false;
  this.reading = false;

  // a flag to be able to tell if the onwrite cb is called immediately,
  // or on a later tick.  We set this to true at first, because any
  // actions that shouldn't happen until "later" should generally also
  // not happen before the first write call.
  this.sync = true;

  // whenever we return null, then we set a flag to say
  // that we're awaiting a 'readable' event emission.
  this.needReadable = false;
  this.emittedReadable = false;
  this.readableListening = false;

  // Crypto is kind of old and crusty.  Historically, its default string
  // encoding is 'binary' so we have to make this configurable.
  // Everything else in the universe uses 'utf8', though.
  this.defaultEncoding = options.defaultEncoding || 'utf8';

  // when piping, we only care about 'readable' events that happen
  // after read()ing all the bytes and not getting any pushback.
  this.ranOut = false;

  // the number of writers that are awaiting a drain event in .pipe()s
  this.awaitDrain = 0;

  // if true, a maybeReadMore has been scheduled
  this.readingMore = false;

  this.decoder = null;
  this.encoding = null;
  if (options.encoding) {
    if (!StringDecoder)
      StringDecoder = require('string_decoder/').StringDecoder;
    this.decoder = new StringDecoder(options.encoding);
    this.encoding = options.encoding;
  }
}

var Duplex;
function Readable(options) {
  Duplex = Duplex || require('./_stream_duplex');

  if (!(this instanceof Readable))
    return new Readable(options);

  this._readableState = new ReadableState(options, this);

  // legacy
  this.readable = true;

  if (options && typeof options.read === 'function')
    this._read = options.read;

  Stream.call(this);
}

// Manually shove something into the read() buffer.
// This returns true if the highWaterMark has not been hit yet,
// similar to how Writable.write() returns true if you should
// write() some more.
Readable.prototype.push = function(chunk, encoding) {
  var state = this._readableState;

  if (!state.objectMode && typeof chunk === 'string') {
    encoding = encoding || state.defaultEncoding;
    if (encoding !== state.encoding) {
      chunk = new Buffer(chunk, encoding);
      encoding = '';
    }
  }

  return readableAddChunk(this, state, chunk, encoding, false);
};

// Unshift should *always* be something directly out of read()
Readable.prototype.unshift = function(chunk) {
  var state = this._readableState;
  return readableAddChunk(this, state, chunk, '', true);
};

Readable.prototype.isPaused = function() {
  return this._readableState.flowing === false;
};

function readableAddChunk(stream, state, chunk, encoding, addToFront) {
  var er = chunkInvalid(state, chunk);
  if (er) {
    stream.emit('error', er);
  } else if (chunk === null) {
    state.reading = false;
    onEofChunk(stream, state);
  } else if (state.objectMode || chunk && chunk.length > 0) {
    if (state.ended && !addToFront) {
      var e = new Error('stream.push() after EOF');
      stream.emit('error', e);
    } else if (state.endEmitted && addToFront) {
      var e = new Error('stream.unshift() after end event');
      stream.emit('error', e);
    } else {
      if (state.decoder && !addToFront && !encoding)
        chunk = state.decoder.write(chunk);

      if (!addToFront)
        state.reading = false;

      // if we want the data now, just emit it.
      if (state.flowing && state.length === 0 && !state.sync) {
        stream.emit('data', chunk);
        stream.read(0);
      } else {
        // update the buffer info.
        state.length += state.objectMode ? 1 : chunk.length;
        if (addToFront)
          state.buffer.unshift(chunk);
        else
          state.buffer.push(chunk);

        if (state.needReadable)
          emitReadable(stream);
      }

      maybeReadMore(stream, state);
    }
  } else if (!addToFront) {
    state.reading = false;
  }

  return needMoreData(state);
}


// if it's past the high water mark, we can push in some more.
// Also, if we have no data yet, we can stand some
// more bytes.  This is to work around cases where hwm=0,
// such as the repl.  Also, if the push() triggered a
// readable event, and the user called read(largeNumber) such that
// needReadable was set, then we ought to push more, so that another
// 'readable' event will be triggered.
function needMoreData(state) {
  return !state.ended &&
         (state.needReadable ||
          state.length < state.highWaterMark ||
          state.length === 0);
}

// backwards compatibility.
Readable.prototype.setEncoding = function(enc) {
  if (!StringDecoder)
    StringDecoder = require('string_decoder/').StringDecoder;
  this._readableState.decoder = new StringDecoder(enc);
  this._readableState.encoding = enc;
  return this;
};

// Don't raise the hwm > 8MB
var MAX_HWM = 0x800000;
function computeNewHighWaterMark(n) {
  if (n >= MAX_HWM) {
    n = MAX_HWM;
  } else {
    // Get the next highest power of 2
    n--;
    n |= n >>> 1;
    n |= n >>> 2;
    n |= n >>> 4;
    n |= n >>> 8;
    n |= n >>> 16;
    n++;
  }
  return n;
}

function howMuchToRead(n, state) {
  if (state.length === 0 && state.ended)
    return 0;

  if (state.objectMode)
    return n === 0 ? 0 : 1;

  if (n === null || isNaN(n)) {
    // only flow one buffer at a time
    if (state.flowing && state.buffer.length)
      return state.buffer[0].length;
    else
      return state.length;
  }

  if (n <= 0)
    return 0;

  // If we're asking for more than the target buffer level,
  // then raise the water mark.  Bump up to the next highest
  // power of 2, to prevent increasing it excessively in tiny
  // amounts.
  if (n > state.highWaterMark)
    state.highWaterMark = computeNewHighWaterMark(n);

  // don't have that much.  return null, unless we've ended.
  if (n > state.length) {
    if (!state.ended) {
      state.needReadable = true;
      return 0;
    } else {
      return state.length;
    }
  }

  return n;
}

// you can override either this method, or the async _read(n) below.
Readable.prototype.read = function(n) {
  debug('read', n);
  var state = this._readableState;
  var nOrig = n;

  if (typeof n !== 'number' || n > 0)
    state.emittedReadable = false;

  // if we're doing read(0) to trigger a readable event, but we
  // already have a bunch of data in the buffer, then just trigger
  // the 'readable' event and move on.
  if (n === 0 &&
      state.needReadable &&
      (state.length >= state.highWaterMark || state.ended)) {
    debug('read: emitReadable', state.length, state.ended);
    if (state.length === 0 && state.ended)
      endReadable(this);
    else
      emitReadable(this);
    return null;
  }

  n = howMuchToRead(n, state);

  // if we've ended, and we're now clear, then finish it up.
  if (n === 0 && state.ended) {
    if (state.length === 0)
      endReadable(this);
    return null;
  }

  // All the actual chunk generation logic needs to be
  // *below* the call to _read.  The reason is that in certain
  // synthetic stream cases, such as passthrough streams, _read
  // may be a completely synchronous operation which may change
  // the state of the read buffer, providing enough data when
  // before there was *not* enough.
  //
  // So, the steps are:
  // 1. Figure out what the state of things will be after we do
  // a read from the buffer.
  //
  // 2. If that resulting state will trigger a _read, then call _read.
  // Note that this may be asynchronous, or synchronous.  Yes, it is
  // deeply ugly to write APIs this way, but that still doesn't mean
  // that the Readable class should behave improperly, as streams are
  // designed to be sync/async agnostic.
  // Take note if the _read call is sync or async (ie, if the read call
  // has returned yet), so that we know whether or not it's safe to emit
  // 'readable' etc.
  //
  // 3. Actually pull the requested chunks out of the buffer and return.

  // if we need a readable event, then we need to do some reading.
  var doRead = state.needReadable;
  debug('need readable', doRead);

  // if we currently have less than the highWaterMark, then also read some
  if (state.length === 0 || state.length - n < state.highWaterMark) {
    doRead = true;
    debug('length less than watermark', doRead);
  }

  // however, if we've ended, then there's no point, and if we're already
  // reading, then it's unnecessary.
  if (state.ended || state.reading) {
    doRead = false;
    debug('reading or ended', doRead);
  }

  if (doRead) {
    debug('do read');
    state.reading = true;
    state.sync = true;
    // if the length is currently zero, then we *need* a readable event.
    if (state.length === 0)
      state.needReadable = true;
    // call internal read method
    this._read(state.highWaterMark);
    state.sync = false;
  }

  // If _read pushed data synchronously, then `reading` will be false,
  // and we need to re-evaluate how much data we can return to the user.
  if (doRead && !state.reading)
    n = howMuchToRead(nOrig, state);

  var ret;
  if (n > 0)
    ret = fromList(n, state);
  else
    ret = null;

  if (ret === null) {
    state.needReadable = true;
    n = 0;
  }

  state.length -= n;

  // If we have nothing in the buffer, then we want to know
  // as soon as we *do* get something into the buffer.
  if (state.length === 0 && !state.ended)
    state.needReadable = true;

  // If we tried to read() past the EOF, then emit end on the next tick.
  if (nOrig !== n && state.ended && state.length === 0)
    endReadable(this);

  if (ret !== null)
    this.emit('data', ret);

  return ret;
};

function chunkInvalid(state, chunk) {
  var er = null;
  if (!(Buffer.isBuffer(chunk)) &&
      typeof chunk !== 'string' &&
      chunk !== null &&
      chunk !== undefined &&
      !state.objectMode) {
    er = new TypeError('Invalid non-string/buffer chunk');
  }
  return er;
}


function onEofChunk(stream, state) {
  if (state.ended) return;
  if (state.decoder) {
    var chunk = state.decoder.end();
    if (chunk && chunk.length) {
      state.buffer.push(chunk);
      state.length += state.objectMode ? 1 : chunk.length;
    }
  }
  state.ended = true;

  // emit 'readable' now to make sure it gets picked up.
  emitReadable(stream);
}

// Don't emit readable right away in sync mode, because this can trigger
// another read() call => stack overflow.  This way, it might trigger
// a nextTick recursion warning, but that's not so bad.
function emitReadable(stream) {
  var state = stream._readableState;
  state.needReadable = false;
  if (!state.emittedReadable) {
    debug('emitReadable', state.flowing);
    state.emittedReadable = true;
    if (state.sync)
      processNextTick(emitReadable_, stream);
    else
      emitReadable_(stream);
  }
}

function emitReadable_(stream) {
  debug('emit readable');
  stream.emit('readable');
  flow(stream);
}


// at this point, the user has presumably seen the 'readable' event,
// and called read() to consume some data.  that may have triggered
// in turn another _read(n) call, in which case reading = true if
// it's in progress.
// However, if we're not ended, or reading, and the length < hwm,
// then go ahead and try to read some more preemptively.
function maybeReadMore(stream, state) {
  if (!state.readingMore) {
    state.readingMore = true;
    processNextTick(maybeReadMore_, stream, state);
  }
}

function maybeReadMore_(stream, state) {
  var len = state.length;
  while (!state.reading && !state.flowing && !state.ended &&
         state.length < state.highWaterMark) {
    debug('maybeReadMore read 0');
    stream.read(0);
    if (len === state.length)
      // didn't get any data, stop spinning.
      break;
    else
      len = state.length;
  }
  state.readingMore = false;
}

// abstract method.  to be overridden in specific implementation classes.
// call cb(er, data) where data is <= n in length.
// for virtual (non-string, non-buffer) streams, "length" is somewhat
// arbitrary, and perhaps not very meaningful.
Readable.prototype._read = function(n) {
  this.emit('error', new Error('not implemented'));
};

Readable.prototype.pipe = function(dest, pipeOpts) {
  var src = this;
  var state = this._readableState;

  switch (state.pipesCount) {
    case 0:
      state.pipes = dest;
      break;
    case 1:
      state.pipes = [state.pipes, dest];
      break;
    default:
      state.pipes.push(dest);
      break;
  }
  state.pipesCount += 1;
  debug('pipe count=%d opts=%j', state.pipesCount, pipeOpts);

  var doEnd = (!pipeOpts || pipeOpts.end !== false) &&
              dest !== process.stdout &&
              dest !== process.stderr;

  var endFn = doEnd ? onend : cleanup;
  if (state.endEmitted)
    processNextTick(endFn);
  else
    src.once('end', endFn);

  dest.on('unpipe', onunpipe);
  function onunpipe(readable) {
    debug('onunpipe');
    if (readable === src) {
      cleanup();
    }
  }

  function onend() {
    debug('onend');
    dest.end();
  }

  // when the dest drains, it reduces the awaitDrain counter
  // on the source.  This would be more elegant with a .once()
  // handler in flow(), but adding and removing repeatedly is
  // too slow.
  var ondrain = pipeOnDrain(src);
  dest.on('drain', ondrain);

  var cleanedUp = false;
  function cleanup() {
    debug('cleanup');
    // cleanup event handlers once the pipe is broken
    dest.removeListener('close', onclose);
    dest.removeListener('finish', onfinish);
    dest.removeListener('drain', ondrain);
    dest.removeListener('error', onerror);
    dest.removeListener('unpipe', onunpipe);
    src.removeListener('end', onend);
    src.removeListener('end', cleanup);
    src.removeListener('data', ondata);

    cleanedUp = true;

    // if the reader is waiting for a drain event from this
    // specific writer, then it would cause it to never start
    // flowing again.
    // So, if this is awaiting a drain, then we just call it now.
    // If we don't know, then assume that we are waiting for one.
    if (state.awaitDrain &&
        (!dest._writableState || dest._writableState.needDrain))
      ondrain();
  }

  src.on('data', ondata);
  function ondata(chunk) {
    debug('ondata');
    var ret = dest.write(chunk);
    if (false === ret) {
      // If the user unpiped during `dest.write()`, it is possible
      // to get stuck in a permanently paused state if that write
      // also returned false.
      if (state.pipesCount === 1 &&
          state.pipes[0] === dest &&
          src.listenerCount('data') === 1 &&
          !cleanedUp) {
        debug('false write response, pause', src._readableState.awaitDrain);
        src._readableState.awaitDrain++;
      }
      src.pause();
    }
  }

  // if the dest has an error, then stop piping into it.
  // however, don't suppress the throwing behavior for this.
  function onerror(er) {
    debug('onerror', er);
    unpipe();
    dest.removeListener('error', onerror);
    if (EElistenerCount(dest, 'error') === 0)
      dest.emit('error', er);
  }
  // This is a brutally ugly hack to make sure that our error handler
  // is attached before any userland ones.  NEVER DO THIS.
  if (!dest._events || !dest._events.error)
    dest.on('error', onerror);
  else if (isArray(dest._events.error))
    dest._events.error.unshift(onerror);
  else
    dest._events.error = [onerror, dest._events.error];


  // Both close and finish should trigger unpipe, but only once.
  function onclose() {
    dest.removeListener('finish', onfinish);
    unpipe();
  }
  dest.once('close', onclose);
  function onfinish() {
    debug('onfinish');
    dest.removeListener('close', onclose);
    unpipe();
  }
  dest.once('finish', onfinish);

  function unpipe() {
    debug('unpipe');
    src.unpipe(dest);
  }

  // tell the dest that it's being piped to
  dest.emit('pipe', src);

  // start the flow if it hasn't been started already.
  if (!state.flowing) {
    debug('pipe resume');
    src.resume();
  }

  return dest;
};

function pipeOnDrain(src) {
  return function() {
    var state = src._readableState;
    debug('pipeOnDrain', state.awaitDrain);
    if (state.awaitDrain)
      state.awaitDrain--;
    if (state.awaitDrain === 0 && EElistenerCount(src, 'data')) {
      state.flowing = true;
      flow(src);
    }
  };
}


Readable.prototype.unpipe = function(dest) {
  var state = this._readableState;

  // if we're not piping anywhere, then do nothing.
  if (state.pipesCount === 0)
    return this;

  // just one destination.  most common case.
  if (state.pipesCount === 1) {
    // passed in one, but it's not the right one.
    if (dest && dest !== state.pipes)
      return this;

    if (!dest)
      dest = state.pipes;

    // got a match.
    state.pipes = null;
    state.pipesCount = 0;
    state.flowing = false;
    if (dest)
      dest.emit('unpipe', this);
    return this;
  }

  // slow case. multiple pipe destinations.

  if (!dest) {
    // remove all.
    var dests = state.pipes;
    var len = state.pipesCount;
    state.pipes = null;
    state.pipesCount = 0;
    state.flowing = false;

    for (var i = 0; i < len; i++)
      dests[i].emit('unpipe', this);
    return this;
  }

  // try to find the right one.
  var i = indexOf(state.pipes, dest);
  if (i === -1)
    return this;

  state.pipes.splice(i, 1);
  state.pipesCount -= 1;
  if (state.pipesCount === 1)
    state.pipes = state.pipes[0];

  dest.emit('unpipe', this);

  return this;
};

// set up data events if they are asked for
// Ensure readable listeners eventually get something
Readable.prototype.on = function(ev, fn) {
  var res = Stream.prototype.on.call(this, ev, fn);

  // If listening to data, and it has not explicitly been paused,
  // then call resume to start the flow of data on the next tick.
  if (ev === 'data' && false !== this._readableState.flowing) {
    this.resume();
  }

  if (ev === 'readable' && this.readable) {
    var state = this._readableState;
    if (!state.readableListening) {
      state.readableListening = true;
      state.emittedReadable = false;
      state.needReadable = true;
      if (!state.reading) {
        processNextTick(nReadingNextTick, this);
      } else if (state.length) {
        emitReadable(this, state);
      }
    }
  }

  return res;
};
Readable.prototype.addListener = Readable.prototype.on;

function nReadingNextTick(self) {
  debug('readable nexttick read 0');
  self.read(0);
}

// pause() and resume() are remnants of the legacy readable stream API
// If the user uses them, then switch into old mode.
Readable.prototype.resume = function() {
  var state = this._readableState;
  if (!state.flowing) {
    debug('resume');
    state.flowing = true;
    resume(this, state);
  }
  return this;
};

function resume(stream, state) {
  if (!state.resumeScheduled) {
    state.resumeScheduled = true;
    processNextTick(resume_, stream, state);
  }
}

function resume_(stream, state) {
  if (!state.reading) {
    debug('resume read 0');
    stream.read(0);
  }

  state.resumeScheduled = false;
  stream.emit('resume');
  flow(stream);
  if (state.flowing && !state.reading)
    stream.read(0);
}

Readable.prototype.pause = function() {
  debug('call pause flowing=%j', this._readableState.flowing);
  if (false !== this._readableState.flowing) {
    debug('pause');
    this._readableState.flowing = false;
    this.emit('pause');
  }
  return this;
};

function flow(stream) {
  var state = stream._readableState;
  debug('flow', state.flowing);
  if (state.flowing) {
    do {
      var chunk = stream.read();
    } while (null !== chunk && state.flowing);
  }
}

// wrap an old-style stream as the async data source.
// This is *not* part of the readable stream interface.
// It is an ugly unfortunate mess of history.
Readable.prototype.wrap = function(stream) {
  var state = this._readableState;
  var paused = false;

  var self = this;
  stream.on('end', function() {
    debug('wrapped end');
    if (state.decoder && !state.ended) {
      var chunk = state.decoder.end();
      if (chunk && chunk.length)
        self.push(chunk);
    }

    self.push(null);
  });

  stream.on('data', function(chunk) {
    debug('wrapped data');
    if (state.decoder)
      chunk = state.decoder.write(chunk);

    // don't skip over falsy values in objectMode
    if (state.objectMode && (chunk === null || chunk === undefined))
      return;
    else if (!state.objectMode && (!chunk || !chunk.length))
      return;

    var ret = self.push(chunk);
    if (!ret) {
      paused = true;
      stream.pause();
    }
  });

  // proxy all the other methods.
  // important when wrapping filters and duplexes.
  for (var i in stream) {
    if (this[i] === undefined && typeof stream[i] === 'function') {
      this[i] = function(method) { return function() {
        return stream[method].apply(stream, arguments);
      }; }(i);
    }
  }

  // proxy certain important events.
  var events = ['error', 'close', 'destroy', 'pause', 'resume'];
  forEach(events, function(ev) {
    stream.on(ev, self.emit.bind(self, ev));
  });

  // when we try to consume some more bytes, simply unpause the
  // underlying stream.
  self._read = function(n) {
    debug('wrapped _read', n);
    if (paused) {
      paused = false;
      stream.resume();
    }
  };

  return self;
};


// exposed for testing purposes only.
Readable._fromList = fromList;

// Pluck off n bytes from an array of buffers.
// Length is the combined lengths of all the buffers in the list.
function fromList(n, state) {
  var list = state.buffer;
  var length = state.length;
  var stringMode = !!state.decoder;
  var objectMode = !!state.objectMode;
  var ret;

  // nothing in the list, definitely empty.
  if (list.length === 0)
    return null;

  if (length === 0)
    ret = null;
  else if (objectMode)
    ret = list.shift();
  else if (!n || n >= length) {
    // read it all, truncate the array.
    if (stringMode)
      ret = list.join('');
    else if (list.length === 1)
      ret = list[0];
    else
      ret = Buffer.concat(list, length);
    list.length = 0;
  } else {
    // read just some of it.
    if (n < list[0].length) {
      // just take a part of the first list item.
      // slice is the same for buffers and strings.
      var buf = list[0];
      ret = buf.slice(0, n);
      list[0] = buf.slice(n);
    } else if (n === list[0].length) {
      // first list is a perfect match
      ret = list.shift();
    } else {
      // complex case.
      // we have enough to cover it, but it spans past the first buffer.
      if (stringMode)
        ret = '';
      else
        ret = new Buffer(n);

      var c = 0;
      for (var i = 0, l = list.length; i < l && c < n; i++) {
        var buf = list[0];
        var cpy = Math.min(n - c, buf.length);

        if (stringMode)
          ret += buf.slice(0, cpy);
        else
          buf.copy(ret, c, 0, cpy);

        if (cpy < buf.length)
          list[0] = buf.slice(cpy);
        else
          list.shift();

        c += cpy;
      }
    }
  }

  return ret;
}

function endReadable(stream) {
  var state = stream._readableState;

  // If we get here before consuming all the bytes, then that is a
  // bug in node.  Should never happen.
  if (state.length > 0)
    throw new Error('endReadable called on non-empty stream');

  if (!state.endEmitted) {
    state.ended = true;
    processNextTick(endReadableNT, state, stream);
  }
}

function endReadableNT(state, stream) {
  // Check that we didn't get one last unshift.
  if (!state.endEmitted && state.length === 0) {
    state.endEmitted = true;
    stream.readable = false;
    stream.emit('end');
  }
}

function forEach (xs, f) {
  for (var i = 0, l = xs.length; i < l; i++) {
    f(xs[i], i);
  }
}

function indexOf (xs, x) {
  for (var i = 0, l = xs.length; i < l; i++) {
    if (xs[i] === x) return i;
  }
  return -1;
}

}).call(this,require('_process'))

},{"./_stream_duplex":72,"_process":66,"buffer":57,"core-util-is":77,"events":61,"inherits":63,"isarray":65,"process-nextick-args":78,"string_decoder/":90,"util":56}],75:[function(require,module,exports){
// a transform stream is a readable/writable stream where you do
// something with the data.  Sometimes it's called a "filter",
// but that's not a great name for it, since that implies a thing where
// some bits pass through, and others are simply ignored.  (That would
// be a valid example of a transform, of course.)
//
// While the output is causally related to the input, it's not a
// necessarily symmetric or synchronous transformation.  For example,
// a zlib stream might take multiple plain-text writes(), and then
// emit a single compressed chunk some time in the future.
//
// Here's how this works:
//
// The Transform stream has all the aspects of the readable and writable
// stream classes.  When you write(chunk), that calls _write(chunk,cb)
// internally, and returns false if there's a lot of pending writes
// buffered up.  When you call read(), that calls _read(n) until
// there's enough pending readable data buffered up.
//
// In a transform stream, the written data is placed in a buffer.  When
// _read(n) is called, it transforms the queued up data, calling the
// buffered _write cb's as it consumes chunks.  If consuming a single
// written chunk would result in multiple output chunks, then the first
// outputted bit calls the readcb, and subsequent chunks just go into
// the read buffer, and will cause it to emit 'readable' if necessary.
//
// This way, back-pressure is actually determined by the reading side,
// since _read has to be called to start processing a new chunk.  However,
// a pathological inflate type of transform can cause excessive buffering
// here.  For example, imagine a stream where every byte of input is
// interpreted as an integer from 0-255, and then results in that many
// bytes of output.  Writing the 4 bytes {ff,ff,ff,ff} would result in
// 1kb of data being output.  In this case, you could write a very small
// amount of input, and end up with a very large amount of output.  In
// such a pathological inflating mechanism, there'd be no way to tell
// the system to stop doing the transform.  A single 4MB write could
// cause the system to run out of memory.
//
// However, even in such a pathological case, only a single written chunk
// would be consumed, and then the rest would wait (un-transformed) until
// the results of the previous transformed chunk were consumed.

'use strict';

module.exports = Transform;

var Duplex = require('./_stream_duplex');

/*<replacement>*/
var util = require('core-util-is');
util.inherits = require('inherits');
/*</replacement>*/

util.inherits(Transform, Duplex);


function TransformState(stream) {
  this.afterTransform = function(er, data) {
    return afterTransform(stream, er, data);
  };

  this.needTransform = false;
  this.transforming = false;
  this.writecb = null;
  this.writechunk = null;
}

function afterTransform(stream, er, data) {
  var ts = stream._transformState;
  ts.transforming = false;

  var cb = ts.writecb;

  if (!cb)
    return stream.emit('error', new Error('no writecb in Transform class'));

  ts.writechunk = null;
  ts.writecb = null;

  if (data !== null && data !== undefined)
    stream.push(data);

  if (cb)
    cb(er);

  var rs = stream._readableState;
  rs.reading = false;
  if (rs.needReadable || rs.length < rs.highWaterMark) {
    stream._read(rs.highWaterMark);
  }
}


function Transform(options) {
  if (!(this instanceof Transform))
    return new Transform(options);

  Duplex.call(this, options);

  this._transformState = new TransformState(this);

  // when the writable side finishes, then flush out anything remaining.
  var stream = this;

  // start out asking for a readable event once data is transformed.
  this._readableState.needReadable = true;

  // we have implemented the _read method, and done the other things
  // that Readable wants before the first _read call, so unset the
  // sync guard flag.
  this._readableState.sync = false;

  if (options) {
    if (typeof options.transform === 'function')
      this._transform = options.transform;

    if (typeof options.flush === 'function')
      this._flush = options.flush;
  }

  this.once('prefinish', function() {
    if (typeof this._flush === 'function')
      this._flush(function(er) {
        done(stream, er);
      });
    else
      done(stream);
  });
}

Transform.prototype.push = function(chunk, encoding) {
  this._transformState.needTransform = false;
  return Duplex.prototype.push.call(this, chunk, encoding);
};

// This is the part where you do stuff!
// override this function in implementation classes.
// 'chunk' is an input chunk.
//
// Call `push(newChunk)` to pass along transformed output
// to the readable side.  You may call 'push' zero or more times.
//
// Call `cb(err)` when you are done with this chunk.  If you pass
// an error, then that'll put the hurt on the whole operation.  If you
// never call cb(), then you'll never get another chunk.
Transform.prototype._transform = function(chunk, encoding, cb) {
  throw new Error('not implemented');
};

Transform.prototype._write = function(chunk, encoding, cb) {
  var ts = this._transformState;
  ts.writecb = cb;
  ts.writechunk = chunk;
  ts.writeencoding = encoding;
  if (!ts.transforming) {
    var rs = this._readableState;
    if (ts.needTransform ||
        rs.needReadable ||
        rs.length < rs.highWaterMark)
      this._read(rs.highWaterMark);
  }
};

// Doesn't matter what the args are here.
// _transform does all the work.
// That we got here means that the readable side wants more data.
Transform.prototype._read = function(n) {
  var ts = this._transformState;

  if (ts.writechunk !== null && ts.writecb && !ts.transforming) {
    ts.transforming = true;
    this._transform(ts.writechunk, ts.writeencoding, ts.afterTransform);
  } else {
    // mark that we need a transform, so that any data that comes in
    // will get processed, now that we've asked for it.
    ts.needTransform = true;
  }
};


function done(stream, er) {
  if (er)
    return stream.emit('error', er);

  // if there's nothing in the write buffer, then that means
  // that nothing more will ever be provided
  var ws = stream._writableState;
  var ts = stream._transformState;

  if (ws.length)
    throw new Error('calling transform done when ws.length != 0');

  if (ts.transforming)
    throw new Error('calling transform done when still transforming');

  return stream.push(null);
}

},{"./_stream_duplex":72,"core-util-is":77,"inherits":63}],76:[function(require,module,exports){
// A bit simpler than readable streams.
// Implement an async ._write(chunk, encoding, cb), and it'll handle all
// the drain event emission and buffering.

'use strict';

module.exports = Writable;

/*<replacement>*/
var processNextTick = require('process-nextick-args');
/*</replacement>*/


/*<replacement>*/
var Buffer = require('buffer').Buffer;
/*</replacement>*/

Writable.WritableState = WritableState;


/*<replacement>*/
var util = require('core-util-is');
util.inherits = require('inherits');
/*</replacement>*/


/*<replacement>*/
var internalUtil = {
  deprecate: require('util-deprecate')
};
/*</replacement>*/



/*<replacement>*/
var Stream;
(function (){try{
  Stream = require('st' + 'ream');
}catch(_){}finally{
  if (!Stream)
    Stream = require('events').EventEmitter;
}}())
/*</replacement>*/

var Buffer = require('buffer').Buffer;

util.inherits(Writable, Stream);

function nop() {}

function WriteReq(chunk, encoding, cb) {
  this.chunk = chunk;
  this.encoding = encoding;
  this.callback = cb;
  this.next = null;
}

var Duplex;
function WritableState(options, stream) {
  Duplex = Duplex || require('./_stream_duplex');

  options = options || {};

  // object stream flag to indicate whether or not this stream
  // contains buffers or objects.
  this.objectMode = !!options.objectMode;

  if (stream instanceof Duplex)
    this.objectMode = this.objectMode || !!options.writableObjectMode;

  // the point at which write() starts returning false
  // Note: 0 is a valid value, means that we always return false if
  // the entire buffer is not flushed immediately on write()
  var hwm = options.highWaterMark;
  var defaultHwm = this.objectMode ? 16 : 16 * 1024;
  this.highWaterMark = (hwm || hwm === 0) ? hwm : defaultHwm;

  // cast to ints.
  this.highWaterMark = ~~this.highWaterMark;

  this.needDrain = false;
  // at the start of calling end()
  this.ending = false;
  // when end() has been called, and returned
  this.ended = false;
  // when 'finish' is emitted
  this.finished = false;

  // should we decode strings into buffers before passing to _write?
  // this is here so that some node-core streams can optimize string
  // handling at a lower level.
  var noDecode = options.decodeStrings === false;
  this.decodeStrings = !noDecode;

  // Crypto is kind of old and crusty.  Historically, its default string
  // encoding is 'binary' so we have to make this configurable.
  // Everything else in the universe uses 'utf8', though.
  this.defaultEncoding = options.defaultEncoding || 'utf8';

  // not an actual buffer we keep track of, but a measurement
  // of how much we're waiting to get pushed to some underlying
  // socket or file.
  this.length = 0;

  // a flag to see when we're in the middle of a write.
  this.writing = false;

  // when true all writes will be buffered until .uncork() call
  this.corked = 0;

  // a flag to be able to tell if the onwrite cb is called immediately,
  // or on a later tick.  We set this to true at first, because any
  // actions that shouldn't happen until "later" should generally also
  // not happen before the first write call.
  this.sync = true;

  // a flag to know if we're processing previously buffered items, which
  // may call the _write() callback in the same tick, so that we don't
  // end up in an overlapped onwrite situation.
  this.bufferProcessing = false;

  // the callback that's passed to _write(chunk,cb)
  this.onwrite = function(er) {
    onwrite(stream, er);
  };

  // the callback that the user supplies to write(chunk,encoding,cb)
  this.writecb = null;

  // the amount that is being written when _write is called.
  this.writelen = 0;

  this.bufferedRequest = null;
  this.lastBufferedRequest = null;

  // number of pending user-supplied write callbacks
  // this must be 0 before 'finish' can be emitted
  this.pendingcb = 0;

  // emit prefinish if the only thing we're waiting for is _write cbs
  // This is relevant for synchronous Transform streams
  this.prefinished = false;

  // True if the error was already emitted and should not be thrown again
  this.errorEmitted = false;
}

WritableState.prototype.getBuffer = function writableStateGetBuffer() {
  var current = this.bufferedRequest;
  var out = [];
  while (current) {
    out.push(current);
    current = current.next;
  }
  return out;
};

(function (){try {
Object.defineProperty(WritableState.prototype, 'buffer', {
  get: internalUtil.deprecate(function() {
    return this.getBuffer();
  }, '_writableState.buffer is deprecated. Use _writableState.getBuffer ' +
     'instead.')
});
}catch(_){}}());


var Duplex;
function Writable(options) {
  Duplex = Duplex || require('./_stream_duplex');

  // Writable ctor is applied to Duplexes, though they're not
  // instanceof Writable, they're instanceof Readable.
  if (!(this instanceof Writable) && !(this instanceof Duplex))
    return new Writable(options);

  this._writableState = new WritableState(options, this);

  // legacy.
  this.writable = true;

  if (options) {
    if (typeof options.write === 'function')
      this._write = options.write;

    if (typeof options.writev === 'function')
      this._writev = options.writev;
  }

  Stream.call(this);
}

// Otherwise people can pipe Writable streams, which is just wrong.
Writable.prototype.pipe = function() {
  this.emit('error', new Error('Cannot pipe. Not readable.'));
};


function writeAfterEnd(stream, cb) {
  var er = new Error('write after end');
  // TODO: defer error events consistently everywhere, not just the cb
  stream.emit('error', er);
  processNextTick(cb, er);
}

// If we get something that is not a buffer, string, null, or undefined,
// and we're not in objectMode, then that's an error.
// Otherwise stream chunks are all considered to be of length=1, and the
// watermarks determine how many objects to keep in the buffer, rather than
// how many bytes or characters.
function validChunk(stream, state, chunk, cb) {
  var valid = true;

  if (!(Buffer.isBuffer(chunk)) &&
      typeof chunk !== 'string' &&
      chunk !== null &&
      chunk !== undefined &&
      !state.objectMode) {
    var er = new TypeError('Invalid non-string/buffer chunk');
    stream.emit('error', er);
    processNextTick(cb, er);
    valid = false;
  }
  return valid;
}

Writable.prototype.write = function(chunk, encoding, cb) {
  var state = this._writableState;
  var ret = false;

  if (typeof encoding === 'function') {
    cb = encoding;
    encoding = null;
  }

  if (Buffer.isBuffer(chunk))
    encoding = 'buffer';
  else if (!encoding)
    encoding = state.defaultEncoding;

  if (typeof cb !== 'function')
    cb = nop;

  if (state.ended)
    writeAfterEnd(this, cb);
  else if (validChunk(this, state, chunk, cb)) {
    state.pendingcb++;
    ret = writeOrBuffer(this, state, chunk, encoding, cb);
  }

  return ret;
};

Writable.prototype.cork = function() {
  var state = this._writableState;

  state.corked++;
};

Writable.prototype.uncork = function() {
  var state = this._writableState;

  if (state.corked) {
    state.corked--;

    if (!state.writing &&
        !state.corked &&
        !state.finished &&
        !state.bufferProcessing &&
        state.bufferedRequest)
      clearBuffer(this, state);
  }
};

Writable.prototype.setDefaultEncoding = function setDefaultEncoding(encoding) {
  // node::ParseEncoding() requires lower case.
  if (typeof encoding === 'string')
    encoding = encoding.toLowerCase();
  if (!(['hex', 'utf8', 'utf-8', 'ascii', 'binary', 'base64',
'ucs2', 'ucs-2','utf16le', 'utf-16le', 'raw']
.indexOf((encoding + '').toLowerCase()) > -1))
    throw new TypeError('Unknown encoding: ' + encoding);
  this._writableState.defaultEncoding = encoding;
};

function decodeChunk(state, chunk, encoding) {
  if (!state.objectMode &&
      state.decodeStrings !== false &&
      typeof chunk === 'string') {
    chunk = new Buffer(chunk, encoding);
  }
  return chunk;
}

// if we're already writing something, then just put this
// in the queue, and wait our turn.  Otherwise, call _write
// If we return false, then we need a drain event, so set that flag.
function writeOrBuffer(stream, state, chunk, encoding, cb) {
  chunk = decodeChunk(state, chunk, encoding);

  if (Buffer.isBuffer(chunk))
    encoding = 'buffer';
  var len = state.objectMode ? 1 : chunk.length;

  state.length += len;

  var ret = state.length < state.highWaterMark;
  // we must ensure that previous needDrain will not be reset to false.
  if (!ret)
    state.needDrain = true;

  if (state.writing || state.corked) {
    var last = state.lastBufferedRequest;
    state.lastBufferedRequest = new WriteReq(chunk, encoding, cb);
    if (last) {
      last.next = state.lastBufferedRequest;
    } else {
      state.bufferedRequest = state.lastBufferedRequest;
    }
  } else {
    doWrite(stream, state, false, len, chunk, encoding, cb);
  }

  return ret;
}

function doWrite(stream, state, writev, len, chunk, encoding, cb) {
  state.writelen = len;
  state.writecb = cb;
  state.writing = true;
  state.sync = true;
  if (writev)
    stream._writev(chunk, state.onwrite);
  else
    stream._write(chunk, encoding, state.onwrite);
  state.sync = false;
}

function onwriteError(stream, state, sync, er, cb) {
  --state.pendingcb;
  if (sync)
    processNextTick(cb, er);
  else
    cb(er);

  stream._writableState.errorEmitted = true;
  stream.emit('error', er);
}

function onwriteStateUpdate(state) {
  state.writing = false;
  state.writecb = null;
  state.length -= state.writelen;
  state.writelen = 0;
}

function onwrite(stream, er) {
  var state = stream._writableState;
  var sync = state.sync;
  var cb = state.writecb;

  onwriteStateUpdate(state);

  if (er)
    onwriteError(stream, state, sync, er, cb);
  else {
    // Check if we're actually ready to finish, but don't emit yet
    var finished = needFinish(state);

    if (!finished &&
        !state.corked &&
        !state.bufferProcessing &&
        state.bufferedRequest) {
      clearBuffer(stream, state);
    }

    if (sync) {
      processNextTick(afterWrite, stream, state, finished, cb);
    } else {
      afterWrite(stream, state, finished, cb);
    }
  }
}

function afterWrite(stream, state, finished, cb) {
  if (!finished)
    onwriteDrain(stream, state);
  state.pendingcb--;
  cb();
  finishMaybe(stream, state);
}

// Must force callback to be called on nextTick, so that we don't
// emit 'drain' before the write() consumer gets the 'false' return
// value, and has a chance to attach a 'drain' listener.
function onwriteDrain(stream, state) {
  if (state.length === 0 && state.needDrain) {
    state.needDrain = false;
    stream.emit('drain');
  }
}


// if there's something in the buffer waiting, then process it
function clearBuffer(stream, state) {
  state.bufferProcessing = true;
  var entry = state.bufferedRequest;

  if (stream._writev && entry && entry.next) {
    // Fast case, write everything using _writev()
    var buffer = [];
    var cbs = [];
    while (entry) {
      cbs.push(entry.callback);
      buffer.push(entry);
      entry = entry.next;
    }

    // count the one we are adding, as well.
    // TODO(isaacs) clean this up
    state.pendingcb++;
    state.lastBufferedRequest = null;
    doWrite(stream, state, true, state.length, buffer, '', function(err) {
      for (var i = 0; i < cbs.length; i++) {
        state.pendingcb--;
        cbs[i](err);
      }
    });

    // Clear buffer
  } else {
    // Slow case, write chunks one-by-one
    while (entry) {
      var chunk = entry.chunk;
      var encoding = entry.encoding;
      var cb = entry.callback;
      var len = state.objectMode ? 1 : chunk.length;

      doWrite(stream, state, false, len, chunk, encoding, cb);
      entry = entry.next;
      // if we didn't call the onwrite immediately, then
      // it means that we need to wait until it does.
      // also, that means that the chunk and cb are currently
      // being processed, so move the buffer counter past them.
      if (state.writing) {
        break;
      }
    }

    if (entry === null)
      state.lastBufferedRequest = null;
  }
  state.bufferedRequest = entry;
  state.bufferProcessing = false;
}

Writable.prototype._write = function(chunk, encoding, cb) {
  cb(new Error('not implemented'));
};

Writable.prototype._writev = null;

Writable.prototype.end = function(chunk, encoding, cb) {
  var state = this._writableState;

  if (typeof chunk === 'function') {
    cb = chunk;
    chunk = null;
    encoding = null;
  } else if (typeof encoding === 'function') {
    cb = encoding;
    encoding = null;
  }

  if (chunk !== null && chunk !== undefined)
    this.write(chunk, encoding);

  // .end() fully uncorks
  if (state.corked) {
    state.corked = 1;
    this.uncork();
  }

  // ignore unnecessary end() calls.
  if (!state.ending && !state.finished)
    endWritable(this, state, cb);
};


function needFinish(state) {
  return (state.ending &&
          state.length === 0 &&
          state.bufferedRequest === null &&
          !state.finished &&
          !state.writing);
}

function prefinish(stream, state) {
  if (!state.prefinished) {
    state.prefinished = true;
    stream.emit('prefinish');
  }
}

function finishMaybe(stream, state) {
  var need = needFinish(state);
  if (need) {
    if (state.pendingcb === 0) {
      prefinish(stream, state);
      state.finished = true;
      stream.emit('finish');
    } else {
      prefinish(stream, state);
    }
  }
  return need;
}

function endWritable(stream, state, cb) {
  state.ending = true;
  finishMaybe(stream, state);
  if (cb) {
    if (state.finished)
      processNextTick(cb);
    else
      stream.once('finish', cb);
  }
  state.ended = true;
}

},{"./_stream_duplex":72,"buffer":57,"core-util-is":77,"events":61,"inherits":63,"process-nextick-args":78,"util-deprecate":79}],77:[function(require,module,exports){
(function (Buffer){
// Copyright Joyent, Inc. and other Node contributors.
//
// Permission is hereby granted, free of charge, to any person obtaining a
// copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to permit
// persons to whom the Software is furnished to do so, subject to the
// following conditions:
//
// The above copyright notice and this permission notice shall be included
// in all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN
// NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
// DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR
// OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE
// USE OR OTHER DEALINGS IN THE SOFTWARE.

// NOTE: These type checking functions intentionally don't use `instanceof`
// because it is fragile and can be easily faked with `Object.create()`.

function isArray(arg) {
  if (Array.isArray) {
    return Array.isArray(arg);
  }
  return objectToString(arg) === '[object Array]';
}
exports.isArray = isArray;

function isBoolean(arg) {
  return typeof arg === 'boolean';
}
exports.isBoolean = isBoolean;

function isNull(arg) {
  return arg === null;
}
exports.isNull = isNull;

function isNullOrUndefined(arg) {
  return arg == null;
}
exports.isNullOrUndefined = isNullOrUndefined;

function isNumber(arg) {
  return typeof arg === 'number';
}
exports.isNumber = isNumber;

function isString(arg) {
  return typeof arg === 'string';
}
exports.isString = isString;

function isSymbol(arg) {
  return typeof arg === 'symbol';
}
exports.isSymbol = isSymbol;

function isUndefined(arg) {
  return arg === void 0;
}
exports.isUndefined = isUndefined;

function isRegExp(re) {
  return objectToString(re) === '[object RegExp]';
}
exports.isRegExp = isRegExp;

function isObject(arg) {
  return typeof arg === 'object' && arg !== null;
}
exports.isObject = isObject;

function isDate(d) {
  return objectToString(d) === '[object Date]';
}
exports.isDate = isDate;

function isError(e) {
  return (objectToString(e) === '[object Error]' || e instanceof Error);
}
exports.isError = isError;

function isFunction(arg) {
  return typeof arg === 'function';
}
exports.isFunction = isFunction;

function isPrimitive(arg) {
  return arg === null ||
         typeof arg === 'boolean' ||
         typeof arg === 'number' ||
         typeof arg === 'string' ||
         typeof arg === 'symbol' ||  // ES6 symbol
         typeof arg === 'undefined';
}
exports.isPrimitive = isPrimitive;

exports.isBuffer = Buffer.isBuffer;

function objectToString(o) {
  return Object.prototype.toString.call(o);
}

}).call(this,{"isBuffer":require("../../../../insert-module-globals/node_modules/is-buffer/index.js")})

},{"../../../../insert-module-globals/node_modules/is-buffer/index.js":64}],78:[function(require,module,exports){
(function (process){
'use strict';

if (!process.version ||
    process.version.indexOf('v0.') === 0 ||
    process.version.indexOf('v1.') === 0 && process.version.indexOf('v1.8.') !== 0) {
  module.exports = nextTick;
} else {
  module.exports = process.nextTick;
}

function nextTick(fn) {
  var args = new Array(arguments.length - 1);
  var i = 0;
  while (i < args.length) {
    args[i++] = arguments[i];
  }
  process.nextTick(function afterTick() {
    fn.apply(null, args);
  });
}

}).call(this,require('_process'))

},{"_process":66}],79:[function(require,module,exports){
(function (global){

/**
 * Module exports.
 */

module.exports = deprecate;

/**
 * Mark that a method should not be used.
 * Returns a modified function which warns once by default.
 *
 * If `localStorage.noDeprecation = true` is set, then it is a no-op.
 *
 * If `localStorage.throwDeprecation = true` is set, then deprecated functions
 * will throw an Error when invoked.
 *
 * If `localStorage.traceDeprecation = true` is set, then deprecated functions
 * will invoke `console.trace()` instead of `console.error()`.
 *
 * @param {Function} fn - the function to deprecate
 * @param {String} msg - the string to print to the console when `fn` is invoked
 * @returns {Function} a new "deprecated" version of `fn`
 * @api public
 */

function deprecate (fn, msg) {
  if (config('noDeprecation')) {
    return fn;
  }

  var warned = false;
  function deprecated() {
    if (!warned) {
      if (config('throwDeprecation')) {
        throw new Error(msg);
      } else if (config('traceDeprecation')) {
        console.trace(msg);
      } else {
        console.warn(msg);
      }
      warned = true;
    }
    return fn.apply(this, arguments);
  }

  return deprecated;
}

/**
 * Checks `localStorage` for boolean values for the given `name`.
 *
 * @param {String} name
 * @returns {Boolean}
 * @api private
 */

function config (name) {
  // accessing global.localStorage can trigger a DOMException in sandboxed iframes
  try {
    if (!global.localStorage) return false;
  } catch (_) {
    return false;
  }
  var val = global.localStorage[name];
  if (null == val) return false;
  return String(val).toLowerCase() === 'true';
}

}).call(this,typeof global !== "undefined" ? global : typeof self !== "undefined" ? self : typeof window !== "undefined" ? window : {})

},{}],80:[function(require,module,exports){
module.exports = require("./lib/_stream_passthrough.js")

},{"./lib/_stream_passthrough.js":73}],81:[function(require,module,exports){
var Stream = (function (){
  try {
    return require('st' + 'ream'); // hack to fix a circular dependency issue when used with browserify
  } catch(_){}
}());
exports = module.exports = require('./lib/_stream_readable.js');
exports.Stream = Stream || exports;
exports.Readable = exports;
exports.Writable = require('./lib/_stream_writable.js');
exports.Duplex = require('./lib/_stream_duplex.js');
exports.Transform = require('./lib/_stream_transform.js');
exports.PassThrough = require('./lib/_stream_passthrough.js');

},{"./lib/_stream_duplex.js":72,"./lib/_stream_passthrough.js":73,"./lib/_stream_readable.js":74,"./lib/_stream_transform.js":75,"./lib/_stream_writable.js":76}],82:[function(require,module,exports){
module.exports = require("./lib/_stream_transform.js")

},{"./lib/_stream_transform.js":75}],83:[function(require,module,exports){
module.exports = require("./lib/_stream_writable.js")

},{"./lib/_stream_writable.js":76}],84:[function(require,module,exports){
// Copyright Joyent, Inc. and other Node contributors.
//
// Permission is hereby granted, free of charge, to any person obtaining a
// copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to permit
// persons to whom the Software is furnished to do so, subject to the
// following conditions:
//
// The above copyright notice and this permission notice shall be included
// in all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN
// NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
// DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR
// OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE
// USE OR OTHER DEALINGS IN THE SOFTWARE.

module.exports = Stream;

var EE = require('events').EventEmitter;
var inherits = require('inherits');

inherits(Stream, EE);
Stream.Readable = require('readable-stream/readable.js');
Stream.Writable = require('readable-stream/writable.js');
Stream.Duplex = require('readable-stream/duplex.js');
Stream.Transform = require('readable-stream/transform.js');
Stream.PassThrough = require('readable-stream/passthrough.js');

// Backwards-compat with node 0.4.x
Stream.Stream = Stream;



// old-style streams.  Note that the pipe method (the only relevant
// part of this class) is overridden in the Readable class.

function Stream() {
  EE.call(this);
}

Stream.prototype.pipe = function(dest, options) {
  var source = this;

  function ondata(chunk) {
    if (dest.writable) {
      if (false === dest.write(chunk) && source.pause) {
        source.pause();
      }
    }
  }

  source.on('data', ondata);

  function ondrain() {
    if (source.readable && source.resume) {
      source.resume();
    }
  }

  dest.on('drain', ondrain);

  // If the 'end' option is not supplied, dest.end() will be called when
  // source gets the 'end' or 'close' events.  Only dest.end() once.
  if (!dest._isStdio && (!options || options.end !== false)) {
    source.on('end', onend);
    source.on('close', onclose);
  }

  var didOnEnd = false;
  function onend() {
    if (didOnEnd) return;
    didOnEnd = true;

    dest.end();
  }


  function onclose() {
    if (didOnEnd) return;
    didOnEnd = true;

    if (typeof dest.destroy === 'function') dest.destroy();
  }

  // don't leave dangling pipes when there are errors.
  function onerror(er) {
    cleanup();
    if (EE.listenerCount(this, 'error') === 0) {
      throw er; // Unhandled stream error in pipe.
    }
  }

  source.on('error', onerror);
  dest.on('error', onerror);

  // remove all the event listeners that were added.
  function cleanup() {
    source.removeListener('data', ondata);
    dest.removeListener('drain', ondrain);

    source.removeListener('end', onend);
    source.removeListener('close', onclose);

    source.removeListener('error', onerror);
    dest.removeListener('error', onerror);

    source.removeListener('end', cleanup);
    source.removeListener('close', cleanup);

    dest.removeListener('close', cleanup);
  }

  source.on('end', cleanup);
  source.on('close', cleanup);

  dest.on('close', cleanup);

  dest.emit('pipe', source);

  // Allow for unix-like usage: A.pipe(B).pipe(C)
  return dest;
};

},{"events":61,"inherits":63,"readable-stream/duplex.js":71,"readable-stream/passthrough.js":80,"readable-stream/readable.js":81,"readable-stream/transform.js":82,"readable-stream/writable.js":83}],85:[function(require,module,exports){
var ClientRequest = require('./lib/request')
var extend = require('xtend')
var statusCodes = require('builtin-status-codes')
var url = require('url')

var http = exports

http.request = function (opts, cb) {
	if (typeof opts === 'string')
		opts = url.parse(opts)
	else
		opts = extend(opts)

	var protocol = opts.protocol || ''
	var host = opts.hostname || opts.host
	var port = opts.port
	var path = opts.path || '/'

	// Necessary for IPv6 addresses
	if (host && host.indexOf(':') !== -1)
		host = '[' + host + ']'

	// This may be a relative url. The browser should always be able to interpret it correctly.
	opts.url = (host ? (protocol + '//' + host) : '') + (port ? ':' + port : '') + path
	opts.method = (opts.method || 'GET').toUpperCase()
	opts.headers = opts.headers || {}

	// Also valid opts.auth, opts.mode

	var req = new ClientRequest(opts)
	if (cb)
		req.on('response', cb)
	return req
}

http.get = function get (opts, cb) {
	var req = http.request(opts, cb)
	req.end()
	return req
}

http.Agent = function () {}
http.Agent.defaultMaxSockets = 4

http.STATUS_CODES = statusCodes

http.METHODS = [
	'CHECKOUT',
	'CONNECT',
	'COPY',
	'DELETE',
	'GET',
	'HEAD',
	'LOCK',
	'M-SEARCH',
	'MERGE',
	'MKACTIVITY',
	'MKCOL',
	'MOVE',
	'NOTIFY',
	'OPTIONS',
	'PATCH',
	'POST',
	'PROPFIND',
	'PROPPATCH',
	'PURGE',
	'PUT',
	'REPORT',
	'SEARCH',
	'SUBSCRIBE',
	'TRACE',
	'UNLOCK',
	'UNSUBSCRIBE'
]
},{"./lib/request":87,"builtin-status-codes":89,"url":91,"xtend":95}],86:[function(require,module,exports){
(function (global){
exports.fetch = isFunction(global.fetch) && isFunction(global.ReadableByteStream)

exports.blobConstructor = false
try {
	new Blob([new ArrayBuffer(1)])
	exports.blobConstructor = true
} catch (e) {}

var xhr = new global.XMLHttpRequest()
// If location.host is empty, e.g. if this page/worker was loaded
// from a Blob, then use example.com to avoid an error
xhr.open('GET', global.location.host ? '/' : 'https://example.com')

function checkTypeSupport (type) {
	try {
		xhr.responseType = type
		return xhr.responseType === type
	} catch (e) {}
	return false
}

// For some strange reason, Safari 7.0 reports typeof global.ArrayBuffer === 'object'.
// Safari 7.1 appears to have fixed this bug.
var haveArrayBuffer = typeof global.ArrayBuffer !== 'undefined'
var haveSlice = haveArrayBuffer && isFunction(global.ArrayBuffer.prototype.slice)

exports.arraybuffer = haveArrayBuffer && checkTypeSupport('arraybuffer')
// These next two tests unavoidably show warnings in Chrome. Since fetch will always
// be used if it's available, just return false for these to avoid the warnings.
exports.msstream = !exports.fetch && haveSlice && checkTypeSupport('ms-stream')
exports.mozchunkedarraybuffer = !exports.fetch && haveArrayBuffer &&
	checkTypeSupport('moz-chunked-arraybuffer')
exports.overrideMimeType = isFunction(xhr.overrideMimeType)
exports.vbArray = isFunction(global.VBArray)

function isFunction (value) {
  return typeof value === 'function'
}

xhr = null // Help gc

}).call(this,typeof global !== "undefined" ? global : typeof self !== "undefined" ? self : typeof window !== "undefined" ? window : {})

},{}],87:[function(require,module,exports){
(function (process,global,Buffer){
// var Base64 = require('Base64')
var capability = require('./capability')
var inherits = require('inherits')
var response = require('./response')
var stream = require('stream')

var IncomingMessage = response.IncomingMessage
var rStates = response.readyStates

function decideMode (preferBinary) {
	if (capability.fetch) {
		return 'fetch'
	} else if (capability.mozchunkedarraybuffer) {
		return 'moz-chunked-arraybuffer'
	} else if (capability.msstream) {
		return 'ms-stream'
	} else if (capability.arraybuffer && preferBinary) {
		return 'arraybuffer'
	} else if (capability.vbArray && preferBinary) {
		return 'text:vbarray'
	} else {
		return 'text'
	}
}

var ClientRequest = module.exports = function (opts) {
	var self = this
	stream.Writable.call(self)

	self._opts = opts
	self._body = []
	self._headers = {}
	if (opts.auth)
		self.setHeader('Authorization', 'Basic ' + new Buffer(opts.auth).toString('base64'))
	Object.keys(opts.headers).forEach(function (name) {
		self.setHeader(name, opts.headers[name])
	})

	var preferBinary
	if (opts.mode === 'prefer-streaming') {
		// If streaming is a high priority but binary compatibility and
		// the accuracy of the 'content-type' header aren't
		preferBinary = false
	} else if (opts.mode === 'allow-wrong-content-type') {
		// If streaming is more important than preserving the 'content-type' header
		preferBinary = !capability.overrideMimeType
	} else if (!opts.mode || opts.mode === 'default' || opts.mode === 'prefer-fast') {
		// Use binary if text streaming may corrupt data or the content-type header, or for speed
		preferBinary = true
	} else {
		throw new Error('Invalid value for opts.mode')
	}
	self._mode = decideMode(preferBinary)

	self.on('finish', function () {
		self._onFinish()
	})
}

inherits(ClientRequest, stream.Writable)

ClientRequest.prototype.setHeader = function (name, value) {
	var self = this
	var lowerName = name.toLowerCase()
	// This check is not necessary, but it prevents warnings from browsers about setting unsafe
	// headers. To be honest I'm not entirely sure hiding these warnings is a good thing, but
	// http-browserify did it, so I will too.
	if (unsafeHeaders.indexOf(lowerName) !== -1)
		return

	self._headers[lowerName] = {
		name: name,
		value: value
	}
}

ClientRequest.prototype.getHeader = function (name) {
	var self = this
	return self._headers[name.toLowerCase()].value
}

ClientRequest.prototype.removeHeader = function (name) {
	var self = this
	delete self._headers[name.toLowerCase()]
}

ClientRequest.prototype._onFinish = function () {
	var self = this

	if (self._destroyed)
		return
	var opts = self._opts

	var headersObj = self._headers
	var body
	if (opts.method === 'POST' || opts.method === 'PUT' || opts.method === 'PATCH') {
		if (capability.blobConstructor) {
			body = new global.Blob(self._body.map(function (buffer) {
				return buffer.toArrayBuffer()
			}), {
				type: (headersObj['content-type'] || {}).value || ''
			})
		} else {
			// get utf8 string
			body = Buffer.concat(self._body).toString()
		}
	}

	if (self._mode === 'fetch') {
		var headers = Object.keys(headersObj).map(function (name) {
			return [headersObj[name].name, headersObj[name].value]
		})

		global.fetch(self._opts.url, {
			method: self._opts.method,
			headers: headers,
			body: body,
			mode: 'cors',
			credentials: opts.withCredentials ? 'include' : 'same-origin'
		}).then(function (response) {
			self._fetchResponse = response
			self._connect()
		}, function (reason) {
			self.emit('error', reason)
		})
	} else {
		var xhr = self._xhr = new global.XMLHttpRequest()
		try {
			xhr.open(self._opts.method, self._opts.url, true)
		} catch (err) {
			process.nextTick(function () {
				self.emit('error', err)
			})
			return
		}

		// Can't set responseType on really old browsers
		if ('responseType' in xhr)
			xhr.responseType = self._mode.split(':')[0]

		if ('withCredentials' in xhr)
			xhr.withCredentials = !!opts.withCredentials

		if (self._mode === 'text' && 'overrideMimeType' in xhr)
			xhr.overrideMimeType('text/plain; charset=x-user-defined')

		Object.keys(headersObj).forEach(function (name) {
			xhr.setRequestHeader(headersObj[name].name, headersObj[name].value)
		})

		self._response = null
		xhr.onreadystatechange = function () {
			switch (xhr.readyState) {
				case rStates.LOADING:
				case rStates.DONE:
					self._onXHRProgress()
					break
			}
		}
		// Necessary for streaming in Firefox, since xhr.response is ONLY defined
		// in onprogress, not in onreadystatechange with xhr.readyState = 3
		if (self._mode === 'moz-chunked-arraybuffer') {
			xhr.onprogress = function () {
				self._onXHRProgress()
			}
		}

		xhr.onerror = function () {
			if (self._destroyed)
				return
			self.emit('error', new Error('XHR error'))
		}

		try {
			xhr.send(body)
		} catch (err) {
			process.nextTick(function () {
				self.emit('error', err)
			})
			return
		}
	}
}

/**
 * Checks if xhr.status is readable. Even though the spec says it should
 * be available in readyState 3, accessing it throws an exception in IE8
 */
function statusValid (xhr) {
	try {
		return (xhr.status !== null)
	} catch (e) {
		return false
	}
}

ClientRequest.prototype._onXHRProgress = function () {
	var self = this

	if (!statusValid(self._xhr) || self._destroyed)
		return

	if (!self._response)
		self._connect()

	self._response._onXHRProgress()
}

ClientRequest.prototype._connect = function () {
	var self = this

	if (self._destroyed)
		return

	self._response = new IncomingMessage(self._xhr, self._fetchResponse, self._mode)
	self.emit('response', self._response)
}

ClientRequest.prototype._write = function (chunk, encoding, cb) {
	var self = this

	self._body.push(chunk)
	cb()
}

ClientRequest.prototype.abort = ClientRequest.prototype.destroy = function () {
	var self = this
	self._destroyed = true
	if (self._response)
		self._response._destroyed = true
	if (self._xhr)
		self._xhr.abort()
	// Currently, there isn't a way to truly abort a fetch.
	// If you like bikeshedding, see https://github.com/whatwg/fetch/issues/27
}

ClientRequest.prototype.end = function (data, encoding, cb) {
	var self = this
	if (typeof data === 'function') {
		cb = data
		data = undefined
	}

	stream.Writable.prototype.end.call(self, data, encoding, cb)
}

ClientRequest.prototype.flushHeaders = function () {}
ClientRequest.prototype.setTimeout = function () {}
ClientRequest.prototype.setNoDelay = function () {}
ClientRequest.prototype.setSocketKeepAlive = function () {}

// Taken from http://www.w3.org/TR/XMLHttpRequest/#the-setrequestheader%28%29-method
var unsafeHeaders = [
	'accept-charset',
	'accept-encoding',
	'access-control-request-headers',
	'access-control-request-method',
	'connection',
	'content-length',
	'cookie',
	'cookie2',
	'date',
	'dnt',
	'expect',
	'host',
	'keep-alive',
	'origin',
	'referer',
	'te',
	'trailer',
	'transfer-encoding',
	'upgrade',
	'user-agent',
	'via'
]

}).call(this,require('_process'),typeof global !== "undefined" ? global : typeof self !== "undefined" ? self : typeof window !== "undefined" ? window : {},require("buffer").Buffer)

},{"./capability":86,"./response":88,"_process":66,"buffer":57,"inherits":63,"stream":84}],88:[function(require,module,exports){
(function (process,global,Buffer){
var capability = require('./capability')
var inherits = require('inherits')
var stream = require('stream')

var rStates = exports.readyStates = {
	UNSENT: 0,
	OPENED: 1,
	HEADERS_RECEIVED: 2,
	LOADING: 3,
	DONE: 4
}

var IncomingMessage = exports.IncomingMessage = function (xhr, response, mode) {
	var self = this
	stream.Readable.call(self)

	self._mode = mode
	self.headers = {}
	self.rawHeaders = []
	self.trailers = {}
	self.rawTrailers = []

	// Fake the 'close' event, but only once 'end' fires
	self.on('end', function () {
		// The nextTick is necessary to prevent the 'request' module from causing an infinite loop
		process.nextTick(function () {
			self.emit('close')
		})
	})

	if (mode === 'fetch') {
		self._fetchResponse = response

		self.statusCode = response.status
		self.statusMessage = response.statusText
		// backwards compatible version of for (<item> of <iterable>):
		// for (var <item>,_i,_it = <iterable>[Symbol.iterator](); <item> = (_i = _it.next()).value,!_i.done;)
		for (var header, _i, _it = response.headers[Symbol.iterator](); header = (_i = _it.next()).value, !_i.done;) {
			self.headers[header[0].toLowerCase()] = header[1]
			self.rawHeaders.push(header[0], header[1])
		}

		// TODO: this doesn't respect backpressure. Once WritableStream is available, this can be fixed
		var reader = response.body.getReader()
		function read () {
			reader.read().then(function (result) {
				if (self._destroyed)
					return
				if (result.done) {
					self.push(null)
					return
				}
				self.push(new Buffer(result.value))
				read()
			})
		}
		read()

	} else {
		self._xhr = xhr
		self._pos = 0

		self.statusCode = xhr.status
		self.statusMessage = xhr.statusText
		var headers = xhr.getAllResponseHeaders().split(/\r?\n/)
		headers.forEach(function (header) {
			var matches = header.match(/^([^:]+):\s*(.*)/)
			if (matches) {
				var key = matches[1].toLowerCase()
				if (self.headers[key] !== undefined)
					self.headers[key] += ', ' + matches[2]
				else
					self.headers[key] = matches[2]
				self.rawHeaders.push(matches[1], matches[2])
			}
		})

		self._charset = 'x-user-defined'
		if (!capability.overrideMimeType) {
			var mimeType = self.rawHeaders['mime-type']
			if (mimeType) {
				var charsetMatch = mimeType.match(/;\s*charset=([^;])(;|$)/)
				if (charsetMatch) {
					self._charset = charsetMatch[1].toLowerCase()
				}
			}
			if (!self._charset)
				self._charset = 'utf-8' // best guess
		}
	}
}

inherits(IncomingMessage, stream.Readable)

IncomingMessage.prototype._read = function () {}

IncomingMessage.prototype._onXHRProgress = function () {
	var self = this

	var xhr = self._xhr

	var response = null
	switch (self._mode) {
		case 'text:vbarray': // For IE9
			if (xhr.readyState !== rStates.DONE)
				break
			try {
				// This fails in IE8
				response = new global.VBArray(xhr.responseBody).toArray()
			} catch (e) {}
			if (response !== null) {
				self.push(new Buffer(response))
				break
			}
			// Falls through in IE8	
		case 'text':
			try { // This will fail when readyState = 3 in IE9. Switch mode and wait for readyState = 4
				response = xhr.responseText
			} catch (e) {
				self._mode = 'text:vbarray'
				break
			}
			if (response.length > self._pos) {
				var newData = response.substr(self._pos)
				if (self._charset === 'x-user-defined') {
					var buffer = new Buffer(newData.length)
					for (var i = 0; i < newData.length; i++)
						buffer[i] = newData.charCodeAt(i) & 0xff

					self.push(buffer)
				} else {
					self.push(newData, self._charset)
				}
				self._pos = response.length
			}
			break
		case 'arraybuffer':
			if (xhr.readyState !== rStates.DONE)
				break
			response = xhr.response
			self.push(new Buffer(new Uint8Array(response)))
			break
		case 'moz-chunked-arraybuffer': // take whole
			response = xhr.response
			if (xhr.readyState !== rStates.LOADING || !response)
				break
			self.push(new Buffer(new Uint8Array(response)))
			break
		case 'ms-stream':
			response = xhr.response
			if (xhr.readyState !== rStates.LOADING)
				break
			var reader = new global.MSStreamReader()
			reader.onprogress = function () {
				if (reader.result.byteLength > self._pos) {
					self.push(new Buffer(new Uint8Array(reader.result.slice(self._pos))))
					self._pos = reader.result.byteLength
				}
			}
			reader.onload = function () {
				self.push(null)
			}
			// reader.onerror = ??? // TODO: this
			reader.readAsArrayBuffer(response)
			break
	}

	// The ms-stream case handles end separately in reader.onload()
	if (self._xhr.readyState === rStates.DONE && self._mode !== 'ms-stream') {
		self.push(null)
	}
}

}).call(this,require('_process'),typeof global !== "undefined" ? global : typeof self !== "undefined" ? self : typeof window !== "undefined" ? window : {},require("buffer").Buffer)

},{"./capability":86,"_process":66,"buffer":57,"inherits":63,"stream":84}],89:[function(require,module,exports){
module.exports = {
  "100": "Continue",
  "101": "Switching Protocols",
  "102": "Processing",
  "200": "OK",
  "201": "Created",
  "202": "Accepted",
  "203": "Non-Authoritative Information",
  "204": "No Content",
  "205": "Reset Content",
  "206": "Partial Content",
  "207": "Multi-Status",
  "300": "Multiple Choices",
  "301": "Moved Permanently",
  "302": "Moved Temporarily",
  "303": "See Other",
  "304": "Not Modified",
  "305": "Use Proxy",
  "307": "Temporary Redirect",
  "308": "Permanent Redirect",
  "400": "Bad Request",
  "401": "Unauthorized",
  "402": "Payment Required",
  "403": "Forbidden",
  "404": "Not Found",
  "405": "Method Not Allowed",
  "406": "Not Acceptable",
  "407": "Proxy Authentication Required",
  "408": "Request Time-out",
  "409": "Conflict",
  "410": "Gone",
  "411": "Length Required",
  "412": "Precondition Failed",
  "413": "Request Entity Too Large",
  "414": "Request-URI Too Large",
  "415": "Unsupported Media Type",
  "416": "Requested Range Not Satisfiable",
  "417": "Expectation Failed",
  "418": "I'm a teapot",
  "422": "Unprocessable Entity",
  "423": "Locked",
  "424": "Failed Dependency",
  "425": "Unordered Collection",
  "426": "Upgrade Required",
  "428": "Precondition Required",
  "429": "Too Many Requests",
  "431": "Request Header Fields Too Large",
  "500": "Internal Server Error",
  "501": "Not Implemented",
  "502": "Bad Gateway",
  "503": "Service Unavailable",
  "504": "Gateway Time-out",
  "505": "HTTP Version Not Supported",
  "506": "Variant Also Negotiates",
  "507": "Insufficient Storage",
  "509": "Bandwidth Limit Exceeded",
  "510": "Not Extended",
  "511": "Network Authentication Required"
}

},{}],90:[function(require,module,exports){
// Copyright Joyent, Inc. and other Node contributors.
//
// Permission is hereby granted, free of charge, to any person obtaining a
// copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to permit
// persons to whom the Software is furnished to do so, subject to the
// following conditions:
//
// The above copyright notice and this permission notice shall be included
// in all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN
// NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
// DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR
// OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE
// USE OR OTHER DEALINGS IN THE SOFTWARE.

var Buffer = require('buffer').Buffer;

var isBufferEncoding = Buffer.isEncoding
  || function(encoding) {
       switch (encoding && encoding.toLowerCase()) {
         case 'hex': case 'utf8': case 'utf-8': case 'ascii': case 'binary': case 'base64': case 'ucs2': case 'ucs-2': case 'utf16le': case 'utf-16le': case 'raw': return true;
         default: return false;
       }
     }


function assertEncoding(encoding) {
  if (encoding && !isBufferEncoding(encoding)) {
    throw new Error('Unknown encoding: ' + encoding);
  }
}

// StringDecoder provides an interface for efficiently splitting a series of
// buffers into a series of JS strings without breaking apart multi-byte
// characters. CESU-8 is handled as part of the UTF-8 encoding.
//
// @TODO Handling all encodings inside a single object makes it very difficult
// to reason about this code, so it should be split up in the future.
// @TODO There should be a utf8-strict encoding that rejects invalid UTF-8 code
// points as used by CESU-8.
var StringDecoder = exports.StringDecoder = function(encoding) {
  this.encoding = (encoding || 'utf8').toLowerCase().replace(/[-_]/, '');
  assertEncoding(encoding);
  switch (this.encoding) {
    case 'utf8':
      // CESU-8 represents each of Surrogate Pair by 3-bytes
      this.surrogateSize = 3;
      break;
    case 'ucs2':
    case 'utf16le':
      // UTF-16 represents each of Surrogate Pair by 2-bytes
      this.surrogateSize = 2;
      this.detectIncompleteChar = utf16DetectIncompleteChar;
      break;
    case 'base64':
      // Base-64 stores 3 bytes in 4 chars, and pads the remainder.
      this.surrogateSize = 3;
      this.detectIncompleteChar = base64DetectIncompleteChar;
      break;
    default:
      this.write = passThroughWrite;
      return;
  }

  // Enough space to store all bytes of a single character. UTF-8 needs 4
  // bytes, but CESU-8 may require up to 6 (3 bytes per surrogate).
  this.charBuffer = new Buffer(6);
  // Number of bytes received for the current incomplete multi-byte character.
  this.charReceived = 0;
  // Number of bytes expected for the current incomplete multi-byte character.
  this.charLength = 0;
};


// write decodes the given buffer and returns it as JS string that is
// guaranteed to not contain any partial multi-byte characters. Any partial
// character found at the end of the buffer is buffered up, and will be
// returned when calling write again with the remaining bytes.
//
// Note: Converting a Buffer containing an orphan surrogate to a String
// currently works, but converting a String to a Buffer (via `new Buffer`, or
// Buffer#write) will replace incomplete surrogates with the unicode
// replacement character. See https://codereview.chromium.org/121173009/ .
StringDecoder.prototype.write = function(buffer) {
  var charStr = '';
  // if our last write ended with an incomplete multibyte character
  while (this.charLength) {
    // determine how many remaining bytes this buffer has to offer for this char
    var available = (buffer.length >= this.charLength - this.charReceived) ?
        this.charLength - this.charReceived :
        buffer.length;

    // add the new bytes to the char buffer
    buffer.copy(this.charBuffer, this.charReceived, 0, available);
    this.charReceived += available;

    if (this.charReceived < this.charLength) {
      // still not enough chars in this buffer? wait for more ...
      return '';
    }

    // remove bytes belonging to the current character from the buffer
    buffer = buffer.slice(available, buffer.length);

    // get the character that was split
    charStr = this.charBuffer.slice(0, this.charLength).toString(this.encoding);

    // CESU-8: lead surrogate (D800-DBFF) is also the incomplete character
    var charCode = charStr.charCodeAt(charStr.length - 1);
    if (charCode >= 0xD800 && charCode <= 0xDBFF) {
      this.charLength += this.surrogateSize;
      charStr = '';
      continue;
    }
    this.charReceived = this.charLength = 0;

    // if there are no more bytes in this buffer, just emit our char
    if (buffer.length === 0) {
      return charStr;
    }
    break;
  }

  // determine and set charLength / charReceived
  this.detectIncompleteChar(buffer);

  var end = buffer.length;
  if (this.charLength) {
    // buffer the incomplete character bytes we got
    buffer.copy(this.charBuffer, 0, buffer.length - this.charReceived, end);
    end -= this.charReceived;
  }

  charStr += buffer.toString(this.encoding, 0, end);

  var end = charStr.length - 1;
  var charCode = charStr.charCodeAt(end);
  // CESU-8: lead surrogate (D800-DBFF) is also the incomplete character
  if (charCode >= 0xD800 && charCode <= 0xDBFF) {
    var size = this.surrogateSize;
    this.charLength += size;
    this.charReceived += size;
    this.charBuffer.copy(this.charBuffer, size, 0, size);
    buffer.copy(this.charBuffer, 0, 0, size);
    return charStr.substring(0, end);
  }

  // or just emit the charStr
  return charStr;
};

// detectIncompleteChar determines if there is an incomplete UTF-8 character at
// the end of the given buffer. If so, it sets this.charLength to the byte
// length that character, and sets this.charReceived to the number of bytes
// that are available for this character.
StringDecoder.prototype.detectIncompleteChar = function(buffer) {
  // determine how many bytes we have to check at the end of this buffer
  var i = (buffer.length >= 3) ? 3 : buffer.length;

  // Figure out if one of the last i bytes of our buffer announces an
  // incomplete char.
  for (; i > 0; i--) {
    var c = buffer[buffer.length - i];

    // See http://en.wikipedia.org/wiki/UTF-8#Description

    // 110XXXXX
    if (i == 1 && c >> 5 == 0x06) {
      this.charLength = 2;
      break;
    }

    // 1110XXXX
    if (i <= 2 && c >> 4 == 0x0E) {
      this.charLength = 3;
      break;
    }

    // 11110XXX
    if (i <= 3 && c >> 3 == 0x1E) {
      this.charLength = 4;
      break;
    }
  }
  this.charReceived = i;
};

StringDecoder.prototype.end = function(buffer) {
  var res = '';
  if (buffer && buffer.length)
    res = this.write(buffer);

  if (this.charReceived) {
    var cr = this.charReceived;
    var buf = this.charBuffer;
    var enc = this.encoding;
    res += buf.slice(0, cr).toString(enc);
  }

  return res;
};

function passThroughWrite(buffer) {
  return buffer.toString(this.encoding);
}

function utf16DetectIncompleteChar(buffer) {
  this.charReceived = buffer.length % 2;
  this.charLength = this.charReceived ? 2 : 0;
}

function base64DetectIncompleteChar(buffer) {
  this.charReceived = buffer.length % 3;
  this.charLength = this.charReceived ? 3 : 0;
}

},{"buffer":57}],91:[function(require,module,exports){
// Copyright Joyent, Inc. and other Node contributors.
//
// Permission is hereby granted, free of charge, to any person obtaining a
// copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to permit
// persons to whom the Software is furnished to do so, subject to the
// following conditions:
//
// The above copyright notice and this permission notice shall be included
// in all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN
// NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
// DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR
// OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE
// USE OR OTHER DEALINGS IN THE SOFTWARE.

'use strict';

var punycode = require('punycode');
var util = require('./util');

exports.parse = urlParse;
exports.resolve = urlResolve;
exports.resolveObject = urlResolveObject;
exports.format = urlFormat;

exports.Url = Url;

function Url() {
  this.protocol = null;
  this.slashes = null;
  this.auth = null;
  this.host = null;
  this.port = null;
  this.hostname = null;
  this.hash = null;
  this.search = null;
  this.query = null;
  this.pathname = null;
  this.path = null;
  this.href = null;
}

// Reference: RFC 3986, RFC 1808, RFC 2396

// define these here so at least they only have to be
// compiled once on the first module load.
var protocolPattern = /^([a-z0-9.+-]+:)/i,
    portPattern = /:[0-9]*$/,

    // Special case for a simple path URL
    simplePathPattern = /^(\/\/?(?!\/)[^\?\s]*)(\?[^\s]*)?$/,

    // RFC 2396: characters reserved for delimiting URLs.
    // We actually just auto-escape these.
    delims = ['<', '>', '"', '`', ' ', '\r', '\n', '\t'],

    // RFC 2396: characters not allowed for various reasons.
    unwise = ['{', '}', '|', '\\', '^', '`'].concat(delims),

    // Allowed by RFCs, but cause of XSS attacks.  Always escape these.
    autoEscape = ['\''].concat(unwise),
    // Characters that are never ever allowed in a hostname.
    // Note that any invalid chars are also handled, but these
    // are the ones that are *expected* to be seen, so we fast-path
    // them.
    nonHostChars = ['%', '/', '?', ';', '#'].concat(autoEscape),
    hostEndingChars = ['/', '?', '#'],
    hostnameMaxLen = 255,
    hostnamePartPattern = /^[+a-z0-9A-Z_-]{0,63}$/,
    hostnamePartStart = /^([+a-z0-9A-Z_-]{0,63})(.*)$/,
    // protocols that can allow "unsafe" and "unwise" chars.
    unsafeProtocol = {
      'javascript': true,
      'javascript:': true
    },
    // protocols that never have a hostname.
    hostlessProtocol = {
      'javascript': true,
      'javascript:': true
    },
    // protocols that always contain a // bit.
    slashedProtocol = {
      'http': true,
      'https': true,
      'ftp': true,
      'gopher': true,
      'file': true,
      'http:': true,
      'https:': true,
      'ftp:': true,
      'gopher:': true,
      'file:': true
    },
    querystring = require('querystring');

function urlParse(url, parseQueryString, slashesDenoteHost) {
  if (url && util.isObject(url) && url instanceof Url) return url;

  var u = new Url;
  u.parse(url, parseQueryString, slashesDenoteHost);
  return u;
}

Url.prototype.parse = function(url, parseQueryString, slashesDenoteHost) {
  if (!util.isString(url)) {
    throw new TypeError("Parameter 'url' must be a string, not " + typeof url);
  }

  // Copy chrome, IE, opera backslash-handling behavior.
  // Back slashes before the query string get converted to forward slashes
  // See: https://code.google.com/p/chromium/issues/detail?id=25916
  var queryIndex = url.indexOf('?'),
      splitter =
          (queryIndex !== -1 && queryIndex < url.indexOf('#')) ? '?' : '#',
      uSplit = url.split(splitter),
      slashRegex = /\\/g;
  uSplit[0] = uSplit[0].replace(slashRegex, '/');
  url = uSplit.join(splitter);

  var rest = url;

  // trim before proceeding.
  // This is to support parse stuff like "  http://foo.com  \n"
  rest = rest.trim();

  if (!slashesDenoteHost && url.split('#').length === 1) {
    // Try fast path regexp
    var simplePath = simplePathPattern.exec(rest);
    if (simplePath) {
      this.path = rest;
      this.href = rest;
      this.pathname = simplePath[1];
      if (simplePath[2]) {
        this.search = simplePath[2];
        if (parseQueryString) {
          this.query = querystring.parse(this.search.substr(1));
        } else {
          this.query = this.search.substr(1);
        }
      } else if (parseQueryString) {
        this.search = '';
        this.query = {};
      }
      return this;
    }
  }

  var proto = protocolPattern.exec(rest);
  if (proto) {
    proto = proto[0];
    var lowerProto = proto.toLowerCase();
    this.protocol = lowerProto;
    rest = rest.substr(proto.length);
  }

  // figure out if it's got a host
  // user@server is *always* interpreted as a hostname, and url
  // resolution will treat //foo/bar as host=foo,path=bar because that's
  // how the browser resolves relative URLs.
  if (slashesDenoteHost || proto || rest.match(/^\/\/[^@\/]+@[^@\/]+/)) {
    var slashes = rest.substr(0, 2) === '//';
    if (slashes && !(proto && hostlessProtocol[proto])) {
      rest = rest.substr(2);
      this.slashes = true;
    }
  }

  if (!hostlessProtocol[proto] &&
      (slashes || (proto && !slashedProtocol[proto]))) {

    // there's a hostname.
    // the first instance of /, ?, ;, or # ends the host.
    //
    // If there is an @ in the hostname, then non-host chars *are* allowed
    // to the left of the last @ sign, unless some host-ending character
    // comes *before* the @-sign.
    // URLs are obnoxious.
    //
    // ex:
    // http://a@b@c/ => user:a@b host:c
    // http://a@b?@c => user:a host:c path:/?@c

    // v0.12 TODO(isaacs): This is not quite how Chrome does things.
    // Review our test case against browsers more comprehensively.

    // find the first instance of any hostEndingChars
    var hostEnd = -1;
    for (var i = 0; i < hostEndingChars.length; i++) {
      var hec = rest.indexOf(hostEndingChars[i]);
      if (hec !== -1 && (hostEnd === -1 || hec < hostEnd))
        hostEnd = hec;
    }

    // at this point, either we have an explicit point where the
    // auth portion cannot go past, or the last @ char is the decider.
    var auth, atSign;
    if (hostEnd === -1) {
      // atSign can be anywhere.
      atSign = rest.lastIndexOf('@');
    } else {
      // atSign must be in auth portion.
      // http://a@b/c@d => host:b auth:a path:/c@d
      atSign = rest.lastIndexOf('@', hostEnd);
    }

    // Now we have a portion which is definitely the auth.
    // Pull that off.
    if (atSign !== -1) {
      auth = rest.slice(0, atSign);
      rest = rest.slice(atSign + 1);
      this.auth = decodeURIComponent(auth);
    }

    // the host is the remaining to the left of the first non-host char
    hostEnd = -1;
    for (var i = 0; i < nonHostChars.length; i++) {
      var hec = rest.indexOf(nonHostChars[i]);
      if (hec !== -1 && (hostEnd === -1 || hec < hostEnd))
        hostEnd = hec;
    }
    // if we still have not hit it, then the entire thing is a host.
    if (hostEnd === -1)
      hostEnd = rest.length;

    this.host = rest.slice(0, hostEnd);
    rest = rest.slice(hostEnd);

    // pull out port.
    this.parseHost();

    // we've indicated that there is a hostname,
    // so even if it's empty, it has to be present.
    this.hostname = this.hostname || '';

    // if hostname begins with [ and ends with ]
    // assume that it's an IPv6 address.
    var ipv6Hostname = this.hostname[0] === '[' &&
        this.hostname[this.hostname.length - 1] === ']';

    // validate a little.
    if (!ipv6Hostname) {
      var hostparts = this.hostname.split(/\./);
      for (var i = 0, l = hostparts.length; i < l; i++) {
        var part = hostparts[i];
        if (!part) continue;
        if (!part.match(hostnamePartPattern)) {
          var newpart = '';
          for (var j = 0, k = part.length; j < k; j++) {
            if (part.charCodeAt(j) > 127) {
              // we replace non-ASCII char with a temporary placeholder
              // we need this to make sure size of hostname is not
              // broken by replacing non-ASCII by nothing
              newpart += 'x';
            } else {
              newpart += part[j];
            }
          }
          // we test again with ASCII char only
          if (!newpart.match(hostnamePartPattern)) {
            var validParts = hostparts.slice(0, i);
            var notHost = hostparts.slice(i + 1);
            var bit = part.match(hostnamePartStart);
            if (bit) {
              validParts.push(bit[1]);
              notHost.unshift(bit[2]);
            }
            if (notHost.length) {
              rest = '/' + notHost.join('.') + rest;
            }
            this.hostname = validParts.join('.');
            break;
          }
        }
      }
    }

    if (this.hostname.length > hostnameMaxLen) {
      this.hostname = '';
    } else {
      // hostnames are always lower case.
      this.hostname = this.hostname.toLowerCase();
    }

    if (!ipv6Hostname) {
      // IDNA Support: Returns a punycoded representation of "domain".
      // It only converts parts of the domain name that
      // have non-ASCII characters, i.e. it doesn't matter if
      // you call it with a domain that already is ASCII-only.
      this.hostname = punycode.toASCII(this.hostname);
    }

    var p = this.port ? ':' + this.port : '';
    var h = this.hostname || '';
    this.host = h + p;
    this.href += this.host;

    // strip [ and ] from the hostname
    // the host field still retains them, though
    if (ipv6Hostname) {
      this.hostname = this.hostname.substr(1, this.hostname.length - 2);
      if (rest[0] !== '/') {
        rest = '/' + rest;
      }
    }
  }

  // now rest is set to the post-host stuff.
  // chop off any delim chars.
  if (!unsafeProtocol[lowerProto]) {

    // First, make 100% sure that any "autoEscape" chars get
    // escaped, even if encodeURIComponent doesn't think they
    // need to be.
    for (var i = 0, l = autoEscape.length; i < l; i++) {
      var ae = autoEscape[i];
      if (rest.indexOf(ae) === -1)
        continue;
      var esc = encodeURIComponent(ae);
      if (esc === ae) {
        esc = escape(ae);
      }
      rest = rest.split(ae).join(esc);
    }
  }


  // chop off from the tail first.
  var hash = rest.indexOf('#');
  if (hash !== -1) {
    // got a fragment string.
    this.hash = rest.substr(hash);
    rest = rest.slice(0, hash);
  }
  var qm = rest.indexOf('?');
  if (qm !== -1) {
    this.search = rest.substr(qm);
    this.query = rest.substr(qm + 1);
    if (parseQueryString) {
      this.query = querystring.parse(this.query);
    }
    rest = rest.slice(0, qm);
  } else if (parseQueryString) {
    // no query string, but parseQueryString still requested
    this.search = '';
    this.query = {};
  }
  if (rest) this.pathname = rest;
  if (slashedProtocol[lowerProto] &&
      this.hostname && !this.pathname) {
    this.pathname = '/';
  }

  //to support http.request
  if (this.pathname || this.search) {
    var p = this.pathname || '';
    var s = this.search || '';
    this.path = p + s;
  }

  // finally, reconstruct the href based on what has been validated.
  this.href = this.format();
  return this;
};

// format a parsed object into a url string
function urlFormat(obj) {
  // ensure it's an object, and not a string url.
  // If it's an obj, this is a no-op.
  // this way, you can call url_format() on strings
  // to clean up potentially wonky urls.
  if (util.isString(obj)) obj = urlParse(obj);
  if (!(obj instanceof Url)) return Url.prototype.format.call(obj);
  return obj.format();
}

Url.prototype.format = function() {
  var auth = this.auth || '';
  if (auth) {
    auth = encodeURIComponent(auth);
    auth = auth.replace(/%3A/i, ':');
    auth += '@';
  }

  var protocol = this.protocol || '',
      pathname = this.pathname || '',
      hash = this.hash || '',
      host = false,
      query = '';

  if (this.host) {
    host = auth + this.host;
  } else if (this.hostname) {
    host = auth + (this.hostname.indexOf(':') === -1 ?
        this.hostname :
        '[' + this.hostname + ']');
    if (this.port) {
      host += ':' + this.port;
    }
  }

  if (this.query &&
      util.isObject(this.query) &&
      Object.keys(this.query).length) {
    query = querystring.stringify(this.query);
  }

  var search = this.search || (query && ('?' + query)) || '';

  if (protocol && protocol.substr(-1) !== ':') protocol += ':';

  // only the slashedProtocols get the //.  Not mailto:, xmpp:, etc.
  // unless they had them to begin with.
  if (this.slashes ||
      (!protocol || slashedProtocol[protocol]) && host !== false) {
    host = '//' + (host || '');
    if (pathname && pathname.charAt(0) !== '/') pathname = '/' + pathname;
  } else if (!host) {
    host = '';
  }

  if (hash && hash.charAt(0) !== '#') hash = '#' + hash;
  if (search && search.charAt(0) !== '?') search = '?' + search;

  pathname = pathname.replace(/[?#]/g, function(match) {
    return encodeURIComponent(match);
  });
  search = search.replace('#', '%23');

  return protocol + host + pathname + search + hash;
};

function urlResolve(source, relative) {
  return urlParse(source, false, true).resolve(relative);
}

Url.prototype.resolve = function(relative) {
  return this.resolveObject(urlParse(relative, false, true)).format();
};

function urlResolveObject(source, relative) {
  if (!source) return relative;
  return urlParse(source, false, true).resolveObject(relative);
}

Url.prototype.resolveObject = function(relative) {
  if (util.isString(relative)) {
    var rel = new Url();
    rel.parse(relative, false, true);
    relative = rel;
  }

  var result = new Url();
  var tkeys = Object.keys(this);
  for (var tk = 0; tk < tkeys.length; tk++) {
    var tkey = tkeys[tk];
    result[tkey] = this[tkey];
  }

  // hash is always overridden, no matter what.
  // even href="" will remove it.
  result.hash = relative.hash;

  // if the relative url is empty, then there's nothing left to do here.
  if (relative.href === '') {
    result.href = result.format();
    return result;
  }

  // hrefs like //foo/bar always cut to the protocol.
  if (relative.slashes && !relative.protocol) {
    // take everything except the protocol from relative
    var rkeys = Object.keys(relative);
    for (var rk = 0; rk < rkeys.length; rk++) {
      var rkey = rkeys[rk];
      if (rkey !== 'protocol')
        result[rkey] = relative[rkey];
    }

    //urlParse appends trailing / to urls like http://www.example.com
    if (slashedProtocol[result.protocol] &&
        result.hostname && !result.pathname) {
      result.path = result.pathname = '/';
    }

    result.href = result.format();
    return result;
  }

  if (relative.protocol && relative.protocol !== result.protocol) {
    // if it's a known url protocol, then changing
    // the protocol does weird things
    // first, if it's not file:, then we MUST have a host,
    // and if there was a path
    // to begin with, then we MUST have a path.
    // if it is file:, then the host is dropped,
    // because that's known to be hostless.
    // anything else is assumed to be absolute.
    if (!slashedProtocol[relative.protocol]) {
      var keys = Object.keys(relative);
      for (var v = 0; v < keys.length; v++) {
        var k = keys[v];
        result[k] = relative[k];
      }
      result.href = result.format();
      return result;
    }

    result.protocol = relative.protocol;
    if (!relative.host && !hostlessProtocol[relative.protocol]) {
      var relPath = (relative.pathname || '').split('/');
      while (relPath.length && !(relative.host = relPath.shift()));
      if (!relative.host) relative.host = '';
      if (!relative.hostname) relative.hostname = '';
      if (relPath[0] !== '') relPath.unshift('');
      if (relPath.length < 2) relPath.unshift('');
      result.pathname = relPath.join('/');
    } else {
      result.pathname = relative.pathname;
    }
    result.search = relative.search;
    result.query = relative.query;
    result.host = relative.host || '';
    result.auth = relative.auth;
    result.hostname = relative.hostname || relative.host;
    result.port = relative.port;
    // to support http.request
    if (result.pathname || result.search) {
      var p = result.pathname || '';
      var s = result.search || '';
      result.path = p + s;
    }
    result.slashes = result.slashes || relative.slashes;
    result.href = result.format();
    return result;
  }

  var isSourceAbs = (result.pathname && result.pathname.charAt(0) === '/'),
      isRelAbs = (
          relative.host ||
          relative.pathname && relative.pathname.charAt(0) === '/'
      ),
      mustEndAbs = (isRelAbs || isSourceAbs ||
                    (result.host && relative.pathname)),
      removeAllDots = mustEndAbs,
      srcPath = result.pathname && result.pathname.split('/') || [],
      relPath = relative.pathname && relative.pathname.split('/') || [],
      psychotic = result.protocol && !slashedProtocol[result.protocol];

  // if the url is a non-slashed url, then relative
  // links like ../.. should be able
  // to crawl up to the hostname, as well.  This is strange.
  // result.protocol has already been set by now.
  // Later on, put the first path part into the host field.
  if (psychotic) {
    result.hostname = '';
    result.port = null;
    if (result.host) {
      if (srcPath[0] === '') srcPath[0] = result.host;
      else srcPath.unshift(result.host);
    }
    result.host = '';
    if (relative.protocol) {
      relative.hostname = null;
      relative.port = null;
      if (relative.host) {
        if (relPath[0] === '') relPath[0] = relative.host;
        else relPath.unshift(relative.host);
      }
      relative.host = null;
    }
    mustEndAbs = mustEndAbs && (relPath[0] === '' || srcPath[0] === '');
  }

  if (isRelAbs) {
    // it's absolute.
    result.host = (relative.host || relative.host === '') ?
                  relative.host : result.host;
    result.hostname = (relative.hostname || relative.hostname === '') ?
                      relative.hostname : result.hostname;
    result.search = relative.search;
    result.query = relative.query;
    srcPath = relPath;
    // fall through to the dot-handling below.
  } else if (relPath.length) {
    // it's relative
    // throw away the existing file, and take the new path instead.
    if (!srcPath) srcPath = [];
    srcPath.pop();
    srcPath = srcPath.concat(relPath);
    result.search = relative.search;
    result.query = relative.query;
  } else if (!util.isNullOrUndefined(relative.search)) {
    // just pull out the search.
    // like href='?foo'.
    // Put this after the other two cases because it simplifies the booleans
    if (psychotic) {
      result.hostname = result.host = srcPath.shift();
      //occationaly the auth can get stuck only in host
      //this especially happens in cases like
      //url.resolveObject('mailto:local1@domain1', 'local2@domain2')
      var authInHost = result.host && result.host.indexOf('@') > 0 ?
                       result.host.split('@') : false;
      if (authInHost) {
        result.auth = authInHost.shift();
        result.host = result.hostname = authInHost.shift();
      }
    }
    result.search = relative.search;
    result.query = relative.query;
    //to support http.request
    if (!util.isNull(result.pathname) || !util.isNull(result.search)) {
      result.path = (result.pathname ? result.pathname : '') +
                    (result.search ? result.search : '');
    }
    result.href = result.format();
    return result;
  }

  if (!srcPath.length) {
    // no path at all.  easy.
    // we've already handled the other stuff above.
    result.pathname = null;
    //to support http.request
    if (result.search) {
      result.path = '/' + result.search;
    } else {
      result.path = null;
    }
    result.href = result.format();
    return result;
  }

  // if a url ENDs in . or .., then it must get a trailing slash.
  // however, if it ends in anything else non-slashy,
  // then it must NOT get a trailing slash.
  var last = srcPath.slice(-1)[0];
  var hasTrailingSlash = (
      (result.host || relative.host || srcPath.length > 1) &&
      (last === '.' || last === '..') || last === '');

  // strip single dots, resolve double dots to parent dir
  // if the path tries to go above the root, `up` ends up > 0
  var up = 0;
  for (var i = srcPath.length; i >= 0; i--) {
    last = srcPath[i];
    if (last === '.') {
      srcPath.splice(i, 1);
    } else if (last === '..') {
      srcPath.splice(i, 1);
      up++;
    } else if (up) {
      srcPath.splice(i, 1);
      up--;
    }
  }

  // if the path is allowed to go above the root, restore leading ..s
  if (!mustEndAbs && !removeAllDots) {
    for (; up--; up) {
      srcPath.unshift('..');
    }
  }

  if (mustEndAbs && srcPath[0] !== '' &&
      (!srcPath[0] || srcPath[0].charAt(0) !== '/')) {
    srcPath.unshift('');
  }

  if (hasTrailingSlash && (srcPath.join('/').substr(-1) !== '/')) {
    srcPath.push('');
  }

  var isAbsolute = srcPath[0] === '' ||
      (srcPath[0] && srcPath[0].charAt(0) === '/');

  // put the host back
  if (psychotic) {
    result.hostname = result.host = isAbsolute ? '' :
                                    srcPath.length ? srcPath.shift() : '';
    //occationaly the auth can get stuck only in host
    //this especially happens in cases like
    //url.resolveObject('mailto:local1@domain1', 'local2@domain2')
    var authInHost = result.host && result.host.indexOf('@') > 0 ?
                     result.host.split('@') : false;
    if (authInHost) {
      result.auth = authInHost.shift();
      result.host = result.hostname = authInHost.shift();
    }
  }

  mustEndAbs = mustEndAbs || (result.host && srcPath.length);

  if (mustEndAbs && !isAbsolute) {
    srcPath.unshift('');
  }

  if (!srcPath.length) {
    result.pathname = null;
    result.path = null;
  } else {
    result.pathname = srcPath.join('/');
  }

  //to support request.http
  if (!util.isNull(result.pathname) || !util.isNull(result.search)) {
    result.path = (result.pathname ? result.pathname : '') +
                  (result.search ? result.search : '');
  }
  result.auth = relative.auth || result.auth;
  result.slashes = result.slashes || relative.slashes;
  result.href = result.format();
  return result;
};

Url.prototype.parseHost = function() {
  var host = this.host;
  var port = portPattern.exec(host);
  if (port) {
    port = port[0];
    if (port !== ':') {
      this.port = port.substr(1);
    }
    host = host.substr(0, host.length - port.length);
  }
  if (host) this.hostname = host;
};

},{"./util":92,"punycode":67,"querystring":70}],92:[function(require,module,exports){
'use strict';

module.exports = {
  isString: function(arg) {
    return typeof(arg) === 'string';
  },
  isObject: function(arg) {
    return typeof(arg) === 'object' && arg !== null;
  },
  isNull: function(arg) {
    return arg === null;
  },
  isNullOrUndefined: function(arg) {
    return arg == null;
  }
};

},{}],93:[function(require,module,exports){
module.exports = function isBuffer(arg) {
  return arg && typeof arg === 'object'
    && typeof arg.copy === 'function'
    && typeof arg.fill === 'function'
    && typeof arg.readUInt8 === 'function';
}
},{}],94:[function(require,module,exports){
(function (process,global){
// Copyright Joyent, Inc. and other Node contributors.
//
// Permission is hereby granted, free of charge, to any person obtaining a
// copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to permit
// persons to whom the Software is furnished to do so, subject to the
// following conditions:
//
// The above copyright notice and this permission notice shall be included
// in all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN
// NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
// DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR
// OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE
// USE OR OTHER DEALINGS IN THE SOFTWARE.

var formatRegExp = /%[sdj%]/g;
exports.format = function(f) {
  if (!isString(f)) {
    var objects = [];
    for (var i = 0; i < arguments.length; i++) {
      objects.push(inspect(arguments[i]));
    }
    return objects.join(' ');
  }

  var i = 1;
  var args = arguments;
  var len = args.length;
  var str = String(f).replace(formatRegExp, function(x) {
    if (x === '%%') return '%';
    if (i >= len) return x;
    switch (x) {
      case '%s': return String(args[i++]);
      case '%d': return Number(args[i++]);
      case '%j':
        try {
          return JSON.stringify(args[i++]);
        } catch (_) {
          return '[Circular]';
        }
      default:
        return x;
    }
  });
  for (var x = args[i]; i < len; x = args[++i]) {
    if (isNull(x) || !isObject(x)) {
      str += ' ' + x;
    } else {
      str += ' ' + inspect(x);
    }
  }
  return str;
};


// Mark that a method should not be used.
// Returns a modified function which warns once by default.
// If --no-deprecation is set, then it is a no-op.
exports.deprecate = function(fn, msg) {
  // Allow for deprecating things in the process of starting up.
  if (isUndefined(global.process)) {
    return function() {
      return exports.deprecate(fn, msg).apply(this, arguments);
    };
  }

  if (process.noDeprecation === true) {
    return fn;
  }

  var warned = false;
  function deprecated() {
    if (!warned) {
      if (process.throwDeprecation) {
        throw new Error(msg);
      } else if (process.traceDeprecation) {
        console.trace(msg);
      } else {
        console.error(msg);
      }
      warned = true;
    }
    return fn.apply(this, arguments);
  }

  return deprecated;
};


var debugs = {};
var debugEnviron;
exports.debuglog = function(set) {
  if (isUndefined(debugEnviron))
    debugEnviron = process.env.NODE_DEBUG || '';
  set = set.toUpperCase();
  if (!debugs[set]) {
    if (new RegExp('\\b' + set + '\\b', 'i').test(debugEnviron)) {
      var pid = process.pid;
      debugs[set] = function() {
        var msg = exports.format.apply(exports, arguments);
        console.error('%s %d: %s', set, pid, msg);
      };
    } else {
      debugs[set] = function() {};
    }
  }
  return debugs[set];
};


/**
 * Echos the value of a value. Trys to print the value out
 * in the best way possible given the different types.
 *
 * @param {Object} obj The object to print out.
 * @param {Object} opts Optional options object that alters the output.
 */
/* legacy: obj, showHidden, depth, colors*/
function inspect(obj, opts) {
  // default options
  var ctx = {
    seen: [],
    stylize: stylizeNoColor
  };
  // legacy...
  if (arguments.length >= 3) ctx.depth = arguments[2];
  if (arguments.length >= 4) ctx.colors = arguments[3];
  if (isBoolean(opts)) {
    // legacy...
    ctx.showHidden = opts;
  } else if (opts) {
    // got an "options" object
    exports._extend(ctx, opts);
  }
  // set default options
  if (isUndefined(ctx.showHidden)) ctx.showHidden = false;
  if (isUndefined(ctx.depth)) ctx.depth = 2;
  if (isUndefined(ctx.colors)) ctx.colors = false;
  if (isUndefined(ctx.customInspect)) ctx.customInspect = true;
  if (ctx.colors) ctx.stylize = stylizeWithColor;
  return formatValue(ctx, obj, ctx.depth);
}
exports.inspect = inspect;


// http://en.wikipedia.org/wiki/ANSI_escape_code#graphics
inspect.colors = {
  'bold' : [1, 22],
  'italic' : [3, 23],
  'underline' : [4, 24],
  'inverse' : [7, 27],
  'white' : [37, 39],
  'grey' : [90, 39],
  'black' : [30, 39],
  'blue' : [34, 39],
  'cyan' : [36, 39],
  'green' : [32, 39],
  'magenta' : [35, 39],
  'red' : [31, 39],
  'yellow' : [33, 39]
};

// Don't use 'blue' not visible on cmd.exe
inspect.styles = {
  'special': 'cyan',
  'number': 'yellow',
  'boolean': 'yellow',
  'undefined': 'grey',
  'null': 'bold',
  'string': 'green',
  'date': 'magenta',
  // "name": intentionally not styling
  'regexp': 'red'
};


function stylizeWithColor(str, styleType) {
  var style = inspect.styles[styleType];

  if (style) {
    return '\u001b[' + inspect.colors[style][0] + 'm' + str +
           '\u001b[' + inspect.colors[style][1] + 'm';
  } else {
    return str;
  }
}


function stylizeNoColor(str, styleType) {
  return str;
}


function arrayToHash(array) {
  var hash = {};

  array.forEach(function(val, idx) {
    hash[val] = true;
  });

  return hash;
}


function formatValue(ctx, value, recurseTimes) {
  // Provide a hook for user-specified inspect functions.
  // Check that value is an object with an inspect function on it
  if (ctx.customInspect &&
      value &&
      isFunction(value.inspect) &&
      // Filter out the util module, it's inspect function is special
      value.inspect !== exports.inspect &&
      // Also filter out any prototype objects using the circular check.
      !(value.constructor && value.constructor.prototype === value)) {
    var ret = value.inspect(recurseTimes, ctx);
    if (!isString(ret)) {
      ret = formatValue(ctx, ret, recurseTimes);
    }
    return ret;
  }

  // Primitive types cannot have properties
  var primitive = formatPrimitive(ctx, value);
  if (primitive) {
    return primitive;
  }

  // Look up the keys of the object.
  var keys = Object.keys(value);
  var visibleKeys = arrayToHash(keys);

  if (ctx.showHidden) {
    keys = Object.getOwnPropertyNames(value);
  }

  // IE doesn't make error fields non-enumerable
  // http://msdn.microsoft.com/en-us/library/ie/dww52sbt(v=vs.94).aspx
  if (isError(value)
      && (keys.indexOf('message') >= 0 || keys.indexOf('description') >= 0)) {
    return formatError(value);
  }

  // Some type of object without properties can be shortcutted.
  if (keys.length === 0) {
    if (isFunction(value)) {
      var name = value.name ? ': ' + value.name : '';
      return ctx.stylize('[Function' + name + ']', 'special');
    }
    if (isRegExp(value)) {
      return ctx.stylize(RegExp.prototype.toString.call(value), 'regexp');
    }
    if (isDate(value)) {
      return ctx.stylize(Date.prototype.toString.call(value), 'date');
    }
    if (isError(value)) {
      return formatError(value);
    }
  }

  var base = '', array = false, braces = ['{', '}'];

  // Make Array say that they are Array
  if (isArray(value)) {
    array = true;
    braces = ['[', ']'];
  }

  // Make functions say that they are functions
  if (isFunction(value)) {
    var n = value.name ? ': ' + value.name : '';
    base = ' [Function' + n + ']';
  }

  // Make RegExps say that they are RegExps
  if (isRegExp(value)) {
    base = ' ' + RegExp.prototype.toString.call(value);
  }

  // Make dates with properties first say the date
  if (isDate(value)) {
    base = ' ' + Date.prototype.toUTCString.call(value);
  }

  // Make error with message first say the error
  if (isError(value)) {
    base = ' ' + formatError(value);
  }

  if (keys.length === 0 && (!array || value.length == 0)) {
    return braces[0] + base + braces[1];
  }

  if (recurseTimes < 0) {
    if (isRegExp(value)) {
      return ctx.stylize(RegExp.prototype.toString.call(value), 'regexp');
    } else {
      return ctx.stylize('[Object]', 'special');
    }
  }

  ctx.seen.push(value);

  var output;
  if (array) {
    output = formatArray(ctx, value, recurseTimes, visibleKeys, keys);
  } else {
    output = keys.map(function(key) {
      return formatProperty(ctx, value, recurseTimes, visibleKeys, key, array);
    });
  }

  ctx.seen.pop();

  return reduceToSingleString(output, base, braces);
}


function formatPrimitive(ctx, value) {
  if (isUndefined(value))
    return ctx.stylize('undefined', 'undefined');
  if (isString(value)) {
    var simple = '\'' + JSON.stringify(value).replace(/^"|"$/g, '')
                                             .replace(/'/g, "\\'")
                                             .replace(/\\"/g, '"') + '\'';
    return ctx.stylize(simple, 'string');
  }
  if (isNumber(value))
    return ctx.stylize('' + value, 'number');
  if (isBoolean(value))
    return ctx.stylize('' + value, 'boolean');
  // For some reason typeof null is "object", so special case here.
  if (isNull(value))
    return ctx.stylize('null', 'null');
}


function formatError(value) {
  return '[' + Error.prototype.toString.call(value) + ']';
}


function formatArray(ctx, value, recurseTimes, visibleKeys, keys) {
  var output = [];
  for (var i = 0, l = value.length; i < l; ++i) {
    if (hasOwnProperty(value, String(i))) {
      output.push(formatProperty(ctx, value, recurseTimes, visibleKeys,
          String(i), true));
    } else {
      output.push('');
    }
  }
  keys.forEach(function(key) {
    if (!key.match(/^\d+$/)) {
      output.push(formatProperty(ctx, value, recurseTimes, visibleKeys,
          key, true));
    }
  });
  return output;
}


function formatProperty(ctx, value, recurseTimes, visibleKeys, key, array) {
  var name, str, desc;
  desc = Object.getOwnPropertyDescriptor(value, key) || { value: value[key] };
  if (desc.get) {
    if (desc.set) {
      str = ctx.stylize('[Getter/Setter]', 'special');
    } else {
      str = ctx.stylize('[Getter]', 'special');
    }
  } else {
    if (desc.set) {
      str = ctx.stylize('[Setter]', 'special');
    }
  }
  if (!hasOwnProperty(visibleKeys, key)) {
    name = '[' + key + ']';
  }
  if (!str) {
    if (ctx.seen.indexOf(desc.value) < 0) {
      if (isNull(recurseTimes)) {
        str = formatValue(ctx, desc.value, null);
      } else {
        str = formatValue(ctx, desc.value, recurseTimes - 1);
      }
      if (str.indexOf('\n') > -1) {
        if (array) {
          str = str.split('\n').map(function(line) {
            return '  ' + line;
          }).join('\n').substr(2);
        } else {
          str = '\n' + str.split('\n').map(function(line) {
            return '   ' + line;
          }).join('\n');
        }
      }
    } else {
      str = ctx.stylize('[Circular]', 'special');
    }
  }
  if (isUndefined(name)) {
    if (array && key.match(/^\d+$/)) {
      return str;
    }
    name = JSON.stringify('' + key);
    if (name.match(/^"([a-zA-Z_][a-zA-Z_0-9]*)"$/)) {
      name = name.substr(1, name.length - 2);
      name = ctx.stylize(name, 'name');
    } else {
      name = name.replace(/'/g, "\\'")
                 .replace(/\\"/g, '"')
                 .replace(/(^"|"$)/g, "'");
      name = ctx.stylize(name, 'string');
    }
  }

  return name + ': ' + str;
}


function reduceToSingleString(output, base, braces) {
  var numLinesEst = 0;
  var length = output.reduce(function(prev, cur) {
    numLinesEst++;
    if (cur.indexOf('\n') >= 0) numLinesEst++;
    return prev + cur.replace(/\u001b\[\d\d?m/g, '').length + 1;
  }, 0);

  if (length > 60) {
    return braces[0] +
           (base === '' ? '' : base + '\n ') +
           ' ' +
           output.join(',\n  ') +
           ' ' +
           braces[1];
  }

  return braces[0] + base + ' ' + output.join(', ') + ' ' + braces[1];
}


// NOTE: These type checking functions intentionally don't use `instanceof`
// because it is fragile and can be easily faked with `Object.create()`.
function isArray(ar) {
  return Array.isArray(ar);
}
exports.isArray = isArray;

function isBoolean(arg) {
  return typeof arg === 'boolean';
}
exports.isBoolean = isBoolean;

function isNull(arg) {
  return arg === null;
}
exports.isNull = isNull;

function isNullOrUndefined(arg) {
  return arg == null;
}
exports.isNullOrUndefined = isNullOrUndefined;

function isNumber(arg) {
  return typeof arg === 'number';
}
exports.isNumber = isNumber;

function isString(arg) {
  return typeof arg === 'string';
}
exports.isString = isString;

function isSymbol(arg) {
  return typeof arg === 'symbol';
}
exports.isSymbol = isSymbol;

function isUndefined(arg) {
  return arg === void 0;
}
exports.isUndefined = isUndefined;

function isRegExp(re) {
  return isObject(re) && objectToString(re) === '[object RegExp]';
}
exports.isRegExp = isRegExp;

function isObject(arg) {
  return typeof arg === 'object' && arg !== null;
}
exports.isObject = isObject;

function isDate(d) {
  return isObject(d) && objectToString(d) === '[object Date]';
}
exports.isDate = isDate;

function isError(e) {
  return isObject(e) &&
      (objectToString(e) === '[object Error]' || e instanceof Error);
}
exports.isError = isError;

function isFunction(arg) {
  return typeof arg === 'function';
}
exports.isFunction = isFunction;

function isPrimitive(arg) {
  return arg === null ||
         typeof arg === 'boolean' ||
         typeof arg === 'number' ||
         typeof arg === 'string' ||
         typeof arg === 'symbol' ||  // ES6 symbol
         typeof arg === 'undefined';
}
exports.isPrimitive = isPrimitive;

exports.isBuffer = require('./support/isBuffer');

function objectToString(o) {
  return Object.prototype.toString.call(o);
}


function pad(n) {
  return n < 10 ? '0' + n.toString(10) : n.toString(10);
}


var months = ['Jan', 'Feb', 'Mar', 'Apr', 'May', 'Jun', 'Jul', 'Aug', 'Sep',
              'Oct', 'Nov', 'Dec'];

// 26 Feb 16:19:34
function timestamp() {
  var d = new Date();
  var time = [pad(d.getHours()),
              pad(d.getMinutes()),
              pad(d.getSeconds())].join(':');
  return [d.getDate(), months[d.getMonth()], time].join(' ');
}


// log is just a thin wrapper to console.log that prepends a timestamp
exports.log = function() {
  console.log('%s - %s', timestamp(), exports.format.apply(exports, arguments));
};


/**
 * Inherit the prototype methods from one constructor into another.
 *
 * The Function.prototype.inherits from lang.js rewritten as a standalone
 * function (not on Function.prototype). NOTE: If this file is to be loaded
 * during bootstrapping this function needs to be rewritten using some native
 * functions as prototype setup using normal JavaScript does not work as
 * expected during bootstrapping (see mirror.js in r114903).
 *
 * @param {function} ctor Constructor function which needs to inherit the
 *     prototype.
 * @param {function} superCtor Constructor function to inherit prototype from.
 */
exports.inherits = require('inherits');

exports._extend = function(origin, add) {
  // Don't do anything if add isn't an object
  if (!add || !isObject(add)) return origin;

  var keys = Object.keys(add);
  var i = keys.length;
  while (i--) {
    origin[keys[i]] = add[keys[i]];
  }
  return origin;
};

function hasOwnProperty(obj, prop) {
  return Object.prototype.hasOwnProperty.call(obj, prop);
}

}).call(this,require('_process'),typeof global !== "undefined" ? global : typeof self !== "undefined" ? self : typeof window !== "undefined" ? window : {})

},{"./support/isBuffer":93,"_process":66,"inherits":63}],95:[function(require,module,exports){
module.exports = extend

var hasOwnProperty = Object.prototype.hasOwnProperty;

function extend() {
    var target = {}

    for (var i = 0; i < arguments.length; i++) {
        var source = arguments[i]

        for (var key in source) {
            if (hasOwnProperty.call(source, key)) {
                target[key] = source[key]
            }
        }
    }

    return target
}

},{}]},{},[4])(4)
});
//# sourceMappingURL=ref-parser.js.map
